/* Automatically @generated by tree-sitter v0.25.9 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 9557
#define LARGE_STATE_COUNT 2738
#define SYMBOL_COUNT 555
#define ALIAS_COUNT 5
#define TOKEN_COUNT 232
#define EXTERNAL_TOKEN_COUNT 2
#define FIELD_COUNT 50
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 221
#define SUPERTYPE_COUNT 7

enum ts_symbol_identifiers {
  sym_identifier = 1,
  aux_sym_preproc_include_token1 = 2,
  aux_sym_preproc_include_token2 = 3,
  aux_sym_preproc_def_token1 = 4,
  anon_sym_LPAREN = 5,
  anon_sym_DOT_DOT_DOT = 6,
  anon_sym_COMMA = 7,
  anon_sym_RPAREN = 8,
  aux_sym_preproc_if_token1 = 9,
  anon_sym_LF = 10,
  aux_sym_preproc_if_token2 = 11,
  aux_sym_preproc_ifdef_token1 = 12,
  aux_sym_preproc_ifdef_token2 = 13,
  aux_sym_preproc_else_token1 = 14,
  aux_sym_preproc_elif_token1 = 15,
  aux_sym_preproc_elifdef_token1 = 16,
  aux_sym_preproc_elifdef_token2 = 17,
  sym_preproc_arg = 18,
  sym_preproc_directive = 19,
  anon_sym_LPAREN2 = 20,
  anon_sym_defined = 21,
  anon_sym_BANG = 22,
  anon_sym_TILDE = 23,
  anon_sym_DASH = 24,
  anon_sym_PLUS = 25,
  anon_sym_STAR = 26,
  anon_sym_SLASH = 27,
  anon_sym_PERCENT = 28,
  anon_sym_PIPE_PIPE = 29,
  anon_sym_AMP_AMP = 30,
  anon_sym_PIPE = 31,
  anon_sym_CARET = 32,
  anon_sym_AMP = 33,
  anon_sym_EQ_EQ = 34,
  anon_sym_BANG_EQ = 35,
  anon_sym_GT = 36,
  anon_sym_GT_EQ = 37,
  anon_sym_LT_EQ = 38,
  anon_sym_LT = 39,
  anon_sym_LT_LT = 40,
  anon_sym_GT_GT = 41,
  anon_sym_SEMI = 42,
  anon_sym___extension__ = 43,
  anon_sym_typedef = 44,
  anon_sym___device__ = 45,
  anon_sym___host__ = 46,
  anon_sym___global__ = 47,
  anon_sym___forceinline__ = 48,
  anon_sym___noinline__ = 49,
  anon_sym_virtual = 50,
  anon_sym_extern = 51,
  anon_sym___attribute__ = 52,
  anon_sym___attribute = 53,
  anon_sym_COLON_COLON = 54,
  anon_sym_LBRACK_LBRACK = 55,
  anon_sym_RBRACK_RBRACK = 56,
  anon_sym___declspec = 57,
  anon_sym___based = 58,
  anon_sym___cdecl = 59,
  anon_sym___clrcall = 60,
  anon_sym___stdcall = 61,
  anon_sym___fastcall = 62,
  anon_sym___thiscall = 63,
  anon_sym___vectorcall = 64,
  sym_ms_restrict_modifier = 65,
  sym_ms_unsigned_ptr_modifier = 66,
  sym_ms_signed_ptr_modifier = 67,
  anon_sym__unaligned = 68,
  anon_sym___unaligned = 69,
  anon_sym_LBRACE = 70,
  anon_sym_RBRACE = 71,
  anon_sym_signed = 72,
  anon_sym_unsigned = 73,
  anon_sym_long = 74,
  anon_sym_short = 75,
  anon_sym_LBRACK = 76,
  anon_sym_static = 77,
  anon_sym_RBRACK = 78,
  anon_sym_EQ = 79,
  anon_sym_register = 80,
  anon_sym_inline = 81,
  anon_sym___inline = 82,
  anon_sym___inline__ = 83,
  anon_sym___forceinline = 84,
  anon_sym_thread_local = 85,
  anon_sym___thread = 86,
  anon_sym_const = 87,
  anon_sym_constexpr = 88,
  anon_sym_volatile = 89,
  anon_sym_restrict = 90,
  anon_sym___restrict__ = 91,
  anon_sym__Atomic = 92,
  anon_sym__Noreturn = 93,
  anon_sym_noreturn = 94,
  anon_sym__Nonnull = 95,
  anon_sym_mutable = 96,
  anon_sym_constinit = 97,
  anon_sym_consteval = 98,
  anon_sym___shared__ = 99,
  anon_sym___local__ = 100,
  anon_sym___constant__ = 101,
  anon_sym___managed__ = 102,
  anon_sym___grid_constant__ = 103,
  anon_sym_alignas = 104,
  anon_sym__Alignas = 105,
  sym_primitive_type = 106,
  anon_sym_enum = 107,
  anon_sym_class = 108,
  anon_sym_struct = 109,
  anon_sym_union = 110,
  anon_sym_COLON = 111,
  anon_sym_if = 112,
  anon_sym_else = 113,
  anon_sym_switch = 114,
  anon_sym_case = 115,
  anon_sym_default = 116,
  anon_sym_while = 117,
  anon_sym_do = 118,
  anon_sym_for = 119,
  anon_sym_return = 120,
  anon_sym_break = 121,
  anon_sym_continue = 122,
  anon_sym_goto = 123,
  anon_sym___try = 124,
  anon_sym___except = 125,
  anon_sym___finally = 126,
  anon_sym___leave = 127,
  anon_sym_QMARK = 128,
  anon_sym_STAR_EQ = 129,
  anon_sym_SLASH_EQ = 130,
  anon_sym_PERCENT_EQ = 131,
  anon_sym_PLUS_EQ = 132,
  anon_sym_DASH_EQ = 133,
  anon_sym_LT_LT_EQ = 134,
  anon_sym_GT_GT_EQ = 135,
  anon_sym_AMP_EQ = 136,
  anon_sym_CARET_EQ = 137,
  anon_sym_PIPE_EQ = 138,
  anon_sym_and_eq = 139,
  anon_sym_or_eq = 140,
  anon_sym_xor_eq = 141,
  anon_sym_not = 142,
  anon_sym_compl = 143,
  anon_sym_LT_EQ_GT = 144,
  anon_sym_or = 145,
  anon_sym_and = 146,
  anon_sym_bitor = 147,
  anon_sym_xor = 148,
  anon_sym_bitand = 149,
  anon_sym_not_eq = 150,
  anon_sym_DASH_DASH = 151,
  anon_sym_PLUS_PLUS = 152,
  anon_sym_sizeof = 153,
  anon_sym___alignof__ = 154,
  anon_sym___alignof = 155,
  anon_sym__alignof = 156,
  anon_sym_alignof = 157,
  anon_sym__Alignof = 158,
  anon_sym_offsetof = 159,
  anon_sym__Generic = 160,
  anon_sym_asm = 161,
  anon_sym___asm__ = 162,
  anon_sym___asm = 163,
  anon_sym___volatile__ = 164,
  anon_sym_DOT = 165,
  anon_sym_DOT_STAR = 166,
  anon_sym_DASH_GT = 167,
  sym_number_literal = 168,
  anon_sym_L_SQUOTE = 169,
  anon_sym_u_SQUOTE = 170,
  anon_sym_U_SQUOTE = 171,
  anon_sym_u8_SQUOTE = 172,
  anon_sym_SQUOTE = 173,
  aux_sym_char_literal_token1 = 174,
  anon_sym_L_DQUOTE = 175,
  anon_sym_u_DQUOTE = 176,
  anon_sym_U_DQUOTE = 177,
  anon_sym_u8_DQUOTE = 178,
  anon_sym_DQUOTE = 179,
  aux_sym_string_literal_token1 = 180,
  sym_escape_sequence = 181,
  sym_system_lib_string = 182,
  sym_true = 183,
  sym_false = 184,
  anon_sym_NULL = 185,
  anon_sym_nullptr = 186,
  sym_comment = 187,
  sym_auto = 188,
  anon_sym_decltype = 189,
  anon_sym_final = 190,
  anon_sym_override = 191,
  anon_sym_explicit = 192,
  anon_sym_typename = 193,
  anon_sym_template = 194,
  anon_sym_GT2 = 195,
  anon_sym_operator = 196,
  anon_sym_try = 197,
  anon_sym_delete = 198,
  aux_sym_pure_virtual_clause_token1 = 199,
  anon_sym_friend = 200,
  anon_sym_public = 201,
  anon_sym_private = 202,
  anon_sym_protected = 203,
  anon_sym_noexcept = 204,
  anon_sym_throw = 205,
  anon_sym_namespace = 206,
  anon_sym_using = 207,
  anon_sym_static_assert = 208,
  anon_sym_concept = 209,
  anon_sym_co_return = 210,
  anon_sym_co_yield = 211,
  anon_sym_catch = 212,
  anon_sym_R_DQUOTE = 213,
  anon_sym_LR_DQUOTE = 214,
  anon_sym_uR_DQUOTE = 215,
  anon_sym_UR_DQUOTE = 216,
  anon_sym_u8R_DQUOTE = 217,
  anon_sym_co_await = 218,
  anon_sym_new = 219,
  anon_sym_requires = 220,
  anon_sym_DASH_GT_STAR = 221,
  anon_sym_LPAREN_RPAREN = 222,
  anon_sym_LBRACK_RBRACK = 223,
  anon_sym_DQUOTE_DQUOTE = 224,
  sym_this = 225,
  sym_literal_suffix = 226,
  aux_sym_kernel_call_syntax_token1 = 227,
  aux_sym_kernel_call_syntax_token2 = 228,
  anon_sym___launch_bounds__ = 229,
  sym_raw_string_delimiter = 230,
  sym_raw_string_content = 231,
  sym_translation_unit = 232,
  sym__top_level_item = 233,
  sym__block_item = 234,
  sym_preproc_include = 235,
  sym_preproc_def = 236,
  sym_preproc_function_def = 237,
  sym_preproc_params = 238,
  sym_preproc_call = 239,
  sym_preproc_if = 240,
  sym_preproc_ifdef = 241,
  sym_preproc_else = 242,
  sym_preproc_elif = 243,
  sym_preproc_elifdef = 244,
  sym_preproc_if_in_field_declaration_list = 245,
  sym_preproc_ifdef_in_field_declaration_list = 246,
  sym_preproc_else_in_field_declaration_list = 247,
  sym_preproc_elif_in_field_declaration_list = 248,
  sym_preproc_elifdef_in_field_declaration_list = 249,
  sym_preproc_if_in_enumerator_list = 250,
  sym_preproc_ifdef_in_enumerator_list = 251,
  sym_preproc_else_in_enumerator_list = 252,
  sym_preproc_elif_in_enumerator_list = 253,
  sym_preproc_elifdef_in_enumerator_list = 254,
  sym_preproc_if_in_enumerator_list_no_comma = 255,
  sym_preproc_ifdef_in_enumerator_list_no_comma = 256,
  sym_preproc_else_in_enumerator_list_no_comma = 257,
  sym_preproc_elif_in_enumerator_list_no_comma = 258,
  sym_preproc_elifdef_in_enumerator_list_no_comma = 259,
  sym__preproc_expression = 260,
  sym_preproc_parenthesized_expression = 261,
  sym_preproc_defined = 262,
  sym_preproc_unary_expression = 263,
  sym_preproc_call_expression = 264,
  sym_preproc_argument_list = 265,
  sym_preproc_binary_expression = 266,
  sym_function_definition = 267,
  sym_declaration = 268,
  sym_type_definition = 269,
  sym__type_definition_type = 270,
  sym__type_definition_declarators = 271,
  sym__declaration_modifiers = 272,
  sym__declaration_specifiers = 273,
  sym_linkage_specification = 274,
  sym_attribute_specifier = 275,
  sym_attribute = 276,
  sym_attribute_declaration = 277,
  sym_ms_declspec_modifier = 278,
  sym_ms_based_modifier = 279,
  sym_ms_call_modifier = 280,
  sym_ms_unaligned_ptr_modifier = 281,
  sym_ms_pointer_modifier = 282,
  sym_declaration_list = 283,
  sym__declarator = 284,
  sym__field_declarator = 285,
  sym__type_declarator = 286,
  sym__abstract_declarator = 287,
  sym_parenthesized_declarator = 288,
  sym_parenthesized_field_declarator = 289,
  sym_parenthesized_type_declarator = 290,
  sym_abstract_parenthesized_declarator = 291,
  sym_attributed_declarator = 292,
  sym_attributed_field_declarator = 293,
  sym_attributed_type_declarator = 294,
  sym_pointer_declarator = 295,
  sym_pointer_field_declarator = 296,
  sym_pointer_type_declarator = 297,
  sym_abstract_pointer_declarator = 298,
  sym_function_declarator = 299,
  sym_function_field_declarator = 300,
  sym_function_type_declarator = 301,
  sym_abstract_function_declarator = 302,
  sym_array_declarator = 303,
  sym_array_field_declarator = 304,
  sym_array_type_declarator = 305,
  sym_abstract_array_declarator = 306,
  sym_init_declarator = 307,
  sym_compound_statement = 308,
  sym_storage_class_specifier = 309,
  sym_type_qualifier = 310,
  sym_alignas_qualifier = 311,
  sym_type_specifier = 312,
  sym_sized_type_specifier = 313,
  sym_enum_specifier = 314,
  sym_enumerator_list = 315,
  sym_struct_specifier = 316,
  sym_union_specifier = 317,
  sym_field_declaration_list = 318,
  sym__field_declaration_list_item = 319,
  sym_field_declaration = 320,
  sym_bitfield_clause = 321,
  sym_enumerator = 322,
  sym_parameter_list = 323,
  sym_parameter_declaration = 324,
  sym_attributed_statement = 325,
  sym_statement = 326,
  sym__top_level_statement = 327,
  sym_labeled_statement = 328,
  sym__top_level_expression_statement = 329,
  sym_expression_statement = 330,
  sym_if_statement = 331,
  sym_else_clause = 332,
  sym_switch_statement = 333,
  sym_case_statement = 334,
  sym_while_statement = 335,
  sym_do_statement = 336,
  sym_for_statement = 337,
  sym__for_statement_body = 338,
  sym_return_statement = 339,
  sym_break_statement = 340,
  sym_continue_statement = 341,
  sym_goto_statement = 342,
  sym_seh_try_statement = 343,
  sym_seh_except_clause = 344,
  sym_seh_finally_clause = 345,
  sym_seh_leave_statement = 346,
  sym_expression = 347,
  sym__string = 348,
  sym_comma_expression = 349,
  sym_conditional_expression = 350,
  sym_assignment_expression = 351,
  sym_pointer_expression = 352,
  sym_unary_expression = 353,
  sym_binary_expression = 354,
  sym_update_expression = 355,
  sym_cast_expression = 356,
  sym_type_descriptor = 357,
  sym_sizeof_expression = 358,
  sym_alignof_expression = 359,
  sym_offsetof_expression = 360,
  sym_generic_expression = 361,
  sym_subscript_expression = 362,
  sym_call_expression = 363,
  sym_gnu_asm_expression = 364,
  sym_gnu_asm_qualifier = 365,
  sym_gnu_asm_output_operand_list = 366,
  sym_gnu_asm_output_operand = 367,
  sym_gnu_asm_input_operand_list = 368,
  sym_gnu_asm_input_operand = 369,
  sym_gnu_asm_clobber_list = 370,
  sym_gnu_asm_goto_list = 371,
  sym_extension_expression = 372,
  sym_argument_list = 373,
  sym_field_expression = 374,
  sym_compound_literal_expression = 375,
  sym_parenthesized_expression = 376,
  sym_initializer_list = 377,
  sym_initializer_pair = 378,
  sym_subscript_designator = 379,
  sym_subscript_range_designator = 380,
  sym_field_designator = 381,
  sym_char_literal = 382,
  sym_concatenated_string = 383,
  sym_string_literal = 384,
  sym_null = 385,
  sym__empty_declaration = 386,
  sym_placeholder_type_specifier = 387,
  sym_decltype_auto = 388,
  sym_decltype = 389,
  sym__class_declaration = 390,
  sym__class_declaration_item = 391,
  sym_class_specifier = 392,
  sym__class_name = 393,
  sym_virtual_specifier = 394,
  sym_explicit_function_specifier = 395,
  sym_base_class_clause = 396,
  sym__enum_base_clause = 397,
  sym_dependent_type = 398,
  sym_template_declaration = 399,
  sym_template_instantiation = 400,
  sym_template_parameter_list = 401,
  sym_type_parameter_declaration = 402,
  sym_variadic_type_parameter_declaration = 403,
  sym_optional_type_parameter_declaration = 404,
  sym_template_template_parameter_declaration = 405,
  sym_optional_parameter_declaration = 406,
  sym_variadic_parameter_declaration = 407,
  sym_variadic_declarator = 408,
  sym_variadic_reference_declarator = 409,
  sym_operator_cast = 410,
  sym_field_initializer_list = 411,
  sym_field_initializer = 412,
  sym_inline_method_definition = 413,
  sym__constructor_specifiers = 414,
  sym_operator_cast_definition = 415,
  sym_operator_cast_declaration = 416,
  sym_constructor_try_statement = 417,
  sym_constructor_or_destructor_definition = 418,
  sym_constructor_or_destructor_declaration = 419,
  sym_default_method_clause = 420,
  sym_delete_method_clause = 421,
  sym_pure_virtual_clause = 422,
  sym_friend_declaration = 423,
  sym_access_specifier = 424,
  sym_reference_declarator = 425,
  sym_reference_field_declarator = 426,
  sym_reference_type_declarator = 427,
  sym_abstract_reference_declarator = 428,
  sym_structured_binding_declarator = 429,
  sym_ref_qualifier = 430,
  sym__function_declarator_seq = 431,
  sym__function_attributes_start = 432,
  sym__function_exception_specification = 433,
  sym__function_attributes_end = 434,
  sym__function_postfix = 435,
  sym_trailing_return_type = 436,
  sym_noexcept = 437,
  sym_throw_specifier = 438,
  sym_template_type = 439,
  sym_template_method = 440,
  sym_template_function = 441,
  sym_template_argument_list = 442,
  sym_namespace_definition = 443,
  sym_namespace_alias_definition = 444,
  sym__namespace_specifier = 445,
  sym_nested_namespace_specifier = 446,
  sym_using_declaration = 447,
  sym_alias_declaration = 448,
  sym_static_assert_declaration = 449,
  sym_concept_definition = 450,
  sym_for_range_loop = 451,
  sym__for_range_loop_body = 452,
  sym_init_statement = 453,
  sym_condition_clause = 454,
  sym_condition_declaration = 455,
  sym_co_return_statement = 456,
  sym_co_yield_statement = 457,
  sym_throw_statement = 458,
  sym_try_statement = 459,
  sym_catch_clause = 460,
  sym_raw_string_literal = 461,
  sym_subscript_argument_list = 462,
  sym_co_await_expression = 463,
  sym_new_expression = 464,
  sym_new_declarator = 465,
  sym_delete_expression = 466,
  sym_type_requirement = 467,
  sym_compound_requirement = 468,
  sym__requirement = 469,
  sym_requirement_seq = 470,
  sym_constraint_conjunction = 471,
  sym_constraint_disjunction = 472,
  sym__requirement_clause_constraint = 473,
  sym_requires_clause = 474,
  sym_requires_parameter_list = 475,
  sym_requires_expression = 476,
  sym_lambda_expression = 477,
  sym_lambda_capture_specifier = 478,
  sym_lambda_default_capture = 479,
  sym__lambda_capture_identifier = 480,
  sym_lambda_capture_initializer = 481,
  sym__lambda_capture = 482,
  sym__fold_operator = 483,
  sym__binary_fold_operator = 484,
  sym__unary_left_fold = 485,
  sym__unary_right_fold = 486,
  sym__binary_fold = 487,
  sym_fold_expression = 488,
  sym_parameter_pack_expansion = 489,
  sym_type_parameter_pack_expansion = 490,
  sym_identifier_parameter_pack_expansion = 491,
  sym_destructor_name = 492,
  sym_dependent_identifier = 493,
  sym_dependent_field_identifier = 494,
  sym_dependent_type_identifier = 495,
  sym__scope_resolution = 496,
  sym_qualified_field_identifier = 497,
  sym_qualified_identifier = 498,
  sym_qualified_type_identifier = 499,
  sym_qualified_operator_cast_identifier = 500,
  sym__assignment_expression_lhs = 501,
  sym_operator_name = 502,
  sym_user_defined_literal = 503,
  sym_kernel_call_expression = 504,
  sym_kernel_call_syntax = 505,
  sym_launch_bounds = 506,
  aux_sym_translation_unit_repeat1 = 507,
  aux_sym_preproc_params_repeat1 = 508,
  aux_sym_preproc_if_repeat1 = 509,
  aux_sym_preproc_if_in_field_declaration_list_repeat1 = 510,
  aux_sym_preproc_if_in_enumerator_list_repeat1 = 511,
  aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1 = 512,
  aux_sym_preproc_argument_list_repeat1 = 513,
  aux_sym_declaration_repeat1 = 514,
  aux_sym_type_definition_repeat1 = 515,
  aux_sym__type_definition_type_repeat1 = 516,
  aux_sym__type_definition_declarators_repeat1 = 517,
  aux_sym__declaration_specifiers_repeat1 = 518,
  aux_sym_attribute_declaration_repeat1 = 519,
  aux_sym_attributed_declarator_repeat1 = 520,
  aux_sym_pointer_declarator_repeat1 = 521,
  aux_sym_array_declarator_repeat1 = 522,
  aux_sym_sized_type_specifier_repeat1 = 523,
  aux_sym_enumerator_list_repeat1 = 524,
  aux_sym_field_declaration_repeat1 = 525,
  aux_sym_parameter_list_repeat1 = 526,
  aux_sym_case_statement_repeat1 = 527,
  aux_sym_generic_expression_repeat1 = 528,
  aux_sym_gnu_asm_expression_repeat1 = 529,
  aux_sym_gnu_asm_output_operand_list_repeat1 = 530,
  aux_sym_gnu_asm_input_operand_list_repeat1 = 531,
  aux_sym_gnu_asm_clobber_list_repeat1 = 532,
  aux_sym_gnu_asm_goto_list_repeat1 = 533,
  aux_sym_argument_list_repeat1 = 534,
  aux_sym_initializer_list_repeat1 = 535,
  aux_sym_initializer_pair_repeat1 = 536,
  aux_sym_char_literal_repeat1 = 537,
  aux_sym_concatenated_string_repeat1 = 538,
  aux_sym_string_literal_repeat1 = 539,
  aux_sym__class_declaration_repeat1 = 540,
  aux_sym_base_class_clause_repeat1 = 541,
  aux_sym_template_parameter_list_repeat1 = 542,
  aux_sym_field_initializer_list_repeat1 = 543,
  aux_sym_operator_cast_definition_repeat1 = 544,
  aux_sym_constructor_try_statement_repeat1 = 545,
  aux_sym_structured_binding_declarator_repeat1 = 546,
  aux_sym__function_postfix_repeat1 = 547,
  aux_sym_throw_specifier_repeat1 = 548,
  aux_sym_template_argument_list_repeat1 = 549,
  aux_sym_subscript_argument_list_repeat1 = 550,
  aux_sym_requirement_seq_repeat1 = 551,
  aux_sym_requires_parameter_list_repeat1 = 552,
  aux_sym_lambda_capture_specifier_repeat1 = 553,
  aux_sym_kernel_call_syntax_repeat1 = 554,
  alias_sym_field_identifier = 555,
  alias_sym_namespace_identifier = 556,
  alias_sym_simple_requirement = 557,
  alias_sym_statement_identifier = 558,
  alias_sym_type_identifier = 559,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [aux_sym_preproc_include_token1] = "#include",
  [aux_sym_preproc_include_token2] = "preproc_include_token2",
  [aux_sym_preproc_def_token1] = "#define",
  [anon_sym_LPAREN] = "(",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_COMMA] = ",",
  [anon_sym_RPAREN] = ")",
  [aux_sym_preproc_if_token1] = "#if",
  [anon_sym_LF] = "\n",
  [aux_sym_preproc_if_token2] = "#endif",
  [aux_sym_preproc_ifdef_token1] = "#ifdef",
  [aux_sym_preproc_ifdef_token2] = "#ifndef",
  [aux_sym_preproc_else_token1] = "#else",
  [aux_sym_preproc_elif_token1] = "#elif",
  [aux_sym_preproc_elifdef_token1] = "#elifdef",
  [aux_sym_preproc_elifdef_token2] = "#elifndef",
  [sym_preproc_arg] = "preproc_arg",
  [sym_preproc_directive] = "preproc_directive",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_defined] = "defined",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_DASH] = "-",
  [anon_sym_PLUS] = "+",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_AMP] = "&",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_SEMI] = ";",
  [anon_sym___extension__] = "__extension__",
  [anon_sym_typedef] = "typedef",
  [anon_sym___device__] = "__device__",
  [anon_sym___host__] = "__host__",
  [anon_sym___global__] = "__global__",
  [anon_sym___forceinline__] = "__forceinline__",
  [anon_sym___noinline__] = "__noinline__",
  [anon_sym_virtual] = "virtual",
  [anon_sym_extern] = "extern",
  [anon_sym___attribute__] = "__attribute__",
  [anon_sym___attribute] = "__attribute",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_LBRACK_LBRACK] = "[[",
  [anon_sym_RBRACK_RBRACK] = "]]",
  [anon_sym___declspec] = "__declspec",
  [anon_sym___based] = "__based",
  [anon_sym___cdecl] = "__cdecl",
  [anon_sym___clrcall] = "__clrcall",
  [anon_sym___stdcall] = "__stdcall",
  [anon_sym___fastcall] = "__fastcall",
  [anon_sym___thiscall] = "__thiscall",
  [anon_sym___vectorcall] = "__vectorcall",
  [sym_ms_restrict_modifier] = "ms_restrict_modifier",
  [sym_ms_unsigned_ptr_modifier] = "ms_unsigned_ptr_modifier",
  [sym_ms_signed_ptr_modifier] = "ms_signed_ptr_modifier",
  [anon_sym__unaligned] = "_unaligned",
  [anon_sym___unaligned] = "__unaligned",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_signed] = "signed",
  [anon_sym_unsigned] = "unsigned",
  [anon_sym_long] = "long",
  [anon_sym_short] = "short",
  [anon_sym_LBRACK] = "[",
  [anon_sym_static] = "static",
  [anon_sym_RBRACK] = "]",
  [anon_sym_EQ] = "=",
  [anon_sym_register] = "register",
  [anon_sym_inline] = "inline",
  [anon_sym___inline] = "__inline",
  [anon_sym___inline__] = "__inline__",
  [anon_sym___forceinline] = "__forceinline",
  [anon_sym_thread_local] = "thread_local",
  [anon_sym___thread] = "__thread",
  [anon_sym_const] = "const",
  [anon_sym_constexpr] = "constexpr",
  [anon_sym_volatile] = "volatile",
  [anon_sym_restrict] = "restrict",
  [anon_sym___restrict__] = "__restrict__",
  [anon_sym__Atomic] = "_Atomic",
  [anon_sym__Noreturn] = "_Noreturn",
  [anon_sym_noreturn] = "noreturn",
  [anon_sym__Nonnull] = "_Nonnull",
  [anon_sym_mutable] = "mutable",
  [anon_sym_constinit] = "constinit",
  [anon_sym_consteval] = "consteval",
  [anon_sym___shared__] = "__shared__",
  [anon_sym___local__] = "__local__",
  [anon_sym___constant__] = "__constant__",
  [anon_sym___managed__] = "__managed__",
  [anon_sym___grid_constant__] = "__grid_constant__",
  [anon_sym_alignas] = "alignas",
  [anon_sym__Alignas] = "_Alignas",
  [sym_primitive_type] = "primitive_type",
  [anon_sym_enum] = "enum",
  [anon_sym_class] = "class",
  [anon_sym_struct] = "struct",
  [anon_sym_union] = "union",
  [anon_sym_COLON] = ":",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_switch] = "switch",
  [anon_sym_case] = "case",
  [anon_sym_default] = "default",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_for] = "for",
  [anon_sym_return] = "return",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_goto] = "goto",
  [anon_sym___try] = "__try",
  [anon_sym___except] = "__except",
  [anon_sym___finally] = "__finally",
  [anon_sym___leave] = "__leave",
  [anon_sym_QMARK] = "\?",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_and_eq] = "and_eq",
  [anon_sym_or_eq] = "or_eq",
  [anon_sym_xor_eq] = "xor_eq",
  [anon_sym_not] = "not",
  [anon_sym_compl] = "compl",
  [anon_sym_LT_EQ_GT] = "<=>",
  [anon_sym_or] = "or",
  [anon_sym_and] = "and",
  [anon_sym_bitor] = "bitor",
  [anon_sym_xor] = "xor",
  [anon_sym_bitand] = "bitand",
  [anon_sym_not_eq] = "not_eq",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_sizeof] = "sizeof",
  [anon_sym___alignof__] = "__alignof__",
  [anon_sym___alignof] = "__alignof",
  [anon_sym__alignof] = "_alignof",
  [anon_sym_alignof] = "alignof",
  [anon_sym__Alignof] = "_Alignof",
  [anon_sym_offsetof] = "offsetof",
  [anon_sym__Generic] = "_Generic",
  [anon_sym_asm] = "asm",
  [anon_sym___asm__] = "__asm__",
  [anon_sym___asm] = "__asm",
  [anon_sym___volatile__] = "__volatile__",
  [anon_sym_DOT] = ".",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_DASH_GT] = "->",
  [sym_number_literal] = "number_literal",
  [anon_sym_L_SQUOTE] = "L'",
  [anon_sym_u_SQUOTE] = "u'",
  [anon_sym_U_SQUOTE] = "U'",
  [anon_sym_u8_SQUOTE] = "u8'",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_char_literal_token1] = "character",
  [anon_sym_L_DQUOTE] = "L\"",
  [anon_sym_u_DQUOTE] = "u\"",
  [anon_sym_U_DQUOTE] = "U\"",
  [anon_sym_u8_DQUOTE] = "u8\"",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_literal_token1] = "string_content",
  [sym_escape_sequence] = "escape_sequence",
  [sym_system_lib_string] = "system_lib_string",
  [sym_true] = "true",
  [sym_false] = "false",
  [anon_sym_NULL] = "NULL",
  [anon_sym_nullptr] = "nullptr",
  [sym_comment] = "comment",
  [sym_auto] = "auto",
  [anon_sym_decltype] = "decltype",
  [anon_sym_final] = "final",
  [anon_sym_override] = "override",
  [anon_sym_explicit] = "explicit",
  [anon_sym_typename] = "typename",
  [anon_sym_template] = "template",
  [anon_sym_GT2] = ">",
  [anon_sym_operator] = "operator",
  [anon_sym_try] = "try",
  [anon_sym_delete] = "delete",
  [aux_sym_pure_virtual_clause_token1] = "pure_virtual_clause_token1",
  [anon_sym_friend] = "friend",
  [anon_sym_public] = "public",
  [anon_sym_private] = "private",
  [anon_sym_protected] = "protected",
  [anon_sym_noexcept] = "noexcept",
  [anon_sym_throw] = "throw",
  [anon_sym_namespace] = "namespace",
  [anon_sym_using] = "using",
  [anon_sym_static_assert] = "static_assert",
  [anon_sym_concept] = "concept",
  [anon_sym_co_return] = "co_return",
  [anon_sym_co_yield] = "co_yield",
  [anon_sym_catch] = "catch",
  [anon_sym_R_DQUOTE] = "R\"",
  [anon_sym_LR_DQUOTE] = "LR\"",
  [anon_sym_uR_DQUOTE] = "uR\"",
  [anon_sym_UR_DQUOTE] = "UR\"",
  [anon_sym_u8R_DQUOTE] = "u8R\"",
  [anon_sym_co_await] = "co_await",
  [anon_sym_new] = "new",
  [anon_sym_requires] = "requires",
  [anon_sym_DASH_GT_STAR] = "->*",
  [anon_sym_LPAREN_RPAREN] = "()",
  [anon_sym_LBRACK_RBRACK] = "[]",
  [anon_sym_DQUOTE_DQUOTE] = "\"\"",
  [sym_this] = "this",
  [sym_literal_suffix] = "literal_suffix",
  [aux_sym_kernel_call_syntax_token1] = "<<<",
  [aux_sym_kernel_call_syntax_token2] = ">>>",
  [anon_sym___launch_bounds__] = "__launch_bounds__",
  [sym_raw_string_delimiter] = "raw_string_delimiter",
  [sym_raw_string_content] = "raw_string_content",
  [sym_translation_unit] = "translation_unit",
  [sym__top_level_item] = "_top_level_item",
  [sym__block_item] = "_block_item",
  [sym_preproc_include] = "preproc_include",
  [sym_preproc_def] = "preproc_def",
  [sym_preproc_function_def] = "preproc_function_def",
  [sym_preproc_params] = "preproc_params",
  [sym_preproc_call] = "preproc_call",
  [sym_preproc_if] = "preproc_if",
  [sym_preproc_ifdef] = "preproc_ifdef",
  [sym_preproc_else] = "preproc_else",
  [sym_preproc_elif] = "preproc_elif",
  [sym_preproc_elifdef] = "preproc_elifdef",
  [sym_preproc_if_in_field_declaration_list] = "preproc_if",
  [sym_preproc_ifdef_in_field_declaration_list] = "preproc_ifdef",
  [sym_preproc_else_in_field_declaration_list] = "preproc_else",
  [sym_preproc_elif_in_field_declaration_list] = "preproc_elif",
  [sym_preproc_elifdef_in_field_declaration_list] = "preproc_elifdef",
  [sym_preproc_if_in_enumerator_list] = "preproc_if",
  [sym_preproc_ifdef_in_enumerator_list] = "preproc_ifdef",
  [sym_preproc_else_in_enumerator_list] = "preproc_else",
  [sym_preproc_elif_in_enumerator_list] = "preproc_elif",
  [sym_preproc_elifdef_in_enumerator_list] = "preproc_elifdef",
  [sym_preproc_if_in_enumerator_list_no_comma] = "preproc_if",
  [sym_preproc_ifdef_in_enumerator_list_no_comma] = "preproc_ifdef",
  [sym_preproc_else_in_enumerator_list_no_comma] = "preproc_else",
  [sym_preproc_elif_in_enumerator_list_no_comma] = "preproc_elif",
  [sym_preproc_elifdef_in_enumerator_list_no_comma] = "preproc_elifdef",
  [sym__preproc_expression] = "_preproc_expression",
  [sym_preproc_parenthesized_expression] = "parenthesized_expression",
  [sym_preproc_defined] = "preproc_defined",
  [sym_preproc_unary_expression] = "unary_expression",
  [sym_preproc_call_expression] = "call_expression",
  [sym_preproc_argument_list] = "argument_list",
  [sym_preproc_binary_expression] = "binary_expression",
  [sym_function_definition] = "function_definition",
  [sym_declaration] = "declaration",
  [sym_type_definition] = "type_definition",
  [sym__type_definition_type] = "_type_definition_type",
  [sym__type_definition_declarators] = "_type_definition_declarators",
  [sym__declaration_modifiers] = "_declaration_modifiers",
  [sym__declaration_specifiers] = "_declaration_specifiers",
  [sym_linkage_specification] = "linkage_specification",
  [sym_attribute_specifier] = "attribute_specifier",
  [sym_attribute] = "attribute",
  [sym_attribute_declaration] = "attribute_declaration",
  [sym_ms_declspec_modifier] = "ms_declspec_modifier",
  [sym_ms_based_modifier] = "ms_based_modifier",
  [sym_ms_call_modifier] = "ms_call_modifier",
  [sym_ms_unaligned_ptr_modifier] = "ms_unaligned_ptr_modifier",
  [sym_ms_pointer_modifier] = "ms_pointer_modifier",
  [sym_declaration_list] = "declaration_list",
  [sym__declarator] = "_declarator",
  [sym__field_declarator] = "_field_declarator",
  [sym__type_declarator] = "_type_declarator",
  [sym__abstract_declarator] = "_abstract_declarator",
  [sym_parenthesized_declarator] = "parenthesized_declarator",
  [sym_parenthesized_field_declarator] = "parenthesized_declarator",
  [sym_parenthesized_type_declarator] = "parenthesized_declarator",
  [sym_abstract_parenthesized_declarator] = "abstract_parenthesized_declarator",
  [sym_attributed_declarator] = "attributed_declarator",
  [sym_attributed_field_declarator] = "attributed_declarator",
  [sym_attributed_type_declarator] = "attributed_declarator",
  [sym_pointer_declarator] = "pointer_declarator",
  [sym_pointer_field_declarator] = "pointer_declarator",
  [sym_pointer_type_declarator] = "pointer_type_declarator",
  [sym_abstract_pointer_declarator] = "abstract_pointer_declarator",
  [sym_function_declarator] = "function_declarator",
  [sym_function_field_declarator] = "function_declarator",
  [sym_function_type_declarator] = "function_declarator",
  [sym_abstract_function_declarator] = "abstract_function_declarator",
  [sym_array_declarator] = "array_declarator",
  [sym_array_field_declarator] = "array_declarator",
  [sym_array_type_declarator] = "array_declarator",
  [sym_abstract_array_declarator] = "abstract_array_declarator",
  [sym_init_declarator] = "init_declarator",
  [sym_compound_statement] = "compound_statement",
  [sym_storage_class_specifier] = "storage_class_specifier",
  [sym_type_qualifier] = "type_qualifier",
  [sym_alignas_qualifier] = "alignas_qualifier",
  [sym_type_specifier] = "type_specifier",
  [sym_sized_type_specifier] = "sized_type_specifier",
  [sym_enum_specifier] = "enum_specifier",
  [sym_enumerator_list] = "enumerator_list",
  [sym_struct_specifier] = "struct_specifier",
  [sym_union_specifier] = "union_specifier",
  [sym_field_declaration_list] = "field_declaration_list",
  [sym__field_declaration_list_item] = "_field_declaration_list_item",
  [sym_field_declaration] = "field_declaration",
  [sym_bitfield_clause] = "bitfield_clause",
  [sym_enumerator] = "enumerator",
  [sym_parameter_list] = "parameter_list",
  [sym_parameter_declaration] = "parameter_declaration",
  [sym_attributed_statement] = "attributed_statement",
  [sym_statement] = "statement",
  [sym__top_level_statement] = "_top_level_statement",
  [sym_labeled_statement] = "labeled_statement",
  [sym__top_level_expression_statement] = "expression_statement",
  [sym_expression_statement] = "expression_statement",
  [sym_if_statement] = "if_statement",
  [sym_else_clause] = "else_clause",
  [sym_switch_statement] = "switch_statement",
  [sym_case_statement] = "case_statement",
  [sym_while_statement] = "while_statement",
  [sym_do_statement] = "do_statement",
  [sym_for_statement] = "for_statement",
  [sym__for_statement_body] = "_for_statement_body",
  [sym_return_statement] = "return_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_goto_statement] = "goto_statement",
  [sym_seh_try_statement] = "seh_try_statement",
  [sym_seh_except_clause] = "seh_except_clause",
  [sym_seh_finally_clause] = "seh_finally_clause",
  [sym_seh_leave_statement] = "seh_leave_statement",
  [sym_expression] = "expression",
  [sym__string] = "_string",
  [sym_comma_expression] = "comma_expression",
  [sym_conditional_expression] = "conditional_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_pointer_expression] = "pointer_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_update_expression] = "update_expression",
  [sym_cast_expression] = "cast_expression",
  [sym_type_descriptor] = "type_descriptor",
  [sym_sizeof_expression] = "sizeof_expression",
  [sym_alignof_expression] = "alignof_expression",
  [sym_offsetof_expression] = "offsetof_expression",
  [sym_generic_expression] = "generic_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_call_expression] = "call_expression",
  [sym_gnu_asm_expression] = "gnu_asm_expression",
  [sym_gnu_asm_qualifier] = "gnu_asm_qualifier",
  [sym_gnu_asm_output_operand_list] = "gnu_asm_output_operand_list",
  [sym_gnu_asm_output_operand] = "gnu_asm_output_operand",
  [sym_gnu_asm_input_operand_list] = "gnu_asm_input_operand_list",
  [sym_gnu_asm_input_operand] = "gnu_asm_input_operand",
  [sym_gnu_asm_clobber_list] = "gnu_asm_clobber_list",
  [sym_gnu_asm_goto_list] = "gnu_asm_goto_list",
  [sym_extension_expression] = "extension_expression",
  [sym_argument_list] = "argument_list",
  [sym_field_expression] = "field_expression",
  [sym_compound_literal_expression] = "compound_literal_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_initializer_list] = "initializer_list",
  [sym_initializer_pair] = "initializer_pair",
  [sym_subscript_designator] = "subscript_designator",
  [sym_subscript_range_designator] = "subscript_range_designator",
  [sym_field_designator] = "field_designator",
  [sym_char_literal] = "char_literal",
  [sym_concatenated_string] = "concatenated_string",
  [sym_string_literal] = "string_literal",
  [sym_null] = "null",
  [sym__empty_declaration] = "_empty_declaration",
  [sym_placeholder_type_specifier] = "placeholder_type_specifier",
  [sym_decltype_auto] = "decltype",
  [sym_decltype] = "decltype",
  [sym__class_declaration] = "_class_declaration",
  [sym__class_declaration_item] = "_class_declaration_item",
  [sym_class_specifier] = "class_specifier",
  [sym__class_name] = "_class_name",
  [sym_virtual_specifier] = "virtual_specifier",
  [sym_explicit_function_specifier] = "explicit_function_specifier",
  [sym_base_class_clause] = "base_class_clause",
  [sym__enum_base_clause] = "_enum_base_clause",
  [sym_dependent_type] = "dependent_type",
  [sym_template_declaration] = "template_declaration",
  [sym_template_instantiation] = "template_instantiation",
  [sym_template_parameter_list] = "template_parameter_list",
  [sym_type_parameter_declaration] = "type_parameter_declaration",
  [sym_variadic_type_parameter_declaration] = "variadic_type_parameter_declaration",
  [sym_optional_type_parameter_declaration] = "optional_type_parameter_declaration",
  [sym_template_template_parameter_declaration] = "template_template_parameter_declaration",
  [sym_optional_parameter_declaration] = "optional_parameter_declaration",
  [sym_variadic_parameter_declaration] = "variadic_parameter_declaration",
  [sym_variadic_declarator] = "variadic_declarator",
  [sym_variadic_reference_declarator] = "reference_declarator",
  [sym_operator_cast] = "operator_cast",
  [sym_field_initializer_list] = "field_initializer_list",
  [sym_field_initializer] = "field_initializer",
  [sym_inline_method_definition] = "function_definition",
  [sym__constructor_specifiers] = "_constructor_specifiers",
  [sym_operator_cast_definition] = "function_definition",
  [sym_operator_cast_declaration] = "declaration",
  [sym_constructor_try_statement] = "try_statement",
  [sym_constructor_or_destructor_definition] = "function_definition",
  [sym_constructor_or_destructor_declaration] = "declaration",
  [sym_default_method_clause] = "default_method_clause",
  [sym_delete_method_clause] = "delete_method_clause",
  [sym_pure_virtual_clause] = "pure_virtual_clause",
  [sym_friend_declaration] = "friend_declaration",
  [sym_access_specifier] = "access_specifier",
  [sym_reference_declarator] = "reference_declarator",
  [sym_reference_field_declarator] = "reference_declarator",
  [sym_reference_type_declarator] = "reference_declarator",
  [sym_abstract_reference_declarator] = "abstract_reference_declarator",
  [sym_structured_binding_declarator] = "structured_binding_declarator",
  [sym_ref_qualifier] = "ref_qualifier",
  [sym__function_declarator_seq] = "_function_declarator_seq",
  [sym__function_attributes_start] = "_function_attributes_start",
  [sym__function_exception_specification] = "_function_exception_specification",
  [sym__function_attributes_end] = "_function_attributes_end",
  [sym__function_postfix] = "_function_postfix",
  [sym_trailing_return_type] = "trailing_return_type",
  [sym_noexcept] = "noexcept",
  [sym_throw_specifier] = "throw_specifier",
  [sym_template_type] = "template_type",
  [sym_template_method] = "template_method",
  [sym_template_function] = "template_function",
  [sym_template_argument_list] = "template_argument_list",
  [sym_namespace_definition] = "namespace_definition",
  [sym_namespace_alias_definition] = "namespace_alias_definition",
  [sym__namespace_specifier] = "_namespace_specifier",
  [sym_nested_namespace_specifier] = "nested_namespace_specifier",
  [sym_using_declaration] = "using_declaration",
  [sym_alias_declaration] = "alias_declaration",
  [sym_static_assert_declaration] = "static_assert_declaration",
  [sym_concept_definition] = "concept_definition",
  [sym_for_range_loop] = "for_range_loop",
  [sym__for_range_loop_body] = "_for_range_loop_body",
  [sym_init_statement] = "init_statement",
  [sym_condition_clause] = "condition_clause",
  [sym_condition_declaration] = "declaration",
  [sym_co_return_statement] = "co_return_statement",
  [sym_co_yield_statement] = "co_yield_statement",
  [sym_throw_statement] = "throw_statement",
  [sym_try_statement] = "try_statement",
  [sym_catch_clause] = "catch_clause",
  [sym_raw_string_literal] = "raw_string_literal",
  [sym_subscript_argument_list] = "subscript_argument_list",
  [sym_co_await_expression] = "co_await_expression",
  [sym_new_expression] = "new_expression",
  [sym_new_declarator] = "new_declarator",
  [sym_delete_expression] = "delete_expression",
  [sym_type_requirement] = "type_requirement",
  [sym_compound_requirement] = "compound_requirement",
  [sym__requirement] = "_requirement",
  [sym_requirement_seq] = "requirement_seq",
  [sym_constraint_conjunction] = "constraint_conjunction",
  [sym_constraint_disjunction] = "constraint_disjunction",
  [sym__requirement_clause_constraint] = "_requirement_clause_constraint",
  [sym_requires_clause] = "requires_clause",
  [sym_requires_parameter_list] = "parameter_list",
  [sym_requires_expression] = "requires_expression",
  [sym_lambda_expression] = "lambda_expression",
  [sym_lambda_capture_specifier] = "lambda_capture_specifier",
  [sym_lambda_default_capture] = "lambda_default_capture",
  [sym__lambda_capture_identifier] = "_lambda_capture_identifier",
  [sym_lambda_capture_initializer] = "lambda_capture_initializer",
  [sym__lambda_capture] = "_lambda_capture",
  [sym__fold_operator] = "_fold_operator",
  [sym__binary_fold_operator] = "_binary_fold_operator",
  [sym__unary_left_fold] = "_unary_left_fold",
  [sym__unary_right_fold] = "_unary_right_fold",
  [sym__binary_fold] = "_binary_fold",
  [sym_fold_expression] = "fold_expression",
  [sym_parameter_pack_expansion] = "parameter_pack_expansion",
  [sym_type_parameter_pack_expansion] = "parameter_pack_expansion",
  [sym_identifier_parameter_pack_expansion] = "parameter_pack_expansion",
  [sym_destructor_name] = "destructor_name",
  [sym_dependent_identifier] = "dependent_name",
  [sym_dependent_field_identifier] = "dependent_name",
  [sym_dependent_type_identifier] = "dependent_name",
  [sym__scope_resolution] = "_scope_resolution",
  [sym_qualified_field_identifier] = "qualified_identifier",
  [sym_qualified_identifier] = "qualified_identifier",
  [sym_qualified_type_identifier] = "qualified_identifier",
  [sym_qualified_operator_cast_identifier] = "qualified_identifier",
  [sym__assignment_expression_lhs] = "assignment_expression",
  [sym_operator_name] = "operator_name",
  [sym_user_defined_literal] = "user_defined_literal",
  [sym_kernel_call_expression] = "call_expression",
  [sym_kernel_call_syntax] = "kernel_call_syntax",
  [sym_launch_bounds] = "launch_bounds",
  [aux_sym_translation_unit_repeat1] = "translation_unit_repeat1",
  [aux_sym_preproc_params_repeat1] = "preproc_params_repeat1",
  [aux_sym_preproc_if_repeat1] = "preproc_if_repeat1",
  [aux_sym_preproc_if_in_field_declaration_list_repeat1] = "preproc_if_in_field_declaration_list_repeat1",
  [aux_sym_preproc_if_in_enumerator_list_repeat1] = "preproc_if_in_enumerator_list_repeat1",
  [aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1] = "preproc_if_in_enumerator_list_no_comma_repeat1",
  [aux_sym_preproc_argument_list_repeat1] = "preproc_argument_list_repeat1",
  [aux_sym_declaration_repeat1] = "declaration_repeat1",
  [aux_sym_type_definition_repeat1] = "type_definition_repeat1",
  [aux_sym__type_definition_type_repeat1] = "_type_definition_type_repeat1",
  [aux_sym__type_definition_declarators_repeat1] = "_type_definition_declarators_repeat1",
  [aux_sym__declaration_specifiers_repeat1] = "_declaration_specifiers_repeat1",
  [aux_sym_attribute_declaration_repeat1] = "attribute_declaration_repeat1",
  [aux_sym_attributed_declarator_repeat1] = "attributed_declarator_repeat1",
  [aux_sym_pointer_declarator_repeat1] = "pointer_declarator_repeat1",
  [aux_sym_array_declarator_repeat1] = "array_declarator_repeat1",
  [aux_sym_sized_type_specifier_repeat1] = "sized_type_specifier_repeat1",
  [aux_sym_enumerator_list_repeat1] = "enumerator_list_repeat1",
  [aux_sym_field_declaration_repeat1] = "field_declaration_repeat1",
  [aux_sym_parameter_list_repeat1] = "parameter_list_repeat1",
  [aux_sym_case_statement_repeat1] = "case_statement_repeat1",
  [aux_sym_generic_expression_repeat1] = "generic_expression_repeat1",
  [aux_sym_gnu_asm_expression_repeat1] = "gnu_asm_expression_repeat1",
  [aux_sym_gnu_asm_output_operand_list_repeat1] = "gnu_asm_output_operand_list_repeat1",
  [aux_sym_gnu_asm_input_operand_list_repeat1] = "gnu_asm_input_operand_list_repeat1",
  [aux_sym_gnu_asm_clobber_list_repeat1] = "gnu_asm_clobber_list_repeat1",
  [aux_sym_gnu_asm_goto_list_repeat1] = "gnu_asm_goto_list_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_initializer_list_repeat1] = "initializer_list_repeat1",
  [aux_sym_initializer_pair_repeat1] = "initializer_pair_repeat1",
  [aux_sym_char_literal_repeat1] = "char_literal_repeat1",
  [aux_sym_concatenated_string_repeat1] = "concatenated_string_repeat1",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
  [aux_sym__class_declaration_repeat1] = "_class_declaration_repeat1",
  [aux_sym_base_class_clause_repeat1] = "base_class_clause_repeat1",
  [aux_sym_template_parameter_list_repeat1] = "template_parameter_list_repeat1",
  [aux_sym_field_initializer_list_repeat1] = "field_initializer_list_repeat1",
  [aux_sym_operator_cast_definition_repeat1] = "operator_cast_definition_repeat1",
  [aux_sym_constructor_try_statement_repeat1] = "constructor_try_statement_repeat1",
  [aux_sym_structured_binding_declarator_repeat1] = "structured_binding_declarator_repeat1",
  [aux_sym__function_postfix_repeat1] = "_function_postfix_repeat1",
  [aux_sym_throw_specifier_repeat1] = "throw_specifier_repeat1",
  [aux_sym_template_argument_list_repeat1] = "template_argument_list_repeat1",
  [aux_sym_subscript_argument_list_repeat1] = "subscript_argument_list_repeat1",
  [aux_sym_requirement_seq_repeat1] = "requirement_seq_repeat1",
  [aux_sym_requires_parameter_list_repeat1] = "requires_parameter_list_repeat1",
  [aux_sym_lambda_capture_specifier_repeat1] = "lambda_capture_specifier_repeat1",
  [aux_sym_kernel_call_syntax_repeat1] = "kernel_call_syntax_repeat1",
  [alias_sym_field_identifier] = "field_identifier",
  [alias_sym_namespace_identifier] = "namespace_identifier",
  [alias_sym_simple_requirement] = "simple_requirement",
  [alias_sym_statement_identifier] = "statement_identifier",
  [alias_sym_type_identifier] = "type_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [aux_sym_preproc_include_token1] = aux_sym_preproc_include_token1,
  [aux_sym_preproc_include_token2] = aux_sym_preproc_include_token2,
  [aux_sym_preproc_def_token1] = aux_sym_preproc_def_token1,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [aux_sym_preproc_if_token1] = aux_sym_preproc_if_token1,
  [anon_sym_LF] = anon_sym_LF,
  [aux_sym_preproc_if_token2] = aux_sym_preproc_if_token2,
  [aux_sym_preproc_ifdef_token1] = aux_sym_preproc_ifdef_token1,
  [aux_sym_preproc_ifdef_token2] = aux_sym_preproc_ifdef_token2,
  [aux_sym_preproc_else_token1] = aux_sym_preproc_else_token1,
  [aux_sym_preproc_elif_token1] = aux_sym_preproc_elif_token1,
  [aux_sym_preproc_elifdef_token1] = aux_sym_preproc_elifdef_token1,
  [aux_sym_preproc_elifdef_token2] = aux_sym_preproc_elifdef_token2,
  [sym_preproc_arg] = sym_preproc_arg,
  [sym_preproc_directive] = sym_preproc_directive,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_defined] = anon_sym_defined,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym___extension__] = anon_sym___extension__,
  [anon_sym_typedef] = anon_sym_typedef,
  [anon_sym___device__] = anon_sym___device__,
  [anon_sym___host__] = anon_sym___host__,
  [anon_sym___global__] = anon_sym___global__,
  [anon_sym___forceinline__] = anon_sym___forceinline__,
  [anon_sym___noinline__] = anon_sym___noinline__,
  [anon_sym_virtual] = anon_sym_virtual,
  [anon_sym_extern] = anon_sym_extern,
  [anon_sym___attribute__] = anon_sym___attribute__,
  [anon_sym___attribute] = anon_sym___attribute,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_LBRACK_LBRACK] = anon_sym_LBRACK_LBRACK,
  [anon_sym_RBRACK_RBRACK] = anon_sym_RBRACK_RBRACK,
  [anon_sym___declspec] = anon_sym___declspec,
  [anon_sym___based] = anon_sym___based,
  [anon_sym___cdecl] = anon_sym___cdecl,
  [anon_sym___clrcall] = anon_sym___clrcall,
  [anon_sym___stdcall] = anon_sym___stdcall,
  [anon_sym___fastcall] = anon_sym___fastcall,
  [anon_sym___thiscall] = anon_sym___thiscall,
  [anon_sym___vectorcall] = anon_sym___vectorcall,
  [sym_ms_restrict_modifier] = sym_ms_restrict_modifier,
  [sym_ms_unsigned_ptr_modifier] = sym_ms_unsigned_ptr_modifier,
  [sym_ms_signed_ptr_modifier] = sym_ms_signed_ptr_modifier,
  [anon_sym__unaligned] = anon_sym__unaligned,
  [anon_sym___unaligned] = anon_sym___unaligned,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_signed] = anon_sym_signed,
  [anon_sym_unsigned] = anon_sym_unsigned,
  [anon_sym_long] = anon_sym_long,
  [anon_sym_short] = anon_sym_short,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_register] = anon_sym_register,
  [anon_sym_inline] = anon_sym_inline,
  [anon_sym___inline] = anon_sym___inline,
  [anon_sym___inline__] = anon_sym___inline__,
  [anon_sym___forceinline] = anon_sym___forceinline,
  [anon_sym_thread_local] = anon_sym_thread_local,
  [anon_sym___thread] = anon_sym___thread,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_constexpr] = anon_sym_constexpr,
  [anon_sym_volatile] = anon_sym_volatile,
  [anon_sym_restrict] = anon_sym_restrict,
  [anon_sym___restrict__] = anon_sym___restrict__,
  [anon_sym__Atomic] = anon_sym__Atomic,
  [anon_sym__Noreturn] = anon_sym__Noreturn,
  [anon_sym_noreturn] = anon_sym_noreturn,
  [anon_sym__Nonnull] = anon_sym__Nonnull,
  [anon_sym_mutable] = anon_sym_mutable,
  [anon_sym_constinit] = anon_sym_constinit,
  [anon_sym_consteval] = anon_sym_consteval,
  [anon_sym___shared__] = anon_sym___shared__,
  [anon_sym___local__] = anon_sym___local__,
  [anon_sym___constant__] = anon_sym___constant__,
  [anon_sym___managed__] = anon_sym___managed__,
  [anon_sym___grid_constant__] = anon_sym___grid_constant__,
  [anon_sym_alignas] = anon_sym_alignas,
  [anon_sym__Alignas] = anon_sym__Alignas,
  [sym_primitive_type] = sym_primitive_type,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_goto] = anon_sym_goto,
  [anon_sym___try] = anon_sym___try,
  [anon_sym___except] = anon_sym___except,
  [anon_sym___finally] = anon_sym___finally,
  [anon_sym___leave] = anon_sym___leave,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_and_eq] = anon_sym_and_eq,
  [anon_sym_or_eq] = anon_sym_or_eq,
  [anon_sym_xor_eq] = anon_sym_xor_eq,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_compl] = anon_sym_compl,
  [anon_sym_LT_EQ_GT] = anon_sym_LT_EQ_GT,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_bitor] = anon_sym_bitor,
  [anon_sym_xor] = anon_sym_xor,
  [anon_sym_bitand] = anon_sym_bitand,
  [anon_sym_not_eq] = anon_sym_not_eq,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_sizeof] = anon_sym_sizeof,
  [anon_sym___alignof__] = anon_sym___alignof__,
  [anon_sym___alignof] = anon_sym___alignof,
  [anon_sym__alignof] = anon_sym__alignof,
  [anon_sym_alignof] = anon_sym_alignof,
  [anon_sym__Alignof] = anon_sym__Alignof,
  [anon_sym_offsetof] = anon_sym_offsetof,
  [anon_sym__Generic] = anon_sym__Generic,
  [anon_sym_asm] = anon_sym_asm,
  [anon_sym___asm__] = anon_sym___asm__,
  [anon_sym___asm] = anon_sym___asm,
  [anon_sym___volatile__] = anon_sym___volatile__,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [sym_number_literal] = sym_number_literal,
  [anon_sym_L_SQUOTE] = anon_sym_L_SQUOTE,
  [anon_sym_u_SQUOTE] = anon_sym_u_SQUOTE,
  [anon_sym_U_SQUOTE] = anon_sym_U_SQUOTE,
  [anon_sym_u8_SQUOTE] = anon_sym_u8_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_char_literal_token1] = aux_sym_char_literal_token1,
  [anon_sym_L_DQUOTE] = anon_sym_L_DQUOTE,
  [anon_sym_u_DQUOTE] = anon_sym_u_DQUOTE,
  [anon_sym_U_DQUOTE] = anon_sym_U_DQUOTE,
  [anon_sym_u8_DQUOTE] = anon_sym_u8_DQUOTE,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_system_lib_string] = sym_system_lib_string,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [anon_sym_NULL] = anon_sym_NULL,
  [anon_sym_nullptr] = anon_sym_nullptr,
  [sym_comment] = sym_comment,
  [sym_auto] = sym_auto,
  [anon_sym_decltype] = anon_sym_decltype,
  [anon_sym_final] = anon_sym_final,
  [anon_sym_override] = anon_sym_override,
  [anon_sym_explicit] = anon_sym_explicit,
  [anon_sym_typename] = anon_sym_typename,
  [anon_sym_template] = anon_sym_template,
  [anon_sym_GT2] = anon_sym_GT,
  [anon_sym_operator] = anon_sym_operator,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_delete] = anon_sym_delete,
  [aux_sym_pure_virtual_clause_token1] = aux_sym_pure_virtual_clause_token1,
  [anon_sym_friend] = anon_sym_friend,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_noexcept] = anon_sym_noexcept,
  [anon_sym_throw] = anon_sym_throw,
  [anon_sym_namespace] = anon_sym_namespace,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_static_assert] = anon_sym_static_assert,
  [anon_sym_concept] = anon_sym_concept,
  [anon_sym_co_return] = anon_sym_co_return,
  [anon_sym_co_yield] = anon_sym_co_yield,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_R_DQUOTE] = anon_sym_R_DQUOTE,
  [anon_sym_LR_DQUOTE] = anon_sym_LR_DQUOTE,
  [anon_sym_uR_DQUOTE] = anon_sym_uR_DQUOTE,
  [anon_sym_UR_DQUOTE] = anon_sym_UR_DQUOTE,
  [anon_sym_u8R_DQUOTE] = anon_sym_u8R_DQUOTE,
  [anon_sym_co_await] = anon_sym_co_await,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_requires] = anon_sym_requires,
  [anon_sym_DASH_GT_STAR] = anon_sym_DASH_GT_STAR,
  [anon_sym_LPAREN_RPAREN] = anon_sym_LPAREN_RPAREN,
  [anon_sym_LBRACK_RBRACK] = anon_sym_LBRACK_RBRACK,
  [anon_sym_DQUOTE_DQUOTE] = anon_sym_DQUOTE_DQUOTE,
  [sym_this] = sym_this,
  [sym_literal_suffix] = sym_literal_suffix,
  [aux_sym_kernel_call_syntax_token1] = aux_sym_kernel_call_syntax_token1,
  [aux_sym_kernel_call_syntax_token2] = aux_sym_kernel_call_syntax_token2,
  [anon_sym___launch_bounds__] = anon_sym___launch_bounds__,
  [sym_raw_string_delimiter] = sym_raw_string_delimiter,
  [sym_raw_string_content] = sym_raw_string_content,
  [sym_translation_unit] = sym_translation_unit,
  [sym__top_level_item] = sym__top_level_item,
  [sym__block_item] = sym__block_item,
  [sym_preproc_include] = sym_preproc_include,
  [sym_preproc_def] = sym_preproc_def,
  [sym_preproc_function_def] = sym_preproc_function_def,
  [sym_preproc_params] = sym_preproc_params,
  [sym_preproc_call] = sym_preproc_call,
  [sym_preproc_if] = sym_preproc_if,
  [sym_preproc_ifdef] = sym_preproc_ifdef,
  [sym_preproc_else] = sym_preproc_else,
  [sym_preproc_elif] = sym_preproc_elif,
  [sym_preproc_elifdef] = sym_preproc_elifdef,
  [sym_preproc_if_in_field_declaration_list] = sym_preproc_if,
  [sym_preproc_ifdef_in_field_declaration_list] = sym_preproc_ifdef,
  [sym_preproc_else_in_field_declaration_list] = sym_preproc_else,
  [sym_preproc_elif_in_field_declaration_list] = sym_preproc_elif,
  [sym_preproc_elifdef_in_field_declaration_list] = sym_preproc_elifdef,
  [sym_preproc_if_in_enumerator_list] = sym_preproc_if,
  [sym_preproc_ifdef_in_enumerator_list] = sym_preproc_ifdef,
  [sym_preproc_else_in_enumerator_list] = sym_preproc_else,
  [sym_preproc_elif_in_enumerator_list] = sym_preproc_elif,
  [sym_preproc_elifdef_in_enumerator_list] = sym_preproc_elifdef,
  [sym_preproc_if_in_enumerator_list_no_comma] = sym_preproc_if,
  [sym_preproc_ifdef_in_enumerator_list_no_comma] = sym_preproc_ifdef,
  [sym_preproc_else_in_enumerator_list_no_comma] = sym_preproc_else,
  [sym_preproc_elif_in_enumerator_list_no_comma] = sym_preproc_elif,
  [sym_preproc_elifdef_in_enumerator_list_no_comma] = sym_preproc_elifdef,
  [sym__preproc_expression] = sym__preproc_expression,
  [sym_preproc_parenthesized_expression] = sym_parenthesized_expression,
  [sym_preproc_defined] = sym_preproc_defined,
  [sym_preproc_unary_expression] = sym_unary_expression,
  [sym_preproc_call_expression] = sym_call_expression,
  [sym_preproc_argument_list] = sym_argument_list,
  [sym_preproc_binary_expression] = sym_binary_expression,
  [sym_function_definition] = sym_function_definition,
  [sym_declaration] = sym_declaration,
  [sym_type_definition] = sym_type_definition,
  [sym__type_definition_type] = sym__type_definition_type,
  [sym__type_definition_declarators] = sym__type_definition_declarators,
  [sym__declaration_modifiers] = sym__declaration_modifiers,
  [sym__declaration_specifiers] = sym__declaration_specifiers,
  [sym_linkage_specification] = sym_linkage_specification,
  [sym_attribute_specifier] = sym_attribute_specifier,
  [sym_attribute] = sym_attribute,
  [sym_attribute_declaration] = sym_attribute_declaration,
  [sym_ms_declspec_modifier] = sym_ms_declspec_modifier,
  [sym_ms_based_modifier] = sym_ms_based_modifier,
  [sym_ms_call_modifier] = sym_ms_call_modifier,
  [sym_ms_unaligned_ptr_modifier] = sym_ms_unaligned_ptr_modifier,
  [sym_ms_pointer_modifier] = sym_ms_pointer_modifier,
  [sym_declaration_list] = sym_declaration_list,
  [sym__declarator] = sym__declarator,
  [sym__field_declarator] = sym__field_declarator,
  [sym__type_declarator] = sym__type_declarator,
  [sym__abstract_declarator] = sym__abstract_declarator,
  [sym_parenthesized_declarator] = sym_parenthesized_declarator,
  [sym_parenthesized_field_declarator] = sym_parenthesized_declarator,
  [sym_parenthesized_type_declarator] = sym_parenthesized_declarator,
  [sym_abstract_parenthesized_declarator] = sym_abstract_parenthesized_declarator,
  [sym_attributed_declarator] = sym_attributed_declarator,
  [sym_attributed_field_declarator] = sym_attributed_declarator,
  [sym_attributed_type_declarator] = sym_attributed_declarator,
  [sym_pointer_declarator] = sym_pointer_declarator,
  [sym_pointer_field_declarator] = sym_pointer_declarator,
  [sym_pointer_type_declarator] = sym_pointer_type_declarator,
  [sym_abstract_pointer_declarator] = sym_abstract_pointer_declarator,
  [sym_function_declarator] = sym_function_declarator,
  [sym_function_field_declarator] = sym_function_declarator,
  [sym_function_type_declarator] = sym_function_declarator,
  [sym_abstract_function_declarator] = sym_abstract_function_declarator,
  [sym_array_declarator] = sym_array_declarator,
  [sym_array_field_declarator] = sym_array_declarator,
  [sym_array_type_declarator] = sym_array_declarator,
  [sym_abstract_array_declarator] = sym_abstract_array_declarator,
  [sym_init_declarator] = sym_init_declarator,
  [sym_compound_statement] = sym_compound_statement,
  [sym_storage_class_specifier] = sym_storage_class_specifier,
  [sym_type_qualifier] = sym_type_qualifier,
  [sym_alignas_qualifier] = sym_alignas_qualifier,
  [sym_type_specifier] = sym_type_specifier,
  [sym_sized_type_specifier] = sym_sized_type_specifier,
  [sym_enum_specifier] = sym_enum_specifier,
  [sym_enumerator_list] = sym_enumerator_list,
  [sym_struct_specifier] = sym_struct_specifier,
  [sym_union_specifier] = sym_union_specifier,
  [sym_field_declaration_list] = sym_field_declaration_list,
  [sym__field_declaration_list_item] = sym__field_declaration_list_item,
  [sym_field_declaration] = sym_field_declaration,
  [sym_bitfield_clause] = sym_bitfield_clause,
  [sym_enumerator] = sym_enumerator,
  [sym_parameter_list] = sym_parameter_list,
  [sym_parameter_declaration] = sym_parameter_declaration,
  [sym_attributed_statement] = sym_attributed_statement,
  [sym_statement] = sym_statement,
  [sym__top_level_statement] = sym__top_level_statement,
  [sym_labeled_statement] = sym_labeled_statement,
  [sym__top_level_expression_statement] = sym_expression_statement,
  [sym_expression_statement] = sym_expression_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_else_clause] = sym_else_clause,
  [sym_switch_statement] = sym_switch_statement,
  [sym_case_statement] = sym_case_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_do_statement] = sym_do_statement,
  [sym_for_statement] = sym_for_statement,
  [sym__for_statement_body] = sym__for_statement_body,
  [sym_return_statement] = sym_return_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_goto_statement] = sym_goto_statement,
  [sym_seh_try_statement] = sym_seh_try_statement,
  [sym_seh_except_clause] = sym_seh_except_clause,
  [sym_seh_finally_clause] = sym_seh_finally_clause,
  [sym_seh_leave_statement] = sym_seh_leave_statement,
  [sym_expression] = sym_expression,
  [sym__string] = sym__string,
  [sym_comma_expression] = sym_comma_expression,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_pointer_expression] = sym_pointer_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_update_expression] = sym_update_expression,
  [sym_cast_expression] = sym_cast_expression,
  [sym_type_descriptor] = sym_type_descriptor,
  [sym_sizeof_expression] = sym_sizeof_expression,
  [sym_alignof_expression] = sym_alignof_expression,
  [sym_offsetof_expression] = sym_offsetof_expression,
  [sym_generic_expression] = sym_generic_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_gnu_asm_expression] = sym_gnu_asm_expression,
  [sym_gnu_asm_qualifier] = sym_gnu_asm_qualifier,
  [sym_gnu_asm_output_operand_list] = sym_gnu_asm_output_operand_list,
  [sym_gnu_asm_output_operand] = sym_gnu_asm_output_operand,
  [sym_gnu_asm_input_operand_list] = sym_gnu_asm_input_operand_list,
  [sym_gnu_asm_input_operand] = sym_gnu_asm_input_operand,
  [sym_gnu_asm_clobber_list] = sym_gnu_asm_clobber_list,
  [sym_gnu_asm_goto_list] = sym_gnu_asm_goto_list,
  [sym_extension_expression] = sym_extension_expression,
  [sym_argument_list] = sym_argument_list,
  [sym_field_expression] = sym_field_expression,
  [sym_compound_literal_expression] = sym_compound_literal_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_initializer_list] = sym_initializer_list,
  [sym_initializer_pair] = sym_initializer_pair,
  [sym_subscript_designator] = sym_subscript_designator,
  [sym_subscript_range_designator] = sym_subscript_range_designator,
  [sym_field_designator] = sym_field_designator,
  [sym_char_literal] = sym_char_literal,
  [sym_concatenated_string] = sym_concatenated_string,
  [sym_string_literal] = sym_string_literal,
  [sym_null] = sym_null,
  [sym__empty_declaration] = sym__empty_declaration,
  [sym_placeholder_type_specifier] = sym_placeholder_type_specifier,
  [sym_decltype_auto] = sym_decltype,
  [sym_decltype] = sym_decltype,
  [sym__class_declaration] = sym__class_declaration,
  [sym__class_declaration_item] = sym__class_declaration_item,
  [sym_class_specifier] = sym_class_specifier,
  [sym__class_name] = sym__class_name,
  [sym_virtual_specifier] = sym_virtual_specifier,
  [sym_explicit_function_specifier] = sym_explicit_function_specifier,
  [sym_base_class_clause] = sym_base_class_clause,
  [sym__enum_base_clause] = sym__enum_base_clause,
  [sym_dependent_type] = sym_dependent_type,
  [sym_template_declaration] = sym_template_declaration,
  [sym_template_instantiation] = sym_template_instantiation,
  [sym_template_parameter_list] = sym_template_parameter_list,
  [sym_type_parameter_declaration] = sym_type_parameter_declaration,
  [sym_variadic_type_parameter_declaration] = sym_variadic_type_parameter_declaration,
  [sym_optional_type_parameter_declaration] = sym_optional_type_parameter_declaration,
  [sym_template_template_parameter_declaration] = sym_template_template_parameter_declaration,
  [sym_optional_parameter_declaration] = sym_optional_parameter_declaration,
  [sym_variadic_parameter_declaration] = sym_variadic_parameter_declaration,
  [sym_variadic_declarator] = sym_variadic_declarator,
  [sym_variadic_reference_declarator] = sym_reference_declarator,
  [sym_operator_cast] = sym_operator_cast,
  [sym_field_initializer_list] = sym_field_initializer_list,
  [sym_field_initializer] = sym_field_initializer,
  [sym_inline_method_definition] = sym_function_definition,
  [sym__constructor_specifiers] = sym__constructor_specifiers,
  [sym_operator_cast_definition] = sym_function_definition,
  [sym_operator_cast_declaration] = sym_declaration,
  [sym_constructor_try_statement] = sym_try_statement,
  [sym_constructor_or_destructor_definition] = sym_function_definition,
  [sym_constructor_or_destructor_declaration] = sym_declaration,
  [sym_default_method_clause] = sym_default_method_clause,
  [sym_delete_method_clause] = sym_delete_method_clause,
  [sym_pure_virtual_clause] = sym_pure_virtual_clause,
  [sym_friend_declaration] = sym_friend_declaration,
  [sym_access_specifier] = sym_access_specifier,
  [sym_reference_declarator] = sym_reference_declarator,
  [sym_reference_field_declarator] = sym_reference_declarator,
  [sym_reference_type_declarator] = sym_reference_declarator,
  [sym_abstract_reference_declarator] = sym_abstract_reference_declarator,
  [sym_structured_binding_declarator] = sym_structured_binding_declarator,
  [sym_ref_qualifier] = sym_ref_qualifier,
  [sym__function_declarator_seq] = sym__function_declarator_seq,
  [sym__function_attributes_start] = sym__function_attributes_start,
  [sym__function_exception_specification] = sym__function_exception_specification,
  [sym__function_attributes_end] = sym__function_attributes_end,
  [sym__function_postfix] = sym__function_postfix,
  [sym_trailing_return_type] = sym_trailing_return_type,
  [sym_noexcept] = sym_noexcept,
  [sym_throw_specifier] = sym_throw_specifier,
  [sym_template_type] = sym_template_type,
  [sym_template_method] = sym_template_method,
  [sym_template_function] = sym_template_function,
  [sym_template_argument_list] = sym_template_argument_list,
  [sym_namespace_definition] = sym_namespace_definition,
  [sym_namespace_alias_definition] = sym_namespace_alias_definition,
  [sym__namespace_specifier] = sym__namespace_specifier,
  [sym_nested_namespace_specifier] = sym_nested_namespace_specifier,
  [sym_using_declaration] = sym_using_declaration,
  [sym_alias_declaration] = sym_alias_declaration,
  [sym_static_assert_declaration] = sym_static_assert_declaration,
  [sym_concept_definition] = sym_concept_definition,
  [sym_for_range_loop] = sym_for_range_loop,
  [sym__for_range_loop_body] = sym__for_range_loop_body,
  [sym_init_statement] = sym_init_statement,
  [sym_condition_clause] = sym_condition_clause,
  [sym_condition_declaration] = sym_declaration,
  [sym_co_return_statement] = sym_co_return_statement,
  [sym_co_yield_statement] = sym_co_yield_statement,
  [sym_throw_statement] = sym_throw_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_catch_clause] = sym_catch_clause,
  [sym_raw_string_literal] = sym_raw_string_literal,
  [sym_subscript_argument_list] = sym_subscript_argument_list,
  [sym_co_await_expression] = sym_co_await_expression,
  [sym_new_expression] = sym_new_expression,
  [sym_new_declarator] = sym_new_declarator,
  [sym_delete_expression] = sym_delete_expression,
  [sym_type_requirement] = sym_type_requirement,
  [sym_compound_requirement] = sym_compound_requirement,
  [sym__requirement] = sym__requirement,
  [sym_requirement_seq] = sym_requirement_seq,
  [sym_constraint_conjunction] = sym_constraint_conjunction,
  [sym_constraint_disjunction] = sym_constraint_disjunction,
  [sym__requirement_clause_constraint] = sym__requirement_clause_constraint,
  [sym_requires_clause] = sym_requires_clause,
  [sym_requires_parameter_list] = sym_parameter_list,
  [sym_requires_expression] = sym_requires_expression,
  [sym_lambda_expression] = sym_lambda_expression,
  [sym_lambda_capture_specifier] = sym_lambda_capture_specifier,
  [sym_lambda_default_capture] = sym_lambda_default_capture,
  [sym__lambda_capture_identifier] = sym__lambda_capture_identifier,
  [sym_lambda_capture_initializer] = sym_lambda_capture_initializer,
  [sym__lambda_capture] = sym__lambda_capture,
  [sym__fold_operator] = sym__fold_operator,
  [sym__binary_fold_operator] = sym__binary_fold_operator,
  [sym__unary_left_fold] = sym__unary_left_fold,
  [sym__unary_right_fold] = sym__unary_right_fold,
  [sym__binary_fold] = sym__binary_fold,
  [sym_fold_expression] = sym_fold_expression,
  [sym_parameter_pack_expansion] = sym_parameter_pack_expansion,
  [sym_type_parameter_pack_expansion] = sym_parameter_pack_expansion,
  [sym_identifier_parameter_pack_expansion] = sym_parameter_pack_expansion,
  [sym_destructor_name] = sym_destructor_name,
  [sym_dependent_identifier] = sym_dependent_identifier,
  [sym_dependent_field_identifier] = sym_dependent_identifier,
  [sym_dependent_type_identifier] = sym_dependent_identifier,
  [sym__scope_resolution] = sym__scope_resolution,
  [sym_qualified_field_identifier] = sym_qualified_identifier,
  [sym_qualified_identifier] = sym_qualified_identifier,
  [sym_qualified_type_identifier] = sym_qualified_identifier,
  [sym_qualified_operator_cast_identifier] = sym_qualified_identifier,
  [sym__assignment_expression_lhs] = sym_assignment_expression,
  [sym_operator_name] = sym_operator_name,
  [sym_user_defined_literal] = sym_user_defined_literal,
  [sym_kernel_call_expression] = sym_call_expression,
  [sym_kernel_call_syntax] = sym_kernel_call_syntax,
  [sym_launch_bounds] = sym_launch_bounds,
  [aux_sym_translation_unit_repeat1] = aux_sym_translation_unit_repeat1,
  [aux_sym_preproc_params_repeat1] = aux_sym_preproc_params_repeat1,
  [aux_sym_preproc_if_repeat1] = aux_sym_preproc_if_repeat1,
  [aux_sym_preproc_if_in_field_declaration_list_repeat1] = aux_sym_preproc_if_in_field_declaration_list_repeat1,
  [aux_sym_preproc_if_in_enumerator_list_repeat1] = aux_sym_preproc_if_in_enumerator_list_repeat1,
  [aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1] = aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
  [aux_sym_preproc_argument_list_repeat1] = aux_sym_preproc_argument_list_repeat1,
  [aux_sym_declaration_repeat1] = aux_sym_declaration_repeat1,
  [aux_sym_type_definition_repeat1] = aux_sym_type_definition_repeat1,
  [aux_sym__type_definition_type_repeat1] = aux_sym__type_definition_type_repeat1,
  [aux_sym__type_definition_declarators_repeat1] = aux_sym__type_definition_declarators_repeat1,
  [aux_sym__declaration_specifiers_repeat1] = aux_sym__declaration_specifiers_repeat1,
  [aux_sym_attribute_declaration_repeat1] = aux_sym_attribute_declaration_repeat1,
  [aux_sym_attributed_declarator_repeat1] = aux_sym_attributed_declarator_repeat1,
  [aux_sym_pointer_declarator_repeat1] = aux_sym_pointer_declarator_repeat1,
  [aux_sym_array_declarator_repeat1] = aux_sym_array_declarator_repeat1,
  [aux_sym_sized_type_specifier_repeat1] = aux_sym_sized_type_specifier_repeat1,
  [aux_sym_enumerator_list_repeat1] = aux_sym_enumerator_list_repeat1,
  [aux_sym_field_declaration_repeat1] = aux_sym_field_declaration_repeat1,
  [aux_sym_parameter_list_repeat1] = aux_sym_parameter_list_repeat1,
  [aux_sym_case_statement_repeat1] = aux_sym_case_statement_repeat1,
  [aux_sym_generic_expression_repeat1] = aux_sym_generic_expression_repeat1,
  [aux_sym_gnu_asm_expression_repeat1] = aux_sym_gnu_asm_expression_repeat1,
  [aux_sym_gnu_asm_output_operand_list_repeat1] = aux_sym_gnu_asm_output_operand_list_repeat1,
  [aux_sym_gnu_asm_input_operand_list_repeat1] = aux_sym_gnu_asm_input_operand_list_repeat1,
  [aux_sym_gnu_asm_clobber_list_repeat1] = aux_sym_gnu_asm_clobber_list_repeat1,
  [aux_sym_gnu_asm_goto_list_repeat1] = aux_sym_gnu_asm_goto_list_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_initializer_list_repeat1] = aux_sym_initializer_list_repeat1,
  [aux_sym_initializer_pair_repeat1] = aux_sym_initializer_pair_repeat1,
  [aux_sym_char_literal_repeat1] = aux_sym_char_literal_repeat1,
  [aux_sym_concatenated_string_repeat1] = aux_sym_concatenated_string_repeat1,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
  [aux_sym__class_declaration_repeat1] = aux_sym__class_declaration_repeat1,
  [aux_sym_base_class_clause_repeat1] = aux_sym_base_class_clause_repeat1,
  [aux_sym_template_parameter_list_repeat1] = aux_sym_template_parameter_list_repeat1,
  [aux_sym_field_initializer_list_repeat1] = aux_sym_field_initializer_list_repeat1,
  [aux_sym_operator_cast_definition_repeat1] = aux_sym_operator_cast_definition_repeat1,
  [aux_sym_constructor_try_statement_repeat1] = aux_sym_constructor_try_statement_repeat1,
  [aux_sym_structured_binding_declarator_repeat1] = aux_sym_structured_binding_declarator_repeat1,
  [aux_sym__function_postfix_repeat1] = aux_sym__function_postfix_repeat1,
  [aux_sym_throw_specifier_repeat1] = aux_sym_throw_specifier_repeat1,
  [aux_sym_template_argument_list_repeat1] = aux_sym_template_argument_list_repeat1,
  [aux_sym_subscript_argument_list_repeat1] = aux_sym_subscript_argument_list_repeat1,
  [aux_sym_requirement_seq_repeat1] = aux_sym_requirement_seq_repeat1,
  [aux_sym_requires_parameter_list_repeat1] = aux_sym_requires_parameter_list_repeat1,
  [aux_sym_lambda_capture_specifier_repeat1] = aux_sym_lambda_capture_specifier_repeat1,
  [aux_sym_kernel_call_syntax_repeat1] = aux_sym_kernel_call_syntax_repeat1,
  [alias_sym_field_identifier] = alias_sym_field_identifier,
  [alias_sym_namespace_identifier] = alias_sym_namespace_identifier,
  [alias_sym_simple_requirement] = alias_sym_simple_requirement,
  [alias_sym_statement_identifier] = alias_sym_statement_identifier,
  [alias_sym_type_identifier] = alias_sym_type_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preproc_include_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_include_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_def_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_ifdef_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_ifdef_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_else_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elif_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elifdef_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elifdef_token2] = {
    .visible = true,
    .named = false,
  },
  [sym_preproc_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_directive] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defined] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___extension__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typedef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___device__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___host__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___global__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___forceinline__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___noinline__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_virtual] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extern] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___attribute__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___attribute] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___declspec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___based] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___cdecl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___clrcall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___stdcall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___fastcall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___thiscall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___vectorcall] = {
    .visible = true,
    .named = false,
  },
  [sym_ms_restrict_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_unsigned_ptr_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_signed_ptr_modifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym__unaligned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___unaligned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_signed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_long] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_short] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_register] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___inline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___inline__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___forceinline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_thread_local] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___thread] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constexpr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_volatile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_restrict] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___restrict__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Atomic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Noreturn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_noreturn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Nonnull] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mutable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constinit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_consteval] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___shared__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___local__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___constant__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___managed__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___grid_constant__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_alignas] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Alignas] = {
    .visible = true,
    .named = false,
  },
  [sym_primitive_type] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_goto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___except] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___leave] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_compl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bitor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bitand] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sizeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___alignof__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___alignof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__alignof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_alignof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Alignof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_offsetof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Generic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_asm] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___asm__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___asm] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___volatile__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [sym_number_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_char_literal_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token1] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_system_lib_string] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_NULL] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nullptr] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_auto] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_decltype] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_final] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_override] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_explicit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typename] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_template] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_operator] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delete] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_pure_virtual_clause_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_friend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_noexcept] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_namespace] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_concept] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_co_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_co_yield] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_R_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LR_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uR_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_UR_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8R_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_co_await] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_requires] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_this] = {
    .visible = true,
    .named = true,
  },
  [sym_literal_suffix] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_kernel_call_syntax_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_kernel_call_syntax_token2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___launch_bounds__] = {
    .visible = true,
    .named = false,
  },
  [sym_raw_string_delimiter] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_translation_unit] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_item] = {
    .visible = false,
    .named = true,
  },
  [sym__block_item] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_include] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_def] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_function_def] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_params] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_call] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elifdef] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elifdef_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elifdef_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elifdef_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_defined] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__type_definition_type] = {
    .visible = false,
    .named = true,
  },
  [sym__type_definition_declarators] = {
    .visible = false,
    .named = true,
  },
  [sym__declaration_modifiers] = {
    .visible = false,
    .named = true,
  },
  [sym__declaration_specifiers] = {
    .visible = false,
    .named = true,
  },
  [sym_linkage_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_declspec_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_based_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_call_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_unaligned_ptr_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_pointer_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym__declarator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__field_declarator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__type_declarator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__abstract_declarator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_parenthesized_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_parenthesized_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_attributed_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_attributed_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_attributed_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_function_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_function_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_array_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_init_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_storage_class_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_type_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_alignas_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_type_specifier] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_sized_type_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_union_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym__field_declaration_list_item] = {
    .visible = false,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_bitfield_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_enumerator] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_attributed_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__top_level_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_labeled_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__for_statement_body] = {
    .visible = false,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_goto_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_seh_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_seh_except_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_seh_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_seh_leave_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__string] = {
    .visible = false,
    .named = true,
  },
  [sym_comma_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_descriptor] = {
    .visible = true,
    .named = true,
  },
  [sym_sizeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_alignof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_offsetof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_output_operand_list] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_output_operand] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_input_operand_list] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_input_operand] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_clobber_list] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_goto_list] = {
    .visible = true,
    .named = true,
  },
  [sym_extension_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_literal_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_initializer_list] = {
    .visible = true,
    .named = true,
  },
  [sym_initializer_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_designator] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_range_designator] = {
    .visible = true,
    .named = true,
  },
  [sym_field_designator] = {
    .visible = true,
    .named = true,
  },
  [sym_char_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_concatenated_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [sym__empty_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym_placeholder_type_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_decltype_auto] = {
    .visible = true,
    .named = true,
  },
  [sym_decltype] = {
    .visible = true,
    .named = true,
  },
  [sym__class_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym__class_declaration_item] = {
    .visible = false,
    .named = true,
  },
  [sym_class_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym__class_name] = {
    .visible = false,
    .named = true,
  },
  [sym_virtual_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_explicit_function_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_base_class_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__enum_base_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_dependent_type] = {
    .visible = true,
    .named = true,
  },
  [sym_template_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_template_instantiation] = {
    .visible = true,
    .named = true,
  },
  [sym_template_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_type_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_optional_type_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_template_template_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_optional_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_reference_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_operator_cast] = {
    .visible = true,
    .named = true,
  },
  [sym_field_initializer_list] = {
    .visible = true,
    .named = true,
  },
  [sym_field_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_method_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__constructor_specifiers] = {
    .visible = false,
    .named = true,
  },
  [sym_operator_cast_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_operator_cast_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_or_destructor_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_or_destructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_default_method_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_method_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_pure_virtual_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_friend_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_access_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_reference_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_structured_binding_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_ref_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym__function_declarator_seq] = {
    .visible = false,
    .named = true,
  },
  [sym__function_attributes_start] = {
    .visible = false,
    .named = true,
  },
  [sym__function_exception_specification] = {
    .visible = false,
    .named = true,
  },
  [sym__function_attributes_end] = {
    .visible = false,
    .named = true,
  },
  [sym__function_postfix] = {
    .visible = false,
    .named = true,
  },
  [sym_trailing_return_type] = {
    .visible = true,
    .named = true,
  },
  [sym_noexcept] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_template_type] = {
    .visible = true,
    .named = true,
  },
  [sym_template_method] = {
    .visible = true,
    .named = true,
  },
  [sym_template_function] = {
    .visible = true,
    .named = true,
  },
  [sym_template_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_alias_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__namespace_specifier] = {
    .visible = false,
    .named = true,
  },
  [sym_nested_namespace_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_using_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_alias_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_static_assert_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_concept_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_for_range_loop] = {
    .visible = true,
    .named = true,
  },
  [sym__for_range_loop_body] = {
    .visible = false,
    .named = true,
  },
  [sym_init_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_condition_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_condition_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_co_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_co_yield_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_co_await_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_requirement] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_requirement] = {
    .visible = true,
    .named = true,
  },
  [sym__requirement] = {
    .visible = false,
    .named = true,
  },
  [sym_requirement_seq] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_conjunction] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_disjunction] = {
    .visible = true,
    .named = true,
  },
  [sym__requirement_clause_constraint] = {
    .visible = false,
    .named = true,
  },
  [sym_requires_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_requires_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_requires_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_capture_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_default_capture] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_capture_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda_capture_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_capture] = {
    .visible = false,
    .named = true,
  },
  [sym__fold_operator] = {
    .visible = false,
    .named = true,
  },
  [sym__binary_fold_operator] = {
    .visible = false,
    .named = true,
  },
  [sym__unary_left_fold] = {
    .visible = false,
    .named = true,
  },
  [sym__unary_right_fold] = {
    .visible = false,
    .named = true,
  },
  [sym__binary_fold] = {
    .visible = false,
    .named = true,
  },
  [sym_fold_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_pack_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_pack_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier_parameter_pack_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_destructor_name] = {
    .visible = true,
    .named = true,
  },
  [sym_dependent_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_dependent_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_dependent_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__scope_resolution] = {
    .visible = false,
    .named = true,
  },
  [sym_qualified_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_operator_cast_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__assignment_expression_lhs] = {
    .visible = true,
    .named = true,
  },
  [sym_operator_name] = {
    .visible = true,
    .named = true,
  },
  [sym_user_defined_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_kernel_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_kernel_call_syntax] = {
    .visible = true,
    .named = true,
  },
  [sym_launch_bounds] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_translation_unit_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_params_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_in_field_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_in_enumerator_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_definition_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_definition_declarators_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__declaration_specifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributed_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pointer_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sized_type_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumerator_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_generic_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_output_operand_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_input_operand_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_clobber_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_goto_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_initializer_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_initializer_pair_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_char_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_concatenated_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__class_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_base_class_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_template_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_initializer_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_operator_cast_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constructor_try_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_structured_binding_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__function_postfix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_throw_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_template_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subscript_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_requirement_seq_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_requires_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_lambda_capture_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_kernel_call_syntax_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_namespace_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_simple_requirement] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_statement_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_argument = 2,
  field_arguments = 3,
  field_assembly_code = 4,
  field_base = 5,
  field_body = 6,
  field_captures = 7,
  field_clobbers = 8,
  field_condition = 9,
  field_consequence = 10,
  field_constraint = 11,
  field_declarator = 12,
  field_default_type = 13,
  field_default_value = 14,
  field_delimiter = 15,
  field_designator = 16,
  field_directive = 17,
  field_end = 18,
  field_field = 19,
  field_filter = 20,
  field_function = 21,
  field_goto_labels = 22,
  field_indices = 23,
  field_initializer = 24,
  field_input_operands = 25,
  field_label = 26,
  field_left = 27,
  field_length = 28,
  field_member = 29,
  field_message = 30,
  field_name = 31,
  field_operand = 32,
  field_operator = 33,
  field_output_operands = 34,
  field_parameters = 35,
  field_path = 36,
  field_pattern = 37,
  field_placement = 38,
  field_prefix = 39,
  field_register = 40,
  field_requirements = 41,
  field_right = 42,
  field_scope = 43,
  field_size = 44,
  field_start = 45,
  field_symbol = 46,
  field_template_parameters = 47,
  field_type = 48,
  field_update = 49,
  field_value = 50,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_assembly_code] = "assembly_code",
  [field_base] = "base",
  [field_body] = "body",
  [field_captures] = "captures",
  [field_clobbers] = "clobbers",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_constraint] = "constraint",
  [field_declarator] = "declarator",
  [field_default_type] = "default_type",
  [field_default_value] = "default_value",
  [field_delimiter] = "delimiter",
  [field_designator] = "designator",
  [field_directive] = "directive",
  [field_end] = "end",
  [field_field] = "field",
  [field_filter] = "filter",
  [field_function] = "function",
  [field_goto_labels] = "goto_labels",
  [field_indices] = "indices",
  [field_initializer] = "initializer",
  [field_input_operands] = "input_operands",
  [field_label] = "label",
  [field_left] = "left",
  [field_length] = "length",
  [field_member] = "member",
  [field_message] = "message",
  [field_name] = "name",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_output_operands] = "output_operands",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_pattern] = "pattern",
  [field_placement] = "placement",
  [field_prefix] = "prefix",
  [field_register] = "register",
  [field_requirements] = "requirements",
  [field_right] = "right",
  [field_scope] = "scope",
  [field_size] = "size",
  [field_start] = "start",
  [field_symbol] = "symbol",
  [field_template_parameters] = "template_parameters",
  [field_type] = "type",
  [field_update] = "update",
  [field_value] = "value",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [4] = {.index = 2, .length = 2},
  [5] = {.index = 4, .length = 1},
  [6] = {.index = 5, .length = 1},
  [7] = {.index = 6, .length = 2},
  [8] = {.index = 8, .length = 2},
  [9] = {.index = 10, .length = 1},
  [10] = {.index = 11, .length = 1},
  [11] = {.index = 12, .length = 1},
  [12] = {.index = 13, .length = 2},
  [13] = {.index = 15, .length = 2},
  [14] = {.index = 17, .length = 1},
  [15] = {.index = 18, .length = 1},
  [16] = {.index = 19, .length = 2},
  [17] = {.index = 19, .length = 2},
  [18] = {.index = 0, .length = 1},
  [20] = {.index = 21, .length = 1},
  [21] = {.index = 22, .length = 1},
  [22] = {.index = 23, .length = 1},
  [23] = {.index = 24, .length = 1},
  [24] = {.index = 25, .length = 2},
  [25] = {.index = 27, .length = 2},
  [26] = {.index = 29, .length = 1},
  [27] = {.index = 30, .length = 1},
  [28] = {.index = 31, .length = 1},
  [29] = {.index = 32, .length = 2},
  [30] = {.index = 34, .length = 2},
  [31] = {.index = 18, .length = 1},
  [32] = {.index = 36, .length = 2},
  [33] = {.index = 38, .length = 1},
  [34] = {.index = 39, .length = 2},
  [35] = {.index = 39, .length = 2},
  [36] = {.index = 21, .length = 1},
  [37] = {.index = 41, .length = 1},
  [38] = {.index = 42, .length = 2},
  [39] = {.index = 44, .length = 2},
  [40] = {.index = 46, .length = 3},
  [41] = {.index = 49, .length = 1},
  [44] = {.index = 50, .length = 2},
  [45] = {.index = 52, .length = 1},
  [46] = {.index = 53, .length = 1},
  [47] = {.index = 54, .length = 1},
  [48] = {.index = 55, .length = 2},
  [49] = {.index = 57, .length = 2},
  [50] = {.index = 59, .length = 2},
  [51] = {.index = 61, .length = 2},
  [52] = {.index = 63, .length = 2},
  [53] = {.index = 65, .length = 1},
  [54] = {.index = 66, .length = 3},
  [55] = {.index = 69, .length = 1},
  [56] = {.index = 70, .length = 1},
  [57] = {.index = 71, .length = 1},
  [58] = {.index = 72, .length = 2},
  [60] = {.index = 55, .length = 2},
  [61] = {.index = 74, .length = 2},
  [62] = {.index = 76, .length = 2},
  [63] = {.index = 78, .length = 2},
  [65] = {.index = 80, .length = 2},
  [66] = {.index = 82, .length = 2},
  [67] = {.index = 84, .length = 3},
  [68] = {.index = 87, .length = 2},
  [69] = {.index = 89, .length = 2},
  [70] = {.index = 91, .length = 3},
  [71] = {.index = 91, .length = 3},
  [72] = {.index = 94, .length = 2},
  [73] = {.index = 96, .length = 3},
  [74] = {.index = 99, .length = 3},
  [75] = {.index = 102, .length = 3},
  [76] = {.index = 52, .length = 1},
  [77] = {.index = 105, .length = 2},
  [78] = {.index = 107, .length = 2},
  [79] = {.index = 109, .length = 2},
  [80] = {.index = 111, .length = 1},
  [81] = {.index = 112, .length = 2},
  [82] = {.index = 114, .length = 2},
  [83] = {.index = 116, .length = 2},
  [84] = {.index = 118, .length = 3},
  [85] = {.index = 121, .length = 2},
  [86] = {.index = 123, .length = 1},
  [87] = {.index = 124, .length = 2},
  [88] = {.index = 126, .length = 2},
  [89] = {.index = 128, .length = 2},
  [90] = {.index = 130, .length = 2},
  [91] = {.index = 132, .length = 2},
  [92] = {.index = 134, .length = 2},
  [93] = {.index = 136, .length = 2},
  [94] = {.index = 138, .length = 2},
  [95] = {.index = 140, .length = 1},
  [96] = {.index = 138, .length = 2},
  [98] = {.index = 141, .length = 2},
  [99] = {.index = 143, .length = 1},
  [100] = {.index = 143, .length = 1},
  [101] = {.index = 144, .length = 3},
  [103] = {.index = 147, .length = 2},
  [104] = {.index = 149, .length = 2},
  [105] = {.index = 151, .length = 2},
  [106] = {.index = 153, .length = 3},
  [107] = {.index = 156, .length = 1},
  [108] = {.index = 157, .length = 1},
  [110] = {.index = 158, .length = 3},
  [111] = {.index = 161, .length = 3},
  [112] = {.index = 164, .length = 3},
  [113] = {.index = 167, .length = 3},
  [114] = {.index = 170, .length = 2},
  [115] = {.index = 172, .length = 3},
  [116] = {.index = 175, .length = 3},
  [117] = {.index = 178, .length = 2},
  [118] = {.index = 180, .length = 3},
  [119] = {.index = 183, .length = 2},
  [120] = {.index = 19, .length = 2},
  [121] = {.index = 39, .length = 2},
  [122] = {.index = 185, .length = 2},
  [123] = {.index = 187, .length = 2},
  [124] = {.index = 189, .length = 1},
  [125] = {.index = 190, .length = 4},
  [126] = {.index = 194, .length = 4},
  [127] = {.index = 198, .length = 2},
  [128] = {.index = 200, .length = 3},
  [129] = {.index = 203, .length = 2},
  [130] = {.index = 205, .length = 2},
  [131] = {.index = 207, .length = 1},
  [132] = {.index = 208, .length = 2},
  [133] = {.index = 210, .length = 2},
  [134] = {.index = 212, .length = 3},
  [135] = {.index = 215, .length = 3},
  [136] = {.index = 218, .length = 3},
  [137] = {.index = 221, .length = 2},
  [138] = {.index = 223, .length = 2},
  [139] = {.index = 223, .length = 2},
  [140] = {.index = 225, .length = 2},
  [141] = {.index = 225, .length = 2},
  [142] = {.index = 227, .length = 2},
  [143] = {.index = 229, .length = 3},
  [144] = {.index = 232, .length = 2},
  [145] = {.index = 234, .length = 2},
  [146] = {.index = 236, .length = 3},
  [147] = {.index = 239, .length = 2},
  [148] = {.index = 241, .length = 3},
  [149] = {.index = 244, .length = 2},
  [150] = {.index = 246, .length = 1},
  [151] = {.index = 247, .length = 2},
  [152] = {.index = 249, .length = 2},
  [153] = {.index = 251, .length = 4},
  [154] = {.index = 255, .length = 5},
  [155] = {.index = 260, .length = 1},
  [156] = {.index = 261, .length = 1},
  [157] = {.index = 262, .length = 2},
  [158] = {.index = 264, .length = 1},
  [160] = {.index = 265, .length = 1},
  [161] = {.index = 266, .length = 2},
  [162] = {.index = 268, .length = 2},
  [163] = {.index = 11, .length = 1},
  [164] = {.index = 11, .length = 1},
  [165] = {.index = 270, .length = 2},
  [166] = {.index = 272, .length = 1},
  [167] = {.index = 273, .length = 1},
  [168] = {.index = 274, .length = 4},
  [169] = {.index = 278, .length = 2},
  [170] = {.index = 280, .length = 4},
  [171] = {.index = 284, .length = 1},
  [172] = {.index = 285, .length = 3},
  [173] = {.index = 288, .length = 2},
  [174] = {.index = 290, .length = 3},
  [175] = {.index = 293, .length = 1},
  [176] = {.index = 294, .length = 5},
  [177] = {.index = 299, .length = 2},
  [178] = {.index = 301, .length = 2},
  [179] = {.index = 303, .length = 4},
  [180] = {.index = 307, .length = 2},
  [181] = {.index = 309, .length = 2},
  [182] = {.index = 311, .length = 3},
  [183] = {.index = 314, .length = 4},
  [184] = {.index = 318, .length = 4},
  [185] = {.index = 322, .length = 3},
  [186] = {.index = 325, .length = 2},
  [187] = {.index = 327, .length = 3},
  [188] = {.index = 330, .length = 3},
  [189] = {.index = 333, .length = 2},
  [190] = {.index = 335, .length = 2},
  [191] = {.index = 337, .length = 2},
  [192] = {.index = 339, .length = 2},
  [193] = {.index = 341, .length = 3},
  [194] = {.index = 344, .length = 2},
  [195] = {.index = 346, .length = 2},
  [196] = {.index = 348, .length = 3},
  [197] = {.index = 351, .length = 2},
  [198] = {.index = 353, .length = 2},
  [199] = {.index = 355, .length = 2},
  [200] = {.index = 357, .length = 4},
  [201] = {.index = 361, .length = 5},
  [202] = {.index = 366, .length = 3},
  [203] = {.index = 369, .length = 4},
  [204] = {.index = 373, .length = 2},
  [205] = {.index = 375, .length = 1},
  [206] = {.index = 376, .length = 4},
  [207] = {.index = 380, .length = 3},
  [208] = {.index = 383, .length = 2},
  [209] = {.index = 385, .length = 1},
  [210] = {.index = 386, .length = 5},
  [211] = {.index = 391, .length = 2},
  [212] = {.index = 393, .length = 2},
  [213] = {.index = 65, .length = 1},
  [214] = {.index = 395, .length = 5},
  [215] = {.index = 400, .length = 4},
  [216] = {.index = 404, .length = 2},
  [217] = {.index = 406, .length = 2},
  [218] = {.index = 408, .length = 5},
  [219] = {.index = 413, .length = 2},
  [220] = {.index = 415, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_type, 0},
  [1] =
    {field_directive, 0},
  [2] =
    {field_argument, 1},
    {field_operator, 0},
  [4] =
    {field_declarator, 1},
  [5] =
    {field_name, 0},
  [6] =
    {field_arguments, 1},
    {field_function, 0},
  [8] =
    {field_type, 0},
    {field_value, 1},
  [10] =
    {field_body, 1},
  [11] =
    {field_name, 1},
  [12] =
    {field_body, 0},
  [13] =
    {field_body, 1, .inherited = true},
    {field_name, 1, .inherited = true},
  [15] =
    {field_body, 0, .inherited = true},
    {field_name, 0, .inherited = true},
  [17] =
    {field_value, 1},
  [18] =
    {field_scope, 0},
  [19] =
    {field_arguments, 1},
    {field_name, 0},
  [21] =
    {field_type, 1},
  [22] =
    {field_requirements, 1},
  [23] =
    {field_constraint, 1},
  [24] =
    {field_parameters, 0},
  [25] =
    {field_declarator, 0},
    {field_parameters, 1, .inherited = true},
  [27] =
    {field_body, 1},
    {field_declarator, 0},
  [29] =
    {field_declarator, 0},
  [30] =
    {field_constraint, 0},
  [31] =
    {field_pattern, 0},
  [32] =
    {field_argument, 0},
    {field_operator, 1},
  [34] =
    {field_argument, 0},
    {field_indices, 1},
  [36] =
    {field_body, 1},
    {field_captures, 0},
  [38] =
    {field_parameters, 0, .inherited = true},
  [39] =
    {field_name, 1},
    {field_scope, 0, .inherited = true},
  [41] =
    {field_path, 1},
  [42] =
    {field_argument, 1},
    {field_directive, 0},
  [44] =
    {field_declarator, 1},
    {field_type, 0},
  [46] =
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [49] =
    {field_declarator, 2},
  [50] =
    {field_body, 2},
    {field_value, 1},
  [52] =
    {field_type, 2},
  [53] =
    {field_body, 2},
  [54] =
    {field_name, 2},
  [55] =
    {field_body, 2},
    {field_name, 1},
  [57] =
    {field_base, 2, .inherited = true},
    {field_name, 1},
  [59] =
    {field_body, 1},
    {field_name, 0},
  [61] =
    {field_condition, 1},
    {field_consequence, 2},
  [63] =
    {field_body, 2},
    {field_condition, 1},
  [65] =
    {field_label, 1},
  [66] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [69] =
    {field_label, 0},
  [70] =
    {field_type, 0, .inherited = true},
  [71] =
    {field_parameters, 1},
  [72] =
    {field_declarator, 2},
    {field_type, 1, .inherited = true},
  [74] =
    {field_arguments, 2},
    {field_type, 1},
  [76] =
    {field_declarator, 2},
    {field_type, 1},
  [78] =
    {field_placement, 1},
    {field_type, 2},
  [80] =
    {field_parameters, 1},
    {field_requirements, 2},
  [82] =
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
  [84] =
    {field_body, 2},
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
  [87] =
    {field_declarator, 0},
    {field_value, 1},
  [89] =
    {field_body, 2},
    {field_declarator, 0},
  [91] =
    {field_argument, 0},
    {field_field, 2},
    {field_operator, 1},
  [94] =
    {field_arguments, 2},
    {field_function, 0},
  [96] =
    {field_body, 2},
    {field_captures, 0},
    {field_declarator, 1},
  [99] =
    {field_body, 2},
    {field_captures, 0},
    {field_template_parameters, 1},
  [102] =
    {field_name, 1},
    {field_name, 2},
    {field_scope, 0, .inherited = true},
  [105] =
    {field_body, 2},
    {field_declarator, 1},
  [107] =
    {field_name, 1},
    {field_value, 2},
  [109] =
    {field_name, 1},
    {field_parameters, 2},
  [111] =
    {field_condition, 1},
  [112] =
    {field_alternative, 2},
    {field_name, 1},
  [114] =
    {field_declarator, 2},
    {field_type, 0},
  [116] =
    {field_left, 0},
    {field_right, 2},
  [118] =
    {field_left, 0},
    {field_operator, 1, .inherited = true},
    {field_right, 2},
  [121] =
    {field_type, 1},
    {field_value, 3},
  [123] =
    {field_declarator, 3},
  [124] =
    {field_declarator, 2, .inherited = true},
    {field_type, 1, .inherited = true},
  [126] =
    {field_declarator, 0},
    {field_parameters, 1},
  [128] =
    {field_declarator, 0},
    {field_declarator, 1, .inherited = true},
  [130] =
    {field_arguments, 3},
    {field_type, 2},
  [132] =
    {field_declarator, 3},
    {field_type, 2},
  [134] =
    {field_placement, 2},
    {field_type, 3},
  [136] =
    {field_name, 2},
    {field_prefix, 0},
  [138] =
    {field_body, 3},
    {field_name, 2},
  [140] =
    {field_body, 3},
  [141] =
    {field_base, 3, .inherited = true},
    {field_name, 2},
  [143] =
    {field_base, 1},
  [144] =
    {field_base, 2, .inherited = true},
    {field_body, 3},
    {field_name, 1},
  [147] =
    {field_body, 2, .inherited = true},
    {field_name, 2, .inherited = true},
  [149] =
    {field_body, 2},
    {field_name, 0},
  [151] =
    {field_condition, 2},
    {field_consequence, 3},
  [153] =
    {field_alternative, 3},
    {field_condition, 1},
    {field_consequence, 2},
  [156] =
    {field_initializer, 0},
  [157] =
    {field_assembly_code, 2},
  [158] =
    {field_arguments, 3},
    {field_declarator, 2},
    {field_type, 1},
  [161] =
    {field_arguments, 3},
    {field_placement, 1},
    {field_type, 2},
  [164] =
    {field_declarator, 3},
    {field_placement, 1},
    {field_type, 2},
  [167] =
    {field_body, 3},
    {field_declarator, 2},
    {field_type, 0, .inherited = true},
  [170] =
    {field_declarator, 0},
    {field_value, 2},
  [172] =
    {field_declarator, 1},
    {field_declarator, 2},
    {field_type, 0, .inherited = true},
  [175] =
    {field_declarator, 1},
    {field_declarator, 2, .inherited = true},
    {field_type, 0, .inherited = true},
  [178] =
    {field_declarator, 0, .inherited = true},
    {field_declarator, 1, .inherited = true},
  [180] =
    {field_body, 3},
    {field_declarator, 2},
    {field_type, 1, .inherited = true},
  [183] =
    {field_declarator, 0},
    {field_size, 2},
  [185] =
    {field_alternative, 3},
    {field_condition, 0},
  [187] =
    {field_declarator, 0},
    {field_default_value, 2},
  [189] =
    {field_size, 1},
  [190] =
    {field_body, 3},
    {field_captures, 0},
    {field_declarator, 2},
    {field_template_parameters, 1},
  [194] =
    {field_body, 3},
    {field_captures, 0},
    {field_constraint, 2},
    {field_template_parameters, 1},
  [198] =
    {field_body, 3},
    {field_declarator, 1},
  [200] =
    {field_name, 1},
    {field_parameters, 2},
    {field_value, 3},
  [203] =
    {field_alternative, 3},
    {field_condition, 1},
  [205] =
    {field_alternative, 3},
    {field_name, 1},
  [207] =
    {field_operator, 0},
  [208] =
    {field_declarator, 3},
    {field_type, 1},
  [210] =
    {field_declarator, 3, .inherited = true},
    {field_type, 2, .inherited = true},
  [212] =
    {field_arguments, 4},
    {field_declarator, 3},
    {field_type, 2},
  [215] =
    {field_arguments, 4},
    {field_placement, 2},
    {field_type, 3},
  [218] =
    {field_declarator, 4},
    {field_placement, 2},
    {field_type, 3},
  [221] =
    {field_left, 1},
    {field_right, 3},
  [223] =
    {field_body, 4},
    {field_name, 3},
  [225] =
    {field_designator, 0},
    {field_value, 2},
  [227] =
    {field_name, 0},
    {field_value, 2},
  [229] =
    {field_base, 3, .inherited = true},
    {field_body, 4},
    {field_name, 2},
  [232] =
    {field_body, 3},
    {field_name, 0},
  [234] =
    {field_body, 3, .inherited = true},
    {field_name, 3, .inherited = true},
  [236] =
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
    {field_value, 2},
  [239] =
    {field_initializer, 1},
    {field_value, 2},
  [241] =
    {field_alternative, 4},
    {field_condition, 2},
    {field_consequence, 3},
  [244] =
    {field_body, 1},
    {field_condition, 3},
  [246] =
    {field_update, 2},
  [247] =
    {field_initializer, 0},
    {field_update, 2},
  [249] =
    {field_condition, 1},
    {field_initializer, 0},
  [251] =
    {field_body, 4},
    {field_condition, 2, .inherited = true},
    {field_initializer, 2, .inherited = true},
    {field_update, 2, .inherited = true},
  [255] =
    {field_body, 4},
    {field_declarator, 2, .inherited = true},
    {field_initializer, 2, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_type, 2, .inherited = true},
  [260] =
    {field_value, 3},
  [261] =
    {field_operand, 1},
  [262] =
    {field_assembly_code, 2},
    {field_output_operands, 3},
  [264] =
    {field_assembly_code, 3},
  [265] =
    {field_default_type, 2},
  [266] =
    {field_default_value, 2},
    {field_type, 0, .inherited = true},
  [268] =
    {field_body, 2},
    {field_parameters, 1},
  [270] =
    {field_name, 1},
    {field_type, 3},
  [272] =
    {field_condition, 2},
  [273] =
    {field_length, 1},
  [274] =
    {field_arguments, 4},
    {field_declarator, 3},
    {field_placement, 1},
    {field_type, 2},
  [278] =
    {field_declarator, 1},
    {field_declarator, 2},
  [280] =
    {field_declarator, 1},
    {field_declarator, 2},
    {field_declarator, 3, .inherited = true},
    {field_type, 0, .inherited = true},
  [284] =
    {field_declarator, 4},
  [285] =
    {field_body, 4},
    {field_declarator, 3},
    {field_type, 1, .inherited = true},
  [288] =
    {field_declarator, 0},
    {field_size, 3},
  [290] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [293] =
    {field_size, 2},
  [294] =
    {field_body, 4},
    {field_captures, 0},
    {field_constraint, 2},
    {field_declarator, 3},
    {field_template_parameters, 1},
  [299] =
    {field_declarator, 1},
    {field_default_value, 3},
  [301] =
    {field_alternative, 4},
    {field_condition, 1},
  [303] =
    {field_arguments, 5},
    {field_declarator, 4},
    {field_placement, 2},
    {field_type, 3},
  [307] =
    {field_body, 2},
    {field_filter, 1},
  [309] =
    {field_left, 2},
    {field_right, 4},
  [311] =
    {field_declarator, 1},
    {field_default_value, 2},
    {field_type, 0, .inherited = true},
  [314] =
    {field_declarator, 1},
    {field_declarator, 2, .inherited = true},
    {field_default_value, 2, .inherited = true},
    {field_type, 0, .inherited = true},
  [318] =
    {field_declarator, 0, .inherited = true},
    {field_declarator, 1, .inherited = true},
    {field_default_value, 0, .inherited = true},
    {field_default_value, 1, .inherited = true},
  [322] =
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
    {field_value, 3},
  [325] =
    {field_condition, 1},
    {field_update, 3},
  [327] =
    {field_condition, 1},
    {field_initializer, 0},
    {field_update, 3},
  [330] =
    {field_declarator, 1},
    {field_right, 3},
    {field_type, 0, .inherited = true},
  [333] =
    {field_initializer, 0},
    {field_update, 3},
  [335] =
    {field_condition, 2},
    {field_initializer, 0},
  [337] =
    {field_member, 4},
    {field_type, 2},
  [339] =
    {field_operand, 1},
    {field_operand, 2, .inherited = true},
  [341] =
    {field_assembly_code, 2},
    {field_input_operands, 4},
    {field_output_operands, 3},
  [344] =
    {field_assembly_code, 3},
    {field_output_operands, 4},
  [346] =
    {field_default_type, 3},
    {field_name, 1},
  [348] =
    {field_declarator, 1},
    {field_default_value, 3},
    {field_type, 0, .inherited = true},
  [351] =
    {field_name, 1},
    {field_type, 4},
  [353] =
    {field_end, 3},
    {field_start, 1},
  [355] =
    {field_declarator, 1},
    {field_default_value, 2},
  [357] =
    {field_declarator, 1},
    {field_declarator, 3, .inherited = true},
    {field_default_value, 3, .inherited = true},
    {field_type, 0, .inherited = true},
  [361] =
    {field_declarator, 1},
    {field_declarator, 3, .inherited = true},
    {field_default_value, 2},
    {field_default_value, 3, .inherited = true},
    {field_type, 0, .inherited = true},
  [366] =
    {field_condition, 2},
    {field_initializer, 0},
    {field_update, 4},
  [369] =
    {field_declarator, 2},
    {field_initializer, 0},
    {field_right, 4},
    {field_type, 1, .inherited = true},
  [373] =
    {field_operand, 0, .inherited = true},
    {field_operand, 1, .inherited = true},
  [375] =
    {field_register, 1},
  [376] =
    {field_assembly_code, 2},
    {field_clobbers, 5},
    {field_input_operands, 4},
    {field_output_operands, 3},
  [380] =
    {field_assembly_code, 3},
    {field_input_operands, 5},
    {field_output_operands, 4},
  [383] =
    {field_condition, 2},
    {field_message, 4},
  [385] =
    {field_delimiter, 1},
  [386] =
    {field_declarator, 1},
    {field_declarator, 4, .inherited = true},
    {field_default_value, 3},
    {field_default_value, 4, .inherited = true},
    {field_type, 0, .inherited = true},
  [391] =
    {field_constraint, 0},
    {field_value, 2},
  [393] =
    {field_register, 1},
    {field_register, 2, .inherited = true},
  [395] =
    {field_assembly_code, 2},
    {field_clobbers, 5},
    {field_goto_labels, 6},
    {field_input_operands, 4},
    {field_output_operands, 3},
  [400] =
    {field_assembly_code, 3},
    {field_clobbers, 6},
    {field_input_operands, 5},
    {field_output_operands, 4},
  [404] =
    {field_register, 0, .inherited = true},
    {field_register, 1, .inherited = true},
  [406] =
    {field_label, 1},
    {field_label, 2, .inherited = true},
  [408] =
    {field_assembly_code, 3},
    {field_clobbers, 6},
    {field_goto_labels, 7},
    {field_input_operands, 5},
    {field_output_operands, 4},
  [413] =
    {field_label, 0, .inherited = true},
    {field_label, 1, .inherited = true},
  [415] =
    {field_constraint, 3},
    {field_symbol, 1},
    {field_value, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_type_identifier,
  },
  [15] = {
    [0] = alias_sym_namespace_identifier,
  },
  [16] = {
    [0] = alias_sym_type_identifier,
  },
  [18] = {
    [0] = alias_sym_type_identifier,
  },
  [19] = {
    [0] = alias_sym_namespace_identifier,
  },
  [35] = {
    [1] = alias_sym_type_identifier,
  },
  [36] = {
    [1] = alias_sym_type_identifier,
  },
  [42] = {
    [0] = sym_primitive_type,
  },
  [43] = {
    [0] = sym_pointer_declarator,
  },
  [53] = {
    [1] = alias_sym_statement_identifier,
  },
  [55] = {
    [0] = alias_sym_statement_identifier,
  },
  [59] = {
    [1] = alias_sym_namespace_identifier,
  },
  [60] = {
    [1] = alias_sym_namespace_identifier,
  },
  [64] = {
    [0] = alias_sym_simple_requirement,
  },
  [70] = {
    [2] = alias_sym_field_identifier,
  },
  [76] = {
    [2] = alias_sym_type_identifier,
  },
  [94] = {
    [2] = alias_sym_namespace_identifier,
  },
  [97] = {
    [1] = alias_sym_field_identifier,
  },
  [100] = {
    [1] = alias_sym_type_identifier,
  },
  [102] = {
    [0] = alias_sym_field_identifier,
  },
  [109] = {
    [1] = alias_sym_type_identifier,
  },
  [120] = {
    [0] = alias_sym_field_identifier,
  },
  [121] = {
    [1] = alias_sym_field_identifier,
  },
  [138] = {
    [3] = alias_sym_namespace_identifier,
  },
  [140] = {
    [0] = alias_sym_field_identifier,
  },
  [159] = {
    [2] = alias_sym_type_identifier,
  },
  [163] = {
    [1] = alias_sym_namespace_identifier,
    [3] = alias_sym_namespace_identifier,
  },
  [164] = {
    [1] = alias_sym_namespace_identifier,
  },
  [165] = {
    [1] = alias_sym_type_identifier,
  },
  [191] = {
    [4] = alias_sym_field_identifier,
  },
  [195] = {
    [1] = alias_sym_type_identifier,
  },
  [197] = {
    [1] = alias_sym_type_identifier,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_pointer_type_declarator, 2,
    sym_pointer_type_declarator,
    sym_pointer_declarator,
  sym_expression_statement, 2,
    sym_expression_statement,
    alias_sym_simple_requirement,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 2,
  [6] = 2,
  [7] = 2,
  [8] = 2,
  [9] = 2,
  [10] = 2,
  [11] = 2,
  [12] = 2,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 13,
  [21] = 21,
  [22] = 21,
  [23] = 14,
  [24] = 15,
  [25] = 15,
  [26] = 21,
  [27] = 21,
  [28] = 14,
  [29] = 15,
  [30] = 14,
  [31] = 13,
  [32] = 13,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 33,
  [38] = 34,
  [39] = 35,
  [40] = 40,
  [41] = 33,
  [42] = 40,
  [43] = 36,
  [44] = 34,
  [45] = 35,
  [46] = 40,
  [47] = 36,
  [48] = 36,
  [49] = 34,
  [50] = 36,
  [51] = 34,
  [52] = 34,
  [53] = 36,
  [54] = 34,
  [55] = 36,
  [56] = 36,
  [57] = 34,
  [58] = 58,
  [59] = 36,
  [60] = 34,
  [61] = 61,
  [62] = 36,
  [63] = 34,
  [64] = 34,
  [65] = 36,
  [66] = 34,
  [67] = 40,
  [68] = 36,
  [69] = 34,
  [70] = 36,
  [71] = 34,
  [72] = 36,
  [73] = 34,
  [74] = 36,
  [75] = 34,
  [76] = 36,
  [77] = 34,
  [78] = 36,
  [79] = 34,
  [80] = 36,
  [81] = 34,
  [82] = 36,
  [83] = 35,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 90,
  [92] = 89,
  [93] = 89,
  [94] = 87,
  [95] = 88,
  [96] = 86,
  [97] = 88,
  [98] = 86,
  [99] = 87,
  [100] = 90,
  [101] = 89,
  [102] = 87,
  [103] = 88,
  [104] = 90,
  [105] = 86,
  [106] = 106,
  [107] = 88,
  [108] = 89,
  [109] = 87,
  [110] = 86,
  [111] = 111,
  [112] = 111,
  [113] = 111,
  [114] = 111,
  [115] = 111,
  [116] = 111,
  [117] = 90,
  [118] = 118,
  [119] = 118,
  [120] = 118,
  [121] = 118,
  [122] = 118,
  [123] = 118,
  [124] = 124,
  [125] = 125,
  [126] = 125,
  [127] = 125,
  [128] = 125,
  [129] = 125,
  [130] = 130,
  [131] = 125,
  [132] = 125,
  [133] = 125,
  [134] = 134,
  [135] = 134,
  [136] = 134,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 142,
  [144] = 142,
  [145] = 142,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 139,
  [151] = 138,
  [152] = 152,
  [153] = 148,
  [154] = 152,
  [155] = 152,
  [156] = 148,
  [157] = 152,
  [158] = 148,
  [159] = 152,
  [160] = 148,
  [161] = 152,
  [162] = 148,
  [163] = 152,
  [164] = 148,
  [165] = 165,
  [166] = 152,
  [167] = 148,
  [168] = 168,
  [169] = 152,
  [170] = 152,
  [171] = 152,
  [172] = 148,
  [173] = 148,
  [174] = 152,
  [175] = 148,
  [176] = 152,
  [177] = 152,
  [178] = 148,
  [179] = 148,
  [180] = 152,
  [181] = 148,
  [182] = 148,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 228,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 141,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 230,
  [246] = 231,
  [247] = 228,
  [248] = 230,
  [249] = 231,
  [250] = 232,
  [251] = 251,
  [252] = 252,
  [253] = 232,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 142,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 140,
  [274] = 274,
  [275] = 140,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 141,
  [281] = 141,
  [282] = 142,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 142,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 142,
  [311] = 311,
  [312] = 140,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 142,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 142,
  [321] = 321,
  [322] = 322,
  [323] = 147,
  [324] = 146,
  [325] = 325,
  [326] = 326,
  [327] = 146,
  [328] = 325,
  [329] = 147,
  [330] = 139,
  [331] = 165,
  [332] = 149,
  [333] = 165,
  [334] = 138,
  [335] = 168,
  [336] = 149,
  [337] = 139,
  [338] = 165,
  [339] = 138,
  [340] = 326,
  [341] = 149,
  [342] = 168,
  [343] = 168,
  [344] = 223,
  [345] = 194,
  [346] = 207,
  [347] = 218,
  [348] = 220,
  [349] = 215,
  [350] = 147,
  [351] = 193,
  [352] = 222,
  [353] = 189,
  [354] = 191,
  [355] = 208,
  [356] = 209,
  [357] = 217,
  [358] = 221,
  [359] = 203,
  [360] = 146,
  [361] = 185,
  [362] = 187,
  [363] = 183,
  [364] = 211,
  [365] = 200,
  [366] = 202,
  [367] = 200,
  [368] = 201,
  [369] = 223,
  [370] = 202,
  [371] = 223,
  [372] = 204,
  [373] = 204,
  [374] = 205,
  [375] = 201,
  [376] = 206,
  [377] = 202,
  [378] = 204,
  [379] = 205,
  [380] = 206,
  [381] = 207,
  [382] = 183,
  [383] = 197,
  [384] = 184,
  [385] = 190,
  [386] = 192,
  [387] = 195,
  [388] = 198,
  [389] = 212,
  [390] = 213,
  [391] = 207,
  [392] = 188,
  [393] = 194,
  [394] = 191,
  [395] = 183,
  [396] = 211,
  [397] = 208,
  [398] = 209,
  [399] = 210,
  [400] = 217,
  [401] = 221,
  [402] = 197,
  [403] = 187,
  [404] = 197,
  [405] = 184,
  [406] = 214,
  [407] = 216,
  [408] = 184,
  [409] = 218,
  [410] = 220,
  [411] = 215,
  [412] = 190,
  [413] = 203,
  [414] = 192,
  [415] = 195,
  [416] = 200,
  [417] = 211,
  [418] = 193,
  [419] = 186,
  [420] = 222,
  [421] = 189,
  [422] = 185,
  [423] = 201,
  [424] = 326,
  [425] = 198,
  [426] = 212,
  [427] = 213,
  [428] = 214,
  [429] = 216,
  [430] = 186,
  [431] = 193,
  [432] = 188,
  [433] = 433,
  [434] = 190,
  [435] = 194,
  [436] = 192,
  [437] = 195,
  [438] = 218,
  [439] = 220,
  [440] = 215,
  [441] = 222,
  [442] = 189,
  [443] = 191,
  [444] = 208,
  [445] = 209,
  [446] = 210,
  [447] = 217,
  [448] = 221,
  [449] = 205,
  [450] = 203,
  [451] = 198,
  [452] = 185,
  [453] = 187,
  [454] = 212,
  [455] = 213,
  [456] = 214,
  [457] = 216,
  [458] = 206,
  [459] = 186,
  [460] = 188,
  [461] = 210,
  [462] = 284,
  [463] = 284,
  [464] = 305,
  [465] = 308,
  [466] = 319,
  [467] = 226,
  [468] = 227,
  [469] = 237,
  [470] = 293,
  [471] = 303,
  [472] = 291,
  [473] = 292,
  [474] = 294,
  [475] = 295,
  [476] = 298,
  [477] = 300,
  [478] = 297,
  [479] = 296,
  [480] = 276,
  [481] = 299,
  [482] = 301,
  [483] = 239,
  [484] = 241,
  [485] = 242,
  [486] = 243,
  [487] = 244,
  [488] = 251,
  [489] = 255,
  [490] = 490,
  [491] = 284,
  [492] = 304,
  [493] = 224,
  [494] = 291,
  [495] = 303,
  [496] = 292,
  [497] = 238,
  [498] = 225,
  [499] = 235,
  [500] = 267,
  [501] = 268,
  [502] = 271,
  [503] = 317,
  [504] = 293,
  [505] = 294,
  [506] = 236,
  [507] = 263,
  [508] = 300,
  [509] = 322,
  [510] = 277,
  [511] = 283,
  [512] = 285,
  [513] = 286,
  [514] = 287,
  [515] = 290,
  [516] = 296,
  [517] = 290,
  [518] = 295,
  [519] = 314,
  [520] = 313,
  [521] = 254,
  [522] = 315,
  [523] = 318,
  [524] = 322,
  [525] = 313,
  [526] = 315,
  [527] = 318,
  [528] = 276,
  [529] = 286,
  [530] = 490,
  [531] = 233,
  [532] = 234,
  [533] = 233,
  [534] = 234,
  [535] = 257,
  [536] = 239,
  [537] = 241,
  [538] = 242,
  [539] = 243,
  [540] = 244,
  [541] = 251,
  [542] = 255,
  [543] = 257,
  [544] = 264,
  [545] = 266,
  [546] = 264,
  [547] = 266,
  [548] = 283,
  [549] = 490,
  [550] = 269,
  [551] = 270,
  [552] = 272,
  [553] = 287,
  [554] = 269,
  [555] = 270,
  [556] = 272,
  [557] = 326,
  [558] = 302,
  [559] = 304,
  [560] = 490,
  [561] = 307,
  [562] = 224,
  [563] = 309,
  [564] = 311,
  [565] = 297,
  [566] = 298,
  [567] = 285,
  [568] = 321,
  [569] = 306,
  [570] = 238,
  [571] = 225,
  [572] = 235,
  [573] = 490,
  [574] = 267,
  [575] = 268,
  [576] = 271,
  [577] = 274,
  [578] = 278,
  [579] = 490,
  [580] = 279,
  [581] = 299,
  [582] = 300,
  [583] = 302,
  [584] = 252,
  [585] = 265,
  [586] = 490,
  [587] = 301,
  [588] = 307,
  [589] = 309,
  [590] = 311,
  [591] = 490,
  [592] = 321,
  [593] = 306,
  [594] = 305,
  [595] = 308,
  [596] = 314,
  [597] = 317,
  [598] = 490,
  [599] = 319,
  [600] = 274,
  [601] = 226,
  [602] = 227,
  [603] = 490,
  [604] = 278,
  [605] = 236,
  [606] = 237,
  [607] = 490,
  [608] = 279,
  [609] = 289,
  [610] = 490,
  [611] = 254,
  [612] = 490,
  [613] = 263,
  [614] = 490,
  [615] = 262,
  [616] = 490,
  [617] = 262,
  [618] = 490,
  [619] = 252,
  [620] = 490,
  [621] = 265,
  [622] = 490,
  [623] = 490,
  [624] = 277,
  [625] = 193,
  [626] = 289,
  [627] = 627,
  [628] = 628,
  [629] = 629,
  [630] = 630,
  [631] = 631,
  [632] = 628,
  [633] = 633,
  [634] = 633,
  [635] = 635,
  [636] = 636,
  [637] = 637,
  [638] = 636,
  [639] = 630,
  [640] = 640,
  [641] = 326,
  [642] = 628,
  [643] = 630,
  [644] = 640,
  [645] = 637,
  [646] = 636,
  [647] = 630,
  [648] = 640,
  [649] = 627,
  [650] = 629,
  [651] = 633,
  [652] = 627,
  [653] = 627,
  [654] = 629,
  [655] = 633,
  [656] = 629,
  [657] = 629,
  [658] = 628,
  [659] = 633,
  [660] = 633,
  [661] = 636,
  [662] = 636,
  [663] = 630,
  [664] = 640,
  [665] = 630,
  [666] = 637,
  [667] = 640,
  [668] = 668,
  [669] = 637,
  [670] = 637,
  [671] = 627,
  [672] = 629,
  [673] = 326,
  [674] = 637,
  [675] = 668,
  [676] = 326,
  [677] = 631,
  [678] = 627,
  [679] = 628,
  [680] = 668,
  [681] = 668,
  [682] = 636,
  [683] = 668,
  [684] = 640,
  [685] = 628,
  [686] = 686,
  [687] = 306,
  [688] = 238,
  [689] = 225,
  [690] = 235,
  [691] = 307,
  [692] = 224,
  [693] = 267,
  [694] = 305,
  [695] = 308,
  [696] = 314,
  [697] = 317,
  [698] = 319,
  [699] = 268,
  [700] = 226,
  [701] = 227,
  [702] = 271,
  [703] = 286,
  [704] = 236,
  [705] = 237,
  [706] = 287,
  [707] = 322,
  [708] = 296,
  [709] = 313,
  [710] = 277,
  [711] = 274,
  [712] = 315,
  [713] = 713,
  [714] = 309,
  [715] = 318,
  [716] = 311,
  [717] = 276,
  [718] = 278,
  [719] = 297,
  [720] = 301,
  [721] = 289,
  [722] = 298,
  [723] = 254,
  [724] = 233,
  [725] = 279,
  [726] = 234,
  [727] = 302,
  [728] = 686,
  [729] = 263,
  [730] = 295,
  [731] = 241,
  [732] = 242,
  [733] = 243,
  [734] = 686,
  [735] = 244,
  [736] = 251,
  [737] = 686,
  [738] = 686,
  [739] = 739,
  [740] = 686,
  [741] = 686,
  [742] = 686,
  [743] = 686,
  [744] = 686,
  [745] = 686,
  [746] = 686,
  [747] = 686,
  [748] = 255,
  [749] = 257,
  [750] = 750,
  [751] = 291,
  [752] = 304,
  [753] = 292,
  [754] = 264,
  [755] = 266,
  [756] = 283,
  [757] = 285,
  [758] = 686,
  [759] = 321,
  [760] = 269,
  [761] = 270,
  [762] = 272,
  [763] = 293,
  [764] = 252,
  [765] = 294,
  [766] = 303,
  [767] = 265,
  [768] = 290,
  [769] = 299,
  [770] = 239,
  [771] = 771,
  [772] = 326,
  [773] = 433,
  [774] = 774,
  [775] = 771,
  [776] = 774,
  [777] = 771,
  [778] = 778,
  [779] = 771,
  [780] = 774,
  [781] = 774,
  [782] = 782,
  [783] = 771,
  [784] = 774,
  [785] = 771,
  [786] = 774,
  [787] = 771,
  [788] = 774,
  [789] = 771,
  [790] = 774,
  [791] = 774,
  [792] = 771,
  [793] = 774,
  [794] = 771,
  [795] = 774,
  [796] = 433,
  [797] = 771,
  [798] = 774,
  [799] = 771,
  [800] = 800,
  [801] = 800,
  [802] = 326,
  [803] = 326,
  [804] = 326,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 807,
  [809] = 807,
  [810] = 807,
  [811] = 807,
  [812] = 807,
  [813] = 807,
  [814] = 326,
  [815] = 326,
  [816] = 326,
  [817] = 326,
  [818] = 818,
  [819] = 325,
  [820] = 818,
  [821] = 325,
  [822] = 818,
  [823] = 325,
  [824] = 818,
  [825] = 818,
  [826] = 818,
  [827] = 818,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 140,
  [833] = 831,
  [834] = 141,
  [835] = 831,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 838,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 840,
  [845] = 845,
  [846] = 843,
  [847] = 842,
  [848] = 848,
  [849] = 139,
  [850] = 840,
  [851] = 848,
  [852] = 840,
  [853] = 843,
  [854] = 149,
  [855] = 843,
  [856] = 856,
  [857] = 168,
  [858] = 138,
  [859] = 840,
  [860] = 165,
  [861] = 861,
  [862] = 843,
  [863] = 863,
  [864] = 861,
  [865] = 805,
  [866] = 211,
  [867] = 222,
  [868] = 189,
  [869] = 214,
  [870] = 191,
  [871] = 216,
  [872] = 208,
  [873] = 209,
  [874] = 210,
  [875] = 217,
  [876] = 830,
  [877] = 218,
  [878] = 220,
  [879] = 215,
  [880] = 221,
  [881] = 185,
  [882] = 194,
  [883] = 203,
  [884] = 806,
  [885] = 201,
  [886] = 202,
  [887] = 223,
  [888] = 204,
  [889] = 205,
  [890] = 206,
  [891] = 207,
  [892] = 183,
  [893] = 197,
  [894] = 184,
  [895] = 190,
  [896] = 192,
  [897] = 195,
  [898] = 198,
  [899] = 212,
  [900] = 213,
  [901] = 200,
  [902] = 186,
  [903] = 188,
  [904] = 187,
  [905] = 905,
  [906] = 325,
  [907] = 325,
  [908] = 908,
  [909] = 325,
  [910] = 908,
  [911] = 908,
  [912] = 908,
  [913] = 913,
  [914] = 913,
  [915] = 908,
  [916] = 908,
  [917] = 913,
  [918] = 918,
  [919] = 918,
  [920] = 920,
  [921] = 921,
  [922] = 920,
  [923] = 923,
  [924] = 924,
  [925] = 921,
  [926] = 920,
  [927] = 921,
  [928] = 920,
  [929] = 929,
  [930] = 921,
  [931] = 931,
  [932] = 924,
  [933] = 920,
  [934] = 934,
  [935] = 921,
  [936] = 921,
  [937] = 924,
  [938] = 920,
  [939] = 921,
  [940] = 920,
  [941] = 920,
  [942] = 921,
  [943] = 924,
  [944] = 924,
  [945] = 945,
  [946] = 924,
  [947] = 947,
  [948] = 921,
  [949] = 949,
  [950] = 920,
  [951] = 951,
  [952] = 920,
  [953] = 921,
  [954] = 921,
  [955] = 955,
  [956] = 924,
  [957] = 924,
  [958] = 958,
  [959] = 920,
  [960] = 960,
  [961] = 960,
  [962] = 960,
  [963] = 963,
  [964] = 963,
  [965] = 963,
  [966] = 960,
  [967] = 967,
  [968] = 960,
  [969] = 963,
  [970] = 960,
  [971] = 963,
  [972] = 960,
  [973] = 960,
  [974] = 963,
  [975] = 963,
  [976] = 963,
  [977] = 977,
  [978] = 978,
  [979] = 979,
  [980] = 980,
  [981] = 980,
  [982] = 982,
  [983] = 955,
  [984] = 982,
  [985] = 985,
  [986] = 982,
  [987] = 982,
  [988] = 314,
  [989] = 254,
  [990] = 990,
  [991] = 967,
  [992] = 992,
  [993] = 992,
  [994] = 994,
  [995] = 992,
  [996] = 996,
  [997] = 997,
  [998] = 990,
  [999] = 996,
  [1000] = 994,
  [1001] = 990,
  [1002] = 992,
  [1003] = 990,
  [1004] = 990,
  [1005] = 990,
  [1006] = 990,
  [1007] = 992,
  [1008] = 990,
  [1009] = 994,
  [1010] = 990,
  [1011] = 992,
  [1012] = 990,
  [1013] = 992,
  [1014] = 992,
  [1015] = 994,
  [1016] = 992,
  [1017] = 994,
  [1018] = 1018,
  [1019] = 990,
  [1020] = 955,
  [1021] = 996,
  [1022] = 1022,
  [1023] = 949,
  [1024] = 1024,
  [1025] = 945,
  [1026] = 947,
  [1027] = 949,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1022,
  [1032] = 1032,
  [1033] = 1022,
  [1034] = 1034,
  [1035] = 1032,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1032,
  [1039] = 945,
  [1040] = 1032,
  [1041] = 1024,
  [1042] = 929,
  [1043] = 1043,
  [1044] = 931,
  [1045] = 934,
  [1046] = 923,
  [1047] = 1022,
  [1048] = 1048,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1022,
  [1053] = 1024,
  [1054] = 1032,
  [1055] = 1032,
  [1056] = 1022,
  [1057] = 1032,
  [1058] = 1022,
  [1059] = 923,
  [1060] = 1022,
  [1061] = 955,
  [1062] = 1022,
  [1063] = 1032,
  [1064] = 1022,
  [1065] = 929,
  [1066] = 931,
  [1067] = 934,
  [1068] = 1022,
  [1069] = 1024,
  [1070] = 967,
  [1071] = 1022,
  [1072] = 1032,
  [1073] = 1022,
  [1074] = 1022,
  [1075] = 1032,
  [1076] = 1022,
  [1077] = 1032,
  [1078] = 947,
  [1079] = 1032,
  [1080] = 1032,
  [1081] = 1032,
  [1082] = 1032,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1086,
  [1087] = 1087,
  [1088] = 1087,
  [1089] = 1087,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1092,
  [1094] = 1084,
  [1095] = 1084,
  [1096] = 1087,
  [1097] = 1087,
  [1098] = 1098,
  [1099] = 1092,
  [1100] = 1084,
  [1101] = 1087,
  [1102] = 1087,
  [1103] = 1084,
  [1104] = 1084,
  [1105] = 1087,
  [1106] = 1084,
  [1107] = 1107,
  [1108] = 1092,
  [1109] = 1109,
  [1110] = 1084,
  [1111] = 1084,
  [1112] = 1087,
  [1113] = 967,
  [1114] = 1114,
  [1115] = 1092,
  [1116] = 1087,
  [1117] = 1117,
  [1118] = 1092,
  [1119] = 1119,
  [1120] = 1084,
  [1121] = 1121,
  [1122] = 1084,
  [1123] = 1092,
  [1124] = 1087,
  [1125] = 1087,
  [1126] = 1092,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1084,
  [1130] = 1084,
  [1131] = 1087,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1084,
  [1135] = 1087,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 1087,
  [1139] = 1084,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 1147,
  [1148] = 1148,
  [1149] = 1149,
  [1150] = 1143,
  [1151] = 1151,
  [1152] = 1143,
  [1153] = 1153,
  [1154] = 1154,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1156,
  [1161] = 1153,
  [1162] = 1158,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1154,
  [1166] = 1166,
  [1167] = 1143,
  [1168] = 1146,
  [1169] = 1147,
  [1170] = 1157,
  [1171] = 1171,
  [1172] = 1143,
  [1173] = 1173,
  [1174] = 1174,
  [1175] = 1149,
  [1176] = 1144,
  [1177] = 1148,
  [1178] = 1178,
  [1179] = 1145,
  [1180] = 1147,
  [1181] = 1155,
  [1182] = 1182,
  [1183] = 1166,
  [1184] = 1146,
  [1185] = 1185,
  [1186] = 1143,
  [1187] = 1187,
  [1188] = 1145,
  [1189] = 1189,
  [1190] = 1166,
  [1191] = 1143,
  [1192] = 1192,
  [1193] = 1166,
  [1194] = 1194,
  [1195] = 1159,
  [1196] = 1166,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1166,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1166,
  [1203] = 1178,
  [1204] = 1192,
  [1205] = 1166,
  [1206] = 1206,
  [1207] = 1143,
  [1208] = 1166,
  [1209] = 1189,
  [1210] = 1210,
  [1211] = 1166,
  [1212] = 1164,
  [1213] = 1166,
  [1214] = 1185,
  [1215] = 1187,
  [1216] = 1143,
  [1217] = 1197,
  [1218] = 1198,
  [1219] = 1173,
  [1220] = 1140,
  [1221] = 1221,
  [1222] = 1222,
  [1223] = 1194,
  [1224] = 1143,
  [1225] = 1143,
  [1226] = 1221,
  [1227] = 1194,
  [1228] = 1194,
  [1229] = 1143,
  [1230] = 1143,
  [1231] = 1145,
  [1232] = 1151,
  [1233] = 1233,
  [1234] = 1146,
  [1235] = 1194,
  [1236] = 1236,
  [1237] = 1200,
  [1238] = 1174,
  [1239] = 1146,
  [1240] = 1143,
  [1241] = 1201,
  [1242] = 1141,
  [1243] = 1142,
  [1244] = 1189,
  [1245] = 1210,
  [1246] = 1147,
  [1247] = 1222,
  [1248] = 1236,
  [1249] = 1143,
  [1250] = 1145,
  [1251] = 1147,
  [1252] = 1166,
  [1253] = 1253,
  [1254] = 1254,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1253,
  [1261] = 1258,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1264,
  [1265] = 1265,
  [1266] = 1266,
  [1267] = 1253,
  [1268] = 1258,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1276,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 1281,
  [1282] = 1262,
  [1283] = 1263,
  [1284] = 1280,
  [1285] = 1285,
  [1286] = 1255,
  [1287] = 1269,
  [1288] = 1270,
  [1289] = 1271,
  [1290] = 1272,
  [1291] = 1273,
  [1292] = 1274,
  [1293] = 1275,
  [1294] = 1276,
  [1295] = 1277,
  [1296] = 1278,
  [1297] = 1279,
  [1298] = 1298,
  [1299] = 1253,
  [1300] = 1258,
  [1301] = 1263,
  [1302] = 1279,
  [1303] = 1303,
  [1304] = 1304,
  [1305] = 1305,
  [1306] = 1306,
  [1307] = 1307,
  [1308] = 1280,
  [1309] = 1255,
  [1310] = 1253,
  [1311] = 1258,
  [1312] = 1263,
  [1313] = 1279,
  [1314] = 1314,
  [1315] = 1315,
  [1316] = 1280,
  [1317] = 1255,
  [1318] = 1253,
  [1319] = 1258,
  [1320] = 1263,
  [1321] = 1279,
  [1322] = 1280,
  [1323] = 1280,
  [1324] = 1255,
  [1325] = 1253,
  [1326] = 1258,
  [1327] = 1263,
  [1328] = 1279,
  [1329] = 1280,
  [1330] = 1330,
  [1331] = 1255,
  [1332] = 1263,
  [1333] = 1279,
  [1334] = 923,
  [1335] = 1280,
  [1336] = 945,
  [1337] = 947,
  [1338] = 949,
  [1339] = 1255,
  [1340] = 929,
  [1341] = 931,
  [1342] = 934,
  [1343] = 967,
  [1344] = 1344,
  [1345] = 1315,
  [1346] = 1305,
  [1347] = 1253,
  [1348] = 1258,
  [1349] = 1281,
  [1350] = 1262,
  [1351] = 1263,
  [1352] = 1314,
  [1353] = 1281,
  [1354] = 1354,
  [1355] = 1269,
  [1356] = 1270,
  [1357] = 1271,
  [1358] = 1272,
  [1359] = 1273,
  [1360] = 1274,
  [1361] = 1275,
  [1362] = 1276,
  [1363] = 1277,
  [1364] = 1278,
  [1365] = 1344,
  [1366] = 1279,
  [1367] = 1262,
  [1368] = 1368,
  [1369] = 1354,
  [1370] = 1280,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 1307,
  [1374] = 1374,
  [1375] = 1255,
  [1376] = 1255,
  [1377] = 1262,
  [1378] = 1378,
  [1379] = 1269,
  [1380] = 1270,
  [1381] = 1271,
  [1382] = 1272,
  [1383] = 1273,
  [1384] = 1274,
  [1385] = 1275,
  [1386] = 1276,
  [1387] = 1277,
  [1388] = 1278,
  [1389] = 1253,
  [1390] = 1258,
  [1391] = 1263,
  [1392] = 1279,
  [1393] = 1280,
  [1394] = 1255,
  [1395] = 1344,
  [1396] = 1315,
  [1397] = 1305,
  [1398] = 1253,
  [1399] = 1258,
  [1400] = 1281,
  [1401] = 1262,
  [1402] = 1263,
  [1403] = 1255,
  [1404] = 1404,
  [1405] = 1269,
  [1406] = 1270,
  [1407] = 1271,
  [1408] = 1272,
  [1409] = 1273,
  [1410] = 1274,
  [1411] = 1275,
  [1412] = 1276,
  [1413] = 1277,
  [1414] = 1278,
  [1415] = 1415,
  [1416] = 1279,
  [1417] = 1417,
  [1418] = 1418,
  [1419] = 1280,
  [1420] = 1255,
  [1421] = 1262,
  [1422] = 1269,
  [1423] = 1270,
  [1424] = 1271,
  [1425] = 1272,
  [1426] = 1273,
  [1427] = 1274,
  [1428] = 1275,
  [1429] = 1276,
  [1430] = 1277,
  [1431] = 1278,
  [1432] = 1253,
  [1433] = 1314,
  [1434] = 1344,
  [1435] = 1305,
  [1436] = 1281,
  [1437] = 1253,
  [1438] = 1258,
  [1439] = 1262,
  [1440] = 1269,
  [1441] = 1270,
  [1442] = 1271,
  [1443] = 1272,
  [1444] = 1273,
  [1445] = 1274,
  [1446] = 1275,
  [1447] = 1276,
  [1448] = 1277,
  [1449] = 1278,
  [1450] = 1344,
  [1451] = 1451,
  [1452] = 1305,
  [1453] = 1262,
  [1454] = 1281,
  [1455] = 1263,
  [1456] = 1262,
  [1457] = 1269,
  [1458] = 1270,
  [1459] = 1271,
  [1460] = 1272,
  [1461] = 1273,
  [1462] = 1274,
  [1463] = 1275,
  [1464] = 1276,
  [1465] = 1277,
  [1466] = 1278,
  [1467] = 1344,
  [1468] = 1305,
  [1469] = 1262,
  [1470] = 1269,
  [1471] = 1270,
  [1472] = 1271,
  [1473] = 1272,
  [1474] = 1273,
  [1475] = 1274,
  [1476] = 1275,
  [1477] = 1276,
  [1478] = 1277,
  [1479] = 1278,
  [1480] = 1344,
  [1481] = 1305,
  [1482] = 1269,
  [1483] = 1270,
  [1484] = 1271,
  [1485] = 1272,
  [1486] = 1273,
  [1487] = 1274,
  [1488] = 1275,
  [1489] = 1276,
  [1490] = 1277,
  [1491] = 1278,
  [1492] = 1279,
  [1493] = 1262,
  [1494] = 1269,
  [1495] = 1270,
  [1496] = 1271,
  [1497] = 1272,
  [1498] = 1273,
  [1499] = 1274,
  [1500] = 1275,
  [1501] = 1276,
  [1502] = 1277,
  [1503] = 1278,
  [1504] = 1344,
  [1505] = 1305,
  [1506] = 1344,
  [1507] = 1305,
  [1508] = 1508,
  [1509] = 1344,
  [1510] = 1305,
  [1511] = 1344,
  [1512] = 1305,
  [1513] = 1344,
  [1514] = 1269,
  [1515] = 1305,
  [1516] = 1270,
  [1517] = 1271,
  [1518] = 1272,
  [1519] = 1273,
  [1520] = 1274,
  [1521] = 1275,
  [1522] = 1276,
  [1523] = 1277,
  [1524] = 1278,
  [1525] = 1417,
  [1526] = 1526,
  [1527] = 1418,
  [1528] = 1528,
  [1529] = 1262,
  [1530] = 1263,
  [1531] = 1378,
  [1532] = 1269,
  [1533] = 1270,
  [1534] = 1271,
  [1535] = 1272,
  [1536] = 1273,
  [1537] = 1274,
  [1538] = 1275,
  [1539] = 1276,
  [1540] = 1277,
  [1541] = 1278,
  [1542] = 1279,
  [1543] = 1543,
  [1544] = 1544,
  [1545] = 1545,
  [1546] = 1280,
  [1547] = 1285,
  [1548] = 1280,
  [1549] = 1372,
  [1550] = 1255,
  [1551] = 1256,
  [1552] = 1526,
  [1553] = 1528,
  [1554] = 1279,
  [1555] = 1555,
  [1556] = 1543,
  [1557] = 1544,
  [1558] = 1545,
  [1559] = 1285,
  [1560] = 1263,
  [1561] = 1543,
  [1562] = 1256,
  [1563] = 1526,
  [1564] = 1528,
  [1565] = 1543,
  [1566] = 1544,
  [1567] = 1545,
  [1568] = 1285,
  [1569] = 1256,
  [1570] = 1526,
  [1571] = 1528,
  [1572] = 1543,
  [1573] = 1544,
  [1574] = 1545,
  [1575] = 1285,
  [1576] = 1256,
  [1577] = 1526,
  [1578] = 1543,
  [1579] = 1544,
  [1580] = 1545,
  [1581] = 1285,
  [1582] = 1528,
  [1583] = 1256,
  [1584] = 1543,
  [1585] = 1544,
  [1586] = 1545,
  [1587] = 1285,
  [1588] = 1544,
  [1589] = 1256,
  [1590] = 1545,
  [1591] = 1256,
  [1592] = 1344,
  [1593] = 1305,
  [1594] = 1253,
  [1595] = 1258,
  [1596] = 1374,
  [1597] = 1344,
  [1598] = 1305,
  [1599] = 1263,
  [1600] = 1269,
  [1601] = 1270,
  [1602] = 1271,
  [1603] = 1272,
  [1604] = 1273,
  [1605] = 1274,
  [1606] = 1275,
  [1607] = 1276,
  [1608] = 1277,
  [1609] = 1278,
  [1610] = 1279,
  [1611] = 1545,
  [1612] = 1280,
  [1613] = 1255,
  [1614] = 1344,
  [1615] = 1305,
  [1616] = 1253,
  [1617] = 1258,
  [1618] = 1374,
  [1619] = 1374,
  [1620] = 1374,
  [1621] = 1374,
  [1622] = 1374,
  [1623] = 1623,
  [1624] = 1281,
  [1625] = 1262,
  [1626] = 1269,
  [1627] = 1270,
  [1628] = 1271,
  [1629] = 1272,
  [1630] = 1273,
  [1631] = 1274,
  [1632] = 1275,
  [1633] = 1276,
  [1634] = 1277,
  [1635] = 1278,
  [1636] = 1253,
  [1637] = 1258,
  [1638] = 1263,
  [1639] = 1279,
  [1640] = 1280,
  [1641] = 1255,
  [1642] = 1262,
  [1643] = 1314,
  [1644] = 1314,
  [1645] = 1314,
  [1646] = 1314,
  [1647] = 1314,
  [1648] = 1258,
  [1649] = 1649,
  [1650] = 913,
  [1651] = 1651,
  [1652] = 913,
  [1653] = 967,
  [1654] = 1654,
  [1655] = 913,
  [1656] = 1656,
  [1657] = 1657,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1658,
  [1661] = 1661,
  [1662] = 1662,
  [1663] = 1658,
  [1664] = 1658,
  [1665] = 1661,
  [1666] = 1662,
  [1667] = 1667,
  [1668] = 1668,
  [1669] = 1667,
  [1670] = 1667,
  [1671] = 1668,
  [1672] = 1667,
  [1673] = 1668,
  [1674] = 945,
  [1675] = 947,
  [1676] = 1667,
  [1677] = 923,
  [1678] = 1668,
  [1679] = 1667,
  [1680] = 1668,
  [1681] = 949,
  [1682] = 929,
  [1683] = 931,
  [1684] = 1668,
  [1685] = 934,
  [1686] = 1668,
  [1687] = 1667,
  [1688] = 1688,
  [1689] = 1689,
  [1690] = 1690,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1697,
  [1698] = 1651,
  [1699] = 1699,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1703,
  [1704] = 1704,
  [1705] = 1704,
  [1706] = 1706,
  [1707] = 967,
  [1708] = 1662,
  [1709] = 1661,
  [1710] = 1706,
  [1711] = 1661,
  [1712] = 1661,
  [1713] = 967,
  [1714] = 1662,
  [1715] = 1651,
  [1716] = 1657,
  [1717] = 1717,
  [1718] = 1662,
  [1719] = 1656,
  [1720] = 1651,
  [1721] = 1651,
  [1722] = 1722,
  [1723] = 1662,
  [1724] = 1722,
  [1725] = 1661,
  [1726] = 147,
  [1727] = 1722,
  [1728] = 1722,
  [1729] = 1706,
  [1730] = 146,
  [1731] = 140,
  [1732] = 1722,
  [1733] = 141,
  [1734] = 1654,
  [1735] = 1735,
  [1736] = 1706,
  [1737] = 1656,
  [1738] = 1651,
  [1739] = 1651,
  [1740] = 1740,
  [1741] = 1654,
  [1742] = 1657,
  [1743] = 1706,
  [1744] = 1654,
  [1745] = 1745,
  [1746] = 1745,
  [1747] = 1745,
  [1748] = 1748,
  [1749] = 1749,
  [1750] = 139,
  [1751] = 1745,
  [1752] = 1657,
  [1753] = 1749,
  [1754] = 1656,
  [1755] = 138,
  [1756] = 1749,
  [1757] = 1745,
  [1758] = 1745,
  [1759] = 149,
  [1760] = 1745,
  [1761] = 1657,
  [1762] = 193,
  [1763] = 1656,
  [1764] = 1749,
  [1765] = 193,
  [1766] = 251,
  [1767] = 254,
  [1768] = 322,
  [1769] = 277,
  [1770] = 1770,
  [1771] = 1771,
  [1772] = 1772,
  [1773] = 1773,
  [1774] = 1774,
  [1775] = 1775,
  [1776] = 1776,
  [1777] = 283,
  [1778] = 285,
  [1779] = 1779,
  [1780] = 1780,
  [1781] = 1781,
  [1782] = 1782,
  [1783] = 1783,
  [1784] = 1784,
  [1785] = 1785,
  [1786] = 1786,
  [1787] = 1787,
  [1788] = 1788,
  [1789] = 1789,
  [1790] = 1790,
  [1791] = 1791,
  [1792] = 1792,
  [1793] = 1793,
  [1794] = 1794,
  [1795] = 1795,
  [1796] = 1796,
  [1797] = 1797,
  [1798] = 286,
  [1799] = 287,
  [1800] = 284,
  [1801] = 291,
  [1802] = 292,
  [1803] = 293,
  [1804] = 294,
  [1805] = 295,
  [1806] = 1806,
  [1807] = 298,
  [1808] = 300,
  [1809] = 923,
  [1810] = 296,
  [1811] = 276,
  [1812] = 233,
  [1813] = 234,
  [1814] = 239,
  [1815] = 241,
  [1816] = 242,
  [1817] = 243,
  [1818] = 244,
  [1819] = 1819,
  [1820] = 255,
  [1821] = 945,
  [1822] = 947,
  [1823] = 949,
  [1824] = 304,
  [1825] = 224,
  [1826] = 309,
  [1827] = 311,
  [1828] = 321,
  [1829] = 306,
  [1830] = 238,
  [1831] = 225,
  [1832] = 235,
  [1833] = 267,
  [1834] = 268,
  [1835] = 929,
  [1836] = 931,
  [1837] = 934,
  [1838] = 317,
  [1839] = 319,
  [1840] = 226,
  [1841] = 227,
  [1842] = 236,
  [1843] = 263,
  [1844] = 1706,
  [1845] = 1654,
  [1846] = 1654,
  [1847] = 214,
  [1848] = 216,
  [1849] = 218,
  [1850] = 220,
  [1851] = 215,
  [1852] = 1852,
  [1853] = 1853,
  [1854] = 1854,
  [1855] = 1855,
  [1856] = 203,
  [1857] = 1857,
  [1858] = 1858,
  [1859] = 186,
  [1860] = 1860,
  [1861] = 1861,
  [1862] = 222,
  [1863] = 189,
  [1864] = 314,
  [1865] = 185,
  [1866] = 271,
  [1867] = 1657,
  [1868] = 141,
  [1869] = 146,
  [1870] = 1870,
  [1871] = 947,
  [1872] = 949,
  [1873] = 1656,
  [1874] = 147,
  [1875] = 929,
  [1876] = 147,
  [1877] = 1657,
  [1878] = 934,
  [1879] = 146,
  [1880] = 140,
  [1881] = 923,
  [1882] = 141,
  [1883] = 140,
  [1884] = 945,
  [1885] = 931,
  [1886] = 1656,
  [1887] = 1887,
  [1888] = 1888,
  [1889] = 1888,
  [1890] = 1888,
  [1891] = 1888,
  [1892] = 1888,
  [1893] = 1888,
  [1894] = 1888,
  [1895] = 1895,
  [1896] = 138,
  [1897] = 193,
  [1898] = 193,
  [1899] = 193,
  [1900] = 955,
  [1901] = 149,
  [1902] = 1654,
  [1903] = 1903,
  [1904] = 149,
  [1905] = 967,
  [1906] = 1903,
  [1907] = 1903,
  [1908] = 138,
  [1909] = 1903,
  [1910] = 139,
  [1911] = 193,
  [1912] = 139,
  [1913] = 296,
  [1914] = 314,
  [1915] = 322,
  [1916] = 238,
  [1917] = 225,
  [1918] = 235,
  [1919] = 1774,
  [1920] = 267,
  [1921] = 251,
  [1922] = 271,
  [1923] = 1789,
  [1924] = 1790,
  [1925] = 222,
  [1926] = 189,
  [1927] = 1806,
  [1928] = 1770,
  [1929] = 1771,
  [1930] = 1772,
  [1931] = 277,
  [1932] = 1819,
  [1933] = 319,
  [1934] = 226,
  [1935] = 227,
  [1936] = 1791,
  [1937] = 1773,
  [1938] = 1794,
  [1939] = 1795,
  [1940] = 1774,
  [1941] = 1775,
  [1942] = 1796,
  [1943] = 185,
  [1944] = 1944,
  [1945] = 1776,
  [1946] = 1797,
  [1947] = 1792,
  [1948] = 186,
  [1949] = 1949,
  [1950] = 1950,
  [1951] = 314,
  [1952] = 317,
  [1953] = 1775,
  [1954] = 214,
  [1955] = 254,
  [1956] = 216,
  [1957] = 1852,
  [1958] = 284,
  [1959] = 236,
  [1960] = 185,
  [1961] = 1779,
  [1962] = 254,
  [1963] = 263,
  [1964] = 1780,
  [1965] = 1781,
  [1966] = 1966,
  [1967] = 218,
  [1968] = 220,
  [1969] = 215,
  [1970] = 1793,
  [1971] = 293,
  [1972] = 1782,
  [1973] = 1795,
  [1974] = 1783,
  [1975] = 203,
  [1976] = 1784,
  [1977] = 1776,
  [1978] = 283,
  [1979] = 1853,
  [1980] = 1854,
  [1981] = 1785,
  [1982] = 1852,
  [1983] = 284,
  [1984] = 1855,
  [1985] = 1857,
  [1986] = 1858,
  [1987] = 1860,
  [1988] = 1861,
  [1989] = 285,
  [1990] = 1796,
  [1991] = 1786,
  [1992] = 1992,
  [1993] = 291,
  [1994] = 292,
  [1995] = 293,
  [1996] = 1797,
  [1997] = 294,
  [1998] = 295,
  [1999] = 923,
  [2000] = 1779,
  [2001] = 298,
  [2002] = 300,
  [2003] = 1853,
  [2004] = 805,
  [2005] = 1854,
  [2006] = 296,
  [2007] = 276,
  [2008] = 233,
  [2009] = 234,
  [2010] = 239,
  [2011] = 241,
  [2012] = 242,
  [2013] = 243,
  [2014] = 244,
  [2015] = 251,
  [2016] = 255,
  [2017] = 322,
  [2018] = 2018,
  [2019] = 1787,
  [2020] = 277,
  [2021] = 1855,
  [2022] = 291,
  [2023] = 292,
  [2024] = 304,
  [2025] = 224,
  [2026] = 309,
  [2027] = 311,
  [2028] = 1788,
  [2029] = 1794,
  [2030] = 233,
  [2031] = 321,
  [2032] = 306,
  [2033] = 238,
  [2034] = 225,
  [2035] = 235,
  [2036] = 234,
  [2037] = 806,
  [2038] = 1857,
  [2039] = 267,
  [2040] = 1789,
  [2041] = 268,
  [2042] = 271,
  [2043] = 283,
  [2044] = 285,
  [2045] = 1858,
  [2046] = 1860,
  [2047] = 1861,
  [2048] = 2048,
  [2049] = 317,
  [2050] = 319,
  [2051] = 226,
  [2052] = 227,
  [2053] = 255,
  [2054] = 236,
  [2055] = 1780,
  [2056] = 286,
  [2057] = 287,
  [2058] = 263,
  [2059] = 1773,
  [2060] = 1781,
  [2061] = 287,
  [2062] = 1806,
  [2063] = 1819,
  [2064] = 929,
  [2065] = 931,
  [2066] = 934,
  [2067] = 955,
  [2068] = 294,
  [2069] = 295,
  [2070] = 298,
  [2071] = 300,
  [2072] = 2072,
  [2073] = 214,
  [2074] = 216,
  [2075] = 1782,
  [2076] = 1783,
  [2077] = 1784,
  [2078] = 1785,
  [2079] = 1770,
  [2080] = 2080,
  [2081] = 218,
  [2082] = 220,
  [2083] = 304,
  [2084] = 945,
  [2085] = 947,
  [2086] = 215,
  [2087] = 949,
  [2088] = 1790,
  [2089] = 1786,
  [2090] = 1791,
  [2091] = 309,
  [2092] = 311,
  [2093] = 321,
  [2094] = 203,
  [2095] = 276,
  [2096] = 306,
  [2097] = 1792,
  [2098] = 224,
  [2099] = 239,
  [2100] = 186,
  [2101] = 1788,
  [2102] = 1771,
  [2103] = 1793,
  [2104] = 1772,
  [2105] = 1787,
  [2106] = 286,
  [2107] = 241,
  [2108] = 242,
  [2109] = 243,
  [2110] = 222,
  [2111] = 189,
  [2112] = 244,
  [2113] = 268,
  [2114] = 2114,
  [2115] = 2115,
  [2116] = 2116,
  [2117] = 1662,
  [2118] = 2118,
  [2119] = 2119,
  [2120] = 2120,
  [2121] = 2121,
  [2122] = 2122,
  [2123] = 2123,
  [2124] = 2124,
  [2125] = 2125,
  [2126] = 1949,
  [2127] = 2127,
  [2128] = 2128,
  [2129] = 2129,
  [2130] = 2130,
  [2131] = 2131,
  [2132] = 2132,
  [2133] = 2133,
  [2134] = 2134,
  [2135] = 2135,
  [2136] = 2136,
  [2137] = 2137,
  [2138] = 2138,
  [2139] = 2139,
  [2140] = 1662,
  [2141] = 2141,
  [2142] = 2142,
  [2143] = 2143,
  [2144] = 1950,
  [2145] = 2145,
  [2146] = 2146,
  [2147] = 967,
  [2148] = 2148,
  [2149] = 2149,
  [2150] = 1966,
  [2151] = 2151,
  [2152] = 2152,
  [2153] = 2153,
  [2154] = 2154,
  [2155] = 1659,
  [2156] = 2156,
  [2157] = 955,
  [2158] = 1661,
  [2159] = 2114,
  [2160] = 2160,
  [2161] = 2080,
  [2162] = 1661,
  [2163] = 2163,
  [2164] = 1949,
  [2165] = 947,
  [2166] = 2166,
  [2167] = 949,
  [2168] = 2168,
  [2169] = 2169,
  [2170] = 945,
  [2171] = 1656,
  [2172] = 1950,
  [2173] = 1870,
  [2174] = 929,
  [2175] = 955,
  [2176] = 931,
  [2177] = 967,
  [2178] = 1966,
  [2179] = 138,
  [2180] = 1657,
  [2181] = 2080,
  [2182] = 139,
  [2183] = 923,
  [2184] = 2184,
  [2185] = 934,
  [2186] = 2114,
  [2187] = 2187,
  [2188] = 1651,
  [2189] = 2189,
  [2190] = 1661,
  [2191] = 2191,
  [2192] = 2192,
  [2193] = 1662,
  [2194] = 2194,
  [2195] = 2195,
  [2196] = 967,
  [2197] = 2197,
  [2198] = 2198,
  [2199] = 2199,
  [2200] = 2200,
  [2201] = 2201,
  [2202] = 2202,
  [2203] = 2203,
  [2204] = 2204,
  [2205] = 2205,
  [2206] = 2206,
  [2207] = 2207,
  [2208] = 2208,
  [2209] = 2209,
  [2210] = 2210,
  [2211] = 2211,
  [2212] = 2072,
  [2213] = 1706,
  [2214] = 1706,
  [2215] = 1944,
  [2216] = 2216,
  [2217] = 2217,
  [2218] = 2048,
  [2219] = 2219,
  [2220] = 2220,
  [2221] = 2221,
  [2222] = 1662,
  [2223] = 2134,
  [2224] = 2224,
  [2225] = 2135,
  [2226] = 2209,
  [2227] = 2136,
  [2228] = 2163,
  [2229] = 2152,
  [2230] = 2116,
  [2231] = 2142,
  [2232] = 2149,
  [2233] = 2209,
  [2234] = 2192,
  [2235] = 2154,
  [2236] = 1661,
  [2237] = 1654,
  [2238] = 2238,
  [2239] = 2138,
  [2240] = 2115,
  [2241] = 2125,
  [2242] = 2129,
  [2243] = 2123,
  [2244] = 1662,
  [2245] = 2130,
  [2246] = 2145,
  [2247] = 2143,
  [2248] = 2120,
  [2249] = 2118,
  [2250] = 2122,
  [2251] = 2124,
  [2252] = 2128,
  [2253] = 2148,
  [2254] = 2151,
  [2255] = 2160,
  [2256] = 2256,
  [2257] = 2121,
  [2258] = 2132,
  [2259] = 2133,
  [2260] = 2192,
  [2261] = 2261,
  [2262] = 2119,
  [2263] = 2141,
  [2264] = 2127,
  [2265] = 2153,
  [2266] = 2156,
  [2267] = 2217,
  [2268] = 2131,
  [2269] = 2137,
  [2270] = 2146,
  [2271] = 1661,
  [2272] = 2139,
  [2273] = 2273,
  [2274] = 2274,
  [2275] = 2275,
  [2276] = 1706,
  [2277] = 1651,
  [2278] = 2278,
  [2279] = 1656,
  [2280] = 1657,
  [2281] = 2281,
  [2282] = 2282,
  [2283] = 2283,
  [2284] = 2217,
  [2285] = 2205,
  [2286] = 2217,
  [2287] = 2201,
  [2288] = 2203,
  [2289] = 2289,
  [2290] = 2202,
  [2291] = 2291,
  [2292] = 2191,
  [2293] = 929,
  [2294] = 2202,
  [2295] = 2191,
  [2296] = 2296,
  [2297] = 2200,
  [2298] = 2206,
  [2299] = 2197,
  [2300] = 2203,
  [2301] = 2301,
  [2302] = 2302,
  [2303] = 2303,
  [2304] = 2199,
  [2305] = 923,
  [2306] = 2306,
  [2307] = 2307,
  [2308] = 2205,
  [2309] = 2189,
  [2310] = 2310,
  [2311] = 2311,
  [2312] = 2312,
  [2313] = 2166,
  [2314] = 2210,
  [2315] = 2195,
  [2316] = 2316,
  [2317] = 2207,
  [2318] = 2210,
  [2319] = 2189,
  [2320] = 931,
  [2321] = 2200,
  [2322] = 934,
  [2323] = 2201,
  [2324] = 2206,
  [2325] = 2197,
  [2326] = 2195,
  [2327] = 1654,
  [2328] = 945,
  [2329] = 947,
  [2330] = 949,
  [2331] = 2199,
  [2332] = 2332,
  [2333] = 1662,
  [2334] = 1706,
  [2335] = 2335,
  [2336] = 2335,
  [2337] = 1654,
  [2338] = 1706,
  [2339] = 2339,
  [2340] = 2335,
  [2341] = 2335,
  [2342] = 2335,
  [2343] = 2343,
  [2344] = 2018,
  [2345] = 2332,
  [2346] = 2209,
  [2347] = 2207,
  [2348] = 2192,
  [2349] = 2332,
  [2350] = 2332,
  [2351] = 2351,
  [2352] = 1992,
  [2353] = 2335,
  [2354] = 1661,
  [2355] = 1870,
  [2356] = 2335,
  [2357] = 2357,
  [2358] = 2358,
  [2359] = 2080,
  [2360] = 1659,
  [2361] = 1657,
  [2362] = 1657,
  [2363] = 1659,
  [2364] = 1966,
  [2365] = 1949,
  [2366] = 1950,
  [2367] = 2367,
  [2368] = 1656,
  [2369] = 2281,
  [2370] = 2278,
  [2371] = 2371,
  [2372] = 2204,
  [2373] = 2166,
  [2374] = 2169,
  [2375] = 2375,
  [2376] = 2376,
  [2377] = 2371,
  [2378] = 1949,
  [2379] = 2379,
  [2380] = 2375,
  [2381] = 2375,
  [2382] = 2376,
  [2383] = 2375,
  [2384] = 2376,
  [2385] = 2080,
  [2386] = 2376,
  [2387] = 2166,
  [2388] = 2278,
  [2389] = 2224,
  [2390] = 2166,
  [2391] = 2379,
  [2392] = 2379,
  [2393] = 2224,
  [2394] = 1950,
  [2395] = 2375,
  [2396] = 923,
  [2397] = 1966,
  [2398] = 2358,
  [2399] = 2375,
  [2400] = 2376,
  [2401] = 2375,
  [2402] = 2208,
  [2403] = 945,
  [2404] = 947,
  [2405] = 949,
  [2406] = 1659,
  [2407] = 2281,
  [2408] = 2281,
  [2409] = 2114,
  [2410] = 2187,
  [2411] = 929,
  [2412] = 931,
  [2413] = 934,
  [2414] = 2376,
  [2415] = 2376,
  [2416] = 2278,
  [2417] = 2417,
  [2418] = 2311,
  [2419] = 2114,
  [2420] = 2420,
  [2421] = 2421,
  [2422] = 2048,
  [2423] = 2423,
  [2424] = 1944,
  [2425] = 2301,
  [2426] = 2426,
  [2427] = 2072,
  [2428] = 2291,
  [2429] = 2316,
  [2430] = 2306,
  [2431] = 2420,
  [2432] = 2420,
  [2433] = 2204,
  [2434] = 2307,
  [2435] = 2166,
  [2436] = 1944,
  [2437] = 2301,
  [2438] = 2166,
  [2439] = 2307,
  [2440] = 2420,
  [2441] = 2289,
  [2442] = 2296,
  [2443] = 2443,
  [2444] = 2289,
  [2445] = 2296,
  [2446] = 2072,
  [2447] = 2302,
  [2448] = 2303,
  [2449] = 2449,
  [2450] = 2316,
  [2451] = 2310,
  [2452] = 2420,
  [2453] = 2224,
  [2454] = 2306,
  [2455] = 2312,
  [2456] = 2311,
  [2457] = 2048,
  [2458] = 2458,
  [2459] = 2459,
  [2460] = 2208,
  [2461] = 2420,
  [2462] = 2462,
  [2463] = 2310,
  [2464] = 2187,
  [2465] = 2312,
  [2466] = 2466,
  [2467] = 2467,
  [2468] = 2468,
  [2469] = 2469,
  [2470] = 1706,
  [2471] = 2114,
  [2472] = 2462,
  [2473] = 2302,
  [2474] = 2303,
  [2475] = 2291,
  [2476] = 2163,
  [2477] = 2119,
  [2478] = 2141,
  [2479] = 2145,
  [2480] = 2205,
  [2481] = 2199,
  [2482] = 2135,
  [2483] = 2136,
  [2484] = 2163,
  [2485] = 2210,
  [2486] = 2195,
  [2487] = 2152,
  [2488] = 2116,
  [2489] = 2142,
  [2490] = 2149,
  [2491] = 2137,
  [2492] = 2154,
  [2493] = 2115,
  [2494] = 2125,
  [2495] = 2138,
  [2496] = 2134,
  [2497] = 2208,
  [2498] = 2146,
  [2499] = 2115,
  [2500] = 2123,
  [2501] = 2129,
  [2502] = 2166,
  [2503] = 2130,
  [2504] = 2125,
  [2505] = 2273,
  [2506] = 2127,
  [2507] = 2139,
  [2508] = 2143,
  [2509] = 2509,
  [2510] = 2289,
  [2511] = 2296,
  [2512] = 2129,
  [2513] = 2130,
  [2514] = 2139,
  [2515] = 2148,
  [2516] = 2151,
  [2517] = 2310,
  [2518] = 2143,
  [2519] = 2148,
  [2520] = 1870,
  [2521] = 2119,
  [2522] = 2169,
  [2523] = 2141,
  [2524] = 2145,
  [2525] = 955,
  [2526] = 2151,
  [2527] = 2160,
  [2528] = 2156,
  [2529] = 2153,
  [2530] = 2156,
  [2531] = 2137,
  [2532] = 2275,
  [2533] = 2187,
  [2534] = 2135,
  [2535] = 2136,
  [2536] = 2204,
  [2537] = 1654,
  [2538] = 2146,
  [2539] = 2152,
  [2540] = 2118,
  [2541] = 2122,
  [2542] = 2124,
  [2543] = 2018,
  [2544] = 2128,
  [2545] = 2116,
  [2546] = 2121,
  [2547] = 2547,
  [2548] = 2548,
  [2549] = 2142,
  [2550] = 2312,
  [2551] = 2138,
  [2552] = 2169,
  [2553] = 2291,
  [2554] = 2132,
  [2555] = 2316,
  [2556] = 2133,
  [2557] = 2283,
  [2558] = 2301,
  [2559] = 2154,
  [2560] = 2560,
  [2561] = 2462,
  [2562] = 2274,
  [2563] = 2307,
  [2564] = 2134,
  [2565] = 2118,
  [2566] = 2122,
  [2567] = 1992,
  [2568] = 2189,
  [2569] = 2302,
  [2570] = 2124,
  [2571] = 2201,
  [2572] = 2160,
  [2573] = 2131,
  [2574] = 2120,
  [2575] = 1870,
  [2576] = 2166,
  [2577] = 2128,
  [2578] = 2166,
  [2579] = 2579,
  [2580] = 2121,
  [2581] = 2306,
  [2582] = 2204,
  [2583] = 2583,
  [2584] = 2132,
  [2585] = 2202,
  [2586] = 2191,
  [2587] = 2587,
  [2588] = 2303,
  [2589] = 2589,
  [2590] = 2590,
  [2591] = 2591,
  [2592] = 2133,
  [2593] = 2593,
  [2594] = 2166,
  [2595] = 2595,
  [2596] = 2131,
  [2597] = 2597,
  [2598] = 2208,
  [2599] = 2599,
  [2600] = 2600,
  [2601] = 2601,
  [2602] = 2602,
  [2603] = 2120,
  [2604] = 2311,
  [2605] = 2166,
  [2606] = 2358,
  [2607] = 2166,
  [2608] = 2200,
  [2609] = 2187,
  [2610] = 2123,
  [2611] = 2127,
  [2612] = 2206,
  [2613] = 2153,
  [2614] = 2614,
  [2615] = 2615,
  [2616] = 2197,
  [2617] = 2203,
  [2618] = 2149,
  [2619] = 2207,
  [2620] = 2199,
  [2621] = 2621,
  [2622] = 2622,
  [2623] = 2210,
  [2624] = 2624,
  [2625] = 2169,
  [2626] = 2626,
  [2627] = 2627,
  [2628] = 2628,
  [2629] = 2282,
  [2630] = 1656,
  [2631] = 2624,
  [2632] = 2632,
  [2633] = 2203,
  [2634] = 2634,
  [2635] = 2626,
  [2636] = 2358,
  [2637] = 2205,
  [2638] = 2205,
  [2639] = 2626,
  [2640] = 2207,
  [2641] = 2201,
  [2642] = 2195,
  [2643] = 2626,
  [2644] = 2626,
  [2645] = 2189,
  [2646] = 2197,
  [2647] = 2210,
  [2648] = 2648,
  [2649] = 2649,
  [2650] = 2195,
  [2651] = 2469,
  [2652] = 2217,
  [2653] = 2653,
  [2654] = 2201,
  [2655] = 2200,
  [2656] = 2622,
  [2657] = 2468,
  [2658] = 2626,
  [2659] = 2202,
  [2660] = 2273,
  [2661] = 2206,
  [2662] = 2662,
  [2663] = 2663,
  [2664] = 2275,
  [2665] = 2665,
  [2666] = 2624,
  [2667] = 2283,
  [2668] = 2206,
  [2669] = 2274,
  [2670] = 2203,
  [2671] = 2468,
  [2672] = 967,
  [2673] = 2634,
  [2674] = 2191,
  [2675] = 2675,
  [2676] = 2676,
  [2677] = 2677,
  [2678] = 2469,
  [2679] = 2199,
  [2680] = 2462,
  [2681] = 2681,
  [2682] = 2202,
  [2683] = 2683,
  [2684] = 2197,
  [2685] = 2634,
  [2686] = 2621,
  [2687] = 2191,
  [2688] = 2688,
  [2689] = 2200,
  [2690] = 2624,
  [2691] = 2189,
  [2692] = 2626,
  [2693] = 2693,
  [2694] = 2694,
  [2695] = 806,
  [2696] = 2187,
  [2697] = 2697,
  [2698] = 2698,
  [2699] = 2358,
  [2700] = 2443,
  [2701] = 2701,
  [2702] = 2283,
  [2703] = 2273,
  [2704] = 2704,
  [2705] = 2649,
  [2706] = 2207,
  [2707] = 2275,
  [2708] = 2708,
  [2709] = 2274,
  [2710] = 2710,
  [2711] = 2217,
  [2712] = 2204,
  [2713] = 2018,
  [2714] = 2274,
  [2715] = 2715,
  [2716] = 2716,
  [2717] = 2717,
  [2718] = 1992,
  [2719] = 2224,
  [2720] = 2648,
  [2721] = 2663,
  [2722] = 2722,
  [2723] = 2723,
  [2724] = 2724,
  [2725] = 2358,
  [2726] = 806,
  [2727] = 2208,
  [2728] = 2728,
  [2729] = 805,
  [2730] = 2261,
  [2731] = 2367,
  [2732] = 2273,
  [2733] = 2275,
  [2734] = 805,
  [2735] = 2735,
  [2736] = 2283,
  [2737] = 2737,
  [2738] = 2738,
  [2739] = 2739,
  [2740] = 2224,
  [2741] = 2741,
  [2742] = 2742,
  [2743] = 2743,
  [2744] = 2217,
  [2745] = 2745,
  [2746] = 2224,
  [2747] = 2018,
  [2748] = 2748,
  [2749] = 2283,
  [2750] = 2750,
  [2751] = 2751,
  [2752] = 1700,
  [2753] = 2184,
  [2754] = 2754,
  [2755] = 2622,
  [2756] = 2756,
  [2757] = 2757,
  [2758] = 2758,
  [2759] = 2759,
  [2760] = 1694,
  [2761] = 2761,
  [2762] = 2762,
  [2763] = 2763,
  [2764] = 2764,
  [2765] = 2765,
  [2766] = 2766,
  [2767] = 2767,
  [2768] = 1701,
  [2769] = 1689,
  [2770] = 1691,
  [2771] = 139,
  [2772] = 2772,
  [2773] = 2773,
  [2774] = 2274,
  [2775] = 2775,
  [2776] = 2776,
  [2777] = 2777,
  [2778] = 2778,
  [2779] = 2779,
  [2780] = 1692,
  [2781] = 1693,
  [2782] = 2275,
  [2783] = 2783,
  [2784] = 2784,
  [2785] = 2785,
  [2786] = 2786,
  [2787] = 2787,
  [2788] = 1695,
  [2789] = 1688,
  [2790] = 1992,
  [2791] = 1699,
  [2792] = 2792,
  [2793] = 2793,
  [2794] = 2794,
  [2795] = 2795,
  [2796] = 2796,
  [2797] = 2797,
  [2798] = 2798,
  [2799] = 2799,
  [2800] = 2800,
  [2801] = 138,
  [2802] = 2802,
  [2803] = 2217,
  [2804] = 2804,
  [2805] = 2805,
  [2806] = 1696,
  [2807] = 2807,
  [2808] = 2621,
  [2809] = 2809,
  [2810] = 1690,
  [2811] = 2811,
  [2812] = 2812,
  [2813] = 2273,
  [2814] = 2621,
  [2815] = 2275,
  [2816] = 2622,
  [2817] = 2817,
  [2818] = 2273,
  [2819] = 2819,
  [2820] = 2820,
  [2821] = 2275,
  [2822] = 2283,
  [2823] = 2274,
  [2824] = 2283,
  [2825] = 2273,
  [2826] = 2274,
  [2827] = 2827,
  [2828] = 2828,
  [2829] = 2829,
  [2830] = 2830,
  [2831] = 2831,
  [2832] = 1703,
  [2833] = 2833,
  [2834] = 1702,
  [2835] = 2168,
  [2836] = 1697,
  [2837] = 2837,
  [2838] = 2206,
  [2839] = 2275,
  [2840] = 2200,
  [2841] = 2469,
  [2842] = 2274,
  [2843] = 2283,
  [2844] = 2018,
  [2845] = 2358,
  [2846] = 2197,
  [2847] = 2462,
  [2848] = 2462,
  [2849] = 1992,
  [2850] = 2274,
  [2851] = 2189,
  [2852] = 2852,
  [2853] = 2203,
  [2854] = 2273,
  [2855] = 2205,
  [2856] = 2281,
  [2857] = 2278,
  [2858] = 2273,
  [2859] = 2283,
  [2860] = 2201,
  [2861] = 2199,
  [2862] = 2275,
  [2863] = 2283,
  [2864] = 2195,
  [2865] = 2852,
  [2866] = 967,
  [2867] = 2202,
  [2868] = 2191,
  [2869] = 955,
  [2870] = 2468,
  [2871] = 2210,
  [2872] = 2274,
  [2873] = 2852,
  [2874] = 1949,
  [2875] = 2875,
  [2876] = 2875,
  [2877] = 2877,
  [2878] = 2621,
  [2879] = 2189,
  [2880] = 2462,
  [2881] = 2189,
  [2882] = 1992,
  [2883] = 2275,
  [2884] = 2877,
  [2885] = 2187,
  [2886] = 2210,
  [2887] = 2887,
  [2888] = 2462,
  [2889] = 2887,
  [2890] = 2195,
  [2891] = 2877,
  [2892] = 1950,
  [2893] = 2195,
  [2894] = 2877,
  [2895] = 2895,
  [2896] = 2875,
  [2897] = 2201,
  [2898] = 2895,
  [2899] = 1966,
  [2900] = 2875,
  [2901] = 2302,
  [2902] = 2877,
  [2903] = 2303,
  [2904] = 2080,
  [2905] = 2301,
  [2906] = 2895,
  [2907] = 2307,
  [2908] = 2224,
  [2909] = 2289,
  [2910] = 2296,
  [2911] = 2291,
  [2912] = 2875,
  [2913] = 2316,
  [2914] = 2306,
  [2915] = 2311,
  [2916] = 2202,
  [2917] = 2310,
  [2918] = 2312,
  [2919] = 2208,
  [2920] = 2852,
  [2921] = 2887,
  [2922] = 2200,
  [2923] = 2877,
  [2924] = 2191,
  [2925] = 2191,
  [2926] = 2206,
  [2927] = 2852,
  [2928] = 2877,
  [2929] = 1659,
  [2930] = 2852,
  [2931] = 2875,
  [2932] = 2895,
  [2933] = 2217,
  [2934] = 2018,
  [2935] = 2205,
  [2936] = 2622,
  [2937] = 2283,
  [2938] = 2887,
  [2939] = 1992,
  [2940] = 2887,
  [2941] = 2210,
  [2942] = 2018,
  [2943] = 2204,
  [2944] = 2852,
  [2945] = 967,
  [2946] = 2200,
  [2947] = 2201,
  [2948] = 2206,
  [2949] = 2197,
  [2950] = 2875,
  [2951] = 2202,
  [2952] = 2887,
  [2953] = 2203,
  [2954] = 2895,
  [2955] = 2274,
  [2956] = 2852,
  [2957] = 2895,
  [2958] = 2887,
  [2959] = 2197,
  [2960] = 2199,
  [2961] = 2203,
  [2962] = 2205,
  [2963] = 2443,
  [2964] = 2199,
  [2965] = 2273,
  [2966] = 2895,
  [2967] = 1992,
  [2968] = 2274,
  [2969] = 2683,
  [2970] = 967,
  [2971] = 2622,
  [2972] = 2114,
  [2973] = 2688,
  [2974] = 1966,
  [2975] = 2207,
  [2976] = 2852,
  [2977] = 2621,
  [2978] = 2978,
  [2979] = 2621,
  [2980] = 2852,
  [2981] = 923,
  [2982] = 1659,
  [2983] = 945,
  [2984] = 1949,
  [2985] = 1950,
  [2986] = 1966,
  [2987] = 2852,
  [2988] = 947,
  [2989] = 1659,
  [2990] = 949,
  [2991] = 2018,
  [2992] = 929,
  [2993] = 931,
  [2994] = 934,
  [2995] = 1949,
  [2996] = 2852,
  [2997] = 2622,
  [2998] = 1659,
  [2999] = 2852,
  [3000] = 2852,
  [3001] = 2080,
  [3002] = 2283,
  [3003] = 1950,
  [3004] = 2080,
  [3005] = 2273,
  [3006] = 2852,
  [3007] = 2852,
  [3008] = 2852,
  [3009] = 2275,
  [3010] = 2852,
  [3011] = 3011,
  [3012] = 2018,
  [3013] = 955,
  [3014] = 2114,
  [3015] = 3015,
  [3016] = 3016,
  [3017] = 2351,
  [3018] = 3018,
  [3019] = 3019,
  [3020] = 3020,
  [3021] = 3021,
  [3022] = 3022,
  [3023] = 2201,
  [3024] = 3024,
  [3025] = 2200,
  [3026] = 2206,
  [3027] = 2197,
  [3028] = 2203,
  [3029] = 2205,
  [3030] = 2207,
  [3031] = 2343,
  [3032] = 2357,
  [3033] = 3033,
  [3034] = 2199,
  [3035] = 2281,
  [3036] = 3036,
  [3037] = 3037,
  [3038] = 3038,
  [3039] = 3039,
  [3040] = 2210,
  [3041] = 2195,
  [3042] = 2114,
  [3043] = 2278,
  [3044] = 2443,
  [3045] = 2207,
  [3046] = 2189,
  [3047] = 2852,
  [3048] = 1992,
  [3049] = 2852,
  [3050] = 2339,
  [3051] = 2202,
  [3052] = 3052,
  [3053] = 3053,
  [3054] = 3054,
  [3055] = 2462,
  [3056] = 2191,
  [3057] = 3057,
  [3058] = 2852,
  [3059] = 3059,
  [3060] = 2779,
  [3061] = 931,
  [3062] = 2289,
  [3063] = 2296,
  [3064] = 934,
  [3065] = 2837,
  [3066] = 200,
  [3067] = 1949,
  [3068] = 2217,
  [3069] = 2311,
  [3070] = 2114,
  [3071] = 1950,
  [3072] = 2767,
  [3073] = 2343,
  [3074] = 2763,
  [3075] = 3075,
  [3076] = 967,
  [3077] = 1659,
  [3078] = 211,
  [3079] = 2852,
  [3080] = 1966,
  [3081] = 2762,
  [3082] = 2357,
  [3083] = 2852,
  [3084] = 947,
  [3085] = 3085,
  [3086] = 929,
  [3087] = 2351,
  [3088] = 2273,
  [3089] = 2339,
  [3090] = 3090,
  [3091] = 2278,
  [3092] = 2310,
  [3093] = 1966,
  [3094] = 2852,
  [3095] = 2351,
  [3096] = 2852,
  [3097] = 2811,
  [3098] = 2357,
  [3099] = 2291,
  [3100] = 2343,
  [3101] = 2742,
  [3102] = 2303,
  [3103] = 3103,
  [3104] = 2316,
  [3105] = 1949,
  [3106] = 2312,
  [3107] = 1950,
  [3108] = 2765,
  [3109] = 949,
  [3110] = 947,
  [3111] = 949,
  [3112] = 929,
  [3113] = 2278,
  [3114] = 2080,
  [3115] = 923,
  [3116] = 2764,
  [3117] = 2281,
  [3118] = 2622,
  [3119] = 2275,
  [3120] = 2281,
  [3121] = 2302,
  [3122] = 2080,
  [3123] = 945,
  [3124] = 931,
  [3125] = 934,
  [3126] = 2339,
  [3127] = 2852,
  [3128] = 2306,
  [3129] = 923,
  [3130] = 3130,
  [3131] = 2621,
  [3132] = 2283,
  [3133] = 2301,
  [3134] = 2621,
  [3135] = 2622,
  [3136] = 2307,
  [3137] = 945,
  [3138] = 2766,
  [3139] = 2274,
  [3140] = 2114,
  [3141] = 3141,
  [3142] = 3142,
  [3143] = 3054,
  [3144] = 2852,
  [3145] = 3145,
  [3146] = 3146,
  [3147] = 2852,
  [3148] = 3145,
  [3149] = 2301,
  [3150] = 2307,
  [3151] = 2289,
  [3152] = 2296,
  [3153] = 2207,
  [3154] = 2302,
  [3155] = 2303,
  [3156] = 3039,
  [3157] = 2194,
  [3158] = 3037,
  [3159] = 2118,
  [3160] = 3141,
  [3161] = 3142,
  [3162] = 2119,
  [3163] = 3015,
  [3164] = 2135,
  [3165] = 2301,
  [3166] = 2307,
  [3167] = 2152,
  [3168] = 2289,
  [3169] = 2296,
  [3170] = 2291,
  [3171] = 2138,
  [3172] = 2852,
  [3173] = 3141,
  [3174] = 2129,
  [3175] = 3016,
  [3176] = 3053,
  [3177] = 3142,
  [3178] = 2306,
  [3179] = 3018,
  [3180] = 2302,
  [3181] = 2311,
  [3182] = 967,
  [3183] = 3145,
  [3184] = 2291,
  [3185] = 3145,
  [3186] = 2303,
  [3187] = 2316,
  [3188] = 2306,
  [3189] = 2311,
  [3190] = 2852,
  [3191] = 2198,
  [3192] = 2310,
  [3193] = 2312,
  [3194] = 3052,
  [3195] = 3033,
  [3196] = 3036,
  [3197] = 3020,
  [3198] = 3021,
  [3199] = 3022,
  [3200] = 3200,
  [3201] = 3038,
  [3202] = 2310,
  [3203] = 3024,
  [3204] = 3019,
  [3205] = 3011,
  [3206] = 3057,
  [3207] = 2312,
  [3208] = 2316,
  [3209] = 3033,
  [3210] = 2152,
  [3211] = 3021,
  [3212] = 3200,
  [3213] = 2343,
  [3214] = 2449,
  [3215] = 2339,
  [3216] = 2467,
  [3217] = 3024,
  [3218] = 2281,
  [3219] = 2421,
  [3220] = 2119,
  [3221] = 3038,
  [3222] = 3146,
  [3223] = 2138,
  [3224] = 2135,
  [3225] = 2423,
  [3226] = 2152,
  [3227] = 3018,
  [3228] = 3015,
  [3229] = 955,
  [3230] = 3011,
  [3231] = 3057,
  [3232] = 1944,
  [3233] = 3020,
  [3234] = 955,
  [3235] = 2129,
  [3236] = 3039,
  [3237] = 2739,
  [3238] = 2118,
  [3239] = 2129,
  [3240] = 2357,
  [3241] = 3022,
  [3242] = 2278,
  [3243] = 3016,
  [3244] = 3036,
  [3245] = 2072,
  [3246] = 3019,
  [3247] = 3037,
  [3248] = 2466,
  [3249] = 2351,
  [3250] = 955,
  [3251] = 2048,
  [3252] = 2118,
  [3253] = 2135,
  [3254] = 3254,
  [3255] = 3052,
  [3256] = 3053,
  [3257] = 3054,
  [3258] = 2138,
  [3259] = 2119,
  [3260] = 3033,
  [3261] = 2316,
  [3262] = 3262,
  [3263] = 3037,
  [3264] = 1870,
  [3265] = 3019,
  [3266] = 2301,
  [3267] = 3267,
  [3268] = 3268,
  [3269] = 2072,
  [3270] = 3270,
  [3271] = 2583,
  [3272] = 3262,
  [3273] = 3038,
  [3274] = 3274,
  [3275] = 3267,
  [3276] = 3057,
  [3277] = 2141,
  [3278] = 2145,
  [3279] = 3262,
  [3280] = 2124,
  [3281] = 3267,
  [3282] = 2590,
  [3283] = 3054,
  [3284] = 2136,
  [3285] = 2163,
  [3286] = 2423,
  [3287] = 2122,
  [3288] = 2131,
  [3289] = 3270,
  [3290] = 2421,
  [3291] = 2072,
  [3292] = 3292,
  [3293] = 3293,
  [3294] = 2622,
  [3295] = 3141,
  [3296] = 3262,
  [3297] = 3142,
  [3298] = 2632,
  [3299] = 3293,
  [3300] = 3300,
  [3301] = 2587,
  [3302] = 3293,
  [3303] = 3267,
  [3304] = 2116,
  [3305] = 2142,
  [3306] = 3267,
  [3307] = 3307,
  [3308] = 2675,
  [3309] = 2115,
  [3310] = 2125,
  [3311] = 222,
  [3312] = 3293,
  [3313] = 189,
  [3314] = 2130,
  [3315] = 2139,
  [3316] = 2143,
  [3317] = 2467,
  [3318] = 3293,
  [3319] = 3020,
  [3320] = 186,
  [3321] = 2148,
  [3322] = 3021,
  [3323] = 2151,
  [3324] = 3293,
  [3325] = 2310,
  [3326] = 2149,
  [3327] = 2169,
  [3328] = 3300,
  [3329] = 2154,
  [3330] = 2289,
  [3331] = 2296,
  [3332] = 2306,
  [3333] = 3270,
  [3334] = 2662,
  [3335] = 2548,
  [3336] = 3270,
  [3337] = 2312,
  [3338] = 967,
  [3339] = 3022,
  [3340] = 314,
  [3341] = 3341,
  [3342] = 3039,
  [3343] = 3262,
  [3344] = 2128,
  [3345] = 3292,
  [3346] = 1944,
  [3347] = 2358,
  [3348] = 2627,
  [3349] = 3293,
  [3350] = 2153,
  [3351] = 2156,
  [3352] = 3292,
  [3353] = 2311,
  [3354] = 3293,
  [3355] = 2160,
  [3356] = 2307,
  [3357] = 3267,
  [3358] = 2137,
  [3359] = 2560,
  [3360] = 2132,
  [3361] = 2146,
  [3362] = 3293,
  [3363] = 3018,
  [3364] = 3293,
  [3365] = 3292,
  [3366] = 2681,
  [3367] = 3300,
  [3368] = 2449,
  [3369] = 2134,
  [3370] = 3270,
  [3371] = 3292,
  [3372] = 3293,
  [3373] = 3300,
  [3374] = 985,
  [3375] = 3292,
  [3376] = 2449,
  [3377] = 3300,
  [3378] = 3036,
  [3379] = 3292,
  [3380] = 3262,
  [3381] = 3300,
  [3382] = 2291,
  [3383] = 3292,
  [3384] = 3300,
  [3385] = 3292,
  [3386] = 3300,
  [3387] = 2466,
  [3388] = 2048,
  [3389] = 3262,
  [3390] = 3274,
  [3391] = 3053,
  [3392] = 3392,
  [3393] = 3293,
  [3394] = 2615,
  [3395] = 2048,
  [3396] = 2421,
  [3397] = 2466,
  [3398] = 2628,
  [3399] = 3293,
  [3400] = 955,
  [3401] = 2123,
  [3402] = 2621,
  [3403] = 3267,
  [3404] = 185,
  [3405] = 3293,
  [3406] = 3024,
  [3407] = 2302,
  [3408] = 3052,
  [3409] = 2676,
  [3410] = 3270,
  [3411] = 2127,
  [3412] = 3270,
  [3413] = 3015,
  [3414] = 3392,
  [3415] = 3293,
  [3416] = 1651,
  [3417] = 3293,
  [3418] = 3262,
  [3419] = 3016,
  [3420] = 3274,
  [3421] = 3421,
  [3422] = 3392,
  [3423] = 2467,
  [3424] = 2121,
  [3425] = 2120,
  [3426] = 3274,
  [3427] = 3392,
  [3428] = 1944,
  [3429] = 3267,
  [3430] = 3274,
  [3431] = 3392,
  [3432] = 3267,
  [3433] = 3274,
  [3434] = 3392,
  [3435] = 3274,
  [3436] = 3392,
  [3437] = 3274,
  [3438] = 3392,
  [3439] = 2133,
  [3440] = 254,
  [3441] = 2423,
  [3442] = 3011,
  [3443] = 3270,
  [3444] = 3262,
  [3445] = 2303,
  [3446] = 3300,
  [3447] = 3039,
  [3448] = 2590,
  [3449] = 2122,
  [3450] = 2124,
  [3451] = 2128,
  [3452] = 2121,
  [3453] = 2132,
  [3454] = 2133,
  [3455] = 2131,
  [3456] = 2120,
  [3457] = 2217,
  [3458] = 3458,
  [3459] = 1870,
  [3460] = 3460,
  [3461] = 3037,
  [3462] = 2204,
  [3463] = 955,
  [3464] = 2208,
  [3465] = 2187,
  [3466] = 3146,
  [3467] = 3200,
  [3468] = 2677,
  [3469] = 2138,
  [3470] = 3142,
  [3471] = 2129,
  [3472] = 2548,
  [3473] = 2224,
  [3474] = 2722,
  [3475] = 2238,
  [3476] = 955,
  [3477] = 955,
  [3478] = 3085,
  [3479] = 2587,
  [3480] = 3480,
  [3481] = 2119,
  [3482] = 2135,
  [3483] = 2152,
  [3484] = 3484,
  [3485] = 3485,
  [3486] = 3486,
  [3487] = 2665,
  [3488] = 3484,
  [3489] = 3480,
  [3490] = 2722,
  [3491] = 2118,
  [3492] = 2722,
  [3493] = 2169,
  [3494] = 3484,
  [3495] = 3485,
  [3496] = 2697,
  [3497] = 3480,
  [3498] = 2548,
  [3499] = 2722,
  [3500] = 3484,
  [3501] = 3485,
  [3502] = 3480,
  [3503] = 3485,
  [3504] = 3484,
  [3505] = 3485,
  [3506] = 2653,
  [3507] = 3480,
  [3508] = 2662,
  [3509] = 3484,
  [3510] = 3485,
  [3511] = 3480,
  [3512] = 2123,
  [3513] = 2127,
  [3514] = 3484,
  [3515] = 3485,
  [3516] = 2627,
  [3517] = 3016,
  [3518] = 2169,
  [3519] = 3480,
  [3520] = 2153,
  [3521] = 2156,
  [3522] = 2137,
  [3523] = 2146,
  [3524] = 2676,
  [3525] = 2681,
  [3526] = 2697,
  [3527] = 3019,
  [3528] = 3485,
  [3529] = 2628,
  [3530] = 2160,
  [3531] = 3480,
  [3532] = 3485,
  [3533] = 3480,
  [3534] = 3015,
  [3535] = 3480,
  [3536] = 2722,
  [3537] = 2115,
  [3538] = 2125,
  [3539] = 3480,
  [3540] = 2130,
  [3541] = 2139,
  [3542] = 2143,
  [3543] = 2148,
  [3544] = 2151,
  [3545] = 3018,
  [3546] = 2560,
  [3547] = 3052,
  [3548] = 2675,
  [3549] = 3020,
  [3550] = 3485,
  [3551] = 3021,
  [3552] = 3022,
  [3553] = 3024,
  [3554] = 3011,
  [3555] = 3057,
  [3556] = 3033,
  [3557] = 3053,
  [3558] = 3054,
  [3559] = 2632,
  [3560] = 3560,
  [3561] = 2261,
  [3562] = 2583,
  [3563] = 3485,
  [3564] = 2141,
  [3565] = 2145,
  [3566] = 2256,
  [3567] = 2136,
  [3568] = 2163,
  [3569] = 3485,
  [3570] = 2116,
  [3571] = 3038,
  [3572] = 2149,
  [3573] = 2154,
  [3574] = 3485,
  [3575] = 3485,
  [3576] = 2134,
  [3577] = 3141,
  [3578] = 3142,
  [3579] = 2358,
  [3580] = 3036,
  [3581] = 2615,
  [3582] = 3485,
  [3583] = 2662,
  [3584] = 3141,
  [3585] = 3037,
  [3586] = 3485,
  [3587] = 3485,
  [3588] = 3038,
  [3589] = 2590,
  [3590] = 2122,
  [3591] = 2124,
  [3592] = 2128,
  [3593] = 2121,
  [3594] = 2132,
  [3595] = 2133,
  [3596] = 3485,
  [3597] = 3039,
  [3598] = 2131,
  [3599] = 2120,
  [3600] = 2123,
  [3601] = 2127,
  [3602] = 2627,
  [3603] = 3016,
  [3604] = 2153,
  [3605] = 2156,
  [3606] = 2137,
  [3607] = 2146,
  [3608] = 2676,
  [3609] = 2681,
  [3610] = 967,
  [3611] = 3019,
  [3612] = 2628,
  [3613] = 2160,
  [3614] = 2627,
  [3615] = 3016,
  [3616] = 2676,
  [3617] = 2681,
  [3618] = 3019,
  [3619] = 2628,
  [3620] = 3015,
  [3621] = 3018,
  [3622] = 3052,
  [3623] = 2675,
  [3624] = 3020,
  [3625] = 3021,
  [3626] = 3022,
  [3627] = 3024,
  [3628] = 3011,
  [3629] = 3057,
  [3630] = 3033,
  [3631] = 3053,
  [3632] = 3054,
  [3633] = 2632,
  [3634] = 3036,
  [3635] = 3037,
  [3636] = 3038,
  [3637] = 3039,
  [3638] = 3015,
  [3639] = 2115,
  [3640] = 2125,
  [3641] = 2587,
  [3642] = 2130,
  [3643] = 2139,
  [3644] = 2143,
  [3645] = 2148,
  [3646] = 2151,
  [3647] = 3018,
  [3648] = 2560,
  [3649] = 3052,
  [3650] = 2675,
  [3651] = 3020,
  [3652] = 3021,
  [3653] = 3022,
  [3654] = 3024,
  [3655] = 3011,
  [3656] = 3057,
  [3657] = 3033,
  [3658] = 3053,
  [3659] = 3054,
  [3660] = 2662,
  [3661] = 2632,
  [3662] = 1870,
  [3663] = 2583,
  [3664] = 2141,
  [3665] = 2145,
  [3666] = 2136,
  [3667] = 2163,
  [3668] = 2116,
  [3669] = 2142,
  [3670] = 2149,
  [3671] = 2154,
  [3672] = 2134,
  [3673] = 3036,
  [3674] = 2615,
  [3675] = 2142,
  [3676] = 3200,
  [3677] = 2722,
  [3678] = 2693,
  [3679] = 2793,
  [3680] = 1703,
  [3681] = 2694,
  [3682] = 3682,
  [3683] = 1702,
  [3684] = 2750,
  [3685] = 2579,
  [3686] = 2597,
  [3687] = 3687,
  [3688] = 2072,
  [3689] = 1697,
  [3690] = 2745,
  [3691] = 2722,
  [3692] = 3687,
  [3693] = 3682,
  [3694] = 2739,
  [3695] = 3695,
  [3696] = 3696,
  [3697] = 3687,
  [3698] = 1661,
  [3699] = 3682,
  [3700] = 2665,
  [3701] = 3687,
  [3702] = 2735,
  [3703] = 3682,
  [3704] = 2591,
  [3705] = 2593,
  [3706] = 3687,
  [3707] = 2600,
  [3708] = 1662,
  [3709] = 1699,
  [3710] = 3682,
  [3711] = 3687,
  [3712] = 2048,
  [3713] = 2677,
  [3714] = 2793,
  [3715] = 3142,
  [3716] = 1694,
  [3717] = 2723,
  [3718] = 2614,
  [3719] = 1695,
  [3720] = 1688,
  [3721] = 1696,
  [3722] = 1690,
  [3723] = 2750,
  [3724] = 806,
  [3725] = 2599,
  [3726] = 3695,
  [3727] = 2745,
  [3728] = 3141,
  [3729] = 3696,
  [3730] = 805,
  [3731] = 1700,
  [3732] = 2601,
  [3733] = 3696,
  [3734] = 2837,
  [3735] = 2602,
  [3736] = 1701,
  [3737] = 3737,
  [3738] = 1689,
  [3739] = 2462,
  [3740] = 1691,
  [3741] = 139,
  [3742] = 2762,
  [3743] = 3737,
  [3744] = 2763,
  [3745] = 2764,
  [3746] = 3737,
  [3747] = 2653,
  [3748] = 2765,
  [3749] = 2766,
  [3750] = 3737,
  [3751] = 3146,
  [3752] = 3737,
  [3753] = 2722,
  [3754] = 2589,
  [3755] = 2767,
  [3756] = 2677,
  [3757] = 3682,
  [3758] = 138,
  [3759] = 967,
  [3760] = 967,
  [3761] = 2595,
  [3762] = 2224,
  [3763] = 2653,
  [3764] = 1692,
  [3765] = 3765,
  [3766] = 1944,
  [3767] = 1693,
  [3768] = 2710,
  [3769] = 2697,
  [3770] = 3770,
  [3771] = 2665,
  [3772] = 3682,
  [3773] = 3773,
  [3774] = 3687,
  [3775] = 2739,
  [3776] = 3737,
  [3777] = 3737,
  [3778] = 1695,
  [3779] = 2676,
  [3780] = 2168,
  [3781] = 2681,
  [3782] = 2204,
  [3783] = 2784,
  [3784] = 2697,
  [3785] = 3142,
  [3786] = 2785,
  [3787] = 2787,
  [3788] = 3788,
  [3789] = 2722,
  [3790] = 2697,
  [3791] = 3019,
  [3792] = 2628,
  [3793] = 2792,
  [3794] = 2204,
  [3795] = 2798,
  [3796] = 2160,
  [3797] = 2275,
  [3798] = 3200,
  [3799] = 2762,
  [3800] = 3800,
  [3801] = 2763,
  [3802] = 2120,
  [3803] = 2764,
  [3804] = 2737,
  [3805] = 1654,
  [3806] = 2827,
  [3807] = 2831,
  [3808] = 3808,
  [3809] = 2800,
  [3810] = 2765,
  [3811] = 2693,
  [3812] = 2758,
  [3813] = 2766,
  [3814] = 2767,
  [3815] = 2715,
  [3816] = 2761,
  [3817] = 2462,
  [3818] = 2189,
  [3819] = 967,
  [3820] = 2201,
  [3821] = 2202,
  [3822] = 2191,
  [3823] = 2778,
  [3824] = 2739,
  [3825] = 2828,
  [3826] = 2200,
  [3827] = 2777,
  [3828] = 2738,
  [3829] = 2206,
  [3830] = 2208,
  [3831] = 2797,
  [3832] = 2722,
  [3833] = 2197,
  [3834] = 1700,
  [3835] = 2203,
  [3836] = 2205,
  [3837] = 2199,
  [3838] = 2595,
  [3839] = 2599,
  [3840] = 2601,
  [3841] = 2602,
  [3842] = 2817,
  [3843] = 2210,
  [3844] = 2195,
  [3845] = 3015,
  [3846] = 806,
  [3847] = 2807,
  [3848] = 2751,
  [3849] = 2722,
  [3850] = 2809,
  [3851] = 2184,
  [3852] = 2595,
  [3853] = 2599,
  [3854] = 2601,
  [3855] = 2602,
  [3856] = 2833,
  [3857] = 2786,
  [3858] = 138,
  [3859] = 1870,
  [3860] = 2750,
  [3861] = 3200,
  [3862] = 2716,
  [3863] = 3141,
  [3864] = 2131,
  [3865] = 2115,
  [3866] = 2125,
  [3867] = 1688,
  [3868] = 2757,
  [3869] = 2614,
  [3870] = 2130,
  [3871] = 2139,
  [3872] = 1992,
  [3873] = 2018,
  [3874] = 2143,
  [3875] = 2148,
  [3876] = 2579,
  [3877] = 2597,
  [3878] = 2151,
  [3879] = 2358,
  [3880] = 2811,
  [3881] = 2187,
  [3882] = 2627,
  [3883] = 2742,
  [3884] = 2717,
  [3885] = 1657,
  [3886] = 3018,
  [3887] = 2759,
  [3888] = 2773,
  [3889] = 2208,
  [3890] = 3142,
  [3891] = 2794,
  [3892] = 2462,
  [3893] = 2795,
  [3894] = 2796,
  [3895] = 2741,
  [3896] = 2560,
  [3897] = 2783,
  [3898] = 1694,
  [3899] = 805,
  [3900] = 2735,
  [3901] = 2748,
  [3902] = 3052,
  [3903] = 1692,
  [3904] = 2675,
  [3905] = 3020,
  [3906] = 3808,
  [3907] = 3022,
  [3908] = 2722,
  [3909] = 3024,
  [3910] = 3016,
  [3911] = 3011,
  [3912] = 3057,
  [3913] = 3033,
  [3914] = 2169,
  [3915] = 2745,
  [3916] = 3141,
  [3917] = 2123,
  [3918] = 2805,
  [3919] = 3053,
  [3920] = 2735,
  [3921] = 1697,
  [3922] = 3054,
  [3923] = 2723,
  [3924] = 3142,
  [3925] = 2799,
  [3926] = 2728,
  [3927] = 3146,
  [3928] = 2837,
  [3929] = 139,
  [3930] = 1693,
  [3931] = 1696,
  [3932] = 2802,
  [3933] = 1699,
  [3934] = 2804,
  [3935] = 2632,
  [3936] = 2589,
  [3937] = 2274,
  [3938] = 3141,
  [3939] = 2583,
  [3940] = 2283,
  [3941] = 1690,
  [3942] = 2776,
  [3943] = 2141,
  [3944] = 2145,
  [3945] = 2812,
  [3946] = 2743,
  [3947] = 2153,
  [3948] = 2136,
  [3949] = 2163,
  [3950] = 2723,
  [3951] = 2116,
  [3952] = 2142,
  [3953] = 2694,
  [3954] = 3141,
  [3955] = 2614,
  [3956] = 2149,
  [3957] = 2154,
  [3958] = 2187,
  [3959] = 2134,
  [3960] = 3142,
  [3961] = 3036,
  [3962] = 2615,
  [3963] = 3800,
  [3964] = 2710,
  [3965] = 3808,
  [3966] = 2793,
  [3967] = 2756,
  [3968] = 2739,
  [3969] = 806,
  [3970] = 2710,
  [3971] = 2693,
  [3972] = 2589,
  [3973] = 2775,
  [3974] = 2772,
  [3975] = 3037,
  [3976] = 2156,
  [3977] = 2724,
  [3978] = 2591,
  [3979] = 2137,
  [3980] = 2579,
  [3981] = 2593,
  [3982] = 2597,
  [3983] = 3038,
  [3984] = 2590,
  [3985] = 2600,
  [3986] = 2273,
  [3987] = 2122,
  [3988] = 2124,
  [3989] = 2819,
  [3990] = 2128,
  [3991] = 2121,
  [3992] = 2132,
  [3993] = 2133,
  [3994] = 2820,
  [3995] = 2146,
  [3996] = 2779,
  [3997] = 805,
  [3998] = 3800,
  [3999] = 2127,
  [4000] = 2694,
  [4001] = 2829,
  [4002] = 3146,
  [4003] = 1656,
  [4004] = 3039,
  [4005] = 2830,
  [4006] = 1703,
  [4007] = 2591,
  [4008] = 1701,
  [4009] = 1689,
  [4010] = 1691,
  [4011] = 2593,
  [4012] = 2600,
  [4013] = 1702,
  [4014] = 2704,
  [4015] = 3021,
  [4016] = 2739,
  [4017] = 945,
  [4018] = 947,
  [4019] = 949,
  [4020] = 929,
  [4021] = 4021,
  [4022] = 931,
  [4023] = 934,
  [4024] = 4024,
  [4025] = 2739,
  [4026] = 2761,
  [4027] = 4027,
  [4028] = 2820,
  [4029] = 2776,
  [4030] = 923,
  [4031] = 4021,
  [4032] = 1703,
  [4033] = 1697,
  [4034] = 2273,
  [4035] = 2275,
  [4036] = 2793,
  [4037] = 2283,
  [4038] = 2800,
  [4039] = 2274,
  [4040] = 2817,
  [4041] = 2783,
  [4042] = 2833,
  [4043] = 2831,
  [4044] = 967,
  [4045] = 2739,
  [4046] = 1703,
  [4047] = 1697,
  [4048] = 2742,
  [4049] = 2748,
  [4050] = 2743,
  [4051] = 2793,
  [4052] = 2828,
  [4053] = 2080,
  [4054] = 2751,
  [4055] = 2785,
  [4056] = 2787,
  [4057] = 2758,
  [4058] = 2761,
  [4059] = 4021,
  [4060] = 2738,
  [4061] = 1700,
  [4062] = 2757,
  [4063] = 2759,
  [4064] = 1694,
  [4065] = 2762,
  [4066] = 2763,
  [4067] = 2764,
  [4068] = 2797,
  [4069] = 2765,
  [4070] = 2766,
  [4071] = 2767,
  [4072] = 2809,
  [4073] = 923,
  [4074] = 2794,
  [4075] = 2795,
  [4076] = 1701,
  [4077] = 1689,
  [4078] = 1691,
  [4079] = 2792,
  [4080] = 2777,
  [4081] = 4024,
  [4082] = 2773,
  [4083] = 4083,
  [4084] = 4024,
  [4085] = 4027,
  [4086] = 945,
  [4087] = 947,
  [4088] = 949,
  [4089] = 4027,
  [4090] = 2168,
  [4091] = 2717,
  [4092] = 2737,
  [4093] = 4021,
  [4094] = 929,
  [4095] = 2715,
  [4096] = 2716,
  [4097] = 2775,
  [4098] = 931,
  [4099] = 934,
  [4100] = 2724,
  [4101] = 2778,
  [4102] = 4083,
  [4103] = 2796,
  [4104] = 1692,
  [4105] = 1693,
  [4106] = 2704,
  [4107] = 2728,
  [4108] = 2738,
  [4109] = 139,
  [4110] = 2797,
  [4111] = 2779,
  [4112] = 2807,
  [4113] = 2809,
  [4114] = 2786,
  [4115] = 1695,
  [4116] = 1688,
  [4117] = 2837,
  [4118] = 1700,
  [4119] = 2750,
  [4120] = 2805,
  [4121] = 2224,
  [4122] = 4083,
  [4123] = 138,
  [4124] = 2802,
  [4125] = 2799,
  [4126] = 1694,
  [4127] = 2750,
  [4128] = 4021,
  [4129] = 2811,
  [4130] = 2804,
  [4131] = 2812,
  [4132] = 2827,
  [4133] = 4024,
  [4134] = 4027,
  [4135] = 2653,
  [4136] = 4083,
  [4137] = 1949,
  [4138] = 1950,
  [4139] = 2739,
  [4140] = 2741,
  [4141] = 2621,
  [4142] = 1966,
  [4143] = 4024,
  [4144] = 4027,
  [4145] = 4083,
  [4146] = 1701,
  [4147] = 1689,
  [4148] = 1691,
  [4149] = 2819,
  [4150] = 2737,
  [4151] = 2715,
  [4152] = 2783,
  [4153] = 3141,
  [4154] = 3142,
  [4155] = 2716,
  [4156] = 2717,
  [4157] = 2653,
  [4158] = 2829,
  [4159] = 2830,
  [4160] = 2622,
  [4161] = 2811,
  [4162] = 1702,
  [4163] = 2184,
  [4164] = 4021,
  [4165] = 2018,
  [4166] = 2796,
  [4167] = 4024,
  [4168] = 4027,
  [4169] = 1696,
  [4170] = 4083,
  [4171] = 1690,
  [4172] = 2704,
  [4173] = 2745,
  [4174] = 2776,
  [4175] = 2792,
  [4176] = 2798,
  [4177] = 2827,
  [4178] = 2741,
  [4179] = 2722,
  [4180] = 2805,
  [4181] = 1692,
  [4182] = 1693,
  [4183] = 1699,
  [4184] = 1695,
  [4185] = 2756,
  [4186] = 2772,
  [4187] = 1688,
  [4188] = 2784,
  [4189] = 2739,
  [4190] = 2777,
  [4191] = 2807,
  [4192] = 2800,
  [4193] = 2817,
  [4194] = 2833,
  [4195] = 2739,
  [4196] = 2728,
  [4197] = 2828,
  [4198] = 2743,
  [4199] = 4083,
  [4200] = 2751,
  [4201] = 2724,
  [4202] = 1702,
  [4203] = 2168,
  [4204] = 1992,
  [4205] = 4024,
  [4206] = 1696,
  [4207] = 4024,
  [4208] = 1690,
  [4209] = 2757,
  [4210] = 4027,
  [4211] = 2759,
  [4212] = 4212,
  [4213] = 4213,
  [4214] = 2831,
  [4215] = 967,
  [4216] = 4027,
  [4217] = 2756,
  [4218] = 2762,
  [4219] = 4083,
  [4220] = 3141,
  [4221] = 2763,
  [4222] = 2764,
  [4223] = 2765,
  [4224] = 2766,
  [4225] = 2767,
  [4226] = 4021,
  [4227] = 2802,
  [4228] = 3142,
  [4229] = 2772,
  [4230] = 2773,
  [4231] = 2745,
  [4232] = 1699,
  [4233] = 2748,
  [4234] = 2462,
  [4235] = 2775,
  [4236] = 2742,
  [4237] = 2778,
  [4238] = 139,
  [4239] = 3268,
  [4240] = 2784,
  [4241] = 138,
  [4242] = 2779,
  [4243] = 2786,
  [4244] = 2785,
  [4245] = 3307,
  [4246] = 2799,
  [4247] = 2837,
  [4248] = 2804,
  [4249] = 2812,
  [4250] = 2787,
  [4251] = 2794,
  [4252] = 2795,
  [4253] = 4253,
  [4254] = 4021,
  [4255] = 2184,
  [4256] = 2798,
  [4257] = 2758,
  [4258] = 2819,
  [4259] = 2820,
  [4260] = 2829,
  [4261] = 2830,
  [4262] = 4262,
  [4263] = 1706,
  [4264] = 2275,
  [4265] = 2358,
  [4266] = 2773,
  [4267] = 2812,
  [4268] = 3200,
  [4269] = 4269,
  [4270] = 3141,
  [4271] = 3142,
  [4272] = 2283,
  [4273] = 2274,
  [4274] = 2358,
  [4275] = 3146,
  [4276] = 1661,
  [4277] = 3788,
  [4278] = 2018,
  [4279] = 2827,
  [4280] = 1662,
  [4281] = 1654,
  [4282] = 2772,
  [4283] = 2207,
  [4284] = 3800,
  [4285] = 3808,
  [4286] = 2723,
  [4287] = 2723,
  [4288] = 1992,
  [4289] = 2273,
  [4290] = 2114,
  [4291] = 4291,
  [4292] = 2805,
  [4293] = 2748,
  [4294] = 4294,
  [4295] = 2819,
  [4296] = 2829,
  [4297] = 2800,
  [4298] = 4298,
  [4299] = 2757,
  [4300] = 2830,
  [4301] = 1703,
  [4302] = 2785,
  [4303] = 2274,
  [4304] = 3141,
  [4305] = 4291,
  [4306] = 2805,
  [4307] = 2817,
  [4308] = 4308,
  [4309] = 4309,
  [4310] = 2833,
  [4311] = 2787,
  [4312] = 2779,
  [4313] = 3808,
  [4314] = 2283,
  [4315] = 2743,
  [4316] = 2184,
  [4317] = 2819,
  [4318] = 2621,
  [4319] = 2622,
  [4320] = 2777,
  [4321] = 1696,
  [4322] = 2820,
  [4323] = 2778,
  [4324] = 1690,
  [4325] = 2756,
  [4326] = 1699,
  [4327] = 2738,
  [4328] = 2797,
  [4329] = 2777,
  [4330] = 2339,
  [4331] = 2792,
  [4332] = 2820,
  [4333] = 2798,
  [4334] = 2807,
  [4335] = 2741,
  [4336] = 4336,
  [4337] = 3800,
  [4338] = 2809,
  [4339] = 2738,
  [4340] = 2756,
  [4341] = 2797,
  [4342] = 2812,
  [4343] = 2759,
  [4344] = 1651,
  [4345] = 2281,
  [4346] = 1691,
  [4347] = 2357,
  [4348] = 2273,
  [4349] = 2772,
  [4350] = 1702,
  [4351] = 2807,
  [4352] = 4352,
  [4353] = 2343,
  [4354] = 2775,
  [4355] = 2809,
  [4356] = 4356,
  [4357] = 2775,
  [4358] = 3141,
  [4359] = 2759,
  [4360] = 2817,
  [4361] = 3142,
  [4362] = 2351,
  [4363] = 2811,
  [4364] = 4309,
  [4365] = 2224,
  [4366] = 2275,
  [4367] = 1689,
  [4368] = 3808,
  [4369] = 2778,
  [4370] = 2273,
  [4371] = 2275,
  [4372] = 138,
  [4373] = 2833,
  [4374] = 2799,
  [4375] = 2792,
  [4376] = 3142,
  [4377] = 2798,
  [4378] = 2799,
  [4379] = 2784,
  [4380] = 2757,
  [4381] = 4309,
  [4382] = 1692,
  [4383] = 4336,
  [4384] = 4352,
  [4385] = 4356,
  [4386] = 2786,
  [4387] = 4336,
  [4388] = 2761,
  [4389] = 1693,
  [4390] = 2785,
  [4391] = 1697,
  [4392] = 4352,
  [4393] = 2168,
  [4394] = 2829,
  [4395] = 2743,
  [4396] = 2800,
  [4397] = 2804,
  [4398] = 2787,
  [4399] = 2827,
  [4400] = 139,
  [4401] = 2283,
  [4402] = 4294,
  [4403] = 1700,
  [4404] = 4298,
  [4405] = 2217,
  [4406] = 2783,
  [4407] = 2741,
  [4408] = 2748,
  [4409] = 4308,
  [4410] = 1701,
  [4411] = 4356,
  [4412] = 3800,
  [4413] = 2804,
  [4414] = 2830,
  [4415] = 1651,
  [4416] = 2742,
  [4417] = 2274,
  [4418] = 2773,
  [4419] = 2761,
  [4420] = 2784,
  [4421] = 2278,
  [4422] = 2224,
  [4423] = 2786,
  [4424] = 1695,
  [4425] = 2758,
  [4426] = 2758,
  [4427] = 1688,
  [4428] = 2783,
  [4429] = 1694,
  [4430] = 2291,
  [4431] = 2351,
  [4432] = 2274,
  [4433] = 2357,
  [4434] = 2207,
  [4435] = 2199,
  [4436] = 2316,
  [4437] = 4437,
  [4438] = 2306,
  [4439] = 2462,
  [4440] = 2224,
  [4441] = 2311,
  [4442] = 4442,
  [4443] = 2189,
  [4444] = 2302,
  [4445] = 2210,
  [4446] = 2195,
  [4447] = 2303,
  [4448] = 1661,
  [4449] = 2310,
  [4450] = 2312,
  [4451] = 2273,
  [4452] = 3142,
  [4453] = 2283,
  [4454] = 2201,
  [4455] = 2339,
  [4456] = 3808,
  [4457] = 2202,
  [4458] = 2191,
  [4459] = 2301,
  [4460] = 2307,
  [4461] = 3800,
  [4462] = 3141,
  [4463] = 3142,
  [4464] = 2621,
  [4465] = 2622,
  [4466] = 2289,
  [4467] = 2296,
  [4468] = 2273,
  [4469] = 2274,
  [4470] = 2343,
  [4471] = 2275,
  [4472] = 3141,
  [4473] = 1662,
  [4474] = 2200,
  [4475] = 2206,
  [4476] = 2197,
  [4477] = 2283,
  [4478] = 2203,
  [4479] = 2205,
  [4480] = 2275,
  [4481] = 2205,
  [4482] = 2189,
  [4483] = 1992,
  [4484] = 1654,
  [4485] = 2018,
  [4486] = 2201,
  [4487] = 2135,
  [4488] = 1706,
  [4489] = 4309,
  [4490] = 2202,
  [4491] = 2191,
  [4492] = 2018,
  [4493] = 2138,
  [4494] = 4336,
  [4495] = 4352,
  [4496] = 2129,
  [4497] = 4356,
  [4498] = 2590,
  [4499] = 2735,
  [4500] = 2200,
  [4501] = 2206,
  [4502] = 2197,
  [4503] = 2203,
  [4504] = 2583,
  [4505] = 3800,
  [4506] = 3808,
  [4507] = 2118,
  [4508] = 2018,
  [4509] = 2710,
  [4510] = 2694,
  [4511] = 3800,
  [4512] = 2152,
  [4513] = 1992,
  [4514] = 1992,
  [4515] = 1661,
  [4516] = 2462,
  [4517] = 2210,
  [4518] = 2195,
  [4519] = 3808,
  [4520] = 4520,
  [4521] = 3800,
  [4522] = 1662,
  [4523] = 3800,
  [4524] = 2217,
  [4525] = 4525,
  [4526] = 2615,
  [4527] = 3808,
  [4528] = 2119,
  [4529] = 3808,
  [4530] = 4525,
  [4531] = 2462,
  [4532] = 2560,
  [4533] = 2199,
  [4534] = 3141,
  [4535] = 2622,
  [4536] = 4437,
  [4537] = 1656,
  [4538] = 2048,
  [4539] = 1656,
  [4540] = 4336,
  [4541] = 1870,
  [4542] = 1657,
  [4543] = 2621,
  [4544] = 1659,
  [4545] = 923,
  [4546] = 2621,
  [4547] = 2622,
  [4548] = 4309,
  [4549] = 4336,
  [4550] = 4352,
  [4551] = 4356,
  [4552] = 4352,
  [4553] = 4356,
  [4554] = 3808,
  [4555] = 945,
  [4556] = 1949,
  [4557] = 947,
  [4558] = 1944,
  [4559] = 1657,
  [4560] = 2072,
  [4561] = 1950,
  [4562] = 4442,
  [4563] = 2621,
  [4564] = 3142,
  [4565] = 2224,
  [4566] = 929,
  [4567] = 931,
  [4568] = 934,
  [4569] = 3800,
  [4570] = 3800,
  [4571] = 3808,
  [4572] = 2675,
  [4573] = 2632,
  [4574] = 2627,
  [4575] = 2676,
  [4576] = 2681,
  [4577] = 2628,
  [4578] = 2462,
  [4579] = 2622,
  [4580] = 4309,
  [4581] = 1966,
  [4582] = 2080,
  [4583] = 949,
  [4584] = 2143,
  [4585] = 3024,
  [4586] = 923,
  [4587] = 945,
  [4588] = 947,
  [4589] = 949,
  [4590] = 929,
  [4591] = 931,
  [4592] = 934,
  [4593] = 2136,
  [4594] = 2145,
  [4595] = 3011,
  [4596] = 3057,
  [4597] = 3033,
  [4598] = 3053,
  [4599] = 2130,
  [4600] = 4600,
  [4601] = 2281,
  [4602] = 2139,
  [4603] = 2141,
  [4604] = 4352,
  [4605] = 3054,
  [4606] = 4336,
  [4607] = 2278,
  [4608] = 2122,
  [4609] = 3036,
  [4610] = 2131,
  [4611] = 2154,
  [4612] = 3037,
  [4613] = 2124,
  [4614] = 3038,
  [4615] = 3039,
  [4616] = 2160,
  [4617] = 3016,
  [4618] = 3019,
  [4619] = 2142,
  [4620] = 2148,
  [4621] = 2151,
  [4622] = 2134,
  [4623] = 4309,
  [4624] = 2116,
  [4625] = 2146,
  [4626] = 4626,
  [4627] = 2149,
  [4628] = 2137,
  [4629] = 2128,
  [4630] = 2123,
  [4631] = 2217,
  [4632] = 2120,
  [4633] = 4520,
  [4634] = 2207,
  [4635] = 3015,
  [4636] = 2132,
  [4637] = 3018,
  [4638] = 3052,
  [4639] = 2207,
  [4640] = 2189,
  [4641] = 2201,
  [4642] = 2351,
  [4643] = 2202,
  [4644] = 2191,
  [4645] = 2080,
  [4646] = 3800,
  [4647] = 3808,
  [4648] = 2127,
  [4649] = 3020,
  [4650] = 2200,
  [4651] = 1706,
  [4652] = 2133,
  [4653] = 2339,
  [4654] = 2206,
  [4655] = 2197,
  [4656] = 2203,
  [4657] = 2205,
  [4658] = 2199,
  [4659] = 2210,
  [4660] = 2195,
  [4661] = 2153,
  [4662] = 3021,
  [4663] = 2156,
  [4664] = 3022,
  [4665] = 2115,
  [4666] = 1949,
  [4667] = 1950,
  [4668] = 2357,
  [4669] = 2114,
  [4670] = 1659,
  [4671] = 2125,
  [4672] = 1966,
  [4673] = 2343,
  [4674] = 4356,
  [4675] = 2224,
  [4676] = 2163,
  [4677] = 2121,
  [4678] = 4356,
  [4679] = 2676,
  [4680] = 4336,
  [4681] = 2615,
  [4682] = 4352,
  [4683] = 4356,
  [4684] = 2310,
  [4685] = 2048,
  [4686] = 2312,
  [4687] = 2339,
  [4688] = 2621,
  [4689] = 4309,
  [4690] = 4336,
  [4691] = 4352,
  [4692] = 2278,
  [4693] = 2622,
  [4694] = 2018,
  [4695] = 4309,
  [4696] = 2462,
  [4697] = 2339,
  [4698] = 2628,
  [4699] = 2114,
  [4700] = 3800,
  [4701] = 4336,
  [4702] = 4352,
  [4703] = 2811,
  [4704] = 2681,
  [4705] = 2357,
  [4706] = 2301,
  [4707] = 4356,
  [4708] = 2307,
  [4709] = 2357,
  [4710] = 2742,
  [4711] = 2289,
  [4712] = 2296,
  [4713] = 4713,
  [4714] = 4309,
  [4715] = 1992,
  [4716] = 2590,
  [4717] = 2675,
  [4718] = 4713,
  [4719] = 4309,
  [4720] = 2779,
  [4721] = 1992,
  [4722] = 2560,
  [4723] = 2343,
  [4724] = 2351,
  [4725] = 2627,
  [4726] = 3808,
  [4727] = 2281,
  [4728] = 4336,
  [4729] = 4352,
  [4730] = 2291,
  [4731] = 1706,
  [4732] = 4713,
  [4733] = 2217,
  [4734] = 2018,
  [4735] = 4356,
  [4736] = 2302,
  [4737] = 2316,
  [4738] = 2306,
  [4739] = 2351,
  [4740] = 2311,
  [4741] = 2632,
  [4742] = 2303,
  [4743] = 2583,
  [4744] = 2343,
  [4745] = 2307,
  [4746] = 2306,
  [4747] = 3146,
  [4748] = 4748,
  [4749] = 2128,
  [4750] = 4750,
  [4751] = 2301,
  [4752] = 4752,
  [4753] = 2311,
  [4754] = 2121,
  [4755] = 4750,
  [4756] = 2132,
  [4757] = 2133,
  [4758] = 2168,
  [4759] = 4752,
  [4760] = 2138,
  [4761] = 3200,
  [4762] = 2115,
  [4763] = 4748,
  [4764] = 2125,
  [4765] = 2289,
  [4766] = 4748,
  [4767] = 2296,
  [4768] = 2129,
  [4769] = 3808,
  [4770] = 2184,
  [4771] = 2130,
  [4772] = 4750,
  [4773] = 2139,
  [4774] = 4752,
  [4775] = 2143,
  [4776] = 4748,
  [4777] = 4748,
  [4778] = 2160,
  [4779] = 2148,
  [4780] = 2151,
  [4781] = 4750,
  [4782] = 4752,
  [4783] = 4748,
  [4784] = 2018,
  [4785] = 2137,
  [4786] = 4750,
  [4787] = 1992,
  [4788] = 4788,
  [4789] = 4309,
  [4790] = 4336,
  [4791] = 4352,
  [4792] = 4356,
  [4793] = 2156,
  [4794] = 4794,
  [4795] = 4750,
  [4796] = 4750,
  [4797] = 4752,
  [4798] = 4748,
  [4799] = 4752,
  [4800] = 2310,
  [4801] = 2312,
  [4802] = 2291,
  [4803] = 2146,
  [4804] = 4748,
  [4805] = 2131,
  [4806] = 4752,
  [4807] = 2120,
  [4808] = 2123,
  [4809] = 4750,
  [4810] = 3800,
  [4811] = 2119,
  [4812] = 2141,
  [4813] = 2145,
  [4814] = 2127,
  [4815] = 2316,
  [4816] = 2118,
  [4817] = 4309,
  [4818] = 4336,
  [4819] = 4352,
  [4820] = 2135,
  [4821] = 4356,
  [4822] = 2136,
  [4823] = 2163,
  [4824] = 2122,
  [4825] = 2152,
  [4826] = 2116,
  [4827] = 2142,
  [4828] = 2302,
  [4829] = 2303,
  [4830] = 2149,
  [4831] = 2154,
  [4832] = 2124,
  [4833] = 3808,
  [4834] = 4752,
  [4835] = 2153,
  [4836] = 2134,
  [4837] = 3800,
  [4838] = 3037,
  [4839] = 3018,
  [4840] = 3016,
  [4841] = 3021,
  [4842] = 3022,
  [4843] = 3024,
  [4844] = 3011,
  [4845] = 3039,
  [4846] = 3057,
  [4847] = 1697,
  [4848] = 3033,
  [4849] = 3038,
  [4850] = 3053,
  [4851] = 3019,
  [4852] = 2138,
  [4853] = 2119,
  [4854] = 3200,
  [4855] = 3015,
  [4856] = 3054,
  [4857] = 1703,
  [4858] = 1702,
  [4859] = 1694,
  [4860] = 3036,
  [4861] = 3052,
  [4862] = 2278,
  [4863] = 3020,
  [4864] = 3016,
  [4865] = 3019,
  [4866] = 3021,
  [4867] = 2118,
  [4868] = 1696,
  [4869] = 1690,
  [4870] = 3022,
  [4871] = 4871,
  [4872] = 1700,
  [4873] = 3146,
  [4874] = 4874,
  [4875] = 1692,
  [4876] = 1693,
  [4877] = 1699,
  [4878] = 3018,
  [4879] = 2129,
  [4880] = 1695,
  [4881] = 1688,
  [4882] = 3036,
  [4883] = 4883,
  [4884] = 2135,
  [4885] = 4309,
  [4886] = 2168,
  [4887] = 4336,
  [4888] = 4352,
  [4889] = 4356,
  [4890] = 3037,
  [4891] = 139,
  [4892] = 2281,
  [4893] = 1701,
  [4894] = 1689,
  [4895] = 2152,
  [4896] = 1691,
  [4897] = 3052,
  [4898] = 3015,
  [4899] = 3039,
  [4900] = 3038,
  [4901] = 3020,
  [4902] = 3024,
  [4903] = 3011,
  [4904] = 138,
  [4905] = 3057,
  [4906] = 3033,
  [4907] = 3053,
  [4908] = 3054,
  [4909] = 2184,
  [4910] = 4910,
  [4911] = 4911,
  [4912] = 1944,
  [4913] = 2312,
  [4914] = 2296,
  [4915] = 4911,
  [4916] = 4916,
  [4917] = 2306,
  [4918] = 2311,
  [4919] = 4309,
  [4920] = 2622,
  [4921] = 1662,
  [4922] = 4922,
  [4923] = 1944,
  [4924] = 4336,
  [4925] = 4352,
  [4926] = 4356,
  [4927] = 4910,
  [4928] = 4788,
  [4929] = 2291,
  [4930] = 3800,
  [4931] = 4911,
  [4932] = 4910,
  [4933] = 4933,
  [4934] = 4934,
  [4935] = 4910,
  [4936] = 4910,
  [4937] = 2622,
  [4938] = 4938,
  [4939] = 4356,
  [4940] = 4910,
  [4941] = 2307,
  [4942] = 4942,
  [4943] = 4910,
  [4944] = 4944,
  [4945] = 4945,
  [4946] = 4945,
  [4947] = 2072,
  [4948] = 2621,
  [4949] = 4933,
  [4950] = 4933,
  [4951] = 4945,
  [4952] = 4933,
  [4953] = 4910,
  [4954] = 4911,
  [4955] = 4934,
  [4956] = 4910,
  [4957] = 2301,
  [4958] = 4958,
  [4959] = 2072,
  [4960] = 4933,
  [4961] = 4916,
  [4962] = 4910,
  [4963] = 4933,
  [4964] = 4910,
  [4965] = 4910,
  [4966] = 4933,
  [4967] = 2316,
  [4968] = 4968,
  [4969] = 4933,
  [4970] = 2462,
  [4971] = 4910,
  [4972] = 4910,
  [4973] = 4910,
  [4974] = 2302,
  [4975] = 4916,
  [4976] = 3808,
  [4977] = 2621,
  [4978] = 4910,
  [4979] = 2622,
  [4980] = 2303,
  [4981] = 4336,
  [4982] = 4916,
  [4983] = 4916,
  [4984] = 1661,
  [4985] = 4945,
  [4986] = 4910,
  [4987] = 2048,
  [4988] = 4916,
  [4989] = 4788,
  [4990] = 4916,
  [4991] = 4945,
  [4992] = 4992,
  [4993] = 4945,
  [4994] = 4945,
  [4995] = 2224,
  [4996] = 4938,
  [4997] = 2048,
  [4998] = 4958,
  [4999] = 2621,
  [5000] = 4916,
  [5001] = 4945,
  [5002] = 2289,
  [5003] = 2310,
  [5004] = 5004,
  [5005] = 4910,
  [5006] = 4916,
  [5007] = 4910,
  [5008] = 2137,
  [5009] = 5009,
  [5010] = 2143,
  [5011] = 2134,
  [5012] = 2139,
  [5013] = 3015,
  [5014] = 2615,
  [5015] = 2136,
  [5016] = 5009,
  [5017] = 2163,
  [5018] = 2143,
  [5019] = 5019,
  [5020] = 3036,
  [5021] = 3039,
  [5022] = 5022,
  [5023] = 2148,
  [5024] = 2116,
  [5025] = 2151,
  [5026] = 5026,
  [5027] = 2142,
  [5028] = 3200,
  [5029] = 2149,
  [5030] = 2676,
  [5031] = 5031,
  [5032] = 2681,
  [5033] = 2154,
  [5034] = 3036,
  [5035] = 2115,
  [5036] = 2118,
  [5037] = 2125,
  [5038] = 2122,
  [5039] = 2615,
  [5040] = 2124,
  [5041] = 5041,
  [5042] = 5041,
  [5043] = 2128,
  [5044] = 2627,
  [5045] = 2134,
  [5046] = 5046,
  [5047] = 3016,
  [5048] = 2676,
  [5049] = 2681,
  [5050] = 3036,
  [5051] = 3019,
  [5052] = 2628,
  [5053] = 5053,
  [5054] = 3015,
  [5055] = 2121,
  [5056] = 5056,
  [5057] = 2153,
  [5058] = 5056,
  [5059] = 2132,
  [5060] = 2156,
  [5061] = 5009,
  [5062] = 2133,
  [5063] = 3019,
  [5064] = 4309,
  [5065] = 2628,
  [5066] = 5066,
  [5067] = 3037,
  [5068] = 5046,
  [5069] = 5009,
  [5070] = 2137,
  [5071] = 5071,
  [5072] = 3018,
  [5073] = 2146,
  [5074] = 2131,
  [5075] = 2627,
  [5076] = 4336,
  [5077] = 4356,
  [5078] = 3038,
  [5079] = 3039,
  [5080] = 2590,
  [5081] = 2120,
  [5082] = 2560,
  [5083] = 5046,
  [5084] = 1870,
  [5085] = 3037,
  [5086] = 2119,
  [5087] = 2632,
  [5088] = 2141,
  [5089] = 3016,
  [5090] = 2160,
  [5091] = 5041,
  [5092] = 5092,
  [5093] = 5009,
  [5094] = 2145,
  [5095] = 5056,
  [5096] = 3018,
  [5097] = 5009,
  [5098] = 5098,
  [5099] = 3052,
  [5100] = 2675,
  [5101] = 3020,
  [5102] = 3021,
  [5103] = 3022,
  [5104] = 5104,
  [5105] = 2122,
  [5106] = 2124,
  [5107] = 3024,
  [5108] = 3039,
  [5109] = 4352,
  [5110] = 5110,
  [5111] = 5056,
  [5112] = 5009,
  [5113] = 3011,
  [5114] = 5114,
  [5115] = 3057,
  [5116] = 3033,
  [5117] = 2560,
  [5118] = 3053,
  [5119] = 5119,
  [5120] = 5056,
  [5121] = 5041,
  [5122] = 5122,
  [5123] = 3054,
  [5124] = 2128,
  [5125] = 5046,
  [5126] = 5126,
  [5127] = 2121,
  [5128] = 5056,
  [5129] = 5041,
  [5130] = 2135,
  [5131] = 3052,
  [5132] = 5056,
  [5133] = 2675,
  [5134] = 3020,
  [5135] = 3021,
  [5136] = 3022,
  [5137] = 5137,
  [5138] = 3024,
  [5139] = 3011,
  [5140] = 3057,
  [5141] = 3033,
  [5142] = 3053,
  [5143] = 4336,
  [5144] = 3054,
  [5145] = 2676,
  [5146] = 2681,
  [5147] = 5147,
  [5148] = 2136,
  [5149] = 2132,
  [5150] = 2163,
  [5151] = 5151,
  [5152] = 2133,
  [5153] = 2152,
  [5154] = 5154,
  [5155] = 5009,
  [5156] = 2632,
  [5157] = 2116,
  [5158] = 2138,
  [5159] = 5009,
  [5160] = 3019,
  [5161] = 3038,
  [5162] = 5041,
  [5163] = 5163,
  [5164] = 5164,
  [5165] = 5163,
  [5166] = 2123,
  [5167] = 2127,
  [5168] = 5046,
  [5169] = 2590,
  [5170] = 2142,
  [5171] = 2583,
  [5172] = 1870,
  [5173] = 2628,
  [5174] = 2131,
  [5175] = 3015,
  [5176] = 3018,
  [5177] = 3052,
  [5178] = 2120,
  [5179] = 3020,
  [5180] = 3021,
  [5181] = 3022,
  [5182] = 3024,
  [5183] = 3011,
  [5184] = 3057,
  [5185] = 3033,
  [5186] = 3053,
  [5187] = 3054,
  [5188] = 2148,
  [5189] = 5189,
  [5190] = 3036,
  [5191] = 3037,
  [5192] = 3038,
  [5193] = 3039,
  [5194] = 2169,
  [5195] = 2149,
  [5196] = 3016,
  [5197] = 2632,
  [5198] = 2169,
  [5199] = 5199,
  [5200] = 3019,
  [5201] = 5164,
  [5202] = 2154,
  [5203] = 5203,
  [5204] = 2115,
  [5205] = 5205,
  [5206] = 2125,
  [5207] = 2153,
  [5208] = 2156,
  [5209] = 2583,
  [5210] = 5031,
  [5211] = 2151,
  [5212] = 2129,
  [5213] = 4626,
  [5214] = 2146,
  [5215] = 2130,
  [5216] = 5009,
  [5217] = 2141,
  [5218] = 4352,
  [5219] = 4309,
  [5220] = 2145,
  [5221] = 4356,
  [5222] = 5009,
  [5223] = 3015,
  [5224] = 3038,
  [5225] = 5009,
  [5226] = 2160,
  [5227] = 5227,
  [5228] = 2123,
  [5229] = 3018,
  [5230] = 4942,
  [5231] = 3146,
  [5232] = 2127,
  [5233] = 3037,
  [5234] = 2627,
  [5235] = 2130,
  [5236] = 3016,
  [5237] = 5009,
  [5238] = 5199,
  [5239] = 5239,
  [5240] = 3052,
  [5241] = 2675,
  [5242] = 3020,
  [5243] = 3021,
  [5244] = 3022,
  [5245] = 3024,
  [5246] = 3011,
  [5247] = 3057,
  [5248] = 3033,
  [5249] = 2139,
  [5250] = 3053,
  [5251] = 5009,
  [5252] = 5009,
  [5253] = 3054,
  [5254] = 5254,
  [5255] = 5255,
  [5256] = 2278,
  [5257] = 5257,
  [5258] = 5257,
  [5259] = 2653,
  [5260] = 5260,
  [5261] = 5261,
  [5262] = 5262,
  [5263] = 5257,
  [5264] = 5264,
  [5265] = 5260,
  [5266] = 5266,
  [5267] = 5262,
  [5268] = 5268,
  [5269] = 5269,
  [5270] = 5257,
  [5271] = 5271,
  [5272] = 5255,
  [5273] = 5273,
  [5274] = 5268,
  [5275] = 5275,
  [5276] = 5276,
  [5277] = 5260,
  [5278] = 5278,
  [5279] = 5268,
  [5280] = 5257,
  [5281] = 5281,
  [5282] = 5262,
  [5283] = 5281,
  [5284] = 5268,
  [5285] = 967,
  [5286] = 5286,
  [5287] = 5287,
  [5288] = 5260,
  [5289] = 5266,
  [5290] = 5260,
  [5291] = 5266,
  [5292] = 5269,
  [5293] = 2621,
  [5294] = 5294,
  [5295] = 2622,
  [5296] = 5269,
  [5297] = 5269,
  [5298] = 5275,
  [5299] = 5266,
  [5300] = 5262,
  [5301] = 5255,
  [5302] = 5257,
  [5303] = 5303,
  [5304] = 967,
  [5305] = 5255,
  [5306] = 5264,
  [5307] = 5264,
  [5308] = 5266,
  [5309] = 5309,
  [5310] = 5276,
  [5311] = 5311,
  [5312] = 5268,
  [5313] = 5278,
  [5314] = 5257,
  [5315] = 5315,
  [5316] = 5255,
  [5317] = 5275,
  [5318] = 3695,
  [5319] = 5257,
  [5320] = 5275,
  [5321] = 5321,
  [5322] = 5322,
  [5323] = 5257,
  [5324] = 5324,
  [5325] = 5276,
  [5326] = 5266,
  [5327] = 5269,
  [5328] = 5328,
  [5329] = 5276,
  [5330] = 5268,
  [5331] = 5257,
  [5332] = 5278,
  [5333] = 5278,
  [5334] = 5278,
  [5335] = 5281,
  [5336] = 5269,
  [5337] = 2282,
  [5338] = 5266,
  [5339] = 5257,
  [5340] = 2653,
  [5341] = 5264,
  [5342] = 5342,
  [5343] = 5262,
  [5344] = 5344,
  [5345] = 5257,
  [5346] = 5346,
  [5347] = 5347,
  [5348] = 5268,
  [5349] = 5281,
  [5350] = 5275,
  [5351] = 5266,
  [5352] = 5271,
  [5353] = 5353,
  [5354] = 5354,
  [5355] = 5355,
  [5356] = 5269,
  [5357] = 5257,
  [5358] = 5264,
  [5359] = 5257,
  [5360] = 5268,
  [5361] = 5361,
  [5362] = 5362,
  [5363] = 5347,
  [5364] = 5268,
  [5365] = 5354,
  [5366] = 5260,
  [5367] = 5268,
  [5368] = 5368,
  [5369] = 5276,
  [5370] = 5370,
  [5371] = 5268,
  [5372] = 5309,
  [5373] = 5281,
  [5374] = 5281,
  [5375] = 5375,
  [5376] = 5375,
  [5377] = 5375,
  [5378] = 5375,
  [5379] = 5375,
  [5380] = 5375,
  [5381] = 5375,
  [5382] = 5375,
  [5383] = 2281,
  [5384] = 5260,
  [5385] = 5281,
  [5386] = 5328,
  [5387] = 2202,
  [5388] = 4309,
  [5389] = 2197,
  [5390] = 2203,
  [5391] = 3085,
  [5392] = 2210,
  [5393] = 2199,
  [5394] = 5394,
  [5395] = 2723,
  [5396] = 2205,
  [5397] = 5397,
  [5398] = 5398,
  [5399] = 2723,
  [5400] = 3146,
  [5401] = 3200,
  [5402] = 2189,
  [5403] = 4788,
  [5404] = 2462,
  [5405] = 2200,
  [5406] = 2206,
  [5407] = 1661,
  [5408] = 4336,
  [5409] = 1662,
  [5410] = 2201,
  [5411] = 1706,
  [5412] = 4352,
  [5413] = 4356,
  [5414] = 3200,
  [5415] = 3146,
  [5416] = 2195,
  [5417] = 2191,
  [5418] = 2819,
  [5419] = 2743,
  [5420] = 2785,
  [5421] = 2787,
  [5422] = 2773,
  [5423] = 2804,
  [5424] = 1700,
  [5425] = 2800,
  [5426] = 2741,
  [5427] = 1699,
  [5428] = 2779,
  [5429] = 2817,
  [5430] = 2756,
  [5431] = 2830,
  [5432] = 2772,
  [5433] = 2833,
  [5434] = 2820,
  [5435] = 2757,
  [5436] = 2759,
  [5437] = 2784,
  [5438] = 5438,
  [5439] = 2741,
  [5440] = 2783,
  [5441] = 1694,
  [5442] = 2777,
  [5443] = 2807,
  [5444] = 5444,
  [5445] = 2758,
  [5446] = 2812,
  [5447] = 2761,
  [5448] = 2777,
  [5449] = 2811,
  [5450] = 2775,
  [5451] = 2738,
  [5452] = 2797,
  [5453] = 2807,
  [5454] = 2809,
  [5455] = 5444,
  [5456] = 2748,
  [5457] = 2779,
  [5458] = 2775,
  [5459] = 2778,
  [5460] = 2783,
  [5461] = 2748,
  [5462] = 2778,
  [5463] = 5444,
  [5464] = 138,
  [5465] = 2799,
  [5466] = 5444,
  [5467] = 1692,
  [5468] = 5468,
  [5469] = 5444,
  [5470] = 2785,
  [5471] = 2787,
  [5472] = 5444,
  [5473] = 2758,
  [5474] = 2761,
  [5475] = 1693,
  [5476] = 2738,
  [5477] = 2784,
  [5478] = 2797,
  [5479] = 2809,
  [5480] = 2756,
  [5481] = 2184,
  [5482] = 2282,
  [5483] = 5444,
  [5484] = 2786,
  [5485] = 5485,
  [5486] = 2757,
  [5487] = 2184,
  [5488] = 2829,
  [5489] = 2830,
  [5490] = 1701,
  [5491] = 1702,
  [5492] = 2302,
  [5493] = 2303,
  [5494] = 2301,
  [5495] = 2307,
  [5496] = 2289,
  [5497] = 2296,
  [5498] = 2291,
  [5499] = 2772,
  [5500] = 2316,
  [5501] = 2306,
  [5502] = 2311,
  [5503] = 2310,
  [5504] = 2312,
  [5505] = 2805,
  [5506] = 2800,
  [5507] = 2792,
  [5508] = 2798,
  [5509] = 2168,
  [5510] = 2759,
  [5511] = 2743,
  [5512] = 2817,
  [5513] = 1689,
  [5514] = 1691,
  [5515] = 2799,
  [5516] = 2811,
  [5517] = 2773,
  [5518] = 2833,
  [5519] = 2804,
  [5520] = 2282,
  [5521] = 1696,
  [5522] = 1690,
  [5523] = 2786,
  [5524] = 5438,
  [5525] = 1695,
  [5526] = 1688,
  [5527] = 5527,
  [5528] = 2812,
  [5529] = 139,
  [5530] = 2742,
  [5531] = 2829,
  [5532] = 2792,
  [5533] = 5533,
  [5534] = 2805,
  [5535] = 2742,
  [5536] = 2798,
  [5537] = 2820,
  [5538] = 2827,
  [5539] = 2827,
  [5540] = 1703,
  [5541] = 2168,
  [5542] = 1697,
  [5543] = 2819,
  [5544] = 5438,
  [5545] = 5545,
  [5546] = 5546,
  [5547] = 5438,
  [5548] = 5545,
  [5549] = 5545,
  [5550] = 5545,
  [5551] = 5551,
  [5552] = 5438,
  [5553] = 5438,
  [5554] = 5545,
  [5555] = 5545,
  [5556] = 5438,
  [5557] = 5545,
  [5558] = 5438,
  [5559] = 5438,
  [5560] = 5560,
  [5561] = 5438,
  [5562] = 5438,
  [5563] = 3268,
  [5564] = 5438,
  [5565] = 1706,
  [5566] = 3307,
  [5567] = 5438,
  [5568] = 5438,
  [5569] = 2207,
  [5570] = 5438,
  [5571] = 5438,
  [5572] = 5572,
  [5573] = 5438,
  [5574] = 5574,
  [5575] = 5438,
  [5576] = 2683,
  [5577] = 5577,
  [5578] = 5578,
  [5579] = 5579,
  [5580] = 5438,
  [5581] = 5579,
  [5582] = 5578,
  [5583] = 5438,
  [5584] = 5578,
  [5585] = 5438,
  [5586] = 5438,
  [5587] = 5579,
  [5588] = 5579,
  [5589] = 5438,
  [5590] = 5438,
  [5591] = 5579,
  [5592] = 5578,
  [5593] = 5578,
  [5594] = 5578,
  [5595] = 5579,
  [5596] = 5578,
  [5597] = 5578,
  [5598] = 5579,
  [5599] = 5438,
  [5600] = 5579,
  [5601] = 2688,
  [5602] = 5438,
  [5603] = 5578,
  [5604] = 5578,
  [5605] = 5579,
  [5606] = 5579,
  [5607] = 5607,
  [5608] = 5607,
  [5609] = 5609,
  [5610] = 5607,
  [5611] = 5607,
  [5612] = 5578,
  [5613] = 5609,
  [5614] = 5579,
  [5615] = 5578,
  [5616] = 5438,
  [5617] = 5609,
  [5618] = 5579,
  [5619] = 5578,
  [5620] = 5609,
  [5621] = 5609,
  [5622] = 5607,
  [5623] = 5607,
  [5624] = 5578,
  [5625] = 5609,
  [5626] = 5609,
  [5627] = 5609,
  [5628] = 5607,
  [5629] = 5607,
  [5630] = 5579,
  [5631] = 5579,
  [5632] = 5607,
  [5633] = 5609,
  [5634] = 5578,
  [5635] = 5579,
  [5636] = 5607,
  [5637] = 5579,
  [5638] = 5438,
  [5639] = 5578,
  [5640] = 5579,
  [5641] = 5438,
  [5642] = 5438,
  [5643] = 5609,
  [5644] = 5578,
  [5645] = 5607,
  [5646] = 5609,
  [5647] = 5578,
  [5648] = 5579,
  [5649] = 5649,
  [5650] = 5650,
  [5651] = 5651,
  [5652] = 5652,
  [5653] = 5650,
  [5654] = 5651,
  [5655] = 5652,
  [5656] = 5656,
  [5657] = 5657,
  [5658] = 5658,
  [5659] = 5659,
  [5660] = 5656,
  [5661] = 5658,
  [5662] = 5650,
  [5663] = 5651,
  [5664] = 5652,
  [5665] = 5657,
  [5666] = 5659,
  [5667] = 5656,
  [5668] = 5658,
  [5669] = 5650,
  [5670] = 5651,
  [5671] = 5652,
  [5672] = 5579,
  [5673] = 5578,
  [5674] = 5659,
  [5675] = 5656,
  [5676] = 5658,
  [5677] = 5650,
  [5678] = 5651,
  [5679] = 5652,
  [5680] = 5649,
  [5681] = 5659,
  [5682] = 5656,
  [5683] = 5658,
  [5684] = 5650,
  [5685] = 5651,
  [5686] = 5652,
  [5687] = 5649,
  [5688] = 5688,
  [5689] = 5657,
  [5690] = 5649,
  [5691] = 5688,
  [5692] = 5657,
  [5693] = 5649,
  [5694] = 5688,
  [5695] = 5657,
  [5696] = 5649,
  [5697] = 5688,
  [5698] = 5657,
  [5699] = 5579,
  [5700] = 5578,
  [5701] = 5649,
  [5702] = 5657,
  [5703] = 5649,
  [5704] = 5688,
  [5705] = 5649,
  [5706] = 5688,
  [5707] = 5657,
  [5708] = 5688,
  [5709] = 5649,
  [5710] = 5688,
  [5711] = 5657,
  [5712] = 5657,
  [5713] = 5649,
  [5714] = 5688,
  [5715] = 5657,
  [5716] = 5649,
  [5717] = 5688,
  [5718] = 5657,
  [5719] = 5649,
  [5720] = 5688,
  [5721] = 5657,
  [5722] = 5649,
  [5723] = 5659,
  [5724] = 5656,
  [5725] = 5658,
  [5726] = 5688,
  [5727] = 5649,
  [5728] = 5688,
  [5729] = 5657,
  [5730] = 5650,
  [5731] = 5651,
  [5732] = 5652,
  [5733] = 5659,
  [5734] = 5649,
  [5735] = 5688,
  [5736] = 5657,
  [5737] = 5657,
  [5738] = 2548,
  [5739] = 5649,
  [5740] = 5688,
  [5741] = 5657,
  [5742] = 5649,
  [5743] = 5688,
  [5744] = 5657,
  [5745] = 5649,
  [5746] = 5688,
  [5747] = 5657,
  [5748] = 5688,
  [5749] = 5649,
  [5750] = 5688,
  [5751] = 5657,
  [5752] = 5659,
  [5753] = 5656,
  [5754] = 5658,
  [5755] = 5688,
  [5756] = 5756,
  [5757] = 5756,
  [5758] = 5758,
  [5759] = 5756,
  [5760] = 5758,
  [5761] = 5579,
  [5762] = 5756,
  [5763] = 5756,
  [5764] = 5764,
  [5765] = 5758,
  [5766] = 5758,
  [5767] = 5756,
  [5768] = 5768,
  [5769] = 5578,
  [5770] = 5579,
  [5771] = 5764,
  [5772] = 5756,
  [5773] = 5768,
  [5774] = 5579,
  [5775] = 5758,
  [5776] = 5756,
  [5777] = 5758,
  [5778] = 5764,
  [5779] = 5756,
  [5780] = 5768,
  [5781] = 5781,
  [5782] = 5756,
  [5783] = 5756,
  [5784] = 5768,
  [5785] = 5578,
  [5786] = 5758,
  [5787] = 5768,
  [5788] = 5758,
  [5789] = 5768,
  [5790] = 5764,
  [5791] = 5768,
  [5792] = 5764,
  [5793] = 5758,
  [5794] = 5781,
  [5795] = 5756,
  [5796] = 5758,
  [5797] = 5768,
  [5798] = 5781,
  [5799] = 5799,
  [5800] = 5758,
  [5801] = 5801,
  [5802] = 5758,
  [5803] = 5756,
  [5804] = 5758,
  [5805] = 5579,
  [5806] = 5758,
  [5807] = 5764,
  [5808] = 5808,
  [5809] = 5756,
  [5810] = 5768,
  [5811] = 5764,
  [5812] = 5758,
  [5813] = 5758,
  [5814] = 5764,
  [5815] = 5578,
  [5816] = 5758,
  [5817] = 5758,
  [5818] = 5758,
  [5819] = 5578,
  [5820] = 5756,
  [5821] = 5781,
  [5822] = 5822,
  [5823] = 5578,
  [5824] = 5758,
  [5825] = 5756,
  [5826] = 5756,
  [5827] = 5579,
  [5828] = 5756,
  [5829] = 5829,
  [5830] = 5756,
  [5831] = 5756,
  [5832] = 5579,
  [5833] = 5768,
  [5834] = 5764,
  [5835] = 5764,
  [5836] = 5578,
  [5837] = 5781,
  [5838] = 5768,
  [5839] = 5758,
  [5840] = 5764,
  [5841] = 5758,
  [5842] = 5842,
  [5843] = 5843,
  [5844] = 5843,
  [5845] = 5845,
  [5846] = 5846,
  [5847] = 5845,
  [5848] = 5848,
  [5849] = 5848,
  [5850] = 5578,
  [5851] = 5843,
  [5852] = 5579,
  [5853] = 5853,
  [5854] = 5845,
  [5855] = 5853,
  [5856] = 5846,
  [5857] = 5848,
  [5858] = 5848,
  [5859] = 5848,
  [5860] = 5579,
  [5861] = 5848,
  [5862] = 5843,
  [5863] = 5845,
  [5864] = 5864,
  [5865] = 5843,
  [5866] = 5578,
  [5867] = 5845,
  [5868] = 5864,
  [5869] = 5578,
  [5870] = 5579,
  [5871] = 5578,
  [5872] = 5872,
  [5873] = 5579,
  [5874] = 5842,
  [5875] = 5875,
  [5876] = 5845,
  [5877] = 5877,
  [5878] = 5843,
  [5879] = 5843,
  [5880] = 5864,
  [5881] = 5864,
  [5882] = 5848,
  [5883] = 5845,
  [5884] = 5842,
  [5885] = 5842,
  [5886] = 5846,
  [5887] = 5846,
  [5888] = 5846,
  [5889] = 5853,
  [5890] = 5853,
  [5891] = 5853,
  [5892] = 5846,
  [5893] = 5846,
  [5894] = 5853,
  [5895] = 5853,
  [5896] = 5853,
  [5897] = 5842,
  [5898] = 5842,
  [5899] = 5846,
  [5900] = 5842,
  [5901] = 5842,
  [5902] = 5853,
  [5903] = 5853,
  [5904] = 5853,
  [5905] = 5842,
  [5906] = 5842,
  [5907] = 5842,
  [5908] = 5842,
  [5909] = 5846,
  [5910] = 5846,
  [5911] = 5842,
  [5912] = 5846,
  [5913] = 5846,
  [5914] = 5853,
  [5915] = 5842,
  [5916] = 5846,
  [5917] = 5853,
  [5918] = 5846,
  [5919] = 5853,
  [5920] = 5842,
  [5921] = 5853,
  [5922] = 5842,
  [5923] = 5846,
  [5924] = 5853,
  [5925] = 5842,
  [5926] = 5846,
  [5927] = 5853,
  [5928] = 5853,
  [5929] = 5842,
  [5930] = 5846,
  [5931] = 5846,
  [5932] = 5932,
  [5933] = 5846,
  [5934] = 5853,
  [5935] = 5932,
  [5936] = 5842,
  [5937] = 5932,
  [5938] = 5846,
  [5939] = 5932,
  [5940] = 5932,
  [5941] = 5853,
  [5942] = 5842,
  [5943] = 5943,
  [5944] = 5943,
  [5945] = 5842,
  [5946] = 5846,
  [5947] = 5943,
  [5948] = 5853,
  [5949] = 5949,
  [5950] = 5943,
  [5951] = 5846,
  [5952] = 5949,
  [5953] = 5943,
  [5954] = 5853,
  [5955] = 5853,
  [5956] = 5842,
  [5957] = 5943,
  [5958] = 5846,
  [5959] = 5853,
  [5960] = 5842,
  [5961] = 5943,
  [5962] = 5943,
  [5963] = 5949,
  [5964] = 5846,
  [5965] = 5842,
  [5966] = 5853,
  [5967] = 5853,
  [5968] = 5846,
  [5969] = 5943,
  [5970] = 5846,
  [5971] = 5842,
  [5972] = 5842,
  [5973] = 5846,
  [5974] = 5842,
  [5975] = 5975,
  [5976] = 5976,
  [5977] = 5846,
  [5978] = 5853,
  [5979] = 5975,
  [5980] = 5980,
  [5981] = 5853,
  [5982] = 5982,
  [5983] = 5842,
  [5984] = 5846,
  [5985] = 5853,
  [5986] = 5853,
  [5987] = 5842,
  [5988] = 5842,
  [5989] = 5975,
  [5990] = 5846,
  [5991] = 5949,
  [5992] = 5992,
  [5993] = 5949,
  [5994] = 5994,
  [5995] = 5995,
  [5996] = 5996,
  [5997] = 5997,
  [5998] = 5996,
  [5999] = 5994,
  [6000] = 6000,
  [6001] = 5997,
  [6002] = 2168,
  [6003] = 5997,
  [6004] = 6004,
  [6005] = 6005,
  [6006] = 5996,
  [6007] = 5997,
  [6008] = 5997,
  [6009] = 6005,
  [6010] = 6005,
  [6011] = 6011,
  [6012] = 5982,
  [6013] = 6013,
  [6014] = 6013,
  [6015] = 6013,
  [6016] = 6005,
  [6017] = 6013,
  [6018] = 5997,
  [6019] = 6013,
  [6020] = 6013,
  [6021] = 6013,
  [6022] = 6013,
  [6023] = 6013,
  [6024] = 5997,
  [6025] = 6013,
  [6026] = 5997,
  [6027] = 6027,
  [6028] = 6028,
  [6029] = 6013,
  [6030] = 6013,
  [6031] = 5976,
  [6032] = 6032,
  [6033] = 2184,
  [6034] = 5997,
  [6035] = 5997,
  [6036] = 6013,
  [6037] = 5997,
  [6038] = 6005,
  [6039] = 6005,
  [6040] = 5997,
  [6041] = 6005,
  [6042] = 6005,
  [6043] = 6013,
  [6044] = 5995,
  [6045] = 5997,
  [6046] = 5997,
  [6047] = 5949,
  [6048] = 6013,
  [6049] = 5997,
  [6050] = 6005,
  [6051] = 6032,
  [6052] = 5997,
  [6053] = 6013,
  [6054] = 6054,
  [6055] = 5997,
  [6056] = 6027,
  [6057] = 6013,
  [6058] = 6013,
  [6059] = 6054,
  [6060] = 5997,
  [6061] = 6061,
  [6062] = 6062,
  [6063] = 5994,
  [6064] = 1702,
  [6065] = 6065,
  [6066] = 1696,
  [6067] = 1690,
  [6068] = 6068,
  [6069] = 1699,
  [6070] = 6070,
  [6071] = 6071,
  [6072] = 6072,
  [6073] = 6073,
  [6074] = 6065,
  [6075] = 6075,
  [6076] = 6073,
  [6077] = 6077,
  [6078] = 6062,
  [6079] = 6071,
  [6080] = 6072,
  [6081] = 6073,
  [6082] = 6077,
  [6083] = 6062,
  [6084] = 6073,
  [6085] = 6077,
  [6086] = 6062,
  [6087] = 6070,
  [6088] = 6065,
  [6089] = 6071,
  [6090] = 6071,
  [6091] = 6072,
  [6092] = 6011,
  [6093] = 6072,
  [6094] = 6073,
  [6095] = 6077,
  [6096] = 6062,
  [6097] = 6071,
  [6098] = 6072,
  [6099] = 6073,
  [6100] = 6077,
  [6101] = 6077,
  [6102] = 6062,
  [6103] = 6065,
  [6104] = 6071,
  [6105] = 6072,
  [6106] = 6071,
  [6107] = 6072,
  [6108] = 6073,
  [6109] = 6077,
  [6110] = 6062,
  [6111] = 6071,
  [6112] = 6072,
  [6113] = 6073,
  [6114] = 6062,
  [6115] = 6054,
  [6116] = 6116,
  [6117] = 6077,
  [6118] = 6062,
  [6119] = 6065,
  [6120] = 6071,
  [6121] = 6072,
  [6122] = 2184,
  [6123] = 6073,
  [6124] = 6077,
  [6125] = 6062,
  [6126] = 6126,
  [6127] = 6068,
  [6128] = 6071,
  [6129] = 6072,
  [6130] = 6073,
  [6131] = 6032,
  [6132] = 6065,
  [6133] = 6077,
  [6134] = 6062,
  [6135] = 139,
  [6136] = 6071,
  [6137] = 6072,
  [6138] = 6073,
  [6139] = 138,
  [6140] = 6073,
  [6141] = 6077,
  [6142] = 6062,
  [6143] = 6071,
  [6144] = 6072,
  [6145] = 6077,
  [6146] = 6146,
  [6147] = 6032,
  [6148] = 1703,
  [6149] = 2168,
  [6150] = 1697,
  [6151] = 6077,
  [6152] = 6062,
  [6153] = 6071,
  [6154] = 6072,
  [6155] = 6073,
  [6156] = 6054,
  [6157] = 6077,
  [6158] = 6062,
  [6159] = 6071,
  [6160] = 6072,
  [6161] = 6073,
  [6162] = 6077,
  [6163] = 6062,
  [6164] = 6071,
  [6165] = 6072,
  [6166] = 6073,
  [6167] = 6027,
  [6168] = 5995,
  [6169] = 6077,
  [6170] = 6062,
  [6171] = 5994,
  [6172] = 6077,
  [6173] = 6071,
  [6174] = 6072,
  [6175] = 6062,
  [6176] = 6073,
  [6177] = 6177,
  [6178] = 6178,
  [6179] = 6065,
  [6180] = 6027,
  [6181] = 6068,
  [6182] = 6075,
  [6183] = 6070,
  [6184] = 6071,
  [6185] = 6072,
  [6186] = 6077,
  [6187] = 6075,
  [6188] = 6062,
  [6189] = 6073,
  [6190] = 5949,
  [6191] = 6077,
  [6192] = 6062,
  [6193] = 6071,
  [6194] = 6072,
  [6195] = 6195,
  [6196] = 6073,
  [6197] = 6197,
  [6198] = 5995,
  [6199] = 6077,
  [6200] = 6071,
  [6201] = 6062,
  [6202] = 1700,
  [6203] = 6071,
  [6204] = 6072,
  [6205] = 6072,
  [6206] = 1694,
  [6207] = 6073,
  [6208] = 1701,
  [6209] = 1689,
  [6210] = 1691,
  [6211] = 1692,
  [6212] = 1693,
  [6213] = 1695,
  [6214] = 1688,
  [6215] = 6215,
  [6216] = 6073,
  [6217] = 6217,
  [6218] = 6218,
  [6219] = 6219,
  [6220] = 6220,
  [6221] = 5949,
  [6222] = 6218,
  [6223] = 2548,
  [6224] = 6224,
  [6225] = 6000,
  [6226] = 5949,
  [6227] = 6219,
  [6228] = 6220,
  [6229] = 5949,
  [6230] = 6218,
  [6231] = 6231,
  [6232] = 6232,
  [6233] = 6233,
  [6234] = 6234,
  [6235] = 6219,
  [6236] = 6236,
  [6237] = 6237,
  [6238] = 6238,
  [6239] = 6239,
  [6240] = 6240,
  [6241] = 6241,
  [6242] = 6242,
  [6243] = 6243,
  [6244] = 6220,
  [6245] = 6218,
  [6246] = 6219,
  [6247] = 6247,
  [6248] = 6248,
  [6249] = 6249,
  [6250] = 6250,
  [6251] = 6251,
  [6252] = 6252,
  [6253] = 6253,
  [6254] = 6254,
  [6255] = 6255,
  [6256] = 6256,
  [6257] = 6257,
  [6258] = 6218,
  [6259] = 6259,
  [6260] = 6219,
  [6261] = 6220,
  [6262] = 6262,
  [6263] = 6218,
  [6264] = 6264,
  [6265] = 6265,
  [6266] = 6219,
  [6267] = 6267,
  [6268] = 6220,
  [6269] = 6218,
  [6270] = 6219,
  [6271] = 6271,
  [6272] = 6028,
  [6273] = 6273,
  [6274] = 6219,
  [6275] = 6220,
  [6276] = 6218,
  [6277] = 6220,
  [6278] = 6278,
  [6279] = 6219,
  [6280] = 6280,
  [6281] = 6220,
  [6282] = 6219,
  [6283] = 6283,
  [6284] = 6219,
  [6285] = 6219,
  [6286] = 6219,
  [6287] = 5949,
  [6288] = 6288,
  [6289] = 6289,
  [6290] = 6290,
  [6291] = 6219,
  [6292] = 6220,
  [6293] = 6220,
  [6294] = 6294,
  [6295] = 6218,
  [6296] = 6218,
  [6297] = 6297,
  [6298] = 6220,
  [6299] = 6299,
  [6300] = 6300,
  [6301] = 6301,
  [6302] = 6004,
  [6303] = 6297,
  [6304] = 6299,
  [6305] = 6219,
  [6306] = 6301,
  [6307] = 6297,
  [6308] = 6299,
  [6309] = 6300,
  [6310] = 6301,
  [6311] = 6297,
  [6312] = 6299,
  [6313] = 6300,
  [6314] = 6301,
  [6315] = 6218,
  [6316] = 6316,
  [6317] = 6290,
  [6318] = 6290,
  [6319] = 6220,
  [6320] = 6294,
  [6321] = 6218,
  [6322] = 6297,
  [6323] = 6299,
  [6324] = 6324,
  [6325] = 6300,
  [6326] = 6301,
  [6327] = 6297,
  [6328] = 6299,
  [6329] = 6300,
  [6330] = 6301,
  [6331] = 6288,
  [6332] = 6289,
  [6333] = 6290,
  [6334] = 6334,
  [6335] = 6294,
  [6336] = 6294,
  [6337] = 6290,
  [6338] = 6294,
  [6339] = 3200,
  [6340] = 6290,
  [6341] = 6294,
  [6342] = 6290,
  [6343] = 6294,
  [6344] = 6290,
  [6345] = 6294,
  [6346] = 6290,
  [6347] = 6294,
  [6348] = 6283,
  [6349] = 6220,
  [6350] = 6218,
  [6351] = 6271,
  [6352] = 6352,
  [6353] = 6353,
  [6354] = 6354,
  [6355] = 6247,
  [6356] = 6248,
  [6357] = 6249,
  [6358] = 6250,
  [6359] = 6251,
  [6360] = 6218,
  [6361] = 6252,
  [6362] = 6253,
  [6363] = 6254,
  [6364] = 6283,
  [6365] = 6220,
  [6366] = 6218,
  [6367] = 6271,
  [6368] = 6283,
  [6369] = 6255,
  [6370] = 6256,
  [6371] = 6220,
  [6372] = 6300,
  [6373] = 6373,
  [6374] = 6278,
  [6375] = 6375,
  [6376] = 6238,
  [6377] = 6239,
  [6378] = 6378,
  [6379] = 6379,
  [6380] = 6380,
  [6381] = 6240,
  [6382] = 6241,
  [6383] = 3200,
  [6384] = 6384,
  [6385] = 6385,
  [6386] = 6386,
  [6387] = 6273,
  [6388] = 6388,
  [6389] = 6389,
  [6390] = 6390,
  [6391] = 6378,
  [6392] = 6392,
  [6393] = 6378,
  [6394] = 6353,
  [6395] = 6379,
  [6396] = 6396,
  [6397] = 6397,
  [6398] = 6378,
  [6399] = 6399,
  [6400] = 6379,
  [6401] = 6401,
  [6402] = 6354,
  [6403] = 6242,
  [6404] = 6243,
  [6405] = 6405,
  [6406] = 6385,
  [6407] = 6407,
  [6408] = 6408,
  [6409] = 6385,
  [6410] = 6386,
  [6411] = 6385,
  [6412] = 6412,
  [6413] = 6413,
  [6414] = 6414,
  [6415] = 6224,
  [6416] = 1992,
  [6417] = 6378,
  [6418] = 6379,
  [6419] = 6419,
  [6420] = 6379,
  [6421] = 6421,
  [6422] = 6378,
  [6423] = 2018,
  [6424] = 6386,
  [6425] = 6425,
  [6426] = 6426,
  [6427] = 6427,
  [6428] = 6379,
  [6429] = 6352,
  [6430] = 6397,
  [6431] = 5949,
  [6432] = 6432,
  [6433] = 6433,
  [6434] = 6434,
  [6435] = 6388,
  [6436] = 6379,
  [6437] = 2697,
  [6438] = 6438,
  [6439] = 6439,
  [6440] = 6440,
  [6441] = 6379,
  [6442] = 6442,
  [6443] = 6443,
  [6444] = 6217,
  [6445] = 6378,
  [6446] = 6446,
  [6447] = 5949,
  [6448] = 6232,
  [6449] = 6397,
  [6450] = 6397,
  [6451] = 6233,
  [6452] = 6234,
  [6453] = 6385,
  [6454] = 6454,
  [6455] = 6236,
  [6456] = 6237,
  [6457] = 6457,
  [6458] = 2423,
  [6459] = 2168,
  [6460] = 1696,
  [6461] = 1690,
  [6462] = 6462,
  [6463] = 1700,
  [6464] = 2793,
  [6465] = 6054,
  [6466] = 2745,
  [6467] = 6061,
  [6468] = 6468,
  [6469] = 1694,
  [6470] = 5995,
  [6471] = 2548,
  [6472] = 1699,
  [6473] = 2184,
  [6474] = 2449,
  [6475] = 2466,
  [6476] = 1701,
  [6477] = 6054,
  [6478] = 1689,
  [6479] = 1691,
  [6480] = 6027,
  [6481] = 5995,
  [6482] = 1703,
  [6483] = 6483,
  [6484] = 1697,
  [6485] = 6485,
  [6486] = 806,
  [6487] = 6297,
  [6488] = 6300,
  [6489] = 6301,
  [6490] = 5994,
  [6491] = 6297,
  [6492] = 6299,
  [6493] = 6300,
  [6494] = 6301,
  [6495] = 6485,
  [6496] = 6496,
  [6497] = 1702,
  [6498] = 6498,
  [6499] = 5994,
  [6500] = 6116,
  [6501] = 6027,
  [6502] = 5949,
  [6503] = 2467,
  [6504] = 6485,
  [6505] = 805,
  [6506] = 1692,
  [6507] = 1693,
  [6508] = 1695,
  [6509] = 1688,
  [6510] = 6485,
  [6511] = 2722,
  [6512] = 139,
  [6513] = 138,
  [6514] = 6032,
  [6515] = 6485,
  [6516] = 6032,
  [6517] = 2421,
  [6518] = 6299,
  [6519] = 6519,
  [6520] = 6300,
  [6521] = 6301,
  [6522] = 5949,
  [6523] = 6523,
  [6524] = 6523,
  [6525] = 2587,
  [6526] = 6526,
  [6527] = 2750,
  [6528] = 6526,
  [6529] = 6523,
  [6530] = 6530,
  [6531] = 2187,
  [6532] = 6526,
  [6533] = 6526,
  [6534] = 6297,
  [6535] = 6535,
  [6536] = 6297,
  [6537] = 6523,
  [6538] = 6523,
  [6539] = 6539,
  [6540] = 967,
  [6541] = 6526,
  [6542] = 6542,
  [6543] = 6543,
  [6544] = 6523,
  [6545] = 6526,
  [6546] = 6523,
  [6547] = 2204,
  [6548] = 2208,
  [6549] = 6297,
  [6550] = 6299,
  [6551] = 6300,
  [6552] = 6301,
  [6553] = 6297,
  [6554] = 6299,
  [6555] = 6300,
  [6556] = 6301,
  [6557] = 6557,
  [6558] = 6526,
  [6559] = 6523,
  [6560] = 6523,
  [6561] = 6526,
  [6562] = 5949,
  [6563] = 6519,
  [6564] = 6523,
  [6565] = 6523,
  [6566] = 6299,
  [6567] = 6567,
  [6568] = 6299,
  [6569] = 6526,
  [6570] = 6570,
  [6571] = 6523,
  [6572] = 6526,
  [6573] = 6526,
  [6574] = 6526,
  [6575] = 6300,
  [6576] = 6301,
  [6577] = 6577,
  [6578] = 6427,
  [6579] = 6577,
  [6580] = 6375,
  [6581] = 6577,
  [6582] = 2837,
  [6583] = 6577,
  [6584] = 6389,
  [6585] = 5949,
  [6586] = 2597,
  [6587] = 6027,
  [6588] = 6588,
  [6589] = 6297,
  [6590] = 6590,
  [6591] = 2762,
  [6592] = 6413,
  [6593] = 2763,
  [6594] = 2764,
  [6595] = 2765,
  [6596] = 6300,
  [6597] = 2766,
  [6598] = 6577,
  [6599] = 6577,
  [6600] = 6396,
  [6601] = 6408,
  [6602] = 6426,
  [6603] = 2767,
  [6604] = 2184,
  [6605] = 6412,
  [6606] = 6301,
  [6607] = 6607,
  [6608] = 2589,
  [6609] = 6609,
  [6610] = 6610,
  [6611] = 6611,
  [6612] = 6612,
  [6613] = 6613,
  [6614] = 6614,
  [6615] = 6577,
  [6616] = 6577,
  [6617] = 6617,
  [6618] = 6392,
  [6619] = 6619,
  [6620] = 6620,
  [6621] = 6621,
  [6622] = 6622,
  [6623] = 6590,
  [6624] = 6609,
  [6625] = 6625,
  [6626] = 2168,
  [6627] = 6627,
  [6628] = 6577,
  [6629] = 6612,
  [6630] = 6373,
  [6631] = 6631,
  [6632] = 6617,
  [6633] = 5994,
  [6634] = 6433,
  [6635] = 6054,
  [6636] = 6432,
  [6637] = 6613,
  [6638] = 6032,
  [6639] = 6620,
  [6640] = 6434,
  [6641] = 6300,
  [6642] = 5995,
  [6643] = 2595,
  [6644] = 2599,
  [6645] = 2601,
  [6646] = 2602,
  [6647] = 6577,
  [6648] = 6590,
  [6649] = 6419,
  [6650] = 6027,
  [6651] = 6032,
  [6652] = 6607,
  [6653] = 2614,
  [6654] = 5995,
  [6655] = 6577,
  [6656] = 6414,
  [6657] = 6577,
  [6658] = 6622,
  [6659] = 6425,
  [6660] = 6660,
  [6661] = 6609,
  [6662] = 6607,
  [6663] = 6299,
  [6664] = 6446,
  [6665] = 6577,
  [6666] = 6577,
  [6667] = 6457,
  [6668] = 5994,
  [6669] = 6577,
  [6670] = 2591,
  [6671] = 6299,
  [6672] = 6577,
  [6673] = 6673,
  [6674] = 6577,
  [6675] = 6612,
  [6676] = 6577,
  [6677] = 6677,
  [6678] = 6613,
  [6679] = 6577,
  [6680] = 6577,
  [6681] = 6617,
  [6682] = 6054,
  [6683] = 5949,
  [6684] = 6620,
  [6685] = 6297,
  [6686] = 6577,
  [6687] = 6622,
  [6688] = 2579,
  [6689] = 6438,
  [6690] = 2593,
  [6691] = 2600,
  [6692] = 6439,
  [6693] = 6443,
  [6694] = 6301,
  [6695] = 6300,
  [6696] = 6696,
  [6697] = 6696,
  [6698] = 6300,
  [6699] = 6699,
  [6700] = 6700,
  [6701] = 6701,
  [6702] = 6702,
  [6703] = 6696,
  [6704] = 6301,
  [6705] = 6300,
  [6706] = 6300,
  [6707] = 6301,
  [6708] = 6301,
  [6709] = 6297,
  [6710] = 6710,
  [6711] = 6711,
  [6712] = 6712,
  [6713] = 6713,
  [6714] = 6299,
  [6715] = 6710,
  [6716] = 6297,
  [6717] = 6710,
  [6718] = 6300,
  [6719] = 6301,
  [6720] = 6699,
  [6721] = 6699,
  [6722] = 6699,
  [6723] = 6301,
  [6724] = 6724,
  [6725] = 6724,
  [6726] = 6300,
  [6727] = 6712,
  [6728] = 6728,
  [6729] = 6724,
  [6730] = 6710,
  [6731] = 6731,
  [6732] = 6710,
  [6733] = 6733,
  [6734] = 6702,
  [6735] = 2358,
  [6736] = 6297,
  [6737] = 6299,
  [6738] = 6300,
  [6739] = 6301,
  [6740] = 6297,
  [6741] = 6699,
  [6742] = 6710,
  [6743] = 6743,
  [6744] = 6710,
  [6745] = 6724,
  [6746] = 6746,
  [6747] = 6747,
  [6748] = 6748,
  [6749] = 6299,
  [6750] = 6750,
  [6751] = 6297,
  [6752] = 6299,
  [6753] = 6300,
  [6754] = 6696,
  [6755] = 6301,
  [6756] = 6699,
  [6757] = 6757,
  [6758] = 6724,
  [6759] = 6299,
  [6760] = 6710,
  [6761] = 6761,
  [6762] = 6699,
  [6763] = 6299,
  [6764] = 6696,
  [6765] = 6700,
  [6766] = 6724,
  [6767] = 6700,
  [6768] = 6301,
  [6769] = 6724,
  [6770] = 6700,
  [6771] = 6699,
  [6772] = 6700,
  [6773] = 6747,
  [6774] = 6710,
  [6775] = 6700,
  [6776] = 6710,
  [6777] = 6724,
  [6778] = 6710,
  [6779] = 6699,
  [6780] = 6297,
  [6781] = 6700,
  [6782] = 6297,
  [6783] = 6710,
  [6784] = 6724,
  [6785] = 6297,
  [6786] = 6733,
  [6787] = 6750,
  [6788] = 6299,
  [6789] = 6299,
  [6790] = 6790,
  [6791] = 6791,
  [6792] = 6054,
  [6793] = 6790,
  [6794] = 6027,
  [6795] = 6795,
  [6796] = 2168,
  [6797] = 5995,
  [6798] = 5994,
  [6799] = 6032,
  [6800] = 6054,
  [6801] = 6027,
  [6802] = 5995,
  [6803] = 5994,
  [6804] = 6297,
  [6805] = 6299,
  [6806] = 6300,
  [6807] = 6301,
  [6808] = 6032,
  [6809] = 6054,
  [6810] = 6027,
  [6811] = 5995,
  [6812] = 5994,
  [6813] = 6790,
  [6814] = 6814,
  [6815] = 6297,
  [6816] = 6299,
  [6817] = 6300,
  [6818] = 6301,
  [6819] = 6790,
  [6820] = 6790,
  [6821] = 6821,
  [6822] = 6822,
  [6823] = 6790,
  [6824] = 6790,
  [6825] = 6822,
  [6826] = 6822,
  [6827] = 6822,
  [6828] = 2273,
  [6829] = 6790,
  [6830] = 2421,
  [6831] = 6814,
  [6832] = 6814,
  [6833] = 6613,
  [6834] = 2275,
  [6835] = 2283,
  [6836] = 6609,
  [6837] = 6837,
  [6838] = 6612,
  [6839] = 6617,
  [6840] = 6814,
  [6841] = 6297,
  [6842] = 6299,
  [6843] = 6300,
  [6844] = 6301,
  [6845] = 6297,
  [6846] = 6032,
  [6847] = 6300,
  [6848] = 6301,
  [6849] = 6620,
  [6850] = 6791,
  [6851] = 6590,
  [6852] = 6607,
  [6853] = 6622,
  [6854] = 6790,
  [6855] = 2168,
  [6856] = 6790,
  [6857] = 2423,
  [6858] = 6822,
  [6859] = 6859,
  [6860] = 6822,
  [6861] = 6790,
  [6862] = 2467,
  [6863] = 6790,
  [6864] = 2449,
  [6865] = 6790,
  [6866] = 6790,
  [6867] = 6790,
  [6868] = 6790,
  [6869] = 6790,
  [6870] = 6790,
  [6871] = 6790,
  [6872] = 6822,
  [6873] = 5949,
  [6874] = 2421,
  [6875] = 2466,
  [6876] = 6790,
  [6877] = 6814,
  [6878] = 2423,
  [6879] = 2467,
  [6880] = 2449,
  [6881] = 2184,
  [6882] = 6032,
  [6883] = 6054,
  [6884] = 6027,
  [6885] = 5995,
  [6886] = 5994,
  [6887] = 2184,
  [6888] = 6814,
  [6889] = 6814,
  [6890] = 6790,
  [6891] = 2466,
  [6892] = 2274,
  [6893] = 6790,
  [6894] = 6299,
  [6895] = 6895,
  [6896] = 6896,
  [6897] = 6613,
  [6898] = 6617,
  [6899] = 6620,
  [6900] = 6607,
  [6901] = 6747,
  [6902] = 6609,
  [6903] = 6612,
  [6904] = 6590,
  [6905] = 6622,
  [6906] = 6895,
  [6907] = 6895,
  [6908] = 6908,
  [6909] = 6909,
  [6910] = 6895,
  [6911] = 6911,
  [6912] = 6895,
  [6913] = 6895,
  [6914] = 6914,
  [6915] = 6909,
  [6916] = 6909,
  [6917] = 6917,
  [6918] = 6609,
  [6919] = 6590,
  [6920] = 6612,
  [6921] = 6895,
  [6922] = 6911,
  [6923] = 6923,
  [6924] = 6924,
  [6925] = 6911,
  [6926] = 6733,
  [6927] = 6297,
  [6928] = 6607,
  [6929] = 6909,
  [6930] = 6299,
  [6931] = 6300,
  [6932] = 6301,
  [6933] = 6933,
  [6934] = 6297,
  [6935] = 6299,
  [6936] = 6300,
  [6937] = 6301,
  [6938] = 6917,
  [6939] = 6895,
  [6940] = 6750,
  [6941] = 6909,
  [6942] = 6942,
  [6943] = 6909,
  [6944] = 6895,
  [6945] = 6917,
  [6946] = 6909,
  [6947] = 6702,
  [6948] = 6543,
  [6949] = 6949,
  [6950] = 6909,
  [6951] = 6911,
  [6952] = 6917,
  [6953] = 6908,
  [6954] = 6712,
  [6955] = 6617,
  [6956] = 6622,
  [6957] = 6620,
  [6958] = 6911,
  [6959] = 6895,
  [6960] = 6613,
  [6961] = 2587,
  [6962] = 6909,
  [6963] = 6963,
  [6964] = 6895,
  [6965] = 6909,
  [6966] = 6909,
  [6967] = 6895,
  [6968] = 6909,
  [6969] = 6908,
  [6970] = 6911,
  [6971] = 2587,
  [6972] = 6949,
  [6973] = 6908,
  [6974] = 6297,
  [6975] = 6975,
  [6976] = 6975,
  [6977] = 6975,
  [6978] = 6297,
  [6979] = 6613,
  [6980] = 6975,
  [6981] = 6975,
  [6982] = 6609,
  [6983] = 6975,
  [6984] = 6612,
  [6985] = 6299,
  [6986] = 6617,
  [6987] = 6620,
  [6988] = 6975,
  [6989] = 6590,
  [6990] = 6607,
  [6991] = 6622,
  [6992] = 6992,
  [6993] = 6993,
  [6994] = 6300,
  [6995] = 6975,
  [6996] = 6996,
  [6997] = 6997,
  [6998] = 6998,
  [6999] = 6301,
  [7000] = 6975,
  [7001] = 6299,
  [7002] = 6975,
  [7003] = 6975,
  [7004] = 6975,
  [7005] = 6300,
  [7006] = 6975,
  [7007] = 6975,
  [7008] = 6975,
  [7009] = 2717,
  [7010] = 6975,
  [7011] = 7011,
  [7012] = 7012,
  [7013] = 7013,
  [7014] = 7014,
  [7015] = 6975,
  [7016] = 6975,
  [7017] = 6301,
  [7018] = 2978,
  [7019] = 6975,
  [7020] = 6975,
  [7021] = 6975,
  [7022] = 6975,
  [7023] = 7023,
  [7024] = 6590,
  [7025] = 7025,
  [7026] = 6613,
  [7027] = 931,
  [7028] = 7028,
  [7029] = 6622,
  [7030] = 934,
  [7031] = 7031,
  [7032] = 7025,
  [7033] = 7033,
  [7034] = 7034,
  [7035] = 7035,
  [7036] = 6617,
  [7037] = 6620,
  [7038] = 7034,
  [7039] = 923,
  [7040] = 7040,
  [7041] = 2168,
  [7042] = 6733,
  [7043] = 7043,
  [7044] = 7044,
  [7045] = 7045,
  [7046] = 7034,
  [7047] = 7033,
  [7048] = 7048,
  [7049] = 6613,
  [7050] = 6032,
  [7051] = 6054,
  [7052] = 6607,
  [7053] = 7031,
  [7054] = 6027,
  [7055] = 5995,
  [7056] = 5994,
  [7057] = 7057,
  [7058] = 7031,
  [7059] = 945,
  [7060] = 7025,
  [7061] = 6620,
  [7062] = 947,
  [7063] = 7031,
  [7064] = 6702,
  [7065] = 7034,
  [7066] = 6032,
  [7067] = 6613,
  [7068] = 7025,
  [7069] = 6609,
  [7070] = 7025,
  [7071] = 7033,
  [7072] = 7033,
  [7073] = 7034,
  [7074] = 7074,
  [7075] = 6607,
  [7076] = 7076,
  [7077] = 7034,
  [7078] = 6027,
  [7079] = 2184,
  [7080] = 6609,
  [7081] = 6612,
  [7082] = 6613,
  [7083] = 5995,
  [7084] = 6617,
  [7085] = 6620,
  [7086] = 7086,
  [7087] = 7087,
  [7088] = 7031,
  [7089] = 7089,
  [7090] = 949,
  [7091] = 7091,
  [7092] = 5994,
  [7093] = 929,
  [7094] = 6617,
  [7095] = 7025,
  [7096] = 6612,
  [7097] = 7097,
  [7098] = 7098,
  [7099] = 7033,
  [7100] = 7034,
  [7101] = 6609,
  [7102] = 6612,
  [7103] = 6609,
  [7104] = 7104,
  [7105] = 6617,
  [7106] = 6612,
  [7107] = 6620,
  [7108] = 7033,
  [7109] = 6750,
  [7110] = 6590,
  [7111] = 6712,
  [7112] = 6590,
  [7113] = 7033,
  [7114] = 7114,
  [7115] = 6590,
  [7116] = 6607,
  [7117] = 6607,
  [7118] = 6622,
  [7119] = 7119,
  [7120] = 7031,
  [7121] = 6622,
  [7122] = 6622,
  [7123] = 7025,
  [7124] = 2621,
  [7125] = 7125,
  [7126] = 7031,
  [7127] = 2622,
  [7128] = 6747,
  [7129] = 7129,
  [7130] = 6054,
  [7131] = 7131,
  [7132] = 7132,
  [7133] = 7132,
  [7134] = 6609,
  [7135] = 7135,
  [7136] = 6607,
  [7137] = 6590,
  [7138] = 7132,
  [7139] = 7132,
  [7140] = 7140,
  [7141] = 6612,
  [7142] = 7142,
  [7143] = 7132,
  [7144] = 7131,
  [7145] = 6590,
  [7146] = 6622,
  [7147] = 7132,
  [7148] = 7148,
  [7149] = 6612,
  [7150] = 7132,
  [7151] = 7132,
  [7152] = 6622,
  [7153] = 7132,
  [7154] = 6613,
  [7155] = 6609,
  [7156] = 6612,
  [7157] = 7132,
  [7158] = 7158,
  [7159] = 6620,
  [7160] = 6617,
  [7161] = 6613,
  [7162] = 7162,
  [7163] = 6620,
  [7164] = 7164,
  [7165] = 7132,
  [7166] = 7132,
  [7167] = 7132,
  [7168] = 6590,
  [7169] = 7169,
  [7170] = 6607,
  [7171] = 6622,
  [7172] = 7132,
  [7173] = 6617,
  [7174] = 6609,
  [7175] = 7132,
  [7176] = 7176,
  [7177] = 6609,
  [7178] = 7178,
  [7179] = 7178,
  [7180] = 6613,
  [7181] = 7181,
  [7182] = 7181,
  [7183] = 7178,
  [7184] = 7184,
  [7185] = 7181,
  [7186] = 6733,
  [7187] = 7178,
  [7188] = 6712,
  [7189] = 7178,
  [7190] = 6750,
  [7191] = 6612,
  [7192] = 6617,
  [7193] = 6620,
  [7194] = 7181,
  [7195] = 7178,
  [7196] = 7181,
  [7197] = 7178,
  [7198] = 7178,
  [7199] = 7178,
  [7200] = 7178,
  [7201] = 7184,
  [7202] = 7178,
  [7203] = 7178,
  [7204] = 7178,
  [7205] = 6702,
  [7206] = 6590,
  [7207] = 7207,
  [7208] = 6607,
  [7209] = 6390,
  [7210] = 7178,
  [7211] = 2184,
  [7212] = 7184,
  [7213] = 7178,
  [7214] = 6747,
  [7215] = 7181,
  [7216] = 2168,
  [7217] = 6622,
  [7218] = 7178,
  [7219] = 7207,
  [7220] = 7207,
  [7221] = 7184,
  [7222] = 7178,
  [7223] = 7207,
  [7224] = 7224,
  [7225] = 7178,
  [7226] = 7181,
  [7227] = 7178,
  [7228] = 7224,
  [7229] = 7178,
  [7230] = 7178,
  [7231] = 6399,
  [7232] = 7178,
  [7233] = 7224,
  [7234] = 7178,
  [7235] = 7224,
  [7236] = 7236,
  [7237] = 7237,
  [7238] = 7238,
  [7239] = 2722,
  [7240] = 7236,
  [7241] = 7237,
  [7242] = 7242,
  [7243] = 6613,
  [7244] = 6617,
  [7245] = 6620,
  [7246] = 6607,
  [7247] = 7247,
  [7248] = 7248,
  [7249] = 6609,
  [7250] = 7238,
  [7251] = 6609,
  [7252] = 6612,
  [7253] = 6590,
  [7254] = 6622,
  [7255] = 6609,
  [7256] = 6612,
  [7257] = 7257,
  [7258] = 7258,
  [7259] = 7236,
  [7260] = 6590,
  [7261] = 6622,
  [7262] = 7262,
  [7263] = 7263,
  [7264] = 6390,
  [7265] = 6590,
  [7266] = 7237,
  [7267] = 6733,
  [7268] = 6750,
  [7269] = 7237,
  [7270] = 7237,
  [7271] = 6702,
  [7272] = 6399,
  [7273] = 6612,
  [7274] = 7238,
  [7275] = 6622,
  [7276] = 6609,
  [7277] = 6612,
  [7278] = 6712,
  [7279] = 7279,
  [7280] = 7280,
  [7281] = 6747,
  [7282] = 7282,
  [7283] = 6590,
  [7284] = 6743,
  [7285] = 6701,
  [7286] = 7237,
  [7287] = 6622,
  [7288] = 6748,
  [7289] = 6761,
  [7290] = 6731,
  [7291] = 7291,
  [7292] = 7292,
  [7293] = 7237,
  [7294] = 7238,
  [7295] = 7295,
  [7296] = 7296,
  [7297] = 7236,
  [7298] = 7298,
  [7299] = 6613,
  [7300] = 7300,
  [7301] = 7301,
  [7302] = 7302,
  [7303] = 6607,
  [7304] = 7304,
  [7305] = 2423,
  [7306] = 7306,
  [7307] = 2421,
  [7308] = 7306,
  [7309] = 7304,
  [7310] = 7310,
  [7311] = 7311,
  [7312] = 6613,
  [7313] = 6622,
  [7314] = 7314,
  [7315] = 7315,
  [7316] = 7302,
  [7317] = 6609,
  [7318] = 6612,
  [7319] = 6590,
  [7320] = 6622,
  [7321] = 7321,
  [7322] = 7322,
  [7323] = 2467,
  [7324] = 7324,
  [7325] = 7325,
  [7326] = 7326,
  [7327] = 2211,
  [7328] = 7328,
  [7329] = 7329,
  [7330] = 7329,
  [7331] = 2466,
  [7332] = 6617,
  [7333] = 6620,
  [7334] = 7329,
  [7335] = 2449,
  [7336] = 7304,
  [7337] = 6617,
  [7338] = 7306,
  [7339] = 7339,
  [7340] = 7340,
  [7341] = 6607,
  [7342] = 7304,
  [7343] = 7302,
  [7344] = 7306,
  [7345] = 7329,
  [7346] = 7346,
  [7347] = 2221,
  [7348] = 2722,
  [7349] = 7346,
  [7350] = 2220,
  [7351] = 7311,
  [7352] = 6609,
  [7353] = 7326,
  [7354] = 6612,
  [7355] = 7304,
  [7356] = 7356,
  [7357] = 7302,
  [7358] = 7358,
  [7359] = 7359,
  [7360] = 7346,
  [7361] = 7311,
  [7362] = 6590,
  [7363] = 7346,
  [7364] = 6620,
  [7365] = 7311,
  [7366] = 7346,
  [7367] = 7311,
  [7368] = 7346,
  [7369] = 7311,
  [7370] = 7346,
  [7371] = 7311,
  [7372] = 7329,
  [7373] = 7346,
  [7374] = 7311,
  [7375] = 7346,
  [7376] = 7311,
  [7377] = 7377,
  [7378] = 7300,
  [7379] = 7379,
  [7380] = 7380,
  [7381] = 7381,
  [7382] = 6923,
  [7383] = 7383,
  [7384] = 7384,
  [7385] = 7385,
  [7386] = 7386,
  [7387] = 7387,
  [7388] = 7388,
  [7389] = 7389,
  [7390] = 7390,
  [7391] = 7391,
  [7392] = 7391,
  [7393] = 7385,
  [7394] = 7394,
  [7395] = 7390,
  [7396] = 7396,
  [7397] = 2722,
  [7398] = 7380,
  [7399] = 7380,
  [7400] = 7400,
  [7401] = 7381,
  [7402] = 7383,
  [7403] = 7403,
  [7404] = 7385,
  [7405] = 7385,
  [7406] = 7389,
  [7407] = 7407,
  [7408] = 7408,
  [7409] = 7409,
  [7410] = 2722,
  [7411] = 7411,
  [7412] = 7394,
  [7413] = 7396,
  [7414] = 6914,
  [7415] = 6933,
  [7416] = 7394,
  [7417] = 7381,
  [7418] = 2587,
  [7419] = 7396,
  [7420] = 7391,
  [7421] = 7385,
  [7422] = 7391,
  [7423] = 7423,
  [7424] = 7385,
  [7425] = 7383,
  [7426] = 7385,
  [7427] = 7388,
  [7428] = 7428,
  [7429] = 7388,
  [7430] = 7389,
  [7431] = 7390,
  [7432] = 7432,
  [7433] = 7391,
  [7434] = 7434,
  [7435] = 7391,
  [7436] = 7391,
  [7437] = 7437,
  [7438] = 7438,
  [7439] = 7439,
  [7440] = 7440,
  [7441] = 7441,
  [7442] = 2722,
  [7443] = 6607,
  [7444] = 7444,
  [7445] = 2722,
  [7446] = 7446,
  [7447] = 7447,
  [7448] = 7448,
  [7449] = 7444,
  [7450] = 7450,
  [7451] = 7444,
  [7452] = 7437,
  [7453] = 7453,
  [7454] = 6399,
  [7455] = 7444,
  [7456] = 7450,
  [7457] = 6613,
  [7458] = 7450,
  [7459] = 6622,
  [7460] = 7447,
  [7461] = 7450,
  [7462] = 7462,
  [7463] = 7450,
  [7464] = 7464,
  [7465] = 7447,
  [7466] = 7464,
  [7467] = 7467,
  [7468] = 7450,
  [7469] = 7464,
  [7470] = 7441,
  [7471] = 7437,
  [7472] = 7453,
  [7473] = 7444,
  [7474] = 7437,
  [7475] = 7453,
  [7476] = 7476,
  [7477] = 7477,
  [7478] = 7444,
  [7479] = 7453,
  [7480] = 7447,
  [7481] = 7444,
  [7482] = 7482,
  [7483] = 7444,
  [7484] = 7484,
  [7485] = 7485,
  [7486] = 7437,
  [7487] = 7450,
  [7488] = 7453,
  [7489] = 7464,
  [7490] = 7437,
  [7491] = 7453,
  [7492] = 7492,
  [7493] = 7464,
  [7494] = 7494,
  [7495] = 2665,
  [7496] = 6617,
  [7497] = 6620,
  [7498] = 7450,
  [7499] = 7437,
  [7500] = 7453,
  [7501] = 7482,
  [7502] = 6609,
  [7503] = 6612,
  [7504] = 7450,
  [7505] = 7437,
  [7506] = 7444,
  [7507] = 6590,
  [7508] = 7453,
  [7509] = 7464,
  [7510] = 7453,
  [7511] = 7437,
  [7512] = 7512,
  [7513] = 7513,
  [7514] = 7514,
  [7515] = 7515,
  [7516] = 7516,
  [7517] = 7517,
  [7518] = 7515,
  [7519] = 7514,
  [7520] = 7520,
  [7521] = 7516,
  [7522] = 7522,
  [7523] = 7523,
  [7524] = 7515,
  [7525] = 7512,
  [7526] = 7523,
  [7527] = 7516,
  [7528] = 7528,
  [7529] = 7520,
  [7530] = 7530,
  [7531] = 7530,
  [7532] = 7532,
  [7533] = 7522,
  [7534] = 7534,
  [7535] = 7535,
  [7536] = 7523,
  [7537] = 7514,
  [7538] = 7538,
  [7539] = 7523,
  [7540] = 7530,
  [7541] = 7528,
  [7542] = 7516,
  [7543] = 7513,
  [7544] = 7544,
  [7545] = 7534,
  [7546] = 7512,
  [7547] = 7530,
  [7548] = 7520,
  [7549] = 7516,
  [7550] = 7534,
  [7551] = 7522,
  [7552] = 7523,
  [7553] = 7523,
  [7554] = 7535,
  [7555] = 7512,
  [7556] = 7514,
  [7557] = 7513,
  [7558] = 7514,
  [7559] = 7559,
  [7560] = 7516,
  [7561] = 7559,
  [7562] = 7530,
  [7563] = 7530,
  [7564] = 7564,
  [7565] = 7528,
  [7566] = 7538,
  [7567] = 7523,
  [7568] = 7513,
  [7569] = 7516,
  [7570] = 7570,
  [7571] = 7571,
  [7572] = 7530,
  [7573] = 7513,
  [7574] = 7523,
  [7575] = 7523,
  [7576] = 7530,
  [7577] = 7517,
  [7578] = 7530,
  [7579] = 7517,
  [7580] = 7580,
  [7581] = 7523,
  [7582] = 7582,
  [7583] = 7528,
  [7584] = 7517,
  [7585] = 7517,
  [7586] = 7530,
  [7587] = 7512,
  [7588] = 7516,
  [7589] = 7515,
  [7590] = 7590,
  [7591] = 7591,
  [7592] = 7522,
  [7593] = 7593,
  [7594] = 7594,
  [7595] = 7520,
  [7596] = 7522,
  [7597] = 7559,
  [7598] = 7582,
  [7599] = 7559,
  [7600] = 7564,
  [7601] = 7538,
  [7602] = 7523,
  [7603] = 7530,
  [7604] = 7528,
  [7605] = 7513,
  [7606] = 7513,
  [7607] = 7516,
  [7608] = 7515,
  [7609] = 7609,
  [7610] = 7610,
  [7611] = 7520,
  [7612] = 7564,
  [7613] = 7522,
  [7614] = 7538,
  [7615] = 7523,
  [7616] = 7616,
  [7617] = 7528,
  [7618] = 7514,
  [7619] = 7564,
  [7620] = 7564,
  [7621] = 7621,
  [7622] = 7538,
  [7623] = 7513,
  [7624] = 7516,
  [7625] = 7528,
  [7626] = 7559,
  [7627] = 7534,
  [7628] = 7530,
  [7629] = 7523,
  [7630] = 7517,
  [7631] = 7559,
  [7632] = 7517,
  [7633] = 7564,
  [7634] = 6399,
  [7635] = 7528,
  [7636] = 7520,
  [7637] = 7516,
  [7638] = 7638,
  [7639] = 7514,
  [7640] = 7640,
  [7641] = 7517,
  [7642] = 7642,
  [7643] = 7520,
  [7644] = 7534,
  [7645] = 7645,
  [7646] = 7538,
  [7647] = 7530,
  [7648] = 7530,
  [7649] = 7530,
  [7650] = 7530,
  [7651] = 7520,
  [7652] = 7538,
  [7653] = 7523,
  [7654] = 7520,
  [7655] = 7522,
  [7656] = 7523,
  [7657] = 7657,
  [7658] = 7512,
  [7659] = 7582,
  [7660] = 7514,
  [7661] = 7517,
  [7662] = 7609,
  [7663] = 7516,
  [7664] = 7532,
  [7665] = 7515,
  [7666] = 7666,
  [7667] = 7515,
  [7668] = 7513,
  [7669] = 7669,
  [7670] = 7670,
  [7671] = 7671,
  [7672] = 7522,
  [7673] = 7516,
  [7674] = 7520,
  [7675] = 7534,
  [7676] = 7522,
  [7677] = 7523,
  [7678] = 7522,
  [7679] = 7523,
  [7680] = 7517,
  [7681] = 7512,
  [7682] = 7528,
  [7683] = 7512,
  [7684] = 7514,
  [7685] = 7514,
  [7686] = 7523,
  [7687] = 7532,
  [7688] = 7520,
  [7689] = 7528,
  [7690] = 7513,
  [7691] = 7520,
  [7692] = 7513,
  [7693] = 7522,
  [7694] = 7516,
  [7695] = 7559,
  [7696] = 2722,
  [7697] = 7528,
  [7698] = 7516,
  [7699] = 7530,
  [7700] = 7700,
  [7701] = 7701,
  [7702] = 7520,
  [7703] = 7535,
  [7704] = 7609,
  [7705] = 7513,
  [7706] = 7532,
  [7707] = 7522,
  [7708] = 7523,
  [7709] = 7514,
  [7710] = 7513,
  [7711] = 7516,
  [7712] = 7609,
  [7713] = 7532,
  [7714] = 7514,
  [7715] = 7517,
  [7716] = 7528,
  [7717] = 7517,
  [7718] = 7523,
  [7719] = 7530,
  [7720] = 7609,
  [7721] = 7532,
  [7722] = 7530,
  [7723] = 7522,
  [7724] = 7523,
  [7725] = 7725,
  [7726] = 7609,
  [7727] = 7532,
  [7728] = 7728,
  [7729] = 7535,
  [7730] = 7582,
  [7731] = 7516,
  [7732] = 7609,
  [7733] = 7532,
  [7734] = 7512,
  [7735] = 7735,
  [7736] = 7530,
  [7737] = 7522,
  [7738] = 7609,
  [7739] = 7532,
  [7740] = 7523,
  [7741] = 7582,
  [7742] = 7609,
  [7743] = 7520,
  [7744] = 7513,
  [7745] = 7530,
  [7746] = 7512,
  [7747] = 7530,
  [7748] = 7516,
  [7749] = 7530,
  [7750] = 7750,
  [7751] = 7582,
  [7752] = 7523,
  [7753] = 7753,
  [7754] = 7754,
  [7755] = 7582,
  [7756] = 7515,
  [7757] = 7757,
  [7758] = 7758,
  [7759] = 7512,
  [7760] = 7516,
  [7761] = 7564,
  [7762] = 2783,
  [7763] = 7763,
  [7764] = 7764,
  [7765] = 7765,
  [7766] = 7766,
  [7767] = 7763,
  [7768] = 7768,
  [7769] = 7769,
  [7770] = 7770,
  [7771] = 7771,
  [7772] = 7772,
  [7773] = 7773,
  [7774] = 7774,
  [7775] = 7769,
  [7776] = 7776,
  [7777] = 7777,
  [7778] = 7776,
  [7779] = 7779,
  [7780] = 7768,
  [7781] = 7781,
  [7782] = 7782,
  [7783] = 7783,
  [7784] = 7784,
  [7785] = 7785,
  [7786] = 7765,
  [7787] = 7787,
  [7788] = 7788,
  [7789] = 7769,
  [7790] = 7776,
  [7791] = 7791,
  [7792] = 7792,
  [7793] = 7768,
  [7794] = 7794,
  [7795] = 7772,
  [7796] = 7796,
  [7797] = 7763,
  [7798] = 7798,
  [7799] = 7799,
  [7800] = 7800,
  [7801] = 7772,
  [7802] = 7802,
  [7803] = 7803,
  [7804] = 7776,
  [7805] = 7805,
  [7806] = 7768,
  [7807] = 7807,
  [7808] = 7808,
  [7809] = 7809,
  [7810] = 7792,
  [7811] = 7796,
  [7812] = 7771,
  [7813] = 7813,
  [7814] = 7772,
  [7815] = 7815,
  [7816] = 7816,
  [7817] = 7802,
  [7818] = 7818,
  [7819] = 7769,
  [7820] = 7798,
  [7821] = 7821,
  [7822] = 7768,
  [7823] = 7823,
  [7824] = 7807,
  [7825] = 7825,
  [7826] = 7809,
  [7827] = 7827,
  [7828] = 7792,
  [7829] = 7829,
  [7830] = 7830,
  [7831] = 7831,
  [7832] = 7832,
  [7833] = 7821,
  [7834] = 7834,
  [7835] = 7763,
  [7836] = 168,
  [7837] = 7837,
  [7838] = 7768,
  [7839] = 2748,
  [7840] = 7792,
  [7841] = 7771,
  [7842] = 7763,
  [7843] = 7769,
  [7844] = 7796,
  [7845] = 7845,
  [7846] = 7846,
  [7847] = 7845,
  [7848] = 7768,
  [7849] = 7802,
  [7850] = 7834,
  [7851] = 7769,
  [7852] = 7852,
  [7853] = 7853,
  [7854] = 7854,
  [7855] = 7783,
  [7856] = 7784,
  [7857] = 7857,
  [7858] = 7785,
  [7859] = 7859,
  [7860] = 7771,
  [7861] = 7783,
  [7862] = 7769,
  [7863] = 7771,
  [7864] = 7845,
  [7865] = 7798,
  [7866] = 7807,
  [7867] = 7809,
  [7868] = 7784,
  [7869] = 7766,
  [7870] = 7798,
  [7871] = 7807,
  [7872] = 7809,
  [7873] = 7785,
  [7874] = 7874,
  [7875] = 7875,
  [7876] = 7766,
  [7877] = 7877,
  [7878] = 7772,
  [7879] = 7879,
  [7880] = 7834,
  [7881] = 7852,
  [7882] = 7821,
  [7883] = 7772,
  [7884] = 7830,
  [7885] = 7885,
  [7886] = 7845,
  [7887] = 7805,
  [7888] = 7875,
  [7889] = 7889,
  [7890] = 7890,
  [7891] = 7854,
  [7892] = 7877,
  [7893] = 7827,
  [7894] = 7831,
  [7895] = 7834,
  [7896] = 7768,
  [7897] = 7783,
  [7898] = 7805,
  [7899] = 7899,
  [7900] = 7769,
  [7901] = 7901,
  [7902] = 7885,
  [7903] = 7890,
  [7904] = 7904,
  [7905] = 7834,
  [7906] = 7783,
  [7907] = 7784,
  [7908] = 7785,
  [7909] = 7845,
  [7910] = 7910,
  [7911] = 7834,
  [7912] = 7784,
  [7913] = 7852,
  [7914] = 7854,
  [7915] = 7915,
  [7916] = 7857,
  [7917] = 7785,
  [7918] = 7859,
  [7919] = 7783,
  [7920] = 7920,
  [7921] = 7921,
  [7922] = 7784,
  [7923] = 7785,
  [7924] = 7770,
  [7925] = 7877,
  [7926] = 7768,
  [7927] = 7798,
  [7928] = 7769,
  [7929] = 7877,
  [7930] = 7845,
  [7931] = 7874,
  [7932] = 7783,
  [7933] = 7875,
  [7934] = 7784,
  [7935] = 7935,
  [7936] = 7832,
  [7937] = 7785,
  [7938] = 7834,
  [7939] = 7832,
  [7940] = 7792,
  [7941] = 7859,
  [7942] = 7805,
  [7943] = 7796,
  [7944] = 7852,
  [7945] = 7768,
  [7946] = 2785,
  [7947] = 2787,
  [7948] = 165,
  [7949] = 7949,
  [7950] = 7821,
  [7951] = 7821,
  [7952] = 7830,
  [7953] = 7765,
  [7954] = 7827,
  [7955] = 7885,
  [7956] = 7859,
  [7957] = 7890,
  [7958] = 7852,
  [7959] = 7854,
  [7960] = 7783,
  [7961] = 7784,
  [7962] = 7785,
  [7963] = 2758,
  [7964] = 7874,
  [7965] = 7965,
  [7966] = 7827,
  [7967] = 7831,
  [7968] = 7769,
  [7969] = 7969,
  [7970] = 7783,
  [7971] = 2761,
  [7972] = 7784,
  [7973] = 7831,
  [7974] = 7785,
  [7975] = 7877,
  [7976] = 7830,
  [7977] = 7935,
  [7978] = 2738,
  [7979] = 7859,
  [7980] = 2797,
  [7981] = 7935,
  [7982] = 7832,
  [7983] = 2809,
  [7984] = 7984,
  [7985] = 7854,
  [7986] = 7986,
  [7987] = 7783,
  [7988] = 7874,
  [7989] = 7989,
  [7990] = 7782,
  [7991] = 7991,
  [7992] = 7992,
  [7993] = 7784,
  [7994] = 7785,
  [7995] = 7813,
  [7996] = 7776,
  [7997] = 7770,
  [7998] = 7768,
  [7999] = 7999,
  [8000] = 8000,
  [8001] = 8001,
  [8002] = 7769,
  [8003] = 7859,
  [8004] = 7783,
  [8005] = 7813,
  [8006] = 7809,
  [8007] = 7785,
  [8008] = 7874,
  [8009] = 7768,
  [8010] = 8010,
  [8011] = 7807,
  [8012] = 7821,
  [8013] = 8013,
  [8014] = 8014,
  [8015] = 7830,
  [8016] = 7768,
  [8017] = 7830,
  [8018] = 7769,
  [8019] = 7783,
  [8020] = 7784,
  [8021] = 7821,
  [8022] = 7830,
  [8023] = 7874,
  [8024] = 7859,
  [8025] = 7785,
  [8026] = 7769,
  [8027] = 7802,
  [8028] = 7768,
  [8029] = 7885,
  [8030] = 7792,
  [8031] = 7859,
  [8032] = 7796,
  [8033] = 7877,
  [8034] = 7890,
  [8035] = 7859,
  [8036] = 8036,
  [8037] = 7859,
  [8038] = 7859,
  [8039] = 7859,
  [8040] = 7768,
  [8041] = 7859,
  [8042] = 8042,
  [8043] = 7831,
  [8044] = 7796,
  [8045] = 7769,
  [8046] = 7885,
  [8047] = 7890,
  [8048] = 7783,
  [8049] = 7784,
  [8050] = 7785,
  [8051] = 7827,
  [8052] = 7831,
  [8053] = 7857,
  [8054] = 7827,
  [8055] = 7771,
  [8056] = 7935,
  [8057] = 7832,
  [8058] = 7831,
  [8059] = 7763,
  [8060] = 7984,
  [8061] = 7768,
  [8062] = 7769,
  [8063] = 7769,
  [8064] = 7765,
  [8065] = 7783,
  [8066] = 7784,
  [8067] = 7792,
  [8068] = 7785,
  [8069] = 7885,
  [8070] = 7890,
  [8071] = 8071,
  [8072] = 8072,
  [8073] = 8073,
  [8074] = 7796,
  [8075] = 7802,
  [8076] = 8076,
  [8077] = 7809,
  [8078] = 8078,
  [8079] = 7765,
  [8080] = 7846,
  [8081] = 8081,
  [8082] = 7792,
  [8083] = 8083,
  [8084] = 8084,
  [8085] = 7763,
  [8086] = 7813,
  [8087] = 7852,
  [8088] = 7768,
  [8089] = 8089,
  [8090] = 2820,
  [8091] = 8091,
  [8092] = 7769,
  [8093] = 7776,
  [8094] = 8094,
  [8095] = 7783,
  [8096] = 7784,
  [8097] = 7832,
  [8098] = 7768,
  [8099] = 7785,
  [8100] = 8100,
  [8101] = 8101,
  [8102] = 8102,
  [8103] = 7845,
  [8104] = 7802,
  [8105] = 7792,
  [8106] = 7796,
  [8107] = 7768,
  [8108] = 7852,
  [8109] = 7854,
  [8110] = 7783,
  [8111] = 7984,
  [8112] = 7802,
  [8113] = 7768,
  [8114] = 7771,
  [8115] = 7784,
  [8116] = 7785,
  [8117] = 7769,
  [8118] = 7263,
  [8119] = 7796,
  [8120] = 7768,
  [8121] = 7798,
  [8122] = 7807,
  [8123] = 7809,
  [8124] = 8124,
  [8125] = 7766,
  [8126] = 7821,
  [8127] = 8127,
  [8128] = 7830,
  [8129] = 7772,
  [8130] = 7885,
  [8131] = 8131,
  [8132] = 7776,
  [8133] = 7890,
  [8134] = 7827,
  [8135] = 8135,
  [8136] = 7857,
  [8137] = 7859,
  [8138] = 8138,
  [8139] = 7821,
  [8140] = 7830,
  [8141] = 7771,
  [8142] = 8142,
  [8143] = 7854,
  [8144] = 7798,
  [8145] = 7769,
  [8146] = 7782,
  [8147] = 7885,
  [8148] = 7885,
  [8149] = 7890,
  [8150] = 7807,
  [8151] = 7827,
  [8152] = 7831,
  [8153] = 7969,
  [8154] = 8154,
  [8155] = 7875,
  [8156] = 7763,
  [8157] = 7852,
  [8158] = 8158,
  [8159] = 7854,
  [8160] = 7783,
  [8161] = 7784,
  [8162] = 7785,
  [8163] = 7874,
  [8164] = 7890,
  [8165] = 7783,
  [8166] = 7802,
  [8167] = 7765,
  [8168] = 7845,
  [8169] = 7768,
  [8170] = 7809,
  [8171] = 7776,
  [8172] = 7784,
  [8173] = 7877,
  [8174] = 8174,
  [8175] = 7834,
  [8176] = 8176,
  [8177] = 8177,
  [8178] = 7765,
  [8179] = 7857,
  [8180] = 7785,
  [8181] = 8181,
  [8182] = 7768,
  [8183] = 7935,
  [8184] = 7832,
  [8185] = 7984,
  [8186] = 2722,
  [8187] = 7852,
  [8188] = 8188,
  [8189] = 7845,
  [8190] = 7854,
  [8191] = 7783,
  [8192] = 7782,
  [8193] = 7784,
  [8194] = 8194,
  [8195] = 8195,
  [8196] = 7798,
  [8197] = 7785,
  [8198] = 8198,
  [8199] = 7807,
  [8200] = 7765,
  [8201] = 8201,
  [8202] = 7766,
  [8203] = 7827,
  [8204] = 7765,
  [8205] = 7771,
  [8206] = 7877,
  [8207] = 7857,
  [8208] = 7784,
  [8209] = 8209,
  [8210] = 8210,
  [8211] = 8211,
  [8212] = 8212,
  [8213] = 8213,
  [8214] = 8214,
  [8215] = 8215,
  [8216] = 8216,
  [8217] = 8217,
  [8218] = 8218,
  [8219] = 8214,
  [8220] = 8220,
  [8221] = 8221,
  [8222] = 8222,
  [8223] = 8223,
  [8224] = 8224,
  [8225] = 8225,
  [8226] = 8226,
  [8227] = 8227,
  [8228] = 8228,
  [8229] = 8229,
  [8230] = 8230,
  [8231] = 8231,
  [8232] = 8232,
  [8233] = 8233,
  [8234] = 8227,
  [8235] = 8235,
  [8236] = 8236,
  [8237] = 8213,
  [8238] = 8238,
  [8239] = 8239,
  [8240] = 8214,
  [8241] = 8241,
  [8242] = 8212,
  [8243] = 8243,
  [8244] = 8244,
  [8245] = 8221,
  [8246] = 8212,
  [8247] = 8230,
  [8248] = 8244,
  [8249] = 8215,
  [8250] = 8244,
  [8251] = 8230,
  [8252] = 8252,
  [8253] = 8253,
  [8254] = 8254,
  [8255] = 8255,
  [8256] = 8244,
  [8257] = 8227,
  [8258] = 8258,
  [8259] = 8213,
  [8260] = 8241,
  [8261] = 8261,
  [8262] = 8262,
  [8263] = 8218,
  [8264] = 8236,
  [8265] = 8209,
  [8266] = 8214,
  [8267] = 8267,
  [8268] = 8224,
  [8269] = 8269,
  [8270] = 8243,
  [8271] = 8271,
  [8272] = 8239,
  [8273] = 8273,
  [8274] = 8244,
  [8275] = 8241,
  [8276] = 8269,
  [8277] = 8277,
  [8278] = 8215,
  [8279] = 8218,
  [8280] = 8280,
  [8281] = 8271,
  [8282] = 8282,
  [8283] = 8283,
  [8284] = 8284,
  [8285] = 8285,
  [8286] = 8215,
  [8287] = 8230,
  [8288] = 8239,
  [8289] = 8241,
  [8290] = 8269,
  [8291] = 8243,
  [8292] = 8292,
  [8293] = 8214,
  [8294] = 8294,
  [8295] = 8295,
  [8296] = 8239,
  [8297] = 8241,
  [8298] = 8271,
  [8299] = 8299,
  [8300] = 8300,
  [8301] = 8218,
  [8302] = 8243,
  [8303] = 8271,
  [8304] = 8304,
  [8305] = 8305,
  [8306] = 8244,
  [8307] = 8230,
  [8308] = 8218,
  [8309] = 8209,
  [8310] = 8209,
  [8311] = 8241,
  [8312] = 8214,
  [8313] = 8243,
  [8314] = 8271,
  [8315] = 8217,
  [8316] = 8316,
  [8317] = 8244,
  [8318] = 8318,
  [8319] = 8319,
  [8320] = 8320,
  [8321] = 8230,
  [8322] = 8241,
  [8323] = 8230,
  [8324] = 8228,
  [8325] = 8325,
  [8326] = 8326,
  [8327] = 8238,
  [8328] = 8223,
  [8329] = 8209,
  [8330] = 8239,
  [8331] = 8236,
  [8332] = 8243,
  [8333] = 8269,
  [8334] = 8243,
  [8335] = 8271,
  [8336] = 8269,
  [8337] = 8221,
  [8338] = 8222,
  [8339] = 8271,
  [8340] = 8269,
  [8341] = 8209,
  [8342] = 8228,
  [8343] = 8282,
  [8344] = 8284,
  [8345] = 8232,
  [8346] = 8243,
  [8347] = 8271,
  [8348] = 8273,
  [8349] = 8212,
  [8350] = 8236,
  [8351] = 8241,
  [8352] = 8210,
  [8353] = 8273,
  [8354] = 8230,
  [8355] = 8282,
  [8356] = 8273,
  [8357] = 8284,
  [8358] = 8230,
  [8359] = 8236,
  [8360] = 8241,
  [8361] = 8210,
  [8362] = 8217,
  [8363] = 8316,
  [8364] = 8318,
  [8365] = 8214,
  [8366] = 8319,
  [8367] = 8230,
  [8368] = 8368,
  [8369] = 8369,
  [8370] = 8241,
  [8371] = 8326,
  [8372] = 8238,
  [8373] = 8223,
  [8374] = 8209,
  [8375] = 8282,
  [8376] = 8273,
  [8377] = 8210,
  [8378] = 8243,
  [8379] = 8271,
  [8380] = 8221,
  [8381] = 8230,
  [8382] = 8222,
  [8383] = 8233,
  [8384] = 8282,
  [8385] = 8228,
  [8386] = 8232,
  [8387] = 8282,
  [8388] = 8284,
  [8389] = 8284,
  [8390] = 8262,
  [8391] = 8282,
  [8392] = 8282,
  [8393] = 8282,
  [8394] = 8217,
  [8395] = 8316,
  [8396] = 8319,
  [8397] = 8284,
  [8398] = 8230,
  [8399] = 8284,
  [8400] = 8326,
  [8401] = 8238,
  [8402] = 8215,
  [8403] = 8241,
  [8404] = 8221,
  [8405] = 8222,
  [8406] = 8368,
  [8407] = 8368,
  [8408] = 8211,
  [8409] = 8228,
  [8410] = 8232,
  [8411] = 8411,
  [8412] = 8230,
  [8413] = 8211,
  [8414] = 8319,
  [8415] = 8239,
  [8416] = 8326,
  [8417] = 8218,
  [8418] = 8241,
  [8419] = 8233,
  [8420] = 8214,
  [8421] = 8241,
  [8422] = 8222,
  [8423] = 8228,
  [8424] = 8424,
  [8425] = 8232,
  [8426] = 8217,
  [8427] = 8236,
  [8428] = 8319,
  [8429] = 8213,
  [8430] = 8262,
  [8431] = 8326,
  [8432] = 8432,
  [8433] = 8224,
  [8434] = 8241,
  [8435] = 8435,
  [8436] = 8368,
  [8437] = 8283,
  [8438] = 8222,
  [8439] = 8439,
  [8440] = 8241,
  [8441] = 8228,
  [8442] = 8442,
  [8443] = 8217,
  [8444] = 8319,
  [8445] = 8326,
  [8446] = 8227,
  [8447] = 8222,
  [8448] = 8448,
  [8449] = 8217,
  [8450] = 8211,
  [8451] = 8227,
  [8452] = 8326,
  [8453] = 8214,
  [8454] = 8318,
  [8455] = 8326,
  [8456] = 8282,
  [8457] = 8241,
  [8458] = 8326,
  [8459] = 8326,
  [8460] = 8230,
  [8461] = 8461,
  [8462] = 8212,
  [8463] = 8238,
  [8464] = 8464,
  [8465] = 8230,
  [8466] = 8466,
  [8467] = 8284,
  [8468] = 8284,
  [8469] = 8215,
  [8470] = 8368,
  [8471] = 8284,
  [8472] = 8283,
  [8473] = 8223,
  [8474] = 8214,
  [8475] = 8318,
  [8476] = 8214,
  [8477] = 8244,
  [8478] = 8218,
  [8479] = 8233,
  [8480] = 8244,
  [8481] = 8224,
  [8482] = 8214,
  [8483] = 8244,
  [8484] = 8241,
  [8485] = 8215,
  [8486] = 8224,
  [8487] = 8218,
  [8488] = 8209,
  [8489] = 8283,
  [8490] = 8262,
  [8491] = 8491,
  [8492] = 8492,
  [8493] = 8239,
  [8494] = 8241,
  [8495] = 8319,
  [8496] = 8209,
  [8497] = 8214,
  [8498] = 8243,
  [8499] = 8271,
  [8500] = 8209,
  [8501] = 8223,
  [8502] = 8209,
  [8503] = 8284,
  [8504] = 8222,
  [8505] = 8243,
  [8506] = 8271,
  [8507] = 8316,
  [8508] = 8243,
  [8509] = 8271,
  [8510] = 8233,
  [8511] = 8511,
  [8512] = 8209,
  [8513] = 8212,
  [8514] = 8218,
  [8515] = 8243,
  [8516] = 8262,
  [8517] = 8217,
  [8518] = 8271,
  [8519] = 8316,
  [8520] = 8318,
  [8521] = 8212,
  [8522] = 8319,
  [8523] = 8236,
  [8524] = 8282,
  [8525] = 8284,
  [8526] = 8230,
  [8527] = 8225,
  [8528] = 8528,
  [8529] = 8227,
  [8530] = 8230,
  [8531] = 8326,
  [8532] = 8273,
  [8533] = 8533,
  [8534] = 8238,
  [8535] = 8535,
  [8536] = 8466,
  [8537] = 8537,
  [8538] = 8214,
  [8539] = 8223,
  [8540] = 8243,
  [8541] = 8271,
  [8542] = 8284,
  [8543] = 8318,
  [8544] = 8282,
  [8545] = 8284,
  [8546] = 8227,
  [8547] = 8212,
  [8548] = 8548,
  [8549] = 8244,
  [8550] = 8232,
  [8551] = 8551,
  [8552] = 8230,
  [8553] = 8466,
  [8554] = 8368,
  [8555] = 8466,
  [8556] = 8368,
  [8557] = 8466,
  [8558] = 8466,
  [8559] = 8559,
  [8560] = 8466,
  [8561] = 8466,
  [8562] = 8262,
  [8563] = 8466,
  [8564] = 8466,
  [8565] = 8466,
  [8566] = 8466,
  [8567] = 8466,
  [8568] = 8466,
  [8569] = 8466,
  [8570] = 8466,
  [8571] = 8466,
  [8572] = 8466,
  [8573] = 8466,
  [8574] = 8466,
  [8575] = 8466,
  [8576] = 8326,
  [8577] = 8368,
  [8578] = 8578,
  [8579] = 8217,
  [8580] = 8580,
  [8581] = 8581,
  [8582] = 8582,
  [8583] = 8583,
  [8584] = 8583,
  [8585] = 8583,
  [8586] = 8586,
  [8587] = 8587,
  [8588] = 8588,
  [8589] = 8589,
  [8590] = 8590,
  [8591] = 8591,
  [8592] = 8592,
  [8593] = 8583,
  [8594] = 8594,
  [8595] = 8595,
  [8596] = 8596,
  [8597] = 8597,
  [8598] = 8598,
  [8599] = 8599,
  [8600] = 8600,
  [8601] = 8601,
  [8602] = 8602,
  [8603] = 8603,
  [8604] = 8604,
  [8605] = 8605,
  [8606] = 8580,
  [8607] = 8591,
  [8608] = 8608,
  [8609] = 8609,
  [8610] = 8610,
  [8611] = 8611,
  [8612] = 8612,
  [8613] = 8613,
  [8614] = 8614,
  [8615] = 8615,
  [8616] = 8616,
  [8617] = 8617,
  [8618] = 8617,
  [8619] = 8619,
  [8620] = 8620,
  [8621] = 8621,
  [8622] = 8621,
  [8623] = 8582,
  [8624] = 8624,
  [8625] = 8625,
  [8626] = 8626,
  [8627] = 8627,
  [8628] = 8586,
  [8629] = 8629,
  [8630] = 8630,
  [8631] = 8631,
  [8632] = 8588,
  [8633] = 8598,
  [8634] = 8634,
  [8635] = 8635,
  [8636] = 8636,
  [8637] = 8637,
  [8638] = 8638,
  [8639] = 8639,
  [8640] = 8614,
  [8641] = 8641,
  [8642] = 8642,
  [8643] = 8643,
  [8644] = 8644,
  [8645] = 8582,
  [8646] = 8646,
  [8647] = 8647,
  [8648] = 8600,
  [8649] = 8649,
  [8650] = 8650,
  [8651] = 8651,
  [8652] = 8621,
  [8653] = 8653,
  [8654] = 8654,
  [8655] = 8655,
  [8656] = 8656,
  [8657] = 8657,
  [8658] = 8658,
  [8659] = 8659,
  [8660] = 8660,
  [8661] = 8583,
  [8662] = 8657,
  [8663] = 8663,
  [8664] = 8664,
  [8665] = 8665,
  [8666] = 8666,
  [8667] = 8629,
  [8668] = 8668,
  [8669] = 8669,
  [8670] = 8670,
  [8671] = 8671,
  [8672] = 8666,
  [8673] = 8673,
  [8674] = 8596,
  [8675] = 8675,
  [8676] = 8676,
  [8677] = 8624,
  [8678] = 8678,
  [8679] = 8679,
  [8680] = 8595,
  [8681] = 8588,
  [8682] = 8682,
  [8683] = 8586,
  [8684] = 8684,
  [8685] = 8685,
  [8686] = 8686,
  [8687] = 8616,
  [8688] = 8688,
  [8689] = 8689,
  [8690] = 8690,
  [8691] = 8636,
  [8692] = 8589,
  [8693] = 8693,
  [8694] = 8694,
  [8695] = 8695,
  [8696] = 8602,
  [8697] = 8697,
  [8698] = 8591,
  [8699] = 8699,
  [8700] = 8700,
  [8701] = 8701,
  [8702] = 8586,
  [8703] = 8703,
  [8704] = 8617,
  [8705] = 8705,
  [8706] = 8706,
  [8707] = 8657,
  [8708] = 8708,
  [8709] = 8639,
  [8710] = 8630,
  [8711] = 8665,
  [8712] = 8712,
  [8713] = 8594,
  [8714] = 8714,
  [8715] = 8715,
  [8716] = 8586,
  [8717] = 8717,
  [8718] = 8718,
  [8719] = 8670,
  [8720] = 8605,
  [8721] = 8580,
  [8722] = 8682,
  [8723] = 8616,
  [8724] = 8724,
  [8725] = 8596,
  [8726] = 8634,
  [8727] = 8727,
  [8728] = 8728,
  [8729] = 8637,
  [8730] = 8708,
  [8731] = 8731,
  [8732] = 8598,
  [8733] = 8630,
  [8734] = 8734,
  [8735] = 8665,
  [8736] = 8736,
  [8737] = 8737,
  [8738] = 8738,
  [8739] = 8643,
  [8740] = 8740,
  [8741] = 8701,
  [8742] = 8617,
  [8743] = 8586,
  [8744] = 8653,
  [8745] = 8745,
  [8746] = 8657,
  [8747] = 8670,
  [8748] = 8635,
  [8749] = 8749,
  [8750] = 8660,
  [8751] = 8693,
  [8752] = 8752,
  [8753] = 8631,
  [8754] = 8657,
  [8755] = 8639,
  [8756] = 8586,
  [8757] = 8583,
  [8758] = 8598,
  [8759] = 8635,
  [8760] = 8583,
  [8761] = 8600,
  [8762] = 8736,
  [8763] = 8581,
  [8764] = 8587,
  [8765] = 8684,
  [8766] = 8611,
  [8767] = 8767,
  [8768] = 8644,
  [8769] = 8624,
  [8770] = 8731,
  [8771] = 8771,
  [8772] = 8671,
  [8773] = 8694,
  [8774] = 8639,
  [8775] = 8775,
  [8776] = 8666,
  [8777] = 8699,
  [8778] = 8689,
  [8779] = 8701,
  [8780] = 8780,
  [8781] = 8666,
  [8782] = 8782,
  [8783] = 8668,
  [8784] = 8666,
  [8785] = 8785,
  [8786] = 8771,
  [8787] = 8596,
  [8788] = 8596,
  [8789] = 8594,
  [8790] = 8586,
  [8791] = 6217,
  [8792] = 8792,
  [8793] = 8596,
  [8794] = 8671,
  [8795] = 8605,
  [8796] = 8580,
  [8797] = 8598,
  [8798] = 8643,
  [8799] = 8799,
  [8800] = 8800,
  [8801] = 8634,
  [8802] = 8594,
  [8803] = 8803,
  [8804] = 8804,
  [8805] = 8660,
  [8806] = 8657,
  [8807] = 8807,
  [8808] = 8688,
  [8809] = 8586,
  [8810] = 8699,
  [8811] = 8595,
  [8812] = 2274,
  [8813] = 8630,
  [8814] = 8814,
  [8815] = 8624,
  [8816] = 8635,
  [8817] = 8583,
  [8818] = 8818,
  [8819] = 8684,
  [8820] = 8820,
  [8821] = 8731,
  [8822] = 8792,
  [8823] = 8823,
  [8824] = 8824,
  [8825] = 8694,
  [8826] = 8624,
  [8827] = 8581,
  [8828] = 8828,
  [8829] = 8829,
  [8830] = 8830,
  [8831] = 8701,
  [8832] = 8832,
  [8833] = 8734,
  [8834] = 8615,
  [8835] = 8588,
  [8836] = 8596,
  [8837] = 8837,
  [8838] = 8715,
  [8839] = 8839,
  [8840] = 8594,
  [8841] = 8708,
  [8842] = 8665,
  [8843] = 8598,
  [8844] = 8596,
  [8845] = 8845,
  [8846] = 8605,
  [8847] = 8580,
  [8848] = 8598,
  [8849] = 8643,
  [8850] = 8850,
  [8851] = 8731,
  [8852] = 8792,
  [8853] = 8599,
  [8854] = 8587,
  [8855] = 8590,
  [8856] = 8660,
  [8857] = 6273,
  [8858] = 8736,
  [8859] = 8614,
  [8860] = 8599,
  [8861] = 8861,
  [8862] = 8612,
  [8863] = 8621,
  [8864] = 8627,
  [8865] = 8865,
  [8866] = 8866,
  [8867] = 8637,
  [8868] = 8771,
  [8869] = 8594,
  [8870] = 8684,
  [8871] = 8598,
  [8872] = 8872,
  [8873] = 8873,
  [8874] = 8694,
  [8875] = 8600,
  [8876] = 8876,
  [8877] = 8682,
  [8878] = 8878,
  [8879] = 8631,
  [8880] = 8701,
  [8881] = 8699,
  [8882] = 8636,
  [8883] = 8872,
  [8884] = 8865,
  [8885] = 8885,
  [8886] = 8670,
  [8887] = 8653,
  [8888] = 8594,
  [8889] = 8731,
  [8890] = 8890,
  [8891] = 8639,
  [8892] = 8682,
  [8893] = 8596,
  [8894] = 8605,
  [8895] = 8580,
  [8896] = 8624,
  [8897] = 8715,
  [8898] = 8598,
  [8899] = 8738,
  [8900] = 6352,
  [8901] = 8605,
  [8902] = 8734,
  [8903] = 8580,
  [8904] = 8712,
  [8905] = 8818,
  [8906] = 8684,
  [8907] = 8907,
  [8908] = 8694,
  [8909] = 8909,
  [8910] = 8668,
  [8911] = 8694,
  [8912] = 8701,
  [8913] = 8913,
  [8914] = 8594,
  [8915] = 8671,
  [8916] = 8916,
  [8917] = 8580,
  [8918] = 8918,
  [8919] = 8668,
  [8920] = 8637,
  [8921] = 8589,
  [8922] = 8876,
  [8923] = 8671,
  [8924] = 8611,
  [8925] = 8780,
  [8926] = 8684,
  [8927] = 8693,
  [8928] = 8928,
  [8929] = 8699,
  [8930] = 8701,
  [8931] = 8703,
  [8932] = 8932,
  [8933] = 8580,
  [8934] = 8666,
  [8935] = 8935,
  [8936] = 8749,
  [8937] = 8937,
  [8938] = 8684,
  [8939] = 8701,
  [8940] = 8596,
  [8941] = 8580,
  [8942] = 8671,
  [8943] = 8694,
  [8944] = 8944,
  [8945] = 8945,
  [8946] = 8684,
  [8947] = 8701,
  [8948] = 8580,
  [8949] = 8668,
  [8950] = 8624,
  [8951] = 8951,
  [8952] = 8952,
  [8953] = 8684,
  [8954] = 8701,
  [8955] = 8580,
  [8956] = 8627,
  [8957] = 8586,
  [8958] = 8701,
  [8959] = 8580,
  [8960] = 8960,
  [8961] = 8845,
  [8962] = 8701,
  [8963] = 8580,
  [8964] = 8701,
  [8965] = 8580,
  [8966] = 8701,
  [8967] = 8580,
  [8968] = 8701,
  [8969] = 8580,
  [8970] = 8701,
  [8971] = 8580,
  [8972] = 8701,
  [8973] = 8734,
  [8974] = 8701,
  [8975] = 8580,
  [8976] = 8701,
  [8977] = 8580,
  [8978] = 8617,
  [8979] = 8630,
  [8980] = 8590,
  [8981] = 8981,
  [8982] = 8982,
  [8983] = 8650,
  [8984] = 8984,
  [8985] = 8985,
  [8986] = 8596,
  [8987] = 8612,
  [8988] = 8649,
  [8989] = 8598,
  [8990] = 8990,
  [8991] = 8818,
  [8992] = 8621,
  [8993] = 8993,
  [8994] = 8994,
  [8995] = 8708,
  [8996] = 8631,
  [8997] = 8598,
  [8998] = 8646,
  [8999] = 8596,
  [9000] = 9000,
  [9001] = 9001,
  [9002] = 9002,
  [9003] = 8678,
  [9004] = 8660,
  [9005] = 9005,
  [9006] = 9006,
  [9007] = 8686,
  [9008] = 8782,
  [9009] = 8708,
  [9010] = 8665,
  [9011] = 8670,
  [9012] = 8705,
  [9013] = 9013,
  [9014] = 9014,
  [9015] = 8602,
  [9016] = 8714,
  [9017] = 8651,
  [9018] = 8621,
  [9019] = 9019,
  [9020] = 9020,
  [9021] = 8724,
  [9022] = 9022,
  [9023] = 8736,
  [9024] = 8639,
  [9025] = 8583,
  [9026] = 9026,
  [9027] = 8738,
  [9028] = 9028,
  [9029] = 9029,
  [9030] = 8589,
  [9031] = 8708,
  [9032] = 8740,
  [9033] = 8583,
  [9034] = 8635,
  [9035] = 8665,
  [9036] = 8598,
  [9037] = 8771,
  [9038] = 9038,
  [9039] = 9039,
  [9040] = 9040,
  [9041] = 8637,
  [9042] = 9042,
  [9043] = 8670,
  [9044] = 8935,
  [9045] = 8639,
  [9046] = 8599,
  [9047] = 8752,
  [9048] = 9048,
  [9049] = 8799,
  [9050] = 8684,
  [9051] = 8602,
  [9052] = 8865,
  [9053] = 8693,
  [9054] = 8731,
  [9055] = 8697,
  [9056] = 8596,
  [9057] = 8598,
  [9058] = 9058,
  [9059] = 9059,
  [9060] = 8602,
  [9061] = 9061,
  [9062] = 8591,
  [9063] = 8602,
  [9064] = 8603,
  [9065] = 9065,
  [9066] = 8666,
  [9067] = 9067,
  [9068] = 8595,
  [9069] = 8665,
  [9070] = 8668,
  [9071] = 8670,
  [9072] = 8736,
  [9073] = 9073,
  [9074] = 9074,
  [9075] = 9075,
  [9076] = 8624,
  [9077] = 8818,
  [9078] = 8615,
  [9079] = 9079,
  [9080] = 8984,
  [9081] = 8583,
  [9082] = 8596,
  [9083] = 8630,
  [9084] = 8639,
  [9085] = 8664,
  [9086] = 8617,
  [9087] = 8596,
  [9088] = 8688,
  [9089] = 8598,
  [9090] = 8792,
  [9091] = 9028,
  [9092] = 8699,
  [9093] = 9093,
  [9094] = 9094,
  [9095] = 8631,
  [9096] = 8598,
  [9097] = 9097,
  [9098] = 9098,
  [9099] = 8591,
  [9100] = 8629,
  [9101] = 9101,
  [9102] = 9102,
  [9103] = 8664,
  [9104] = 9029,
  [9105] = 8635,
  [9106] = 8616,
  [9107] = 8603,
  [9108] = 8985,
  [9109] = 8624,
  [9110] = 9110,
  [9111] = 8643,
  [9112] = 8818,
  [9113] = 8839,
  [9114] = 8708,
  [9115] = 8671,
  [9116] = 9116,
  [9117] = 8688,
  [9118] = 8588,
  [9119] = 8588,
  [9120] = 9120,
  [9121] = 8734,
  [9122] = 9122,
  [9123] = 9123,
  [9124] = 9124,
  [9125] = 8589,
  [9126] = 8588,
  [9127] = 8682,
  [9128] = 9128,
  [9129] = 8581,
  [9130] = 8865,
  [9131] = 8603,
  [9132] = 8605,
  [9133] = 8818,
  [9134] = 9134,
  [9135] = 8624,
  [9136] = 8671,
  [9137] = 8596,
  [9138] = 8712,
  [9139] = 8598,
  [9140] = 8767,
  [9141] = 9141,
  [9142] = 8839,
  [9143] = 8670,
  [9144] = 8588,
  [9145] = 8617,
  [9146] = 8651,
  [9147] = 8587,
  [9148] = 9148,
  [9149] = 8671,
  [9150] = 8596,
  [9151] = 9151,
  [9152] = 9152,
  [9153] = 8624,
  [9154] = 9154,
  [9155] = 8818,
  [9156] = 8598,
  [9157] = 8643,
  [9158] = 8644,
  [9159] = 8588,
  [9160] = 9160,
  [9161] = 9161,
  [9162] = 8614,
  [9163] = 9163,
  [9164] = 8682,
  [9165] = 8588,
  [9166] = 8993,
  [9167] = 8664,
  [9168] = 8688,
  [9169] = 8602,
  [9170] = 8591,
  [9171] = 8602,
  [9172] = 8621,
  [9173] = 8602,
  [9174] = 8591,
  [9175] = 8641,
  [9176] = 8771,
  [9177] = 9177,
  [9178] = 8596,
  [9179] = 8598,
  [9180] = 8617,
  [9181] = 9006,
  [9182] = 8602,
  [9183] = 8637,
  [9184] = 9184,
  [9185] = 8616,
  [9186] = 8665,
  [9187] = 9187,
  [9188] = 8708,
  [9189] = 8596,
  [9190] = 8634,
  [9191] = 8731,
  [9192] = 8617,
  [9193] = 8653,
  [9194] = 8602,
  [9195] = 8785,
  [9196] = 8643,
  [9197] = 8644,
  [9198] = 9198,
  [9199] = 9199,
  [9200] = 8581,
  [9201] = 8678,
  [9202] = 9202,
  [9203] = 8981,
  [9204] = 8587,
  [9205] = 8984,
  [9206] = 8985,
  [9207] = 9207,
  [9208] = 9208,
  [9209] = 8649,
  [9210] = 8634,
  [9211] = 8990,
  [9212] = 9212,
  [9213] = 9213,
  [9214] = 8611,
  [9215] = 8708,
  [9216] = 9216,
  [9217] = 9217,
  [9218] = 9218,
  [9219] = 9006,
  [9220] = 8616,
  [9221] = 8782,
  [9222] = 8665,
  [9223] = 8651,
  [9224] = 8657,
  [9225] = 8657,
  [9226] = 9013,
  [9227] = 9014,
  [9228] = 9228,
  [9229] = 8621,
  [9230] = 8583,
  [9231] = 8588,
  [9232] = 9029,
  [9233] = 8637,
  [9234] = 9013,
  [9235] = 8583,
  [9236] = 8583,
  [9237] = 8734,
  [9238] = 8935,
  [9239] = 8799,
  [9240] = 8771,
  [9241] = 9014,
  [9242] = 8981,
  [9243] = 8984,
  [9244] = 8649,
  [9245] = 8582,
  [9246] = 8990,
  [9247] = 9247,
  [9248] = 8686,
  [9249] = 9006,
  [9250] = 8731,
  [9251] = 8782,
  [9252] = 8660,
  [9253] = 8653,
  [9254] = 8705,
  [9255] = 9013,
  [9256] = 9014,
  [9257] = 9029,
  [9258] = 7462,
  [9259] = 8699,
  [9260] = 8670,
  [9261] = 8935,
  [9262] = 8799,
  [9263] = 9263,
  [9264] = 8981,
  [9265] = 8984,
  [9266] = 8649,
  [9267] = 8682,
  [9268] = 8990,
  [9269] = 8631,
  [9270] = 8629,
  [9271] = 9006,
  [9272] = 8782,
  [9273] = 8734,
  [9274] = 8635,
  [9275] = 9013,
  [9276] = 9014,
  [9277] = 9029,
  [9278] = 8660,
  [9279] = 8598,
  [9280] = 8611,
  [9281] = 8935,
  [9282] = 8799,
  [9283] = 8614,
  [9284] = 8981,
  [9285] = 8984,
  [9286] = 8649,
  [9287] = 8708,
  [9288] = 8990,
  [9289] = 8586,
  [9290] = 8714,
  [9291] = 8782,
  [9292] = 8639,
  [9293] = 8617,
  [9294] = 9013,
  [9295] = 9014,
  [9296] = 9029,
  [9297] = 8708,
  [9298] = 8646,
  [9299] = 8688,
  [9300] = 8935,
  [9301] = 8799,
  [9302] = 8671,
  [9303] = 8981,
  [9304] = 8984,
  [9305] = 8649,
  [9306] = 8736,
  [9307] = 8990,
  [9308] = 8703,
  [9309] = 8724,
  [9310] = 8782,
  [9311] = 8671,
  [9312] = 8701,
  [9313] = 9013,
  [9314] = 9014,
  [9315] = 9029,
  [9316] = 8839,
  [9317] = 8651,
  [9318] = 8688,
  [9319] = 8935,
  [9320] = 8799,
  [9321] = 8693,
  [9322] = 8981,
  [9323] = 8984,
  [9324] = 8649,
  [9325] = 8616,
  [9326] = 8990,
  [9327] = 8631,
  [9328] = 8782,
  [9329] = 8580,
  [9330] = 9014,
  [9331] = 9029,
  [9332] = 8598,
  [9333] = 8697,
  [9334] = 8935,
  [9335] = 8799,
  [9336] = 6224,
  [9337] = 8981,
  [9338] = 8984,
  [9339] = 8878,
  [9340] = 8990,
  [9341] = 8603,
  [9342] = 8740,
  [9343] = 9014,
  [9344] = 8771,
  [9345] = 8935,
  [9346] = 8981,
  [9347] = 8984,
  [9348] = 8990,
  [9349] = 9014,
  [9350] = 8935,
  [9351] = 8981,
  [9352] = 8984,
  [9353] = 8990,
  [9354] = 9014,
  [9355] = 8935,
  [9356] = 8981,
  [9357] = 8984,
  [9358] = 8990,
  [9359] = 9014,
  [9360] = 8935,
  [9361] = 8984,
  [9362] = 9014,
  [9363] = 8935,
  [9364] = 8984,
  [9365] = 9014,
  [9366] = 8935,
  [9367] = 9014,
  [9368] = 8935,
  [9369] = 9014,
  [9370] = 8935,
  [9371] = 9014,
  [9372] = 8935,
  [9373] = 9014,
  [9374] = 8935,
  [9375] = 9014,
  [9376] = 8935,
  [9377] = 9014,
  [9378] = 8935,
  [9379] = 9014,
  [9380] = 8935,
  [9381] = 8736,
  [9382] = 8624,
  [9383] = 8985,
  [9384] = 8775,
  [9385] = 8800,
  [9386] = 8780,
  [9387] = 9387,
  [9388] = 8666,
  [9389] = 8596,
  [9390] = 8588,
  [9391] = 8708,
  [9392] = 8595,
  [9393] = 8664,
  [9394] = 8749,
  [9395] = 9395,
  [9396] = 9028,
  [9397] = 9128,
  [9398] = 9398,
  [9399] = 8614,
  [9400] = 8708,
  [9401] = 8615,
  [9402] = 8792,
  [9403] = 8665,
  [9404] = 8586,
  [9405] = 8670,
  [9406] = 8639,
  [9407] = 8630,
  [9408] = 8872,
  [9409] = 9409,
  [9410] = 9410,
  [9411] = 8771,
  [9412] = 9412,
  [9413] = 8780,
  [9414] = 8635,
  [9415] = 8752,
  [9416] = 8715,
  [9417] = 8602,
  [9418] = 9418,
  [9419] = 8602,
  [9420] = 8734,
  [9421] = 8657,
  [9422] = 8708,
  [9423] = 8981,
  [9424] = 8646,
  [9425] = 8684,
  [9426] = 8734,
  [9427] = 8581,
  [9428] = 8591,
  [9429] = 8583,
  [9430] = 9430,
  [9431] = 8651,
  [9432] = 8587,
  [9433] = 8985,
  [9434] = 8775,
  [9435] = 8800,
  [9436] = 8611,
  [9437] = 8624,
  [9438] = 8697,
  [9439] = 9028,
  [9440] = 9128,
  [9441] = 9441,
  [9442] = 8865,
  [9443] = 8708,
  [9444] = 8665,
  [9445] = 8985,
  [9446] = 8775,
  [9447] = 8800,
  [9448] = 8818,
  [9449] = 8670,
  [9450] = 9028,
  [9451] = 9128,
  [9452] = 8639,
  [9453] = 8581,
  [9454] = 8752,
  [9455] = 8775,
  [9456] = 8800,
  [9457] = 8617,
  [9458] = 9458,
  [9459] = 9028,
  [9460] = 9128,
  [9461] = 8598,
  [9462] = 8666,
  [9463] = 8775,
  [9464] = 8800,
  [9465] = 8587,
  [9466] = 8689,
  [9467] = 9028,
  [9468] = 9128,
  [9469] = 8736,
  [9470] = 8775,
  [9471] = 8800,
  [9472] = 8617,
  [9473] = 8668,
  [9474] = 9028,
  [9475] = 9128,
  [9476] = 8865,
  [9477] = 8614,
  [9478] = 8736,
  [9479] = 9028,
  [9480] = 9128,
  [9481] = 8657,
  [9482] = 8865,
  [9483] = 9128,
  [9484] = 8589,
  [9485] = 9128,
  [9486] = 8693,
  [9487] = 9128,
  [9488] = 8694,
  [9489] = 9128,
  [9490] = 8602,
  [9491] = 9128,
  [9492] = 8611,
  [9493] = 9128,
  [9494] = 8629,
  [9495] = 9128,
  [9496] = 8671,
  [9497] = 9128,
  [9498] = 8602,
  [9499] = 9128,
  [9500] = 9500,
  [9501] = 9128,
  [9502] = 8657,
  [9503] = 9128,
  [9504] = 8701,
  [9505] = 9128,
  [9506] = 9506,
  [9507] = 9128,
  [9508] = 8673,
  [9509] = 9228,
  [9510] = 2283,
  [9511] = 8673,
  [9512] = 9228,
  [9513] = 8596,
  [9514] = 8673,
  [9515] = 9228,
  [9516] = 8684,
  [9517] = 8673,
  [9518] = 9228,
  [9519] = 8651,
  [9520] = 8673,
  [9521] = 9228,
  [9522] = 9522,
  [9523] = 8673,
  [9524] = 9228,
  [9525] = 8990,
  [9526] = 8673,
  [9527] = 9228,
  [9528] = 8771,
  [9529] = 9228,
  [9530] = 9228,
  [9531] = 9228,
  [9532] = 9228,
  [9533] = 9228,
  [9534] = 9228,
  [9535] = 9228,
  [9536] = 9228,
  [9537] = 9228,
  [9538] = 9228,
  [9539] = 9228,
  [9540] = 9228,
  [9541] = 9228,
  [9542] = 9542,
  [9543] = 8599,
  [9544] = 9544,
  [9545] = 8603,
  [9546] = 8657,
  [9547] = 8845,
  [9548] = 8615,
  [9549] = 8737,
  [9550] = 8737,
  [9551] = 8737,
  [9552] = 8737,
  [9553] = 8737,
  [9554] = 8737,
  [9555] = 8737,
  [9556] = 8624,
};

static const TSSymbol ts_supertype_symbols[SUPERTYPE_COUNT] = {
  sym__abstract_declarator,
  sym__declarator,
  sym__field_declarator,
  sym__type_declarator,
  sym_expression,
  sym_statement,
  sym_type_specifier,
};

static const TSMapSlice ts_supertype_map_slices[] = {
  [sym__abstract_declarator] = {.index = 0, .length = 5},
  [sym__declarator] = {.index = 5, .length = 12},
  [sym__field_declarator] = {.index = 17, .length = 20},
  [sym__type_declarator] = {.index = 37, .length = 19},
  [sym_expression] = {.index = 56, .length = 41},
  [sym_statement] = {.index = 97, .length = 21},
  [sym_type_specifier] = {.index = 118, .length = 15},
};

static const TSSymbol ts_supertype_map_entries[] = {
  [0] =
    sym_abstract_array_declarator,
    sym_abstract_function_declarator,
    sym_abstract_parenthesized_declarator,
    sym_abstract_pointer_declarator,
    sym_abstract_reference_declarator,
  [5] =
    sym_array_declarator,
    sym_attributed_declarator,
    sym_destructor_name,
    sym_function_declarator,
    sym_identifier,
    sym_operator_name,
    sym_parenthesized_declarator,
    sym_pointer_declarator,
    sym_qualified_identifier,
    sym_reference_declarator,
    sym_structured_binding_declarator,
    sym_template_function,
  [17] =
    alias_sym_field_identifier,
    sym_array_declarator,
    sym_array_field_declarator,
    sym_array_type_declarator,
    sym_attributed_declarator,
    sym_attributed_field_declarator,
    sym_attributed_type_declarator,
    sym_function_declarator,
    sym_function_field_declarator,
    sym_function_type_declarator,
    sym_operator_name,
    sym_parenthesized_declarator,
    sym_parenthesized_field_declarator,
    sym_parenthesized_type_declarator,
    sym_pointer_declarator,
    sym_reference_declarator,
    sym_reference_field_declarator,
    sym_reference_type_declarator,
    sym_template_method,
    sym_variadic_reference_declarator,
  [37] =
    alias_sym_type_identifier,
    sym_array_declarator,
    sym_array_field_declarator,
    sym_array_type_declarator,
    sym_attributed_declarator,
    sym_attributed_field_declarator,
    sym_attributed_type_declarator,
    sym_function_declarator,
    sym_function_field_declarator,
    sym_function_type_declarator,
    sym_parenthesized_declarator,
    sym_parenthesized_field_declarator,
    sym_parenthesized_type_declarator,
    sym_pointer_declarator,
    sym_primitive_type,
    sym_reference_declarator,
    sym_reference_field_declarator,
    sym_reference_type_declarator,
    sym_variadic_reference_declarator,
  [56] =
    sym_alignof_expression,
    sym_assignment_expression,
    sym_binary_expression,
    sym_call_expression,
    sym_cast_expression,
    sym_char_literal,
    sym_co_await_expression,
    sym_compound_literal_expression,
    sym_concatenated_string,
    sym_conditional_expression,
    sym_delete_expression,
    sym_extension_expression,
    sym_false,
    sym_field_expression,
    sym_fold_expression,
    sym_generic_expression,
    sym_gnu_asm_expression,
    sym_identifier,
    sym_kernel_call_expression,
    sym_lambda_expression,
    sym_new_expression,
    sym_null,
    sym_number_literal,
    sym_offsetof_expression,
    sym_parameter_pack_expansion,
    sym_parenthesized_expression,
    sym_pointer_expression,
    sym_preproc_call_expression,
    sym_qualified_identifier,
    sym_raw_string_literal,
    sym_requires_clause,
    sym_requires_expression,
    sym_sizeof_expression,
    sym_string_literal,
    sym_subscript_expression,
    sym_template_function,
    sym_this,
    sym_true,
    sym_unary_expression,
    sym_update_expression,
    sym_user_defined_literal,
  [97] =
    sym_attributed_statement,
    sym_break_statement,
    sym_case_statement,
    sym_co_return_statement,
    sym_co_yield_statement,
    sym_compound_statement,
    sym_continue_statement,
    sym_do_statement,
    sym_expression_statement,
    sym_for_range_loop,
    sym_for_statement,
    sym_goto_statement,
    sym_if_statement,
    sym_labeled_statement,
    sym_return_statement,
    sym_seh_leave_statement,
    sym_seh_try_statement,
    sym_switch_statement,
    sym_throw_statement,
    sym_try_statement,
    sym_while_statement,
  [118] =
    alias_sym_type_identifier,
    sym_class_specifier,
    sym_decltype,
    sym_dependent_type,
    sym_enum_specifier,
    sym_placeholder_type_specifier,
    sym_primitive_type,
    sym_qualified_field_identifier,
    sym_qualified_identifier,
    sym_qualified_operator_cast_identifier,
    sym_qualified_type_identifier,
    sym_sized_type_specifier,
    sym_struct_specifier,
    sym_template_type,
    sym_union_specifier,
};

static const TSCharacterRange sym_identifier_character_set_1[] = {
  {'$', '$'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xba},
  {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374},
  {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5},
  {0x3f7, 0x481}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a},
  {0x66e, 0x66f}, {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710},
  {0x712, 0x72f}, {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a},
  {0x824, 0x824}, {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939},
  {0x93d, 0x93d}, {0x950, 0x950}, {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0},
  {0x9b2, 0x9b2}, {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc},
  {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c},
  {0xa5e, 0xa5e}, {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9},
  {0xabd, 0xabd}, {0xad0, 0xad0}, {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30},
  {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a},
  {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9},
  {0xbd0, 0xbd0}, {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d},
  {0xc60, 0xc61}, {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd},
  {0xcdd, 0xcde}, {0xce0, 0xce1}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e},
  {0xd54, 0xd56}, {0xd5f, 0xd61}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6},
  {0xe01, 0xe30}, {0xe32, 0xe32}, {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5},
  {0xea7, 0xeb0}, {0xeb2, 0xeb2}, {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47},
  {0xf49, 0xf6c}, {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066},
  {0x106e, 0x1070}, {0x1075, 0x1081}, {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248},
  {0x124a, 0x124d}, {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5},
  {0x12b8, 0x12be}, {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f},
  {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711},
  {0x171f, 0x1731}, {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878},
  {0x1880, 0x18a8}, {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9},
  {0x1a00, 0x1a16}, {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5},
  {0x1c00, 0x1c23}, {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c8a}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3},
  {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57},
  {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f},
  {0x2090, 0x209c}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126},
  {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee},
  {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6},
  {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x3005, 0x3007},
  {0x3021, 0x3029}, {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f},
  {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f},
  {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7cd}, {0xa7d0, 0xa7d1},
  {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7dc}, {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3},
  {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf},
  {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a},
  {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea},
  {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69},
  {0xab70, 0xabe2}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17},
  {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1},
  {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77},
  {0xfe79, 0xfe79}, {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xff9d}, {0xffa0, 0xffbe},
  {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d},
  {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a},
  {0x10350, 0x10375}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb},
  {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1},
  {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x105c0, 0x105f3}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0},
  {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876},
  {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a00},
  {0x10a10, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10b00, 0x10b35},
  {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d23}, {0x10d4a, 0x10d65},
  {0x10d6f, 0x10d85}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10ec2, 0x10ec4}, {0x10f00, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f45}, {0x10f70, 0x10f81},
  {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11071, 0x11072}, {0x11075, 0x11075}, {0x11083, 0x110af}, {0x110d0, 0x110e8}, {0x11103, 0x11126},
  {0x11144, 0x11144}, {0x11147, 0x11147}, {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2}, {0x111c1, 0x111c4}, {0x111da, 0x111da}, {0x111dc, 0x111dc},
  {0x11200, 0x11211}, {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8},
  {0x112b0, 0x112de}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133d, 0x1133d},
  {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11380, 0x11389}, {0x1138b, 0x1138b}, {0x1138e, 0x1138e}, {0x11390, 0x113b5}, {0x113b7, 0x113b7}, {0x113d1, 0x113d1},
  {0x113d3, 0x113d3}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x1145f, 0x11461}, {0x11480, 0x114af}, {0x114c4, 0x114c5}, {0x114c7, 0x114c7}, {0x11580, 0x115ae},
  {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11680, 0x116aa}, {0x116b8, 0x116b8}, {0x11700, 0x1171a}, {0x11740, 0x11746}, {0x11800, 0x1182b},
  {0x118a0, 0x118df}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941},
  {0x119a0, 0x119a7}, {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3}, {0x11a00, 0x11a00}, {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50},
  {0x11a5c, 0x11a89}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11bc0, 0x11be0}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c2e}, {0x11c40, 0x11c40}, {0x11c72, 0x11c8f},
  {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d89}, {0x11d98, 0x11d98},
  {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543},
  {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13441, 0x13446}, {0x13460, 0x143fa}, {0x14400, 0x14646}, {0x16100, 0x1611d}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e},
  {0x16a70, 0x16abe}, {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16d40, 0x16d6c}, {0x16e40, 0x16e7f},
  {0x16f00, 0x16f4a}, {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18cff, 0x18d08},
  {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167},
  {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f},
  {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a},
  {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5},
  {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788},
  {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d},
  {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e4d0, 0x1e4eb}, {0x1e5d0, 0x1e5ed}, {0x1e5f0, 0x1e5f0}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb},
  {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e900, 0x1e943}, {0x1e94b, 0x1e94b}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22},
  {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47},
  {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b},
  {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c},
  {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739},
  {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static const TSCharacterRange sym_identifier_character_set_2[] = {
  {'$', '$'}, {'0', '9'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5},
  {0xb7, 0xb7}, {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec},
  {0x2ee, 0x2ee}, {0x300, 0x374}, {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1},
  {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x483, 0x487}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x591, 0x5bd},
  {0x5bf, 0x5bf}, {0x5c1, 0x5c2}, {0x5c4, 0x5c5}, {0x5c7, 0x5c7}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x610, 0x61a}, {0x620, 0x669},
  {0x66e, 0x6d3}, {0x6d5, 0x6dc}, {0x6df, 0x6e8}, {0x6ea, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x74a}, {0x74d, 0x7b1}, {0x7c0, 0x7f5},
  {0x7fa, 0x7fa}, {0x7fd, 0x7fd}, {0x800, 0x82d}, {0x840, 0x85b}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x897, 0x8e1},
  {0x8e3, 0x963}, {0x966, 0x96f}, {0x971, 0x983}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2},
  {0x9b6, 0x9b9}, {0x9bc, 0x9c4}, {0x9c7, 0x9c8}, {0x9cb, 0x9ce}, {0x9d7, 0x9d7}, {0x9dc, 0x9dd}, {0x9df, 0x9e3}, {0x9e6, 0x9f1},
  {0x9fc, 0x9fc}, {0x9fe, 0x9fe}, {0xa01, 0xa03}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33},
  {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa3c, 0xa3c}, {0xa3e, 0xa42}, {0xa47, 0xa48}, {0xa4b, 0xa4d}, {0xa51, 0xa51}, {0xa59, 0xa5c},
  {0xa5e, 0xa5e}, {0xa66, 0xa75}, {0xa81, 0xa83}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3},
  {0xab5, 0xab9}, {0xabc, 0xac5}, {0xac7, 0xac9}, {0xacb, 0xacd}, {0xad0, 0xad0}, {0xae0, 0xae3}, {0xae6, 0xaef}, {0xaf9, 0xaff},
  {0xb01, 0xb03}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3c, 0xb44},
  {0xb47, 0xb48}, {0xb4b, 0xb4d}, {0xb55, 0xb57}, {0xb5c, 0xb5d}, {0xb5f, 0xb63}, {0xb66, 0xb6f}, {0xb71, 0xb71}, {0xb82, 0xb83},
  {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa},
  {0xbae, 0xbb9}, {0xbbe, 0xbc2}, {0xbc6, 0xbc8}, {0xbca, 0xbcd}, {0xbd0, 0xbd0}, {0xbd7, 0xbd7}, {0xbe6, 0xbef}, {0xc00, 0xc0c},
  {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3c, 0xc44}, {0xc46, 0xc48}, {0xc4a, 0xc4d}, {0xc55, 0xc56}, {0xc58, 0xc5a},
  {0xc5d, 0xc5d}, {0xc60, 0xc63}, {0xc66, 0xc6f}, {0xc80, 0xc83}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3},
  {0xcb5, 0xcb9}, {0xcbc, 0xcc4}, {0xcc6, 0xcc8}, {0xcca, 0xccd}, {0xcd5, 0xcd6}, {0xcdd, 0xcde}, {0xce0, 0xce3}, {0xce6, 0xcef},
  {0xcf1, 0xcf3}, {0xd00, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd44}, {0xd46, 0xd48}, {0xd4a, 0xd4e}, {0xd54, 0xd57}, {0xd5f, 0xd63},
  {0xd66, 0xd6f}, {0xd7a, 0xd7f}, {0xd81, 0xd83}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6},
  {0xdca, 0xdca}, {0xdcf, 0xdd4}, {0xdd6, 0xdd6}, {0xdd8, 0xddf}, {0xde6, 0xdef}, {0xdf2, 0xdf3}, {0xe01, 0xe3a}, {0xe40, 0xe4e},
  {0xe50, 0xe59}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xebd}, {0xec0, 0xec4},
  {0xec6, 0xec6}, {0xec8, 0xece}, {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf18, 0xf19}, {0xf20, 0xf29}, {0xf35, 0xf35},
  {0xf37, 0xf37}, {0xf39, 0xf39}, {0xf3e, 0xf47}, {0xf49, 0xf6c}, {0xf71, 0xf84}, {0xf86, 0xf97}, {0xf99, 0xfbc}, {0xfc6, 0xfc6},
  {0x1000, 0x1049}, {0x1050, 0x109d}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d},
  {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be},
  {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x135d, 0x135f}, {0x1369, 0x1371},
  {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8},
  {0x1700, 0x1715}, {0x171f, 0x1734}, {0x1740, 0x1753}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1772, 0x1773}, {0x1780, 0x17d3}, {0x17d7, 0x17d7},
  {0x17dc, 0x17dd}, {0x17e0, 0x17e9}, {0x180b, 0x180d}, {0x180f, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e},
  {0x1920, 0x192b}, {0x1930, 0x193b}, {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a1b},
  {0x1a20, 0x1a5e}, {0x1a60, 0x1a7c}, {0x1a7f, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1ab0, 0x1abd}, {0x1abf, 0x1ace}, {0x1b00, 0x1b4c},
  {0x1b50, 0x1b59}, {0x1b6b, 0x1b73}, {0x1b80, 0x1bf3}, {0x1c00, 0x1c37}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c8a}, {0x1c90, 0x1cba},
  {0x1cbd, 0x1cbf}, {0x1cd0, 0x1cd2}, {0x1cd4, 0x1cfa}, {0x1d00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57},
  {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x200c, 0x200d}, {0x203f, 0x2040},
  {0x2054, 0x2054}, {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c}, {0x20d0, 0x20dc}, {0x20e1, 0x20e1}, {0x20e5, 0x20f0}, {0x2102, 0x2102},
  {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139},
  {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27},
  {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d7f, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe},
  {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2de0, 0x2dff}, {0x3005, 0x3007}, {0x3021, 0x302f}, {0x3031, 0x3035},
  {0x3038, 0x303c}, {0x3041, 0x3096}, {0x3099, 0x309a}, {0x309d, 0x309f}, {0x30a1, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf},
  {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66f}, {0xa674, 0xa67d},
  {0xa67f, 0xa6f1}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7cd}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7dc}, {0xa7f2, 0xa827},
  {0xa82c, 0xa82c}, {0xa840, 0xa873}, {0xa880, 0xa8c5}, {0xa8d0, 0xa8d9}, {0xa8e0, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa92d}, {0xa930, 0xa953},
  {0xa960, 0xa97c}, {0xa980, 0xa9c0}, {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9fe}, {0xaa00, 0xaa36}, {0xaa40, 0xaa4d}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76},
  {0xaa7a, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaef}, {0xaaf2, 0xaaf6}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26},
  {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabea}, {0xabec, 0xabed}, {0xabf0, 0xabf9}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6},
  {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c},
  {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7},
  {0xfdf0, 0xfdf9}, {0xfe00, 0xfe0f}, {0xfe20, 0xfe2f}, {0xfe33, 0xfe34}, {0xfe4d, 0xfe4f}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77},
  {0xfe79, 0xfe79}, {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff3f, 0xff3f}, {0xff41, 0xff5a},
  {0xff65, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a},
  {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x101fd, 0x101fd}, {0x10280, 0x1029c}, {0x102a0, 0x102d0},
  {0x102e0, 0x102e0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x1037a}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5},
  {0x10400, 0x1049d}, {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a},
  {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x105c0, 0x105f3}, {0x10600, 0x10736},
  {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835},
  {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915},
  {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a03}, {0x10a05, 0x10a06}, {0x10a0c, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35},
  {0x10a38, 0x10a3a}, {0x10a3f, 0x10a3f}, {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae6}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55},
  {0x10b60, 0x10b72}, {0x10b80, 0x10b91}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d27}, {0x10d30, 0x10d39}, {0x10d40, 0x10d65},
  {0x10d69, 0x10d6d}, {0x10d6f, 0x10d85}, {0x10e80, 0x10ea9}, {0x10eab, 0x10eac}, {0x10eb0, 0x10eb1}, {0x10ec2, 0x10ec4}, {0x10efc, 0x10f1c}, {0x10f27, 0x10f27},
  {0x10f30, 0x10f50}, {0x10f70, 0x10f85}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11000, 0x11046}, {0x11066, 0x11075}, {0x1107f, 0x110ba}, {0x110c2, 0x110c2},
  {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11100, 0x11134}, {0x11136, 0x1113f}, {0x11144, 0x11147}, {0x11150, 0x11173}, {0x11176, 0x11176}, {0x11180, 0x111c4},
  {0x111c9, 0x111cc}, {0x111ce, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x11237}, {0x1123e, 0x11241}, {0x11280, 0x11286}, {0x11288, 0x11288},
  {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112ea}, {0x112f0, 0x112f9}, {0x11300, 0x11303}, {0x11305, 0x1130c}, {0x1130f, 0x11310},
  {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133b, 0x11344}, {0x11347, 0x11348}, {0x1134b, 0x1134d}, {0x11350, 0x11350},
  {0x11357, 0x11357}, {0x1135d, 0x11363}, {0x11366, 0x1136c}, {0x11370, 0x11374}, {0x11380, 0x11389}, {0x1138b, 0x1138b}, {0x1138e, 0x1138e}, {0x11390, 0x113b5},
  {0x113b7, 0x113c0}, {0x113c2, 0x113c2}, {0x113c5, 0x113c5}, {0x113c7, 0x113ca}, {0x113cc, 0x113d3}, {0x113e1, 0x113e2}, {0x11400, 0x1144a}, {0x11450, 0x11459},
  {0x1145e, 0x11461}, {0x11480, 0x114c5}, {0x114c7, 0x114c7}, {0x114d0, 0x114d9}, {0x11580, 0x115b5}, {0x115b8, 0x115c0}, {0x115d8, 0x115dd}, {0x11600, 0x11640},
  {0x11644, 0x11644}, {0x11650, 0x11659}, {0x11680, 0x116b8}, {0x116c0, 0x116c9}, {0x116d0, 0x116e3}, {0x11700, 0x1171a}, {0x1171d, 0x1172b}, {0x11730, 0x11739},
  {0x11740, 0x11746}, {0x11800, 0x1183a}, {0x118a0, 0x118e9}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x11935},
  {0x11937, 0x11938}, {0x1193b, 0x11943}, {0x11950, 0x11959}, {0x119a0, 0x119a7}, {0x119aa, 0x119d7}, {0x119da, 0x119e1}, {0x119e3, 0x119e4}, {0x11a00, 0x11a3e},
  {0x11a47, 0x11a47}, {0x11a50, 0x11a99}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11bc0, 0x11be0}, {0x11bf0, 0x11bf9}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c36},
  {0x11c38, 0x11c40}, {0x11c50, 0x11c59}, {0x11c72, 0x11c8f}, {0x11c92, 0x11ca7}, {0x11ca9, 0x11cb6}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d36},
  {0x11d3a, 0x11d3a}, {0x11d3c, 0x11d3d}, {0x11d3f, 0x11d47}, {0x11d50, 0x11d59}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d8e}, {0x11d90, 0x11d91},
  {0x11d93, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef6}, {0x11f00, 0x11f10}, {0x11f12, 0x11f3a}, {0x11f3e, 0x11f42}, {0x11f50, 0x11f5a}, {0x11fb0, 0x11fb0},
  {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13440, 0x13455}, {0x13460, 0x143fa}, {0x14400, 0x14646},
  {0x16100, 0x16139}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe}, {0x16ac0, 0x16ac9}, {0x16ad0, 0x16aed}, {0x16af0, 0x16af4},
  {0x16b00, 0x16b36}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16d40, 0x16d6c}, {0x16d70, 0x16d79}, {0x16e40, 0x16e7f},
  {0x16f00, 0x16f4a}, {0x16f4f, 0x16f87}, {0x16f8f, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe4}, {0x16ff0, 0x16ff1}, {0x17000, 0x187f7}, {0x18800, 0x18cd5},
  {0x18cff, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155},
  {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1bc9d, 0x1bc9e}, {0x1ccf0, 0x1ccf9},
  {0x1cf00, 0x1cf2d}, {0x1cf30, 0x1cf46}, {0x1d165, 0x1d169}, {0x1d16d, 0x1d172}, {0x1d17b, 0x1d182}, {0x1d185, 0x1d18b}, {0x1d1aa, 0x1d1ad}, {0x1d242, 0x1d244},
  {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb},
  {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544},
  {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734},
  {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1da00, 0x1da36},
  {0x1da3b, 0x1da6c}, {0x1da75, 0x1da75}, {0x1da84, 0x1da84}, {0x1da9b, 0x1da9f}, {0x1daa1, 0x1daaf}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e000, 0x1e006},
  {0x1e008, 0x1e018}, {0x1e01b, 0x1e021}, {0x1e023, 0x1e024}, {0x1e026, 0x1e02a}, {0x1e030, 0x1e06d}, {0x1e08f, 0x1e08f}, {0x1e100, 0x1e12c}, {0x1e130, 0x1e13d},
  {0x1e140, 0x1e149}, {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ae}, {0x1e2c0, 0x1e2f9}, {0x1e4d0, 0x1e4f9}, {0x1e5d0, 0x1e5fa}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb},
  {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e8d0, 0x1e8d6}, {0x1e900, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f},
  {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42},
  {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59},
  {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77},
  {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x1fbf0, 0x1fbf9},
  {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a},
  {0x31350, 0x323af}, {0xe0100, 0xe01ef},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(390);
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '#', 336,
        '%', 481,
        '&', 491,
        '\'', 573,
        '(', 394,
        ')', 397,
        '*', 477,
        '+', 471,
        ',', 396,
        '-', 460,
        '.', 548,
        '/', 479,
        '0', 555,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 524,
        '\\', 2,
        ']', 526,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 485,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(388);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(191);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(191);
      if (lookahead == '\r') SKIP(1);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(202);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(202);
      if (lookahead == '\r') SKIP(3);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 5:
      if (lookahead == '\n') SKIP(201);
      END_STATE();
    case 6:
      if (lookahead == '\n') SKIP(201);
      if (lookahead == '\r') SKIP(5);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 7:
      if (lookahead == '\n') SKIP(204);
      END_STATE();
    case 8:
      if (lookahead == '\n') SKIP(204);
      if (lookahead == '\r') SKIP(7);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 9:
      if (lookahead == '\n') SKIP(203);
      END_STATE();
    case 10:
      if (lookahead == '\n') SKIP(203);
      if (lookahead == '\r') SKIP(9);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 11:
      if (lookahead == '\n') SKIP(205);
      END_STATE();
    case 12:
      if (lookahead == '\n') SKIP(205);
      if (lookahead == '\r') SKIP(11);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 13:
      if (lookahead == '\n') SKIP(206);
      END_STATE();
    case 14:
      if (lookahead == '\n') SKIP(206);
      if (lookahead == '\r') SKIP(13);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 15:
      if (lookahead == '\n') SKIP(285);
      END_STATE();
    case 16:
      if (lookahead == '\n') SKIP(285);
      if (lookahead == '\r') SKIP(15);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 17:
      if (lookahead == '\n') SKIP(194);
      END_STATE();
    case 18:
      if (lookahead == '\n') SKIP(194);
      if (lookahead == '\r') SKIP(17);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 19:
      if (lookahead == '\n') SKIP(195);
      END_STATE();
    case 20:
      if (lookahead == '\n') SKIP(195);
      if (lookahead == '\r') SKIP(19);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 21:
      if (lookahead == '\n') SKIP(229);
      END_STATE();
    case 22:
      if (lookahead == '\n') SKIP(229);
      if (lookahead == '\r') SKIP(21);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 23:
      if (lookahead == '\n') SKIP(286);
      END_STATE();
    case 24:
      if (lookahead == '\n') SKIP(286);
      if (lookahead == '\r') SKIP(23);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 25:
      if (lookahead == '\n') SKIP(199);
      END_STATE();
    case 26:
      if (lookahead == '\n') SKIP(199);
      if (lookahead == '\r') SKIP(25);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 27:
      if (lookahead == '\n') SKIP(217);
      END_STATE();
    case 28:
      if (lookahead == '\n') SKIP(217);
      if (lookahead == '\r') SKIP(27);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 29:
      if (lookahead == '\n') SKIP(213);
      END_STATE();
    case 30:
      if (lookahead == '\n') SKIP(213);
      if (lookahead == '\r') SKIP(29);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 31:
      if (lookahead == '\n') SKIP(230);
      END_STATE();
    case 32:
      if (lookahead == '\n') SKIP(230);
      if (lookahead == '\r') SKIP(31);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 33:
      if (lookahead == '\n') SKIP(228);
      END_STATE();
    case 34:
      if (lookahead == '\n') SKIP(228);
      if (lookahead == '\r') SKIP(33);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 35:
      if (lookahead == '\n') SKIP(266);
      END_STATE();
    case 36:
      if (lookahead == '\n') SKIP(266);
      if (lookahead == '\r') SKIP(35);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 37:
      if (lookahead == '\n') SKIP(214);
      END_STATE();
    case 38:
      if (lookahead == '\n') SKIP(214);
      if (lookahead == '\r') SKIP(37);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 39:
      if (lookahead == '\n') SKIP(233);
      END_STATE();
    case 40:
      if (lookahead == '\n') SKIP(233);
      if (lookahead == '\r') SKIP(39);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 41:
      if (lookahead == '\n') SKIP(218);
      END_STATE();
    case 42:
      if (lookahead == '\n') SKIP(218);
      if (lookahead == '\r') SKIP(41);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 43:
      if (lookahead == '\n') SKIP(208);
      END_STATE();
    case 44:
      if (lookahead == '\n') SKIP(208);
      if (lookahead == '\r') SKIP(43);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 45:
      if (lookahead == '\n') SKIP(231);
      END_STATE();
    case 46:
      if (lookahead == '\n') SKIP(231);
      if (lookahead == '\r') SKIP(45);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 47:
      if (lookahead == '\n') SKIP(246);
      END_STATE();
    case 48:
      if (lookahead == '\n') SKIP(246);
      if (lookahead == '\r') SKIP(47);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 49:
      if (lookahead == '\n') SKIP(261);
      END_STATE();
    case 50:
      if (lookahead == '\n') SKIP(261);
      if (lookahead == '\r') SKIP(49);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 51:
      if (lookahead == '\n') SKIP(243);
      END_STATE();
    case 52:
      if (lookahead == '\n') SKIP(243);
      if (lookahead == '\r') SKIP(51);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 53:
      if (lookahead == '\n') SKIP(250);
      END_STATE();
    case 54:
      if (lookahead == '\n') SKIP(250);
      if (lookahead == '\r') SKIP(53);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 55:
      if (lookahead == '\n') SKIP(267);
      END_STATE();
    case 56:
      if (lookahead == '\n') SKIP(267);
      if (lookahead == '\r') SKIP(55);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 57:
      if (lookahead == '\n') SKIP(284);
      END_STATE();
    case 58:
      if (lookahead == '\n') SKIP(284);
      if (lookahead == '\r') SKIP(57);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 59:
      if (lookahead == '\n') SKIP(238);
      END_STATE();
    case 60:
      if (lookahead == '\n') SKIP(238);
      if (lookahead == '\r') SKIP(59);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 61:
      if (lookahead == '\n') SKIP(209);
      END_STATE();
    case 62:
      if (lookahead == '\n') SKIP(209);
      if (lookahead == '\r') SKIP(61);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 63:
      if (lookahead == '\n') SKIP(287);
      END_STATE();
    case 64:
      if (lookahead == '\n') SKIP(287);
      if (lookahead == '\r') SKIP(63);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 65:
      if (lookahead == '\n') SKIP(271);
      END_STATE();
    case 66:
      if (lookahead == '\n') SKIP(271);
      if (lookahead == '\r') SKIP(65);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 67:
      if (lookahead == '\n') SKIP(279);
      END_STATE();
    case 68:
      if (lookahead == '\n') SKIP(279);
      if (lookahead == '\r') SKIP(67);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 69:
      if (lookahead == '\n') SKIP(289);
      END_STATE();
    case 70:
      if (lookahead == '\n') SKIP(289);
      if (lookahead == '\r') SKIP(69);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 71:
      if (lookahead == '\n') SKIP(215);
      END_STATE();
    case 72:
      if (lookahead == '\n') SKIP(215);
      if (lookahead == '\r') SKIP(71);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 73:
      if (lookahead == '\n') SKIP(288);
      END_STATE();
    case 74:
      if (lookahead == '\n') SKIP(288);
      if (lookahead == '\r') SKIP(73);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 75:
      if (lookahead == '\n') SKIP(222);
      END_STATE();
    case 76:
      if (lookahead == '\n') SKIP(222);
      if (lookahead == '\r') SKIP(75);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 77:
      if (lookahead == '\n') SKIP(237);
      END_STATE();
    case 78:
      if (lookahead == '\n') SKIP(237);
      if (lookahead == '\r') SKIP(77);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 79:
      if (lookahead == '\n') SKIP(255);
      END_STATE();
    case 80:
      if (lookahead == '\n') SKIP(255);
      if (lookahead == '\r') SKIP(79);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 81:
      if (lookahead == '\n') SKIP(200);
      END_STATE();
    case 82:
      if (lookahead == '\n') SKIP(200);
      if (lookahead == '\r') SKIP(81);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 83:
      if (lookahead == '\n') SKIP(254);
      END_STATE();
    case 84:
      if (lookahead == '\n') SKIP(254);
      if (lookahead == '\r') SKIP(83);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 85:
      if (lookahead == '\n') SKIP(245);
      END_STATE();
    case 86:
      if (lookahead == '\n') SKIP(245);
      if (lookahead == '\r') SKIP(85);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 87:
      if (lookahead == '\n') SKIP(291);
      END_STATE();
    case 88:
      if (lookahead == '\n') SKIP(291);
      if (lookahead == '\r') SKIP(87);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 89:
      if (lookahead == '\n') SKIP(290);
      END_STATE();
    case 90:
      if (lookahead == '\n') SKIP(290);
      if (lookahead == '\r') SKIP(89);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 91:
      if (lookahead == '\n') SKIP(265);
      END_STATE();
    case 92:
      if (lookahead == '\n') SKIP(265);
      if (lookahead == '\r') SKIP(91);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 93:
      if (lookahead == '\n') SKIP(297);
      END_STATE();
    case 94:
      if (lookahead == '\n') SKIP(297);
      if (lookahead == '\r') SKIP(93);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 95:
      if (lookahead == '\n') SKIP(207);
      END_STATE();
    case 96:
      if (lookahead == '\n') SKIP(207);
      if (lookahead == '\r') SKIP(95);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 97:
      if (lookahead == '\n') SKIP(99);
      END_STATE();
    case 98:
      if (lookahead == '\n') SKIP(99);
      if (lookahead == '\r') SKIP(97);
      END_STATE();
    case 99:
      ADVANCE_MAP(
        '\n', 399,
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 469,
        '-', 459,
        '/', 478,
        '<', 504,
        '=', 322,
        '>', 495,
      );
      if (lookahead == '\\') SKIP(98);
      if (lookahead == '^') ADVANCE(487);
      if (lookahead == '|') ADVANCE(486);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(99);
      END_STATE();
    case 100:
      if (lookahead == '\n') SKIP(292);
      END_STATE();
    case 101:
      if (lookahead == '\n') SKIP(292);
      if (lookahead == '\r') SKIP(100);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 102:
      if (lookahead == '\n') SKIP(296);
      END_STATE();
    case 103:
      if (lookahead == '\n') SKIP(296);
      if (lookahead == '\r') SKIP(102);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 104:
      if (lookahead == '\n') SKIP(280);
      END_STATE();
    case 105:
      if (lookahead == '\n') SKIP(280);
      if (lookahead == '\r') SKIP(104);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 106:
      if (lookahead == '\n') SKIP(281);
      END_STATE();
    case 107:
      if (lookahead == '\n') SKIP(281);
      if (lookahead == '\r') SKIP(106);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 108:
      if (lookahead == '\n') SKIP(293);
      if (lookahead == '\'') ADVANCE(573);
      if (lookahead == '/') ADVANCE(576);
      if (lookahead == '\\') ADVANCE(575);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(577);
      if (lookahead != 0) ADVANCE(574);
      END_STATE();
    case 109:
      if (lookahead == '\n') ADVANCE(589);
      if (lookahead == '\r') ADVANCE(588);
      if (lookahead == 'U') ADVANCE(386);
      if (lookahead == 'u') ADVANCE(378);
      if (lookahead == 'x') ADVANCE(372);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(591);
      if (lookahead != 0) ADVANCE(588);
      END_STATE();
    case 110:
      if (lookahead == '\n') SKIP(282);
      if (lookahead == '"') ADVANCE(582);
      if (lookahead == '/') ADVANCE(583);
      if (lookahead == '\\') ADVANCE(109);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(586);
      if (lookahead != 0) ADVANCE(587);
      END_STATE();
    case 111:
      if (lookahead == '\n') ADVANCE(392);
      if (lookahead == '\r') ADVANCE(115);
      if (lookahead == '(') ADVANCE(394);
      if (lookahead == '/') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(415);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(310);
      if (lookahead != 0) ADVANCE(422);
      END_STATE();
    case 112:
      if (lookahead == '\n') ADVANCE(392);
      if (lookahead == '\r') ADVANCE(115);
      if (lookahead == '/') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(415);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(310);
      if (lookahead != 0) ADVANCE(422);
      END_STATE();
    case 113:
      if (lookahead == '\n') ADVANCE(392);
      if (lookahead == '\r') ADVANCE(114);
      if (lookahead == '(') ADVANCE(455);
      if (lookahead == '/') ADVANCE(301);
      if (lookahead == '\\') SKIP(117);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(298);
      END_STATE();
    case 114:
      if (lookahead == '\n') ADVANCE(392);
      if (lookahead == '(') ADVANCE(455);
      if (lookahead == '/') ADVANCE(301);
      if (lookahead == '\\') SKIP(117);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(298);
      END_STATE();
    case 115:
      if (lookahead == '\n') ADVANCE(392);
      if (lookahead == '/') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(415);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(310);
      if (lookahead != 0) ADVANCE(422);
      END_STATE();
    case 116:
      if (lookahead == '\n') SKIP(298);
      END_STATE();
    case 117:
      if (lookahead == '\n') SKIP(298);
      if (lookahead == '\r') SKIP(116);
      END_STATE();
    case 118:
      if (lookahead == '\n') SKIP(192);
      END_STATE();
    case 119:
      if (lookahead == '\n') SKIP(192);
      if (lookahead == '\r') SKIP(118);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 120:
      if (lookahead == '\n') SKIP(196);
      END_STATE();
    case 121:
      if (lookahead == '\n') SKIP(196);
      if (lookahead == '\r') SKIP(120);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 122:
      if (lookahead == '\n') SKIP(239);
      END_STATE();
    case 123:
      if (lookahead == '\n') SKIP(239);
      if (lookahead == '\r') SKIP(122);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 124:
      if (lookahead == '\n') SKIP(219);
      END_STATE();
    case 125:
      if (lookahead == '\n') SKIP(219);
      if (lookahead == '\r') SKIP(124);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 126:
      if (lookahead == '\n') SKIP(240);
      END_STATE();
    case 127:
      if (lookahead == '\n') SKIP(240);
      if (lookahead == '\r') SKIP(126);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 128:
      if (lookahead == '\n') SKIP(256);
      END_STATE();
    case 129:
      if (lookahead == '\n') SKIP(256);
      if (lookahead == '\r') SKIP(128);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 130:
      if (lookahead == '\n') SKIP(244);
      END_STATE();
    case 131:
      if (lookahead == '\n') SKIP(244);
      if (lookahead == '\r') SKIP(130);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 132:
      if (lookahead == '\n') SKIP(268);
      END_STATE();
    case 133:
      if (lookahead == '\n') SKIP(268);
      if (lookahead == '\r') SKIP(132);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 134:
      if (lookahead == '\n') SKIP(211);
      END_STATE();
    case 135:
      if (lookahead == '\n') SKIP(211);
      if (lookahead == '\r') SKIP(134);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 136:
      if (lookahead == '\n') SKIP(269);
      END_STATE();
    case 137:
      if (lookahead == '\n') SKIP(269);
      if (lookahead == '\r') SKIP(136);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 138:
      if (lookahead == '\n') SKIP(220);
      END_STATE();
    case 139:
      if (lookahead == '\n') SKIP(220);
      if (lookahead == '\r') SKIP(138);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 140:
      if (lookahead == '\n') SKIP(236);
      END_STATE();
    case 141:
      if (lookahead == '\n') SKIP(236);
      if (lookahead == '\r') SKIP(140);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 142:
      if (lookahead == '\n') SKIP(260);
      END_STATE();
    case 143:
      if (lookahead == '\n') SKIP(260);
      if (lookahead == '\r') SKIP(142);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 144:
      if (lookahead == '\n') SKIP(248);
      END_STATE();
    case 145:
      if (lookahead == '\n') SKIP(248);
      if (lookahead == '\r') SKIP(144);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 146:
      if (lookahead == '\n') SKIP(193);
      END_STATE();
    case 147:
      if (lookahead == '\n') SKIP(193);
      if (lookahead == '\r') SKIP(146);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 148:
      if (lookahead == '\n') SKIP(197);
      END_STATE();
    case 149:
      if (lookahead == '\n') SKIP(197);
      if (lookahead == '\r') SKIP(148);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 150:
      if (lookahead == '\n') SKIP(234);
      END_STATE();
    case 151:
      if (lookahead == '\n') SKIP(234);
      if (lookahead == '\r') SKIP(150);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 152:
      if (lookahead == '\n') SKIP(273);
      END_STATE();
    case 153:
      if (lookahead == '\n') SKIP(273);
      if (lookahead == '\r') SKIP(152);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 154:
      if (lookahead == '\n') SKIP(252);
      END_STATE();
    case 155:
      if (lookahead == '\n') SKIP(252);
      if (lookahead == '\r') SKIP(154);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 156:
      if (lookahead == '\n') SKIP(224);
      END_STATE();
    case 157:
      if (lookahead == '\n') SKIP(224);
      if (lookahead == '\r') SKIP(156);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 158:
      if (lookahead == '\n') SKIP(242);
      END_STATE();
    case 159:
      if (lookahead == '\n') SKIP(242);
      if (lookahead == '\r') SKIP(158);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 160:
      if (lookahead == '\n') SKIP(259);
      END_STATE();
    case 161:
      if (lookahead == '\n') SKIP(259);
      if (lookahead == '\r') SKIP(160);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 162:
      if (lookahead == '\n') SKIP(249);
      END_STATE();
    case 163:
      if (lookahead == '\n') SKIP(249);
      if (lookahead == '\r') SKIP(162);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 164:
      if (lookahead == '\n') SKIP(198);
      END_STATE();
    case 165:
      if (lookahead == '\n') SKIP(198);
      if (lookahead == '\r') SKIP(164);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 166:
      if (lookahead == '\n') SKIP(232);
      END_STATE();
    case 167:
      if (lookahead == '\n') SKIP(232);
      if (lookahead == '\r') SKIP(166);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 168:
      if (lookahead == '\n') SKIP(276);
      END_STATE();
    case 169:
      if (lookahead == '\n') SKIP(276);
      if (lookahead == '\r') SKIP(168);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 170:
      if (lookahead == '\n') SKIP(251);
      END_STATE();
    case 171:
      if (lookahead == '\n') SKIP(251);
      if (lookahead == '\r') SKIP(170);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 172:
      if (lookahead == '\n') SKIP(226);
      END_STATE();
    case 173:
      if (lookahead == '\n') SKIP(226);
      if (lookahead == '\r') SKIP(172);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 174:
      if (lookahead == '\n') SKIP(264);
      END_STATE();
    case 175:
      if (lookahead == '\n') SKIP(264);
      if (lookahead == '\r') SKIP(174);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 176:
      if (lookahead == '\n') SKIP(253);
      END_STATE();
    case 177:
      if (lookahead == '\n') SKIP(253);
      if (lookahead == '\r') SKIP(176);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 178:
      if (lookahead == '\n') SKIP(263);
      END_STATE();
    case 179:
      if (lookahead == '\n') SKIP(263);
      if (lookahead == '\r') SKIP(178);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 180:
      if (lookahead == '\n') SKIP(270);
      END_STATE();
    case 181:
      if (lookahead == '\n') SKIP(270);
      if (lookahead == '\r') SKIP(180);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 182:
      if (lookahead == '\n') SKIP(258);
      END_STATE();
    case 183:
      if (lookahead == '\n') SKIP(258);
      if (lookahead == '\r') SKIP(182);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 184:
      if (lookahead == '\n') SKIP(272);
      END_STATE();
    case 185:
      if (lookahead == '\n') SKIP(272);
      if (lookahead == '\r') SKIP(184);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 186:
      if (lookahead == '\n') SKIP(278);
      END_STATE();
    case 187:
      if (lookahead == '\n') SKIP(278);
      if (lookahead == '\r') SKIP(186);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 188:
      if (lookahead == '\n') SKIP(275);
      END_STATE();
    case 189:
      if (lookahead == '\n') SKIP(275);
      if (lookahead == '\r') SKIP(188);
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 190:
      if (lookahead == '\r') ADVANCE(697);
      if (lookahead == '\\') ADVANCE(691);
      if (lookahead != 0) ADVANCE(696);
      END_STATE();
    case 191:
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '#', 336,
        '%', 481,
        '&', 491,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 471,
        ',', 396,
        '-', 460,
        '.', 548,
        '/', 479,
        '0', 555,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 524,
        '\\', 2,
        ']', 526,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 485,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(191);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 192:
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '#', 345,
        '%', 481,
        '&', 491,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 471,
        ',', 396,
        '-', 461,
        '.', 548,
        '/', 479,
        '0', 555,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 119,
        ']', 526,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 485,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(192);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 193:
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '#', 345,
        '%', 480,
        '&', 490,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 462,
        '.', 548,
        '/', 478,
        '0', 555,
        ':', 532,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 147,
        ']', 526,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 486,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(193);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 194:
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '%', 481,
        '&', 491,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 471,
        ',', 396,
        '-', 460,
        '.', 548,
        '/', 479,
        '0', 555,
        ':', 317,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 18,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 485,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(194);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 195:
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '%', 481,
        '&', 491,
        '\'', 573,
        '(', 455,
        '*', 477,
        '+', 471,
        ',', 396,
        '-', 461,
        '.', 548,
        '/', 479,
        '0', 555,
        ':', 317,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 20,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 485,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(195);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 196:
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '%', 481,
        '&', 491,
        '\'', 573,
        '(', 455,
        '*', 477,
        '+', 471,
        ',', 396,
        '-', 461,
        '.', 548,
        '/', 479,
        '0', 555,
        ':', 317,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 121,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 485,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(196);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 197:
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '%', 480,
        '&', 490,
        '\'', 573,
        '(', 455,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 462,
        '.', 548,
        '/', 478,
        '0', 555,
        ':', 317,
        '<', 507,
        '=', 322,
        '>', 698,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 149,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 486,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(197);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 198:
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '%', 480,
        '&', 490,
        '\'', 573,
        '(', 455,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 462,
        '.', 548,
        '/', 478,
        '0', 555,
        ':', 317,
        '<', 507,
        '=', 322,
        '>', 498,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 165,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 486,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(198);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 199:
      ADVANCE_MAP(
        '!', 457,
        '"', 283,
        '%', 481,
        '&', 491,
        '(', 299,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '/', 479,
        ':', 317,
        '<', 505,
        '=', 528,
        '>', 496,
        '[', 333,
        '\\', 26,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '|', 485,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(199);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 200:
      ADVANCE_MAP(
        '!', 457,
        '"', 283,
        '%', 481,
        '&', 491,
        '(', 299,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '/', 479,
        '<', 505,
        '=', 528,
        '>', 496,
        '[', 334,
        '\\', 82,
        '^', 488,
        '|', 485,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(200);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 201:
      ADVANCE_MAP(
        '!', 456,
        '"', 582,
        '#', 336,
        '&', 490,
        '\'', 573,
        '(', 455,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 463,
        '.', 365,
        '/', 301,
        '0', 555,
        ':', 317,
        ';', 516,
        '<', 319,
        '>', 323,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 523,
        '\\', 6,
        ']', 335,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 484,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(201);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 202:
      ADVANCE_MAP(
        '!', 456,
        '"', 582,
        '#', 340,
        '%', 480,
        '&', 490,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 463,
        '.', 549,
        '/', 478,
        '0', 555,
        ':', 532,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 523,
        '\\', 4,
        ']', 526,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 359,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(202);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 203:
      ADVANCE_MAP(
        '!', 456,
        '"', 582,
        '#', 344,
        '&', 489,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 472,
        '-', 463,
        '.', 307,
        '/', 301,
        '0', 555,
        ':', 317,
        ';', 516,
        '>', 326,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 523,
        '\\', 10,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(203);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 204:
      ADVANCE_MAP(
        '!', 456,
        '"', 582,
        '#', 338,
        '&', 490,
        '\'', 573,
        '(', 455,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 463,
        '.', 365,
        '/', 301,
        '0', 555,
        ':', 317,
        ';', 516,
        '>', 494,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 523,
        '\\', 8,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(204);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 205:
      ADVANCE_MAP(
        '!', 456,
        '"', 582,
        '&', 490,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 463,
        '.', 549,
        '/', 301,
        '0', 555,
        ':', 317,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 12,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(205);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 206:
      ADVANCE_MAP(
        '!', 456,
        '"', 582,
        '&', 489,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 463,
        '.', 549,
        '/', 301,
        '0', 555,
        ':', 532,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 522,
        '\\', 14,
        ']', 526,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(206);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 207:
      ADVANCE_MAP(
        '!', 456,
        '\'', 573,
        '(', 455,
        ')', 397,
        '+', 474,
        '-', 467,
        '.', 365,
        '/', 301,
        '0', 555,
        'L', 617,
        'U', 618,
        '\\', 96,
        'u', 619,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(207);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 208:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 44,
        ']', 526,
        '^', 488,
        'u', 607,
        '{', 520,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(208);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 209:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 62,
        ']', 526,
        '^', 488,
        'u', 607,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(209);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 210:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'L', 709,
        'R', 710,
        'U', 711,
        '[', 522,
        '\\', 62,
        ']', 526,
        '^', 488,
        'u', 712,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(209);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 211:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '#', 345,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 531,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 135,
        ']', 526,
        '^', 487,
        'u', 607,
        '|', 486,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(211);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 212:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '#', 345,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 531,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        'L', 709,
        'R', 710,
        'U', 711,
        '[', 522,
        '\\', 135,
        ']', 526,
        '^', 487,
        'u', 712,
        '|', 486,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(211);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 213:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        ':', 317,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 523,
        '\\', 30,
        '^', 488,
        'u', 607,
        '{', 520,
        '|', 485,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(213);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 214:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        ':', 317,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 38,
        '^', 488,
        'u', 607,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(214);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 215:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 72,
        '^', 488,
        'u', 607,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(215);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 216:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'L', 709,
        'R', 710,
        'U', 711,
        '[', 522,
        '\\', 72,
        '^', 488,
        'u', 712,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(215);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 217:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 523,
        '\\', 28,
        '^', 488,
        'u', 607,
        '{', 520,
        '|', 485,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(217);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 218:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 317,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 42,
        '^', 488,
        'u', 607,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(218);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 219:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 317,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 125,
        '^', 488,
        'u', 607,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(219);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 220:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 139,
        '^', 488,
        'u', 607,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(220);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 221:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        'L', 709,
        'R', 710,
        'U', 711,
        '[', 522,
        '\\', 139,
        '^', 488,
        'u', 712,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(220);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 222:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 76,
        '^', 488,
        'u', 607,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(222);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 223:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        'L', 709,
        'R', 710,
        'U', 711,
        '[', 522,
        '\\', 76,
        '^', 488,
        'u', 712,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(222);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 224:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 698,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 157,
        '^', 487,
        'u', 607,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(224);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 225:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 698,
        '?', 533,
        'L', 709,
        'R', 710,
        'U', 711,
        '[', 522,
        '\\', 157,
        '^', 487,
        'u', 712,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(224);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 226:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 498,
        '?', 533,
        'L', 600,
        'R', 602,
        'U', 604,
        '[', 522,
        '\\', 173,
        '^', 487,
        'u', 607,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(226);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 227:
      ADVANCE_MAP(
        '!', 321,
        '"', 582,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 498,
        '?', 533,
        'L', 709,
        'R', 710,
        'U', 711,
        '[', 522,
        '\\', 173,
        '^', 487,
        'u', 712,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(226);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 228:
      ADVANCE_MAP(
        '!', 321,
        '#', 356,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        ':', 317,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 523,
        '\\', 34,
        '^', 488,
        '{', 520,
        '|', 485,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(228);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 229:
      ADVANCE_MAP(
        '!', 321,
        '#', 341,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 469,
        ',', 396,
        '-', 459,
        '/', 478,
        ':', 317,
        ';', 516,
        '<', 504,
        '=', 322,
        '>', 495,
        '[', 523,
        '\\', 22,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '|', 486,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(229);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 230:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '0', 699,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 523,
        '\\', 32,
        ']', 526,
        '^', 488,
        '{', 520,
        '|', 485,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(230);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 231:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 46,
        ']', 526,
        '^', 488,
        '{', 520,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(231);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 232:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 523,
        '\\', 167,
        ']', 526,
        '^', 488,
        '{', 520,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(232);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 233:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 40,
        ']', 526,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(233);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 234:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 151,
        ']', 526,
        '^', 488,
        '{', 520,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(234);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 235:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 141,
        ']', 526,
        '^', 488,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(236);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 236:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 141,
        ']', 526,
        '^', 488,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(236);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 237:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 525,
        '\\', 78,
        ']', 526,
        '^', 488,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(237);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 238:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 532,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        '[', 522,
        '\\', 60,
        ']', 526,
        '^', 487,
        '{', 520,
        '|', 486,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(238);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 239:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 531,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        '[', 522,
        '\\', 123,
        ']', 526,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 486,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(239);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 240:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 531,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        '[', 522,
        '\\', 127,
        ']', 526,
        '^', 487,
        '{', 520,
        '|', 486,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(240);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 241:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 531,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        '[', 522,
        '\\', 159,
        ']', 526,
        '^', 487,
        '|', 486,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(242);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 242:
      ADVANCE_MAP(
        '!', 321,
        '#', 345,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 531,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        '[', 522,
        '\\', 159,
        ']', 526,
        '^', 487,
        '|', 486,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(242);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 243:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 52,
        '^', 488,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(243);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 244:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        ':', 531,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 131,
        '^', 488,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(244);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 245:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 524,
        '\\', 86,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(245);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 246:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 48,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(246);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 247:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 145,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(248);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 248:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 522,
        '\\', 145,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(248);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 249:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 464,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 525,
        '\\', 163,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(249);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 250:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 532,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 54,
        '^', 488,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(250);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 251:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 532,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        '[', 522,
        '\\', 171,
        '^', 488,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(251);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 252:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 155,
        '^', 488,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(252);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 253:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ':', 531,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        '[', 522,
        '\\', 177,
        '^', 488,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(253);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 254:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 496,
        '?', 533,
        '[', 524,
        '\\', 84,
        '^', 488,
        '|', 485,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(254);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 255:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        '[', 523,
        '\\', 80,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(255);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 256:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 129,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(256);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 257:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 183,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(258);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 258:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 183,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(258);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 259:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        '[', 525,
        '\\', 161,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(259);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 260:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        '[', 523,
        '\\', 143,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(260);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 261:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        '[', 522,
        '\\', 50,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(261);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 262:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        '[', 522,
        '\\', 179,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(263);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 263:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        '[', 522,
        '\\', 179,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(263);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 264:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '(', 455,
        '*', 477,
        '+', 473,
        ',', 396,
        '-', 465,
        '.', 547,
        '/', 479,
        '<', 503,
        '=', 528,
        '>', 497,
        '?', 533,
        '[', 525,
        '\\', 175,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(264);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 265:
      ADVANCE_MAP(
        '!', 321,
        '%', 481,
        '&', 491,
        '*', 477,
        '+', 475,
        ',', 396,
        '-', 468,
        '.', 300,
        '/', 479,
        '<', 506,
        '=', 528,
        '>', 496,
        '\\', 92,
        '^', 488,
        '|', 485,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(265);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 266:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 532,
        ';', 516,
        '<', 507,
        '=', 528,
        '>', 495,
        '?', 533,
        '[', 523,
        '\\', 36,
        ']', 526,
        '^', 487,
        '{', 520,
        '|', 486,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(266);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 267:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 532,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        '[', 522,
        '\\', 56,
        ']', 526,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 486,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(267);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 268:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 317,
        ';', 516,
        '<', 507,
        '=', 322,
        '>', 495,
        '?', 533,
        '[', 522,
        '\\', 133,
        ']', 335,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 486,
        '}', 521,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(268);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 269:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 532,
        '<', 507,
        '=', 322,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 137,
        '^', 487,
        '{', 520,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(269);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 270:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 532,
        '<', 507,
        '=', 322,
        '>', 498,
        '?', 533,
        '[', 522,
        '\\', 181,
        '^', 487,
        '{', 520,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(270);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 271:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 531,
        '<', 507,
        '=', 322,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 66,
        '^', 487,
        '{', 520,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(271);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 272:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        ':', 531,
        '<', 507,
        '=', 322,
        '>', 498,
        '?', 533,
        '[', 522,
        '\\', 185,
        '^', 487,
        '{', 520,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(272);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 273:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 153,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(273);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 274:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 189,
        '^', 487,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(275);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 275:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 698,
        '?', 533,
        '[', 522,
        '\\', 189,
        '^', 487,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(275);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 276:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 498,
        '?', 533,
        '[', 522,
        '\\', 169,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(276);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 277:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 498,
        '?', 533,
        '[', 522,
        '\\', 187,
        '^', 487,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(278);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 278:
      ADVANCE_MAP(
        '!', 321,
        '%', 480,
        '&', 490,
        '(', 455,
        '*', 476,
        '+', 470,
        ',', 396,
        '-', 466,
        '.', 547,
        '/', 478,
        '<', 507,
        '=', 322,
        '>', 498,
        '?', 533,
        '[', 522,
        '\\', 187,
        '^', 487,
        '|', 486,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(278);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 279:
      ADVANCE_MAP(
        '"', 582,
        '&', 490,
        '(', 455,
        '*', 476,
        '/', 301,
        ':', 317,
        'L', 601,
        'U', 605,
        '[', 523,
        '\\', 68,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 608,
        'v', 668,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(279);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 280:
      ADVANCE_MAP(
        '"', 582,
        ')', 397,
        ',', 396,
        '/', 301,
        ':', 531,
        'L', 600,
        'R', 602,
        'U', 604,
        '\\', 105,
        'u', 607,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(280);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 281:
      if (lookahead == '"') ADVANCE(582);
      if (lookahead == '/') ADVANCE(301);
      if (lookahead == '<') ADVANCE(328);
      if (lookahead == 'L') ADVANCE(601);
      if (lookahead == 'U') ADVANCE(605);
      if (lookahead == '\\') ADVANCE(107);
      if (lookahead == 'u') ADVANCE(609);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(281);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 282:
      if (lookahead == '"') ADVANCE(582);
      if (lookahead == '/') ADVANCE(301);
      if (lookahead == '\\') ADVANCE(109);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(282);
      END_STATE();
    case 283:
      if (lookahead == '"') ADVANCE(708);
      END_STATE();
    case 284:
      ADVANCE_MAP(
        '#', 345,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        ',', 396,
        '-', 327,
        '.', 306,
        '/', 301,
        ':', 532,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        '[', 523,
        '\\', 58,
        ']', 526,
        '{', 520,
        '|', 359,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(284);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 285:
      ADVANCE_MAP(
        '#', 337,
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 469,
        ',', 396,
        '-', 327,
        '.', 306,
        '/', 301,
        ':', 532,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        '[', 523,
        '\\', 16,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
        '|', 359,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(285);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 286:
      ADVANCE_MAP(
        '#', 339,
        '&', 490,
        '(', 455,
        '*', 476,
        ',', 396,
        '/', 301,
        ':', 317,
        ';', 516,
        '[', 523,
        '\\', 24,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(286);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 287:
      ADVANCE_MAP(
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        ',', 396,
        '-', 327,
        '.', 306,
        '/', 301,
        ':', 532,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        '[', 522,
        '\\', 64,
        '{', 520,
        '|', 359,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(287);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 288:
      ADVANCE_MAP(
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        ',', 396,
        '-', 327,
        '.', 306,
        '/', 301,
        ':', 531,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        '[', 523,
        '\\', 74,
        ']', 526,
        '{', 520,
        '|', 359,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(288);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 289:
      ADVANCE_MAP(
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        ',', 396,
        '-', 327,
        '/', 301,
        ':', 531,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        '[', 523,
        '\\', 70,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(289);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 290:
      ADVANCE_MAP(
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        ',', 396,
        '.', 306,
        '/', 301,
        ':', 531,
        ';', 516,
        '=', 527,
        '>', 698,
        '[', 522,
        '\\', 90,
        '{', 520,
        '|', 359,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(290);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 291:
      ADVANCE_MAP(
        '&', 490,
        '(', 455,
        ')', 397,
        '*', 476,
        ',', 396,
        '/', 301,
        ';', 516,
        '=', 527,
        '>', 698,
        '[', 522,
        '\\', 88,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 663,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        'u', 656,
        'v', 668,
        '{', 520,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(291);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 292:
      ADVANCE_MAP(
        '&', 489,
        '*', 476,
        '.', 306,
        '/', 301,
        ':', 317,
        '=', 527,
        '\\', 101,
        ']', 526,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(292);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 293:
      if (lookahead == '\'') ADVANCE(573);
      if (lookahead == '/') ADVANCE(301);
      if (lookahead == '\\') ADVANCE(109);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(293);
      END_STATE();
    case 294:
      if (lookahead == '\'') ADVANCE(370);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(360);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(294);
      END_STATE();
    case 295:
      if (lookahead == '\'') ADVANCE(366);
      if (lookahead == '.') ADVANCE(562);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(360);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(295);
      END_STATE();
    case 296:
      ADVANCE_MAP(
        '(', 455,
        ')', 397,
        ',', 396,
        '/', 301,
        ':', 531,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        '[', 524,
        '\\', 103,
        ']', 526,
        '{', 520,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(296);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 297:
      ADVANCE_MAP(
        '(', 455,
        '/', 301,
        ':', 317,
        'F', 625,
        'T', 629,
        '[', 522,
        '\\', 94,
        'f', 635,
        't', 676,
        '{', 520,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(297);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 298:
      if (lookahead == '(') ADVANCE(455);
      if (lookahead == '/') ADVANCE(301);
      if (lookahead == '\\') SKIP(117);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(298);
      END_STATE();
    case 299:
      if (lookahead == ')') ADVANCE(706);
      END_STATE();
    case 300:
      if (lookahead == '*') ADVANCE(550);
      END_STATE();
    case 301:
      if (lookahead == '*') ADVANCE(304);
      if (lookahead == '/') ADVANCE(696);
      END_STATE();
    case 302:
      if (lookahead == '*') ADVANCE(705);
      END_STATE();
    case 303:
      if (lookahead == '*') ADVANCE(303);
      if (lookahead == '/') ADVANCE(689);
      if (lookahead != 0) ADVANCE(304);
      END_STATE();
    case 304:
      if (lookahead == '*') ADVANCE(303);
      if (lookahead != 0) ADVANCE(304);
      END_STATE();
    case 305:
      if (lookahead == '*') ADVANCE(303);
      if (lookahead != 0) ADVANCE(413);
      END_STATE();
    case 306:
      if (lookahead == '.') ADVANCE(308);
      END_STATE();
    case 307:
      if (lookahead == '.') ADVANCE(308);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(554);
      END_STATE();
    case 308:
      if (lookahead == '.') ADVANCE(395);
      END_STATE();
    case 309:
      if (lookahead == '.') ADVANCE(370);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(560);
      END_STATE();
    case 310:
      if (lookahead == '/') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(415);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(310);
      if (lookahead != 0) ADVANCE(422);
      END_STATE();
    case 311:
      if (lookahead == '1') ADVANCE(315);
      END_STATE();
    case 312:
      if (lookahead == '2') ADVANCE(553);
      END_STATE();
    case 313:
      if (lookahead == '2') ADVANCE(316);
      if (lookahead == '6') ADVANCE(553);
      END_STATE();
    case 314:
      if (lookahead == '4') ADVANCE(553);
      END_STATE();
    case 315:
      if (lookahead == '6') ADVANCE(553);
      END_STATE();
    case 316:
      if (lookahead == '8') ADVANCE(553);
      END_STATE();
    case 317:
      if (lookahead == ':') ADVANCE(517);
      END_STATE();
    case 318:
      if (lookahead == '<') ADVANCE(719);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(318);
      END_STATE();
    case 319:
      if (lookahead == '<') ADVANCE(508);
      if (lookahead == '=') ADVANCE(500);
      END_STATE();
    case 320:
      if (lookahead == '<') ADVANCE(318);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(320);
      END_STATE();
    case 321:
      if (lookahead == '=') ADVANCE(493);
      END_STATE();
    case 322:
      if (lookahead == '=') ADVANCE(492);
      END_STATE();
    case 323:
      if (lookahead == '=') ADVANCE(499);
      if (lookahead == '>') ADVANCE(324);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(330);
      END_STATE();
    case 324:
      if (lookahead == '=') ADVANCE(540);
      if (lookahead == '>') ADVANCE(720);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(325);
      END_STATE();
    case 325:
      if (lookahead == '>') ADVANCE(720);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(325);
      END_STATE();
    case 326:
      if (lookahead == '>') ADVANCE(512);
      END_STATE();
    case 327:
      if (lookahead == '>') ADVANCE(551);
      END_STATE();
    case 328:
      if (lookahead == '>') ADVANCE(595);
      if (lookahead == '\\') ADVANCE(329);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(328);
      END_STATE();
    case 329:
      if (lookahead == '>') ADVANCE(596);
      if (lookahead == '\\') ADVANCE(329);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(328);
      END_STATE();
    case 330:
      if (lookahead == '>') ADVANCE(325);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(330);
      END_STATE();
    case 331:
      if (lookahead == 'F') ADVANCE(311);
      END_STATE();
    case 332:
      if (lookahead == 'U') ADVANCE(385);
      if (lookahead == 'u') ADVANCE(377);
      END_STATE();
    case 333:
      if (lookahead == '[') ADVANCE(518);
      if (lookahead == ']') ADVANCE(707);
      END_STATE();
    case 334:
      if (lookahead == ']') ADVANCE(707);
      END_STATE();
    case 335:
      if (lookahead == ']') ADVANCE(519);
      END_STATE();
    case 336:
      if (lookahead == 'd') ADVANCE(429);
      if (lookahead == 'e') ADVANCE(449);
      if (lookahead == 'i') ADVANCE(437);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(336);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 337:
      if (lookahead == 'd') ADVANCE(429);
      if (lookahead == 'e') ADVANCE(449);
      if (lookahead == 'i') ADVANCE(438);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(337);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 338:
      if (lookahead == 'd') ADVANCE(429);
      if (lookahead == 'e') ADVANCE(451);
      if (lookahead == 'i') ADVANCE(437);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(338);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 339:
      if (lookahead == 'd') ADVANCE(429);
      if (lookahead == 'e') ADVANCE(451);
      if (lookahead == 'i') ADVANCE(438);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(339);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 340:
      if (lookahead == 'd') ADVANCE(429);
      if (lookahead == 'i') ADVANCE(437);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(340);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 341:
      if (lookahead == 'd') ADVANCE(429);
      if (lookahead == 'i') ADVANCE(438);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(341);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 342:
      if (lookahead == 'd') ADVANCE(354);
      END_STATE();
    case 343:
      if (lookahead == 'd') ADVANCE(348);
      END_STATE();
    case 344:
      if (lookahead == 'e') ADVANCE(358);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(344);
      END_STATE();
    case 345:
      if (lookahead == 'e') ADVANCE(357);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(345);
      END_STATE();
    case 346:
      if (lookahead == 'e') ADVANCE(404);
      END_STATE();
    case 347:
      if (lookahead == 'e') ADVANCE(352);
      END_STATE();
    case 348:
      if (lookahead == 'e') ADVANCE(353);
      END_STATE();
    case 349:
      if (lookahead == 'f') ADVANCE(311);
      END_STATE();
    case 350:
      if (lookahead == 'f') ADVANCE(400);
      END_STATE();
    case 351:
      if (lookahead == 'f') ADVANCE(406);
      END_STATE();
    case 352:
      if (lookahead == 'f') ADVANCE(408);
      END_STATE();
    case 353:
      if (lookahead == 'f') ADVANCE(410);
      END_STATE();
    case 354:
      if (lookahead == 'i') ADVANCE(350);
      END_STATE();
    case 355:
      if (lookahead == 'i') ADVANCE(351);
      if (lookahead == 's') ADVANCE(346);
      END_STATE();
    case 356:
      if (lookahead == 'i') ADVANCE(438);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(356);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 357:
      if (lookahead == 'l') ADVANCE(355);
      if (lookahead == 'n') ADVANCE(342);
      END_STATE();
    case 358:
      if (lookahead == 'n') ADVANCE(342);
      END_STATE();
    case 359:
      if (lookahead == '|') ADVANCE(482);
      END_STATE();
    case 360:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(367);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(559);
      END_STATE();
    case 361:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(360);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(294);
      END_STATE();
    case 362:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(557);
      END_STATE();
    case 363:
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(295);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(556);
      END_STATE();
    case 364:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 365:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(554);
      END_STATE();
    case 366:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(295);
      END_STATE();
    case 367:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(559);
      END_STATE();
    case 368:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(688);
      END_STATE();
    case 369:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(560);
      END_STATE();
    case 370:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(294);
      END_STATE();
    case 371:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(588);
      END_STATE();
    case 372:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(594);
      END_STATE();
    case 373:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(368);
      END_STATE();
    case 374:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(371);
      END_STATE();
    case 375:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(373);
      END_STATE();
    case 376:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(374);
      END_STATE();
    case 377:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(375);
      END_STATE();
    case 378:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(376);
      END_STATE();
    case 379:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(377);
      END_STATE();
    case 380:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(378);
      END_STATE();
    case 381:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(379);
      END_STATE();
    case 382:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(380);
      END_STATE();
    case 383:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(381);
      END_STATE();
    case 384:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(382);
      END_STATE();
    case 385:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(383);
      END_STATE();
    case 386:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(384);
      END_STATE();
    case 387:
      if (lookahead != 0 &&
          lookahead != '*') ADVANCE(422);
      END_STATE();
    case 388:
      if (eof) ADVANCE(390);
      ADVANCE_MAP(
        '!', 457,
        '"', 582,
        '#', 336,
        '%', 481,
        '&', 491,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 477,
        '+', 471,
        ',', 396,
        '-', 460,
        '.', 548,
        '/', 479,
        '0', 555,
        ':', 532,
        ';', 516,
        '<', 503,
        '=', 528,
        '>', 698,
        '?', 533,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 524,
        '\\', 2,
        ']', 526,
        '^', 488,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 485,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(388);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 389:
      if (eof) ADVANCE(390);
      ADVANCE_MAP(
        '!', 456,
        '"', 582,
        '#', 340,
        '%', 480,
        '&', 490,
        '\'', 573,
        '(', 455,
        ')', 397,
        '*', 476,
        '+', 472,
        ',', 396,
        '-', 463,
        '.', 549,
        '/', 478,
        '0', 555,
        ':', 532,
        ';', 516,
        '<', 502,
        '=', 527,
        '>', 698,
        'F', 625,
        'L', 599,
        'R', 602,
        'T', 629,
        'U', 603,
        '[', 523,
        '\\', 4,
        ']', 526,
        '^', 487,
        'b', 671,
        'c', 650,
        'd', 667,
        'f', 634,
        'i', 664,
        'm', 636,
        'n', 684,
        'p', 681,
        's', 651,
        't', 676,
        'u', 606,
        'v', 668,
        '{', 520,
        '|', 359,
        '}', 521,
        '~', 458,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(389);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      if (set_contains(sym_identifier_character_set_1, 687, lookahead)) ADVANCE(688);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(aux_sym_preproc_include_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(aux_sym_preproc_include_token2);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(aux_sym_preproc_def_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(aux_sym_preproc_if_token1);
      if (lookahead == 'd') ADVANCE(433);
      if (lookahead == 'n') ADVANCE(427);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(399);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(aux_sym_preproc_ifdef_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(aux_sym_preproc_ifdef_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(aux_sym_preproc_else_token1);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(aux_sym_preproc_else_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(aux_sym_preproc_elif_token1);
      if (lookahead == 'd') ADVANCE(347);
      if (lookahead == 'n') ADVANCE(343);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(aux_sym_preproc_elif_token1);
      if (lookahead == 'd') ADVANCE(435);
      if (lookahead == 'n') ADVANCE(428);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(aux_sym_preproc_elifdef_token1);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(aux_sym_preproc_elifdef_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(aux_sym_preproc_elifdef_token2);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(aux_sym_preproc_elifdef_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(304);
      if (lookahead == '*') ADVANCE(412);
      if (lookahead == '/') ADVANCE(689);
      if (lookahead == '\\') ADVANCE(418);
      if (lookahead != 0) ADVANCE(413);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(304);
      if (lookahead == '*') ADVANCE(412);
      if (lookahead == '/') ADVANCE(305);
      if (lookahead == '\\') ADVANCE(418);
      if (lookahead != 0) ADVANCE(413);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(696);
      if (lookahead == '\r') ADVANCE(690);
      if (lookahead == '/') ADVANCE(693);
      if (lookahead == '\\') ADVANCE(692);
      if (lookahead != 0) ADVANCE(694);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') SKIP(310);
      if (lookahead == '\r') ADVANCE(416);
      if (lookahead == '/') ADVANCE(387);
      if (lookahead == '\\') ADVANCE(417);
      if (lookahead != 0) ADVANCE(422);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') SKIP(310);
      if (lookahead == '/') ADVANCE(387);
      if (lookahead == '\\') ADVANCE(417);
      if (lookahead != 0) ADVANCE(422);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(423);
      if (lookahead == '/') ADVANCE(387);
      if (lookahead == '\\') ADVANCE(417);
      if (lookahead != 0) ADVANCE(422);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(421);
      if (lookahead == '*') ADVANCE(412);
      if (lookahead == '/') ADVANCE(305);
      if (lookahead == '\\') ADVANCE(418);
      if (lookahead != 0) ADVANCE(413);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(695);
      if (lookahead == '/') ADVANCE(693);
      if (lookahead == '\\') ADVANCE(692);
      if (lookahead != 0) ADVANCE(694);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(413);
      if (lookahead == '/') ADVANCE(693);
      if (lookahead == '\\') ADVANCE(417);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(422);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(412);
      if (lookahead == '/') ADVANCE(305);
      if (lookahead == '\\') ADVANCE(418);
      if (lookahead != 0) ADVANCE(413);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(387);
      if (lookahead == '\\') ADVANCE(417);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(422);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(387);
      if (lookahead == '\\') ADVANCE(417);
      if (lookahead != 0) ADVANCE(422);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'c') ADVANCE(450);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(448);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(432);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(434);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(436);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(405);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(393);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(391);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(442);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(443);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(444);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(445);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(398);
      if (lookahead == 'n') ADVANCE(424);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(398);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(446);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(407);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(401);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(402);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(403);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(409);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(411);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(452);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(440);
      if (lookahead == 's') ADVANCE(430);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(441);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'l') ADVANCE(447);
      if (lookahead == 'n') ADVANCE(425);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'l') ADVANCE(453);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'n') ADVANCE(425);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'n') ADVANCE(431);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'u') ADVANCE(426);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(454);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(493);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(545);
      if (lookahead == '.') ADVANCE(365);
      if (lookahead == '0') ADVANCE(555);
      if (lookahead == '=') ADVANCE(538);
      if (lookahead == '>') ADVANCE(552);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(545);
      if (lookahead == '.') ADVANCE(365);
      if (lookahead == '0') ADVANCE(555);
      if (lookahead == '=') ADVANCE(538);
      if (lookahead == '>') ADVANCE(551);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(545);
      if (lookahead == '.') ADVANCE(365);
      if (lookahead == '0') ADVANCE(555);
      if (lookahead == '>') ADVANCE(551);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(545);
      if (lookahead == '.') ADVANCE(365);
      if (lookahead == '0') ADVANCE(555);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(545);
      if (lookahead == '=') ADVANCE(538);
      if (lookahead == '>') ADVANCE(552);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(545);
      if (lookahead == '=') ADVANCE(538);
      if (lookahead == '>') ADVANCE(551);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(545);
      if (lookahead == '>') ADVANCE(551);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(365);
      if (lookahead == '0') ADVANCE(555);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(538);
      if (lookahead == '>') ADVANCE(302);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(546);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(546);
      if (lookahead == '.') ADVANCE(365);
      if (lookahead == '0') ADVANCE(555);
      if (lookahead == '=') ADVANCE(537);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(546);
      if (lookahead == '.') ADVANCE(365);
      if (lookahead == '0') ADVANCE(555);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(546);
      if (lookahead == '=') ADVANCE(537);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '.') ADVANCE(365);
      if (lookahead == '0') ADVANCE(555);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(537);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(534);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(304);
      if (lookahead == '/') ADVANCE(696);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(304);
      if (lookahead == '/') ADVANCE(696);
      if (lookahead == '=') ADVANCE(535);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(536);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(543);
      if (lookahead == '|') ADVANCE(482);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(482);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(542);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(483);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(483);
      if (lookahead == '=') ADVANCE(541);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(499);
      if (lookahead == '>') ADVANCE(512);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(499);
      if (lookahead == '>') ADVANCE(513);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(499);
      if (lookahead == '>') ADVANCE(514);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(330);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(499);
      if (lookahead == '>') ADVANCE(515);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(330);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      if (lookahead == '>') ADVANCE(544);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(509);
      if (lookahead == '=') ADVANCE(501);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(320);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(508);
      if (lookahead == '=') ADVANCE(500);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(511);
      if (lookahead == '=') ADVANCE(501);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(511);
      if (lookahead == '=') ADVANCE(500);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(510);
      if (lookahead == '=') ADVANCE(501);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(320);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '<') ADVANCE(719);
      if (lookahead == '=') ADVANCE(539);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(318);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '<') ADVANCE(719);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(318);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(539);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(540);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(540);
      if (lookahead == '>') ADVANCE(720);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(325);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '>') ADVANCE(720);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(325);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(anon_sym_LBRACK_LBRACK);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(anon_sym_RBRACK_RBRACK);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '[') ADVANCE(518);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '[') ADVANCE(518);
      if (lookahead == ']') ADVANCE(707);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == ']') ADVANCE(707);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(492);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(sym_primitive_type);
      if (lookahead == '1') ADVANCE(624);
      if (lookahead == '3') ADVANCE(622);
      if (lookahead == '6') ADVANCE(623);
      if (lookahead == '8') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'p') ADVANCE(682);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(sym_primitive_type);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(517);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(anon_sym_LT_EQ_GT);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '*') ADVANCE(550);
      if (lookahead == '.') ADVANCE(308);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '*') ADVANCE(550);
      if (lookahead == '.') ADVANCE(308);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(554);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(308);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(554);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      if (lookahead == '*') ADVANCE(705);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(sym_number_literal);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 365,
        'B', 331,
        'b', 349,
        'E', 360,
        'e', 360,
        'F', 561,
        'f', 561,
        'L', 553,
        'l', 553,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(554);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 363,
        '.', 562,
        'L', 563,
        'l', 566,
        'B', 362,
        'b', 362,
        'E', 360,
        'e', 360,
        'U', 565,
        'u', 565,
        'X', 309,
        'x', 309,
        'Z', 568,
        'z', 568,
        '8', 295,
        '9', 295,
      );
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(556);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 363,
        '.', 562,
        'L', 563,
        'l', 566,
        'E', 360,
        'e', 360,
        'U', 565,
        'u', 565,
        'Z', 568,
        'z', 568,
        '8', 295,
        '9', 295,
      );
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(556);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 362,
        'L', 563,
        'l', 566,
        'U', 565,
        'u', 565,
        'Z', 568,
        'z', 568,
        '0', 557,
        '1', 557,
      );
      END_STATE();
    case 558:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 364,
        '.', 562,
        'L', 563,
        'l', 566,
        'E', 360,
        'e', 360,
        'U', 565,
        'u', 565,
        'Z', 568,
        'z', 568,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(558);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(367);
      if (lookahead == 'B') ADVANCE(331);
      if (lookahead == 'b') ADVANCE(349);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(561);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(553);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(559);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 369,
        '.', 361,
        'L', 563,
        'l', 566,
        'P', 360,
        'p', 360,
        'U', 565,
        'u', 565,
        'Z', 568,
        'z', 568,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(560);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '1') ADVANCE(313);
      if (lookahead == '3') ADVANCE(312);
      if (lookahead == '6') ADVANCE(314);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        'B', 331,
        'b', 349,
        'E', 360,
        'e', 360,
        'F', 561,
        'f', 561,
        'L', 553,
        'l', 553,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(554);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'L') ADVANCE(568);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(553);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'L') ADVANCE(553);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'L') ADVANCE(564);
      if (lookahead == 'l') ADVANCE(567);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(553);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'l') ADVANCE(568);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(553);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'l') ADVANCE(553);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(553);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_L_SQUOTE);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_u_SQUOTE);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_U_SQUOTE);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_u8_SQUOTE);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '\n') ADVANCE(589);
      if (lookahead == '\r') ADVANCE(588);
      if (lookahead == 'U') ADVANCE(386);
      if (lookahead == 'u') ADVANCE(378);
      if (lookahead == 'x') ADVANCE(372);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(591);
      if (lookahead != 0) ADVANCE(588);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '*') ADVANCE(304);
      if (lookahead == '/') ADVANCE(696);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '\\') ADVANCE(109);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_L_DQUOTE);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_u_DQUOTE);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_U_DQUOTE);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_u8_DQUOTE);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(585);
      if (lookahead == '/') ADVANCE(587);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(587);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(584);
      if (lookahead == '/') ADVANCE(587);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(585);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(584);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(585);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '/') ADVANCE(583);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(586);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(587);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(587);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == '\\') ADVANCE(109);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(588);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(590);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(588);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(592);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(593);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(sym_system_lib_string);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(sym_system_lib_string);
      if (lookahead == '>') ADVANCE(595);
      if (lookahead == '\\') ADVANCE(329);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(328);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(sym_true);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(sym_false);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(578);
      if (lookahead == '\'') ADVANCE(569);
      if (lookahead == 'R') ADVANCE(610);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(578);
      if (lookahead == 'R') ADVANCE(610);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(578);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(700);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(580);
      if (lookahead == '\'') ADVANCE(571);
      if (lookahead == 'R') ADVANCE(611);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(580);
      if (lookahead == 'R') ADVANCE(611);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(580);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(579);
      if (lookahead == '\'') ADVANCE(570);
      if (lookahead == '8') ADVANCE(612);
      if (lookahead == 'R') ADVANCE(615);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'i') ADVANCE(666);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(579);
      if (lookahead == '8') ADVANCE(613);
      if (lookahead == 'R') ADVANCE(615);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(579);
      if (lookahead == '8') ADVANCE(614);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'i') ADVANCE(666);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(579);
      if (lookahead == '8') ADVANCE(614);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(701);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(703);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(581);
      if (lookahead == '\'') ADVANCE(572);
      if (lookahead == 'R') ADVANCE(616);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(581);
      if (lookahead == 'R') ADVANCE(616);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(581);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(702);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(704);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(569);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(571);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(570);
      if (lookahead == '8') ADVANCE(620);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(572);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(624);
      if (lookahead == '3') ADVANCE(622);
      if (lookahead == '6') ADVANCE(623);
      if (lookahead == '8') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'p') ADVANCE(682);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '4') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '6') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A') ADVANCE(628);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(597);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(598);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(630);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R') ADVANCE(631);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S') ADVANCE(627);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U') ADVANCE(626);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '_') ADVANCE(639);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '_') ADVANCE(679);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'a') ADVANCE(657);
      if (lookahead == 'l') ADVANCE(669);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'a') ADVANCE(657);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'a') ADVANCE(686);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'a') ADVANCE(673);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'a') ADVANCE(679);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'a') ADVANCE(661);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'b') ADVANCE(662);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'd') ADVANCE(530);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'd') ADVANCE(653);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'e') ADVANCE(597);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'e') ADVANCE(530);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'e') ADVANCE(598);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'e') ADVANCE(633);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'f') ADVANCE(633);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'f') ADVANCE(647);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'g') ADVANCE(665);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'h') ADVANCE(637);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'i') ADVANCE(687);
      if (lookahead == 's') ADVANCE(652);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'i') ADVANCE(687);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'i') ADVANCE(648);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'i') ADVANCE(649);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'i') ADVANCE(641);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'i') ADVANCE(666);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'l') ADVANCE(677);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'l') ADVANCE(530);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'l') ADVANCE(672);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'l') ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'l') ADVANCE(654);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'l') ADVANCE(644);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'l') ADVANCE(669);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'n') ADVANCE(678);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'n') ADVANCE(633);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'n') ADVANCE(680);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'o') ADVANCE(683);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'o') ADVANCE(655);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'o') ADVANCE(638);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'o') ADVANCE(658);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'o') ADVANCE(670);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'p') ADVANCE(682);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'r') ADVANCE(529);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'r') ADVANCE(642);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'r') ADVANCE(633);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'r') ADVANCE(685);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 's') ADVANCE(645);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 't') ADVANCE(529);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 't') ADVANCE(530);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 't') ADVANCE(621);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 't') ADVANCE(674);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 't') ADVANCE(675);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'u') ADVANCE(640);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'u') ADVANCE(660);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'u') ADVANCE(643);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'x') ADVANCE(632);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == 'z') ADVANCE(646);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(332);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(696);
      if (lookahead == '/') ADVANCE(693);
      if (lookahead == '\\') ADVANCE(419);
      if (lookahead != 0) ADVANCE(694);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\r') ADVANCE(697);
      if (lookahead == '\\') ADVANCE(691);
      if (lookahead != 0) ADVANCE(696);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\r') ADVANCE(695);
      if (lookahead == '/') ADVANCE(693);
      if (lookahead == '\\') ADVANCE(692);
      if (lookahead != 0) ADVANCE(694);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '*') ADVANCE(696);
      if (lookahead == '\\') ADVANCE(414);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(694);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '/') ADVANCE(693);
      if (lookahead == '\\') ADVANCE(419);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(694);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '/') ADVANCE(693);
      if (lookahead == '\\') ADVANCE(419);
      if (lookahead != 0) ADVANCE(694);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(190);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(696);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(190);
      if (lookahead != 0) ADVANCE(696);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(anon_sym_GT2);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(aux_sym_pure_virtual_clause_token1);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(anon_sym_R_DQUOTE);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(anon_sym_LR_DQUOTE);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(anon_sym_uR_DQUOTE);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(anon_sym_UR_DQUOTE);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(anon_sym_u8R_DQUOTE);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(anon_sym_DASH_GT_STAR);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(anon_sym_LPAREN_RPAREN);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(anon_sym_LBRACK_RBRACK);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(anon_sym_DQUOTE_DQUOTE);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(578);
      if (lookahead == 'R') ADVANCE(713);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 710:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(700);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(580);
      if (lookahead == 'R') ADVANCE(714);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(579);
      if (lookahead == '8') ADVANCE(715);
      if (lookahead == 'R') ADVANCE(716);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 713:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(701);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(703);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 715:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(581);
      if (lookahead == 'R') ADVANCE(717);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(702);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(704);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(718);
      if (set_contains(sym_identifier_character_set_2, 802, lookahead)) ADVANCE(688);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(aux_sym_kernel_call_syntax_token1);
      END_STATE();
    case 720:
      ACCEPT_TOKEN(aux_sym_kernel_call_syntax_token2);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == 'N') ADVANCE(1);
      if (lookahead == '\\') SKIP(2);
      if (lookahead == '_') ADVANCE(3);
      if (lookahead == 'a') ADVANCE(4);
      if (lookahead == 'b') ADVANCE(5);
      if (lookahead == 'c') ADVANCE(6);
      if (lookahead == 'd') ADVANCE(7);
      if (lookahead == 'e') ADVANCE(8);
      if (lookahead == 'f') ADVANCE(9);
      if (lookahead == 'g') ADVANCE(10);
      if (lookahead == 'i') ADVANCE(11);
      if (lookahead == 'l') ADVANCE(12);
      if (lookahead == 'm') ADVANCE(13);
      if (lookahead == 'n') ADVANCE(14);
      if (lookahead == 'o') ADVANCE(15);
      if (lookahead == 'p') ADVANCE(16);
      if (lookahead == 'r') ADVANCE(17);
      if (lookahead == 's') ADVANCE(18);
      if (lookahead == 't') ADVANCE(19);
      if (lookahead == 'u') ADVANCE(20);
      if (lookahead == 'v') ADVANCE(21);
      if (lookahead == 'w') ADVANCE(22);
      if (lookahead == 'x') ADVANCE(23);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'U') ADVANCE(24);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(0);
      if (lookahead == '\r') SKIP(25);
      END_STATE();
    case 3:
      if (lookahead == 'A') ADVANCE(26);
      if (lookahead == 'G') ADVANCE(27);
      if (lookahead == 'N') ADVANCE(28);
      if (lookahead == '_') ADVANCE(29);
      if (lookahead == 'a') ADVANCE(30);
      if (lookahead == 'u') ADVANCE(31);
      END_STATE();
    case 4:
      if (lookahead == 'l') ADVANCE(32);
      if (lookahead == 'n') ADVANCE(33);
      if (lookahead == 's') ADVANCE(34);
      if (lookahead == 'u') ADVANCE(35);
      END_STATE();
    case 5:
      if (lookahead == 'i') ADVANCE(36);
      if (lookahead == 'r') ADVANCE(37);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(38);
      if (lookahead == 'l') ADVANCE(39);
      if (lookahead == 'o') ADVANCE(40);
      END_STATE();
    case 7:
      if (lookahead == 'e') ADVANCE(41);
      if (lookahead == 'o') ADVANCE(42);
      END_STATE();
    case 8:
      if (lookahead == 'l') ADVANCE(43);
      if (lookahead == 'n') ADVANCE(44);
      if (lookahead == 'x') ADVANCE(45);
      END_STATE();
    case 9:
      if (lookahead == 'i') ADVANCE(46);
      if (lookahead == 'o') ADVANCE(47);
      if (lookahead == 'r') ADVANCE(48);
      END_STATE();
    case 10:
      if (lookahead == 'o') ADVANCE(49);
      END_STATE();
    case 11:
      if (lookahead == 'f') ADVANCE(50);
      if (lookahead == 'n') ADVANCE(51);
      END_STATE();
    case 12:
      if (lookahead == 'o') ADVANCE(52);
      END_STATE();
    case 13:
      if (lookahead == 'u') ADVANCE(53);
      END_STATE();
    case 14:
      if (lookahead == 'a') ADVANCE(54);
      if (lookahead == 'e') ADVANCE(55);
      if (lookahead == 'o') ADVANCE(56);
      if (lookahead == 'u') ADVANCE(57);
      END_STATE();
    case 15:
      if (lookahead == 'f') ADVANCE(58);
      if (lookahead == 'p') ADVANCE(59);
      if (lookahead == 'r') ADVANCE(60);
      if (lookahead == 'v') ADVANCE(61);
      END_STATE();
    case 16:
      if (lookahead == 'r') ADVANCE(62);
      if (lookahead == 'u') ADVANCE(63);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(64);
      END_STATE();
    case 18:
      if (lookahead == 'h') ADVANCE(65);
      if (lookahead == 'i') ADVANCE(66);
      if (lookahead == 't') ADVANCE(67);
      if (lookahead == 'w') ADVANCE(68);
      END_STATE();
    case 19:
      if (lookahead == 'e') ADVANCE(69);
      if (lookahead == 'h') ADVANCE(70);
      if (lookahead == 'r') ADVANCE(71);
      if (lookahead == 'y') ADVANCE(72);
      END_STATE();
    case 20:
      if (lookahead == 'n') ADVANCE(73);
      if (lookahead == 's') ADVANCE(74);
      END_STATE();
    case 21:
      if (lookahead == 'i') ADVANCE(75);
      if (lookahead == 'o') ADVANCE(76);
      END_STATE();
    case 22:
      if (lookahead == 'h') ADVANCE(77);
      END_STATE();
    case 23:
      if (lookahead == 'o') ADVANCE(78);
      END_STATE();
    case 24:
      if (lookahead == 'L') ADVANCE(79);
      END_STATE();
    case 25:
      if (lookahead == '\n') SKIP(0);
      END_STATE();
    case 26:
      if (lookahead == 'l') ADVANCE(80);
      if (lookahead == 't') ADVANCE(81);
      END_STATE();
    case 27:
      if (lookahead == 'e') ADVANCE(82);
      END_STATE();
    case 28:
      if (lookahead == 'o') ADVANCE(83);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        'a', 84,
        'b', 85,
        'c', 86,
        'd', 87,
        'e', 88,
        'f', 89,
        'g', 90,
        'h', 91,
        'i', 92,
        'l', 93,
        'm', 94,
        'n', 95,
        'r', 96,
        's', 97,
        't', 98,
        'u', 99,
        'v', 100,
      );
      END_STATE();
    case 30:
      if (lookahead == 'l') ADVANCE(101);
      END_STATE();
    case 31:
      if (lookahead == 'n') ADVANCE(102);
      END_STATE();
    case 32:
      if (lookahead == 'i') ADVANCE(103);
      END_STATE();
    case 33:
      if (lookahead == 'd') ADVANCE(104);
      END_STATE();
    case 34:
      if (lookahead == 'm') ADVANCE(105);
      END_STATE();
    case 35:
      if (lookahead == 't') ADVANCE(106);
      END_STATE();
    case 36:
      if (lookahead == 't') ADVANCE(107);
      END_STATE();
    case 37:
      if (lookahead == 'e') ADVANCE(108);
      END_STATE();
    case 38:
      if (lookahead == 's') ADVANCE(109);
      if (lookahead == 't') ADVANCE(110);
      END_STATE();
    case 39:
      if (lookahead == 'a') ADVANCE(111);
      END_STATE();
    case 40:
      if (lookahead == '_') ADVANCE(112);
      if (lookahead == 'm') ADVANCE(113);
      if (lookahead == 'n') ADVANCE(114);
      END_STATE();
    case 41:
      if (lookahead == 'c') ADVANCE(115);
      if (lookahead == 'f') ADVANCE(116);
      if (lookahead == 'l') ADVANCE(117);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 43:
      if (lookahead == 's') ADVANCE(118);
      END_STATE();
    case 44:
      if (lookahead == 'u') ADVANCE(119);
      END_STATE();
    case 45:
      if (lookahead == 'p') ADVANCE(120);
      if (lookahead == 't') ADVANCE(121);
      END_STATE();
    case 46:
      if (lookahead == 'n') ADVANCE(122);
      END_STATE();
    case 47:
      if (lookahead == 'r') ADVANCE(123);
      END_STATE();
    case 48:
      if (lookahead == 'i') ADVANCE(124);
      END_STATE();
    case 49:
      if (lookahead == 't') ADVANCE(125);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 51:
      if (lookahead == 'l') ADVANCE(126);
      END_STATE();
    case 52:
      if (lookahead == 'n') ADVANCE(127);
      END_STATE();
    case 53:
      if (lookahead == 't') ADVANCE(128);
      END_STATE();
    case 54:
      if (lookahead == 'm') ADVANCE(129);
      END_STATE();
    case 55:
      if (lookahead == 'w') ADVANCE(130);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(131);
      if (lookahead == 'r') ADVANCE(132);
      if (lookahead == 't') ADVANCE(133);
      END_STATE();
    case 57:
      if (lookahead == 'l') ADVANCE(134);
      END_STATE();
    case 58:
      if (lookahead == 'f') ADVANCE(135);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == '_') ADVANCE(137);
      END_STATE();
    case 61:
      if (lookahead == 'e') ADVANCE(138);
      END_STATE();
    case 62:
      if (lookahead == 'i') ADVANCE(139);
      if (lookahead == 'o') ADVANCE(140);
      END_STATE();
    case 63:
      if (lookahead == 'b') ADVANCE(141);
      END_STATE();
    case 64:
      if (lookahead == 'g') ADVANCE(142);
      if (lookahead == 'q') ADVANCE(143);
      if (lookahead == 's') ADVANCE(144);
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 65:
      if (lookahead == 'o') ADVANCE(146);
      END_STATE();
    case 66:
      if (lookahead == 'g') ADVANCE(147);
      if (lookahead == 'z') ADVANCE(148);
      END_STATE();
    case 67:
      if (lookahead == 'a') ADVANCE(149);
      if (lookahead == 'r') ADVANCE(150);
      END_STATE();
    case 68:
      if (lookahead == 'i') ADVANCE(151);
      END_STATE();
    case 69:
      if (lookahead == 'm') ADVANCE(152);
      END_STATE();
    case 70:
      if (lookahead == 'i') ADVANCE(153);
      if (lookahead == 'r') ADVANCE(154);
      END_STATE();
    case 71:
      if (lookahead == 'y') ADVANCE(155);
      END_STATE();
    case 72:
      if (lookahead == 'p') ADVANCE(156);
      END_STATE();
    case 73:
      if (lookahead == 'i') ADVANCE(157);
      if (lookahead == 's') ADVANCE(158);
      END_STATE();
    case 74:
      if (lookahead == 'i') ADVANCE(159);
      END_STATE();
    case 75:
      if (lookahead == 'r') ADVANCE(160);
      END_STATE();
    case 76:
      if (lookahead == 'l') ADVANCE(161);
      END_STATE();
    case 77:
      if (lookahead == 'i') ADVANCE(162);
      END_STATE();
    case 78:
      if (lookahead == 'r') ADVANCE(163);
      END_STATE();
    case 79:
      if (lookahead == 'L') ADVANCE(164);
      END_STATE();
    case 80:
      if (lookahead == 'i') ADVANCE(165);
      END_STATE();
    case 81:
      if (lookahead == 'o') ADVANCE(166);
      END_STATE();
    case 82:
      if (lookahead == 'n') ADVANCE(167);
      END_STATE();
    case 83:
      if (lookahead == 'n') ADVANCE(168);
      if (lookahead == 'r') ADVANCE(169);
      END_STATE();
    case 84:
      if (lookahead == 'l') ADVANCE(170);
      if (lookahead == 's') ADVANCE(171);
      if (lookahead == 't') ADVANCE(172);
      END_STATE();
    case 85:
      if (lookahead == 'a') ADVANCE(173);
      END_STATE();
    case 86:
      if (lookahead == 'd') ADVANCE(174);
      if (lookahead == 'l') ADVANCE(175);
      if (lookahead == 'o') ADVANCE(176);
      END_STATE();
    case 87:
      if (lookahead == 'e') ADVANCE(177);
      END_STATE();
    case 88:
      if (lookahead == 'x') ADVANCE(178);
      END_STATE();
    case 89:
      if (lookahead == 'a') ADVANCE(179);
      if (lookahead == 'i') ADVANCE(180);
      if (lookahead == 'o') ADVANCE(181);
      END_STATE();
    case 90:
      if (lookahead == 'l') ADVANCE(182);
      if (lookahead == 'r') ADVANCE(183);
      END_STATE();
    case 91:
      if (lookahead == 'o') ADVANCE(184);
      END_STATE();
    case 92:
      if (lookahead == 'n') ADVANCE(185);
      END_STATE();
    case 93:
      if (lookahead == 'a') ADVANCE(186);
      if (lookahead == 'e') ADVANCE(187);
      if (lookahead == 'o') ADVANCE(188);
      END_STATE();
    case 94:
      if (lookahead == 'a') ADVANCE(189);
      END_STATE();
    case 95:
      if (lookahead == 'o') ADVANCE(190);
      END_STATE();
    case 96:
      if (lookahead == 'e') ADVANCE(191);
      END_STATE();
    case 97:
      if (lookahead == 'h') ADVANCE(192);
      if (lookahead == 'p') ADVANCE(193);
      if (lookahead == 't') ADVANCE(194);
      END_STATE();
    case 98:
      if (lookahead == 'h') ADVANCE(195);
      if (lookahead == 'r') ADVANCE(196);
      END_STATE();
    case 99:
      if (lookahead == 'n') ADVANCE(197);
      if (lookahead == 'p') ADVANCE(198);
      END_STATE();
    case 100:
      if (lookahead == 'e') ADVANCE(199);
      if (lookahead == 'o') ADVANCE(200);
      END_STATE();
    case 101:
      if (lookahead == 'i') ADVANCE(201);
      END_STATE();
    case 102:
      if (lookahead == 'a') ADVANCE(202);
      END_STATE();
    case 103:
      if (lookahead == 'g') ADVANCE(203);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_and);
      if (lookahead == '_') ADVANCE(204);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_asm);
      END_STATE();
    case 106:
      if (lookahead == 'o') ADVANCE(205);
      END_STATE();
    case 107:
      if (lookahead == 'a') ADVANCE(206);
      if (lookahead == 'o') ADVANCE(207);
      END_STATE();
    case 108:
      if (lookahead == 'a') ADVANCE(208);
      END_STATE();
    case 109:
      if (lookahead == 'e') ADVANCE(209);
      END_STATE();
    case 110:
      if (lookahead == 'c') ADVANCE(210);
      END_STATE();
    case 111:
      if (lookahead == 's') ADVANCE(211);
      END_STATE();
    case 112:
      if (lookahead == 'a') ADVANCE(212);
      if (lookahead == 'r') ADVANCE(213);
      if (lookahead == 'y') ADVANCE(214);
      END_STATE();
    case 113:
      if (lookahead == 'p') ADVANCE(215);
      END_STATE();
    case 114:
      if (lookahead == 'c') ADVANCE(216);
      if (lookahead == 's') ADVANCE(217);
      if (lookahead == 't') ADVANCE(218);
      END_STATE();
    case 115:
      if (lookahead == 'l') ADVANCE(219);
      END_STATE();
    case 116:
      if (lookahead == 'a') ADVANCE(220);
      if (lookahead == 'i') ADVANCE(221);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(222);
      END_STATE();
    case 118:
      if (lookahead == 'e') ADVANCE(223);
      END_STATE();
    case 119:
      if (lookahead == 'm') ADVANCE(224);
      END_STATE();
    case 120:
      if (lookahead == 'l') ADVANCE(225);
      END_STATE();
    case 121:
      if (lookahead == 'e') ADVANCE(226);
      END_STATE();
    case 122:
      if (lookahead == 'a') ADVANCE(227);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 124:
      if (lookahead == 'e') ADVANCE(228);
      END_STATE();
    case 125:
      if (lookahead == 'o') ADVANCE(229);
      END_STATE();
    case 126:
      if (lookahead == 'i') ADVANCE(230);
      END_STATE();
    case 127:
      if (lookahead == 'g') ADVANCE(231);
      END_STATE();
    case 128:
      if (lookahead == 'a') ADVANCE(232);
      END_STATE();
    case 129:
      if (lookahead == 'e') ADVANCE(233);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 131:
      if (lookahead == 'x') ADVANCE(234);
      END_STATE();
    case 132:
      if (lookahead == 'e') ADVANCE(235);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_not);
      if (lookahead == '_') ADVANCE(236);
      END_STATE();
    case 134:
      if (lookahead == 'l') ADVANCE(237);
      END_STATE();
    case 135:
      if (lookahead == 's') ADVANCE(238);
      END_STATE();
    case 136:
      if (lookahead == 'r') ADVANCE(239);
      END_STATE();
    case 137:
      if (lookahead == 'e') ADVANCE(240);
      END_STATE();
    case 138:
      if (lookahead == 'r') ADVANCE(241);
      END_STATE();
    case 139:
      if (lookahead == 'v') ADVANCE(242);
      END_STATE();
    case 140:
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 141:
      if (lookahead == 'l') ADVANCE(244);
      END_STATE();
    case 142:
      if (lookahead == 'i') ADVANCE(245);
      END_STATE();
    case 143:
      if (lookahead == 'u') ADVANCE(246);
      END_STATE();
    case 144:
      if (lookahead == 't') ADVANCE(247);
      END_STATE();
    case 145:
      if (lookahead == 'u') ADVANCE(248);
      END_STATE();
    case 146:
      if (lookahead == 'r') ADVANCE(249);
      END_STATE();
    case 147:
      if (lookahead == 'n') ADVANCE(250);
      END_STATE();
    case 148:
      if (lookahead == 'e') ADVANCE(251);
      END_STATE();
    case 149:
      if (lookahead == 't') ADVANCE(252);
      END_STATE();
    case 150:
      if (lookahead == 'u') ADVANCE(253);
      END_STATE();
    case 151:
      if (lookahead == 't') ADVANCE(254);
      END_STATE();
    case 152:
      if (lookahead == 'p') ADVANCE(255);
      END_STATE();
    case 153:
      if (lookahead == 's') ADVANCE(256);
      END_STATE();
    case 154:
      if (lookahead == 'e') ADVANCE(257);
      if (lookahead == 'o') ADVANCE(258);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 156:
      if (lookahead == 'e') ADVANCE(259);
      END_STATE();
    case 157:
      if (lookahead == 'o') ADVANCE(260);
      END_STATE();
    case 158:
      if (lookahead == 'i') ADVANCE(261);
      END_STATE();
    case 159:
      if (lookahead == 'n') ADVANCE(262);
      END_STATE();
    case 160:
      if (lookahead == 't') ADVANCE(263);
      END_STATE();
    case 161:
      if (lookahead == 'a') ADVANCE(264);
      END_STATE();
    case 162:
      if (lookahead == 'l') ADVANCE(265);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_xor);
      if (lookahead == '_') ADVANCE(266);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_NULL);
      END_STATE();
    case 165:
      if (lookahead == 'g') ADVANCE(267);
      END_STATE();
    case 166:
      if (lookahead == 'm') ADVANCE(268);
      END_STATE();
    case 167:
      if (lookahead == 'e') ADVANCE(269);
      END_STATE();
    case 168:
      if (lookahead == 'n') ADVANCE(270);
      END_STATE();
    case 169:
      if (lookahead == 'e') ADVANCE(271);
      END_STATE();
    case 170:
      if (lookahead == 'i') ADVANCE(272);
      END_STATE();
    case 171:
      if (lookahead == 'm') ADVANCE(273);
      END_STATE();
    case 172:
      if (lookahead == 't') ADVANCE(274);
      END_STATE();
    case 173:
      if (lookahead == 's') ADVANCE(275);
      END_STATE();
    case 174:
      if (lookahead == 'e') ADVANCE(276);
      END_STATE();
    case 175:
      if (lookahead == 'r') ADVANCE(277);
      END_STATE();
    case 176:
      if (lookahead == 'n') ADVANCE(278);
      END_STATE();
    case 177:
      if (lookahead == 'c') ADVANCE(279);
      if (lookahead == 'v') ADVANCE(280);
      END_STATE();
    case 178:
      if (lookahead == 'c') ADVANCE(281);
      if (lookahead == 't') ADVANCE(282);
      END_STATE();
    case 179:
      if (lookahead == 's') ADVANCE(283);
      END_STATE();
    case 180:
      if (lookahead == 'n') ADVANCE(284);
      END_STATE();
    case 181:
      if (lookahead == 'r') ADVANCE(285);
      END_STATE();
    case 182:
      if (lookahead == 'o') ADVANCE(286);
      END_STATE();
    case 183:
      if (lookahead == 'i') ADVANCE(287);
      END_STATE();
    case 184:
      if (lookahead == 's') ADVANCE(288);
      END_STATE();
    case 185:
      if (lookahead == 'l') ADVANCE(289);
      END_STATE();
    case 186:
      if (lookahead == 'u') ADVANCE(290);
      END_STATE();
    case 187:
      if (lookahead == 'a') ADVANCE(291);
      END_STATE();
    case 188:
      if (lookahead == 'c') ADVANCE(292);
      END_STATE();
    case 189:
      if (lookahead == 'n') ADVANCE(293);
      END_STATE();
    case 190:
      if (lookahead == 'i') ADVANCE(294);
      END_STATE();
    case 191:
      if (lookahead == 's') ADVANCE(295);
      END_STATE();
    case 192:
      if (lookahead == 'a') ADVANCE(296);
      END_STATE();
    case 193:
      if (lookahead == 't') ADVANCE(297);
      END_STATE();
    case 194:
      if (lookahead == 'd') ADVANCE(298);
      END_STATE();
    case 195:
      if (lookahead == 'i') ADVANCE(299);
      if (lookahead == 'r') ADVANCE(300);
      END_STATE();
    case 196:
      if (lookahead == 'y') ADVANCE(301);
      END_STATE();
    case 197:
      if (lookahead == 'a') ADVANCE(302);
      END_STATE();
    case 198:
      if (lookahead == 't') ADVANCE(303);
      END_STATE();
    case 199:
      if (lookahead == 'c') ADVANCE(304);
      END_STATE();
    case 200:
      if (lookahead == 'l') ADVANCE(305);
      END_STATE();
    case 201:
      if (lookahead == 'g') ADVANCE(306);
      END_STATE();
    case 202:
      if (lookahead == 'l') ADVANCE(307);
      END_STATE();
    case 203:
      if (lookahead == 'n') ADVANCE(308);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(309);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(sym_auto);
      END_STATE();
    case 206:
      if (lookahead == 'n') ADVANCE(310);
      END_STATE();
    case 207:
      if (lookahead == 'r') ADVANCE(311);
      END_STATE();
    case 208:
      if (lookahead == 'k') ADVANCE(312);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 210:
      if (lookahead == 'h') ADVANCE(313);
      END_STATE();
    case 211:
      if (lookahead == 's') ADVANCE(314);
      END_STATE();
    case 212:
      if (lookahead == 'w') ADVANCE(315);
      END_STATE();
    case 213:
      if (lookahead == 'e') ADVANCE(316);
      END_STATE();
    case 214:
      if (lookahead == 'i') ADVANCE(317);
      END_STATE();
    case 215:
      if (lookahead == 'l') ADVANCE(318);
      END_STATE();
    case 216:
      if (lookahead == 'e') ADVANCE(319);
      END_STATE();
    case 217:
      if (lookahead == 't') ADVANCE(320);
      END_STATE();
    case 218:
      if (lookahead == 'i') ADVANCE(321);
      END_STATE();
    case 219:
      if (lookahead == 't') ADVANCE(322);
      END_STATE();
    case 220:
      if (lookahead == 'u') ADVANCE(323);
      END_STATE();
    case 221:
      if (lookahead == 'n') ADVANCE(324);
      END_STATE();
    case 222:
      if (lookahead == 't') ADVANCE(325);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 225:
      if (lookahead == 'i') ADVANCE(326);
      END_STATE();
    case 226:
      if (lookahead == 'r') ADVANCE(327);
      END_STATE();
    case 227:
      if (lookahead == 'l') ADVANCE(328);
      END_STATE();
    case 228:
      if (lookahead == 'n') ADVANCE(329);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(anon_sym_goto);
      END_STATE();
    case 230:
      if (lookahead == 'n') ADVANCE(330);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_long);
      END_STATE();
    case 232:
      if (lookahead == 'b') ADVANCE(331);
      END_STATE();
    case 233:
      if (lookahead == 's') ADVANCE(332);
      END_STATE();
    case 234:
      if (lookahead == 'c') ADVANCE(333);
      END_STATE();
    case 235:
      if (lookahead == 't') ADVANCE(334);
      END_STATE();
    case 236:
      if (lookahead == 'e') ADVANCE(335);
      END_STATE();
    case 237:
      if (lookahead == 'p') ADVANCE(336);
      END_STATE();
    case 238:
      if (lookahead == 'e') ADVANCE(337);
      END_STATE();
    case 239:
      if (lookahead == 'a') ADVANCE(338);
      END_STATE();
    case 240:
      if (lookahead == 'q') ADVANCE(339);
      END_STATE();
    case 241:
      if (lookahead == 'r') ADVANCE(340);
      END_STATE();
    case 242:
      if (lookahead == 'a') ADVANCE(341);
      END_STATE();
    case 243:
      if (lookahead == 'e') ADVANCE(342);
      END_STATE();
    case 244:
      if (lookahead == 'i') ADVANCE(343);
      END_STATE();
    case 245:
      if (lookahead == 's') ADVANCE(344);
      END_STATE();
    case 246:
      if (lookahead == 'i') ADVANCE(345);
      END_STATE();
    case 247:
      if (lookahead == 'r') ADVANCE(346);
      END_STATE();
    case 248:
      if (lookahead == 'r') ADVANCE(347);
      END_STATE();
    case 249:
      if (lookahead == 't') ADVANCE(348);
      END_STATE();
    case 250:
      if (lookahead == 'e') ADVANCE(349);
      END_STATE();
    case 251:
      if (lookahead == 'o') ADVANCE(350);
      END_STATE();
    case 252:
      if (lookahead == 'i') ADVANCE(351);
      END_STATE();
    case 253:
      if (lookahead == 'c') ADVANCE(352);
      END_STATE();
    case 254:
      if (lookahead == 'c') ADVANCE(353);
      END_STATE();
    case 255:
      if (lookahead == 'l') ADVANCE(354);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(sym_this);
      END_STATE();
    case 257:
      if (lookahead == 'a') ADVANCE(355);
      END_STATE();
    case 258:
      if (lookahead == 'w') ADVANCE(356);
      END_STATE();
    case 259:
      if (lookahead == 'd') ADVANCE(357);
      if (lookahead == 'n') ADVANCE(358);
      END_STATE();
    case 260:
      if (lookahead == 'n') ADVANCE(359);
      END_STATE();
    case 261:
      if (lookahead == 'g') ADVANCE(360);
      END_STATE();
    case 262:
      if (lookahead == 'g') ADVANCE(361);
      END_STATE();
    case 263:
      if (lookahead == 'u') ADVANCE(362);
      END_STATE();
    case 264:
      if (lookahead == 't') ADVANCE(363);
      END_STATE();
    case 265:
      if (lookahead == 'e') ADVANCE(364);
      END_STATE();
    case 266:
      if (lookahead == 'e') ADVANCE(365);
      END_STATE();
    case 267:
      if (lookahead == 'n') ADVANCE(366);
      END_STATE();
    case 268:
      if (lookahead == 'i') ADVANCE(367);
      END_STATE();
    case 269:
      if (lookahead == 'r') ADVANCE(368);
      END_STATE();
    case 270:
      if (lookahead == 'u') ADVANCE(369);
      END_STATE();
    case 271:
      if (lookahead == 't') ADVANCE(370);
      END_STATE();
    case 272:
      if (lookahead == 'g') ADVANCE(371);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym___asm);
      if (lookahead == '_') ADVANCE(372);
      END_STATE();
    case 274:
      if (lookahead == 'r') ADVANCE(373);
      END_STATE();
    case 275:
      if (lookahead == 'e') ADVANCE(374);
      END_STATE();
    case 276:
      if (lookahead == 'c') ADVANCE(375);
      END_STATE();
    case 277:
      if (lookahead == 'c') ADVANCE(376);
      END_STATE();
    case 278:
      if (lookahead == 's') ADVANCE(377);
      END_STATE();
    case 279:
      if (lookahead == 'l') ADVANCE(378);
      END_STATE();
    case 280:
      if (lookahead == 'i') ADVANCE(379);
      END_STATE();
    case 281:
      if (lookahead == 'e') ADVANCE(380);
      END_STATE();
    case 282:
      if (lookahead == 'e') ADVANCE(381);
      END_STATE();
    case 283:
      if (lookahead == 't') ADVANCE(382);
      END_STATE();
    case 284:
      if (lookahead == 'a') ADVANCE(383);
      END_STATE();
    case 285:
      if (lookahead == 'c') ADVANCE(384);
      END_STATE();
    case 286:
      if (lookahead == 'b') ADVANCE(385);
      END_STATE();
    case 287:
      if (lookahead == 'd') ADVANCE(386);
      END_STATE();
    case 288:
      if (lookahead == 't') ADVANCE(387);
      END_STATE();
    case 289:
      if (lookahead == 'i') ADVANCE(388);
      END_STATE();
    case 290:
      if (lookahead == 'n') ADVANCE(389);
      END_STATE();
    case 291:
      if (lookahead == 'v') ADVANCE(390);
      END_STATE();
    case 292:
      if (lookahead == 'a') ADVANCE(391);
      END_STATE();
    case 293:
      if (lookahead == 'a') ADVANCE(392);
      END_STATE();
    case 294:
      if (lookahead == 'n') ADVANCE(393);
      END_STATE();
    case 295:
      if (lookahead == 't') ADVANCE(394);
      END_STATE();
    case 296:
      if (lookahead == 'r') ADVANCE(395);
      END_STATE();
    case 297:
      if (lookahead == 'r') ADVANCE(396);
      END_STATE();
    case 298:
      if (lookahead == 'c') ADVANCE(397);
      END_STATE();
    case 299:
      if (lookahead == 's') ADVANCE(398);
      END_STATE();
    case 300:
      if (lookahead == 'e') ADVANCE(399);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(anon_sym___try);
      END_STATE();
    case 302:
      if (lookahead == 'l') ADVANCE(400);
      END_STATE();
    case 303:
      if (lookahead == 'r') ADVANCE(401);
      END_STATE();
    case 304:
      if (lookahead == 't') ADVANCE(402);
      END_STATE();
    case 305:
      if (lookahead == 'a') ADVANCE(403);
      END_STATE();
    case 306:
      if (lookahead == 'n') ADVANCE(404);
      END_STATE();
    case 307:
      if (lookahead == 'i') ADVANCE(405);
      END_STATE();
    case 308:
      if (lookahead == 'a') ADVANCE(406);
      if (lookahead == 'o') ADVANCE(407);
      END_STATE();
    case 309:
      if (lookahead == 'q') ADVANCE(408);
      END_STATE();
    case 310:
      if (lookahead == 'd') ADVANCE(409);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(anon_sym_bitor);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 315:
      if (lookahead == 'a') ADVANCE(410);
      END_STATE();
    case 316:
      if (lookahead == 't') ADVANCE(411);
      END_STATE();
    case 317:
      if (lookahead == 'e') ADVANCE(412);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(anon_sym_compl);
      END_STATE();
    case 319:
      if (lookahead == 'p') ADVANCE(413);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(anon_sym_const);
      if (lookahead == 'e') ADVANCE(414);
      if (lookahead == 'i') ADVANCE(415);
      END_STATE();
    case 321:
      if (lookahead == 'n') ADVANCE(416);
      END_STATE();
    case 322:
      if (lookahead == 'y') ADVANCE(417);
      END_STATE();
    case 323:
      if (lookahead == 'l') ADVANCE(418);
      END_STATE();
    case 324:
      if (lookahead == 'e') ADVANCE(419);
      END_STATE();
    case 325:
      if (lookahead == 'e') ADVANCE(420);
      END_STATE();
    case 326:
      if (lookahead == 'c') ADVANCE(421);
      END_STATE();
    case 327:
      if (lookahead == 'n') ADVANCE(422);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(anon_sym_final);
      END_STATE();
    case 329:
      if (lookahead == 'd') ADVANCE(423);
      END_STATE();
    case 330:
      if (lookahead == 'e') ADVANCE(424);
      END_STATE();
    case 331:
      if (lookahead == 'l') ADVANCE(425);
      END_STATE();
    case 332:
      if (lookahead == 'p') ADVANCE(426);
      END_STATE();
    case 333:
      if (lookahead == 'e') ADVANCE(427);
      END_STATE();
    case 334:
      if (lookahead == 'u') ADVANCE(428);
      END_STATE();
    case 335:
      if (lookahead == 'q') ADVANCE(429);
      END_STATE();
    case 336:
      if (lookahead == 't') ADVANCE(430);
      END_STATE();
    case 337:
      if (lookahead == 't') ADVANCE(431);
      END_STATE();
    case 338:
      if (lookahead == 't') ADVANCE(432);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(anon_sym_or_eq);
      END_STATE();
    case 340:
      if (lookahead == 'i') ADVANCE(433);
      END_STATE();
    case 341:
      if (lookahead == 't') ADVANCE(434);
      END_STATE();
    case 342:
      if (lookahead == 'c') ADVANCE(435);
      END_STATE();
    case 343:
      if (lookahead == 'c') ADVANCE(436);
      END_STATE();
    case 344:
      if (lookahead == 't') ADVANCE(437);
      END_STATE();
    case 345:
      if (lookahead == 'r') ADVANCE(438);
      END_STATE();
    case 346:
      if (lookahead == 'i') ADVANCE(439);
      END_STATE();
    case 347:
      if (lookahead == 'n') ADVANCE(440);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(anon_sym_short);
      END_STATE();
    case 349:
      if (lookahead == 'd') ADVANCE(441);
      END_STATE();
    case 350:
      if (lookahead == 'f') ADVANCE(442);
      END_STATE();
    case 351:
      if (lookahead == 'c') ADVANCE(443);
      END_STATE();
    case 352:
      if (lookahead == 't') ADVANCE(444);
      END_STATE();
    case 353:
      if (lookahead == 'h') ADVANCE(445);
      END_STATE();
    case 354:
      if (lookahead == 'a') ADVANCE(446);
      END_STATE();
    case 355:
      if (lookahead == 'd') ADVANCE(447);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(anon_sym_throw);
      END_STATE();
    case 357:
      if (lookahead == 'e') ADVANCE(448);
      END_STATE();
    case 358:
      if (lookahead == 'a') ADVANCE(449);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 360:
      if (lookahead == 'n') ADVANCE(450);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 362:
      if (lookahead == 'a') ADVANCE(451);
      END_STATE();
    case 363:
      if (lookahead == 'i') ADVANCE(452);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 365:
      if (lookahead == 'q') ADVANCE(453);
      END_STATE();
    case 366:
      if (lookahead == 'a') ADVANCE(454);
      if (lookahead == 'o') ADVANCE(455);
      END_STATE();
    case 367:
      if (lookahead == 'c') ADVANCE(456);
      END_STATE();
    case 368:
      if (lookahead == 'i') ADVANCE(457);
      END_STATE();
    case 369:
      if (lookahead == 'l') ADVANCE(458);
      END_STATE();
    case 370:
      if (lookahead == 'u') ADVANCE(459);
      END_STATE();
    case 371:
      if (lookahead == 'n') ADVANCE(460);
      END_STATE();
    case 372:
      if (lookahead == '_') ADVANCE(461);
      END_STATE();
    case 373:
      if (lookahead == 'i') ADVANCE(462);
      END_STATE();
    case 374:
      if (lookahead == 'd') ADVANCE(463);
      END_STATE();
    case 375:
      if (lookahead == 'l') ADVANCE(464);
      END_STATE();
    case 376:
      if (lookahead == 'a') ADVANCE(465);
      END_STATE();
    case 377:
      if (lookahead == 't') ADVANCE(466);
      END_STATE();
    case 378:
      if (lookahead == 's') ADVANCE(467);
      END_STATE();
    case 379:
      if (lookahead == 'c') ADVANCE(468);
      END_STATE();
    case 380:
      if (lookahead == 'p') ADVANCE(469);
      END_STATE();
    case 381:
      if (lookahead == 'n') ADVANCE(470);
      END_STATE();
    case 382:
      if (lookahead == 'c') ADVANCE(471);
      END_STATE();
    case 383:
      if (lookahead == 'l') ADVANCE(472);
      END_STATE();
    case 384:
      if (lookahead == 'e') ADVANCE(473);
      END_STATE();
    case 385:
      if (lookahead == 'a') ADVANCE(474);
      END_STATE();
    case 386:
      if (lookahead == '_') ADVANCE(475);
      END_STATE();
    case 387:
      if (lookahead == '_') ADVANCE(476);
      END_STATE();
    case 388:
      if (lookahead == 'n') ADVANCE(477);
      END_STATE();
    case 389:
      if (lookahead == 'c') ADVANCE(478);
      END_STATE();
    case 390:
      if (lookahead == 'e') ADVANCE(479);
      END_STATE();
    case 391:
      if (lookahead == 'l') ADVANCE(480);
      END_STATE();
    case 392:
      if (lookahead == 'g') ADVANCE(481);
      END_STATE();
    case 393:
      if (lookahead == 'l') ADVANCE(482);
      END_STATE();
    case 394:
      if (lookahead == 'r') ADVANCE(483);
      END_STATE();
    case 395:
      if (lookahead == 'e') ADVANCE(484);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(sym_ms_signed_ptr_modifier);
      END_STATE();
    case 397:
      if (lookahead == 'a') ADVANCE(485);
      END_STATE();
    case 398:
      if (lookahead == 'c') ADVANCE(486);
      END_STATE();
    case 399:
      if (lookahead == 'a') ADVANCE(487);
      END_STATE();
    case 400:
      if (lookahead == 'i') ADVANCE(488);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(sym_ms_unsigned_ptr_modifier);
      END_STATE();
    case 402:
      if (lookahead == 'o') ADVANCE(489);
      END_STATE();
    case 403:
      if (lookahead == 't') ADVANCE(490);
      END_STATE();
    case 404:
      if (lookahead == 'o') ADVANCE(491);
      END_STATE();
    case 405:
      if (lookahead == 'g') ADVANCE(492);
      END_STATE();
    case 406:
      if (lookahead == 's') ADVANCE(493);
      END_STATE();
    case 407:
      if (lookahead == 'f') ADVANCE(494);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(anon_sym_and_eq);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_bitand);
      END_STATE();
    case 410:
      if (lookahead == 'i') ADVANCE(495);
      END_STATE();
    case 411:
      if (lookahead == 'u') ADVANCE(496);
      END_STATE();
    case 412:
      if (lookahead == 'l') ADVANCE(497);
      END_STATE();
    case 413:
      if (lookahead == 't') ADVANCE(498);
      END_STATE();
    case 414:
      if (lookahead == 'v') ADVANCE(499);
      if (lookahead == 'x') ADVANCE(500);
      END_STATE();
    case 415:
      if (lookahead == 'n') ADVANCE(501);
      END_STATE();
    case 416:
      if (lookahead == 'u') ADVANCE(502);
      END_STATE();
    case 417:
      if (lookahead == 'p') ADVANCE(503);
      END_STATE();
    case 418:
      if (lookahead == 't') ADVANCE(504);
      END_STATE();
    case 419:
      if (lookahead == 'd') ADVANCE(505);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_delete);
      END_STATE();
    case 421:
      if (lookahead == 'i') ADVANCE(506);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(anon_sym_extern);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(anon_sym_friend);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(anon_sym_inline);
      END_STATE();
    case 425:
      if (lookahead == 'e') ADVANCE(507);
      END_STATE();
    case 426:
      if (lookahead == 'a') ADVANCE(508);
      END_STATE();
    case 427:
      if (lookahead == 'p') ADVANCE(509);
      END_STATE();
    case 428:
      if (lookahead == 'r') ADVANCE(510);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(anon_sym_not_eq);
      END_STATE();
    case 430:
      if (lookahead == 'r') ADVANCE(511);
      END_STATE();
    case 431:
      if (lookahead == 'o') ADVANCE(512);
      END_STATE();
    case 432:
      if (lookahead == 'o') ADVANCE(513);
      END_STATE();
    case 433:
      if (lookahead == 'd') ADVANCE(514);
      END_STATE();
    case 434:
      if (lookahead == 'e') ADVANCE(515);
      END_STATE();
    case 435:
      if (lookahead == 't') ADVANCE(516);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 437:
      if (lookahead == 'e') ADVANCE(517);
      END_STATE();
    case 438:
      if (lookahead == 'e') ADVANCE(518);
      END_STATE();
    case 439:
      if (lookahead == 'c') ADVANCE(519);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_signed);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(anon_sym_sizeof);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(anon_sym_static);
      if (lookahead == '_') ADVANCE(520);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 446:
      if (lookahead == 't') ADVANCE(521);
      END_STATE();
    case 447:
      if (lookahead == '_') ADVANCE(522);
      END_STATE();
    case 448:
      if (lookahead == 'f') ADVANCE(523);
      END_STATE();
    case 449:
      if (lookahead == 'm') ADVANCE(524);
      END_STATE();
    case 450:
      if (lookahead == 'e') ADVANCE(525);
      END_STATE();
    case 451:
      if (lookahead == 'l') ADVANCE(526);
      END_STATE();
    case 452:
      if (lookahead == 'l') ADVANCE(527);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(anon_sym_xor_eq);
      END_STATE();
    case 454:
      if (lookahead == 's') ADVANCE(528);
      END_STATE();
    case 455:
      if (lookahead == 'f') ADVANCE(529);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym__Atomic);
      END_STATE();
    case 457:
      if (lookahead == 'c') ADVANCE(530);
      END_STATE();
    case 458:
      if (lookahead == 'l') ADVANCE(531);
      END_STATE();
    case 459:
      if (lookahead == 'r') ADVANCE(532);
      END_STATE();
    case 460:
      if (lookahead == 'o') ADVANCE(533);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym___asm__);
      END_STATE();
    case 462:
      if (lookahead == 'b') ADVANCE(534);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym___based);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym___cdecl);
      END_STATE();
    case 465:
      if (lookahead == 'l') ADVANCE(535);
      END_STATE();
    case 466:
      if (lookahead == 'a') ADVANCE(536);
      END_STATE();
    case 467:
      if (lookahead == 'p') ADVANCE(537);
      END_STATE();
    case 468:
      if (lookahead == 'e') ADVANCE(538);
      END_STATE();
    case 469:
      if (lookahead == 't') ADVANCE(539);
      END_STATE();
    case 470:
      if (lookahead == 's') ADVANCE(540);
      END_STATE();
    case 471:
      if (lookahead == 'a') ADVANCE(541);
      END_STATE();
    case 472:
      if (lookahead == 'l') ADVANCE(542);
      END_STATE();
    case 473:
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 474:
      if (lookahead == 'l') ADVANCE(544);
      END_STATE();
    case 475:
      if (lookahead == 'c') ADVANCE(545);
      END_STATE();
    case 476:
      if (lookahead == '_') ADVANCE(546);
      END_STATE();
    case 477:
      if (lookahead == 'e') ADVANCE(547);
      END_STATE();
    case 478:
      if (lookahead == 'h') ADVANCE(548);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym___leave);
      END_STATE();
    case 480:
      if (lookahead == '_') ADVANCE(549);
      END_STATE();
    case 481:
      if (lookahead == 'e') ADVANCE(550);
      END_STATE();
    case 482:
      if (lookahead == 'i') ADVANCE(551);
      END_STATE();
    case 483:
      if (lookahead == 'i') ADVANCE(552);
      END_STATE();
    case 484:
      if (lookahead == 'd') ADVANCE(553);
      END_STATE();
    case 485:
      if (lookahead == 'l') ADVANCE(554);
      END_STATE();
    case 486:
      if (lookahead == 'a') ADVANCE(555);
      END_STATE();
    case 487:
      if (lookahead == 'd') ADVANCE(556);
      END_STATE();
    case 488:
      if (lookahead == 'g') ADVANCE(557);
      END_STATE();
    case 489:
      if (lookahead == 'r') ADVANCE(558);
      END_STATE();
    case 490:
      if (lookahead == 'i') ADVANCE(559);
      END_STATE();
    case 491:
      if (lookahead == 'f') ADVANCE(560);
      END_STATE();
    case 492:
      if (lookahead == 'n') ADVANCE(561);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_alignas);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_alignof);
      END_STATE();
    case 495:
      if (lookahead == 't') ADVANCE(562);
      END_STATE();
    case 496:
      if (lookahead == 'r') ADVANCE(563);
      END_STATE();
    case 497:
      if (lookahead == 'd') ADVANCE(564);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_concept);
      END_STATE();
    case 499:
      if (lookahead == 'a') ADVANCE(565);
      END_STATE();
    case 500:
      if (lookahead == 'p') ADVANCE(566);
      END_STATE();
    case 501:
      if (lookahead == 'i') ADVANCE(567);
      END_STATE();
    case 502:
      if (lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 503:
      if (lookahead == 'e') ADVANCE(569);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(anon_sym_defined);
      END_STATE();
    case 506:
      if (lookahead == 't') ADVANCE(570);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_mutable);
      END_STATE();
    case 508:
      if (lookahead == 'c') ADVANCE(571);
      END_STATE();
    case 509:
      if (lookahead == 't') ADVANCE(572);
      END_STATE();
    case 510:
      if (lookahead == 'n') ADVANCE(573);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_nullptr);
      END_STATE();
    case 512:
      if (lookahead == 'f') ADVANCE(574);
      END_STATE();
    case 513:
      if (lookahead == 'r') ADVANCE(575);
      END_STATE();
    case 514:
      if (lookahead == 'e') ADVANCE(576);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 516:
      if (lookahead == 'e') ADVANCE(577);
      END_STATE();
    case 517:
      if (lookahead == 'r') ADVANCE(578);
      END_STATE();
    case 518:
      if (lookahead == 's') ADVANCE(579);
      END_STATE();
    case 519:
      if (lookahead == 't') ADVANCE(580);
      END_STATE();
    case 520:
      if (lookahead == 'a') ADVANCE(581);
      END_STATE();
    case 521:
      if (lookahead == 'e') ADVANCE(582);
      END_STATE();
    case 522:
      if (lookahead == 'l') ADVANCE(583);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_typedef);
      END_STATE();
    case 524:
      if (lookahead == 'e') ADVANCE(584);
      END_STATE();
    case 525:
      if (lookahead == 'd') ADVANCE(585);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_virtual);
      END_STATE();
    case 527:
      if (lookahead == 'e') ADVANCE(586);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym__Alignas);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym__Alignof);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym__Generic);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym__Nonnull);
      END_STATE();
    case 532:
      if (lookahead == 'n') ADVANCE(587);
      END_STATE();
    case 533:
      if (lookahead == 'f') ADVANCE(588);
      END_STATE();
    case 534:
      if (lookahead == 'u') ADVANCE(589);
      END_STATE();
    case 535:
      if (lookahead == 'l') ADVANCE(590);
      END_STATE();
    case 536:
      if (lookahead == 'n') ADVANCE(591);
      END_STATE();
    case 537:
      if (lookahead == 'e') ADVANCE(592);
      END_STATE();
    case 538:
      if (lookahead == '_') ADVANCE(593);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym___except);
      END_STATE();
    case 540:
      if (lookahead == 'i') ADVANCE(594);
      END_STATE();
    case 541:
      if (lookahead == 'l') ADVANCE(595);
      END_STATE();
    case 542:
      if (lookahead == 'y') ADVANCE(596);
      END_STATE();
    case 543:
      if (lookahead == 'n') ADVANCE(597);
      END_STATE();
    case 544:
      if (lookahead == '_') ADVANCE(598);
      END_STATE();
    case 545:
      if (lookahead == 'o') ADVANCE(599);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym___host__);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym___inline);
      if (lookahead == '_') ADVANCE(600);
      END_STATE();
    case 548:
      if (lookahead == '_') ADVANCE(601);
      END_STATE();
    case 549:
      if (lookahead == '_') ADVANCE(602);
      END_STATE();
    case 550:
      if (lookahead == 'd') ADVANCE(603);
      END_STATE();
    case 551:
      if (lookahead == 'n') ADVANCE(604);
      END_STATE();
    case 552:
      if (lookahead == 'c') ADVANCE(605);
      END_STATE();
    case 553:
      if (lookahead == '_') ADVANCE(606);
      END_STATE();
    case 554:
      if (lookahead == 'l') ADVANCE(607);
      END_STATE();
    case 555:
      if (lookahead == 'l') ADVANCE(608);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(anon_sym___thread);
      END_STATE();
    case 557:
      if (lookahead == 'n') ADVANCE(609);
      END_STATE();
    case 558:
      if (lookahead == 'c') ADVANCE(610);
      END_STATE();
    case 559:
      if (lookahead == 'l') ADVANCE(611);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym__alignof);
      END_STATE();
    case 561:
      if (lookahead == 'e') ADVANCE(612);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_co_await);
      END_STATE();
    case 563:
      if (lookahead == 'n') ADVANCE(613);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_co_yield);
      END_STATE();
    case 565:
      if (lookahead == 'l') ADVANCE(614);
      END_STATE();
    case 566:
      if (lookahead == 'r') ADVANCE(615);
      END_STATE();
    case 567:
      if (lookahead == 't') ADVANCE(616);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_decltype);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_explicit);
      END_STATE();
    case 571:
      if (lookahead == 'e') ADVANCE(617);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_noexcept);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_noreturn);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_offsetof);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_operator);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_override);
      END_STATE();
    case 577:
      if (lookahead == 'd') ADVANCE(618);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_register);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_requires);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_restrict);
      END_STATE();
    case 581:
      if (lookahead == 's') ADVANCE(619);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_template);
      END_STATE();
    case 583:
      if (lookahead == 'o') ADVANCE(620);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_typename);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_unsigned);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(anon_sym_volatile);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym__Noreturn);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(anon_sym___alignof);
      if (lookahead == '_') ADVANCE(621);
      END_STATE();
    case 589:
      if (lookahead == 't') ADVANCE(622);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(anon_sym___clrcall);
      END_STATE();
    case 591:
      if (lookahead == 't') ADVANCE(623);
      END_STATE();
    case 592:
      if (lookahead == 'c') ADVANCE(624);
      END_STATE();
    case 593:
      if (lookahead == '_') ADVANCE(625);
      END_STATE();
    case 594:
      if (lookahead == 'o') ADVANCE(626);
      END_STATE();
    case 595:
      if (lookahead == 'l') ADVANCE(627);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym___finally);
      END_STATE();
    case 597:
      if (lookahead == 'l') ADVANCE(628);
      END_STATE();
    case 598:
      if (lookahead == '_') ADVANCE(629);
      END_STATE();
    case 599:
      if (lookahead == 'n') ADVANCE(630);
      END_STATE();
    case 600:
      if (lookahead == '_') ADVANCE(631);
      END_STATE();
    case 601:
      if (lookahead == 'b') ADVANCE(632);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym___local__);
      END_STATE();
    case 603:
      if (lookahead == '_') ADVANCE(633);
      END_STATE();
    case 604:
      if (lookahead == 'e') ADVANCE(634);
      END_STATE();
    case 605:
      if (lookahead == 't') ADVANCE(635);
      END_STATE();
    case 606:
      if (lookahead == '_') ADVANCE(636);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(anon_sym___stdcall);
      END_STATE();
    case 608:
      if (lookahead == 'l') ADVANCE(637);
      END_STATE();
    case 609:
      if (lookahead == 'e') ADVANCE(638);
      END_STATE();
    case 610:
      if (lookahead == 'a') ADVANCE(639);
      END_STATE();
    case 611:
      if (lookahead == 'e') ADVANCE(640);
      END_STATE();
    case 612:
      if (lookahead == 'd') ADVANCE(641);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_co_return);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_consteval);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(anon_sym_constexpr);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(anon_sym_constinit);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(anon_sym_namespace);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 619:
      if (lookahead == 's') ADVANCE(642);
      END_STATE();
    case 620:
      if (lookahead == 'c') ADVANCE(643);
      END_STATE();
    case 621:
      if (lookahead == '_') ADVANCE(644);
      END_STATE();
    case 622:
      if (lookahead == 'e') ADVANCE(645);
      END_STATE();
    case 623:
      if (lookahead == '_') ADVANCE(646);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(anon_sym___declspec);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(anon_sym___device__);
      END_STATE();
    case 626:
      if (lookahead == 'n') ADVANCE(647);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(anon_sym___fastcall);
      END_STATE();
    case 628:
      if (lookahead == 'i') ADVANCE(648);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(anon_sym___global__);
      END_STATE();
    case 630:
      if (lookahead == 's') ADVANCE(649);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(anon_sym___inline__);
      END_STATE();
    case 632:
      if (lookahead == 'o') ADVANCE(650);
      END_STATE();
    case 633:
      if (lookahead == '_') ADVANCE(651);
      END_STATE();
    case 634:
      if (lookahead == '_') ADVANCE(652);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(sym_ms_restrict_modifier);
      if (lookahead == '_') ADVANCE(653);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(anon_sym___shared__);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(anon_sym___thiscall);
      END_STATE();
    case 638:
      if (lookahead == 'd') ADVANCE(654);
      END_STATE();
    case 639:
      if (lookahead == 'l') ADVANCE(655);
      END_STATE();
    case 640:
      if (lookahead == '_') ADVANCE(656);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(anon_sym__unaligned);
      END_STATE();
    case 642:
      if (lookahead == 'e') ADVANCE(657);
      END_STATE();
    case 643:
      if (lookahead == 'a') ADVANCE(658);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(anon_sym___alignof__);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(anon_sym___attribute);
      if (lookahead == '_') ADVANCE(659);
      END_STATE();
    case 646:
      if (lookahead == '_') ADVANCE(660);
      END_STATE();
    case 647:
      if (lookahead == '_') ADVANCE(661);
      END_STATE();
    case 648:
      if (lookahead == 'n') ADVANCE(662);
      END_STATE();
    case 649:
      if (lookahead == 't') ADVANCE(663);
      END_STATE();
    case 650:
      if (lookahead == 'u') ADVANCE(664);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(anon_sym___managed__);
      END_STATE();
    case 652:
      if (lookahead == '_') ADVANCE(665);
      END_STATE();
    case 653:
      if (lookahead == '_') ADVANCE(666);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(anon_sym___unaligned);
      END_STATE();
    case 655:
      if (lookahead == 'l') ADVANCE(667);
      END_STATE();
    case 656:
      if (lookahead == '_') ADVANCE(668);
      END_STATE();
    case 657:
      if (lookahead == 'r') ADVANCE(669);
      END_STATE();
    case 658:
      if (lookahead == 'l') ADVANCE(670);
      END_STATE();
    case 659:
      if (lookahead == '_') ADVANCE(671);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(anon_sym___constant__);
      END_STATE();
    case 661:
      if (lookahead == '_') ADVANCE(672);
      END_STATE();
    case 662:
      if (lookahead == 'e') ADVANCE(673);
      END_STATE();
    case 663:
      if (lookahead == 'a') ADVANCE(674);
      END_STATE();
    case 664:
      if (lookahead == 'n') ADVANCE(675);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(anon_sym___noinline__);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(anon_sym___restrict__);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(anon_sym___vectorcall);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(anon_sym___volatile__);
      END_STATE();
    case 669:
      if (lookahead == 't') ADVANCE(676);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(anon_sym_thread_local);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(anon_sym___attribute__);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(anon_sym___extension__);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(anon_sym___forceinline);
      if (lookahead == '_') ADVANCE(677);
      END_STATE();
    case 674:
      if (lookahead == 'n') ADVANCE(678);
      END_STATE();
    case 675:
      if (lookahead == 'd') ADVANCE(679);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(anon_sym_static_assert);
      END_STATE();
    case 677:
      if (lookahead == '_') ADVANCE(680);
      END_STATE();
    case 678:
      if (lookahead == 't') ADVANCE(681);
      END_STATE();
    case 679:
      if (lookahead == 's') ADVANCE(682);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(anon_sym___forceinline__);
      END_STATE();
    case 681:
      if (lookahead == '_') ADVANCE(683);
      END_STATE();
    case 682:
      if (lookahead == '_') ADVANCE(684);
      END_STATE();
    case 683:
      if (lookahead == '_') ADVANCE(685);
      END_STATE();
    case 684:
      if (lookahead == '_') ADVANCE(686);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(anon_sym___grid_constant__);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(anon_sym___launch_bounds__);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 389},
  [2] = {.lex_state = 389},
  [3] = {.lex_state = 389},
  [4] = {.lex_state = 389},
  [5] = {.lex_state = 389},
  [6] = {.lex_state = 389},
  [7] = {.lex_state = 389},
  [8] = {.lex_state = 389},
  [9] = {.lex_state = 389},
  [10] = {.lex_state = 389},
  [11] = {.lex_state = 389},
  [12] = {.lex_state = 389},
  [13] = {.lex_state = 201},
  [14] = {.lex_state = 201},
  [15] = {.lex_state = 201},
  [16] = {.lex_state = 201},
  [17] = {.lex_state = 201},
  [18] = {.lex_state = 201},
  [19] = {.lex_state = 201},
  [20] = {.lex_state = 201},
  [21] = {.lex_state = 201},
  [22] = {.lex_state = 201},
  [23] = {.lex_state = 201},
  [24] = {.lex_state = 201},
  [25] = {.lex_state = 201},
  [26] = {.lex_state = 201},
  [27] = {.lex_state = 201},
  [28] = {.lex_state = 201},
  [29] = {.lex_state = 201},
  [30] = {.lex_state = 201},
  [31] = {.lex_state = 201},
  [32] = {.lex_state = 201},
  [33] = {.lex_state = 201},
  [34] = {.lex_state = 389},
  [35] = {.lex_state = 389},
  [36] = {.lex_state = 389},
  [37] = {.lex_state = 389},
  [38] = {.lex_state = 389},
  [39] = {.lex_state = 389},
  [40] = {.lex_state = 389},
  [41] = {.lex_state = 204},
  [42] = {.lex_state = 389},
  [43] = {.lex_state = 389},
  [44] = {.lex_state = 389},
  [45] = {.lex_state = 389},
  [46] = {.lex_state = 389},
  [47] = {.lex_state = 389},
  [48] = {.lex_state = 389},
  [49] = {.lex_state = 389},
  [50] = {.lex_state = 389},
  [51] = {.lex_state = 389},
  [52] = {.lex_state = 389},
  [53] = {.lex_state = 389},
  [54] = {.lex_state = 389},
  [55] = {.lex_state = 389},
  [56] = {.lex_state = 389},
  [57] = {.lex_state = 389},
  [58] = {.lex_state = 204},
  [59] = {.lex_state = 389},
  [60] = {.lex_state = 389},
  [61] = {.lex_state = 204},
  [62] = {.lex_state = 389},
  [63] = {.lex_state = 389},
  [64] = {.lex_state = 389},
  [65] = {.lex_state = 389},
  [66] = {.lex_state = 389},
  [67] = {.lex_state = 389},
  [68] = {.lex_state = 389},
  [69] = {.lex_state = 389},
  [70] = {.lex_state = 389},
  [71] = {.lex_state = 389},
  [72] = {.lex_state = 389},
  [73] = {.lex_state = 389},
  [74] = {.lex_state = 389},
  [75] = {.lex_state = 389},
  [76] = {.lex_state = 389},
  [77] = {.lex_state = 389},
  [78] = {.lex_state = 389},
  [79] = {.lex_state = 389},
  [80] = {.lex_state = 389},
  [81] = {.lex_state = 389},
  [82] = {.lex_state = 389},
  [83] = {.lex_state = 389},
  [84] = {.lex_state = 389},
  [85] = {.lex_state = 389},
  [86] = {.lex_state = 201},
  [87] = {.lex_state = 201},
  [88] = {.lex_state = 201},
  [89] = {.lex_state = 201},
  [90] = {.lex_state = 201},
  [91] = {.lex_state = 204},
  [92] = {.lex_state = 389},
  [93] = {.lex_state = 204},
  [94] = {.lex_state = 204},
  [95] = {.lex_state = 204},
  [96] = {.lex_state = 204},
  [97] = {.lex_state = 389},
  [98] = {.lex_state = 389},
  [99] = {.lex_state = 389},
  [100] = {.lex_state = 389},
  [101] = {.lex_state = 389},
  [102] = {.lex_state = 389},
  [103] = {.lex_state = 389},
  [104] = {.lex_state = 389},
  [105] = {.lex_state = 389},
  [106] = {.lex_state = 203},
  [107] = {.lex_state = 203},
  [108] = {.lex_state = 203},
  [109] = {.lex_state = 203},
  [110] = {.lex_state = 203},
  [111] = {.lex_state = 203},
  [112] = {.lex_state = 203},
  [113] = {.lex_state = 203},
  [114] = {.lex_state = 203},
  [115] = {.lex_state = 203},
  [116] = {.lex_state = 203},
  [117] = {.lex_state = 203},
  [118] = {.lex_state = 203},
  [119] = {.lex_state = 203},
  [120] = {.lex_state = 203},
  [121] = {.lex_state = 203},
  [122] = {.lex_state = 203},
  [123] = {.lex_state = 203},
  [124] = {.lex_state = 203},
  [125] = {.lex_state = 203},
  [126] = {.lex_state = 203},
  [127] = {.lex_state = 203},
  [128] = {.lex_state = 203},
  [129] = {.lex_state = 203},
  [130] = {.lex_state = 203},
  [131] = {.lex_state = 203},
  [132] = {.lex_state = 203},
  [133] = {.lex_state = 203},
  [134] = {.lex_state = 205},
  [135] = {.lex_state = 205},
  [136] = {.lex_state = 205},
  [137] = {.lex_state = 203},
  [138] = {.lex_state = 389},
  [139] = {.lex_state = 389},
  [140] = {.lex_state = 201},
  [141] = {.lex_state = 201},
  [142] = {.lex_state = 389},
  [143] = {.lex_state = 389},
  [144] = {.lex_state = 389},
  [145] = {.lex_state = 389},
  [146] = {.lex_state = 201},
  [147] = {.lex_state = 201},
  [148] = {.lex_state = 206},
  [149] = {.lex_state = 201},
  [150] = {.lex_state = 201},
  [151] = {.lex_state = 201},
  [152] = {.lex_state = 206},
  [153] = {.lex_state = 206},
  [154] = {.lex_state = 206},
  [155] = {.lex_state = 206},
  [156] = {.lex_state = 206},
  [157] = {.lex_state = 206},
  [158] = {.lex_state = 206},
  [159] = {.lex_state = 206},
  [160] = {.lex_state = 206},
  [161] = {.lex_state = 206},
  [162] = {.lex_state = 206},
  [163] = {.lex_state = 206},
  [164] = {.lex_state = 206},
  [165] = {.lex_state = 201},
  [166] = {.lex_state = 206},
  [167] = {.lex_state = 206},
  [168] = {.lex_state = 201},
  [169] = {.lex_state = 206},
  [170] = {.lex_state = 206},
  [171] = {.lex_state = 206},
  [172] = {.lex_state = 206},
  [173] = {.lex_state = 206},
  [174] = {.lex_state = 206},
  [175] = {.lex_state = 206},
  [176] = {.lex_state = 206},
  [177] = {.lex_state = 206},
  [178] = {.lex_state = 206},
  [179] = {.lex_state = 206},
  [180] = {.lex_state = 206},
  [181] = {.lex_state = 206},
  [182] = {.lex_state = 206},
  [183] = {.lex_state = 201},
  [184] = {.lex_state = 201},
  [185] = {.lex_state = 201},
  [186] = {.lex_state = 201},
  [187] = {.lex_state = 201},
  [188] = {.lex_state = 201},
  [189] = {.lex_state = 201},
  [190] = {.lex_state = 201},
  [191] = {.lex_state = 201},
  [192] = {.lex_state = 201},
  [193] = {.lex_state = 201},
  [194] = {.lex_state = 201},
  [195] = {.lex_state = 201},
  [196] = {.lex_state = 203},
  [197] = {.lex_state = 201},
  [198] = {.lex_state = 201},
  [199] = {.lex_state = 203},
  [200] = {.lex_state = 201},
  [201] = {.lex_state = 201},
  [202] = {.lex_state = 201},
  [203] = {.lex_state = 201},
  [204] = {.lex_state = 201},
  [205] = {.lex_state = 201},
  [206] = {.lex_state = 201},
  [207] = {.lex_state = 201},
  [208] = {.lex_state = 201},
  [209] = {.lex_state = 201},
  [210] = {.lex_state = 201},
  [211] = {.lex_state = 201},
  [212] = {.lex_state = 201},
  [213] = {.lex_state = 201},
  [214] = {.lex_state = 201},
  [215] = {.lex_state = 201},
  [216] = {.lex_state = 201},
  [217] = {.lex_state = 201},
  [218] = {.lex_state = 201},
  [219] = {.lex_state = 203},
  [220] = {.lex_state = 201},
  [221] = {.lex_state = 201},
  [222] = {.lex_state = 201},
  [223] = {.lex_state = 201},
  [224] = {.lex_state = 201},
  [225] = {.lex_state = 201},
  [226] = {.lex_state = 201},
  [227] = {.lex_state = 201},
  [228] = {.lex_state = 285},
  [229] = {.lex_state = 285},
  [230] = {.lex_state = 285},
  [231] = {.lex_state = 285},
  [232] = {.lex_state = 285},
  [233] = {.lex_state = 201},
  [234] = {.lex_state = 201},
  [235] = {.lex_state = 201},
  [236] = {.lex_state = 201},
  [237] = {.lex_state = 201},
  [238] = {.lex_state = 201},
  [239] = {.lex_state = 201},
  [240] = {.lex_state = 389},
  [241] = {.lex_state = 201},
  [242] = {.lex_state = 201},
  [243] = {.lex_state = 201},
  [244] = {.lex_state = 201},
  [245] = {.lex_state = 285},
  [246] = {.lex_state = 285},
  [247] = {.lex_state = 285},
  [248] = {.lex_state = 285},
  [249] = {.lex_state = 285},
  [250] = {.lex_state = 285},
  [251] = {.lex_state = 201},
  [252] = {.lex_state = 201},
  [253] = {.lex_state = 285},
  [254] = {.lex_state = 201},
  [255] = {.lex_state = 201},
  [256] = {.lex_state = 285},
  [257] = {.lex_state = 201},
  [258] = {.lex_state = 285},
  [259] = {.lex_state = 285},
  [260] = {.lex_state = 285},
  [261] = {.lex_state = 203},
  [262] = {.lex_state = 201},
  [263] = {.lex_state = 201},
  [264] = {.lex_state = 201},
  [265] = {.lex_state = 201},
  [266] = {.lex_state = 201},
  [267] = {.lex_state = 201},
  [268] = {.lex_state = 201},
  [269] = {.lex_state = 201},
  [270] = {.lex_state = 201},
  [271] = {.lex_state = 201},
  [272] = {.lex_state = 201},
  [273] = {.lex_state = 204},
  [274] = {.lex_state = 201},
  [275] = {.lex_state = 389},
  [276] = {.lex_state = 201},
  [277] = {.lex_state = 201},
  [278] = {.lex_state = 201},
  [279] = {.lex_state = 201},
  [280] = {.lex_state = 389},
  [281] = {.lex_state = 204},
  [282] = {.lex_state = 203},
  [283] = {.lex_state = 201},
  [284] = {.lex_state = 201},
  [285] = {.lex_state = 201},
  [286] = {.lex_state = 201},
  [287] = {.lex_state = 201},
  [288] = {.lex_state = 203},
  [289] = {.lex_state = 201},
  [290] = {.lex_state = 201},
  [291] = {.lex_state = 201},
  [292] = {.lex_state = 201},
  [293] = {.lex_state = 201},
  [294] = {.lex_state = 201},
  [295] = {.lex_state = 201},
  [296] = {.lex_state = 201},
  [297] = {.lex_state = 201},
  [298] = {.lex_state = 201},
  [299] = {.lex_state = 201},
  [300] = {.lex_state = 201},
  [301] = {.lex_state = 201},
  [302] = {.lex_state = 201},
  [303] = {.lex_state = 201},
  [304] = {.lex_state = 201},
  [305] = {.lex_state = 201},
  [306] = {.lex_state = 201},
  [307] = {.lex_state = 201},
  [308] = {.lex_state = 201},
  [309] = {.lex_state = 201},
  [310] = {.lex_state = 203},
  [311] = {.lex_state = 201},
  [312] = {.lex_state = 389},
  [313] = {.lex_state = 201},
  [314] = {.lex_state = 201},
  [315] = {.lex_state = 201},
  [316] = {.lex_state = 203},
  [317] = {.lex_state = 201},
  [318] = {.lex_state = 201},
  [319] = {.lex_state = 201},
  [320] = {.lex_state = 203},
  [321] = {.lex_state = 201},
  [322] = {.lex_state = 201},
  [323] = {.lex_state = 204},
  [324] = {.lex_state = 204},
  [325] = {.lex_state = 203},
  [326] = {.lex_state = 192},
  [327] = {.lex_state = 389},
  [328] = {.lex_state = 203},
  [329] = {.lex_state = 389},
  [330] = {.lex_state = 204},
  [331] = {.lex_state = 389},
  [332] = {.lex_state = 389},
  [333] = {.lex_state = 389},
  [334] = {.lex_state = 204},
  [335] = {.lex_state = 389},
  [336] = {.lex_state = 204},
  [337] = {.lex_state = 389},
  [338] = {.lex_state = 204},
  [339] = {.lex_state = 389},
  [340] = {.lex_state = 192},
  [341] = {.lex_state = 389},
  [342] = {.lex_state = 204},
  [343] = {.lex_state = 389},
  [344] = {.lex_state = 204},
  [345] = {.lex_state = 389},
  [346] = {.lex_state = 389},
  [347] = {.lex_state = 389},
  [348] = {.lex_state = 389},
  [349] = {.lex_state = 389},
  [350] = {.lex_state = 389},
  [351] = {.lex_state = 389},
  [352] = {.lex_state = 389},
  [353] = {.lex_state = 389},
  [354] = {.lex_state = 389},
  [355] = {.lex_state = 389},
  [356] = {.lex_state = 389},
  [357] = {.lex_state = 389},
  [358] = {.lex_state = 389},
  [359] = {.lex_state = 389},
  [360] = {.lex_state = 389},
  [361] = {.lex_state = 389},
  [362] = {.lex_state = 389},
  [363] = {.lex_state = 389},
  [364] = {.lex_state = 389},
  [365] = {.lex_state = 389},
  [366] = {.lex_state = 389},
  [367] = {.lex_state = 389},
  [368] = {.lex_state = 389},
  [369] = {.lex_state = 389},
  [370] = {.lex_state = 389},
  [371] = {.lex_state = 389},
  [372] = {.lex_state = 389},
  [373] = {.lex_state = 389},
  [374] = {.lex_state = 389},
  [375] = {.lex_state = 204},
  [376] = {.lex_state = 389},
  [377] = {.lex_state = 204},
  [378] = {.lex_state = 204},
  [379] = {.lex_state = 204},
  [380] = {.lex_state = 204},
  [381] = {.lex_state = 204},
  [382] = {.lex_state = 204},
  [383] = {.lex_state = 204},
  [384] = {.lex_state = 204},
  [385] = {.lex_state = 204},
  [386] = {.lex_state = 204},
  [387] = {.lex_state = 204},
  [388] = {.lex_state = 204},
  [389] = {.lex_state = 204},
  [390] = {.lex_state = 204},
  [391] = {.lex_state = 389},
  [392] = {.lex_state = 204},
  [393] = {.lex_state = 204},
  [394] = {.lex_state = 204},
  [395] = {.lex_state = 389},
  [396] = {.lex_state = 389},
  [397] = {.lex_state = 204},
  [398] = {.lex_state = 204},
  [399] = {.lex_state = 204},
  [400] = {.lex_state = 204},
  [401] = {.lex_state = 204},
  [402] = {.lex_state = 389},
  [403] = {.lex_state = 204},
  [404] = {.lex_state = 389},
  [405] = {.lex_state = 389},
  [406] = {.lex_state = 204},
  [407] = {.lex_state = 204},
  [408] = {.lex_state = 389},
  [409] = {.lex_state = 204},
  [410] = {.lex_state = 204},
  [411] = {.lex_state = 204},
  [412] = {.lex_state = 389},
  [413] = {.lex_state = 204},
  [414] = {.lex_state = 389},
  [415] = {.lex_state = 389},
  [416] = {.lex_state = 204},
  [417] = {.lex_state = 204},
  [418] = {.lex_state = 204},
  [419] = {.lex_state = 204},
  [420] = {.lex_state = 204},
  [421] = {.lex_state = 204},
  [422] = {.lex_state = 204},
  [423] = {.lex_state = 389},
  [424] = {.lex_state = 192},
  [425] = {.lex_state = 389},
  [426] = {.lex_state = 389},
  [427] = {.lex_state = 389},
  [428] = {.lex_state = 389},
  [429] = {.lex_state = 389},
  [430] = {.lex_state = 389},
  [431] = {.lex_state = 389},
  [432] = {.lex_state = 389},
  [433] = {.lex_state = 285},
  [434] = {.lex_state = 389},
  [435] = {.lex_state = 389},
  [436] = {.lex_state = 389},
  [437] = {.lex_state = 389},
  [438] = {.lex_state = 389},
  [439] = {.lex_state = 389},
  [440] = {.lex_state = 389},
  [441] = {.lex_state = 389},
  [442] = {.lex_state = 389},
  [443] = {.lex_state = 389},
  [444] = {.lex_state = 389},
  [445] = {.lex_state = 389},
  [446] = {.lex_state = 389},
  [447] = {.lex_state = 389},
  [448] = {.lex_state = 389},
  [449] = {.lex_state = 389},
  [450] = {.lex_state = 389},
  [451] = {.lex_state = 389},
  [452] = {.lex_state = 389},
  [453] = {.lex_state = 389},
  [454] = {.lex_state = 389},
  [455] = {.lex_state = 389},
  [456] = {.lex_state = 389},
  [457] = {.lex_state = 389},
  [458] = {.lex_state = 389},
  [459] = {.lex_state = 389},
  [460] = {.lex_state = 389},
  [461] = {.lex_state = 389},
  [462] = {.lex_state = 204},
  [463] = {.lex_state = 389},
  [464] = {.lex_state = 204},
  [465] = {.lex_state = 204},
  [466] = {.lex_state = 204},
  [467] = {.lex_state = 204},
  [468] = {.lex_state = 204},
  [469] = {.lex_state = 204},
  [470] = {.lex_state = 204},
  [471] = {.lex_state = 389},
  [472] = {.lex_state = 204},
  [473] = {.lex_state = 204},
  [474] = {.lex_state = 204},
  [475] = {.lex_state = 204},
  [476] = {.lex_state = 204},
  [477] = {.lex_state = 204},
  [478] = {.lex_state = 204},
  [479] = {.lex_state = 204},
  [480] = {.lex_state = 204},
  [481] = {.lex_state = 204},
  [482] = {.lex_state = 204},
  [483] = {.lex_state = 204},
  [484] = {.lex_state = 204},
  [485] = {.lex_state = 204},
  [486] = {.lex_state = 204},
  [487] = {.lex_state = 204},
  [488] = {.lex_state = 204},
  [489] = {.lex_state = 204},
  [490] = {.lex_state = 206},
  [491] = {.lex_state = 389},
  [492] = {.lex_state = 204},
  [493] = {.lex_state = 204},
  [494] = {.lex_state = 389},
  [495] = {.lex_state = 204},
  [496] = {.lex_state = 389},
  [497] = {.lex_state = 204},
  [498] = {.lex_state = 204},
  [499] = {.lex_state = 204},
  [500] = {.lex_state = 204},
  [501] = {.lex_state = 204},
  [502] = {.lex_state = 204},
  [503] = {.lex_state = 204},
  [504] = {.lex_state = 389},
  [505] = {.lex_state = 389},
  [506] = {.lex_state = 204},
  [507] = {.lex_state = 204},
  [508] = {.lex_state = 389},
  [509] = {.lex_state = 204},
  [510] = {.lex_state = 204},
  [511] = {.lex_state = 204},
  [512] = {.lex_state = 204},
  [513] = {.lex_state = 204},
  [514] = {.lex_state = 204},
  [515] = {.lex_state = 389},
  [516] = {.lex_state = 389},
  [517] = {.lex_state = 204},
  [518] = {.lex_state = 389},
  [519] = {.lex_state = 204},
  [520] = {.lex_state = 204},
  [521] = {.lex_state = 204},
  [522] = {.lex_state = 204},
  [523] = {.lex_state = 204},
  [524] = {.lex_state = 389},
  [525] = {.lex_state = 389},
  [526] = {.lex_state = 389},
  [527] = {.lex_state = 389},
  [528] = {.lex_state = 389},
  [529] = {.lex_state = 389},
  [530] = {.lex_state = 206},
  [531] = {.lex_state = 204},
  [532] = {.lex_state = 204},
  [533] = {.lex_state = 389},
  [534] = {.lex_state = 389},
  [535] = {.lex_state = 204},
  [536] = {.lex_state = 389},
  [537] = {.lex_state = 389},
  [538] = {.lex_state = 389},
  [539] = {.lex_state = 389},
  [540] = {.lex_state = 389},
  [541] = {.lex_state = 389},
  [542] = {.lex_state = 389},
  [543] = {.lex_state = 389},
  [544] = {.lex_state = 389},
  [545] = {.lex_state = 389},
  [546] = {.lex_state = 204},
  [547] = {.lex_state = 204},
  [548] = {.lex_state = 389},
  [549] = {.lex_state = 206},
  [550] = {.lex_state = 389},
  [551] = {.lex_state = 389},
  [552] = {.lex_state = 389},
  [553] = {.lex_state = 389},
  [554] = {.lex_state = 204},
  [555] = {.lex_state = 204},
  [556] = {.lex_state = 204},
  [557] = {.lex_state = 194},
  [558] = {.lex_state = 389},
  [559] = {.lex_state = 389},
  [560] = {.lex_state = 206},
  [561] = {.lex_state = 389},
  [562] = {.lex_state = 389},
  [563] = {.lex_state = 389},
  [564] = {.lex_state = 389},
  [565] = {.lex_state = 389},
  [566] = {.lex_state = 389},
  [567] = {.lex_state = 389},
  [568] = {.lex_state = 389},
  [569] = {.lex_state = 389},
  [570] = {.lex_state = 389},
  [571] = {.lex_state = 389},
  [572] = {.lex_state = 389},
  [573] = {.lex_state = 206},
  [574] = {.lex_state = 389},
  [575] = {.lex_state = 389},
  [576] = {.lex_state = 389},
  [577] = {.lex_state = 389},
  [578] = {.lex_state = 389},
  [579] = {.lex_state = 206},
  [580] = {.lex_state = 389},
  [581] = {.lex_state = 389},
  [582] = {.lex_state = 389},
  [583] = {.lex_state = 204},
  [584] = {.lex_state = 389},
  [585] = {.lex_state = 389},
  [586] = {.lex_state = 206},
  [587] = {.lex_state = 389},
  [588] = {.lex_state = 204},
  [589] = {.lex_state = 204},
  [590] = {.lex_state = 204},
  [591] = {.lex_state = 206},
  [592] = {.lex_state = 204},
  [593] = {.lex_state = 204},
  [594] = {.lex_state = 389},
  [595] = {.lex_state = 389},
  [596] = {.lex_state = 389},
  [597] = {.lex_state = 389},
  [598] = {.lex_state = 206},
  [599] = {.lex_state = 389},
  [600] = {.lex_state = 204},
  [601] = {.lex_state = 389},
  [602] = {.lex_state = 389},
  [603] = {.lex_state = 206},
  [604] = {.lex_state = 204},
  [605] = {.lex_state = 389},
  [606] = {.lex_state = 389},
  [607] = {.lex_state = 206},
  [608] = {.lex_state = 204},
  [609] = {.lex_state = 389},
  [610] = {.lex_state = 206},
  [611] = {.lex_state = 389},
  [612] = {.lex_state = 206},
  [613] = {.lex_state = 389},
  [614] = {.lex_state = 206},
  [615] = {.lex_state = 389},
  [616] = {.lex_state = 206},
  [617] = {.lex_state = 204},
  [618] = {.lex_state = 206},
  [619] = {.lex_state = 204},
  [620] = {.lex_state = 206},
  [621] = {.lex_state = 204},
  [622] = {.lex_state = 206},
  [623] = {.lex_state = 206},
  [624] = {.lex_state = 389},
  [625] = {.lex_state = 389},
  [626] = {.lex_state = 204},
  [627] = {.lex_state = 203},
  [628] = {.lex_state = 203},
  [629] = {.lex_state = 203},
  [630] = {.lex_state = 203},
  [631] = {.lex_state = 205},
  [632] = {.lex_state = 203},
  [633] = {.lex_state = 203},
  [634] = {.lex_state = 203},
  [635] = {.lex_state = 206},
  [636] = {.lex_state = 203},
  [637] = {.lex_state = 203},
  [638] = {.lex_state = 203},
  [639] = {.lex_state = 203},
  [640] = {.lex_state = 203},
  [641] = {.lex_state = 195},
  [642] = {.lex_state = 203},
  [643] = {.lex_state = 203},
  [644] = {.lex_state = 203},
  [645] = {.lex_state = 203},
  [646] = {.lex_state = 203},
  [647] = {.lex_state = 203},
  [648] = {.lex_state = 203},
  [649] = {.lex_state = 203},
  [650] = {.lex_state = 203},
  [651] = {.lex_state = 203},
  [652] = {.lex_state = 203},
  [653] = {.lex_state = 203},
  [654] = {.lex_state = 203},
  [655] = {.lex_state = 203},
  [656] = {.lex_state = 203},
  [657] = {.lex_state = 203},
  [658] = {.lex_state = 203},
  [659] = {.lex_state = 203},
  [660] = {.lex_state = 203},
  [661] = {.lex_state = 203},
  [662] = {.lex_state = 203},
  [663] = {.lex_state = 203},
  [664] = {.lex_state = 203},
  [665] = {.lex_state = 203},
  [666] = {.lex_state = 203},
  [667] = {.lex_state = 203},
  [668] = {.lex_state = 203},
  [669] = {.lex_state = 203},
  [670] = {.lex_state = 203},
  [671] = {.lex_state = 203},
  [672] = {.lex_state = 203},
  [673] = {.lex_state = 196},
  [674] = {.lex_state = 203},
  [675] = {.lex_state = 203},
  [676] = {.lex_state = 192},
  [677] = {.lex_state = 205},
  [678] = {.lex_state = 203},
  [679] = {.lex_state = 203},
  [680] = {.lex_state = 203},
  [681] = {.lex_state = 203},
  [682] = {.lex_state = 203},
  [683] = {.lex_state = 203},
  [684] = {.lex_state = 203},
  [685] = {.lex_state = 203},
  [686] = {.lex_state = 206},
  [687] = {.lex_state = 389},
  [688] = {.lex_state = 389},
  [689] = {.lex_state = 389},
  [690] = {.lex_state = 389},
  [691] = {.lex_state = 389},
  [692] = {.lex_state = 389},
  [693] = {.lex_state = 389},
  [694] = {.lex_state = 389},
  [695] = {.lex_state = 389},
  [696] = {.lex_state = 389},
  [697] = {.lex_state = 389},
  [698] = {.lex_state = 389},
  [699] = {.lex_state = 389},
  [700] = {.lex_state = 389},
  [701] = {.lex_state = 389},
  [702] = {.lex_state = 389},
  [703] = {.lex_state = 389},
  [704] = {.lex_state = 389},
  [705] = {.lex_state = 389},
  [706] = {.lex_state = 389},
  [707] = {.lex_state = 389},
  [708] = {.lex_state = 389},
  [709] = {.lex_state = 389},
  [710] = {.lex_state = 389},
  [711] = {.lex_state = 389},
  [712] = {.lex_state = 389},
  [713] = {.lex_state = 389},
  [714] = {.lex_state = 389},
  [715] = {.lex_state = 389},
  [716] = {.lex_state = 389},
  [717] = {.lex_state = 389},
  [718] = {.lex_state = 389},
  [719] = {.lex_state = 389},
  [720] = {.lex_state = 389},
  [721] = {.lex_state = 389},
  [722] = {.lex_state = 389},
  [723] = {.lex_state = 389},
  [724] = {.lex_state = 389},
  [725] = {.lex_state = 389},
  [726] = {.lex_state = 389},
  [727] = {.lex_state = 389},
  [728] = {.lex_state = 206},
  [729] = {.lex_state = 389},
  [730] = {.lex_state = 389},
  [731] = {.lex_state = 389},
  [732] = {.lex_state = 389},
  [733] = {.lex_state = 389},
  [734] = {.lex_state = 206},
  [735] = {.lex_state = 389},
  [736] = {.lex_state = 389},
  [737] = {.lex_state = 206},
  [738] = {.lex_state = 206},
  [739] = {.lex_state = 389},
  [740] = {.lex_state = 206},
  [741] = {.lex_state = 206},
  [742] = {.lex_state = 206},
  [743] = {.lex_state = 206},
  [744] = {.lex_state = 206},
  [745] = {.lex_state = 206},
  [746] = {.lex_state = 206},
  [747] = {.lex_state = 206},
  [748] = {.lex_state = 389},
  [749] = {.lex_state = 389},
  [750] = {.lex_state = 389},
  [751] = {.lex_state = 389},
  [752] = {.lex_state = 389},
  [753] = {.lex_state = 389},
  [754] = {.lex_state = 389},
  [755] = {.lex_state = 389},
  [756] = {.lex_state = 389},
  [757] = {.lex_state = 389},
  [758] = {.lex_state = 206},
  [759] = {.lex_state = 389},
  [760] = {.lex_state = 389},
  [761] = {.lex_state = 389},
  [762] = {.lex_state = 389},
  [763] = {.lex_state = 389},
  [764] = {.lex_state = 389},
  [765] = {.lex_state = 389},
  [766] = {.lex_state = 389},
  [767] = {.lex_state = 389},
  [768] = {.lex_state = 389},
  [769] = {.lex_state = 389},
  [770] = {.lex_state = 389},
  [771] = {.lex_state = 229},
  [772] = {.lex_state = 194},
  [773] = {.lex_state = 286},
  [774] = {.lex_state = 229},
  [775] = {.lex_state = 229},
  [776] = {.lex_state = 229},
  [777] = {.lex_state = 229},
  [778] = {.lex_state = 286},
  [779] = {.lex_state = 229},
  [780] = {.lex_state = 229},
  [781] = {.lex_state = 229},
  [782] = {.lex_state = 286},
  [783] = {.lex_state = 229},
  [784] = {.lex_state = 229},
  [785] = {.lex_state = 229},
  [786] = {.lex_state = 229},
  [787] = {.lex_state = 229},
  [788] = {.lex_state = 229},
  [789] = {.lex_state = 229},
  [790] = {.lex_state = 229},
  [791] = {.lex_state = 229},
  [792] = {.lex_state = 229},
  [793] = {.lex_state = 229},
  [794] = {.lex_state = 229},
  [795] = {.lex_state = 229},
  [796] = {.lex_state = 229},
  [797] = {.lex_state = 229},
  [798] = {.lex_state = 229},
  [799] = {.lex_state = 229},
  [800] = {.lex_state = 199},
  [801] = {.lex_state = 199},
  [802] = {.lex_state = 193},
  [803] = {.lex_state = 193},
  [804] = {.lex_state = 193},
  [805] = {.lex_state = 389},
  [806] = {.lex_state = 389},
  [807] = {.lex_state = 285},
  [808] = {.lex_state = 285},
  [809] = {.lex_state = 285},
  [810] = {.lex_state = 285},
  [811] = {.lex_state = 285},
  [812] = {.lex_state = 285},
  [813] = {.lex_state = 285},
  [814] = {.lex_state = 193},
  [815] = {.lex_state = 197},
  [816] = {.lex_state = 198},
  [817] = {.lex_state = 193},
  [818] = {.lex_state = 285},
  [819] = {.lex_state = 206},
  [820] = {.lex_state = 285},
  [821] = {.lex_state = 206},
  [822] = {.lex_state = 285},
  [823] = {.lex_state = 206},
  [824] = {.lex_state = 285},
  [825] = {.lex_state = 285},
  [826] = {.lex_state = 285},
  [827] = {.lex_state = 285},
  [828] = {.lex_state = 193},
  [829] = {.lex_state = 217},
  [830] = {.lex_state = 389},
  [831] = {.lex_state = 217},
  [832] = {.lex_state = 203},
  [833] = {.lex_state = 217},
  [834] = {.lex_state = 203},
  [835] = {.lex_state = 217},
  [836] = {.lex_state = 217},
  [837] = {.lex_state = 206},
  [838] = {.lex_state = 206},
  [839] = {.lex_state = 206},
  [840] = {.lex_state = 206},
  [841] = {.lex_state = 206},
  [842] = {.lex_state = 206},
  [843] = {.lex_state = 206},
  [844] = {.lex_state = 206},
  [845] = {.lex_state = 206},
  [846] = {.lex_state = 206},
  [847] = {.lex_state = 206},
  [848] = {.lex_state = 206},
  [849] = {.lex_state = 203},
  [850] = {.lex_state = 206},
  [851] = {.lex_state = 206},
  [852] = {.lex_state = 206},
  [853] = {.lex_state = 206},
  [854] = {.lex_state = 203},
  [855] = {.lex_state = 206},
  [856] = {.lex_state = 206},
  [857] = {.lex_state = 203},
  [858] = {.lex_state = 203},
  [859] = {.lex_state = 206},
  [860] = {.lex_state = 203},
  [861] = {.lex_state = 206},
  [862] = {.lex_state = 206},
  [863] = {.lex_state = 206},
  [864] = {.lex_state = 206},
  [865] = {.lex_state = 203},
  [866] = {.lex_state = 203},
  [867] = {.lex_state = 203},
  [868] = {.lex_state = 203},
  [869] = {.lex_state = 203},
  [870] = {.lex_state = 203},
  [871] = {.lex_state = 203},
  [872] = {.lex_state = 203},
  [873] = {.lex_state = 203},
  [874] = {.lex_state = 203},
  [875] = {.lex_state = 203},
  [876] = {.lex_state = 203},
  [877] = {.lex_state = 203},
  [878] = {.lex_state = 203},
  [879] = {.lex_state = 203},
  [880] = {.lex_state = 203},
  [881] = {.lex_state = 203},
  [882] = {.lex_state = 203},
  [883] = {.lex_state = 203},
  [884] = {.lex_state = 203},
  [885] = {.lex_state = 203},
  [886] = {.lex_state = 203},
  [887] = {.lex_state = 203},
  [888] = {.lex_state = 203},
  [889] = {.lex_state = 203},
  [890] = {.lex_state = 203},
  [891] = {.lex_state = 203},
  [892] = {.lex_state = 203},
  [893] = {.lex_state = 203},
  [894] = {.lex_state = 203},
  [895] = {.lex_state = 203},
  [896] = {.lex_state = 203},
  [897] = {.lex_state = 203},
  [898] = {.lex_state = 203},
  [899] = {.lex_state = 203},
  [900] = {.lex_state = 203},
  [901] = {.lex_state = 203},
  [902] = {.lex_state = 203},
  [903] = {.lex_state = 203},
  [904] = {.lex_state = 203},
  [905] = {.lex_state = 285},
  [906] = {.lex_state = 205},
  [907] = {.lex_state = 205},
  [908] = {.lex_state = 217},
  [909] = {.lex_state = 206},
  [910] = {.lex_state = 217},
  [911] = {.lex_state = 217},
  [912] = {.lex_state = 217},
  [913] = {.lex_state = 217},
  [914] = {.lex_state = 213},
  [915] = {.lex_state = 217},
  [916] = {.lex_state = 217},
  [917] = {.lex_state = 217},
  [918] = {.lex_state = 205},
  [919] = {.lex_state = 205},
  [920] = {.lex_state = 206},
  [921] = {.lex_state = 206},
  [922] = {.lex_state = 206},
  [923] = {.lex_state = 230},
  [924] = {.lex_state = 206},
  [925] = {.lex_state = 206},
  [926] = {.lex_state = 206},
  [927] = {.lex_state = 206},
  [928] = {.lex_state = 206},
  [929] = {.lex_state = 230},
  [930] = {.lex_state = 206},
  [931] = {.lex_state = 230},
  [932] = {.lex_state = 206},
  [933] = {.lex_state = 206},
  [934] = {.lex_state = 230},
  [935] = {.lex_state = 206},
  [936] = {.lex_state = 206},
  [937] = {.lex_state = 206},
  [938] = {.lex_state = 206},
  [939] = {.lex_state = 206},
  [940] = {.lex_state = 206},
  [941] = {.lex_state = 206},
  [942] = {.lex_state = 206},
  [943] = {.lex_state = 206},
  [944] = {.lex_state = 206},
  [945] = {.lex_state = 230},
  [946] = {.lex_state = 206},
  [947] = {.lex_state = 230},
  [948] = {.lex_state = 206},
  [949] = {.lex_state = 230},
  [950] = {.lex_state = 206},
  [951] = {.lex_state = 206},
  [952] = {.lex_state = 206},
  [953] = {.lex_state = 206},
  [954] = {.lex_state = 206},
  [955] = {.lex_state = 230},
  [956] = {.lex_state = 206},
  [957] = {.lex_state = 206},
  [958] = {.lex_state = 206},
  [959] = {.lex_state = 206},
  [960] = {.lex_state = 206},
  [961] = {.lex_state = 206},
  [962] = {.lex_state = 206},
  [963] = {.lex_state = 206},
  [964] = {.lex_state = 206},
  [965] = {.lex_state = 206},
  [966] = {.lex_state = 206},
  [967] = {.lex_state = 230},
  [968] = {.lex_state = 206},
  [969] = {.lex_state = 206},
  [970] = {.lex_state = 206},
  [971] = {.lex_state = 206},
  [972] = {.lex_state = 206},
  [973] = {.lex_state = 206},
  [974] = {.lex_state = 206},
  [975] = {.lex_state = 206},
  [976] = {.lex_state = 206},
  [977] = {.lex_state = 206},
  [978] = {.lex_state = 206},
  [979] = {.lex_state = 206},
  [980] = {.lex_state = 285},
  [981] = {.lex_state = 285},
  [982] = {.lex_state = 285},
  [983] = {.lex_state = 230},
  [984] = {.lex_state = 285},
  [985] = {.lex_state = 203},
  [986] = {.lex_state = 285},
  [987] = {.lex_state = 285},
  [988] = {.lex_state = 203},
  [989] = {.lex_state = 203},
  [990] = {.lex_state = 206},
  [991] = {.lex_state = 230},
  [992] = {.lex_state = 206},
  [993] = {.lex_state = 206},
  [994] = {.lex_state = 206},
  [995] = {.lex_state = 206},
  [996] = {.lex_state = 206},
  [997] = {.lex_state = 206},
  [998] = {.lex_state = 206},
  [999] = {.lex_state = 206},
  [1000] = {.lex_state = 206},
  [1001] = {.lex_state = 206},
  [1002] = {.lex_state = 206},
  [1003] = {.lex_state = 206},
  [1004] = {.lex_state = 206},
  [1005] = {.lex_state = 206},
  [1006] = {.lex_state = 206},
  [1007] = {.lex_state = 206},
  [1008] = {.lex_state = 206},
  [1009] = {.lex_state = 206},
  [1010] = {.lex_state = 206},
  [1011] = {.lex_state = 206},
  [1012] = {.lex_state = 206},
  [1013] = {.lex_state = 206},
  [1014] = {.lex_state = 206},
  [1015] = {.lex_state = 206},
  [1016] = {.lex_state = 206},
  [1017] = {.lex_state = 206},
  [1018] = {.lex_state = 206},
  [1019] = {.lex_state = 206},
  [1020] = {.lex_state = 228},
  [1021] = {.lex_state = 206},
  [1022] = {.lex_state = 205},
  [1023] = {.lex_state = 266},
  [1024] = {.lex_state = 206},
  [1025] = {.lex_state = 228},
  [1026] = {.lex_state = 228},
  [1027] = {.lex_state = 228},
  [1028] = {.lex_state = 206},
  [1029] = {.lex_state = 206},
  [1030] = {.lex_state = 206},
  [1031] = {.lex_state = 205},
  [1032] = {.lex_state = 205},
  [1033] = {.lex_state = 205},
  [1034] = {.lex_state = 206},
  [1035] = {.lex_state = 205},
  [1036] = {.lex_state = 206},
  [1037] = {.lex_state = 206},
  [1038] = {.lex_state = 205},
  [1039] = {.lex_state = 266},
  [1040] = {.lex_state = 205},
  [1041] = {.lex_state = 206},
  [1042] = {.lex_state = 266},
  [1043] = {.lex_state = 206},
  [1044] = {.lex_state = 266},
  [1045] = {.lex_state = 266},
  [1046] = {.lex_state = 266},
  [1047] = {.lex_state = 205},
  [1048] = {.lex_state = 206},
  [1049] = {.lex_state = 206},
  [1050] = {.lex_state = 206},
  [1051] = {.lex_state = 206},
  [1052] = {.lex_state = 205},
  [1053] = {.lex_state = 206},
  [1054] = {.lex_state = 205},
  [1055] = {.lex_state = 205},
  [1056] = {.lex_state = 205},
  [1057] = {.lex_state = 205},
  [1058] = {.lex_state = 205},
  [1059] = {.lex_state = 228},
  [1060] = {.lex_state = 205},
  [1061] = {.lex_state = 230},
  [1062] = {.lex_state = 205},
  [1063] = {.lex_state = 205},
  [1064] = {.lex_state = 205},
  [1065] = {.lex_state = 228},
  [1066] = {.lex_state = 228},
  [1067] = {.lex_state = 228},
  [1068] = {.lex_state = 205},
  [1069] = {.lex_state = 206},
  [1070] = {.lex_state = 228},
  [1071] = {.lex_state = 205},
  [1072] = {.lex_state = 205},
  [1073] = {.lex_state = 205},
  [1074] = {.lex_state = 205},
  [1075] = {.lex_state = 205},
  [1076] = {.lex_state = 205},
  [1077] = {.lex_state = 205},
  [1078] = {.lex_state = 266},
  [1079] = {.lex_state = 205},
  [1080] = {.lex_state = 205},
  [1081] = {.lex_state = 205},
  [1082] = {.lex_state = 205},
  [1083] = {.lex_state = 206},
  [1084] = {.lex_state = 206},
  [1085] = {.lex_state = 206},
  [1086] = {.lex_state = 206},
  [1087] = {.lex_state = 206},
  [1088] = {.lex_state = 206},
  [1089] = {.lex_state = 206},
  [1090] = {.lex_state = 206},
  [1091] = {.lex_state = 206},
  [1092] = {.lex_state = 206},
  [1093] = {.lex_state = 206},
  [1094] = {.lex_state = 206},
  [1095] = {.lex_state = 206},
  [1096] = {.lex_state = 206},
  [1097] = {.lex_state = 206},
  [1098] = {.lex_state = 206},
  [1099] = {.lex_state = 206},
  [1100] = {.lex_state = 206},
  [1101] = {.lex_state = 206},
  [1102] = {.lex_state = 206},
  [1103] = {.lex_state = 206},
  [1104] = {.lex_state = 206},
  [1105] = {.lex_state = 206},
  [1106] = {.lex_state = 206},
  [1107] = {.lex_state = 206},
  [1108] = {.lex_state = 206},
  [1109] = {.lex_state = 206},
  [1110] = {.lex_state = 206},
  [1111] = {.lex_state = 206},
  [1112] = {.lex_state = 206},
  [1113] = {.lex_state = 230},
  [1114] = {.lex_state = 206},
  [1115] = {.lex_state = 206},
  [1116] = {.lex_state = 206},
  [1117] = {.lex_state = 206},
  [1118] = {.lex_state = 206},
  [1119] = {.lex_state = 206},
  [1120] = {.lex_state = 206},
  [1121] = {.lex_state = 206},
  [1122] = {.lex_state = 206},
  [1123] = {.lex_state = 206},
  [1124] = {.lex_state = 206},
  [1125] = {.lex_state = 206},
  [1126] = {.lex_state = 206},
  [1127] = {.lex_state = 206},
  [1128] = {.lex_state = 206},
  [1129] = {.lex_state = 206},
  [1130] = {.lex_state = 206},
  [1131] = {.lex_state = 206},
  [1132] = {.lex_state = 206},
  [1133] = {.lex_state = 206},
  [1134] = {.lex_state = 206},
  [1135] = {.lex_state = 206},
  [1136] = {.lex_state = 206},
  [1137] = {.lex_state = 206},
  [1138] = {.lex_state = 206},
  [1139] = {.lex_state = 206},
  [1140] = {.lex_state = 206},
  [1141] = {.lex_state = 206},
  [1142] = {.lex_state = 206},
  [1143] = {.lex_state = 206},
  [1144] = {.lex_state = 206},
  [1145] = {.lex_state = 206},
  [1146] = {.lex_state = 206},
  [1147] = {.lex_state = 206},
  [1148] = {.lex_state = 206},
  [1149] = {.lex_state = 206},
  [1150] = {.lex_state = 206},
  [1151] = {.lex_state = 206},
  [1152] = {.lex_state = 206},
  [1153] = {.lex_state = 206},
  [1154] = {.lex_state = 206},
  [1155] = {.lex_state = 206},
  [1156] = {.lex_state = 206},
  [1157] = {.lex_state = 206},
  [1158] = {.lex_state = 206},
  [1159] = {.lex_state = 206},
  [1160] = {.lex_state = 206},
  [1161] = {.lex_state = 206},
  [1162] = {.lex_state = 206},
  [1163] = {.lex_state = 206},
  [1164] = {.lex_state = 206},
  [1165] = {.lex_state = 206},
  [1166] = {.lex_state = 206},
  [1167] = {.lex_state = 206},
  [1168] = {.lex_state = 206},
  [1169] = {.lex_state = 206},
  [1170] = {.lex_state = 206},
  [1171] = {.lex_state = 206},
  [1172] = {.lex_state = 206},
  [1173] = {.lex_state = 206},
  [1174] = {.lex_state = 206},
  [1175] = {.lex_state = 206},
  [1176] = {.lex_state = 206},
  [1177] = {.lex_state = 206},
  [1178] = {.lex_state = 206},
  [1179] = {.lex_state = 206},
  [1180] = {.lex_state = 206},
  [1181] = {.lex_state = 206},
  [1182] = {.lex_state = 206},
  [1183] = {.lex_state = 206},
  [1184] = {.lex_state = 206},
  [1185] = {.lex_state = 206},
  [1186] = {.lex_state = 206},
  [1187] = {.lex_state = 206},
  [1188] = {.lex_state = 206},
  [1189] = {.lex_state = 206},
  [1190] = {.lex_state = 206},
  [1191] = {.lex_state = 206},
  [1192] = {.lex_state = 206},
  [1193] = {.lex_state = 206},
  [1194] = {.lex_state = 206},
  [1195] = {.lex_state = 206},
  [1196] = {.lex_state = 206},
  [1197] = {.lex_state = 206},
  [1198] = {.lex_state = 206},
  [1199] = {.lex_state = 206},
  [1200] = {.lex_state = 206},
  [1201] = {.lex_state = 206},
  [1202] = {.lex_state = 206},
  [1203] = {.lex_state = 206},
  [1204] = {.lex_state = 206},
  [1205] = {.lex_state = 206},
  [1206] = {.lex_state = 206},
  [1207] = {.lex_state = 206},
  [1208] = {.lex_state = 206},
  [1209] = {.lex_state = 206},
  [1210] = {.lex_state = 206},
  [1211] = {.lex_state = 206},
  [1212] = {.lex_state = 206},
  [1213] = {.lex_state = 206},
  [1214] = {.lex_state = 206},
  [1215] = {.lex_state = 206},
  [1216] = {.lex_state = 206},
  [1217] = {.lex_state = 206},
  [1218] = {.lex_state = 206},
  [1219] = {.lex_state = 206},
  [1220] = {.lex_state = 206},
  [1221] = {.lex_state = 206},
  [1222] = {.lex_state = 206},
  [1223] = {.lex_state = 206},
  [1224] = {.lex_state = 206},
  [1225] = {.lex_state = 206},
  [1226] = {.lex_state = 206},
  [1227] = {.lex_state = 206},
  [1228] = {.lex_state = 206},
  [1229] = {.lex_state = 206},
  [1230] = {.lex_state = 206},
  [1231] = {.lex_state = 206},
  [1232] = {.lex_state = 206},
  [1233] = {.lex_state = 206},
  [1234] = {.lex_state = 206},
  [1235] = {.lex_state = 206},
  [1236] = {.lex_state = 206},
  [1237] = {.lex_state = 206},
  [1238] = {.lex_state = 206},
  [1239] = {.lex_state = 206},
  [1240] = {.lex_state = 206},
  [1241] = {.lex_state = 206},
  [1242] = {.lex_state = 206},
  [1243] = {.lex_state = 206},
  [1244] = {.lex_state = 206},
  [1245] = {.lex_state = 206},
  [1246] = {.lex_state = 206},
  [1247] = {.lex_state = 206},
  [1248] = {.lex_state = 206},
  [1249] = {.lex_state = 206},
  [1250] = {.lex_state = 206},
  [1251] = {.lex_state = 206},
  [1252] = {.lex_state = 206},
  [1253] = {.lex_state = 206},
  [1254] = {.lex_state = 206},
  [1255] = {.lex_state = 206},
  [1256] = {.lex_state = 206},
  [1257] = {.lex_state = 206},
  [1258] = {.lex_state = 206},
  [1259] = {.lex_state = 206},
  [1260] = {.lex_state = 206},
  [1261] = {.lex_state = 206},
  [1262] = {.lex_state = 206},
  [1263] = {.lex_state = 206},
  [1264] = {.lex_state = 206},
  [1265] = {.lex_state = 206},
  [1266] = {.lex_state = 206},
  [1267] = {.lex_state = 206},
  [1268] = {.lex_state = 206},
  [1269] = {.lex_state = 206},
  [1270] = {.lex_state = 206},
  [1271] = {.lex_state = 206},
  [1272] = {.lex_state = 206},
  [1273] = {.lex_state = 206},
  [1274] = {.lex_state = 206},
  [1275] = {.lex_state = 206},
  [1276] = {.lex_state = 206},
  [1277] = {.lex_state = 206},
  [1278] = {.lex_state = 206},
  [1279] = {.lex_state = 206},
  [1280] = {.lex_state = 206},
  [1281] = {.lex_state = 206},
  [1282] = {.lex_state = 206},
  [1283] = {.lex_state = 206},
  [1284] = {.lex_state = 206},
  [1285] = {.lex_state = 206},
  [1286] = {.lex_state = 206},
  [1287] = {.lex_state = 206},
  [1288] = {.lex_state = 206},
  [1289] = {.lex_state = 206},
  [1290] = {.lex_state = 206},
  [1291] = {.lex_state = 206},
  [1292] = {.lex_state = 206},
  [1293] = {.lex_state = 206},
  [1294] = {.lex_state = 206},
  [1295] = {.lex_state = 206},
  [1296] = {.lex_state = 206},
  [1297] = {.lex_state = 206},
  [1298] = {.lex_state = 206},
  [1299] = {.lex_state = 206},
  [1300] = {.lex_state = 206},
  [1301] = {.lex_state = 206},
  [1302] = {.lex_state = 206},
  [1303] = {.lex_state = 206},
  [1304] = {.lex_state = 206},
  [1305] = {.lex_state = 206},
  [1306] = {.lex_state = 206},
  [1307] = {.lex_state = 206},
  [1308] = {.lex_state = 206},
  [1309] = {.lex_state = 206},
  [1310] = {.lex_state = 206},
  [1311] = {.lex_state = 206},
  [1312] = {.lex_state = 206},
  [1313] = {.lex_state = 206},
  [1314] = {.lex_state = 206},
  [1315] = {.lex_state = 206},
  [1316] = {.lex_state = 206},
  [1317] = {.lex_state = 206},
  [1318] = {.lex_state = 206},
  [1319] = {.lex_state = 206},
  [1320] = {.lex_state = 206},
  [1321] = {.lex_state = 206},
  [1322] = {.lex_state = 206},
  [1323] = {.lex_state = 206},
  [1324] = {.lex_state = 206},
  [1325] = {.lex_state = 206},
  [1326] = {.lex_state = 206},
  [1327] = {.lex_state = 206},
  [1328] = {.lex_state = 206},
  [1329] = {.lex_state = 206},
  [1330] = {.lex_state = 206},
  [1331] = {.lex_state = 206},
  [1332] = {.lex_state = 206},
  [1333] = {.lex_state = 206},
  [1334] = {.lex_state = 228},
  [1335] = {.lex_state = 206},
  [1336] = {.lex_state = 228},
  [1337] = {.lex_state = 228},
  [1338] = {.lex_state = 228},
  [1339] = {.lex_state = 206},
  [1340] = {.lex_state = 228},
  [1341] = {.lex_state = 228},
  [1342] = {.lex_state = 228},
  [1343] = {.lex_state = 228},
  [1344] = {.lex_state = 206},
  [1345] = {.lex_state = 206},
  [1346] = {.lex_state = 206},
  [1347] = {.lex_state = 206},
  [1348] = {.lex_state = 206},
  [1349] = {.lex_state = 206},
  [1350] = {.lex_state = 206},
  [1351] = {.lex_state = 206},
  [1352] = {.lex_state = 206},
  [1353] = {.lex_state = 206},
  [1354] = {.lex_state = 206},
  [1355] = {.lex_state = 206},
  [1356] = {.lex_state = 206},
  [1357] = {.lex_state = 206},
  [1358] = {.lex_state = 206},
  [1359] = {.lex_state = 206},
  [1360] = {.lex_state = 206},
  [1361] = {.lex_state = 206},
  [1362] = {.lex_state = 206},
  [1363] = {.lex_state = 206},
  [1364] = {.lex_state = 206},
  [1365] = {.lex_state = 206},
  [1366] = {.lex_state = 206},
  [1367] = {.lex_state = 206},
  [1368] = {.lex_state = 206},
  [1369] = {.lex_state = 206},
  [1370] = {.lex_state = 206},
  [1371] = {.lex_state = 206},
  [1372] = {.lex_state = 206},
  [1373] = {.lex_state = 206},
  [1374] = {.lex_state = 206},
  [1375] = {.lex_state = 206},
  [1376] = {.lex_state = 206},
  [1377] = {.lex_state = 206},
  [1378] = {.lex_state = 206},
  [1379] = {.lex_state = 206},
  [1380] = {.lex_state = 206},
  [1381] = {.lex_state = 206},
  [1382] = {.lex_state = 206},
  [1383] = {.lex_state = 206},
  [1384] = {.lex_state = 206},
  [1385] = {.lex_state = 206},
  [1386] = {.lex_state = 206},
  [1387] = {.lex_state = 206},
  [1388] = {.lex_state = 206},
  [1389] = {.lex_state = 206},
  [1390] = {.lex_state = 206},
  [1391] = {.lex_state = 206},
  [1392] = {.lex_state = 206},
  [1393] = {.lex_state = 206},
  [1394] = {.lex_state = 206},
  [1395] = {.lex_state = 206},
  [1396] = {.lex_state = 206},
  [1397] = {.lex_state = 206},
  [1398] = {.lex_state = 206},
  [1399] = {.lex_state = 206},
  [1400] = {.lex_state = 206},
  [1401] = {.lex_state = 206},
  [1402] = {.lex_state = 206},
  [1403] = {.lex_state = 206},
  [1404] = {.lex_state = 206},
  [1405] = {.lex_state = 206},
  [1406] = {.lex_state = 206},
  [1407] = {.lex_state = 206},
  [1408] = {.lex_state = 206},
  [1409] = {.lex_state = 206},
  [1410] = {.lex_state = 206},
  [1411] = {.lex_state = 206},
  [1412] = {.lex_state = 206},
  [1413] = {.lex_state = 206},
  [1414] = {.lex_state = 206},
  [1415] = {.lex_state = 206},
  [1416] = {.lex_state = 206},
  [1417] = {.lex_state = 206},
  [1418] = {.lex_state = 206},
  [1419] = {.lex_state = 206},
  [1420] = {.lex_state = 206},
  [1421] = {.lex_state = 206},
  [1422] = {.lex_state = 206},
  [1423] = {.lex_state = 206},
  [1424] = {.lex_state = 206},
  [1425] = {.lex_state = 206},
  [1426] = {.lex_state = 206},
  [1427] = {.lex_state = 206},
  [1428] = {.lex_state = 206},
  [1429] = {.lex_state = 206},
  [1430] = {.lex_state = 206},
  [1431] = {.lex_state = 206},
  [1432] = {.lex_state = 206},
  [1433] = {.lex_state = 206},
  [1434] = {.lex_state = 206},
  [1435] = {.lex_state = 206},
  [1436] = {.lex_state = 206},
  [1437] = {.lex_state = 206},
  [1438] = {.lex_state = 206},
  [1439] = {.lex_state = 206},
  [1440] = {.lex_state = 206},
  [1441] = {.lex_state = 206},
  [1442] = {.lex_state = 206},
  [1443] = {.lex_state = 206},
  [1444] = {.lex_state = 206},
  [1445] = {.lex_state = 206},
  [1446] = {.lex_state = 206},
  [1447] = {.lex_state = 206},
  [1448] = {.lex_state = 206},
  [1449] = {.lex_state = 206},
  [1450] = {.lex_state = 206},
  [1451] = {.lex_state = 206},
  [1452] = {.lex_state = 206},
  [1453] = {.lex_state = 206},
  [1454] = {.lex_state = 206},
  [1455] = {.lex_state = 206},
  [1456] = {.lex_state = 206},
  [1457] = {.lex_state = 206},
  [1458] = {.lex_state = 206},
  [1459] = {.lex_state = 206},
  [1460] = {.lex_state = 206},
  [1461] = {.lex_state = 206},
  [1462] = {.lex_state = 206},
  [1463] = {.lex_state = 206},
  [1464] = {.lex_state = 206},
  [1465] = {.lex_state = 206},
  [1466] = {.lex_state = 206},
  [1467] = {.lex_state = 206},
  [1468] = {.lex_state = 206},
  [1469] = {.lex_state = 206},
  [1470] = {.lex_state = 206},
  [1471] = {.lex_state = 206},
  [1472] = {.lex_state = 206},
  [1473] = {.lex_state = 206},
  [1474] = {.lex_state = 206},
  [1475] = {.lex_state = 206},
  [1476] = {.lex_state = 206},
  [1477] = {.lex_state = 206},
  [1478] = {.lex_state = 206},
  [1479] = {.lex_state = 206},
  [1480] = {.lex_state = 206},
  [1481] = {.lex_state = 206},
  [1482] = {.lex_state = 206},
  [1483] = {.lex_state = 206},
  [1484] = {.lex_state = 206},
  [1485] = {.lex_state = 206},
  [1486] = {.lex_state = 206},
  [1487] = {.lex_state = 206},
  [1488] = {.lex_state = 206},
  [1489] = {.lex_state = 206},
  [1490] = {.lex_state = 206},
  [1491] = {.lex_state = 206},
  [1492] = {.lex_state = 206},
  [1493] = {.lex_state = 206},
  [1494] = {.lex_state = 206},
  [1495] = {.lex_state = 206},
  [1496] = {.lex_state = 206},
  [1497] = {.lex_state = 206},
  [1498] = {.lex_state = 206},
  [1499] = {.lex_state = 206},
  [1500] = {.lex_state = 206},
  [1501] = {.lex_state = 206},
  [1502] = {.lex_state = 206},
  [1503] = {.lex_state = 206},
  [1504] = {.lex_state = 206},
  [1505] = {.lex_state = 206},
  [1506] = {.lex_state = 206},
  [1507] = {.lex_state = 206},
  [1508] = {.lex_state = 206},
  [1509] = {.lex_state = 206},
  [1510] = {.lex_state = 206},
  [1511] = {.lex_state = 206},
  [1512] = {.lex_state = 206},
  [1513] = {.lex_state = 206},
  [1514] = {.lex_state = 206},
  [1515] = {.lex_state = 206},
  [1516] = {.lex_state = 206},
  [1517] = {.lex_state = 206},
  [1518] = {.lex_state = 206},
  [1519] = {.lex_state = 206},
  [1520] = {.lex_state = 206},
  [1521] = {.lex_state = 206},
  [1522] = {.lex_state = 206},
  [1523] = {.lex_state = 206},
  [1524] = {.lex_state = 206},
  [1525] = {.lex_state = 206},
  [1526] = {.lex_state = 206},
  [1527] = {.lex_state = 206},
  [1528] = {.lex_state = 206},
  [1529] = {.lex_state = 206},
  [1530] = {.lex_state = 206},
  [1531] = {.lex_state = 206},
  [1532] = {.lex_state = 206},
  [1533] = {.lex_state = 206},
  [1534] = {.lex_state = 206},
  [1535] = {.lex_state = 206},
  [1536] = {.lex_state = 206},
  [1537] = {.lex_state = 206},
  [1538] = {.lex_state = 206},
  [1539] = {.lex_state = 206},
  [1540] = {.lex_state = 206},
  [1541] = {.lex_state = 206},
  [1542] = {.lex_state = 206},
  [1543] = {.lex_state = 206},
  [1544] = {.lex_state = 206},
  [1545] = {.lex_state = 206},
  [1546] = {.lex_state = 206},
  [1547] = {.lex_state = 206},
  [1548] = {.lex_state = 206},
  [1549] = {.lex_state = 206},
  [1550] = {.lex_state = 206},
  [1551] = {.lex_state = 206},
  [1552] = {.lex_state = 206},
  [1553] = {.lex_state = 206},
  [1554] = {.lex_state = 206},
  [1555] = {.lex_state = 206},
  [1556] = {.lex_state = 206},
  [1557] = {.lex_state = 206},
  [1558] = {.lex_state = 206},
  [1559] = {.lex_state = 206},
  [1560] = {.lex_state = 206},
  [1561] = {.lex_state = 206},
  [1562] = {.lex_state = 206},
  [1563] = {.lex_state = 206},
  [1564] = {.lex_state = 206},
  [1565] = {.lex_state = 206},
  [1566] = {.lex_state = 206},
  [1567] = {.lex_state = 206},
  [1568] = {.lex_state = 206},
  [1569] = {.lex_state = 206},
  [1570] = {.lex_state = 206},
  [1571] = {.lex_state = 206},
  [1572] = {.lex_state = 206},
  [1573] = {.lex_state = 206},
  [1574] = {.lex_state = 206},
  [1575] = {.lex_state = 206},
  [1576] = {.lex_state = 206},
  [1577] = {.lex_state = 206},
  [1578] = {.lex_state = 206},
  [1579] = {.lex_state = 206},
  [1580] = {.lex_state = 206},
  [1581] = {.lex_state = 206},
  [1582] = {.lex_state = 206},
  [1583] = {.lex_state = 206},
  [1584] = {.lex_state = 206},
  [1585] = {.lex_state = 206},
  [1586] = {.lex_state = 206},
  [1587] = {.lex_state = 206},
  [1588] = {.lex_state = 206},
  [1589] = {.lex_state = 206},
  [1590] = {.lex_state = 206},
  [1591] = {.lex_state = 206},
  [1592] = {.lex_state = 206},
  [1593] = {.lex_state = 206},
  [1594] = {.lex_state = 206},
  [1595] = {.lex_state = 206},
  [1596] = {.lex_state = 206},
  [1597] = {.lex_state = 206},
  [1598] = {.lex_state = 206},
  [1599] = {.lex_state = 206},
  [1600] = {.lex_state = 206},
  [1601] = {.lex_state = 206},
  [1602] = {.lex_state = 206},
  [1603] = {.lex_state = 206},
  [1604] = {.lex_state = 206},
  [1605] = {.lex_state = 206},
  [1606] = {.lex_state = 206},
  [1607] = {.lex_state = 206},
  [1608] = {.lex_state = 206},
  [1609] = {.lex_state = 206},
  [1610] = {.lex_state = 206},
  [1611] = {.lex_state = 206},
  [1612] = {.lex_state = 206},
  [1613] = {.lex_state = 206},
  [1614] = {.lex_state = 206},
  [1615] = {.lex_state = 206},
  [1616] = {.lex_state = 206},
  [1617] = {.lex_state = 206},
  [1618] = {.lex_state = 206},
  [1619] = {.lex_state = 206},
  [1620] = {.lex_state = 206},
  [1621] = {.lex_state = 206},
  [1622] = {.lex_state = 206},
  [1623] = {.lex_state = 206},
  [1624] = {.lex_state = 206},
  [1625] = {.lex_state = 206},
  [1626] = {.lex_state = 206},
  [1627] = {.lex_state = 206},
  [1628] = {.lex_state = 206},
  [1629] = {.lex_state = 206},
  [1630] = {.lex_state = 206},
  [1631] = {.lex_state = 206},
  [1632] = {.lex_state = 206},
  [1633] = {.lex_state = 206},
  [1634] = {.lex_state = 206},
  [1635] = {.lex_state = 206},
  [1636] = {.lex_state = 206},
  [1637] = {.lex_state = 206},
  [1638] = {.lex_state = 206},
  [1639] = {.lex_state = 206},
  [1640] = {.lex_state = 206},
  [1641] = {.lex_state = 206},
  [1642] = {.lex_state = 206},
  [1643] = {.lex_state = 206},
  [1644] = {.lex_state = 206},
  [1645] = {.lex_state = 206},
  [1646] = {.lex_state = 206},
  [1647] = {.lex_state = 206},
  [1648] = {.lex_state = 206},
  [1649] = {.lex_state = 213},
  [1650] = {.lex_state = 214},
  [1651] = {.lex_state = 233},
  [1652] = {.lex_state = 218},
  [1653] = {.lex_state = 266},
  [1654] = {.lex_state = 233},
  [1655] = {.lex_state = 208},
  [1656] = {.lex_state = 233},
  [1657] = {.lex_state = 233},
  [1658] = {.lex_state = 285},
  [1659] = {.lex_state = 285},
  [1660] = {.lex_state = 285},
  [1661] = {.lex_state = 233},
  [1662] = {.lex_state = 233},
  [1663] = {.lex_state = 285},
  [1664] = {.lex_state = 285},
  [1665] = {.lex_state = 233},
  [1666] = {.lex_state = 233},
  [1667] = {.lex_state = 285},
  [1668] = {.lex_state = 285},
  [1669] = {.lex_state = 285},
  [1670] = {.lex_state = 285},
  [1671] = {.lex_state = 285},
  [1672] = {.lex_state = 285},
  [1673] = {.lex_state = 285},
  [1674] = {.lex_state = 231},
  [1675] = {.lex_state = 231},
  [1676] = {.lex_state = 285},
  [1677] = {.lex_state = 231},
  [1678] = {.lex_state = 285},
  [1679] = {.lex_state = 285},
  [1680] = {.lex_state = 285},
  [1681] = {.lex_state = 231},
  [1682] = {.lex_state = 231},
  [1683] = {.lex_state = 231},
  [1684] = {.lex_state = 285},
  [1685] = {.lex_state = 231},
  [1686] = {.lex_state = 285},
  [1687] = {.lex_state = 285},
  [1688] = {.lex_state = 285},
  [1689] = {.lex_state = 285},
  [1690] = {.lex_state = 285},
  [1691] = {.lex_state = 285},
  [1692] = {.lex_state = 285},
  [1693] = {.lex_state = 285},
  [1694] = {.lex_state = 285},
  [1695] = {.lex_state = 285},
  [1696] = {.lex_state = 285},
  [1697] = {.lex_state = 285},
  [1698] = {.lex_state = 285},
  [1699] = {.lex_state = 285},
  [1700] = {.lex_state = 285},
  [1701] = {.lex_state = 285},
  [1702] = {.lex_state = 285},
  [1703] = {.lex_state = 285},
  [1704] = {.lex_state = 285},
  [1705] = {.lex_state = 285},
  [1706] = {.lex_state = 233},
  [1707] = {.lex_state = 266},
  [1708] = {.lex_state = 246},
  [1709] = {.lex_state = 246},
  [1710] = {.lex_state = 233},
  [1711] = {.lex_state = 261},
  [1712] = {.lex_state = 256},
  [1713] = {.lex_state = 266},
  [1714] = {.lex_state = 256},
  [1715] = {.lex_state = 246},
  [1716] = {.lex_state = 285},
  [1717] = {.lex_state = 285},
  [1718] = {.lex_state = 261},
  [1719] = {.lex_state = 285},
  [1720] = {.lex_state = 256},
  [1721] = {.lex_state = 261},
  [1722] = {.lex_state = 285},
  [1723] = {.lex_state = 246},
  [1724] = {.lex_state = 285},
  [1725] = {.lex_state = 246},
  [1726] = {.lex_state = 285},
  [1727] = {.lex_state = 285},
  [1728] = {.lex_state = 285},
  [1729] = {.lex_state = 246},
  [1730] = {.lex_state = 285},
  [1731] = {.lex_state = 285},
  [1732] = {.lex_state = 285},
  [1733] = {.lex_state = 285},
  [1734] = {.lex_state = 246},
  [1735] = {.lex_state = 285},
  [1736] = {.lex_state = 261},
  [1737] = {.lex_state = 246},
  [1738] = {.lex_state = 239},
  [1739] = {.lex_state = 246},
  [1740] = {.lex_state = 285},
  [1741] = {.lex_state = 261},
  [1742] = {.lex_state = 246},
  [1743] = {.lex_state = 256},
  [1744] = {.lex_state = 256},
  [1745] = {.lex_state = 266},
  [1746] = {.lex_state = 266},
  [1747] = {.lex_state = 266},
  [1748] = {.lex_state = 285},
  [1749] = {.lex_state = 266},
  [1750] = {.lex_state = 285},
  [1751] = {.lex_state = 266},
  [1752] = {.lex_state = 261},
  [1753] = {.lex_state = 266},
  [1754] = {.lex_state = 256},
  [1755] = {.lex_state = 285},
  [1756] = {.lex_state = 266},
  [1757] = {.lex_state = 266},
  [1758] = {.lex_state = 266},
  [1759] = {.lex_state = 285},
  [1760] = {.lex_state = 266},
  [1761] = {.lex_state = 256},
  [1762] = {.lex_state = 285},
  [1763] = {.lex_state = 261},
  [1764] = {.lex_state = 266},
  [1765] = {.lex_state = 285},
  [1766] = {.lex_state = 285},
  [1767] = {.lex_state = 285},
  [1768] = {.lex_state = 285},
  [1769] = {.lex_state = 285},
  [1770] = {.lex_state = 285},
  [1771] = {.lex_state = 285},
  [1772] = {.lex_state = 285},
  [1773] = {.lex_state = 285},
  [1774] = {.lex_state = 285},
  [1775] = {.lex_state = 285},
  [1776] = {.lex_state = 285},
  [1777] = {.lex_state = 285},
  [1778] = {.lex_state = 285},
  [1779] = {.lex_state = 285},
  [1780] = {.lex_state = 285},
  [1781] = {.lex_state = 285},
  [1782] = {.lex_state = 285},
  [1783] = {.lex_state = 285},
  [1784] = {.lex_state = 285},
  [1785] = {.lex_state = 285},
  [1786] = {.lex_state = 285},
  [1787] = {.lex_state = 285},
  [1788] = {.lex_state = 285},
  [1789] = {.lex_state = 285},
  [1790] = {.lex_state = 285},
  [1791] = {.lex_state = 285},
  [1792] = {.lex_state = 285},
  [1793] = {.lex_state = 285},
  [1794] = {.lex_state = 285},
  [1795] = {.lex_state = 285},
  [1796] = {.lex_state = 285},
  [1797] = {.lex_state = 285},
  [1798] = {.lex_state = 285},
  [1799] = {.lex_state = 285},
  [1800] = {.lex_state = 285},
  [1801] = {.lex_state = 285},
  [1802] = {.lex_state = 285},
  [1803] = {.lex_state = 285},
  [1804] = {.lex_state = 285},
  [1805] = {.lex_state = 285},
  [1806] = {.lex_state = 285},
  [1807] = {.lex_state = 285},
  [1808] = {.lex_state = 285},
  [1809] = {.lex_state = 243},
  [1810] = {.lex_state = 285},
  [1811] = {.lex_state = 285},
  [1812] = {.lex_state = 285},
  [1813] = {.lex_state = 285},
  [1814] = {.lex_state = 285},
  [1815] = {.lex_state = 285},
  [1816] = {.lex_state = 285},
  [1817] = {.lex_state = 285},
  [1818] = {.lex_state = 285},
  [1819] = {.lex_state = 285},
  [1820] = {.lex_state = 285},
  [1821] = {.lex_state = 243},
  [1822] = {.lex_state = 243},
  [1823] = {.lex_state = 243},
  [1824] = {.lex_state = 285},
  [1825] = {.lex_state = 285},
  [1826] = {.lex_state = 285},
  [1827] = {.lex_state = 285},
  [1828] = {.lex_state = 285},
  [1829] = {.lex_state = 285},
  [1830] = {.lex_state = 285},
  [1831] = {.lex_state = 285},
  [1832] = {.lex_state = 285},
  [1833] = {.lex_state = 285},
  [1834] = {.lex_state = 285},
  [1835] = {.lex_state = 243},
  [1836] = {.lex_state = 243},
  [1837] = {.lex_state = 243},
  [1838] = {.lex_state = 285},
  [1839] = {.lex_state = 285},
  [1840] = {.lex_state = 285},
  [1841] = {.lex_state = 285},
  [1842] = {.lex_state = 285},
  [1843] = {.lex_state = 285},
  [1844] = {.lex_state = 246},
  [1845] = {.lex_state = 239},
  [1846] = {.lex_state = 246},
  [1847] = {.lex_state = 285},
  [1848] = {.lex_state = 285},
  [1849] = {.lex_state = 285},
  [1850] = {.lex_state = 285},
  [1851] = {.lex_state = 285},
  [1852] = {.lex_state = 285},
  [1853] = {.lex_state = 285},
  [1854] = {.lex_state = 285},
  [1855] = {.lex_state = 285},
  [1856] = {.lex_state = 285},
  [1857] = {.lex_state = 285},
  [1858] = {.lex_state = 285},
  [1859] = {.lex_state = 285},
  [1860] = {.lex_state = 285},
  [1861] = {.lex_state = 285},
  [1862] = {.lex_state = 285},
  [1863] = {.lex_state = 285},
  [1864] = {.lex_state = 285},
  [1865] = {.lex_state = 285},
  [1866] = {.lex_state = 285},
  [1867] = {.lex_state = 246},
  [1868] = {.lex_state = 229},
  [1869] = {.lex_state = 229},
  [1870] = {.lex_state = 285},
  [1871] = {.lex_state = 250},
  [1872] = {.lex_state = 250},
  [1873] = {.lex_state = 239},
  [1874] = {.lex_state = 286},
  [1875] = {.lex_state = 250},
  [1876] = {.lex_state = 229},
  [1877] = {.lex_state = 239},
  [1878] = {.lex_state = 250},
  [1879] = {.lex_state = 286},
  [1880] = {.lex_state = 286},
  [1881] = {.lex_state = 250},
  [1882] = {.lex_state = 286},
  [1883] = {.lex_state = 229},
  [1884] = {.lex_state = 250},
  [1885] = {.lex_state = 250},
  [1886] = {.lex_state = 246},
  [1887] = {.lex_state = 285},
  [1888] = {.lex_state = 285},
  [1889] = {.lex_state = 285},
  [1890] = {.lex_state = 285},
  [1891] = {.lex_state = 285},
  [1892] = {.lex_state = 285},
  [1893] = {.lex_state = 285},
  [1894] = {.lex_state = 285},
  [1895] = {.lex_state = 206},
  [1896] = {.lex_state = 229},
  [1897] = {.lex_state = 229},
  [1898] = {.lex_state = 286},
  [1899] = {.lex_state = 229},
  [1900] = {.lex_state = 228},
  [1901] = {.lex_state = 229},
  [1902] = {.lex_state = 285},
  [1903] = {.lex_state = 285},
  [1904] = {.lex_state = 286},
  [1905] = {.lex_state = 228},
  [1906] = {.lex_state = 285},
  [1907] = {.lex_state = 285},
  [1908] = {.lex_state = 286},
  [1909] = {.lex_state = 285},
  [1910] = {.lex_state = 286},
  [1911] = {.lex_state = 286},
  [1912] = {.lex_state = 229},
  [1913] = {.lex_state = 229},
  [1914] = {.lex_state = 286},
  [1915] = {.lex_state = 229},
  [1916] = {.lex_state = 229},
  [1917] = {.lex_state = 229},
  [1918] = {.lex_state = 229},
  [1919] = {.lex_state = 229},
  [1920] = {.lex_state = 229},
  [1921] = {.lex_state = 229},
  [1922] = {.lex_state = 229},
  [1923] = {.lex_state = 229},
  [1924] = {.lex_state = 229},
  [1925] = {.lex_state = 229},
  [1926] = {.lex_state = 229},
  [1927] = {.lex_state = 229},
  [1928] = {.lex_state = 286},
  [1929] = {.lex_state = 286},
  [1930] = {.lex_state = 286},
  [1931] = {.lex_state = 229},
  [1932] = {.lex_state = 229},
  [1933] = {.lex_state = 229},
  [1934] = {.lex_state = 229},
  [1935] = {.lex_state = 229},
  [1936] = {.lex_state = 229},
  [1937] = {.lex_state = 286},
  [1938] = {.lex_state = 286},
  [1939] = {.lex_state = 286},
  [1940] = {.lex_state = 286},
  [1941] = {.lex_state = 286},
  [1942] = {.lex_state = 286},
  [1943] = {.lex_state = 286},
  [1944] = {.lex_state = 267},
  [1945] = {.lex_state = 286},
  [1946] = {.lex_state = 286},
  [1947] = {.lex_state = 229},
  [1948] = {.lex_state = 229},
  [1949] = {.lex_state = 267},
  [1950] = {.lex_state = 267},
  [1951] = {.lex_state = 229},
  [1952] = {.lex_state = 229},
  [1953] = {.lex_state = 229},
  [1954] = {.lex_state = 229},
  [1955] = {.lex_state = 286},
  [1956] = {.lex_state = 229},
  [1957] = {.lex_state = 229},
  [1958] = {.lex_state = 229},
  [1959] = {.lex_state = 229},
  [1960] = {.lex_state = 229},
  [1961] = {.lex_state = 286},
  [1962] = {.lex_state = 229},
  [1963] = {.lex_state = 229},
  [1964] = {.lex_state = 286},
  [1965] = {.lex_state = 286},
  [1966] = {.lex_state = 267},
  [1967] = {.lex_state = 229},
  [1968] = {.lex_state = 229},
  [1969] = {.lex_state = 229},
  [1970] = {.lex_state = 229},
  [1971] = {.lex_state = 229},
  [1972] = {.lex_state = 286},
  [1973] = {.lex_state = 229},
  [1974] = {.lex_state = 286},
  [1975] = {.lex_state = 229},
  [1976] = {.lex_state = 286},
  [1977] = {.lex_state = 229},
  [1978] = {.lex_state = 229},
  [1979] = {.lex_state = 229},
  [1980] = {.lex_state = 229},
  [1981] = {.lex_state = 286},
  [1982] = {.lex_state = 286},
  [1983] = {.lex_state = 286},
  [1984] = {.lex_state = 229},
  [1985] = {.lex_state = 229},
  [1986] = {.lex_state = 229},
  [1987] = {.lex_state = 229},
  [1988] = {.lex_state = 229},
  [1989] = {.lex_state = 229},
  [1990] = {.lex_state = 229},
  [1991] = {.lex_state = 286},
  [1992] = {.lex_state = 285},
  [1993] = {.lex_state = 286},
  [1994] = {.lex_state = 286},
  [1995] = {.lex_state = 286},
  [1996] = {.lex_state = 229},
  [1997] = {.lex_state = 286},
  [1998] = {.lex_state = 286},
  [1999] = {.lex_state = 267},
  [2000] = {.lex_state = 229},
  [2001] = {.lex_state = 286},
  [2002] = {.lex_state = 286},
  [2003] = {.lex_state = 286},
  [2004] = {.lex_state = 284},
  [2005] = {.lex_state = 286},
  [2006] = {.lex_state = 286},
  [2007] = {.lex_state = 286},
  [2008] = {.lex_state = 286},
  [2009] = {.lex_state = 286},
  [2010] = {.lex_state = 286},
  [2011] = {.lex_state = 286},
  [2012] = {.lex_state = 286},
  [2013] = {.lex_state = 286},
  [2014] = {.lex_state = 286},
  [2015] = {.lex_state = 286},
  [2016] = {.lex_state = 286},
  [2017] = {.lex_state = 286},
  [2018] = {.lex_state = 285},
  [2019] = {.lex_state = 286},
  [2020] = {.lex_state = 286},
  [2021] = {.lex_state = 286},
  [2022] = {.lex_state = 229},
  [2023] = {.lex_state = 229},
  [2024] = {.lex_state = 286},
  [2025] = {.lex_state = 286},
  [2026] = {.lex_state = 286},
  [2027] = {.lex_state = 286},
  [2028] = {.lex_state = 286},
  [2029] = {.lex_state = 229},
  [2030] = {.lex_state = 229},
  [2031] = {.lex_state = 286},
  [2032] = {.lex_state = 286},
  [2033] = {.lex_state = 286},
  [2034] = {.lex_state = 286},
  [2035] = {.lex_state = 286},
  [2036] = {.lex_state = 229},
  [2037] = {.lex_state = 284},
  [2038] = {.lex_state = 286},
  [2039] = {.lex_state = 286},
  [2040] = {.lex_state = 286},
  [2041] = {.lex_state = 286},
  [2042] = {.lex_state = 286},
  [2043] = {.lex_state = 286},
  [2044] = {.lex_state = 286},
  [2045] = {.lex_state = 286},
  [2046] = {.lex_state = 286},
  [2047] = {.lex_state = 286},
  [2048] = {.lex_state = 239},
  [2049] = {.lex_state = 286},
  [2050] = {.lex_state = 286},
  [2051] = {.lex_state = 286},
  [2052] = {.lex_state = 286},
  [2053] = {.lex_state = 229},
  [2054] = {.lex_state = 286},
  [2055] = {.lex_state = 229},
  [2056] = {.lex_state = 286},
  [2057] = {.lex_state = 286},
  [2058] = {.lex_state = 286},
  [2059] = {.lex_state = 229},
  [2060] = {.lex_state = 229},
  [2061] = {.lex_state = 229},
  [2062] = {.lex_state = 286},
  [2063] = {.lex_state = 286},
  [2064] = {.lex_state = 267},
  [2065] = {.lex_state = 267},
  [2066] = {.lex_state = 267},
  [2067] = {.lex_state = 243},
  [2068] = {.lex_state = 229},
  [2069] = {.lex_state = 229},
  [2070] = {.lex_state = 229},
  [2071] = {.lex_state = 229},
  [2072] = {.lex_state = 267},
  [2073] = {.lex_state = 286},
  [2074] = {.lex_state = 286},
  [2075] = {.lex_state = 229},
  [2076] = {.lex_state = 229},
  [2077] = {.lex_state = 229},
  [2078] = {.lex_state = 229},
  [2079] = {.lex_state = 229},
  [2080] = {.lex_state = 267},
  [2081] = {.lex_state = 286},
  [2082] = {.lex_state = 286},
  [2083] = {.lex_state = 229},
  [2084] = {.lex_state = 267},
  [2085] = {.lex_state = 267},
  [2086] = {.lex_state = 286},
  [2087] = {.lex_state = 267},
  [2088] = {.lex_state = 286},
  [2089] = {.lex_state = 229},
  [2090] = {.lex_state = 286},
  [2091] = {.lex_state = 229},
  [2092] = {.lex_state = 229},
  [2093] = {.lex_state = 229},
  [2094] = {.lex_state = 286},
  [2095] = {.lex_state = 229},
  [2096] = {.lex_state = 229},
  [2097] = {.lex_state = 286},
  [2098] = {.lex_state = 229},
  [2099] = {.lex_state = 229},
  [2100] = {.lex_state = 286},
  [2101] = {.lex_state = 229},
  [2102] = {.lex_state = 229},
  [2103] = {.lex_state = 286},
  [2104] = {.lex_state = 229},
  [2105] = {.lex_state = 229},
  [2106] = {.lex_state = 229},
  [2107] = {.lex_state = 229},
  [2108] = {.lex_state = 229},
  [2109] = {.lex_state = 229},
  [2110] = {.lex_state = 286},
  [2111] = {.lex_state = 286},
  [2112] = {.lex_state = 229},
  [2113] = {.lex_state = 229},
  [2114] = {.lex_state = 284},
  [2115] = {.lex_state = 239},
  [2116] = {.lex_state = 239},
  [2117] = {.lex_state = 239},
  [2118] = {.lex_state = 239},
  [2119] = {.lex_state = 239},
  [2120] = {.lex_state = 239},
  [2121] = {.lex_state = 239},
  [2122] = {.lex_state = 239},
  [2123] = {.lex_state = 239},
  [2124] = {.lex_state = 239},
  [2125] = {.lex_state = 239},
  [2126] = {.lex_state = 284},
  [2127] = {.lex_state = 239},
  [2128] = {.lex_state = 239},
  [2129] = {.lex_state = 239},
  [2130] = {.lex_state = 239},
  [2131] = {.lex_state = 239},
  [2132] = {.lex_state = 239},
  [2133] = {.lex_state = 239},
  [2134] = {.lex_state = 239},
  [2135] = {.lex_state = 239},
  [2136] = {.lex_state = 239},
  [2137] = {.lex_state = 239},
  [2138] = {.lex_state = 239},
  [2139] = {.lex_state = 239},
  [2140] = {.lex_state = 239},
  [2141] = {.lex_state = 239},
  [2142] = {.lex_state = 239},
  [2143] = {.lex_state = 239},
  [2144] = {.lex_state = 284},
  [2145] = {.lex_state = 239},
  [2146] = {.lex_state = 239},
  [2147] = {.lex_state = 243},
  [2148] = {.lex_state = 239},
  [2149] = {.lex_state = 239},
  [2150] = {.lex_state = 284},
  [2151] = {.lex_state = 239},
  [2152] = {.lex_state = 239},
  [2153] = {.lex_state = 239},
  [2154] = {.lex_state = 239},
  [2155] = {.lex_state = 238},
  [2156] = {.lex_state = 239},
  [2157] = {.lex_state = 250},
  [2158] = {.lex_state = 239},
  [2159] = {.lex_state = 239},
  [2160] = {.lex_state = 239},
  [2161] = {.lex_state = 284},
  [2162] = {.lex_state = 239},
  [2163] = {.lex_state = 239},
  [2164] = {.lex_state = 285},
  [2165] = {.lex_state = 285},
  [2166] = {.lex_state = 208},
  [2167] = {.lex_state = 285},
  [2168] = {.lex_state = 285},
  [2169] = {.lex_state = 240},
  [2170] = {.lex_state = 285},
  [2171] = {.lex_state = 206},
  [2172] = {.lex_state = 285},
  [2173] = {.lex_state = 240},
  [2174] = {.lex_state = 285},
  [2175] = {.lex_state = 231},
  [2176] = {.lex_state = 285},
  [2177] = {.lex_state = 250},
  [2178] = {.lex_state = 285},
  [2179] = {.lex_state = 285},
  [2180] = {.lex_state = 206},
  [2181] = {.lex_state = 285},
  [2182] = {.lex_state = 285},
  [2183] = {.lex_state = 285},
  [2184] = {.lex_state = 285},
  [2185] = {.lex_state = 285},
  [2186] = {.lex_state = 285},
  [2187] = {.lex_state = 210},
  [2188] = {.lex_state = 273},
  [2189] = {.lex_state = 240},
  [2190] = {.lex_state = 285},
  [2191] = {.lex_state = 240},
  [2192] = {.lex_state = 287},
  [2193] = {.lex_state = 285},
  [2194] = {.lex_state = 284},
  [2195] = {.lex_state = 240},
  [2196] = {.lex_state = 231},
  [2197] = {.lex_state = 240},
  [2198] = {.lex_state = 284},
  [2199] = {.lex_state = 240},
  [2200] = {.lex_state = 240},
  [2201] = {.lex_state = 240},
  [2202] = {.lex_state = 240},
  [2203] = {.lex_state = 240},
  [2204] = {.lex_state = 210},
  [2205] = {.lex_state = 240},
  [2206] = {.lex_state = 240},
  [2207] = {.lex_state = 240},
  [2208] = {.lex_state = 210},
  [2209] = {.lex_state = 287},
  [2210] = {.lex_state = 240},
  [2211] = {.lex_state = 285},
  [2212] = {.lex_state = 284},
  [2213] = {.lex_state = 239},
  [2214] = {.lex_state = 239},
  [2215] = {.lex_state = 284},
  [2216] = {.lex_state = 203},
  [2217] = {.lex_state = 240},
  [2218] = {.lex_state = 284},
  [2219] = {.lex_state = 203},
  [2220] = {.lex_state = 285},
  [2221] = {.lex_state = 285},
  [2222] = {.lex_state = 276},
  [2223] = {.lex_state = 284},
  [2224] = {.lex_state = 284},
  [2225] = {.lex_state = 284},
  [2226] = {.lex_state = 287},
  [2227] = {.lex_state = 284},
  [2228] = {.lex_state = 284},
  [2229] = {.lex_state = 284},
  [2230] = {.lex_state = 284},
  [2231] = {.lex_state = 284},
  [2232] = {.lex_state = 284},
  [2233] = {.lex_state = 238},
  [2234] = {.lex_state = 238},
  [2235] = {.lex_state = 284},
  [2236] = {.lex_state = 276},
  [2237] = {.lex_state = 273},
  [2238] = {.lex_state = 284},
  [2239] = {.lex_state = 284},
  [2240] = {.lex_state = 284},
  [2241] = {.lex_state = 284},
  [2242] = {.lex_state = 284},
  [2243] = {.lex_state = 284},
  [2244] = {.lex_state = 273},
  [2245] = {.lex_state = 284},
  [2246] = {.lex_state = 284},
  [2247] = {.lex_state = 284},
  [2248] = {.lex_state = 284},
  [2249] = {.lex_state = 284},
  [2250] = {.lex_state = 284},
  [2251] = {.lex_state = 284},
  [2252] = {.lex_state = 284},
  [2253] = {.lex_state = 284},
  [2254] = {.lex_state = 284},
  [2255] = {.lex_state = 284},
  [2256] = {.lex_state = 284},
  [2257] = {.lex_state = 284},
  [2258] = {.lex_state = 284},
  [2259] = {.lex_state = 284},
  [2260] = {.lex_state = 287},
  [2261] = {.lex_state = 284},
  [2262] = {.lex_state = 284},
  [2263] = {.lex_state = 284},
  [2264] = {.lex_state = 284},
  [2265] = {.lex_state = 284},
  [2266] = {.lex_state = 284},
  [2267] = {.lex_state = 284},
  [2268] = {.lex_state = 284},
  [2269] = {.lex_state = 284},
  [2270] = {.lex_state = 284},
  [2271] = {.lex_state = 273},
  [2272] = {.lex_state = 284},
  [2273] = {.lex_state = 210},
  [2274] = {.lex_state = 210},
  [2275] = {.lex_state = 210},
  [2276] = {.lex_state = 285},
  [2277] = {.lex_state = 276},
  [2278] = {.lex_state = 240},
  [2279] = {.lex_state = 273},
  [2280] = {.lex_state = 273},
  [2281] = {.lex_state = 240},
  [2282] = {.lex_state = 284},
  [2283] = {.lex_state = 210},
  [2284] = {.lex_state = 234},
  [2285] = {.lex_state = 271},
  [2286] = {.lex_state = 271},
  [2287] = {.lex_state = 271},
  [2288] = {.lex_state = 284},
  [2289] = {.lex_state = 240},
  [2290] = {.lex_state = 284},
  [2291] = {.lex_state = 240},
  [2292] = {.lex_state = 284},
  [2293] = {.lex_state = 284},
  [2294] = {.lex_state = 271},
  [2295] = {.lex_state = 271},
  [2296] = {.lex_state = 240},
  [2297] = {.lex_state = 271},
  [2298] = {.lex_state = 271},
  [2299] = {.lex_state = 271},
  [2300] = {.lex_state = 271},
  [2301] = {.lex_state = 240},
  [2302] = {.lex_state = 240},
  [2303] = {.lex_state = 240},
  [2304] = {.lex_state = 271},
  [2305] = {.lex_state = 284},
  [2306] = {.lex_state = 240},
  [2307] = {.lex_state = 240},
  [2308] = {.lex_state = 284},
  [2309] = {.lex_state = 284},
  [2310] = {.lex_state = 240},
  [2311] = {.lex_state = 240},
  [2312] = {.lex_state = 240},
  [2313] = {.lex_state = 208},
  [2314] = {.lex_state = 271},
  [2315] = {.lex_state = 271},
  [2316] = {.lex_state = 240},
  [2317] = {.lex_state = 271},
  [2318] = {.lex_state = 284},
  [2319] = {.lex_state = 271},
  [2320] = {.lex_state = 284},
  [2321] = {.lex_state = 284},
  [2322] = {.lex_state = 284},
  [2323] = {.lex_state = 284},
  [2324] = {.lex_state = 284},
  [2325] = {.lex_state = 284},
  [2326] = {.lex_state = 284},
  [2327] = {.lex_state = 284},
  [2328] = {.lex_state = 284},
  [2329] = {.lex_state = 284},
  [2330] = {.lex_state = 284},
  [2331] = {.lex_state = 284},
  [2332] = {.lex_state = 279},
  [2333] = {.lex_state = 285},
  [2334] = {.lex_state = 273},
  [2335] = {.lex_state = 266},
  [2336] = {.lex_state = 266},
  [2337] = {.lex_state = 276},
  [2338] = {.lex_state = 276},
  [2339] = {.lex_state = 234},
  [2340] = {.lex_state = 266},
  [2341] = {.lex_state = 266},
  [2342] = {.lex_state = 266},
  [2343] = {.lex_state = 234},
  [2344] = {.lex_state = 231},
  [2345] = {.lex_state = 279},
  [2346] = {.lex_state = 238},
  [2347] = {.lex_state = 284},
  [2348] = {.lex_state = 238},
  [2349] = {.lex_state = 279},
  [2350] = {.lex_state = 279},
  [2351] = {.lex_state = 234},
  [2352] = {.lex_state = 231},
  [2353] = {.lex_state = 266},
  [2354] = {.lex_state = 285},
  [2355] = {.lex_state = 284},
  [2356] = {.lex_state = 266},
  [2357] = {.lex_state = 234},
  [2358] = {.lex_state = 210},
  [2359] = {.lex_state = 231},
  [2360] = {.lex_state = 284},
  [2361] = {.lex_state = 276},
  [2362] = {.lex_state = 284},
  [2363] = {.lex_state = 231},
  [2364] = {.lex_state = 231},
  [2365] = {.lex_state = 231},
  [2366] = {.lex_state = 231},
  [2367] = {.lex_state = 284},
  [2368] = {.lex_state = 276},
  [2369] = {.lex_state = 284},
  [2370] = {.lex_state = 271},
  [2371] = {.lex_state = 213},
  [2372] = {.lex_state = 210},
  [2373] = {.lex_state = 208},
  [2374] = {.lex_state = 289},
  [2375] = {.lex_state = 266},
  [2376] = {.lex_state = 266},
  [2377] = {.lex_state = 217},
  [2378] = {.lex_state = 269},
  [2379] = {.lex_state = 217},
  [2380] = {.lex_state = 266},
  [2381] = {.lex_state = 266},
  [2382] = {.lex_state = 266},
  [2383] = {.lex_state = 266},
  [2384] = {.lex_state = 266},
  [2385] = {.lex_state = 269},
  [2386] = {.lex_state = 266},
  [2387] = {.lex_state = 208},
  [2388] = {.lex_state = 234},
  [2389] = {.lex_state = 284},
  [2390] = {.lex_state = 208},
  [2391] = {.lex_state = 213},
  [2392] = {.lex_state = 217},
  [2393] = {.lex_state = 231},
  [2394] = {.lex_state = 269},
  [2395] = {.lex_state = 266},
  [2396] = {.lex_state = 269},
  [2397] = {.lex_state = 269},
  [2398] = {.lex_state = 210},
  [2399] = {.lex_state = 266},
  [2400] = {.lex_state = 266},
  [2401] = {.lex_state = 266},
  [2402] = {.lex_state = 210},
  [2403] = {.lex_state = 269},
  [2404] = {.lex_state = 269},
  [2405] = {.lex_state = 269},
  [2406] = {.lex_state = 269},
  [2407] = {.lex_state = 234},
  [2408] = {.lex_state = 271},
  [2409] = {.lex_state = 234},
  [2410] = {.lex_state = 210},
  [2411] = {.lex_state = 269},
  [2412] = {.lex_state = 269},
  [2413] = {.lex_state = 269},
  [2414] = {.lex_state = 266},
  [2415] = {.lex_state = 266},
  [2416] = {.lex_state = 284},
  [2417] = {.lex_state = 208},
  [2418] = {.lex_state = 234},
  [2419] = {.lex_state = 271},
  [2420] = {.lex_state = 208},
  [2421] = {.lex_state = 232},
  [2422] = {.lex_state = 271},
  [2423] = {.lex_state = 232},
  [2424] = {.lex_state = 269},
  [2425] = {.lex_state = 271},
  [2426] = {.lex_state = 208},
  [2427] = {.lex_state = 231},
  [2428] = {.lex_state = 234},
  [2429] = {.lex_state = 234},
  [2430] = {.lex_state = 234},
  [2431] = {.lex_state = 208},
  [2432] = {.lex_state = 208},
  [2433] = {.lex_state = 216},
  [2434] = {.lex_state = 271},
  [2435] = {.lex_state = 214},
  [2436] = {.lex_state = 231},
  [2437] = {.lex_state = 234},
  [2438] = {.lex_state = 214},
  [2439] = {.lex_state = 234},
  [2440] = {.lex_state = 208},
  [2441] = {.lex_state = 271},
  [2442] = {.lex_state = 271},
  [2443] = {.lex_state = 284},
  [2444] = {.lex_state = 234},
  [2445] = {.lex_state = 234},
  [2446] = {.lex_state = 269},
  [2447] = {.lex_state = 234},
  [2448] = {.lex_state = 234},
  [2449] = {.lex_state = 232},
  [2450] = {.lex_state = 271},
  [2451] = {.lex_state = 234},
  [2452] = {.lex_state = 208},
  [2453] = {.lex_state = 231},
  [2454] = {.lex_state = 271},
  [2455] = {.lex_state = 234},
  [2456] = {.lex_state = 271},
  [2457] = {.lex_state = 234},
  [2458] = {.lex_state = 284},
  [2459] = {.lex_state = 208},
  [2460] = {.lex_state = 216},
  [2461] = {.lex_state = 208},
  [2462] = {.lex_state = 284},
  [2463] = {.lex_state = 271},
  [2464] = {.lex_state = 216},
  [2465] = {.lex_state = 271},
  [2466] = {.lex_state = 232},
  [2467] = {.lex_state = 232},
  [2468] = {.lex_state = 287},
  [2469] = {.lex_state = 287},
  [2470] = {.lex_state = 285},
  [2471] = {.lex_state = 288},
  [2472] = {.lex_state = 231},
  [2473] = {.lex_state = 271},
  [2474] = {.lex_state = 271},
  [2475] = {.lex_state = 271},
  [2476] = {.lex_state = 271},
  [2477] = {.lex_state = 234},
  [2478] = {.lex_state = 234},
  [2479] = {.lex_state = 234},
  [2480] = {.lex_state = 231},
  [2481] = {.lex_state = 231},
  [2482] = {.lex_state = 234},
  [2483] = {.lex_state = 234},
  [2484] = {.lex_state = 234},
  [2485] = {.lex_state = 231},
  [2486] = {.lex_state = 231},
  [2487] = {.lex_state = 234},
  [2488] = {.lex_state = 234},
  [2489] = {.lex_state = 234},
  [2490] = {.lex_state = 234},
  [2491] = {.lex_state = 271},
  [2492] = {.lex_state = 234},
  [2493] = {.lex_state = 271},
  [2494] = {.lex_state = 271},
  [2495] = {.lex_state = 234},
  [2496] = {.lex_state = 234},
  [2497] = {.lex_state = 223},
  [2498] = {.lex_state = 271},
  [2499] = {.lex_state = 234},
  [2500] = {.lex_state = 234},
  [2501] = {.lex_state = 271},
  [2502] = {.lex_state = 219},
  [2503] = {.lex_state = 271},
  [2504] = {.lex_state = 234},
  [2505] = {.lex_state = 210},
  [2506] = {.lex_state = 234},
  [2507] = {.lex_state = 271},
  [2508] = {.lex_state = 271},
  [2509] = {.lex_state = 208},
  [2510] = {.lex_state = 284},
  [2511] = {.lex_state = 284},
  [2512] = {.lex_state = 234},
  [2513] = {.lex_state = 234},
  [2514] = {.lex_state = 234},
  [2515] = {.lex_state = 271},
  [2516] = {.lex_state = 271},
  [2517] = {.lex_state = 284},
  [2518] = {.lex_state = 234},
  [2519] = {.lex_state = 234},
  [2520] = {.lex_state = 271},
  [2521] = {.lex_state = 271},
  [2522] = {.lex_state = 234},
  [2523] = {.lex_state = 271},
  [2524] = {.lex_state = 271},
  [2525] = {.lex_state = 231},
  [2526] = {.lex_state = 234},
  [2527] = {.lex_state = 271},
  [2528] = {.lex_state = 271},
  [2529] = {.lex_state = 234},
  [2530] = {.lex_state = 234},
  [2531] = {.lex_state = 234},
  [2532] = {.lex_state = 210},
  [2533] = {.lex_state = 223},
  [2534] = {.lex_state = 271},
  [2535] = {.lex_state = 271},
  [2536] = {.lex_state = 223},
  [2537] = {.lex_state = 231},
  [2538] = {.lex_state = 234},
  [2539] = {.lex_state = 271},
  [2540] = {.lex_state = 234},
  [2541] = {.lex_state = 234},
  [2542] = {.lex_state = 234},
  [2543] = {.lex_state = 284},
  [2544] = {.lex_state = 234},
  [2545] = {.lex_state = 271},
  [2546] = {.lex_state = 234},
  [2547] = {.lex_state = 208},
  [2548] = {.lex_state = 232},
  [2549] = {.lex_state = 271},
  [2550] = {.lex_state = 284},
  [2551] = {.lex_state = 271},
  [2552] = {.lex_state = 271},
  [2553] = {.lex_state = 284},
  [2554] = {.lex_state = 234},
  [2555] = {.lex_state = 284},
  [2556] = {.lex_state = 234},
  [2557] = {.lex_state = 210},
  [2558] = {.lex_state = 284},
  [2559] = {.lex_state = 271},
  [2560] = {.lex_state = 234},
  [2561] = {.lex_state = 231},
  [2562] = {.lex_state = 210},
  [2563] = {.lex_state = 284},
  [2564] = {.lex_state = 271},
  [2565] = {.lex_state = 271},
  [2566] = {.lex_state = 271},
  [2567] = {.lex_state = 284},
  [2568] = {.lex_state = 231},
  [2569] = {.lex_state = 284},
  [2570] = {.lex_state = 271},
  [2571] = {.lex_state = 231},
  [2572] = {.lex_state = 234},
  [2573] = {.lex_state = 234},
  [2574] = {.lex_state = 234},
  [2575] = {.lex_state = 234},
  [2576] = {.lex_state = 218},
  [2577] = {.lex_state = 271},
  [2578] = {.lex_state = 219},
  [2579] = {.lex_state = 232},
  [2580] = {.lex_state = 271},
  [2581] = {.lex_state = 284},
  [2582] = {.lex_state = 221},
  [2583] = {.lex_state = 234},
  [2584] = {.lex_state = 271},
  [2585] = {.lex_state = 231},
  [2586] = {.lex_state = 231},
  [2587] = {.lex_state = 232},
  [2588] = {.lex_state = 284},
  [2589] = {.lex_state = 232},
  [2590] = {.lex_state = 234},
  [2591] = {.lex_state = 232},
  [2592] = {.lex_state = 271},
  [2593] = {.lex_state = 232},
  [2594] = {.lex_state = 208},
  [2595] = {.lex_state = 232},
  [2596] = {.lex_state = 271},
  [2597] = {.lex_state = 232},
  [2598] = {.lex_state = 221},
  [2599] = {.lex_state = 232},
  [2600] = {.lex_state = 232},
  [2601] = {.lex_state = 232},
  [2602] = {.lex_state = 232},
  [2603] = {.lex_state = 271},
  [2604] = {.lex_state = 284},
  [2605] = {.lex_state = 208},
  [2606] = {.lex_state = 210},
  [2607] = {.lex_state = 218},
  [2608] = {.lex_state = 231},
  [2609] = {.lex_state = 221},
  [2610] = {.lex_state = 271},
  [2611] = {.lex_state = 271},
  [2612] = {.lex_state = 231},
  [2613] = {.lex_state = 271},
  [2614] = {.lex_state = 232},
  [2615] = {.lex_state = 234},
  [2616] = {.lex_state = 231},
  [2617] = {.lex_state = 231},
  [2618] = {.lex_state = 271},
  [2619] = {.lex_state = 234},
  [2620] = {.lex_state = 284},
  [2621] = {.lex_state = 234},
  [2622] = {.lex_state = 234},
  [2623] = {.lex_state = 234},
  [2624] = {.lex_state = 285},
  [2625] = {.lex_state = 284},
  [2626] = {.lex_state = 285},
  [2627] = {.lex_state = 231},
  [2628] = {.lex_state = 231},
  [2629] = {.lex_state = 284},
  [2630] = {.lex_state = 284},
  [2631] = {.lex_state = 285},
  [2632] = {.lex_state = 231},
  [2633] = {.lex_state = 234},
  [2634] = {.lex_state = 285},
  [2635] = {.lex_state = 285},
  [2636] = {.lex_state = 216},
  [2637] = {.lex_state = 234},
  [2638] = {.lex_state = 284},
  [2639] = {.lex_state = 285},
  [2640] = {.lex_state = 284},
  [2641] = {.lex_state = 234},
  [2642] = {.lex_state = 234},
  [2643] = {.lex_state = 285},
  [2644] = {.lex_state = 285},
  [2645] = {.lex_state = 284},
  [2646] = {.lex_state = 284},
  [2647] = {.lex_state = 284},
  [2648] = {.lex_state = 284},
  [2649] = {.lex_state = 284},
  [2650] = {.lex_state = 284},
  [2651] = {.lex_state = 287},
  [2652] = {.lex_state = 288},
  [2653] = {.lex_state = 234},
  [2654] = {.lex_state = 284},
  [2655] = {.lex_state = 234},
  [2656] = {.lex_state = 266},
  [2657] = {.lex_state = 287},
  [2658] = {.lex_state = 285},
  [2659] = {.lex_state = 234},
  [2660] = {.lex_state = 210},
  [2661] = {.lex_state = 284},
  [2662] = {.lex_state = 231},
  [2663] = {.lex_state = 284},
  [2664] = {.lex_state = 210},
  [2665] = {.lex_state = 231},
  [2666] = {.lex_state = 285},
  [2667] = {.lex_state = 210},
  [2668] = {.lex_state = 234},
  [2669] = {.lex_state = 210},
  [2670] = {.lex_state = 284},
  [2671] = {.lex_state = 238},
  [2672] = {.lex_state = 231},
  [2673] = {.lex_state = 285},
  [2674] = {.lex_state = 234},
  [2675] = {.lex_state = 231},
  [2676] = {.lex_state = 231},
  [2677] = {.lex_state = 231},
  [2678] = {.lex_state = 238},
  [2679] = {.lex_state = 234},
  [2680] = {.lex_state = 284},
  [2681] = {.lex_state = 231},
  [2682] = {.lex_state = 284},
  [2683] = {.lex_state = 284},
  [2684] = {.lex_state = 234},
  [2685] = {.lex_state = 285},
  [2686] = {.lex_state = 266},
  [2687] = {.lex_state = 284},
  [2688] = {.lex_state = 284},
  [2689] = {.lex_state = 284},
  [2690] = {.lex_state = 285},
  [2691] = {.lex_state = 234},
  [2692] = {.lex_state = 285},
  [2693] = {.lex_state = 231},
  [2694] = {.lex_state = 232},
  [2695] = {.lex_state = 285},
  [2696] = {.lex_state = 216},
  [2697] = {.lex_state = 237},
  [2698] = {.lex_state = 284},
  [2699] = {.lex_state = 221},
  [2700] = {.lex_state = 284},
  [2701] = {.lex_state = 266},
  [2702] = {.lex_state = 216},
  [2703] = {.lex_state = 216},
  [2704] = {.lex_state = 234},
  [2705] = {.lex_state = 285},
  [2706] = {.lex_state = 231},
  [2707] = {.lex_state = 216},
  [2708] = {.lex_state = 285},
  [2709] = {.lex_state = 216},
  [2710] = {.lex_state = 232},
  [2711] = {.lex_state = 244},
  [2712] = {.lex_state = 216},
  [2713] = {.lex_state = 284},
  [2714] = {.lex_state = 210},
  [2715] = {.lex_state = 234},
  [2716] = {.lex_state = 234},
  [2717] = {.lex_state = 234},
  [2718] = {.lex_state = 284},
  [2719] = {.lex_state = 243},
  [2720] = {.lex_state = 285},
  [2721] = {.lex_state = 285},
  [2722] = {.lex_state = 234},
  [2723] = {.lex_state = 234},
  [2724] = {.lex_state = 234},
  [2725] = {.lex_state = 223},
  [2726] = {.lex_state = 232},
  [2727] = {.lex_state = 216},
  [2728] = {.lex_state = 234},
  [2729] = {.lex_state = 285},
  [2730] = {.lex_state = 285},
  [2731] = {.lex_state = 285},
  [2732] = {.lex_state = 210},
  [2733] = {.lex_state = 210},
  [2734] = {.lex_state = 232},
  [2735] = {.lex_state = 232},
  [2736] = {.lex_state = 210},
  [2737] = {.lex_state = 234},
  [2738] = {.lex_state = 234},
  [2739] = {.lex_state = 234},
  [2740] = {.lex_state = 250},
  [2741] = {.lex_state = 234},
  [2742] = {.lex_state = 234},
  [2743] = {.lex_state = 234},
  [2744] = {.lex_state = 252},
  [2745] = {.lex_state = 234},
  [2746] = {.lex_state = 251},
  [2747] = {.lex_state = 284},
  [2748] = {.lex_state = 234},
  [2749] = {.lex_state = 216},
  [2750] = {.lex_state = 234},
  [2751] = {.lex_state = 234},
  [2752] = {.lex_state = 234},
  [2753] = {.lex_state = 234},
  [2754] = {.lex_state = 284},
  [2755] = {.lex_state = 234},
  [2756] = {.lex_state = 234},
  [2757] = {.lex_state = 234},
  [2758] = {.lex_state = 234},
  [2759] = {.lex_state = 234},
  [2760] = {.lex_state = 234},
  [2761] = {.lex_state = 234},
  [2762] = {.lex_state = 234},
  [2763] = {.lex_state = 234},
  [2764] = {.lex_state = 234},
  [2765] = {.lex_state = 234},
  [2766] = {.lex_state = 234},
  [2767] = {.lex_state = 234},
  [2768] = {.lex_state = 234},
  [2769] = {.lex_state = 234},
  [2770] = {.lex_state = 234},
  [2771] = {.lex_state = 234},
  [2772] = {.lex_state = 234},
  [2773] = {.lex_state = 234},
  [2774] = {.lex_state = 216},
  [2775] = {.lex_state = 234},
  [2776] = {.lex_state = 234},
  [2777] = {.lex_state = 234},
  [2778] = {.lex_state = 234},
  [2779] = {.lex_state = 234},
  [2780] = {.lex_state = 234},
  [2781] = {.lex_state = 234},
  [2782] = {.lex_state = 216},
  [2783] = {.lex_state = 234},
  [2784] = {.lex_state = 234},
  [2785] = {.lex_state = 234},
  [2786] = {.lex_state = 234},
  [2787] = {.lex_state = 234},
  [2788] = {.lex_state = 234},
  [2789] = {.lex_state = 234},
  [2790] = {.lex_state = 284},
  [2791] = {.lex_state = 234},
  [2792] = {.lex_state = 234},
  [2793] = {.lex_state = 234},
  [2794] = {.lex_state = 234},
  [2795] = {.lex_state = 234},
  [2796] = {.lex_state = 234},
  [2797] = {.lex_state = 234},
  [2798] = {.lex_state = 234},
  [2799] = {.lex_state = 234},
  [2800] = {.lex_state = 234},
  [2801] = {.lex_state = 234},
  [2802] = {.lex_state = 234},
  [2803] = {.lex_state = 253},
  [2804] = {.lex_state = 234},
  [2805] = {.lex_state = 234},
  [2806] = {.lex_state = 234},
  [2807] = {.lex_state = 234},
  [2808] = {.lex_state = 234},
  [2809] = {.lex_state = 234},
  [2810] = {.lex_state = 234},
  [2811] = {.lex_state = 234},
  [2812] = {.lex_state = 234},
  [2813] = {.lex_state = 221},
  [2814] = {.lex_state = 284},
  [2815] = {.lex_state = 221},
  [2816] = {.lex_state = 284},
  [2817] = {.lex_state = 234},
  [2818] = {.lex_state = 223},
  [2819] = {.lex_state = 234},
  [2820] = {.lex_state = 234},
  [2821] = {.lex_state = 223},
  [2822] = {.lex_state = 221},
  [2823] = {.lex_state = 221},
  [2824] = {.lex_state = 223},
  [2825] = {.lex_state = 216},
  [2826] = {.lex_state = 223},
  [2827] = {.lex_state = 234},
  [2828] = {.lex_state = 234},
  [2829] = {.lex_state = 234},
  [2830] = {.lex_state = 234},
  [2831] = {.lex_state = 234},
  [2832] = {.lex_state = 234},
  [2833] = {.lex_state = 234},
  [2834] = {.lex_state = 234},
  [2835] = {.lex_state = 234},
  [2836] = {.lex_state = 234},
  [2837] = {.lex_state = 234},
  [2838] = {.lex_state = 243},
  [2839] = {.lex_state = 221},
  [2840] = {.lex_state = 243},
  [2841] = {.lex_state = 238},
  [2842] = {.lex_state = 221},
  [2843] = {.lex_state = 223},
  [2844] = {.lex_state = 243},
  [2845] = {.lex_state = 216},
  [2846] = {.lex_state = 243},
  [2847] = {.lex_state = 243},
  [2848] = {.lex_state = 284},
  [2849] = {.lex_state = 243},
  [2850] = {.lex_state = 223},
  [2851] = {.lex_state = 243},
  [2852] = {.lex_state = 288},
  [2853] = {.lex_state = 243},
  [2854] = {.lex_state = 221},
  [2855] = {.lex_state = 243},
  [2856] = {.lex_state = 284},
  [2857] = {.lex_state = 284},
  [2858] = {.lex_state = 223},
  [2859] = {.lex_state = 285},
  [2860] = {.lex_state = 243},
  [2861] = {.lex_state = 243},
  [2862] = {.lex_state = 223},
  [2863] = {.lex_state = 221},
  [2864] = {.lex_state = 243},
  [2865] = {.lex_state = 288},
  [2866] = {.lex_state = 269},
  [2867] = {.lex_state = 243},
  [2868] = {.lex_state = 243},
  [2869] = {.lex_state = 284},
  [2870] = {.lex_state = 238},
  [2871] = {.lex_state = 243},
  [2872] = {.lex_state = 285},
  [2873] = {.lex_state = 288},
  [2874] = {.lex_state = 243},
  [2875] = {.lex_state = 238},
  [2876] = {.lex_state = 238},
  [2877] = {.lex_state = 238},
  [2878] = {.lex_state = 244},
  [2879] = {.lex_state = 251},
  [2880] = {.lex_state = 250},
  [2881] = {.lex_state = 250},
  [2882] = {.lex_state = 250},
  [2883] = {.lex_state = 216},
  [2884] = {.lex_state = 238},
  [2885] = {.lex_state = 212},
  [2886] = {.lex_state = 251},
  [2887] = {.lex_state = 238},
  [2888] = {.lex_state = 251},
  [2889] = {.lex_state = 238},
  [2890] = {.lex_state = 251},
  [2891] = {.lex_state = 238},
  [2892] = {.lex_state = 243},
  [2893] = {.lex_state = 250},
  [2894] = {.lex_state = 238},
  [2895] = {.lex_state = 238},
  [2896] = {.lex_state = 238},
  [2897] = {.lex_state = 250},
  [2898] = {.lex_state = 238},
  [2899] = {.lex_state = 243},
  [2900] = {.lex_state = 238},
  [2901] = {.lex_state = 284},
  [2902] = {.lex_state = 238},
  [2903] = {.lex_state = 284},
  [2904] = {.lex_state = 243},
  [2905] = {.lex_state = 284},
  [2906] = {.lex_state = 238},
  [2907] = {.lex_state = 284},
  [2908] = {.lex_state = 243},
  [2909] = {.lex_state = 284},
  [2910] = {.lex_state = 284},
  [2911] = {.lex_state = 284},
  [2912] = {.lex_state = 238},
  [2913] = {.lex_state = 284},
  [2914] = {.lex_state = 284},
  [2915] = {.lex_state = 284},
  [2916] = {.lex_state = 250},
  [2917] = {.lex_state = 284},
  [2918] = {.lex_state = 284},
  [2919] = {.lex_state = 212},
  [2920] = {.lex_state = 288},
  [2921] = {.lex_state = 238},
  [2922] = {.lex_state = 251},
  [2923] = {.lex_state = 238},
  [2924] = {.lex_state = 250},
  [2925] = {.lex_state = 251},
  [2926] = {.lex_state = 251},
  [2927] = {.lex_state = 284},
  [2928] = {.lex_state = 238},
  [2929] = {.lex_state = 243},
  [2930] = {.lex_state = 288},
  [2931] = {.lex_state = 238},
  [2932] = {.lex_state = 238},
  [2933] = {.lex_state = 244},
  [2934] = {.lex_state = 250},
  [2935] = {.lex_state = 251},
  [2936] = {.lex_state = 244},
  [2937] = {.lex_state = 216},
  [2938] = {.lex_state = 238},
  [2939] = {.lex_state = 251},
  [2940] = {.lex_state = 238},
  [2941] = {.lex_state = 250},
  [2942] = {.lex_state = 251},
  [2943] = {.lex_state = 212},
  [2944] = {.lex_state = 284},
  [2945] = {.lex_state = 238},
  [2946] = {.lex_state = 250},
  [2947] = {.lex_state = 251},
  [2948] = {.lex_state = 250},
  [2949] = {.lex_state = 250},
  [2950] = {.lex_state = 238},
  [2951] = {.lex_state = 251},
  [2952] = {.lex_state = 238},
  [2953] = {.lex_state = 250},
  [2954] = {.lex_state = 238},
  [2955] = {.lex_state = 216},
  [2956] = {.lex_state = 288},
  [2957] = {.lex_state = 238},
  [2958] = {.lex_state = 238},
  [2959] = {.lex_state = 251},
  [2960] = {.lex_state = 250},
  [2961] = {.lex_state = 251},
  [2962] = {.lex_state = 250},
  [2963] = {.lex_state = 284},
  [2964] = {.lex_state = 251},
  [2965] = {.lex_state = 216},
  [2966] = {.lex_state = 238},
  [2967] = {.lex_state = 206},
  [2968] = {.lex_state = 216},
  [2969] = {.lex_state = 266},
  [2970] = {.lex_state = 266},
  [2971] = {.lex_state = 252},
  [2972] = {.lex_state = 244},
  [2973] = {.lex_state = 266},
  [2974] = {.lex_state = 251},
  [2975] = {.lex_state = 243},
  [2976] = {.lex_state = 266},
  [2977] = {.lex_state = 252},
  [2978] = {.lex_state = 285},
  [2979] = {.lex_state = 253},
  [2980] = {.lex_state = 284},
  [2981] = {.lex_state = 251},
  [2982] = {.lex_state = 250},
  [2983] = {.lex_state = 251},
  [2984] = {.lex_state = 250},
  [2985] = {.lex_state = 250},
  [2986] = {.lex_state = 250},
  [2987] = {.lex_state = 284},
  [2988] = {.lex_state = 251},
  [2989] = {.lex_state = 251},
  [2990] = {.lex_state = 251},
  [2991] = {.lex_state = 206},
  [2992] = {.lex_state = 251},
  [2993] = {.lex_state = 251},
  [2994] = {.lex_state = 251},
  [2995] = {.lex_state = 251},
  [2996] = {.lex_state = 266},
  [2997] = {.lex_state = 253},
  [2998] = {.lex_state = 243},
  [2999] = {.lex_state = 266},
  [3000] = {.lex_state = 284},
  [3001] = {.lex_state = 250},
  [3002] = {.lex_state = 216},
  [3003] = {.lex_state = 251},
  [3004] = {.lex_state = 251},
  [3005] = {.lex_state = 216},
  [3006] = {.lex_state = 284},
  [3007] = {.lex_state = 284},
  [3008] = {.lex_state = 284},
  [3009] = {.lex_state = 216},
  [3010] = {.lex_state = 266},
  [3011] = {.lex_state = 231},
  [3012] = {.lex_state = 243},
  [3013] = {.lex_state = 284},
  [3014] = {.lex_state = 253},
  [3015] = {.lex_state = 231},
  [3016] = {.lex_state = 231},
  [3017] = {.lex_state = 243},
  [3018] = {.lex_state = 231},
  [3019] = {.lex_state = 231},
  [3020] = {.lex_state = 231},
  [3021] = {.lex_state = 231},
  [3022] = {.lex_state = 231},
  [3023] = {.lex_state = 243},
  [3024] = {.lex_state = 231},
  [3025] = {.lex_state = 243},
  [3026] = {.lex_state = 243},
  [3027] = {.lex_state = 243},
  [3028] = {.lex_state = 243},
  [3029] = {.lex_state = 243},
  [3030] = {.lex_state = 251},
  [3031] = {.lex_state = 243},
  [3032] = {.lex_state = 243},
  [3033] = {.lex_state = 231},
  [3034] = {.lex_state = 243},
  [3035] = {.lex_state = 243},
  [3036] = {.lex_state = 231},
  [3037] = {.lex_state = 231},
  [3038] = {.lex_state = 231},
  [3039] = {.lex_state = 231},
  [3040] = {.lex_state = 243},
  [3041] = {.lex_state = 243},
  [3042] = {.lex_state = 252},
  [3043] = {.lex_state = 243},
  [3044] = {.lex_state = 284},
  [3045] = {.lex_state = 250},
  [3046] = {.lex_state = 243},
  [3047] = {.lex_state = 284},
  [3048] = {.lex_state = 243},
  [3049] = {.lex_state = 284},
  [3050] = {.lex_state = 243},
  [3051] = {.lex_state = 243},
  [3052] = {.lex_state = 231},
  [3053] = {.lex_state = 231},
  [3054] = {.lex_state = 231},
  [3055] = {.lex_state = 243},
  [3056] = {.lex_state = 243},
  [3057] = {.lex_state = 231},
  [3058] = {.lex_state = 284},
  [3059] = {.lex_state = 206},
  [3060] = {.lex_state = 268},
  [3061] = {.lex_state = 243},
  [3062] = {.lex_state = 243},
  [3063] = {.lex_state = 243},
  [3064] = {.lex_state = 243},
  [3065] = {.lex_state = 232},
  [3066] = {.lex_state = 206},
  [3067] = {.lex_state = 206},
  [3068] = {.lex_state = 288},
  [3069] = {.lex_state = 243},
  [3070] = {.lex_state = 206},
  [3071] = {.lex_state = 206},
  [3072] = {.lex_state = 232},
  [3073] = {.lex_state = 251},
  [3074] = {.lex_state = 232},
  [3075] = {.lex_state = 206},
  [3076] = {.lex_state = 284},
  [3077] = {.lex_state = 206},
  [3078] = {.lex_state = 206},
  [3079] = {.lex_state = 284},
  [3080] = {.lex_state = 243},
  [3081] = {.lex_state = 232},
  [3082] = {.lex_state = 250},
  [3083] = {.lex_state = 284},
  [3084] = {.lex_state = 243},
  [3085] = {.lex_state = 289},
  [3086] = {.lex_state = 243},
  [3087] = {.lex_state = 251},
  [3088] = {.lex_state = 212},
  [3089] = {.lex_state = 250},
  [3090] = {.lex_state = 206},
  [3091] = {.lex_state = 251},
  [3092] = {.lex_state = 243},
  [3093] = {.lex_state = 206},
  [3094] = {.lex_state = 266},
  [3095] = {.lex_state = 250},
  [3096] = {.lex_state = 266},
  [3097] = {.lex_state = 268},
  [3098] = {.lex_state = 251},
  [3099] = {.lex_state = 243},
  [3100] = {.lex_state = 250},
  [3101] = {.lex_state = 268},
  [3102] = {.lex_state = 243},
  [3103] = {.lex_state = 206},
  [3104] = {.lex_state = 243},
  [3105] = {.lex_state = 243},
  [3106] = {.lex_state = 243},
  [3107] = {.lex_state = 243},
  [3108] = {.lex_state = 232},
  [3109] = {.lex_state = 243},
  [3110] = {.lex_state = 206},
  [3111] = {.lex_state = 206},
  [3112] = {.lex_state = 206},
  [3113] = {.lex_state = 250},
  [3114] = {.lex_state = 243},
  [3115] = {.lex_state = 243},
  [3116] = {.lex_state = 232},
  [3117] = {.lex_state = 251},
  [3118] = {.lex_state = 244},
  [3119] = {.lex_state = 212},
  [3120] = {.lex_state = 250},
  [3121] = {.lex_state = 243},
  [3122] = {.lex_state = 206},
  [3123] = {.lex_state = 243},
  [3124] = {.lex_state = 206},
  [3125] = {.lex_state = 206},
  [3126] = {.lex_state = 251},
  [3127] = {.lex_state = 284},
  [3128] = {.lex_state = 243},
  [3129] = {.lex_state = 206},
  [3130] = {.lex_state = 206},
  [3131] = {.lex_state = 244},
  [3132] = {.lex_state = 212},
  [3133] = {.lex_state = 243},
  [3134] = {.lex_state = 288},
  [3135] = {.lex_state = 288},
  [3136] = {.lex_state = 243},
  [3137] = {.lex_state = 206},
  [3138] = {.lex_state = 232},
  [3139] = {.lex_state = 212},
  [3140] = {.lex_state = 244},
  [3141] = {.lex_state = 288},
  [3142] = {.lex_state = 288},
  [3143] = {.lex_state = 231},
  [3144] = {.lex_state = 288},
  [3145] = {.lex_state = 243},
  [3146] = {.lex_state = 235},
  [3147] = {.lex_state = 288},
  [3148] = {.lex_state = 243},
  [3149] = {.lex_state = 250},
  [3150] = {.lex_state = 250},
  [3151] = {.lex_state = 250},
  [3152] = {.lex_state = 250},
  [3153] = {.lex_state = 243},
  [3154] = {.lex_state = 251},
  [3155] = {.lex_state = 251},
  [3156] = {.lex_state = 231},
  [3157] = {.lex_state = 266},
  [3158] = {.lex_state = 231},
  [3159] = {.lex_state = 243},
  [3160] = {.lex_state = 288},
  [3161] = {.lex_state = 288},
  [3162] = {.lex_state = 243},
  [3163] = {.lex_state = 231},
  [3164] = {.lex_state = 243},
  [3165] = {.lex_state = 251},
  [3166] = {.lex_state = 251},
  [3167] = {.lex_state = 243},
  [3168] = {.lex_state = 251},
  [3169] = {.lex_state = 251},
  [3170] = {.lex_state = 250},
  [3171] = {.lex_state = 243},
  [3172] = {.lex_state = 288},
  [3173] = {.lex_state = 284},
  [3174] = {.lex_state = 243},
  [3175] = {.lex_state = 231},
  [3176] = {.lex_state = 231},
  [3177] = {.lex_state = 284},
  [3178] = {.lex_state = 250},
  [3179] = {.lex_state = 231},
  [3180] = {.lex_state = 250},
  [3181] = {.lex_state = 250},
  [3182] = {.lex_state = 230},
  [3183] = {.lex_state = 243},
  [3184] = {.lex_state = 251},
  [3185] = {.lex_state = 243},
  [3186] = {.lex_state = 250},
  [3187] = {.lex_state = 251},
  [3188] = {.lex_state = 251},
  [3189] = {.lex_state = 251},
  [3190] = {.lex_state = 288},
  [3191] = {.lex_state = 266},
  [3192] = {.lex_state = 251},
  [3193] = {.lex_state = 251},
  [3194] = {.lex_state = 231},
  [3195] = {.lex_state = 231},
  [3196] = {.lex_state = 231},
  [3197] = {.lex_state = 231},
  [3198] = {.lex_state = 231},
  [3199] = {.lex_state = 231},
  [3200] = {.lex_state = 235},
  [3201] = {.lex_state = 231},
  [3202] = {.lex_state = 250},
  [3203] = {.lex_state = 231},
  [3204] = {.lex_state = 231},
  [3205] = {.lex_state = 231},
  [3206] = {.lex_state = 231},
  [3207] = {.lex_state = 250},
  [3208] = {.lex_state = 250},
  [3209] = {.lex_state = 231},
  [3210] = {.lex_state = 250},
  [3211] = {.lex_state = 231},
  [3212] = {.lex_state = 235},
  [3213] = {.lex_state = 243},
  [3214] = {.lex_state = 228},
  [3215] = {.lex_state = 243},
  [3216] = {.lex_state = 228},
  [3217] = {.lex_state = 231},
  [3218] = {.lex_state = 243},
  [3219] = {.lex_state = 228},
  [3220] = {.lex_state = 251},
  [3221] = {.lex_state = 231},
  [3222] = {.lex_state = 235},
  [3223] = {.lex_state = 251},
  [3224] = {.lex_state = 251},
  [3225] = {.lex_state = 228},
  [3226] = {.lex_state = 251},
  [3227] = {.lex_state = 231},
  [3228] = {.lex_state = 231},
  [3229] = {.lex_state = 230},
  [3230] = {.lex_state = 231},
  [3231] = {.lex_state = 231},
  [3232] = {.lex_state = 243},
  [3233] = {.lex_state = 231},
  [3234] = {.lex_state = 284},
  [3235] = {.lex_state = 251},
  [3236] = {.lex_state = 231},
  [3237] = {.lex_state = 231},
  [3238] = {.lex_state = 251},
  [3239] = {.lex_state = 250},
  [3240] = {.lex_state = 243},
  [3241] = {.lex_state = 231},
  [3242] = {.lex_state = 243},
  [3243] = {.lex_state = 231},
  [3244] = {.lex_state = 231},
  [3245] = {.lex_state = 243},
  [3246] = {.lex_state = 231},
  [3247] = {.lex_state = 231},
  [3248] = {.lex_state = 228},
  [3249] = {.lex_state = 243},
  [3250] = {.lex_state = 228},
  [3251] = {.lex_state = 243},
  [3252] = {.lex_state = 250},
  [3253] = {.lex_state = 250},
  [3254] = {.lex_state = 285},
  [3255] = {.lex_state = 231},
  [3256] = {.lex_state = 231},
  [3257] = {.lex_state = 231},
  [3258] = {.lex_state = 250},
  [3259] = {.lex_state = 250},
  [3260] = {.lex_state = 243},
  [3261] = {.lex_state = 243},
  [3262] = {.lex_state = 285},
  [3263] = {.lex_state = 243},
  [3264] = {.lex_state = 243},
  [3265] = {.lex_state = 243},
  [3266] = {.lex_state = 243},
  [3267] = {.lex_state = 285},
  [3268] = {.lex_state = 289},
  [3269] = {.lex_state = 251},
  [3270] = {.lex_state = 285},
  [3271] = {.lex_state = 243},
  [3272] = {.lex_state = 285},
  [3273] = {.lex_state = 243},
  [3274] = {.lex_state = 285},
  [3275] = {.lex_state = 285},
  [3276] = {.lex_state = 243},
  [3277] = {.lex_state = 243},
  [3278] = {.lex_state = 243},
  [3279] = {.lex_state = 285},
  [3280] = {.lex_state = 243},
  [3281] = {.lex_state = 285},
  [3282] = {.lex_state = 243},
  [3283] = {.lex_state = 243},
  [3284] = {.lex_state = 243},
  [3285] = {.lex_state = 243},
  [3286] = {.lex_state = 255},
  [3287] = {.lex_state = 243},
  [3288] = {.lex_state = 243},
  [3289] = {.lex_state = 285},
  [3290] = {.lex_state = 260},
  [3291] = {.lex_state = 250},
  [3292] = {.lex_state = 285},
  [3293] = {.lex_state = 285},
  [3294] = {.lex_state = 288},
  [3295] = {.lex_state = 284},
  [3296] = {.lex_state = 285},
  [3297] = {.lex_state = 284},
  [3298] = {.lex_state = 243},
  [3299] = {.lex_state = 285},
  [3300] = {.lex_state = 285},
  [3301] = {.lex_state = 228},
  [3302] = {.lex_state = 285},
  [3303] = {.lex_state = 285},
  [3304] = {.lex_state = 243},
  [3305] = {.lex_state = 243},
  [3306] = {.lex_state = 285},
  [3307] = {.lex_state = 289},
  [3308] = {.lex_state = 243},
  [3309] = {.lex_state = 243},
  [3310] = {.lex_state = 243},
  [3311] = {.lex_state = 285},
  [3312] = {.lex_state = 285},
  [3313] = {.lex_state = 285},
  [3314] = {.lex_state = 243},
  [3315] = {.lex_state = 243},
  [3316] = {.lex_state = 243},
  [3317] = {.lex_state = 260},
  [3318] = {.lex_state = 285},
  [3319] = {.lex_state = 243},
  [3320] = {.lex_state = 285},
  [3321] = {.lex_state = 243},
  [3322] = {.lex_state = 243},
  [3323] = {.lex_state = 243},
  [3324] = {.lex_state = 285},
  [3325] = {.lex_state = 243},
  [3326] = {.lex_state = 243},
  [3327] = {.lex_state = 243},
  [3328] = {.lex_state = 285},
  [3329] = {.lex_state = 243},
  [3330] = {.lex_state = 243},
  [3331] = {.lex_state = 243},
  [3332] = {.lex_state = 243},
  [3333] = {.lex_state = 285},
  [3334] = {.lex_state = 243},
  [3335] = {.lex_state = 228},
  [3336] = {.lex_state = 285},
  [3337] = {.lex_state = 243},
  [3338] = {.lex_state = 228},
  [3339] = {.lex_state = 243},
  [3340] = {.lex_state = 285},
  [3341] = {.lex_state = 285},
  [3342] = {.lex_state = 243},
  [3343] = {.lex_state = 285},
  [3344] = {.lex_state = 243},
  [3345] = {.lex_state = 285},
  [3346] = {.lex_state = 251},
  [3347] = {.lex_state = 212},
  [3348] = {.lex_state = 243},
  [3349] = {.lex_state = 285},
  [3350] = {.lex_state = 243},
  [3351] = {.lex_state = 243},
  [3352] = {.lex_state = 285},
  [3353] = {.lex_state = 243},
  [3354] = {.lex_state = 285},
  [3355] = {.lex_state = 243},
  [3356] = {.lex_state = 243},
  [3357] = {.lex_state = 285},
  [3358] = {.lex_state = 243},
  [3359] = {.lex_state = 243},
  [3360] = {.lex_state = 243},
  [3361] = {.lex_state = 243},
  [3362] = {.lex_state = 285},
  [3363] = {.lex_state = 243},
  [3364] = {.lex_state = 285},
  [3365] = {.lex_state = 285},
  [3366] = {.lex_state = 243},
  [3367] = {.lex_state = 285},
  [3368] = {.lex_state = 255},
  [3369] = {.lex_state = 243},
  [3370] = {.lex_state = 285},
  [3371] = {.lex_state = 285},
  [3372] = {.lex_state = 285},
  [3373] = {.lex_state = 285},
  [3374] = {.lex_state = 285},
  [3375] = {.lex_state = 285},
  [3376] = {.lex_state = 260},
  [3377] = {.lex_state = 285},
  [3378] = {.lex_state = 243},
  [3379] = {.lex_state = 285},
  [3380] = {.lex_state = 285},
  [3381] = {.lex_state = 285},
  [3382] = {.lex_state = 243},
  [3383] = {.lex_state = 285},
  [3384] = {.lex_state = 285},
  [3385] = {.lex_state = 285},
  [3386] = {.lex_state = 285},
  [3387] = {.lex_state = 255},
  [3388] = {.lex_state = 251},
  [3389] = {.lex_state = 285},
  [3390] = {.lex_state = 285},
  [3391] = {.lex_state = 243},
  [3392] = {.lex_state = 285},
  [3393] = {.lex_state = 285},
  [3394] = {.lex_state = 243},
  [3395] = {.lex_state = 250},
  [3396] = {.lex_state = 255},
  [3397] = {.lex_state = 260},
  [3398] = {.lex_state = 243},
  [3399] = {.lex_state = 285},
  [3400] = {.lex_state = 243},
  [3401] = {.lex_state = 243},
  [3402] = {.lex_state = 288},
  [3403] = {.lex_state = 285},
  [3404] = {.lex_state = 285},
  [3405] = {.lex_state = 285},
  [3406] = {.lex_state = 243},
  [3407] = {.lex_state = 243},
  [3408] = {.lex_state = 243},
  [3409] = {.lex_state = 243},
  [3410] = {.lex_state = 285},
  [3411] = {.lex_state = 243},
  [3412] = {.lex_state = 285},
  [3413] = {.lex_state = 243},
  [3414] = {.lex_state = 285},
  [3415] = {.lex_state = 285},
  [3416] = {.lex_state = 289},
  [3417] = {.lex_state = 285},
  [3418] = {.lex_state = 285},
  [3419] = {.lex_state = 243},
  [3420] = {.lex_state = 285},
  [3421] = {.lex_state = 285},
  [3422] = {.lex_state = 285},
  [3423] = {.lex_state = 255},
  [3424] = {.lex_state = 243},
  [3425] = {.lex_state = 243},
  [3426] = {.lex_state = 285},
  [3427] = {.lex_state = 285},
  [3428] = {.lex_state = 250},
  [3429] = {.lex_state = 285},
  [3430] = {.lex_state = 285},
  [3431] = {.lex_state = 285},
  [3432] = {.lex_state = 285},
  [3433] = {.lex_state = 285},
  [3434] = {.lex_state = 285},
  [3435] = {.lex_state = 285},
  [3436] = {.lex_state = 285},
  [3437] = {.lex_state = 285},
  [3438] = {.lex_state = 285},
  [3439] = {.lex_state = 243},
  [3440] = {.lex_state = 285},
  [3441] = {.lex_state = 260},
  [3442] = {.lex_state = 243},
  [3443] = {.lex_state = 285},
  [3444] = {.lex_state = 285},
  [3445] = {.lex_state = 243},
  [3446] = {.lex_state = 285},
  [3447] = {.lex_state = 251},
  [3448] = {.lex_state = 251},
  [3449] = {.lex_state = 251},
  [3450] = {.lex_state = 251},
  [3451] = {.lex_state = 251},
  [3452] = {.lex_state = 251},
  [3453] = {.lex_state = 251},
  [3454] = {.lex_state = 251},
  [3455] = {.lex_state = 251},
  [3456] = {.lex_state = 251},
  [3457] = {.lex_state = 240},
  [3458] = {.lex_state = 231},
  [3459] = {.lex_state = 251},
  [3460] = {.lex_state = 285},
  [3461] = {.lex_state = 251},
  [3462] = {.lex_state = 212},
  [3463] = {.lex_state = 284},
  [3464] = {.lex_state = 212},
  [3465] = {.lex_state = 212},
  [3466] = {.lex_state = 235},
  [3467] = {.lex_state = 235},
  [3468] = {.lex_state = 243},
  [3469] = {.lex_state = 243},
  [3470] = {.lex_state = 288},
  [3471] = {.lex_state = 243},
  [3472] = {.lex_state = 255},
  [3473] = {.lex_state = 238},
  [3474] = {.lex_state = 228},
  [3475] = {.lex_state = 266},
  [3476] = {.lex_state = 251},
  [3477] = {.lex_state = 250},
  [3478] = {.lex_state = 287},
  [3479] = {.lex_state = 260},
  [3480] = {.lex_state = 243},
  [3481] = {.lex_state = 243},
  [3482] = {.lex_state = 243},
  [3483] = {.lex_state = 243},
  [3484] = {.lex_state = 200},
  [3485] = {.lex_state = 285},
  [3486] = {.lex_state = 231},
  [3487] = {.lex_state = 243},
  [3488] = {.lex_state = 200},
  [3489] = {.lex_state = 243},
  [3490] = {.lex_state = 230},
  [3491] = {.lex_state = 243},
  [3492] = {.lex_state = 228},
  [3493] = {.lex_state = 250},
  [3494] = {.lex_state = 200},
  [3495] = {.lex_state = 285},
  [3496] = {.lex_state = 254},
  [3497] = {.lex_state = 243},
  [3498] = {.lex_state = 260},
  [3499] = {.lex_state = 231},
  [3500] = {.lex_state = 200},
  [3501] = {.lex_state = 285},
  [3502] = {.lex_state = 243},
  [3503] = {.lex_state = 285},
  [3504] = {.lex_state = 200},
  [3505] = {.lex_state = 285},
  [3506] = {.lex_state = 243},
  [3507] = {.lex_state = 243},
  [3508] = {.lex_state = 251},
  [3509] = {.lex_state = 200},
  [3510] = {.lex_state = 285},
  [3511] = {.lex_state = 243},
  [3512] = {.lex_state = 250},
  [3513] = {.lex_state = 250},
  [3514] = {.lex_state = 200},
  [3515] = {.lex_state = 285},
  [3516] = {.lex_state = 250},
  [3517] = {.lex_state = 250},
  [3518] = {.lex_state = 251},
  [3519] = {.lex_state = 243},
  [3520] = {.lex_state = 250},
  [3521] = {.lex_state = 250},
  [3522] = {.lex_state = 250},
  [3523] = {.lex_state = 250},
  [3524] = {.lex_state = 250},
  [3525] = {.lex_state = 250},
  [3526] = {.lex_state = 245},
  [3527] = {.lex_state = 250},
  [3528] = {.lex_state = 285},
  [3529] = {.lex_state = 250},
  [3530] = {.lex_state = 250},
  [3531] = {.lex_state = 243},
  [3532] = {.lex_state = 285},
  [3533] = {.lex_state = 243},
  [3534] = {.lex_state = 250},
  [3535] = {.lex_state = 243},
  [3536] = {.lex_state = 230},
  [3537] = {.lex_state = 250},
  [3538] = {.lex_state = 250},
  [3539] = {.lex_state = 243},
  [3540] = {.lex_state = 250},
  [3541] = {.lex_state = 250},
  [3542] = {.lex_state = 250},
  [3543] = {.lex_state = 250},
  [3544] = {.lex_state = 250},
  [3545] = {.lex_state = 250},
  [3546] = {.lex_state = 250},
  [3547] = {.lex_state = 250},
  [3548] = {.lex_state = 250},
  [3549] = {.lex_state = 250},
  [3550] = {.lex_state = 285},
  [3551] = {.lex_state = 250},
  [3552] = {.lex_state = 250},
  [3553] = {.lex_state = 250},
  [3554] = {.lex_state = 250},
  [3555] = {.lex_state = 250},
  [3556] = {.lex_state = 250},
  [3557] = {.lex_state = 250},
  [3558] = {.lex_state = 250},
  [3559] = {.lex_state = 250},
  [3560] = {.lex_state = 206},
  [3561] = {.lex_state = 266},
  [3562] = {.lex_state = 250},
  [3563] = {.lex_state = 285},
  [3564] = {.lex_state = 250},
  [3565] = {.lex_state = 250},
  [3566] = {.lex_state = 266},
  [3567] = {.lex_state = 250},
  [3568] = {.lex_state = 250},
  [3569] = {.lex_state = 285},
  [3570] = {.lex_state = 250},
  [3571] = {.lex_state = 251},
  [3572] = {.lex_state = 250},
  [3573] = {.lex_state = 250},
  [3574] = {.lex_state = 285},
  [3575] = {.lex_state = 285},
  [3576] = {.lex_state = 250},
  [3577] = {.lex_state = 287},
  [3578] = {.lex_state = 287},
  [3579] = {.lex_state = 212},
  [3580] = {.lex_state = 250},
  [3581] = {.lex_state = 250},
  [3582] = {.lex_state = 285},
  [3583] = {.lex_state = 250},
  [3584] = {.lex_state = 288},
  [3585] = {.lex_state = 250},
  [3586] = {.lex_state = 285},
  [3587] = {.lex_state = 285},
  [3588] = {.lex_state = 250},
  [3589] = {.lex_state = 250},
  [3590] = {.lex_state = 250},
  [3591] = {.lex_state = 250},
  [3592] = {.lex_state = 250},
  [3593] = {.lex_state = 250},
  [3594] = {.lex_state = 250},
  [3595] = {.lex_state = 250},
  [3596] = {.lex_state = 285},
  [3597] = {.lex_state = 250},
  [3598] = {.lex_state = 250},
  [3599] = {.lex_state = 250},
  [3600] = {.lex_state = 251},
  [3601] = {.lex_state = 251},
  [3602] = {.lex_state = 251},
  [3603] = {.lex_state = 251},
  [3604] = {.lex_state = 251},
  [3605] = {.lex_state = 251},
  [3606] = {.lex_state = 251},
  [3607] = {.lex_state = 251},
  [3608] = {.lex_state = 251},
  [3609] = {.lex_state = 251},
  [3610] = {.lex_state = 243},
  [3611] = {.lex_state = 251},
  [3612] = {.lex_state = 251},
  [3613] = {.lex_state = 251},
  [3614] = {.lex_state = 234},
  [3615] = {.lex_state = 234},
  [3616] = {.lex_state = 234},
  [3617] = {.lex_state = 234},
  [3618] = {.lex_state = 234},
  [3619] = {.lex_state = 234},
  [3620] = {.lex_state = 234},
  [3621] = {.lex_state = 234},
  [3622] = {.lex_state = 234},
  [3623] = {.lex_state = 234},
  [3624] = {.lex_state = 234},
  [3625] = {.lex_state = 234},
  [3626] = {.lex_state = 234},
  [3627] = {.lex_state = 234},
  [3628] = {.lex_state = 234},
  [3629] = {.lex_state = 234},
  [3630] = {.lex_state = 234},
  [3631] = {.lex_state = 234},
  [3632] = {.lex_state = 234},
  [3633] = {.lex_state = 234},
  [3634] = {.lex_state = 234},
  [3635] = {.lex_state = 234},
  [3636] = {.lex_state = 234},
  [3637] = {.lex_state = 234},
  [3638] = {.lex_state = 251},
  [3639] = {.lex_state = 251},
  [3640] = {.lex_state = 251},
  [3641] = {.lex_state = 255},
  [3642] = {.lex_state = 251},
  [3643] = {.lex_state = 251},
  [3644] = {.lex_state = 251},
  [3645] = {.lex_state = 251},
  [3646] = {.lex_state = 251},
  [3647] = {.lex_state = 251},
  [3648] = {.lex_state = 251},
  [3649] = {.lex_state = 251},
  [3650] = {.lex_state = 251},
  [3651] = {.lex_state = 251},
  [3652] = {.lex_state = 251},
  [3653] = {.lex_state = 251},
  [3654] = {.lex_state = 251},
  [3655] = {.lex_state = 251},
  [3656] = {.lex_state = 251},
  [3657] = {.lex_state = 251},
  [3658] = {.lex_state = 251},
  [3659] = {.lex_state = 251},
  [3660] = {.lex_state = 234},
  [3661] = {.lex_state = 251},
  [3662] = {.lex_state = 250},
  [3663] = {.lex_state = 251},
  [3664] = {.lex_state = 251},
  [3665] = {.lex_state = 251},
  [3666] = {.lex_state = 251},
  [3667] = {.lex_state = 251},
  [3668] = {.lex_state = 251},
  [3669] = {.lex_state = 251},
  [3670] = {.lex_state = 251},
  [3671] = {.lex_state = 251},
  [3672] = {.lex_state = 251},
  [3673] = {.lex_state = 251},
  [3674] = {.lex_state = 251},
  [3675] = {.lex_state = 250},
  [3676] = {.lex_state = 247},
  [3677] = {.lex_state = 243},
  [3678] = {.lex_state = 243},
  [3679] = {.lex_state = 230},
  [3680] = {.lex_state = 240},
  [3681] = {.lex_state = 228},
  [3682] = {.lex_state = 238},
  [3683] = {.lex_state = 240},
  [3684] = {.lex_state = 230},
  [3685] = {.lex_state = 228},
  [3686] = {.lex_state = 228},
  [3687] = {.lex_state = 238},
  [3688] = {.lex_state = 243},
  [3689] = {.lex_state = 240},
  [3690] = {.lex_state = 230},
  [3691] = {.lex_state = 243},
  [3692] = {.lex_state = 238},
  [3693] = {.lex_state = 238},
  [3694] = {.lex_state = 231},
  [3695] = {.lex_state = 230},
  [3696] = {.lex_state = 230},
  [3697] = {.lex_state = 238},
  [3698] = {.lex_state = 289},
  [3699] = {.lex_state = 238},
  [3700] = {.lex_state = 250},
  [3701] = {.lex_state = 238},
  [3702] = {.lex_state = 228},
  [3703] = {.lex_state = 238},
  [3704] = {.lex_state = 228},
  [3705] = {.lex_state = 228},
  [3706] = {.lex_state = 238},
  [3707] = {.lex_state = 228},
  [3708] = {.lex_state = 289},
  [3709] = {.lex_state = 240},
  [3710] = {.lex_state = 238},
  [3711] = {.lex_state = 238},
  [3712] = {.lex_state = 243},
  [3713] = {.lex_state = 250},
  [3714] = {.lex_state = 228},
  [3715] = {.lex_state = 266},
  [3716] = {.lex_state = 240},
  [3717] = {.lex_state = 243},
  [3718] = {.lex_state = 228},
  [3719] = {.lex_state = 240},
  [3720] = {.lex_state = 240},
  [3721] = {.lex_state = 240},
  [3722] = {.lex_state = 240},
  [3723] = {.lex_state = 228},
  [3724] = {.lex_state = 228},
  [3725] = {.lex_state = 228},
  [3726] = {.lex_state = 228},
  [3727] = {.lex_state = 228},
  [3728] = {.lex_state = 266},
  [3729] = {.lex_state = 228},
  [3730] = {.lex_state = 228},
  [3731] = {.lex_state = 240},
  [3732] = {.lex_state = 228},
  [3733] = {.lex_state = 230},
  [3734] = {.lex_state = 228},
  [3735] = {.lex_state = 228},
  [3736] = {.lex_state = 240},
  [3737] = {.lex_state = 238},
  [3738] = {.lex_state = 240},
  [3739] = {.lex_state = 238},
  [3740] = {.lex_state = 240},
  [3741] = {.lex_state = 240},
  [3742] = {.lex_state = 228},
  [3743] = {.lex_state = 238},
  [3744] = {.lex_state = 228},
  [3745] = {.lex_state = 228},
  [3746] = {.lex_state = 238},
  [3747] = {.lex_state = 250},
  [3748] = {.lex_state = 228},
  [3749] = {.lex_state = 228},
  [3750] = {.lex_state = 238},
  [3751] = {.lex_state = 247},
  [3752] = {.lex_state = 238},
  [3753] = {.lex_state = 243},
  [3754] = {.lex_state = 228},
  [3755] = {.lex_state = 228},
  [3756] = {.lex_state = 251},
  [3757] = {.lex_state = 238},
  [3758] = {.lex_state = 240},
  [3759] = {.lex_state = 250},
  [3760] = {.lex_state = 251},
  [3761] = {.lex_state = 228},
  [3762] = {.lex_state = 238},
  [3763] = {.lex_state = 251},
  [3764] = {.lex_state = 240},
  [3765] = {.lex_state = 266},
  [3766] = {.lex_state = 243},
  [3767] = {.lex_state = 240},
  [3768] = {.lex_state = 228},
  [3769] = {.lex_state = 249},
  [3770] = {.lex_state = 266},
  [3771] = {.lex_state = 251},
  [3772] = {.lex_state = 238},
  [3773] = {.lex_state = 266},
  [3774] = {.lex_state = 238},
  [3775] = {.lex_state = 231},
  [3776] = {.lex_state = 238},
  [3777] = {.lex_state = 238},
  [3778] = {.lex_state = 243},
  [3779] = {.lex_state = 243},
  [3780] = {.lex_state = 243},
  [3781] = {.lex_state = 243},
  [3782] = {.lex_state = 225},
  [3783] = {.lex_state = 243},
  [3784] = {.lex_state = 259},
  [3785] = {.lex_state = 238},
  [3786] = {.lex_state = 243},
  [3787] = {.lex_state = 243},
  [3788] = {.lex_state = 284},
  [3789] = {.lex_state = 250},
  [3790] = {.lex_state = 264},
  [3791] = {.lex_state = 243},
  [3792] = {.lex_state = 243},
  [3793] = {.lex_state = 243},
  [3794] = {.lex_state = 227},
  [3795] = {.lex_state = 243},
  [3796] = {.lex_state = 243},
  [3797] = {.lex_state = 212},
  [3798] = {.lex_state = 262},
  [3799] = {.lex_state = 243},
  [3800] = {.lex_state = 288},
  [3801] = {.lex_state = 243},
  [3802] = {.lex_state = 243},
  [3803] = {.lex_state = 243},
  [3804] = {.lex_state = 243},
  [3805] = {.lex_state = 238},
  [3806] = {.lex_state = 243},
  [3807] = {.lex_state = 243},
  [3808] = {.lex_state = 288},
  [3809] = {.lex_state = 243},
  [3810] = {.lex_state = 243},
  [3811] = {.lex_state = 251},
  [3812] = {.lex_state = 243},
  [3813] = {.lex_state = 243},
  [3814] = {.lex_state = 243},
  [3815] = {.lex_state = 243},
  [3816] = {.lex_state = 243},
  [3817] = {.lex_state = 238},
  [3818] = {.lex_state = 238},
  [3819] = {.lex_state = 266},
  [3820] = {.lex_state = 238},
  [3821] = {.lex_state = 238},
  [3822] = {.lex_state = 238},
  [3823] = {.lex_state = 243},
  [3824] = {.lex_state = 243},
  [3825] = {.lex_state = 243},
  [3826] = {.lex_state = 238},
  [3827] = {.lex_state = 243},
  [3828] = {.lex_state = 243},
  [3829] = {.lex_state = 238},
  [3830] = {.lex_state = 227},
  [3831] = {.lex_state = 243},
  [3832] = {.lex_state = 250},
  [3833] = {.lex_state = 238},
  [3834] = {.lex_state = 243},
  [3835] = {.lex_state = 238},
  [3836] = {.lex_state = 238},
  [3837] = {.lex_state = 238},
  [3838] = {.lex_state = 260},
  [3839] = {.lex_state = 260},
  [3840] = {.lex_state = 260},
  [3841] = {.lex_state = 260},
  [3842] = {.lex_state = 243},
  [3843] = {.lex_state = 238},
  [3844] = {.lex_state = 238},
  [3845] = {.lex_state = 243},
  [3846] = {.lex_state = 260},
  [3847] = {.lex_state = 243},
  [3848] = {.lex_state = 243},
  [3849] = {.lex_state = 251},
  [3850] = {.lex_state = 243},
  [3851] = {.lex_state = 243},
  [3852] = {.lex_state = 255},
  [3853] = {.lex_state = 255},
  [3854] = {.lex_state = 255},
  [3855] = {.lex_state = 255},
  [3856] = {.lex_state = 243},
  [3857] = {.lex_state = 243},
  [3858] = {.lex_state = 243},
  [3859] = {.lex_state = 243},
  [3860] = {.lex_state = 243},
  [3861] = {.lex_state = 257},
  [3862] = {.lex_state = 243},
  [3863] = {.lex_state = 287},
  [3864] = {.lex_state = 243},
  [3865] = {.lex_state = 243},
  [3866] = {.lex_state = 243},
  [3867] = {.lex_state = 243},
  [3868] = {.lex_state = 243},
  [3869] = {.lex_state = 255},
  [3870] = {.lex_state = 243},
  [3871] = {.lex_state = 243},
  [3872] = {.lex_state = 238},
  [3873] = {.lex_state = 238},
  [3874] = {.lex_state = 243},
  [3875] = {.lex_state = 243},
  [3876] = {.lex_state = 255},
  [3877] = {.lex_state = 255},
  [3878] = {.lex_state = 243},
  [3879] = {.lex_state = 212},
  [3880] = {.lex_state = 243},
  [3881] = {.lex_state = 227},
  [3882] = {.lex_state = 243},
  [3883] = {.lex_state = 243},
  [3884] = {.lex_state = 243},
  [3885] = {.lex_state = 289},
  [3886] = {.lex_state = 243},
  [3887] = {.lex_state = 243},
  [3888] = {.lex_state = 243},
  [3889] = {.lex_state = 225},
  [3890] = {.lex_state = 287},
  [3891] = {.lex_state = 243},
  [3892] = {.lex_state = 284},
  [3893] = {.lex_state = 243},
  [3894] = {.lex_state = 243},
  [3895] = {.lex_state = 243},
  [3896] = {.lex_state = 243},
  [3897] = {.lex_state = 243},
  [3898] = {.lex_state = 243},
  [3899] = {.lex_state = 260},
  [3900] = {.lex_state = 260},
  [3901] = {.lex_state = 243},
  [3902] = {.lex_state = 243},
  [3903] = {.lex_state = 243},
  [3904] = {.lex_state = 243},
  [3905] = {.lex_state = 243},
  [3906] = {.lex_state = 288},
  [3907] = {.lex_state = 243},
  [3908] = {.lex_state = 231},
  [3909] = {.lex_state = 243},
  [3910] = {.lex_state = 243},
  [3911] = {.lex_state = 243},
  [3912] = {.lex_state = 243},
  [3913] = {.lex_state = 243},
  [3914] = {.lex_state = 243},
  [3915] = {.lex_state = 243},
  [3916] = {.lex_state = 287},
  [3917] = {.lex_state = 243},
  [3918] = {.lex_state = 243},
  [3919] = {.lex_state = 243},
  [3920] = {.lex_state = 255},
  [3921] = {.lex_state = 243},
  [3922] = {.lex_state = 243},
  [3923] = {.lex_state = 250},
  [3924] = {.lex_state = 287},
  [3925] = {.lex_state = 243},
  [3926] = {.lex_state = 243},
  [3927] = {.lex_state = 262},
  [3928] = {.lex_state = 243},
  [3929] = {.lex_state = 243},
  [3930] = {.lex_state = 243},
  [3931] = {.lex_state = 243},
  [3932] = {.lex_state = 243},
  [3933] = {.lex_state = 243},
  [3934] = {.lex_state = 243},
  [3935] = {.lex_state = 243},
  [3936] = {.lex_state = 260},
  [3937] = {.lex_state = 212},
  [3938] = {.lex_state = 238},
  [3939] = {.lex_state = 243},
  [3940] = {.lex_state = 212},
  [3941] = {.lex_state = 243},
  [3942] = {.lex_state = 243},
  [3943] = {.lex_state = 243},
  [3944] = {.lex_state = 243},
  [3945] = {.lex_state = 243},
  [3946] = {.lex_state = 243},
  [3947] = {.lex_state = 243},
  [3948] = {.lex_state = 243},
  [3949] = {.lex_state = 243},
  [3950] = {.lex_state = 251},
  [3951] = {.lex_state = 243},
  [3952] = {.lex_state = 243},
  [3953] = {.lex_state = 255},
  [3954] = {.lex_state = 238},
  [3955] = {.lex_state = 260},
  [3956] = {.lex_state = 243},
  [3957] = {.lex_state = 243},
  [3958] = {.lex_state = 225},
  [3959] = {.lex_state = 243},
  [3960] = {.lex_state = 238},
  [3961] = {.lex_state = 243},
  [3962] = {.lex_state = 243},
  [3963] = {.lex_state = 284},
  [3964] = {.lex_state = 255},
  [3965] = {.lex_state = 284},
  [3966] = {.lex_state = 243},
  [3967] = {.lex_state = 243},
  [3968] = {.lex_state = 243},
  [3969] = {.lex_state = 255},
  [3970] = {.lex_state = 260},
  [3971] = {.lex_state = 250},
  [3972] = {.lex_state = 255},
  [3973] = {.lex_state = 243},
  [3974] = {.lex_state = 243},
  [3975] = {.lex_state = 243},
  [3976] = {.lex_state = 243},
  [3977] = {.lex_state = 243},
  [3978] = {.lex_state = 255},
  [3979] = {.lex_state = 243},
  [3980] = {.lex_state = 260},
  [3981] = {.lex_state = 255},
  [3982] = {.lex_state = 260},
  [3983] = {.lex_state = 243},
  [3984] = {.lex_state = 243},
  [3985] = {.lex_state = 255},
  [3986] = {.lex_state = 212},
  [3987] = {.lex_state = 243},
  [3988] = {.lex_state = 243},
  [3989] = {.lex_state = 243},
  [3990] = {.lex_state = 243},
  [3991] = {.lex_state = 243},
  [3992] = {.lex_state = 243},
  [3993] = {.lex_state = 243},
  [3994] = {.lex_state = 243},
  [3995] = {.lex_state = 243},
  [3996] = {.lex_state = 243},
  [3997] = {.lex_state = 255},
  [3998] = {.lex_state = 288},
  [3999] = {.lex_state = 243},
  [4000] = {.lex_state = 260},
  [4001] = {.lex_state = 243},
  [4002] = {.lex_state = 257},
  [4003] = {.lex_state = 289},
  [4004] = {.lex_state = 243},
  [4005] = {.lex_state = 243},
  [4006] = {.lex_state = 243},
  [4007] = {.lex_state = 260},
  [4008] = {.lex_state = 243},
  [4009] = {.lex_state = 243},
  [4010] = {.lex_state = 243},
  [4011] = {.lex_state = 260},
  [4012] = {.lex_state = 260},
  [4013] = {.lex_state = 243},
  [4014] = {.lex_state = 243},
  [4015] = {.lex_state = 243},
  [4016] = {.lex_state = 231},
  [4017] = {.lex_state = 238},
  [4018] = {.lex_state = 238},
  [4019] = {.lex_state = 238},
  [4020] = {.lex_state = 238},
  [4021] = {.lex_state = 285},
  [4022] = {.lex_state = 238},
  [4023] = {.lex_state = 238},
  [4024] = {.lex_state = 285},
  [4025] = {.lex_state = 250},
  [4026] = {.lex_state = 250},
  [4027] = {.lex_state = 285},
  [4028] = {.lex_state = 251},
  [4029] = {.lex_state = 251},
  [4030] = {.lex_state = 238},
  [4031] = {.lex_state = 285},
  [4032] = {.lex_state = 250},
  [4033] = {.lex_state = 250},
  [4034] = {.lex_state = 212},
  [4035] = {.lex_state = 212},
  [4036] = {.lex_state = 251},
  [4037] = {.lex_state = 212},
  [4038] = {.lex_state = 250},
  [4039] = {.lex_state = 212},
  [4040] = {.lex_state = 250},
  [4041] = {.lex_state = 251},
  [4042] = {.lex_state = 250},
  [4043] = {.lex_state = 251},
  [4044] = {.lex_state = 243},
  [4045] = {.lex_state = 250},
  [4046] = {.lex_state = 251},
  [4047] = {.lex_state = 251},
  [4048] = {.lex_state = 251},
  [4049] = {.lex_state = 251},
  [4050] = {.lex_state = 250},
  [4051] = {.lex_state = 250},
  [4052] = {.lex_state = 250},
  [4053] = {.lex_state = 238},
  [4054] = {.lex_state = 250},
  [4055] = {.lex_state = 251},
  [4056] = {.lex_state = 251},
  [4057] = {.lex_state = 251},
  [4058] = {.lex_state = 251},
  [4059] = {.lex_state = 285},
  [4060] = {.lex_state = 251},
  [4061] = {.lex_state = 250},
  [4062] = {.lex_state = 250},
  [4063] = {.lex_state = 250},
  [4064] = {.lex_state = 250},
  [4065] = {.lex_state = 251},
  [4066] = {.lex_state = 251},
  [4067] = {.lex_state = 251},
  [4068] = {.lex_state = 251},
  [4069] = {.lex_state = 251},
  [4070] = {.lex_state = 251},
  [4071] = {.lex_state = 251},
  [4072] = {.lex_state = 251},
  [4073] = {.lex_state = 234},
  [4074] = {.lex_state = 251},
  [4075] = {.lex_state = 251},
  [4076] = {.lex_state = 250},
  [4077] = {.lex_state = 250},
  [4078] = {.lex_state = 250},
  [4079] = {.lex_state = 251},
  [4080] = {.lex_state = 251},
  [4081] = {.lex_state = 285},
  [4082] = {.lex_state = 250},
  [4083] = {.lex_state = 285},
  [4084] = {.lex_state = 285},
  [4085] = {.lex_state = 285},
  [4086] = {.lex_state = 234},
  [4087] = {.lex_state = 234},
  [4088] = {.lex_state = 234},
  [4089] = {.lex_state = 285},
  [4090] = {.lex_state = 251},
  [4091] = {.lex_state = 251},
  [4092] = {.lex_state = 250},
  [4093] = {.lex_state = 285},
  [4094] = {.lex_state = 234},
  [4095] = {.lex_state = 250},
  [4096] = {.lex_state = 250},
  [4097] = {.lex_state = 250},
  [4098] = {.lex_state = 234},
  [4099] = {.lex_state = 234},
  [4100] = {.lex_state = 251},
  [4101] = {.lex_state = 250},
  [4102] = {.lex_state = 285},
  [4103] = {.lex_state = 250},
  [4104] = {.lex_state = 250},
  [4105] = {.lex_state = 250},
  [4106] = {.lex_state = 251},
  [4107] = {.lex_state = 250},
  [4108] = {.lex_state = 250},
  [4109] = {.lex_state = 250},
  [4110] = {.lex_state = 250},
  [4111] = {.lex_state = 251},
  [4112] = {.lex_state = 251},
  [4113] = {.lex_state = 250},
  [4114] = {.lex_state = 250},
  [4115] = {.lex_state = 250},
  [4116] = {.lex_state = 250},
  [4117] = {.lex_state = 251},
  [4118] = {.lex_state = 251},
  [4119] = {.lex_state = 250},
  [4120] = {.lex_state = 251},
  [4121] = {.lex_state = 284},
  [4122] = {.lex_state = 285},
  [4123] = {.lex_state = 250},
  [4124] = {.lex_state = 251},
  [4125] = {.lex_state = 250},
  [4126] = {.lex_state = 251},
  [4127] = {.lex_state = 251},
  [4128] = {.lex_state = 285},
  [4129] = {.lex_state = 250},
  [4130] = {.lex_state = 250},
  [4131] = {.lex_state = 250},
  [4132] = {.lex_state = 251},
  [4133] = {.lex_state = 285},
  [4134] = {.lex_state = 285},
  [4135] = {.lex_state = 243},
  [4136] = {.lex_state = 285},
  [4137] = {.lex_state = 238},
  [4138] = {.lex_state = 238},
  [4139] = {.lex_state = 234},
  [4140] = {.lex_state = 251},
  [4141] = {.lex_state = 240},
  [4142] = {.lex_state = 238},
  [4143] = {.lex_state = 285},
  [4144] = {.lex_state = 285},
  [4145] = {.lex_state = 285},
  [4146] = {.lex_state = 251},
  [4147] = {.lex_state = 251},
  [4148] = {.lex_state = 251},
  [4149] = {.lex_state = 250},
  [4150] = {.lex_state = 251},
  [4151] = {.lex_state = 251},
  [4152] = {.lex_state = 250},
  [4153] = {.lex_state = 287},
  [4154] = {.lex_state = 287},
  [4155] = {.lex_state = 251},
  [4156] = {.lex_state = 250},
  [4157] = {.lex_state = 240},
  [4158] = {.lex_state = 250},
  [4159] = {.lex_state = 250},
  [4160] = {.lex_state = 240},
  [4161] = {.lex_state = 251},
  [4162] = {.lex_state = 250},
  [4163] = {.lex_state = 250},
  [4164] = {.lex_state = 285},
  [4165] = {.lex_state = 284},
  [4166] = {.lex_state = 251},
  [4167] = {.lex_state = 285},
  [4168] = {.lex_state = 285},
  [4169] = {.lex_state = 250},
  [4170] = {.lex_state = 285},
  [4171] = {.lex_state = 250},
  [4172] = {.lex_state = 250},
  [4173] = {.lex_state = 250},
  [4174] = {.lex_state = 250},
  [4175] = {.lex_state = 250},
  [4176] = {.lex_state = 250},
  [4177] = {.lex_state = 250},
  [4178] = {.lex_state = 250},
  [4179] = {.lex_state = 231},
  [4180] = {.lex_state = 250},
  [4181] = {.lex_state = 251},
  [4182] = {.lex_state = 251},
  [4183] = {.lex_state = 250},
  [4184] = {.lex_state = 251},
  [4185] = {.lex_state = 250},
  [4186] = {.lex_state = 250},
  [4187] = {.lex_state = 251},
  [4188] = {.lex_state = 250},
  [4189] = {.lex_state = 251},
  [4190] = {.lex_state = 250},
  [4191] = {.lex_state = 250},
  [4192] = {.lex_state = 251},
  [4193] = {.lex_state = 251},
  [4194] = {.lex_state = 251},
  [4195] = {.lex_state = 251},
  [4196] = {.lex_state = 251},
  [4197] = {.lex_state = 251},
  [4198] = {.lex_state = 251},
  [4199] = {.lex_state = 285},
  [4200] = {.lex_state = 251},
  [4201] = {.lex_state = 250},
  [4202] = {.lex_state = 251},
  [4203] = {.lex_state = 250},
  [4204] = {.lex_state = 284},
  [4205] = {.lex_state = 285},
  [4206] = {.lex_state = 251},
  [4207] = {.lex_state = 285},
  [4208] = {.lex_state = 251},
  [4209] = {.lex_state = 251},
  [4210] = {.lex_state = 285},
  [4211] = {.lex_state = 251},
  [4212] = {.lex_state = 231},
  [4213] = {.lex_state = 231},
  [4214] = {.lex_state = 250},
  [4215] = {.lex_state = 238},
  [4216] = {.lex_state = 285},
  [4217] = {.lex_state = 251},
  [4218] = {.lex_state = 250},
  [4219] = {.lex_state = 285},
  [4220] = {.lex_state = 284},
  [4221] = {.lex_state = 250},
  [4222] = {.lex_state = 250},
  [4223] = {.lex_state = 250},
  [4224] = {.lex_state = 250},
  [4225] = {.lex_state = 250},
  [4226] = {.lex_state = 285},
  [4227] = {.lex_state = 250},
  [4228] = {.lex_state = 284},
  [4229] = {.lex_state = 251},
  [4230] = {.lex_state = 251},
  [4231] = {.lex_state = 251},
  [4232] = {.lex_state = 251},
  [4233] = {.lex_state = 250},
  [4234] = {.lex_state = 284},
  [4235] = {.lex_state = 251},
  [4236] = {.lex_state = 250},
  [4237] = {.lex_state = 251},
  [4238] = {.lex_state = 251},
  [4239] = {.lex_state = 287},
  [4240] = {.lex_state = 251},
  [4241] = {.lex_state = 251},
  [4242] = {.lex_state = 250},
  [4243] = {.lex_state = 251},
  [4244] = {.lex_state = 250},
  [4245] = {.lex_state = 287},
  [4246] = {.lex_state = 251},
  [4247] = {.lex_state = 250},
  [4248] = {.lex_state = 251},
  [4249] = {.lex_state = 251},
  [4250] = {.lex_state = 250},
  [4251] = {.lex_state = 250},
  [4252] = {.lex_state = 250},
  [4253] = {.lex_state = 230},
  [4254] = {.lex_state = 285},
  [4255] = {.lex_state = 251},
  [4256] = {.lex_state = 251},
  [4257] = {.lex_state = 250},
  [4258] = {.lex_state = 251},
  [4259] = {.lex_state = 250},
  [4260] = {.lex_state = 251},
  [4261] = {.lex_state = 251},
  [4262] = {.lex_state = 231},
  [4263] = {.lex_state = 289},
  [4264] = {.lex_state = 212},
  [4265] = {.lex_state = 227},
  [4266] = {.lex_state = 240},
  [4267] = {.lex_state = 240},
  [4268] = {.lex_state = 247},
  [4269] = {.lex_state = 231},
  [4270] = {.lex_state = 288},
  [4271] = {.lex_state = 288},
  [4272] = {.lex_state = 212},
  [4273] = {.lex_state = 212},
  [4274] = {.lex_state = 225},
  [4275] = {.lex_state = 247},
  [4276] = {.lex_state = 291},
  [4277] = {.lex_state = 288},
  [4278] = {.lex_state = 238},
  [4279] = {.lex_state = 240},
  [4280] = {.lex_state = 291},
  [4281] = {.lex_state = 289},
  [4282] = {.lex_state = 240},
  [4283] = {.lex_state = 238},
  [4284] = {.lex_state = 284},
  [4285] = {.lex_state = 284},
  [4286] = {.lex_state = 240},
  [4287] = {.lex_state = 243},
  [4288] = {.lex_state = 238},
  [4289] = {.lex_state = 212},
  [4290] = {.lex_state = 240},
  [4291] = {.lex_state = 266},
  [4292] = {.lex_state = 240},
  [4293] = {.lex_state = 243},
  [4294] = {.lex_state = 266},
  [4295] = {.lex_state = 240},
  [4296] = {.lex_state = 240},
  [4297] = {.lex_state = 243},
  [4298] = {.lex_state = 266},
  [4299] = {.lex_state = 243},
  [4300] = {.lex_state = 240},
  [4301] = {.lex_state = 243},
  [4302] = {.lex_state = 240},
  [4303] = {.lex_state = 225},
  [4304] = {.lex_state = 287},
  [4305] = {.lex_state = 266},
  [4306] = {.lex_state = 243},
  [4307] = {.lex_state = 243},
  [4308] = {.lex_state = 266},
  [4309] = {.lex_state = 284},
  [4310] = {.lex_state = 243},
  [4311] = {.lex_state = 240},
  [4312] = {.lex_state = 243},
  [4313] = {.lex_state = 287},
  [4314] = {.lex_state = 225},
  [4315] = {.lex_state = 240},
  [4316] = {.lex_state = 243},
  [4317] = {.lex_state = 243},
  [4318] = {.lex_state = 240},
  [4319] = {.lex_state = 240},
  [4320] = {.lex_state = 243},
  [4321] = {.lex_state = 243},
  [4322] = {.lex_state = 243},
  [4323] = {.lex_state = 240},
  [4324] = {.lex_state = 243},
  [4325] = {.lex_state = 240},
  [4326] = {.lex_state = 243},
  [4327] = {.lex_state = 243},
  [4328] = {.lex_state = 243},
  [4329] = {.lex_state = 240},
  [4330] = {.lex_state = 238},
  [4331] = {.lex_state = 240},
  [4332] = {.lex_state = 240},
  [4333] = {.lex_state = 240},
  [4334] = {.lex_state = 243},
  [4335] = {.lex_state = 240},
  [4336] = {.lex_state = 284},
  [4337] = {.lex_state = 287},
  [4338] = {.lex_state = 243},
  [4339] = {.lex_state = 240},
  [4340] = {.lex_state = 243},
  [4341] = {.lex_state = 240},
  [4342] = {.lex_state = 243},
  [4343] = {.lex_state = 243},
  [4344] = {.lex_state = 291},
  [4345] = {.lex_state = 238},
  [4346] = {.lex_state = 243},
  [4347] = {.lex_state = 238},
  [4348] = {.lex_state = 225},
  [4349] = {.lex_state = 243},
  [4350] = {.lex_state = 243},
  [4351] = {.lex_state = 240},
  [4352] = {.lex_state = 284},
  [4353] = {.lex_state = 238},
  [4354] = {.lex_state = 243},
  [4355] = {.lex_state = 240},
  [4356] = {.lex_state = 284},
  [4357] = {.lex_state = 240},
  [4358] = {.lex_state = 240},
  [4359] = {.lex_state = 240},
  [4360] = {.lex_state = 240},
  [4361] = {.lex_state = 240},
  [4362] = {.lex_state = 238},
  [4363] = {.lex_state = 243},
  [4364] = {.lex_state = 288},
  [4365] = {.lex_state = 270},
  [4366] = {.lex_state = 225},
  [4367] = {.lex_state = 243},
  [4368] = {.lex_state = 288},
  [4369] = {.lex_state = 243},
  [4370] = {.lex_state = 227},
  [4371] = {.lex_state = 227},
  [4372] = {.lex_state = 243},
  [4373] = {.lex_state = 240},
  [4374] = {.lex_state = 243},
  [4375] = {.lex_state = 243},
  [4376] = {.lex_state = 287},
  [4377] = {.lex_state = 243},
  [4378] = {.lex_state = 240},
  [4379] = {.lex_state = 243},
  [4380] = {.lex_state = 240},
  [4381] = {.lex_state = 288},
  [4382] = {.lex_state = 243},
  [4383] = {.lex_state = 288},
  [4384] = {.lex_state = 288},
  [4385] = {.lex_state = 288},
  [4386] = {.lex_state = 240},
  [4387] = {.lex_state = 288},
  [4388] = {.lex_state = 243},
  [4389] = {.lex_state = 243},
  [4390] = {.lex_state = 243},
  [4391] = {.lex_state = 243},
  [4392] = {.lex_state = 288},
  [4393] = {.lex_state = 243},
  [4394] = {.lex_state = 243},
  [4395] = {.lex_state = 243},
  [4396] = {.lex_state = 240},
  [4397] = {.lex_state = 240},
  [4398] = {.lex_state = 243},
  [4399] = {.lex_state = 243},
  [4400] = {.lex_state = 243},
  [4401] = {.lex_state = 227},
  [4402] = {.lex_state = 266},
  [4403] = {.lex_state = 243},
  [4404] = {.lex_state = 266},
  [4405] = {.lex_state = 272},
  [4406] = {.lex_state = 240},
  [4407] = {.lex_state = 243},
  [4408] = {.lex_state = 240},
  [4409] = {.lex_state = 266},
  [4410] = {.lex_state = 243},
  [4411] = {.lex_state = 288},
  [4412] = {.lex_state = 288},
  [4413] = {.lex_state = 243},
  [4414] = {.lex_state = 243},
  [4415] = {.lex_state = 287},
  [4416] = {.lex_state = 243},
  [4417] = {.lex_state = 227},
  [4418] = {.lex_state = 243},
  [4419] = {.lex_state = 240},
  [4420] = {.lex_state = 240},
  [4421] = {.lex_state = 238},
  [4422] = {.lex_state = 269},
  [4423] = {.lex_state = 243},
  [4424] = {.lex_state = 243},
  [4425] = {.lex_state = 240},
  [4426] = {.lex_state = 243},
  [4427] = {.lex_state = 243},
  [4428] = {.lex_state = 243},
  [4429] = {.lex_state = 243},
  [4430] = {.lex_state = 238},
  [4431] = {.lex_state = 238},
  [4432] = {.lex_state = 227},
  [4433] = {.lex_state = 238},
  [4434] = {.lex_state = 288},
  [4435] = {.lex_state = 288},
  [4436] = {.lex_state = 238},
  [4437] = {.lex_state = 284},
  [4438] = {.lex_state = 238},
  [4439] = {.lex_state = 287},
  [4440] = {.lex_state = 287},
  [4441] = {.lex_state = 238},
  [4442] = {.lex_state = 284},
  [4443] = {.lex_state = 288},
  [4444] = {.lex_state = 238},
  [4445] = {.lex_state = 288},
  [4446] = {.lex_state = 288},
  [4447] = {.lex_state = 238},
  [4448] = {.lex_state = 239},
  [4449] = {.lex_state = 238},
  [4450] = {.lex_state = 238},
  [4451] = {.lex_state = 227},
  [4452] = {.lex_state = 238},
  [4453] = {.lex_state = 225},
  [4454] = {.lex_state = 288},
  [4455] = {.lex_state = 238},
  [4456] = {.lex_state = 266},
  [4457] = {.lex_state = 288},
  [4458] = {.lex_state = 288},
  [4459] = {.lex_state = 238},
  [4460] = {.lex_state = 238},
  [4461] = {.lex_state = 266},
  [4462] = {.lex_state = 287},
  [4463] = {.lex_state = 287},
  [4464] = {.lex_state = 288},
  [4465] = {.lex_state = 288},
  [4466] = {.lex_state = 238},
  [4467] = {.lex_state = 238},
  [4468] = {.lex_state = 225},
  [4469] = {.lex_state = 225},
  [4470] = {.lex_state = 238},
  [4471] = {.lex_state = 225},
  [4472] = {.lex_state = 238},
  [4473] = {.lex_state = 239},
  [4474] = {.lex_state = 288},
  [4475] = {.lex_state = 288},
  [4476] = {.lex_state = 288},
  [4477] = {.lex_state = 227},
  [4478] = {.lex_state = 288},
  [4479] = {.lex_state = 288},
  [4480] = {.lex_state = 227},
  [4481] = {.lex_state = 270},
  [4482] = {.lex_state = 270},
  [4483] = {.lex_state = 270},
  [4484] = {.lex_state = 291},
  [4485] = {.lex_state = 269},
  [4486] = {.lex_state = 270},
  [4487] = {.lex_state = 238},
  [4488] = {.lex_state = 291},
  [4489] = {.lex_state = 284},
  [4490] = {.lex_state = 270},
  [4491] = {.lex_state = 270},
  [4492] = {.lex_state = 270},
  [4493] = {.lex_state = 238},
  [4494] = {.lex_state = 284},
  [4495] = {.lex_state = 284},
  [4496] = {.lex_state = 238},
  [4497] = {.lex_state = 284},
  [4498] = {.lex_state = 240},
  [4499] = {.lex_state = 288},
  [4500] = {.lex_state = 270},
  [4501] = {.lex_state = 270},
  [4502] = {.lex_state = 270},
  [4503] = {.lex_state = 270},
  [4504] = {.lex_state = 240},
  [4505] = {.lex_state = 238},
  [4506] = {.lex_state = 287},
  [4507] = {.lex_state = 238},
  [4508] = {.lex_state = 287},
  [4509] = {.lex_state = 288},
  [4510] = {.lex_state = 288},
  [4511] = {.lex_state = 287},
  [4512] = {.lex_state = 238},
  [4513] = {.lex_state = 269},
  [4514] = {.lex_state = 287},
  [4515] = {.lex_state = 273},
  [4516] = {.lex_state = 269},
  [4517] = {.lex_state = 270},
  [4518] = {.lex_state = 270},
  [4519] = {.lex_state = 287},
  [4520] = {.lex_state = 284},
  [4521] = {.lex_state = 238},
  [4522] = {.lex_state = 273},
  [4523] = {.lex_state = 287},
  [4524] = {.lex_state = 288},
  [4525] = {.lex_state = 287},
  [4526] = {.lex_state = 240},
  [4527] = {.lex_state = 238},
  [4528] = {.lex_state = 238},
  [4529] = {.lex_state = 238},
  [4530] = {.lex_state = 287},
  [4531] = {.lex_state = 270},
  [4532] = {.lex_state = 240},
  [4533] = {.lex_state = 270},
  [4534] = {.lex_state = 240},
  [4535] = {.lex_state = 272},
  [4536] = {.lex_state = 288},
  [4537] = {.lex_state = 287},
  [4538] = {.lex_state = 238},
  [4539] = {.lex_state = 291},
  [4540] = {.lex_state = 288},
  [4541] = {.lex_state = 288},
  [4542] = {.lex_state = 291},
  [4543] = {.lex_state = 272},
  [4544] = {.lex_state = 270},
  [4545] = {.lex_state = 270},
  [4546] = {.lex_state = 271},
  [4547] = {.lex_state = 271},
  [4548] = {.lex_state = 287},
  [4549] = {.lex_state = 287},
  [4550] = {.lex_state = 287},
  [4551] = {.lex_state = 287},
  [4552] = {.lex_state = 288},
  [4553] = {.lex_state = 288},
  [4554] = {.lex_state = 287},
  [4555] = {.lex_state = 270},
  [4556] = {.lex_state = 270},
  [4557] = {.lex_state = 270},
  [4558] = {.lex_state = 238},
  [4559] = {.lex_state = 287},
  [4560] = {.lex_state = 238},
  [4561] = {.lex_state = 270},
  [4562] = {.lex_state = 288},
  [4563] = {.lex_state = 288},
  [4564] = {.lex_state = 240},
  [4565] = {.lex_state = 287},
  [4566] = {.lex_state = 270},
  [4567] = {.lex_state = 270},
  [4568] = {.lex_state = 270},
  [4569] = {.lex_state = 287},
  [4570] = {.lex_state = 284},
  [4571] = {.lex_state = 284},
  [4572] = {.lex_state = 238},
  [4573] = {.lex_state = 238},
  [4574] = {.lex_state = 238},
  [4575] = {.lex_state = 238},
  [4576] = {.lex_state = 238},
  [4577] = {.lex_state = 238},
  [4578] = {.lex_state = 287},
  [4579] = {.lex_state = 288},
  [4580] = {.lex_state = 288},
  [4581] = {.lex_state = 270},
  [4582] = {.lex_state = 270},
  [4583] = {.lex_state = 270},
  [4584] = {.lex_state = 238},
  [4585] = {.lex_state = 238},
  [4586] = {.lex_state = 287},
  [4587] = {.lex_state = 287},
  [4588] = {.lex_state = 287},
  [4589] = {.lex_state = 287},
  [4590] = {.lex_state = 287},
  [4591] = {.lex_state = 287},
  [4592] = {.lex_state = 287},
  [4593] = {.lex_state = 238},
  [4594] = {.lex_state = 238},
  [4595] = {.lex_state = 238},
  [4596] = {.lex_state = 238},
  [4597] = {.lex_state = 238},
  [4598] = {.lex_state = 238},
  [4599] = {.lex_state = 238},
  [4600] = {.lex_state = 287},
  [4601] = {.lex_state = 288},
  [4602] = {.lex_state = 238},
  [4603] = {.lex_state = 238},
  [4604] = {.lex_state = 266},
  [4605] = {.lex_state = 238},
  [4606] = {.lex_state = 266},
  [4607] = {.lex_state = 288},
  [4608] = {.lex_state = 238},
  [4609] = {.lex_state = 238},
  [4610] = {.lex_state = 238},
  [4611] = {.lex_state = 238},
  [4612] = {.lex_state = 238},
  [4613] = {.lex_state = 238},
  [4614] = {.lex_state = 238},
  [4615] = {.lex_state = 238},
  [4616] = {.lex_state = 238},
  [4617] = {.lex_state = 238},
  [4618] = {.lex_state = 238},
  [4619] = {.lex_state = 238},
  [4620] = {.lex_state = 238},
  [4621] = {.lex_state = 238},
  [4622] = {.lex_state = 238},
  [4623] = {.lex_state = 266},
  [4624] = {.lex_state = 238},
  [4625] = {.lex_state = 238},
  [4626] = {.lex_state = 238},
  [4627] = {.lex_state = 238},
  [4628] = {.lex_state = 238},
  [4629] = {.lex_state = 238},
  [4630] = {.lex_state = 238},
  [4631] = {.lex_state = 290},
  [4632] = {.lex_state = 238},
  [4633] = {.lex_state = 288},
  [4634] = {.lex_state = 270},
  [4635] = {.lex_state = 238},
  [4636] = {.lex_state = 238},
  [4637] = {.lex_state = 238},
  [4638] = {.lex_state = 238},
  [4639] = {.lex_state = 287},
  [4640] = {.lex_state = 287},
  [4641] = {.lex_state = 287},
  [4642] = {.lex_state = 240},
  [4643] = {.lex_state = 287},
  [4644] = {.lex_state = 287},
  [4645] = {.lex_state = 287},
  [4646] = {.lex_state = 288},
  [4647] = {.lex_state = 288},
  [4648] = {.lex_state = 238},
  [4649] = {.lex_state = 238},
  [4650] = {.lex_state = 287},
  [4651] = {.lex_state = 239},
  [4652] = {.lex_state = 238},
  [4653] = {.lex_state = 240},
  [4654] = {.lex_state = 287},
  [4655] = {.lex_state = 287},
  [4656] = {.lex_state = 287},
  [4657] = {.lex_state = 287},
  [4658] = {.lex_state = 287},
  [4659] = {.lex_state = 287},
  [4660] = {.lex_state = 287},
  [4661] = {.lex_state = 238},
  [4662] = {.lex_state = 238},
  [4663] = {.lex_state = 238},
  [4664] = {.lex_state = 238},
  [4665] = {.lex_state = 238},
  [4666] = {.lex_state = 287},
  [4667] = {.lex_state = 287},
  [4668] = {.lex_state = 240},
  [4669] = {.lex_state = 272},
  [4670] = {.lex_state = 287},
  [4671] = {.lex_state = 238},
  [4672] = {.lex_state = 287},
  [4673] = {.lex_state = 240},
  [4674] = {.lex_state = 266},
  [4675] = {.lex_state = 287},
  [4676] = {.lex_state = 238},
  [4677] = {.lex_state = 238},
  [4678] = {.lex_state = 238},
  [4679] = {.lex_state = 238},
  [4680] = {.lex_state = 287},
  [4681] = {.lex_state = 238},
  [4682] = {.lex_state = 287},
  [4683] = {.lex_state = 287},
  [4684] = {.lex_state = 288},
  [4685] = {.lex_state = 288},
  [4686] = {.lex_state = 288},
  [4687] = {.lex_state = 270},
  [4688] = {.lex_state = 290},
  [4689] = {.lex_state = 238},
  [4690] = {.lex_state = 238},
  [4691] = {.lex_state = 238},
  [4692] = {.lex_state = 270},
  [4693] = {.lex_state = 290},
  [4694] = {.lex_state = 287},
  [4695] = {.lex_state = 238},
  [4696] = {.lex_state = 287},
  [4697] = {.lex_state = 271},
  [4698] = {.lex_state = 238},
  [4699] = {.lex_state = 290},
  [4700] = {.lex_state = 240},
  [4701] = {.lex_state = 238},
  [4702] = {.lex_state = 238},
  [4703] = {.lex_state = 240},
  [4704] = {.lex_state = 238},
  [4705] = {.lex_state = 270},
  [4706] = {.lex_state = 288},
  [4707] = {.lex_state = 238},
  [4708] = {.lex_state = 288},
  [4709] = {.lex_state = 271},
  [4710] = {.lex_state = 240},
  [4711] = {.lex_state = 288},
  [4712] = {.lex_state = 288},
  [4713] = {.lex_state = 238},
  [4714] = {.lex_state = 287},
  [4715] = {.lex_state = 287},
  [4716] = {.lex_state = 238},
  [4717] = {.lex_state = 238},
  [4718] = {.lex_state = 238},
  [4719] = {.lex_state = 287},
  [4720] = {.lex_state = 240},
  [4721] = {.lex_state = 287},
  [4722] = {.lex_state = 238},
  [4723] = {.lex_state = 271},
  [4724] = {.lex_state = 270},
  [4725] = {.lex_state = 238},
  [4726] = {.lex_state = 240},
  [4727] = {.lex_state = 270},
  [4728] = {.lex_state = 287},
  [4729] = {.lex_state = 287},
  [4730] = {.lex_state = 288},
  [4731] = {.lex_state = 273},
  [4732] = {.lex_state = 238},
  [4733] = {.lex_state = 239},
  [4734] = {.lex_state = 287},
  [4735] = {.lex_state = 287},
  [4736] = {.lex_state = 288},
  [4737] = {.lex_state = 288},
  [4738] = {.lex_state = 288},
  [4739] = {.lex_state = 271},
  [4740] = {.lex_state = 288},
  [4741] = {.lex_state = 238},
  [4742] = {.lex_state = 288},
  [4743] = {.lex_state = 238},
  [4744] = {.lex_state = 270},
  [4745] = {.lex_state = 270},
  [4746] = {.lex_state = 270},
  [4747] = {.lex_state = 241},
  [4748] = {.lex_state = 285},
  [4749] = {.lex_state = 288},
  [4750] = {.lex_state = 285},
  [4751] = {.lex_state = 270},
  [4752] = {.lex_state = 285},
  [4753] = {.lex_state = 270},
  [4754] = {.lex_state = 288},
  [4755] = {.lex_state = 285},
  [4756] = {.lex_state = 288},
  [4757] = {.lex_state = 288},
  [4758] = {.lex_state = 240},
  [4759] = {.lex_state = 285},
  [4760] = {.lex_state = 288},
  [4761] = {.lex_state = 241},
  [4762] = {.lex_state = 288},
  [4763] = {.lex_state = 285},
  [4764] = {.lex_state = 288},
  [4765] = {.lex_state = 270},
  [4766] = {.lex_state = 285},
  [4767] = {.lex_state = 270},
  [4768] = {.lex_state = 288},
  [4769] = {.lex_state = 238},
  [4770] = {.lex_state = 240},
  [4771] = {.lex_state = 288},
  [4772] = {.lex_state = 285},
  [4773] = {.lex_state = 288},
  [4774] = {.lex_state = 285},
  [4775] = {.lex_state = 288},
  [4776] = {.lex_state = 285},
  [4777] = {.lex_state = 285},
  [4778] = {.lex_state = 288},
  [4779] = {.lex_state = 288},
  [4780] = {.lex_state = 288},
  [4781] = {.lex_state = 285},
  [4782] = {.lex_state = 285},
  [4783] = {.lex_state = 285},
  [4784] = {.lex_state = 285},
  [4785] = {.lex_state = 288},
  [4786] = {.lex_state = 285},
  [4787] = {.lex_state = 285},
  [4788] = {.lex_state = 287},
  [4789] = {.lex_state = 287},
  [4790] = {.lex_state = 287},
  [4791] = {.lex_state = 287},
  [4792] = {.lex_state = 287},
  [4793] = {.lex_state = 288},
  [4794] = {.lex_state = 288},
  [4795] = {.lex_state = 285},
  [4796] = {.lex_state = 285},
  [4797] = {.lex_state = 285},
  [4798] = {.lex_state = 285},
  [4799] = {.lex_state = 285},
  [4800] = {.lex_state = 270},
  [4801] = {.lex_state = 270},
  [4802] = {.lex_state = 270},
  [4803] = {.lex_state = 288},
  [4804] = {.lex_state = 285},
  [4805] = {.lex_state = 288},
  [4806] = {.lex_state = 285},
  [4807] = {.lex_state = 288},
  [4808] = {.lex_state = 288},
  [4809] = {.lex_state = 285},
  [4810] = {.lex_state = 287},
  [4811] = {.lex_state = 288},
  [4812] = {.lex_state = 288},
  [4813] = {.lex_state = 288},
  [4814] = {.lex_state = 288},
  [4815] = {.lex_state = 270},
  [4816] = {.lex_state = 288},
  [4817] = {.lex_state = 284},
  [4818] = {.lex_state = 284},
  [4819] = {.lex_state = 284},
  [4820] = {.lex_state = 288},
  [4821] = {.lex_state = 284},
  [4822] = {.lex_state = 288},
  [4823] = {.lex_state = 288},
  [4824] = {.lex_state = 288},
  [4825] = {.lex_state = 288},
  [4826] = {.lex_state = 288},
  [4827] = {.lex_state = 288},
  [4828] = {.lex_state = 270},
  [4829] = {.lex_state = 270},
  [4830] = {.lex_state = 288},
  [4831] = {.lex_state = 288},
  [4832] = {.lex_state = 288},
  [4833] = {.lex_state = 287},
  [4834] = {.lex_state = 285},
  [4835] = {.lex_state = 288},
  [4836] = {.lex_state = 288},
  [4837] = {.lex_state = 238},
  [4838] = {.lex_state = 238},
  [4839] = {.lex_state = 238},
  [4840] = {.lex_state = 238},
  [4841] = {.lex_state = 238},
  [4842] = {.lex_state = 238},
  [4843] = {.lex_state = 238},
  [4844] = {.lex_state = 238},
  [4845] = {.lex_state = 238},
  [4846] = {.lex_state = 238},
  [4847] = {.lex_state = 271},
  [4848] = {.lex_state = 238},
  [4849] = {.lex_state = 238},
  [4850] = {.lex_state = 238},
  [4851] = {.lex_state = 238},
  [4852] = {.lex_state = 270},
  [4853] = {.lex_state = 270},
  [4854] = {.lex_state = 241},
  [4855] = {.lex_state = 238},
  [4856] = {.lex_state = 238},
  [4857] = {.lex_state = 271},
  [4858] = {.lex_state = 271},
  [4859] = {.lex_state = 271},
  [4860] = {.lex_state = 238},
  [4861] = {.lex_state = 238},
  [4862] = {.lex_state = 287},
  [4863] = {.lex_state = 238},
  [4864] = {.lex_state = 238},
  [4865] = {.lex_state = 238},
  [4866] = {.lex_state = 238},
  [4867] = {.lex_state = 270},
  [4868] = {.lex_state = 271},
  [4869] = {.lex_state = 271},
  [4870] = {.lex_state = 238},
  [4871] = {.lex_state = 238},
  [4872] = {.lex_state = 271},
  [4873] = {.lex_state = 241},
  [4874] = {.lex_state = 238},
  [4875] = {.lex_state = 271},
  [4876] = {.lex_state = 271},
  [4877] = {.lex_state = 271},
  [4878] = {.lex_state = 238},
  [4879] = {.lex_state = 270},
  [4880] = {.lex_state = 271},
  [4881] = {.lex_state = 271},
  [4882] = {.lex_state = 238},
  [4883] = {.lex_state = 238},
  [4884] = {.lex_state = 270},
  [4885] = {.lex_state = 288},
  [4886] = {.lex_state = 238},
  [4887] = {.lex_state = 288},
  [4888] = {.lex_state = 288},
  [4889] = {.lex_state = 288},
  [4890] = {.lex_state = 238},
  [4891] = {.lex_state = 271},
  [4892] = {.lex_state = 287},
  [4893] = {.lex_state = 271},
  [4894] = {.lex_state = 271},
  [4895] = {.lex_state = 270},
  [4896] = {.lex_state = 271},
  [4897] = {.lex_state = 238},
  [4898] = {.lex_state = 238},
  [4899] = {.lex_state = 238},
  [4900] = {.lex_state = 238},
  [4901] = {.lex_state = 238},
  [4902] = {.lex_state = 238},
  [4903] = {.lex_state = 238},
  [4904] = {.lex_state = 271},
  [4905] = {.lex_state = 238},
  [4906] = {.lex_state = 238},
  [4907] = {.lex_state = 238},
  [4908] = {.lex_state = 238},
  [4909] = {.lex_state = 238},
  [4910] = {.lex_state = 271},
  [4911] = {.lex_state = 238},
  [4912] = {.lex_state = 287},
  [4913] = {.lex_state = 287},
  [4914] = {.lex_state = 287},
  [4915] = {.lex_state = 238},
  [4916] = {.lex_state = 238},
  [4917] = {.lex_state = 287},
  [4918] = {.lex_state = 287},
  [4919] = {.lex_state = 240},
  [4920] = {.lex_state = 271},
  [4921] = {.lex_state = 285},
  [4922] = {.lex_state = 238},
  [4923] = {.lex_state = 270},
  [4924] = {.lex_state = 240},
  [4925] = {.lex_state = 240},
  [4926] = {.lex_state = 240},
  [4927] = {.lex_state = 271},
  [4928] = {.lex_state = 287},
  [4929] = {.lex_state = 287},
  [4930] = {.lex_state = 240},
  [4931] = {.lex_state = 238},
  [4932] = {.lex_state = 271},
  [4933] = {.lex_state = 238},
  [4934] = {.lex_state = 266},
  [4935] = {.lex_state = 271},
  [4936] = {.lex_state = 271},
  [4937] = {.lex_state = 240},
  [4938] = {.lex_state = 266},
  [4939] = {.lex_state = 287},
  [4940] = {.lex_state = 271},
  [4941] = {.lex_state = 287},
  [4942] = {.lex_state = 238},
  [4943] = {.lex_state = 271},
  [4944] = {.lex_state = 270},
  [4945] = {.lex_state = 238},
  [4946] = {.lex_state = 238},
  [4947] = {.lex_state = 270},
  [4948] = {.lex_state = 240},
  [4949] = {.lex_state = 238},
  [4950] = {.lex_state = 238},
  [4951] = {.lex_state = 238},
  [4952] = {.lex_state = 238},
  [4953] = {.lex_state = 271},
  [4954] = {.lex_state = 238},
  [4955] = {.lex_state = 266},
  [4956] = {.lex_state = 271},
  [4957] = {.lex_state = 287},
  [4958] = {.lex_state = 266},
  [4959] = {.lex_state = 287},
  [4960] = {.lex_state = 238},
  [4961] = {.lex_state = 238},
  [4962] = {.lex_state = 271},
  [4963] = {.lex_state = 238},
  [4964] = {.lex_state = 271},
  [4965] = {.lex_state = 271},
  [4966] = {.lex_state = 238},
  [4967] = {.lex_state = 287},
  [4968] = {.lex_state = 238},
  [4969] = {.lex_state = 238},
  [4970] = {.lex_state = 284},
  [4971] = {.lex_state = 271},
  [4972] = {.lex_state = 271},
  [4973] = {.lex_state = 271},
  [4974] = {.lex_state = 287},
  [4975] = {.lex_state = 238},
  [4976] = {.lex_state = 240},
  [4977] = {.lex_state = 271},
  [4978] = {.lex_state = 271},
  [4979] = {.lex_state = 239},
  [4980] = {.lex_state = 287},
  [4981] = {.lex_state = 287},
  [4982] = {.lex_state = 238},
  [4983] = {.lex_state = 238},
  [4984] = {.lex_state = 285},
  [4985] = {.lex_state = 238},
  [4986] = {.lex_state = 271},
  [4987] = {.lex_state = 270},
  [4988] = {.lex_state = 238},
  [4989] = {.lex_state = 238},
  [4990] = {.lex_state = 238},
  [4991] = {.lex_state = 238},
  [4992] = {.lex_state = 238},
  [4993] = {.lex_state = 238},
  [4994] = {.lex_state = 238},
  [4995] = {.lex_state = 285},
  [4996] = {.lex_state = 266},
  [4997] = {.lex_state = 287},
  [4998] = {.lex_state = 266},
  [4999] = {.lex_state = 239},
  [5000] = {.lex_state = 238},
  [5001] = {.lex_state = 238},
  [5002] = {.lex_state = 287},
  [5003] = {.lex_state = 287},
  [5004] = {.lex_state = 238},
  [5005] = {.lex_state = 271},
  [5006] = {.lex_state = 238},
  [5007] = {.lex_state = 271},
  [5008] = {.lex_state = 270},
  [5009] = {.lex_state = 240},
  [5010] = {.lex_state = 270},
  [5011] = {.lex_state = 287},
  [5012] = {.lex_state = 287},
  [5013] = {.lex_state = 270},
  [5014] = {.lex_state = 271},
  [5015] = {.lex_state = 270},
  [5016] = {.lex_state = 240},
  [5017] = {.lex_state = 270},
  [5018] = {.lex_state = 287},
  [5019] = {.lex_state = 238},
  [5020] = {.lex_state = 240},
  [5021] = {.lex_state = 271},
  [5022] = {.lex_state = 238},
  [5023] = {.lex_state = 287},
  [5024] = {.lex_state = 270},
  [5025] = {.lex_state = 287},
  [5026] = {.lex_state = 238},
  [5027] = {.lex_state = 270},
  [5028] = {.lex_state = 241},
  [5029] = {.lex_state = 270},
  [5030] = {.lex_state = 270},
  [5031] = {.lex_state = 238},
  [5032] = {.lex_state = 270},
  [5033] = {.lex_state = 270},
  [5034] = {.lex_state = 270},
  [5035] = {.lex_state = 270},
  [5036] = {.lex_state = 287},
  [5037] = {.lex_state = 270},
  [5038] = {.lex_state = 287},
  [5039] = {.lex_state = 270},
  [5040] = {.lex_state = 287},
  [5041] = {.lex_state = 238},
  [5042] = {.lex_state = 238},
  [5043] = {.lex_state = 287},
  [5044] = {.lex_state = 240},
  [5045] = {.lex_state = 270},
  [5046] = {.lex_state = 238},
  [5047] = {.lex_state = 240},
  [5048] = {.lex_state = 240},
  [5049] = {.lex_state = 240},
  [5050] = {.lex_state = 271},
  [5051] = {.lex_state = 240},
  [5052] = {.lex_state = 240},
  [5053] = {.lex_state = 238},
  [5054] = {.lex_state = 271},
  [5055] = {.lex_state = 287},
  [5056] = {.lex_state = 238},
  [5057] = {.lex_state = 287},
  [5058] = {.lex_state = 238},
  [5059] = {.lex_state = 287},
  [5060] = {.lex_state = 287},
  [5061] = {.lex_state = 240},
  [5062] = {.lex_state = 287},
  [5063] = {.lex_state = 270},
  [5064] = {.lex_state = 238},
  [5065] = {.lex_state = 270},
  [5066] = {.lex_state = 238},
  [5067] = {.lex_state = 270},
  [5068] = {.lex_state = 238},
  [5069] = {.lex_state = 240},
  [5070] = {.lex_state = 287},
  [5071] = {.lex_state = 238},
  [5072] = {.lex_state = 270},
  [5073] = {.lex_state = 287},
  [5074] = {.lex_state = 287},
  [5075] = {.lex_state = 271},
  [5076] = {.lex_state = 287},
  [5077] = {.lex_state = 287},
  [5078] = {.lex_state = 270},
  [5079] = {.lex_state = 240},
  [5080] = {.lex_state = 270},
  [5081] = {.lex_state = 287},
  [5082] = {.lex_state = 270},
  [5083] = {.lex_state = 238},
  [5084] = {.lex_state = 287},
  [5085] = {.lex_state = 240},
  [5086] = {.lex_state = 287},
  [5087] = {.lex_state = 240},
  [5088] = {.lex_state = 287},
  [5089] = {.lex_state = 271},
  [5090] = {.lex_state = 287},
  [5091] = {.lex_state = 238},
  [5092] = {.lex_state = 238},
  [5093] = {.lex_state = 240},
  [5094] = {.lex_state = 287},
  [5095] = {.lex_state = 238},
  [5096] = {.lex_state = 271},
  [5097] = {.lex_state = 240},
  [5098] = {.lex_state = 238},
  [5099] = {.lex_state = 270},
  [5100] = {.lex_state = 270},
  [5101] = {.lex_state = 270},
  [5102] = {.lex_state = 270},
  [5103] = {.lex_state = 270},
  [5104] = {.lex_state = 271},
  [5105] = {.lex_state = 270},
  [5106] = {.lex_state = 270},
  [5107] = {.lex_state = 270},
  [5108] = {.lex_state = 270},
  [5109] = {.lex_state = 287},
  [5110] = {.lex_state = 238},
  [5111] = {.lex_state = 238},
  [5112] = {.lex_state = 240},
  [5113] = {.lex_state = 270},
  [5114] = {.lex_state = 238},
  [5115] = {.lex_state = 270},
  [5116] = {.lex_state = 270},
  [5117] = {.lex_state = 271},
  [5118] = {.lex_state = 270},
  [5119] = {.lex_state = 238},
  [5120] = {.lex_state = 238},
  [5121] = {.lex_state = 238},
  [5122] = {.lex_state = 238},
  [5123] = {.lex_state = 270},
  [5124] = {.lex_state = 270},
  [5125] = {.lex_state = 238},
  [5126] = {.lex_state = 238},
  [5127] = {.lex_state = 270},
  [5128] = {.lex_state = 238},
  [5129] = {.lex_state = 238},
  [5130] = {.lex_state = 287},
  [5131] = {.lex_state = 271},
  [5132] = {.lex_state = 238},
  [5133] = {.lex_state = 271},
  [5134] = {.lex_state = 271},
  [5135] = {.lex_state = 271},
  [5136] = {.lex_state = 271},
  [5137] = {.lex_state = 238},
  [5138] = {.lex_state = 271},
  [5139] = {.lex_state = 271},
  [5140] = {.lex_state = 271},
  [5141] = {.lex_state = 271},
  [5142] = {.lex_state = 271},
  [5143] = {.lex_state = 238},
  [5144] = {.lex_state = 271},
  [5145] = {.lex_state = 271},
  [5146] = {.lex_state = 271},
  [5147] = {.lex_state = 238},
  [5148] = {.lex_state = 287},
  [5149] = {.lex_state = 270},
  [5150] = {.lex_state = 287},
  [5151] = {.lex_state = 238},
  [5152] = {.lex_state = 270},
  [5153] = {.lex_state = 287},
  [5154] = {.lex_state = 238},
  [5155] = {.lex_state = 240},
  [5156] = {.lex_state = 270},
  [5157] = {.lex_state = 287},
  [5158] = {.lex_state = 287},
  [5159] = {.lex_state = 240},
  [5160] = {.lex_state = 271},
  [5161] = {.lex_state = 271},
  [5162] = {.lex_state = 238},
  [5163] = {.lex_state = 271},
  [5164] = {.lex_state = 271},
  [5165] = {.lex_state = 238},
  [5166] = {.lex_state = 270},
  [5167] = {.lex_state = 270},
  [5168] = {.lex_state = 238},
  [5169] = {.lex_state = 271},
  [5170] = {.lex_state = 287},
  [5171] = {.lex_state = 270},
  [5172] = {.lex_state = 270},
  [5173] = {.lex_state = 271},
  [5174] = {.lex_state = 270},
  [5175] = {.lex_state = 238},
  [5176] = {.lex_state = 238},
  [5177] = {.lex_state = 238},
  [5178] = {.lex_state = 270},
  [5179] = {.lex_state = 238},
  [5180] = {.lex_state = 238},
  [5181] = {.lex_state = 238},
  [5182] = {.lex_state = 238},
  [5183] = {.lex_state = 238},
  [5184] = {.lex_state = 238},
  [5185] = {.lex_state = 238},
  [5186] = {.lex_state = 238},
  [5187] = {.lex_state = 238},
  [5188] = {.lex_state = 270},
  [5189] = {.lex_state = 238},
  [5190] = {.lex_state = 238},
  [5191] = {.lex_state = 238},
  [5192] = {.lex_state = 238},
  [5193] = {.lex_state = 238},
  [5194] = {.lex_state = 287},
  [5195] = {.lex_state = 287},
  [5196] = {.lex_state = 238},
  [5197] = {.lex_state = 271},
  [5198] = {.lex_state = 270},
  [5199] = {.lex_state = 238},
  [5200] = {.lex_state = 238},
  [5201] = {.lex_state = 238},
  [5202] = {.lex_state = 287},
  [5203] = {.lex_state = 238},
  [5204] = {.lex_state = 287},
  [5205] = {.lex_state = 238},
  [5206] = {.lex_state = 287},
  [5207] = {.lex_state = 270},
  [5208] = {.lex_state = 270},
  [5209] = {.lex_state = 271},
  [5210] = {.lex_state = 271},
  [5211] = {.lex_state = 270},
  [5212] = {.lex_state = 287},
  [5213] = {.lex_state = 238},
  [5214] = {.lex_state = 270},
  [5215] = {.lex_state = 287},
  [5216] = {.lex_state = 240},
  [5217] = {.lex_state = 270},
  [5218] = {.lex_state = 238},
  [5219] = {.lex_state = 287},
  [5220] = {.lex_state = 270},
  [5221] = {.lex_state = 238},
  [5222] = {.lex_state = 240},
  [5223] = {.lex_state = 240},
  [5224] = {.lex_state = 240},
  [5225] = {.lex_state = 240},
  [5226] = {.lex_state = 270},
  [5227] = {.lex_state = 238},
  [5228] = {.lex_state = 287},
  [5229] = {.lex_state = 240},
  [5230] = {.lex_state = 240},
  [5231] = {.lex_state = 241},
  [5232] = {.lex_state = 287},
  [5233] = {.lex_state = 271},
  [5234] = {.lex_state = 270},
  [5235] = {.lex_state = 270},
  [5236] = {.lex_state = 270},
  [5237] = {.lex_state = 240},
  [5238] = {.lex_state = 238},
  [5239] = {.lex_state = 270},
  [5240] = {.lex_state = 240},
  [5241] = {.lex_state = 240},
  [5242] = {.lex_state = 240},
  [5243] = {.lex_state = 240},
  [5244] = {.lex_state = 240},
  [5245] = {.lex_state = 240},
  [5246] = {.lex_state = 240},
  [5247] = {.lex_state = 240},
  [5248] = {.lex_state = 240},
  [5249] = {.lex_state = 270},
  [5250] = {.lex_state = 240},
  [5251] = {.lex_state = 240},
  [5252] = {.lex_state = 240},
  [5253] = {.lex_state = 240},
  [5254] = {.lex_state = 238},
  [5255] = {.lex_state = 238},
  [5256] = {.lex_state = 285},
  [5257] = {.lex_state = 238},
  [5258] = {.lex_state = 238},
  [5259] = {.lex_state = 270},
  [5260] = {.lex_state = 238},
  [5261] = {.lex_state = 238},
  [5262] = {.lex_state = 240},
  [5263] = {.lex_state = 238},
  [5264] = {.lex_state = 238},
  [5265] = {.lex_state = 238},
  [5266] = {.lex_state = 238},
  [5267] = {.lex_state = 240},
  [5268] = {.lex_state = 238},
  [5269] = {.lex_state = 238},
  [5270] = {.lex_state = 238},
  [5271] = {.lex_state = 238},
  [5272] = {.lex_state = 238},
  [5273] = {.lex_state = 238},
  [5274] = {.lex_state = 238},
  [5275] = {.lex_state = 238},
  [5276] = {.lex_state = 238},
  [5277] = {.lex_state = 238},
  [5278] = {.lex_state = 238},
  [5279] = {.lex_state = 238},
  [5280] = {.lex_state = 238},
  [5281] = {.lex_state = 238},
  [5282] = {.lex_state = 240},
  [5283] = {.lex_state = 238},
  [5284] = {.lex_state = 238},
  [5285] = {.lex_state = 269},
  [5286] = {.lex_state = 238},
  [5287] = {.lex_state = 238},
  [5288] = {.lex_state = 238},
  [5289] = {.lex_state = 238},
  [5290] = {.lex_state = 238},
  [5291] = {.lex_state = 238},
  [5292] = {.lex_state = 238},
  [5293] = {.lex_state = 288},
  [5294] = {.lex_state = 238},
  [5295] = {.lex_state = 288},
  [5296] = {.lex_state = 238},
  [5297] = {.lex_state = 238},
  [5298] = {.lex_state = 238},
  [5299] = {.lex_state = 238},
  [5300] = {.lex_state = 240},
  [5301] = {.lex_state = 238},
  [5302] = {.lex_state = 238},
  [5303] = {.lex_state = 238},
  [5304] = {.lex_state = 270},
  [5305] = {.lex_state = 238},
  [5306] = {.lex_state = 238},
  [5307] = {.lex_state = 238},
  [5308] = {.lex_state = 238},
  [5309] = {.lex_state = 238},
  [5310] = {.lex_state = 238},
  [5311] = {.lex_state = 238},
  [5312] = {.lex_state = 238},
  [5313] = {.lex_state = 238},
  [5314] = {.lex_state = 238},
  [5315] = {.lex_state = 238},
  [5316] = {.lex_state = 238},
  [5317] = {.lex_state = 238},
  [5318] = {.lex_state = 266},
  [5319] = {.lex_state = 238},
  [5320] = {.lex_state = 238},
  [5321] = {.lex_state = 238},
  [5322] = {.lex_state = 238},
  [5323] = {.lex_state = 238},
  [5324] = {.lex_state = 238},
  [5325] = {.lex_state = 238},
  [5326] = {.lex_state = 238},
  [5327] = {.lex_state = 238},
  [5328] = {.lex_state = 238},
  [5329] = {.lex_state = 238},
  [5330] = {.lex_state = 238},
  [5331] = {.lex_state = 238},
  [5332] = {.lex_state = 238},
  [5333] = {.lex_state = 238},
  [5334] = {.lex_state = 238},
  [5335] = {.lex_state = 238},
  [5336] = {.lex_state = 238},
  [5337] = {.lex_state = 287},
  [5338] = {.lex_state = 238},
  [5339] = {.lex_state = 238},
  [5340] = {.lex_state = 271},
  [5341] = {.lex_state = 238},
  [5342] = {.lex_state = 238},
  [5343] = {.lex_state = 240},
  [5344] = {.lex_state = 238},
  [5345] = {.lex_state = 238},
  [5346] = {.lex_state = 265},
  [5347] = {.lex_state = 238},
  [5348] = {.lex_state = 238},
  [5349] = {.lex_state = 238},
  [5350] = {.lex_state = 238},
  [5351] = {.lex_state = 238},
  [5352] = {.lex_state = 238},
  [5353] = {.lex_state = 238},
  [5354] = {.lex_state = 238},
  [5355] = {.lex_state = 238},
  [5356] = {.lex_state = 238},
  [5357] = {.lex_state = 238},
  [5358] = {.lex_state = 238},
  [5359] = {.lex_state = 238},
  [5360] = {.lex_state = 238},
  [5361] = {.lex_state = 238},
  [5362] = {.lex_state = 238},
  [5363] = {.lex_state = 238},
  [5364] = {.lex_state = 238},
  [5365] = {.lex_state = 238},
  [5366] = {.lex_state = 238},
  [5367] = {.lex_state = 238},
  [5368] = {.lex_state = 238},
  [5369] = {.lex_state = 238},
  [5370] = {.lex_state = 238},
  [5371] = {.lex_state = 238},
  [5372] = {.lex_state = 238},
  [5373] = {.lex_state = 238},
  [5374] = {.lex_state = 238},
  [5375] = {.lex_state = 238},
  [5376] = {.lex_state = 238},
  [5377] = {.lex_state = 238},
  [5378] = {.lex_state = 238},
  [5379] = {.lex_state = 238},
  [5380] = {.lex_state = 238},
  [5381] = {.lex_state = 238},
  [5382] = {.lex_state = 238},
  [5383] = {.lex_state = 285},
  [5384] = {.lex_state = 238},
  [5385] = {.lex_state = 238},
  [5386] = {.lex_state = 238},
  [5387] = {.lex_state = 285},
  [5388] = {.lex_state = 240},
  [5389] = {.lex_state = 285},
  [5390] = {.lex_state = 285},
  [5391] = {.lex_state = 240},
  [5392] = {.lex_state = 285},
  [5393] = {.lex_state = 285},
  [5394] = {.lex_state = 238},
  [5395] = {.lex_state = 271},
  [5396] = {.lex_state = 285},
  [5397] = {.lex_state = 285},
  [5398] = {.lex_state = 285},
  [5399] = {.lex_state = 270},
  [5400] = {.lex_state = 277},
  [5401] = {.lex_state = 274},
  [5402] = {.lex_state = 285},
  [5403] = {.lex_state = 238},
  [5404] = {.lex_state = 285},
  [5405] = {.lex_state = 285},
  [5406] = {.lex_state = 285},
  [5407] = {.lex_state = 285},
  [5408] = {.lex_state = 240},
  [5409] = {.lex_state = 285},
  [5410] = {.lex_state = 285},
  [5411] = {.lex_state = 285},
  [5412] = {.lex_state = 240},
  [5413] = {.lex_state = 240},
  [5414] = {.lex_state = 277},
  [5415] = {.lex_state = 274},
  [5416] = {.lex_state = 285},
  [5417] = {.lex_state = 285},
  [5418] = {.lex_state = 271},
  [5419] = {.lex_state = 271},
  [5420] = {.lex_state = 271},
  [5421] = {.lex_state = 271},
  [5422] = {.lex_state = 271},
  [5423] = {.lex_state = 270},
  [5424] = {.lex_state = 270},
  [5425] = {.lex_state = 270},
  [5426] = {.lex_state = 270},
  [5427] = {.lex_state = 270},
  [5428] = {.lex_state = 270},
  [5429] = {.lex_state = 270},
  [5430] = {.lex_state = 270},
  [5431] = {.lex_state = 271},
  [5432] = {.lex_state = 270},
  [5433] = {.lex_state = 270},
  [5434] = {.lex_state = 270},
  [5435] = {.lex_state = 270},
  [5436] = {.lex_state = 270},
  [5437] = {.lex_state = 270},
  [5438] = {.lex_state = 288},
  [5439] = {.lex_state = 271},
  [5440] = {.lex_state = 271},
  [5441] = {.lex_state = 270},
  [5442] = {.lex_state = 270},
  [5443] = {.lex_state = 270},
  [5444] = {.lex_state = 238},
  [5445] = {.lex_state = 271},
  [5446] = {.lex_state = 270},
  [5447] = {.lex_state = 271},
  [5448] = {.lex_state = 271},
  [5449] = {.lex_state = 270},
  [5450] = {.lex_state = 271},
  [5451] = {.lex_state = 271},
  [5452] = {.lex_state = 271},
  [5453] = {.lex_state = 271},
  [5454] = {.lex_state = 271},
  [5455] = {.lex_state = 238},
  [5456] = {.lex_state = 271},
  [5457] = {.lex_state = 271},
  [5458] = {.lex_state = 270},
  [5459] = {.lex_state = 270},
  [5460] = {.lex_state = 270},
  [5461] = {.lex_state = 270},
  [5462] = {.lex_state = 271},
  [5463] = {.lex_state = 238},
  [5464] = {.lex_state = 270},
  [5465] = {.lex_state = 270},
  [5466] = {.lex_state = 238},
  [5467] = {.lex_state = 270},
  [5468] = {.lex_state = 238},
  [5469] = {.lex_state = 238},
  [5470] = {.lex_state = 270},
  [5471] = {.lex_state = 270},
  [5472] = {.lex_state = 238},
  [5473] = {.lex_state = 270},
  [5474] = {.lex_state = 270},
  [5475] = {.lex_state = 270},
  [5476] = {.lex_state = 270},
  [5477] = {.lex_state = 271},
  [5478] = {.lex_state = 270},
  [5479] = {.lex_state = 270},
  [5480] = {.lex_state = 271},
  [5481] = {.lex_state = 271},
  [5482] = {.lex_state = 238},
  [5483] = {.lex_state = 238},
  [5484] = {.lex_state = 271},
  [5485] = {.lex_state = 266},
  [5486] = {.lex_state = 271},
  [5487] = {.lex_state = 270},
  [5488] = {.lex_state = 270},
  [5489] = {.lex_state = 270},
  [5490] = {.lex_state = 270},
  [5491] = {.lex_state = 270},
  [5492] = {.lex_state = 285},
  [5493] = {.lex_state = 285},
  [5494] = {.lex_state = 285},
  [5495] = {.lex_state = 285},
  [5496] = {.lex_state = 285},
  [5497] = {.lex_state = 285},
  [5498] = {.lex_state = 285},
  [5499] = {.lex_state = 271},
  [5500] = {.lex_state = 285},
  [5501] = {.lex_state = 285},
  [5502] = {.lex_state = 285},
  [5503] = {.lex_state = 285},
  [5504] = {.lex_state = 285},
  [5505] = {.lex_state = 271},
  [5506] = {.lex_state = 271},
  [5507] = {.lex_state = 271},
  [5508] = {.lex_state = 271},
  [5509] = {.lex_state = 271},
  [5510] = {.lex_state = 271},
  [5511] = {.lex_state = 270},
  [5512] = {.lex_state = 271},
  [5513] = {.lex_state = 270},
  [5514] = {.lex_state = 270},
  [5515] = {.lex_state = 271},
  [5516] = {.lex_state = 271},
  [5517] = {.lex_state = 270},
  [5518] = {.lex_state = 271},
  [5519] = {.lex_state = 271},
  [5520] = {.lex_state = 238},
  [5521] = {.lex_state = 270},
  [5522] = {.lex_state = 270},
  [5523] = {.lex_state = 270},
  [5524] = {.lex_state = 288},
  [5525] = {.lex_state = 270},
  [5526] = {.lex_state = 270},
  [5527] = {.lex_state = 241},
  [5528] = {.lex_state = 271},
  [5529] = {.lex_state = 270},
  [5530] = {.lex_state = 271},
  [5531] = {.lex_state = 271},
  [5532] = {.lex_state = 270},
  [5533] = {.lex_state = 238},
  [5534] = {.lex_state = 270},
  [5535] = {.lex_state = 270},
  [5536] = {.lex_state = 270},
  [5537] = {.lex_state = 271},
  [5538] = {.lex_state = 270},
  [5539] = {.lex_state = 271},
  [5540] = {.lex_state = 270},
  [5541] = {.lex_state = 270},
  [5542] = {.lex_state = 270},
  [5543] = {.lex_state = 270},
  [5544] = {.lex_state = 288},
  [5545] = {.lex_state = 238},
  [5546] = {.lex_state = 238},
  [5547] = {.lex_state = 284},
  [5548] = {.lex_state = 238},
  [5549] = {.lex_state = 238},
  [5550] = {.lex_state = 238},
  [5551] = {.lex_state = 238},
  [5552] = {.lex_state = 284},
  [5553] = {.lex_state = 288},
  [5554] = {.lex_state = 238},
  [5555] = {.lex_state = 238},
  [5556] = {.lex_state = 288},
  [5557] = {.lex_state = 238},
  [5558] = {.lex_state = 288},
  [5559] = {.lex_state = 266},
  [5560] = {.lex_state = 284},
  [5561] = {.lex_state = 266},
  [5562] = {.lex_state = 284},
  [5563] = {.lex_state = 240},
  [5564] = {.lex_state = 284},
  [5565] = {.lex_state = 285},
  [5566] = {.lex_state = 240},
  [5567] = {.lex_state = 284},
  [5568] = {.lex_state = 284},
  [5569] = {.lex_state = 285},
  [5570] = {.lex_state = 284},
  [5571] = {.lex_state = 266},
  [5572] = {.lex_state = 285},
  [5573] = {.lex_state = 266},
  [5574] = {.lex_state = 285},
  [5575] = {.lex_state = 284},
  [5576] = {.lex_state = 287},
  [5577] = {.lex_state = 285},
  [5578] = {.lex_state = 288},
  [5579] = {.lex_state = 288},
  [5580] = {.lex_state = 284},
  [5581] = {.lex_state = 288},
  [5582] = {.lex_state = 288},
  [5583] = {.lex_state = 284},
  [5584] = {.lex_state = 288},
  [5585] = {.lex_state = 284},
  [5586] = {.lex_state = 284},
  [5587] = {.lex_state = 288},
  [5588] = {.lex_state = 288},
  [5589] = {.lex_state = 284},
  [5590] = {.lex_state = 266},
  [5591] = {.lex_state = 284},
  [5592] = {.lex_state = 284},
  [5593] = {.lex_state = 284},
  [5594] = {.lex_state = 288},
  [5595] = {.lex_state = 288},
  [5596] = {.lex_state = 288},
  [5597] = {.lex_state = 288},
  [5598] = {.lex_state = 288},
  [5599] = {.lex_state = 266},
  [5600] = {.lex_state = 284},
  [5601] = {.lex_state = 287},
  [5602] = {.lex_state = 284},
  [5603] = {.lex_state = 284},
  [5604] = {.lex_state = 230},
  [5605] = {.lex_state = 284},
  [5606] = {.lex_state = 284},
  [5607] = {.lex_state = 285},
  [5608] = {.lex_state = 285},
  [5609] = {.lex_state = 285},
  [5610] = {.lex_state = 285},
  [5611] = {.lex_state = 285},
  [5612] = {.lex_state = 284},
  [5613] = {.lex_state = 285},
  [5614] = {.lex_state = 230},
  [5615] = {.lex_state = 230},
  [5616] = {.lex_state = 288},
  [5617] = {.lex_state = 285},
  [5618] = {.lex_state = 230},
  [5619] = {.lex_state = 230},
  [5620] = {.lex_state = 285},
  [5621] = {.lex_state = 285},
  [5622] = {.lex_state = 285},
  [5623] = {.lex_state = 285},
  [5624] = {.lex_state = 284},
  [5625] = {.lex_state = 285},
  [5626] = {.lex_state = 285},
  [5627] = {.lex_state = 285},
  [5628] = {.lex_state = 285},
  [5629] = {.lex_state = 285},
  [5630] = {.lex_state = 230},
  [5631] = {.lex_state = 230},
  [5632] = {.lex_state = 285},
  [5633] = {.lex_state = 285},
  [5634] = {.lex_state = 284},
  [5635] = {.lex_state = 284},
  [5636] = {.lex_state = 285},
  [5637] = {.lex_state = 284},
  [5638] = {.lex_state = 288},
  [5639] = {.lex_state = 230},
  [5640] = {.lex_state = 284},
  [5641] = {.lex_state = 288},
  [5642] = {.lex_state = 288},
  [5643] = {.lex_state = 285},
  [5644] = {.lex_state = 284},
  [5645] = {.lex_state = 285},
  [5646] = {.lex_state = 285},
  [5647] = {.lex_state = 284},
  [5648] = {.lex_state = 284},
  [5649] = {.lex_state = 230},
  [5650] = {.lex_state = 230},
  [5651] = {.lex_state = 230},
  [5652] = {.lex_state = 230},
  [5653] = {.lex_state = 230},
  [5654] = {.lex_state = 230},
  [5655] = {.lex_state = 230},
  [5656] = {.lex_state = 230},
  [5657] = {.lex_state = 230},
  [5658] = {.lex_state = 230},
  [5659] = {.lex_state = 230},
  [5660] = {.lex_state = 230},
  [5661] = {.lex_state = 230},
  [5662] = {.lex_state = 230},
  [5663] = {.lex_state = 230},
  [5664] = {.lex_state = 230},
  [5665] = {.lex_state = 230},
  [5666] = {.lex_state = 230},
  [5667] = {.lex_state = 230},
  [5668] = {.lex_state = 230},
  [5669] = {.lex_state = 230},
  [5670] = {.lex_state = 230},
  [5671] = {.lex_state = 230},
  [5672] = {.lex_state = 284},
  [5673] = {.lex_state = 284},
  [5674] = {.lex_state = 230},
  [5675] = {.lex_state = 230},
  [5676] = {.lex_state = 230},
  [5677] = {.lex_state = 230},
  [5678] = {.lex_state = 230},
  [5679] = {.lex_state = 230},
  [5680] = {.lex_state = 230},
  [5681] = {.lex_state = 230},
  [5682] = {.lex_state = 230},
  [5683] = {.lex_state = 230},
  [5684] = {.lex_state = 230},
  [5685] = {.lex_state = 230},
  [5686] = {.lex_state = 230},
  [5687] = {.lex_state = 230},
  [5688] = {.lex_state = 230},
  [5689] = {.lex_state = 230},
  [5690] = {.lex_state = 230},
  [5691] = {.lex_state = 230},
  [5692] = {.lex_state = 230},
  [5693] = {.lex_state = 230},
  [5694] = {.lex_state = 230},
  [5695] = {.lex_state = 230},
  [5696] = {.lex_state = 230},
  [5697] = {.lex_state = 230},
  [5698] = {.lex_state = 230},
  [5699] = {.lex_state = 284},
  [5700] = {.lex_state = 284},
  [5701] = {.lex_state = 230},
  [5702] = {.lex_state = 230},
  [5703] = {.lex_state = 230},
  [5704] = {.lex_state = 230},
  [5705] = {.lex_state = 230},
  [5706] = {.lex_state = 230},
  [5707] = {.lex_state = 230},
  [5708] = {.lex_state = 230},
  [5709] = {.lex_state = 230},
  [5710] = {.lex_state = 230},
  [5711] = {.lex_state = 230},
  [5712] = {.lex_state = 230},
  [5713] = {.lex_state = 230},
  [5714] = {.lex_state = 230},
  [5715] = {.lex_state = 230},
  [5716] = {.lex_state = 230},
  [5717] = {.lex_state = 230},
  [5718] = {.lex_state = 230},
  [5719] = {.lex_state = 230},
  [5720] = {.lex_state = 230},
  [5721] = {.lex_state = 230},
  [5722] = {.lex_state = 230},
  [5723] = {.lex_state = 230},
  [5724] = {.lex_state = 230},
  [5725] = {.lex_state = 230},
  [5726] = {.lex_state = 230},
  [5727] = {.lex_state = 230},
  [5728] = {.lex_state = 230},
  [5729] = {.lex_state = 230},
  [5730] = {.lex_state = 230},
  [5731] = {.lex_state = 230},
  [5732] = {.lex_state = 230},
  [5733] = {.lex_state = 230},
  [5734] = {.lex_state = 230},
  [5735] = {.lex_state = 230},
  [5736] = {.lex_state = 230},
  [5737] = {.lex_state = 230},
  [5738] = {.lex_state = 284},
  [5739] = {.lex_state = 230},
  [5740] = {.lex_state = 230},
  [5741] = {.lex_state = 230},
  [5742] = {.lex_state = 230},
  [5743] = {.lex_state = 230},
  [5744] = {.lex_state = 230},
  [5745] = {.lex_state = 230},
  [5746] = {.lex_state = 230},
  [5747] = {.lex_state = 230},
  [5748] = {.lex_state = 230},
  [5749] = {.lex_state = 230},
  [5750] = {.lex_state = 230},
  [5751] = {.lex_state = 230},
  [5752] = {.lex_state = 230},
  [5753] = {.lex_state = 230},
  [5754] = {.lex_state = 230},
  [5755] = {.lex_state = 230},
  [5756] = {.lex_state = 230},
  [5757] = {.lex_state = 230},
  [5758] = {.lex_state = 285},
  [5759] = {.lex_state = 230},
  [5760] = {.lex_state = 285},
  [5761] = {.lex_state = 230},
  [5762] = {.lex_state = 230},
  [5763] = {.lex_state = 230},
  [5764] = {.lex_state = 285},
  [5765] = {.lex_state = 285},
  [5766] = {.lex_state = 285},
  [5767] = {.lex_state = 230},
  [5768] = {.lex_state = 285},
  [5769] = {.lex_state = 284},
  [5770] = {.lex_state = 284},
  [5771] = {.lex_state = 285},
  [5772] = {.lex_state = 230},
  [5773] = {.lex_state = 285},
  [5774] = {.lex_state = 284},
  [5775] = {.lex_state = 285},
  [5776] = {.lex_state = 230},
  [5777] = {.lex_state = 285},
  [5778] = {.lex_state = 285},
  [5779] = {.lex_state = 230},
  [5780] = {.lex_state = 285},
  [5781] = {.lex_state = 238},
  [5782] = {.lex_state = 230},
  [5783] = {.lex_state = 230},
  [5784] = {.lex_state = 285},
  [5785] = {.lex_state = 284},
  [5786] = {.lex_state = 285},
  [5787] = {.lex_state = 285},
  [5788] = {.lex_state = 285},
  [5789] = {.lex_state = 285},
  [5790] = {.lex_state = 285},
  [5791] = {.lex_state = 285},
  [5792] = {.lex_state = 285},
  [5793] = {.lex_state = 285},
  [5794] = {.lex_state = 238},
  [5795] = {.lex_state = 230},
  [5796] = {.lex_state = 285},
  [5797] = {.lex_state = 285},
  [5798] = {.lex_state = 238},
  [5799] = {.lex_state = 238},
  [5800] = {.lex_state = 285},
  [5801] = {.lex_state = 285},
  [5802] = {.lex_state = 285},
  [5803] = {.lex_state = 230},
  [5804] = {.lex_state = 285},
  [5805] = {.lex_state = 230},
  [5806] = {.lex_state = 285},
  [5807] = {.lex_state = 285},
  [5808] = {.lex_state = 238},
  [5809] = {.lex_state = 230},
  [5810] = {.lex_state = 285},
  [5811] = {.lex_state = 285},
  [5812] = {.lex_state = 285},
  [5813] = {.lex_state = 285},
  [5814] = {.lex_state = 285},
  [5815] = {.lex_state = 230},
  [5816] = {.lex_state = 285},
  [5817] = {.lex_state = 285},
  [5818] = {.lex_state = 285},
  [5819] = {.lex_state = 284},
  [5820] = {.lex_state = 230},
  [5821] = {.lex_state = 238},
  [5822] = {.lex_state = 285},
  [5823] = {.lex_state = 230},
  [5824] = {.lex_state = 285},
  [5825] = {.lex_state = 230},
  [5826] = {.lex_state = 230},
  [5827] = {.lex_state = 284},
  [5828] = {.lex_state = 230},
  [5829] = {.lex_state = 238},
  [5830] = {.lex_state = 230},
  [5831] = {.lex_state = 230},
  [5832] = {.lex_state = 284},
  [5833] = {.lex_state = 285},
  [5834] = {.lex_state = 285},
  [5835] = {.lex_state = 285},
  [5836] = {.lex_state = 284},
  [5837] = {.lex_state = 238},
  [5838] = {.lex_state = 285},
  [5839] = {.lex_state = 285},
  [5840] = {.lex_state = 285},
  [5841] = {.lex_state = 285},
  [5842] = {.lex_state = 288},
  [5843] = {.lex_state = 238},
  [5844] = {.lex_state = 238},
  [5845] = {.lex_state = 238},
  [5846] = {.lex_state = 288},
  [5847] = {.lex_state = 238},
  [5848] = {.lex_state = 238},
  [5849] = {.lex_state = 238},
  [5850] = {.lex_state = 232},
  [5851] = {.lex_state = 238},
  [5852] = {.lex_state = 232},
  [5853] = {.lex_state = 288},
  [5854] = {.lex_state = 238},
  [5855] = {.lex_state = 288},
  [5856] = {.lex_state = 288},
  [5857] = {.lex_state = 238},
  [5858] = {.lex_state = 238},
  [5859] = {.lex_state = 238},
  [5860] = {.lex_state = 232},
  [5861] = {.lex_state = 238},
  [5862] = {.lex_state = 238},
  [5863] = {.lex_state = 238},
  [5864] = {.lex_state = 238},
  [5865] = {.lex_state = 238},
  [5866] = {.lex_state = 232},
  [5867] = {.lex_state = 238},
  [5868] = {.lex_state = 238},
  [5869] = {.lex_state = 232},
  [5870] = {.lex_state = 232},
  [5871] = {.lex_state = 232},
  [5872] = {.lex_state = 238},
  [5873] = {.lex_state = 232},
  [5874] = {.lex_state = 288},
  [5875] = {.lex_state = 238},
  [5876] = {.lex_state = 238},
  [5877] = {.lex_state = 238},
  [5878] = {.lex_state = 238},
  [5879] = {.lex_state = 238},
  [5880] = {.lex_state = 238},
  [5881] = {.lex_state = 238},
  [5882] = {.lex_state = 238},
  [5883] = {.lex_state = 238},
  [5884] = {.lex_state = 284},
  [5885] = {.lex_state = 288},
  [5886] = {.lex_state = 284},
  [5887] = {.lex_state = 288},
  [5888] = {.lex_state = 288},
  [5889] = {.lex_state = 288},
  [5890] = {.lex_state = 288},
  [5891] = {.lex_state = 288},
  [5892] = {.lex_state = 288},
  [5893] = {.lex_state = 284},
  [5894] = {.lex_state = 284},
  [5895] = {.lex_state = 288},
  [5896] = {.lex_state = 284},
  [5897] = {.lex_state = 288},
  [5898] = {.lex_state = 288},
  [5899] = {.lex_state = 288},
  [5900] = {.lex_state = 288},
  [5901] = {.lex_state = 284},
  [5902] = {.lex_state = 284},
  [5903] = {.lex_state = 230},
  [5904] = {.lex_state = 284},
  [5905] = {.lex_state = 284},
  [5906] = {.lex_state = 230},
  [5907] = {.lex_state = 230},
  [5908] = {.lex_state = 230},
  [5909] = {.lex_state = 284},
  [5910] = {.lex_state = 230},
  [5911] = {.lex_state = 284},
  [5912] = {.lex_state = 230},
  [5913] = {.lex_state = 284},
  [5914] = {.lex_state = 284},
  [5915] = {.lex_state = 284},
  [5916] = {.lex_state = 284},
  [5917] = {.lex_state = 230},
  [5918] = {.lex_state = 284},
  [5919] = {.lex_state = 230},
  [5920] = {.lex_state = 230},
  [5921] = {.lex_state = 230},
  [5922] = {.lex_state = 284},
  [5923] = {.lex_state = 230},
  [5924] = {.lex_state = 284},
  [5925] = {.lex_state = 284},
  [5926] = {.lex_state = 284},
  [5927] = {.lex_state = 284},
  [5928] = {.lex_state = 284},
  [5929] = {.lex_state = 284},
  [5930] = {.lex_state = 284},
  [5931] = {.lex_state = 230},
  [5932] = {.lex_state = 285},
  [5933] = {.lex_state = 284},
  [5934] = {.lex_state = 284},
  [5935] = {.lex_state = 285},
  [5936] = {.lex_state = 284},
  [5937] = {.lex_state = 285},
  [5938] = {.lex_state = 284},
  [5939] = {.lex_state = 285},
  [5940] = {.lex_state = 285},
  [5941] = {.lex_state = 284},
  [5942] = {.lex_state = 284},
  [5943] = {.lex_state = 297},
  [5944] = {.lex_state = 297},
  [5945] = {.lex_state = 284},
  [5946] = {.lex_state = 284},
  [5947] = {.lex_state = 297},
  [5948] = {.lex_state = 284},
  [5949] = {.lex_state = 288},
  [5950] = {.lex_state = 297},
  [5951] = {.lex_state = 284},
  [5952] = {.lex_state = 284},
  [5953] = {.lex_state = 297},
  [5954] = {.lex_state = 284},
  [5955] = {.lex_state = 284},
  [5956] = {.lex_state = 230},
  [5957] = {.lex_state = 297},
  [5958] = {.lex_state = 230},
  [5959] = {.lex_state = 230},
  [5960] = {.lex_state = 284},
  [5961] = {.lex_state = 297},
  [5962] = {.lex_state = 297},
  [5963] = {.lex_state = 288},
  [5964] = {.lex_state = 284},
  [5965] = {.lex_state = 284},
  [5966] = {.lex_state = 284},
  [5967] = {.lex_state = 230},
  [5968] = {.lex_state = 284},
  [5969] = {.lex_state = 297},
  [5970] = {.lex_state = 230},
  [5971] = {.lex_state = 230},
  [5972] = {.lex_state = 284},
  [5973] = {.lex_state = 232},
  [5974] = {.lex_state = 232},
  [5975] = {.lex_state = 288},
  [5976] = {.lex_state = 284},
  [5977] = {.lex_state = 232},
  [5978] = {.lex_state = 232},
  [5979] = {.lex_state = 288},
  [5980] = {.lex_state = 266},
  [5981] = {.lex_state = 232},
  [5982] = {.lex_state = 284},
  [5983] = {.lex_state = 232},
  [5984] = {.lex_state = 232},
  [5985] = {.lex_state = 232},
  [5986] = {.lex_state = 232},
  [5987] = {.lex_state = 232},
  [5988] = {.lex_state = 232},
  [5989] = {.lex_state = 288},
  [5990] = {.lex_state = 232},
  [5991] = {.lex_state = 284},
  [5992] = {.lex_state = 288},
  [5993] = {.lex_state = 288},
  [5994] = {.lex_state = 284},
  [5995] = {.lex_state = 284},
  [5996] = {.lex_state = 266},
  [5997] = {.lex_state = 297},
  [5998] = {.lex_state = 266},
  [5999] = {.lex_state = 284},
  [6000] = {.lex_state = 284},
  [6001] = {.lex_state = 297},
  [6002] = {.lex_state = 284},
  [6003] = {.lex_state = 297},
  [6004] = {.lex_state = 284},
  [6005] = {.lex_state = 297},
  [6006] = {.lex_state = 266},
  [6007] = {.lex_state = 297},
  [6008] = {.lex_state = 297},
  [6009] = {.lex_state = 297},
  [6010] = {.lex_state = 297},
  [6011] = {.lex_state = 229},
  [6012] = {.lex_state = 288},
  [6013] = {.lex_state = 297},
  [6014] = {.lex_state = 297},
  [6015] = {.lex_state = 297},
  [6016] = {.lex_state = 297},
  [6017] = {.lex_state = 297},
  [6018] = {.lex_state = 297},
  [6019] = {.lex_state = 297},
  [6020] = {.lex_state = 297},
  [6021] = {.lex_state = 297},
  [6022] = {.lex_state = 297},
  [6023] = {.lex_state = 297},
  [6024] = {.lex_state = 297},
  [6025] = {.lex_state = 297},
  [6026] = {.lex_state = 297},
  [6027] = {.lex_state = 284},
  [6028] = {.lex_state = 284},
  [6029] = {.lex_state = 297},
  [6030] = {.lex_state = 297},
  [6031] = {.lex_state = 288},
  [6032] = {.lex_state = 284},
  [6033] = {.lex_state = 284},
  [6034] = {.lex_state = 297},
  [6035] = {.lex_state = 297},
  [6036] = {.lex_state = 297},
  [6037] = {.lex_state = 297},
  [6038] = {.lex_state = 297},
  [6039] = {.lex_state = 297},
  [6040] = {.lex_state = 297},
  [6041] = {.lex_state = 297},
  [6042] = {.lex_state = 297},
  [6043] = {.lex_state = 297},
  [6044] = {.lex_state = 284},
  [6045] = {.lex_state = 297},
  [6046] = {.lex_state = 297},
  [6047] = {.lex_state = 287},
  [6048] = {.lex_state = 297},
  [6049] = {.lex_state = 297},
  [6050] = {.lex_state = 297},
  [6051] = {.lex_state = 284},
  [6052] = {.lex_state = 297},
  [6053] = {.lex_state = 297},
  [6054] = {.lex_state = 284},
  [6055] = {.lex_state = 297},
  [6056] = {.lex_state = 284},
  [6057] = {.lex_state = 297},
  [6058] = {.lex_state = 297},
  [6059] = {.lex_state = 284},
  [6060] = {.lex_state = 297},
  [6061] = {.lex_state = 288},
  [6062] = {.lex_state = 230},
  [6063] = {.lex_state = 288},
  [6064] = {.lex_state = 288},
  [6065] = {.lex_state = 284},
  [6066] = {.lex_state = 288},
  [6067] = {.lex_state = 288},
  [6068] = {.lex_state = 207},
  [6069] = {.lex_state = 288},
  [6070] = {.lex_state = 266},
  [6071] = {.lex_state = 230},
  [6072] = {.lex_state = 230},
  [6073] = {.lex_state = 230},
  [6074] = {.lex_state = 284},
  [6075] = {.lex_state = 229},
  [6076] = {.lex_state = 230},
  [6077] = {.lex_state = 230},
  [6078] = {.lex_state = 230},
  [6079] = {.lex_state = 230},
  [6080] = {.lex_state = 230},
  [6081] = {.lex_state = 230},
  [6082] = {.lex_state = 230},
  [6083] = {.lex_state = 230},
  [6084] = {.lex_state = 230},
  [6085] = {.lex_state = 230},
  [6086] = {.lex_state = 230},
  [6087] = {.lex_state = 266},
  [6088] = {.lex_state = 284},
  [6089] = {.lex_state = 230},
  [6090] = {.lex_state = 230},
  [6091] = {.lex_state = 230},
  [6092] = {.lex_state = 99},
  [6093] = {.lex_state = 230},
  [6094] = {.lex_state = 230},
  [6095] = {.lex_state = 230},
  [6096] = {.lex_state = 230},
  [6097] = {.lex_state = 230},
  [6098] = {.lex_state = 230},
  [6099] = {.lex_state = 230},
  [6100] = {.lex_state = 230},
  [6101] = {.lex_state = 230},
  [6102] = {.lex_state = 230},
  [6103] = {.lex_state = 284},
  [6104] = {.lex_state = 230},
  [6105] = {.lex_state = 230},
  [6106] = {.lex_state = 230},
  [6107] = {.lex_state = 230},
  [6108] = {.lex_state = 230},
  [6109] = {.lex_state = 230},
  [6110] = {.lex_state = 230},
  [6111] = {.lex_state = 230},
  [6112] = {.lex_state = 230},
  [6113] = {.lex_state = 230},
  [6114] = {.lex_state = 230},
  [6115] = {.lex_state = 288},
  [6116] = {.lex_state = 288},
  [6117] = {.lex_state = 230},
  [6118] = {.lex_state = 230},
  [6119] = {.lex_state = 284},
  [6120] = {.lex_state = 230},
  [6121] = {.lex_state = 230},
  [6122] = {.lex_state = 288},
  [6123] = {.lex_state = 230},
  [6124] = {.lex_state = 230},
  [6125] = {.lex_state = 230},
  [6126] = {.lex_state = 266},
  [6127] = {.lex_state = 207},
  [6128] = {.lex_state = 230},
  [6129] = {.lex_state = 230},
  [6130] = {.lex_state = 230},
  [6131] = {.lex_state = 288},
  [6132] = {.lex_state = 284},
  [6133] = {.lex_state = 230},
  [6134] = {.lex_state = 230},
  [6135] = {.lex_state = 288},
  [6136] = {.lex_state = 230},
  [6137] = {.lex_state = 230},
  [6138] = {.lex_state = 230},
  [6139] = {.lex_state = 288},
  [6140] = {.lex_state = 230},
  [6141] = {.lex_state = 230},
  [6142] = {.lex_state = 230},
  [6143] = {.lex_state = 230},
  [6144] = {.lex_state = 230},
  [6145] = {.lex_state = 230},
  [6146] = {.lex_state = 288},
  [6147] = {.lex_state = 288},
  [6148] = {.lex_state = 288},
  [6149] = {.lex_state = 288},
  [6150] = {.lex_state = 288},
  [6151] = {.lex_state = 230},
  [6152] = {.lex_state = 230},
  [6153] = {.lex_state = 230},
  [6154] = {.lex_state = 230},
  [6155] = {.lex_state = 230},
  [6156] = {.lex_state = 288},
  [6157] = {.lex_state = 230},
  [6158] = {.lex_state = 230},
  [6159] = {.lex_state = 230},
  [6160] = {.lex_state = 230},
  [6161] = {.lex_state = 230},
  [6162] = {.lex_state = 230},
  [6163] = {.lex_state = 230},
  [6164] = {.lex_state = 230},
  [6165] = {.lex_state = 230},
  [6166] = {.lex_state = 230},
  [6167] = {.lex_state = 288},
  [6168] = {.lex_state = 288},
  [6169] = {.lex_state = 230},
  [6170] = {.lex_state = 230},
  [6171] = {.lex_state = 288},
  [6172] = {.lex_state = 230},
  [6173] = {.lex_state = 230},
  [6174] = {.lex_state = 230},
  [6175] = {.lex_state = 230},
  [6176] = {.lex_state = 230},
  [6177] = {.lex_state = 288},
  [6178] = {.lex_state = 288},
  [6179] = {.lex_state = 284},
  [6180] = {.lex_state = 288},
  [6181] = {.lex_state = 207},
  [6182] = {.lex_state = 229},
  [6183] = {.lex_state = 266},
  [6184] = {.lex_state = 230},
  [6185] = {.lex_state = 230},
  [6186] = {.lex_state = 230},
  [6187] = {.lex_state = 229},
  [6188] = {.lex_state = 230},
  [6189] = {.lex_state = 230},
  [6190] = {.lex_state = 266},
  [6191] = {.lex_state = 230},
  [6192] = {.lex_state = 230},
  [6193] = {.lex_state = 230},
  [6194] = {.lex_state = 230},
  [6195] = {.lex_state = 288},
  [6196] = {.lex_state = 230},
  [6197] = {.lex_state = 288},
  [6198] = {.lex_state = 288},
  [6199] = {.lex_state = 230},
  [6200] = {.lex_state = 230},
  [6201] = {.lex_state = 230},
  [6202] = {.lex_state = 288},
  [6203] = {.lex_state = 230},
  [6204] = {.lex_state = 230},
  [6205] = {.lex_state = 230},
  [6206] = {.lex_state = 288},
  [6207] = {.lex_state = 230},
  [6208] = {.lex_state = 288},
  [6209] = {.lex_state = 288},
  [6210] = {.lex_state = 288},
  [6211] = {.lex_state = 288},
  [6212] = {.lex_state = 288},
  [6213] = {.lex_state = 288},
  [6214] = {.lex_state = 288},
  [6215] = {.lex_state = 288},
  [6216] = {.lex_state = 230},
  [6217] = {.lex_state = 229},
  [6218] = {.lex_state = 292},
  [6219] = {.lex_state = 266},
  [6220] = {.lex_state = 292},
  [6221] = {.lex_state = 287},
  [6222] = {.lex_state = 292},
  [6223] = {.lex_state = 288},
  [6224] = {.lex_state = 229},
  [6225] = {.lex_state = 288},
  [6226] = {.lex_state = 238},
  [6227] = {.lex_state = 266},
  [6228] = {.lex_state = 292},
  [6229] = {.lex_state = 238},
  [6230] = {.lex_state = 292},
  [6231] = {.lex_state = 207},
  [6232] = {.lex_state = 229},
  [6233] = {.lex_state = 229},
  [6234] = {.lex_state = 229},
  [6235] = {.lex_state = 266},
  [6236] = {.lex_state = 229},
  [6237] = {.lex_state = 229},
  [6238] = {.lex_state = 229},
  [6239] = {.lex_state = 229},
  [6240] = {.lex_state = 229},
  [6241] = {.lex_state = 229},
  [6242] = {.lex_state = 229},
  [6243] = {.lex_state = 229},
  [6244] = {.lex_state = 292},
  [6245] = {.lex_state = 292},
  [6246] = {.lex_state = 266},
  [6247] = {.lex_state = 207},
  [6248] = {.lex_state = 207},
  [6249] = {.lex_state = 207},
  [6250] = {.lex_state = 207},
  [6251] = {.lex_state = 207},
  [6252] = {.lex_state = 207},
  [6253] = {.lex_state = 207},
  [6254] = {.lex_state = 207},
  [6255] = {.lex_state = 207},
  [6256] = {.lex_state = 207},
  [6257] = {.lex_state = 207},
  [6258] = {.lex_state = 292},
  [6259] = {.lex_state = 207},
  [6260] = {.lex_state = 266},
  [6261] = {.lex_state = 292},
  [6262] = {.lex_state = 207},
  [6263] = {.lex_state = 292},
  [6264] = {.lex_state = 207},
  [6265] = {.lex_state = 207},
  [6266] = {.lex_state = 266},
  [6267] = {.lex_state = 292},
  [6268] = {.lex_state = 292},
  [6269] = {.lex_state = 292},
  [6270] = {.lex_state = 266},
  [6271] = {.lex_state = 207},
  [6272] = {.lex_state = 288},
  [6273] = {.lex_state = 229},
  [6274] = {.lex_state = 266},
  [6275] = {.lex_state = 292},
  [6276] = {.lex_state = 292},
  [6277] = {.lex_state = 292},
  [6278] = {.lex_state = 229},
  [6279] = {.lex_state = 266},
  [6280] = {.lex_state = 292},
  [6281] = {.lex_state = 292},
  [6282] = {.lex_state = 266},
  [6283] = {.lex_state = 207},
  [6284] = {.lex_state = 266},
  [6285] = {.lex_state = 266},
  [6286] = {.lex_state = 266},
  [6287] = {.lex_state = 287},
  [6288] = {.lex_state = 207},
  [6289] = {.lex_state = 207},
  [6290] = {.lex_state = 285},
  [6291] = {.lex_state = 266},
  [6292] = {.lex_state = 292},
  [6293] = {.lex_state = 292},
  [6294] = {.lex_state = 285},
  [6295] = {.lex_state = 292},
  [6296] = {.lex_state = 292},
  [6297] = {.lex_state = 288},
  [6298] = {.lex_state = 292},
  [6299] = {.lex_state = 288},
  [6300] = {.lex_state = 288},
  [6301] = {.lex_state = 288},
  [6302] = {.lex_state = 288},
  [6303] = {.lex_state = 284},
  [6304] = {.lex_state = 284},
  [6305] = {.lex_state = 266},
  [6306] = {.lex_state = 284},
  [6307] = {.lex_state = 288},
  [6308] = {.lex_state = 288},
  [6309] = {.lex_state = 288},
  [6310] = {.lex_state = 288},
  [6311] = {.lex_state = 284},
  [6312] = {.lex_state = 284},
  [6313] = {.lex_state = 284},
  [6314] = {.lex_state = 284},
  [6315] = {.lex_state = 292},
  [6316] = {.lex_state = 229},
  [6317] = {.lex_state = 285},
  [6318] = {.lex_state = 285},
  [6319] = {.lex_state = 292},
  [6320] = {.lex_state = 285},
  [6321] = {.lex_state = 292},
  [6322] = {.lex_state = 288},
  [6323] = {.lex_state = 288},
  [6324] = {.lex_state = 207},
  [6325] = {.lex_state = 288},
  [6326] = {.lex_state = 288},
  [6327] = {.lex_state = 288},
  [6328] = {.lex_state = 288},
  [6329] = {.lex_state = 288},
  [6330] = {.lex_state = 288},
  [6331] = {.lex_state = 207},
  [6332] = {.lex_state = 207},
  [6333] = {.lex_state = 285},
  [6334] = {.lex_state = 207},
  [6335] = {.lex_state = 285},
  [6336] = {.lex_state = 285},
  [6337] = {.lex_state = 285},
  [6338] = {.lex_state = 285},
  [6339] = {.lex_state = 229},
  [6340] = {.lex_state = 285},
  [6341] = {.lex_state = 285},
  [6342] = {.lex_state = 285},
  [6343] = {.lex_state = 285},
  [6344] = {.lex_state = 285},
  [6345] = {.lex_state = 285},
  [6346] = {.lex_state = 285},
  [6347] = {.lex_state = 285},
  [6348] = {.lex_state = 207},
  [6349] = {.lex_state = 292},
  [6350] = {.lex_state = 292},
  [6351] = {.lex_state = 207},
  [6352] = {.lex_state = 229},
  [6353] = {.lex_state = 229},
  [6354] = {.lex_state = 229},
  [6355] = {.lex_state = 207},
  [6356] = {.lex_state = 207},
  [6357] = {.lex_state = 207},
  [6358] = {.lex_state = 207},
  [6359] = {.lex_state = 207},
  [6360] = {.lex_state = 292},
  [6361] = {.lex_state = 207},
  [6362] = {.lex_state = 207},
  [6363] = {.lex_state = 207},
  [6364] = {.lex_state = 207},
  [6365] = {.lex_state = 292},
  [6366] = {.lex_state = 292},
  [6367] = {.lex_state = 207},
  [6368] = {.lex_state = 207},
  [6369] = {.lex_state = 207},
  [6370] = {.lex_state = 207},
  [6371] = {.lex_state = 292},
  [6372] = {.lex_state = 284},
  [6373] = {.lex_state = 288},
  [6374] = {.lex_state = 99},
  [6375] = {.lex_state = 288},
  [6376] = {.lex_state = 99},
  [6377] = {.lex_state = 99},
  [6378] = {.lex_state = 266},
  [6379] = {.lex_state = 285},
  [6380] = {.lex_state = 99},
  [6381] = {.lex_state = 99},
  [6382] = {.lex_state = 99},
  [6383] = {.lex_state = 99},
  [6384] = {.lex_state = 99},
  [6385] = {.lex_state = 285},
  [6386] = {.lex_state = 99},
  [6387] = {.lex_state = 99},
  [6388] = {.lex_state = 229},
  [6389] = {.lex_state = 288},
  [6390] = {.lex_state = 284},
  [6391] = {.lex_state = 266},
  [6392] = {.lex_state = 288},
  [6393] = {.lex_state = 266},
  [6394] = {.lex_state = 99},
  [6395] = {.lex_state = 285},
  [6396] = {.lex_state = 288},
  [6397] = {.lex_state = 99},
  [6398] = {.lex_state = 266},
  [6399] = {.lex_state = 284},
  [6400] = {.lex_state = 285},
  [6401] = {.lex_state = 99},
  [6402] = {.lex_state = 99},
  [6403] = {.lex_state = 99},
  [6404] = {.lex_state = 99},
  [6405] = {.lex_state = 99},
  [6406] = {.lex_state = 285},
  [6407] = {.lex_state = 99},
  [6408] = {.lex_state = 288},
  [6409] = {.lex_state = 285},
  [6410] = {.lex_state = 99},
  [6411] = {.lex_state = 285},
  [6412] = {.lex_state = 288},
  [6413] = {.lex_state = 288},
  [6414] = {.lex_state = 288},
  [6415] = {.lex_state = 99},
  [6416] = {.lex_state = 287},
  [6417] = {.lex_state = 266},
  [6418] = {.lex_state = 285},
  [6419] = {.lex_state = 288},
  [6420] = {.lex_state = 285},
  [6421] = {.lex_state = 288},
  [6422] = {.lex_state = 266},
  [6423] = {.lex_state = 287},
  [6424] = {.lex_state = 99},
  [6425] = {.lex_state = 288},
  [6426] = {.lex_state = 288},
  [6427] = {.lex_state = 288},
  [6428] = {.lex_state = 285},
  [6429] = {.lex_state = 99},
  [6430] = {.lex_state = 99},
  [6431] = {.lex_state = 284},
  [6432] = {.lex_state = 288},
  [6433] = {.lex_state = 288},
  [6434] = {.lex_state = 288},
  [6435] = {.lex_state = 229},
  [6436] = {.lex_state = 285},
  [6437] = {.lex_state = 296},
  [6438] = {.lex_state = 288},
  [6439] = {.lex_state = 288},
  [6440] = {.lex_state = 99},
  [6441] = {.lex_state = 285},
  [6442] = {.lex_state = 99},
  [6443] = {.lex_state = 288},
  [6444] = {.lex_state = 99},
  [6445] = {.lex_state = 266},
  [6446] = {.lex_state = 288},
  [6447] = {.lex_state = 287},
  [6448] = {.lex_state = 99},
  [6449] = {.lex_state = 99},
  [6450] = {.lex_state = 99},
  [6451] = {.lex_state = 99},
  [6452] = {.lex_state = 99},
  [6453] = {.lex_state = 285},
  [6454] = {.lex_state = 285},
  [6455] = {.lex_state = 99},
  [6456] = {.lex_state = 99},
  [6457] = {.lex_state = 288},
  [6458] = {.lex_state = 284},
  [6459] = {.lex_state = 287},
  [6460] = {.lex_state = 287},
  [6461] = {.lex_state = 287},
  [6462] = {.lex_state = 230},
  [6463] = {.lex_state = 287},
  [6464] = {.lex_state = 288},
  [6465] = {.lex_state = 287},
  [6466] = {.lex_state = 288},
  [6467] = {.lex_state = 290},
  [6468] = {.lex_state = 230},
  [6469] = {.lex_state = 287},
  [6470] = {.lex_state = 287},
  [6471] = {.lex_state = 284},
  [6472] = {.lex_state = 287},
  [6473] = {.lex_state = 287},
  [6474] = {.lex_state = 284},
  [6475] = {.lex_state = 284},
  [6476] = {.lex_state = 287},
  [6477] = {.lex_state = 287},
  [6478] = {.lex_state = 287},
  [6479] = {.lex_state = 287},
  [6480] = {.lex_state = 287},
  [6481] = {.lex_state = 287},
  [6482] = {.lex_state = 287},
  [6483] = {.lex_state = 230},
  [6484] = {.lex_state = 287},
  [6485] = {.lex_state = 284},
  [6486] = {.lex_state = 288},
  [6487] = {.lex_state = 284},
  [6488] = {.lex_state = 284},
  [6489] = {.lex_state = 284},
  [6490] = {.lex_state = 287},
  [6491] = {.lex_state = 284},
  [6492] = {.lex_state = 284},
  [6493] = {.lex_state = 284},
  [6494] = {.lex_state = 284},
  [6495] = {.lex_state = 284},
  [6496] = {.lex_state = 230},
  [6497] = {.lex_state = 287},
  [6498] = {.lex_state = 284},
  [6499] = {.lex_state = 287},
  [6500] = {.lex_state = 290},
  [6501] = {.lex_state = 287},
  [6502] = {.lex_state = 288},
  [6503] = {.lex_state = 284},
  [6504] = {.lex_state = 284},
  [6505] = {.lex_state = 288},
  [6506] = {.lex_state = 287},
  [6507] = {.lex_state = 287},
  [6508] = {.lex_state = 287},
  [6509] = {.lex_state = 287},
  [6510] = {.lex_state = 284},
  [6511] = {.lex_state = 288},
  [6512] = {.lex_state = 287},
  [6513] = {.lex_state = 287},
  [6514] = {.lex_state = 287},
  [6515] = {.lex_state = 284},
  [6516] = {.lex_state = 287},
  [6517] = {.lex_state = 284},
  [6518] = {.lex_state = 284},
  [6519] = {.lex_state = 266},
  [6520] = {.lex_state = 288},
  [6521] = {.lex_state = 288},
  [6522] = {.lex_state = 287},
  [6523] = {.lex_state = 238},
  [6524] = {.lex_state = 238},
  [6525] = {.lex_state = 284},
  [6526] = {.lex_state = 205},
  [6527] = {.lex_state = 288},
  [6528] = {.lex_state = 205},
  [6529] = {.lex_state = 238},
  [6530] = {.lex_state = 284},
  [6531] = {.lex_state = 280},
  [6532] = {.lex_state = 205},
  [6533] = {.lex_state = 205},
  [6534] = {.lex_state = 288},
  [6535] = {.lex_state = 266},
  [6536] = {.lex_state = 288},
  [6537] = {.lex_state = 238},
  [6538] = {.lex_state = 238},
  [6539] = {.lex_state = 292},
  [6540] = {.lex_state = 284},
  [6541] = {.lex_state = 205},
  [6542] = {.lex_state = 280},
  [6543] = {.lex_state = 284},
  [6544] = {.lex_state = 238},
  [6545] = {.lex_state = 205},
  [6546] = {.lex_state = 238},
  [6547] = {.lex_state = 280},
  [6548] = {.lex_state = 280},
  [6549] = {.lex_state = 287},
  [6550] = {.lex_state = 287},
  [6551] = {.lex_state = 287},
  [6552] = {.lex_state = 287},
  [6553] = {.lex_state = 287},
  [6554] = {.lex_state = 287},
  [6555] = {.lex_state = 287},
  [6556] = {.lex_state = 287},
  [6557] = {.lex_state = 266},
  [6558] = {.lex_state = 205},
  [6559] = {.lex_state = 238},
  [6560] = {.lex_state = 238},
  [6561] = {.lex_state = 205},
  [6562] = {.lex_state = 240},
  [6563] = {.lex_state = 266},
  [6564] = {.lex_state = 238},
  [6565] = {.lex_state = 238},
  [6566] = {.lex_state = 288},
  [6567] = {.lex_state = 292},
  [6568] = {.lex_state = 288},
  [6569] = {.lex_state = 205},
  [6570] = {.lex_state = 230},
  [6571] = {.lex_state = 238},
  [6572] = {.lex_state = 205},
  [6573] = {.lex_state = 205},
  [6574] = {.lex_state = 205},
  [6575] = {.lex_state = 288},
  [6576] = {.lex_state = 288},
  [6577] = {.lex_state = 285},
  [6578] = {.lex_state = 290},
  [6579] = {.lex_state = 285},
  [6580] = {.lex_state = 290},
  [6581] = {.lex_state = 285},
  [6582] = {.lex_state = 288},
  [6583] = {.lex_state = 285},
  [6584] = {.lex_state = 290},
  [6585] = {.lex_state = 205},
  [6586] = {.lex_state = 288},
  [6587] = {.lex_state = 240},
  [6588] = {.lex_state = 288},
  [6589] = {.lex_state = 230},
  [6590] = {.lex_state = 288},
  [6591] = {.lex_state = 288},
  [6592] = {.lex_state = 290},
  [6593] = {.lex_state = 288},
  [6594] = {.lex_state = 288},
  [6595] = {.lex_state = 288},
  [6596] = {.lex_state = 230},
  [6597] = {.lex_state = 288},
  [6598] = {.lex_state = 285},
  [6599] = {.lex_state = 285},
  [6600] = {.lex_state = 290},
  [6601] = {.lex_state = 290},
  [6602] = {.lex_state = 290},
  [6603] = {.lex_state = 288},
  [6604] = {.lex_state = 240},
  [6605] = {.lex_state = 290},
  [6606] = {.lex_state = 230},
  [6607] = {.lex_state = 288},
  [6608] = {.lex_state = 288},
  [6609] = {.lex_state = 284},
  [6610] = {.lex_state = 288},
  [6611] = {.lex_state = 288},
  [6612] = {.lex_state = 284},
  [6613] = {.lex_state = 288},
  [6614] = {.lex_state = 288},
  [6615] = {.lex_state = 285},
  [6616] = {.lex_state = 285},
  [6617] = {.lex_state = 284},
  [6618] = {.lex_state = 290},
  [6619] = {.lex_state = 288},
  [6620] = {.lex_state = 284},
  [6621] = {.lex_state = 230},
  [6622] = {.lex_state = 288},
  [6623] = {.lex_state = 284},
  [6624] = {.lex_state = 288},
  [6625] = {.lex_state = 288},
  [6626] = {.lex_state = 240},
  [6627] = {.lex_state = 288},
  [6628] = {.lex_state = 285},
  [6629] = {.lex_state = 288},
  [6630] = {.lex_state = 290},
  [6631] = {.lex_state = 288},
  [6632] = {.lex_state = 288},
  [6633] = {.lex_state = 240},
  [6634] = {.lex_state = 290},
  [6635] = {.lex_state = 240},
  [6636] = {.lex_state = 290},
  [6637] = {.lex_state = 284},
  [6638] = {.lex_state = 240},
  [6639] = {.lex_state = 288},
  [6640] = {.lex_state = 290},
  [6641] = {.lex_state = 230},
  [6642] = {.lex_state = 240},
  [6643] = {.lex_state = 288},
  [6644] = {.lex_state = 288},
  [6645] = {.lex_state = 288},
  [6646] = {.lex_state = 288},
  [6647] = {.lex_state = 285},
  [6648] = {.lex_state = 288},
  [6649] = {.lex_state = 290},
  [6650] = {.lex_state = 240},
  [6651] = {.lex_state = 240},
  [6652] = {.lex_state = 288},
  [6653] = {.lex_state = 288},
  [6654] = {.lex_state = 240},
  [6655] = {.lex_state = 285},
  [6656] = {.lex_state = 290},
  [6657] = {.lex_state = 285},
  [6658] = {.lex_state = 288},
  [6659] = {.lex_state = 290},
  [6660] = {.lex_state = 288},
  [6661] = {.lex_state = 288},
  [6662] = {.lex_state = 284},
  [6663] = {.lex_state = 230},
  [6664] = {.lex_state = 290},
  [6665] = {.lex_state = 285},
  [6666] = {.lex_state = 285},
  [6667] = {.lex_state = 290},
  [6668] = {.lex_state = 240},
  [6669] = {.lex_state = 285},
  [6670] = {.lex_state = 288},
  [6671] = {.lex_state = 230},
  [6672] = {.lex_state = 285},
  [6673] = {.lex_state = 288},
  [6674] = {.lex_state = 285},
  [6675] = {.lex_state = 288},
  [6676] = {.lex_state = 285},
  [6677] = {.lex_state = 288},
  [6678] = {.lex_state = 288},
  [6679] = {.lex_state = 285},
  [6680] = {.lex_state = 285},
  [6681] = {.lex_state = 288},
  [6682] = {.lex_state = 240},
  [6683] = {.lex_state = 205},
  [6684] = {.lex_state = 288},
  [6685] = {.lex_state = 230},
  [6686] = {.lex_state = 285},
  [6687] = {.lex_state = 284},
  [6688] = {.lex_state = 288},
  [6689] = {.lex_state = 290},
  [6690] = {.lex_state = 288},
  [6691] = {.lex_state = 288},
  [6692] = {.lex_state = 290},
  [6693] = {.lex_state = 290},
  [6694] = {.lex_state = 230},
  [6695] = {.lex_state = 287},
  [6696] = {.lex_state = 230},
  [6697] = {.lex_state = 230},
  [6698] = {.lex_state = 250},
  [6699] = {.lex_state = 217},
  [6700] = {.lex_state = 217},
  [6701] = {.lex_state = 288},
  [6702] = {.lex_state = 284},
  [6703] = {.lex_state = 230},
  [6704] = {.lex_state = 250},
  [6705] = {.lex_state = 231},
  [6706] = {.lex_state = 231},
  [6707] = {.lex_state = 231},
  [6708] = {.lex_state = 287},
  [6709] = {.lex_state = 231},
  [6710] = {.lex_state = 205},
  [6711] = {.lex_state = 230},
  [6712] = {.lex_state = 284},
  [6713] = {.lex_state = 230},
  [6714] = {.lex_state = 231},
  [6715] = {.lex_state = 205},
  [6716] = {.lex_state = 231},
  [6717] = {.lex_state = 205},
  [6718] = {.lex_state = 231},
  [6719] = {.lex_state = 231},
  [6720] = {.lex_state = 217},
  [6721] = {.lex_state = 217},
  [6722] = {.lex_state = 217},
  [6723] = {.lex_state = 287},
  [6724] = {.lex_state = 217},
  [6725] = {.lex_state = 217},
  [6726] = {.lex_state = 287},
  [6727] = {.lex_state = 288},
  [6728] = {.lex_state = 217},
  [6729] = {.lex_state = 217},
  [6730] = {.lex_state = 205},
  [6731] = {.lex_state = 288},
  [6732] = {.lex_state = 205},
  [6733] = {.lex_state = 284},
  [6734] = {.lex_state = 288},
  [6735] = {.lex_state = 210},
  [6736] = {.lex_state = 231},
  [6737] = {.lex_state = 231},
  [6738] = {.lex_state = 231},
  [6739] = {.lex_state = 231},
  [6740] = {.lex_state = 287},
  [6741] = {.lex_state = 217},
  [6742] = {.lex_state = 205},
  [6743] = {.lex_state = 288},
  [6744] = {.lex_state = 205},
  [6745] = {.lex_state = 217},
  [6746] = {.lex_state = 230},
  [6747] = {.lex_state = 288},
  [6748] = {.lex_state = 288},
  [6749] = {.lex_state = 287},
  [6750] = {.lex_state = 284},
  [6751] = {.lex_state = 250},
  [6752] = {.lex_state = 250},
  [6753] = {.lex_state = 250},
  [6754] = {.lex_state = 230},
  [6755] = {.lex_state = 250},
  [6756] = {.lex_state = 217},
  [6757] = {.lex_state = 230},
  [6758] = {.lex_state = 217},
  [6759] = {.lex_state = 287},
  [6760] = {.lex_state = 205},
  [6761] = {.lex_state = 288},
  [6762] = {.lex_state = 217},
  [6763] = {.lex_state = 231},
  [6764] = {.lex_state = 230},
  [6765] = {.lex_state = 217},
  [6766] = {.lex_state = 217},
  [6767] = {.lex_state = 217},
  [6768] = {.lex_state = 231},
  [6769] = {.lex_state = 217},
  [6770] = {.lex_state = 217},
  [6771] = {.lex_state = 217},
  [6772] = {.lex_state = 217},
  [6773] = {.lex_state = 284},
  [6774] = {.lex_state = 205},
  [6775] = {.lex_state = 217},
  [6776] = {.lex_state = 205},
  [6777] = {.lex_state = 217},
  [6778] = {.lex_state = 205},
  [6779] = {.lex_state = 217},
  [6780] = {.lex_state = 231},
  [6781] = {.lex_state = 217},
  [6782] = {.lex_state = 287},
  [6783] = {.lex_state = 205},
  [6784] = {.lex_state = 217},
  [6785] = {.lex_state = 250},
  [6786] = {.lex_state = 288},
  [6787] = {.lex_state = 288},
  [6788] = {.lex_state = 250},
  [6789] = {.lex_state = 231},
  [6790] = {.lex_state = 230},
  [6791] = {.lex_state = 284},
  [6792] = {.lex_state = 230},
  [6793] = {.lex_state = 230},
  [6794] = {.lex_state = 230},
  [6795] = {.lex_state = 230},
  [6796] = {.lex_state = 230},
  [6797] = {.lex_state = 230},
  [6798] = {.lex_state = 230},
  [6799] = {.lex_state = 250},
  [6800] = {.lex_state = 250},
  [6801] = {.lex_state = 250},
  [6802] = {.lex_state = 250},
  [6803] = {.lex_state = 250},
  [6804] = {.lex_state = 250},
  [6805] = {.lex_state = 250},
  [6806] = {.lex_state = 250},
  [6807] = {.lex_state = 250},
  [6808] = {.lex_state = 250},
  [6809] = {.lex_state = 250},
  [6810] = {.lex_state = 250},
  [6811] = {.lex_state = 250},
  [6812] = {.lex_state = 250},
  [6813] = {.lex_state = 230},
  [6814] = {.lex_state = 288},
  [6815] = {.lex_state = 250},
  [6816] = {.lex_state = 250},
  [6817] = {.lex_state = 250},
  [6818] = {.lex_state = 250},
  [6819] = {.lex_state = 230},
  [6820] = {.lex_state = 230},
  [6821] = {.lex_state = 230},
  [6822] = {.lex_state = 288},
  [6823] = {.lex_state = 230},
  [6824] = {.lex_state = 230},
  [6825] = {.lex_state = 288},
  [6826] = {.lex_state = 288},
  [6827] = {.lex_state = 288},
  [6828] = {.lex_state = 280},
  [6829] = {.lex_state = 230},
  [6830] = {.lex_state = 230},
  [6831] = {.lex_state = 288},
  [6832] = {.lex_state = 288},
  [6833] = {.lex_state = 284},
  [6834] = {.lex_state = 280},
  [6835] = {.lex_state = 280},
  [6836] = {.lex_state = 284},
  [6837] = {.lex_state = 230},
  [6838] = {.lex_state = 284},
  [6839] = {.lex_state = 284},
  [6840] = {.lex_state = 288},
  [6841] = {.lex_state = 284},
  [6842] = {.lex_state = 284},
  [6843] = {.lex_state = 284},
  [6844] = {.lex_state = 284},
  [6845] = {.lex_state = 284},
  [6846] = {.lex_state = 230},
  [6847] = {.lex_state = 284},
  [6848] = {.lex_state = 284},
  [6849] = {.lex_state = 284},
  [6850] = {.lex_state = 284},
  [6851] = {.lex_state = 284},
  [6852] = {.lex_state = 284},
  [6853] = {.lex_state = 284},
  [6854] = {.lex_state = 230},
  [6855] = {.lex_state = 250},
  [6856] = {.lex_state = 230},
  [6857] = {.lex_state = 230},
  [6858] = {.lex_state = 288},
  [6859] = {.lex_state = 230},
  [6860] = {.lex_state = 288},
  [6861] = {.lex_state = 230},
  [6862] = {.lex_state = 230},
  [6863] = {.lex_state = 230},
  [6864] = {.lex_state = 230},
  [6865] = {.lex_state = 230},
  [6866] = {.lex_state = 230},
  [6867] = {.lex_state = 230},
  [6868] = {.lex_state = 230},
  [6869] = {.lex_state = 230},
  [6870] = {.lex_state = 230},
  [6871] = {.lex_state = 230},
  [6872] = {.lex_state = 288},
  [6873] = {.lex_state = 239},
  [6874] = {.lex_state = 288},
  [6875] = {.lex_state = 288},
  [6876] = {.lex_state = 230},
  [6877] = {.lex_state = 288},
  [6878] = {.lex_state = 288},
  [6879] = {.lex_state = 288},
  [6880] = {.lex_state = 288},
  [6881] = {.lex_state = 250},
  [6882] = {.lex_state = 230},
  [6883] = {.lex_state = 230},
  [6884] = {.lex_state = 230},
  [6885] = {.lex_state = 230},
  [6886] = {.lex_state = 230},
  [6887] = {.lex_state = 230},
  [6888] = {.lex_state = 288},
  [6889] = {.lex_state = 288},
  [6890] = {.lex_state = 230},
  [6891] = {.lex_state = 230},
  [6892] = {.lex_state = 280},
  [6893] = {.lex_state = 230},
  [6894] = {.lex_state = 284},
  [6895] = {.lex_state = 228},
  [6896] = {.lex_state = 230},
  [6897] = {.lex_state = 287},
  [6898] = {.lex_state = 287},
  [6899] = {.lex_state = 287},
  [6900] = {.lex_state = 287},
  [6901] = {.lex_state = 284},
  [6902] = {.lex_state = 287},
  [6903] = {.lex_state = 287},
  [6904] = {.lex_state = 287},
  [6905] = {.lex_state = 287},
  [6906] = {.lex_state = 228},
  [6907] = {.lex_state = 228},
  [6908] = {.lex_state = 288},
  [6909] = {.lex_state = 228},
  [6910] = {.lex_state = 228},
  [6911] = {.lex_state = 230},
  [6912] = {.lex_state = 228},
  [6913] = {.lex_state = 228},
  [6914] = {.lex_state = 288},
  [6915] = {.lex_state = 228},
  [6916] = {.lex_state = 228},
  [6917] = {.lex_state = 288},
  [6918] = {.lex_state = 288},
  [6919] = {.lex_state = 288},
  [6920] = {.lex_state = 288},
  [6921] = {.lex_state = 228},
  [6922] = {.lex_state = 230},
  [6923] = {.lex_state = 288},
  [6924] = {.lex_state = 230},
  [6925] = {.lex_state = 230},
  [6926] = {.lex_state = 284},
  [6927] = {.lex_state = 232},
  [6928] = {.lex_state = 288},
  [6929] = {.lex_state = 228},
  [6930] = {.lex_state = 232},
  [6931] = {.lex_state = 232},
  [6932] = {.lex_state = 232},
  [6933] = {.lex_state = 288},
  [6934] = {.lex_state = 232},
  [6935] = {.lex_state = 232},
  [6936] = {.lex_state = 232},
  [6937] = {.lex_state = 232},
  [6938] = {.lex_state = 288},
  [6939] = {.lex_state = 228},
  [6940] = {.lex_state = 284},
  [6941] = {.lex_state = 228},
  [6942] = {.lex_state = 230},
  [6943] = {.lex_state = 228},
  [6944] = {.lex_state = 228},
  [6945] = {.lex_state = 288},
  [6946] = {.lex_state = 228},
  [6947] = {.lex_state = 284},
  [6948] = {.lex_state = 288},
  [6949] = {.lex_state = 205},
  [6950] = {.lex_state = 228},
  [6951] = {.lex_state = 230},
  [6952] = {.lex_state = 288},
  [6953] = {.lex_state = 288},
  [6954] = {.lex_state = 284},
  [6955] = {.lex_state = 288},
  [6956] = {.lex_state = 288},
  [6957] = {.lex_state = 288},
  [6958] = {.lex_state = 230},
  [6959] = {.lex_state = 228},
  [6960] = {.lex_state = 288},
  [6961] = {.lex_state = 288},
  [6962] = {.lex_state = 228},
  [6963] = {.lex_state = 205},
  [6964] = {.lex_state = 228},
  [6965] = {.lex_state = 228},
  [6966] = {.lex_state = 228},
  [6967] = {.lex_state = 228},
  [6968] = {.lex_state = 228},
  [6969] = {.lex_state = 288},
  [6970] = {.lex_state = 230},
  [6971] = {.lex_state = 230},
  [6972] = {.lex_state = 205},
  [6973] = {.lex_state = 288},
  [6974] = {.lex_state = 240},
  [6975] = {.lex_state = 230},
  [6976] = {.lex_state = 230},
  [6977] = {.lex_state = 230},
  [6978] = {.lex_state = 240},
  [6979] = {.lex_state = 230},
  [6980] = {.lex_state = 230},
  [6981] = {.lex_state = 230},
  [6982] = {.lex_state = 230},
  [6983] = {.lex_state = 230},
  [6984] = {.lex_state = 230},
  [6985] = {.lex_state = 240},
  [6986] = {.lex_state = 230},
  [6987] = {.lex_state = 230},
  [6988] = {.lex_state = 230},
  [6989] = {.lex_state = 230},
  [6990] = {.lex_state = 230},
  [6991] = {.lex_state = 230},
  [6992] = {.lex_state = 288},
  [6993] = {.lex_state = 288},
  [6994] = {.lex_state = 240},
  [6995] = {.lex_state = 230},
  [6996] = {.lex_state = 288},
  [6997] = {.lex_state = 288},
  [6998] = {.lex_state = 0},
  [6999] = {.lex_state = 240},
  [7000] = {.lex_state = 230},
  [7001] = {.lex_state = 240},
  [7002] = {.lex_state = 230},
  [7003] = {.lex_state = 230},
  [7004] = {.lex_state = 230},
  [7005] = {.lex_state = 240},
  [7006] = {.lex_state = 230},
  [7007] = {.lex_state = 230},
  [7008] = {.lex_state = 230},
  [7009] = {.lex_state = 288},
  [7010] = {.lex_state = 230},
  [7011] = {.lex_state = 288},
  [7012] = {.lex_state = 288},
  [7013] = {.lex_state = 288},
  [7014] = {.lex_state = 288},
  [7015] = {.lex_state = 230},
  [7016] = {.lex_state = 230},
  [7017] = {.lex_state = 240},
  [7018] = {.lex_state = 238},
  [7019] = {.lex_state = 230},
  [7020] = {.lex_state = 230},
  [7021] = {.lex_state = 230},
  [7022] = {.lex_state = 230},
  [7023] = {.lex_state = 288},
  [7024] = {.lex_state = 287},
  [7025] = {.lex_state = 230},
  [7026] = {.lex_state = 287},
  [7027] = {.lex_state = 288},
  [7028] = {.lex_state = 230},
  [7029] = {.lex_state = 250},
  [7030] = {.lex_state = 288},
  [7031] = {.lex_state = 230},
  [7032] = {.lex_state = 230},
  [7033] = {.lex_state = 230},
  [7034] = {.lex_state = 230},
  [7035] = {.lex_state = 230},
  [7036] = {.lex_state = 250},
  [7037] = {.lex_state = 250},
  [7038] = {.lex_state = 230},
  [7039] = {.lex_state = 288},
  [7040] = {.lex_state = 230},
  [7041] = {.lex_state = 232},
  [7042] = {.lex_state = 230},
  [7043] = {.lex_state = 230},
  [7044] = {.lex_state = 230},
  [7045] = {.lex_state = 230},
  [7046] = {.lex_state = 230},
  [7047] = {.lex_state = 230},
  [7048] = {.lex_state = 228},
  [7049] = {.lex_state = 250},
  [7050] = {.lex_state = 232},
  [7051] = {.lex_state = 232},
  [7052] = {.lex_state = 250},
  [7053] = {.lex_state = 230},
  [7054] = {.lex_state = 232},
  [7055] = {.lex_state = 232},
  [7056] = {.lex_state = 232},
  [7057] = {.lex_state = 230},
  [7058] = {.lex_state = 230},
  [7059] = {.lex_state = 288},
  [7060] = {.lex_state = 230},
  [7061] = {.lex_state = 231},
  [7062] = {.lex_state = 288},
  [7063] = {.lex_state = 230},
  [7064] = {.lex_state = 230},
  [7065] = {.lex_state = 230},
  [7066] = {.lex_state = 232},
  [7067] = {.lex_state = 231},
  [7068] = {.lex_state = 230},
  [7069] = {.lex_state = 250},
  [7070] = {.lex_state = 230},
  [7071] = {.lex_state = 230},
  [7072] = {.lex_state = 230},
  [7073] = {.lex_state = 230},
  [7074] = {.lex_state = 230},
  [7075] = {.lex_state = 231},
  [7076] = {.lex_state = 230},
  [7077] = {.lex_state = 230},
  [7078] = {.lex_state = 232},
  [7079] = {.lex_state = 232},
  [7080] = {.lex_state = 231},
  [7081] = {.lex_state = 231},
  [7082] = {.lex_state = 231},
  [7083] = {.lex_state = 232},
  [7084] = {.lex_state = 287},
  [7085] = {.lex_state = 287},
  [7086] = {.lex_state = 230},
  [7087] = {.lex_state = 230},
  [7088] = {.lex_state = 230},
  [7089] = {.lex_state = 230},
  [7090] = {.lex_state = 288},
  [7091] = {.lex_state = 230},
  [7092] = {.lex_state = 232},
  [7093] = {.lex_state = 288},
  [7094] = {.lex_state = 231},
  [7095] = {.lex_state = 230},
  [7096] = {.lex_state = 250},
  [7097] = {.lex_state = 230},
  [7098] = {.lex_state = 230},
  [7099] = {.lex_state = 230},
  [7100] = {.lex_state = 230},
  [7101] = {.lex_state = 287},
  [7102] = {.lex_state = 287},
  [7103] = {.lex_state = 231},
  [7104] = {.lex_state = 230},
  [7105] = {.lex_state = 231},
  [7106] = {.lex_state = 231},
  [7107] = {.lex_state = 231},
  [7108] = {.lex_state = 230},
  [7109] = {.lex_state = 230},
  [7110] = {.lex_state = 231},
  [7111] = {.lex_state = 230},
  [7112] = {.lex_state = 231},
  [7113] = {.lex_state = 230},
  [7114] = {.lex_state = 230},
  [7115] = {.lex_state = 250},
  [7116] = {.lex_state = 231},
  [7117] = {.lex_state = 287},
  [7118] = {.lex_state = 287},
  [7119] = {.lex_state = 230},
  [7120] = {.lex_state = 230},
  [7121] = {.lex_state = 231},
  [7122] = {.lex_state = 231},
  [7123] = {.lex_state = 230},
  [7124] = {.lex_state = 271},
  [7125] = {.lex_state = 230},
  [7126] = {.lex_state = 230},
  [7127] = {.lex_state = 271},
  [7128] = {.lex_state = 230},
  [7129] = {.lex_state = 230},
  [7130] = {.lex_state = 232},
  [7131] = {.lex_state = 250},
  [7132] = {.lex_state = 266},
  [7133] = {.lex_state = 266},
  [7134] = {.lex_state = 287},
  [7135] = {.lex_state = 210},
  [7136] = {.lex_state = 250},
  [7137] = {.lex_state = 287},
  [7138] = {.lex_state = 266},
  [7139] = {.lex_state = 266},
  [7140] = {.lex_state = 389},
  [7141] = {.lex_state = 250},
  [7142] = {.lex_state = 230},
  [7143] = {.lex_state = 266},
  [7144] = {.lex_state = 231},
  [7145] = {.lex_state = 250},
  [7146] = {.lex_state = 250},
  [7147] = {.lex_state = 266},
  [7148] = {.lex_state = 230},
  [7149] = {.lex_state = 287},
  [7150] = {.lex_state = 266},
  [7151] = {.lex_state = 266},
  [7152] = {.lex_state = 287},
  [7153] = {.lex_state = 266},
  [7154] = {.lex_state = 284},
  [7155] = {.lex_state = 284},
  [7156] = {.lex_state = 284},
  [7157] = {.lex_state = 266},
  [7158] = {.lex_state = 230},
  [7159] = {.lex_state = 250},
  [7160] = {.lex_state = 284},
  [7161] = {.lex_state = 250},
  [7162] = {.lex_state = 230},
  [7163] = {.lex_state = 284},
  [7164] = {.lex_state = 210},
  [7165] = {.lex_state = 266},
  [7166] = {.lex_state = 266},
  [7167] = {.lex_state = 266},
  [7168] = {.lex_state = 284},
  [7169] = {.lex_state = 230},
  [7170] = {.lex_state = 284},
  [7171] = {.lex_state = 284},
  [7172] = {.lex_state = 266},
  [7173] = {.lex_state = 250},
  [7174] = {.lex_state = 250},
  [7175] = {.lex_state = 266},
  [7176] = {.lex_state = 230},
  [7177] = {.lex_state = 232},
  [7178] = {.lex_state = 230},
  [7179] = {.lex_state = 230},
  [7180] = {.lex_state = 232},
  [7181] = {.lex_state = 230},
  [7182] = {.lex_state = 230},
  [7183] = {.lex_state = 230},
  [7184] = {.lex_state = 281},
  [7185] = {.lex_state = 230},
  [7186] = {.lex_state = 389},
  [7187] = {.lex_state = 230},
  [7188] = {.lex_state = 389},
  [7189] = {.lex_state = 230},
  [7190] = {.lex_state = 389},
  [7191] = {.lex_state = 232},
  [7192] = {.lex_state = 232},
  [7193] = {.lex_state = 232},
  [7194] = {.lex_state = 230},
  [7195] = {.lex_state = 230},
  [7196] = {.lex_state = 230},
  [7197] = {.lex_state = 230},
  [7198] = {.lex_state = 230},
  [7199] = {.lex_state = 230},
  [7200] = {.lex_state = 230},
  [7201] = {.lex_state = 281},
  [7202] = {.lex_state = 230},
  [7203] = {.lex_state = 230},
  [7204] = {.lex_state = 230},
  [7205] = {.lex_state = 389},
  [7206] = {.lex_state = 232},
  [7207] = {.lex_state = 230},
  [7208] = {.lex_state = 232},
  [7209] = {.lex_state = 389},
  [7210] = {.lex_state = 230},
  [7211] = {.lex_state = 238},
  [7212] = {.lex_state = 281},
  [7213] = {.lex_state = 230},
  [7214] = {.lex_state = 389},
  [7215] = {.lex_state = 230},
  [7216] = {.lex_state = 238},
  [7217] = {.lex_state = 232},
  [7218] = {.lex_state = 230},
  [7219] = {.lex_state = 230},
  [7220] = {.lex_state = 230},
  [7221] = {.lex_state = 281},
  [7222] = {.lex_state = 230},
  [7223] = {.lex_state = 230},
  [7224] = {.lex_state = 230},
  [7225] = {.lex_state = 230},
  [7226] = {.lex_state = 230},
  [7227] = {.lex_state = 230},
  [7228] = {.lex_state = 230},
  [7229] = {.lex_state = 230},
  [7230] = {.lex_state = 230},
  [7231] = {.lex_state = 389},
  [7232] = {.lex_state = 230},
  [7233] = {.lex_state = 230},
  [7234] = {.lex_state = 230},
  [7235] = {.lex_state = 230},
  [7236] = {.lex_state = 389},
  [7237] = {.lex_state = 389},
  [7238] = {.lex_state = 389},
  [7239] = {.lex_state = 289},
  [7240] = {.lex_state = 389},
  [7241] = {.lex_state = 389},
  [7242] = {.lex_state = 389},
  [7243] = {.lex_state = 240},
  [7244] = {.lex_state = 240},
  [7245] = {.lex_state = 240},
  [7246] = {.lex_state = 240},
  [7247] = {.lex_state = 389},
  [7248] = {.lex_state = 389},
  [7249] = {.lex_state = 250},
  [7250] = {.lex_state = 389},
  [7251] = {.lex_state = 240},
  [7252] = {.lex_state = 240},
  [7253] = {.lex_state = 240},
  [7254] = {.lex_state = 240},
  [7255] = {.lex_state = 231},
  [7256] = {.lex_state = 231},
  [7257] = {.lex_state = 266},
  [7258] = {.lex_state = 289},
  [7259] = {.lex_state = 389},
  [7260] = {.lex_state = 231},
  [7261] = {.lex_state = 231},
  [7262] = {.lex_state = 266},
  [7263] = {.lex_state = 284},
  [7264] = {.lex_state = 284},
  [7265] = {.lex_state = 250},
  [7266] = {.lex_state = 389},
  [7267] = {.lex_state = 289},
  [7268] = {.lex_state = 289},
  [7269] = {.lex_state = 389},
  [7270] = {.lex_state = 389},
  [7271] = {.lex_state = 289},
  [7272] = {.lex_state = 284},
  [7273] = {.lex_state = 250},
  [7274] = {.lex_state = 389},
  [7275] = {.lex_state = 250},
  [7276] = {.lex_state = 287},
  [7277] = {.lex_state = 287},
  [7278] = {.lex_state = 289},
  [7279] = {.lex_state = 230},
  [7280] = {.lex_state = 230},
  [7281] = {.lex_state = 289},
  [7282] = {.lex_state = 389},
  [7283] = {.lex_state = 287},
  [7284] = {.lex_state = 389},
  [7285] = {.lex_state = 389},
  [7286] = {.lex_state = 389},
  [7287] = {.lex_state = 287},
  [7288] = {.lex_state = 389},
  [7289] = {.lex_state = 389},
  [7290] = {.lex_state = 389},
  [7291] = {.lex_state = 389},
  [7292] = {.lex_state = 205},
  [7293] = {.lex_state = 389},
  [7294] = {.lex_state = 389},
  [7295] = {.lex_state = 287},
  [7296] = {.lex_state = 205},
  [7297] = {.lex_state = 389},
  [7298] = {.lex_state = 205},
  [7299] = {.lex_state = 205},
  [7300] = {.lex_state = 287},
  [7301] = {.lex_state = 250},
  [7302] = {.lex_state = 230},
  [7303] = {.lex_state = 205},
  [7304] = {.lex_state = 389},
  [7305] = {.lex_state = 289},
  [7306] = {.lex_state = 230},
  [7307] = {.lex_state = 289},
  [7308] = {.lex_state = 230},
  [7309] = {.lex_state = 389},
  [7310] = {.lex_state = 389},
  [7311] = {.lex_state = 230},
  [7312] = {.lex_state = 205},
  [7313] = {.lex_state = 205},
  [7314] = {.lex_state = 389},
  [7315] = {.lex_state = 389},
  [7316] = {.lex_state = 230},
  [7317] = {.lex_state = 205},
  [7318] = {.lex_state = 205},
  [7319] = {.lex_state = 205},
  [7320] = {.lex_state = 205},
  [7321] = {.lex_state = 205},
  [7322] = {.lex_state = 230},
  [7323] = {.lex_state = 289},
  [7324] = {.lex_state = 205},
  [7325] = {.lex_state = 205},
  [7326] = {.lex_state = 230},
  [7327] = {.lex_state = 238},
  [7328] = {.lex_state = 230},
  [7329] = {.lex_state = 389},
  [7330] = {.lex_state = 389},
  [7331] = {.lex_state = 289},
  [7332] = {.lex_state = 205},
  [7333] = {.lex_state = 205},
  [7334] = {.lex_state = 389},
  [7335] = {.lex_state = 289},
  [7336] = {.lex_state = 389},
  [7337] = {.lex_state = 205},
  [7338] = {.lex_state = 230},
  [7339] = {.lex_state = 389},
  [7340] = {.lex_state = 205},
  [7341] = {.lex_state = 205},
  [7342] = {.lex_state = 389},
  [7343] = {.lex_state = 230},
  [7344] = {.lex_state = 230},
  [7345] = {.lex_state = 389},
  [7346] = {.lex_state = 230},
  [7347] = {.lex_state = 238},
  [7348] = {.lex_state = 284},
  [7349] = {.lex_state = 230},
  [7350] = {.lex_state = 238},
  [7351] = {.lex_state = 230},
  [7352] = {.lex_state = 205},
  [7353] = {.lex_state = 230},
  [7354] = {.lex_state = 205},
  [7355] = {.lex_state = 389},
  [7356] = {.lex_state = 205},
  [7357] = {.lex_state = 230},
  [7358] = {.lex_state = 205},
  [7359] = {.lex_state = 250},
  [7360] = {.lex_state = 230},
  [7361] = {.lex_state = 230},
  [7362] = {.lex_state = 205},
  [7363] = {.lex_state = 230},
  [7364] = {.lex_state = 205},
  [7365] = {.lex_state = 230},
  [7366] = {.lex_state = 230},
  [7367] = {.lex_state = 230},
  [7368] = {.lex_state = 230},
  [7369] = {.lex_state = 230},
  [7370] = {.lex_state = 230},
  [7371] = {.lex_state = 230},
  [7372] = {.lex_state = 389},
  [7373] = {.lex_state = 230},
  [7374] = {.lex_state = 230},
  [7375] = {.lex_state = 230},
  [7376] = {.lex_state = 230},
  [7377] = {.lex_state = 250},
  [7378] = {.lex_state = 287},
  [7379] = {.lex_state = 228},
  [7380] = {.lex_state = 230},
  [7381] = {.lex_state = 230},
  [7382] = {.lex_state = 389},
  [7383] = {.lex_state = 230},
  [7384] = {.lex_state = 230},
  [7385] = {.lex_state = 284},
  [7386] = {.lex_state = 228},
  [7387] = {.lex_state = 228},
  [7388] = {.lex_state = 230},
  [7389] = {.lex_state = 230},
  [7390] = {.lex_state = 230},
  [7391] = {.lex_state = 284},
  [7392] = {.lex_state = 284},
  [7393] = {.lex_state = 284},
  [7394] = {.lex_state = 230},
  [7395] = {.lex_state = 230},
  [7396] = {.lex_state = 230},
  [7397] = {.lex_state = 389},
  [7398] = {.lex_state = 230},
  [7399] = {.lex_state = 230},
  [7400] = {.lex_state = 0},
  [7401] = {.lex_state = 230},
  [7402] = {.lex_state = 230},
  [7403] = {.lex_state = 228},
  [7404] = {.lex_state = 284},
  [7405] = {.lex_state = 284},
  [7406] = {.lex_state = 230},
  [7407] = {.lex_state = 228},
  [7408] = {.lex_state = 228},
  [7409] = {.lex_state = 228},
  [7410] = {.lex_state = 389},
  [7411] = {.lex_state = 228},
  [7412] = {.lex_state = 230},
  [7413] = {.lex_state = 230},
  [7414] = {.lex_state = 389},
  [7415] = {.lex_state = 389},
  [7416] = {.lex_state = 230},
  [7417] = {.lex_state = 230},
  [7418] = {.lex_state = 289},
  [7419] = {.lex_state = 230},
  [7420] = {.lex_state = 284},
  [7421] = {.lex_state = 284},
  [7422] = {.lex_state = 284},
  [7423] = {.lex_state = 228},
  [7424] = {.lex_state = 284},
  [7425] = {.lex_state = 230},
  [7426] = {.lex_state = 284},
  [7427] = {.lex_state = 230},
  [7428] = {.lex_state = 228},
  [7429] = {.lex_state = 230},
  [7430] = {.lex_state = 230},
  [7431] = {.lex_state = 230},
  [7432] = {.lex_state = 0},
  [7433] = {.lex_state = 284},
  [7434] = {.lex_state = 228},
  [7435] = {.lex_state = 284},
  [7436] = {.lex_state = 284},
  [7437] = {.lex_state = 230},
  [7438] = {.lex_state = 250},
  [7439] = {.lex_state = 230},
  [7440] = {.lex_state = 284},
  [7441] = {.lex_state = 205},
  [7442] = {.lex_state = 389},
  [7443] = {.lex_state = 233},
  [7444] = {.lex_state = 230},
  [7445] = {.lex_state = 389},
  [7446] = {.lex_state = 230},
  [7447] = {.lex_state = 230},
  [7448] = {.lex_state = 230},
  [7449] = {.lex_state = 230},
  [7450] = {.lex_state = 230},
  [7451] = {.lex_state = 230},
  [7452] = {.lex_state = 230},
  [7453] = {.lex_state = 230},
  [7454] = {.lex_state = 389},
  [7455] = {.lex_state = 230},
  [7456] = {.lex_state = 230},
  [7457] = {.lex_state = 233},
  [7458] = {.lex_state = 230},
  [7459] = {.lex_state = 233},
  [7460] = {.lex_state = 230},
  [7461] = {.lex_state = 230},
  [7462] = {.lex_state = 230},
  [7463] = {.lex_state = 230},
  [7464] = {.lex_state = 230},
  [7465] = {.lex_state = 230},
  [7466] = {.lex_state = 230},
  [7467] = {.lex_state = 230},
  [7468] = {.lex_state = 230},
  [7469] = {.lex_state = 230},
  [7470] = {.lex_state = 205},
  [7471] = {.lex_state = 230},
  [7472] = {.lex_state = 230},
  [7473] = {.lex_state = 230},
  [7474] = {.lex_state = 230},
  [7475] = {.lex_state = 230},
  [7476] = {.lex_state = 230},
  [7477] = {.lex_state = 230},
  [7478] = {.lex_state = 230},
  [7479] = {.lex_state = 230},
  [7480] = {.lex_state = 230},
  [7481] = {.lex_state = 230},
  [7482] = {.lex_state = 205},
  [7483] = {.lex_state = 230},
  [7484] = {.lex_state = 230},
  [7485] = {.lex_state = 201},
  [7486] = {.lex_state = 230},
  [7487] = {.lex_state = 230},
  [7488] = {.lex_state = 230},
  [7489] = {.lex_state = 230},
  [7490] = {.lex_state = 230},
  [7491] = {.lex_state = 230},
  [7492] = {.lex_state = 230},
  [7493] = {.lex_state = 230},
  [7494] = {.lex_state = 250},
  [7495] = {.lex_state = 389},
  [7496] = {.lex_state = 233},
  [7497] = {.lex_state = 233},
  [7498] = {.lex_state = 230},
  [7499] = {.lex_state = 230},
  [7500] = {.lex_state = 230},
  [7501] = {.lex_state = 205},
  [7502] = {.lex_state = 233},
  [7503] = {.lex_state = 233},
  [7504] = {.lex_state = 230},
  [7505] = {.lex_state = 230},
  [7506] = {.lex_state = 230},
  [7507] = {.lex_state = 233},
  [7508] = {.lex_state = 230},
  [7509] = {.lex_state = 230},
  [7510] = {.lex_state = 230},
  [7511] = {.lex_state = 230},
  [7512] = {.lex_state = 389},
  [7513] = {.lex_state = 233},
  [7514] = {.lex_state = 205},
  [7515] = {.lex_state = 389},
  [7516] = {.lex_state = 389},
  [7517] = {.lex_state = 205},
  [7518] = {.lex_state = 389},
  [7519] = {.lex_state = 205},
  [7520] = {.lex_state = 233},
  [7521] = {.lex_state = 389},
  [7522] = {.lex_state = 108},
  [7523] = {.lex_state = 110},
  [7524] = {.lex_state = 389},
  [7525] = {.lex_state = 389},
  [7526] = {.lex_state = 110},
  [7527] = {.lex_state = 389},
  [7528] = {.lex_state = 205},
  [7529] = {.lex_state = 233},
  [7530] = {.lex_state = 110},
  [7531] = {.lex_state = 110},
  [7532] = {.lex_state = 389},
  [7533] = {.lex_state = 108},
  [7534] = {.lex_state = 230},
  [7535] = {.lex_state = 389},
  [7536] = {.lex_state = 110},
  [7537] = {.lex_state = 205},
  [7538] = {.lex_state = 284},
  [7539] = {.lex_state = 110},
  [7540] = {.lex_state = 110},
  [7541] = {.lex_state = 205},
  [7542] = {.lex_state = 389},
  [7543] = {.lex_state = 233},
  [7544] = {.lex_state = 233},
  [7545] = {.lex_state = 230},
  [7546] = {.lex_state = 389},
  [7547] = {.lex_state = 110},
  [7548] = {.lex_state = 233},
  [7549] = {.lex_state = 389},
  [7550] = {.lex_state = 230},
  [7551] = {.lex_state = 108},
  [7552] = {.lex_state = 110},
  [7553] = {.lex_state = 110},
  [7554] = {.lex_state = 389},
  [7555] = {.lex_state = 389},
  [7556] = {.lex_state = 205},
  [7557] = {.lex_state = 233},
  [7558] = {.lex_state = 205},
  [7559] = {.lex_state = 389},
  [7560] = {.lex_state = 389},
  [7561] = {.lex_state = 389},
  [7562] = {.lex_state = 110},
  [7563] = {.lex_state = 110},
  [7564] = {.lex_state = 233},
  [7565] = {.lex_state = 205},
  [7566] = {.lex_state = 284},
  [7567] = {.lex_state = 110},
  [7568] = {.lex_state = 233},
  [7569] = {.lex_state = 389},
  [7570] = {.lex_state = 230},
  [7571] = {.lex_state = 230},
  [7572] = {.lex_state = 110},
  [7573] = {.lex_state = 233},
  [7574] = {.lex_state = 110},
  [7575] = {.lex_state = 110},
  [7576] = {.lex_state = 110},
  [7577] = {.lex_state = 205},
  [7578] = {.lex_state = 110},
  [7579] = {.lex_state = 205},
  [7580] = {.lex_state = 230},
  [7581] = {.lex_state = 110},
  [7582] = {.lex_state = 111},
  [7583] = {.lex_state = 205},
  [7584] = {.lex_state = 205},
  [7585] = {.lex_state = 205},
  [7586] = {.lex_state = 110},
  [7587] = {.lex_state = 389},
  [7588] = {.lex_state = 389},
  [7589] = {.lex_state = 389},
  [7590] = {.lex_state = 108},
  [7591] = {.lex_state = 230},
  [7592] = {.lex_state = 108},
  [7593] = {.lex_state = 230},
  [7594] = {.lex_state = 0},
  [7595] = {.lex_state = 233},
  [7596] = {.lex_state = 108},
  [7597] = {.lex_state = 389},
  [7598] = {.lex_state = 111},
  [7599] = {.lex_state = 389},
  [7600] = {.lex_state = 233},
  [7601] = {.lex_state = 284},
  [7602] = {.lex_state = 110},
  [7603] = {.lex_state = 110},
  [7604] = {.lex_state = 205},
  [7605] = {.lex_state = 233},
  [7606] = {.lex_state = 233},
  [7607] = {.lex_state = 389},
  [7608] = {.lex_state = 389},
  [7609] = {.lex_state = 389},
  [7610] = {.lex_state = 110},
  [7611] = {.lex_state = 233},
  [7612] = {.lex_state = 233},
  [7613] = {.lex_state = 108},
  [7614] = {.lex_state = 284},
  [7615] = {.lex_state = 110},
  [7616] = {.lex_state = 284},
  [7617] = {.lex_state = 205},
  [7618] = {.lex_state = 205},
  [7619] = {.lex_state = 233},
  [7620] = {.lex_state = 233},
  [7621] = {.lex_state = 389},
  [7622] = {.lex_state = 284},
  [7623] = {.lex_state = 233},
  [7624] = {.lex_state = 389},
  [7625] = {.lex_state = 205},
  [7626] = {.lex_state = 389},
  [7627] = {.lex_state = 230},
  [7628] = {.lex_state = 110},
  [7629] = {.lex_state = 110},
  [7630] = {.lex_state = 205},
  [7631] = {.lex_state = 389},
  [7632] = {.lex_state = 205},
  [7633] = {.lex_state = 233},
  [7634] = {.lex_state = 389},
  [7635] = {.lex_state = 205},
  [7636] = {.lex_state = 233},
  [7637] = {.lex_state = 389},
  [7638] = {.lex_state = 201},
  [7639] = {.lex_state = 205},
  [7640] = {.lex_state = 250},
  [7641] = {.lex_state = 205},
  [7642] = {.lex_state = 0},
  [7643] = {.lex_state = 233},
  [7644] = {.lex_state = 230},
  [7645] = {.lex_state = 0},
  [7646] = {.lex_state = 284},
  [7647] = {.lex_state = 110},
  [7648] = {.lex_state = 110},
  [7649] = {.lex_state = 110},
  [7650] = {.lex_state = 110},
  [7651] = {.lex_state = 233},
  [7652] = {.lex_state = 284},
  [7653] = {.lex_state = 110},
  [7654] = {.lex_state = 233},
  [7655] = {.lex_state = 108},
  [7656] = {.lex_state = 110},
  [7657] = {.lex_state = 230},
  [7658] = {.lex_state = 389},
  [7659] = {.lex_state = 111},
  [7660] = {.lex_state = 205},
  [7661] = {.lex_state = 205},
  [7662] = {.lex_state = 389},
  [7663] = {.lex_state = 389},
  [7664] = {.lex_state = 389},
  [7665] = {.lex_state = 389},
  [7666] = {.lex_state = 284},
  [7667] = {.lex_state = 389},
  [7668] = {.lex_state = 233},
  [7669] = {.lex_state = 233},
  [7670] = {.lex_state = 233},
  [7671] = {.lex_state = 284},
  [7672] = {.lex_state = 108},
  [7673] = {.lex_state = 389},
  [7674] = {.lex_state = 233},
  [7675] = {.lex_state = 230},
  [7676] = {.lex_state = 108},
  [7677] = {.lex_state = 110},
  [7678] = {.lex_state = 108},
  [7679] = {.lex_state = 110},
  [7680] = {.lex_state = 205},
  [7681] = {.lex_state = 389},
  [7682] = {.lex_state = 205},
  [7683] = {.lex_state = 389},
  [7684] = {.lex_state = 205},
  [7685] = {.lex_state = 205},
  [7686] = {.lex_state = 110},
  [7687] = {.lex_state = 389},
  [7688] = {.lex_state = 233},
  [7689] = {.lex_state = 205},
  [7690] = {.lex_state = 233},
  [7691] = {.lex_state = 233},
  [7692] = {.lex_state = 233},
  [7693] = {.lex_state = 108},
  [7694] = {.lex_state = 389},
  [7695] = {.lex_state = 389},
  [7696] = {.lex_state = 389},
  [7697] = {.lex_state = 205},
  [7698] = {.lex_state = 389},
  [7699] = {.lex_state = 110},
  [7700] = {.lex_state = 230},
  [7701] = {.lex_state = 230},
  [7702] = {.lex_state = 233},
  [7703] = {.lex_state = 389},
  [7704] = {.lex_state = 389},
  [7705] = {.lex_state = 233},
  [7706] = {.lex_state = 389},
  [7707] = {.lex_state = 108},
  [7708] = {.lex_state = 110},
  [7709] = {.lex_state = 205},
  [7710] = {.lex_state = 233},
  [7711] = {.lex_state = 389},
  [7712] = {.lex_state = 389},
  [7713] = {.lex_state = 389},
  [7714] = {.lex_state = 205},
  [7715] = {.lex_state = 205},
  [7716] = {.lex_state = 205},
  [7717] = {.lex_state = 205},
  [7718] = {.lex_state = 110},
  [7719] = {.lex_state = 110},
  [7720] = {.lex_state = 389},
  [7721] = {.lex_state = 389},
  [7722] = {.lex_state = 110},
  [7723] = {.lex_state = 108},
  [7724] = {.lex_state = 110},
  [7725] = {.lex_state = 205},
  [7726] = {.lex_state = 389},
  [7727] = {.lex_state = 389},
  [7728] = {.lex_state = 0},
  [7729] = {.lex_state = 389},
  [7730] = {.lex_state = 111},
  [7731] = {.lex_state = 389},
  [7732] = {.lex_state = 389},
  [7733] = {.lex_state = 389},
  [7734] = {.lex_state = 389},
  [7735] = {.lex_state = 233},
  [7736] = {.lex_state = 110},
  [7737] = {.lex_state = 108},
  [7738] = {.lex_state = 389},
  [7739] = {.lex_state = 389},
  [7740] = {.lex_state = 110},
  [7741] = {.lex_state = 111},
  [7742] = {.lex_state = 389},
  [7743] = {.lex_state = 233},
  [7744] = {.lex_state = 233},
  [7745] = {.lex_state = 110},
  [7746] = {.lex_state = 389},
  [7747] = {.lex_state = 110},
  [7748] = {.lex_state = 389},
  [7749] = {.lex_state = 110},
  [7750] = {.lex_state = 233},
  [7751] = {.lex_state = 111},
  [7752] = {.lex_state = 110},
  [7753] = {.lex_state = 233},
  [7754] = {.lex_state = 233},
  [7755] = {.lex_state = 111},
  [7756] = {.lex_state = 389},
  [7757] = {.lex_state = 233},
  [7758] = {.lex_state = 233},
  [7759] = {.lex_state = 389},
  [7760] = {.lex_state = 389},
  [7761] = {.lex_state = 233},
  [7762] = {.lex_state = 230},
  [7763] = {.lex_state = 230},
  [7764] = {.lex_state = 0},
  [7765] = {.lex_state = 201},
  [7766] = {.lex_state = 0},
  [7767] = {.lex_state = 230},
  [7768] = {.lex_state = 230},
  [7769] = {.lex_state = 389},
  [7770] = {.lex_state = 0},
  [7771] = {.lex_state = 233},
  [7772] = {.lex_state = 230},
  [7773] = {.lex_state = 0},
  [7774] = {.lex_state = 0},
  [7775] = {.lex_state = 389},
  [7776] = {.lex_state = 0},
  [7777] = {.lex_state = 0},
  [7778] = {.lex_state = 0},
  [7779] = {.lex_state = 0},
  [7780] = {.lex_state = 230},
  [7781] = {.lex_state = 0},
  [7782] = {.lex_state = 113},
  [7783] = {.lex_state = 389},
  [7784] = {.lex_state = 389},
  [7785] = {.lex_state = 389},
  [7786] = {.lex_state = 201},
  [7787] = {.lex_state = 0},
  [7788] = {.lex_state = 0},
  [7789] = {.lex_state = 389},
  [7790] = {.lex_state = 0},
  [7791] = {.lex_state = 205},
  [7792] = {.lex_state = 201},
  [7793] = {.lex_state = 230},
  [7794] = {.lex_state = 250},
  [7795] = {.lex_state = 230},
  [7796] = {.lex_state = 0},
  [7797] = {.lex_state = 230},
  [7798] = {.lex_state = 0},
  [7799] = {.lex_state = 201},
  [7800] = {.lex_state = 0},
  [7801] = {.lex_state = 230},
  [7802] = {.lex_state = 0},
  [7803] = {.lex_state = 0},
  [7804] = {.lex_state = 0},
  [7805] = {.lex_state = 0},
  [7806] = {.lex_state = 230},
  [7807] = {.lex_state = 0},
  [7808] = {.lex_state = 0},
  [7809] = {.lex_state = 0},
  [7810] = {.lex_state = 201},
  [7811] = {.lex_state = 0},
  [7812] = {.lex_state = 233},
  [7813] = {.lex_state = 0},
  [7814] = {.lex_state = 230},
  [7815] = {.lex_state = 0},
  [7816] = {.lex_state = 0},
  [7817] = {.lex_state = 0},
  [7818] = {.lex_state = 0},
  [7819] = {.lex_state = 389},
  [7820] = {.lex_state = 0},
  [7821] = {.lex_state = 233},
  [7822] = {.lex_state = 230},
  [7823] = {.lex_state = 233},
  [7824] = {.lex_state = 0},
  [7825] = {.lex_state = 0},
  [7826] = {.lex_state = 0},
  [7827] = {.lex_state = 233},
  [7828] = {.lex_state = 201},
  [7829] = {.lex_state = 0},
  [7830] = {.lex_state = 233},
  [7831] = {.lex_state = 0},
  [7832] = {.lex_state = 230},
  [7833] = {.lex_state = 233},
  [7834] = {.lex_state = 0},
  [7835] = {.lex_state = 230},
  [7836] = {.lex_state = 230},
  [7837] = {.lex_state = 0},
  [7838] = {.lex_state = 230},
  [7839] = {.lex_state = 230},
  [7840] = {.lex_state = 201},
  [7841] = {.lex_state = 233},
  [7842] = {.lex_state = 230},
  [7843] = {.lex_state = 389},
  [7844] = {.lex_state = 0},
  [7845] = {.lex_state = 0},
  [7846] = {.lex_state = 389},
  [7847] = {.lex_state = 0},
  [7848] = {.lex_state = 230},
  [7849] = {.lex_state = 0},
  [7850] = {.lex_state = 0},
  [7851] = {.lex_state = 389},
  [7852] = {.lex_state = 233},
  [7853] = {.lex_state = 0},
  [7854] = {.lex_state = 233},
  [7855] = {.lex_state = 389},
  [7856] = {.lex_state = 389},
  [7857] = {.lex_state = 230},
  [7858] = {.lex_state = 389},
  [7859] = {.lex_state = 108},
  [7860] = {.lex_state = 233},
  [7861] = {.lex_state = 389},
  [7862] = {.lex_state = 389},
  [7863] = {.lex_state = 233},
  [7864] = {.lex_state = 0},
  [7865] = {.lex_state = 0},
  [7866] = {.lex_state = 0},
  [7867] = {.lex_state = 0},
  [7868] = {.lex_state = 389},
  [7869] = {.lex_state = 0},
  [7870] = {.lex_state = 0},
  [7871] = {.lex_state = 0},
  [7872] = {.lex_state = 0},
  [7873] = {.lex_state = 389},
  [7874] = {.lex_state = 230},
  [7875] = {.lex_state = 0},
  [7876] = {.lex_state = 0},
  [7877] = {.lex_state = 0},
  [7878] = {.lex_state = 230},
  [7879] = {.lex_state = 0},
  [7880] = {.lex_state = 0},
  [7881] = {.lex_state = 233},
  [7882] = {.lex_state = 233},
  [7883] = {.lex_state = 230},
  [7884] = {.lex_state = 233},
  [7885] = {.lex_state = 233},
  [7886] = {.lex_state = 0},
  [7887] = {.lex_state = 0},
  [7888] = {.lex_state = 0},
  [7889] = {.lex_state = 233},
  [7890] = {.lex_state = 233},
  [7891] = {.lex_state = 233},
  [7892] = {.lex_state = 0},
  [7893] = {.lex_state = 233},
  [7894] = {.lex_state = 0},
  [7895] = {.lex_state = 0},
  [7896] = {.lex_state = 230},
  [7897] = {.lex_state = 389},
  [7898] = {.lex_state = 0},
  [7899] = {.lex_state = 0},
  [7900] = {.lex_state = 389},
  [7901] = {.lex_state = 0},
  [7902] = {.lex_state = 233},
  [7903] = {.lex_state = 233},
  [7904] = {.lex_state = 0},
  [7905] = {.lex_state = 0},
  [7906] = {.lex_state = 389},
  [7907] = {.lex_state = 389},
  [7908] = {.lex_state = 389},
  [7909] = {.lex_state = 0},
  [7910] = {.lex_state = 0},
  [7911] = {.lex_state = 0},
  [7912] = {.lex_state = 389},
  [7913] = {.lex_state = 233},
  [7914] = {.lex_state = 233},
  [7915] = {.lex_state = 233},
  [7916] = {.lex_state = 230},
  [7917] = {.lex_state = 389},
  [7918] = {.lex_state = 108},
  [7919] = {.lex_state = 389},
  [7920] = {.lex_state = 0},
  [7921] = {.lex_state = 233},
  [7922] = {.lex_state = 389},
  [7923] = {.lex_state = 389},
  [7924] = {.lex_state = 0},
  [7925] = {.lex_state = 0},
  [7926] = {.lex_state = 230},
  [7927] = {.lex_state = 0},
  [7928] = {.lex_state = 389},
  [7929] = {.lex_state = 0},
  [7930] = {.lex_state = 0},
  [7931] = {.lex_state = 230},
  [7932] = {.lex_state = 389},
  [7933] = {.lex_state = 0},
  [7934] = {.lex_state = 389},
  [7935] = {.lex_state = 0},
  [7936] = {.lex_state = 230},
  [7937] = {.lex_state = 389},
  [7938] = {.lex_state = 0},
  [7939] = {.lex_state = 230},
  [7940] = {.lex_state = 201},
  [7941] = {.lex_state = 108},
  [7942] = {.lex_state = 0},
  [7943] = {.lex_state = 0},
  [7944] = {.lex_state = 233},
  [7945] = {.lex_state = 230},
  [7946] = {.lex_state = 230},
  [7947] = {.lex_state = 230},
  [7948] = {.lex_state = 230},
  [7949] = {.lex_state = 0},
  [7950] = {.lex_state = 233},
  [7951] = {.lex_state = 233},
  [7952] = {.lex_state = 233},
  [7953] = {.lex_state = 201},
  [7954] = {.lex_state = 233},
  [7955] = {.lex_state = 233},
  [7956] = {.lex_state = 108},
  [7957] = {.lex_state = 233},
  [7958] = {.lex_state = 233},
  [7959] = {.lex_state = 233},
  [7960] = {.lex_state = 389},
  [7961] = {.lex_state = 389},
  [7962] = {.lex_state = 389},
  [7963] = {.lex_state = 230},
  [7964] = {.lex_state = 230},
  [7965] = {.lex_state = 0},
  [7966] = {.lex_state = 233},
  [7967] = {.lex_state = 0},
  [7968] = {.lex_state = 389},
  [7969] = {.lex_state = 389},
  [7970] = {.lex_state = 389},
  [7971] = {.lex_state = 230},
  [7972] = {.lex_state = 389},
  [7973] = {.lex_state = 0},
  [7974] = {.lex_state = 389},
  [7975] = {.lex_state = 0},
  [7976] = {.lex_state = 233},
  [7977] = {.lex_state = 0},
  [7978] = {.lex_state = 230},
  [7979] = {.lex_state = 108},
  [7980] = {.lex_state = 230},
  [7981] = {.lex_state = 0},
  [7982] = {.lex_state = 230},
  [7983] = {.lex_state = 230},
  [7984] = {.lex_state = 0},
  [7985] = {.lex_state = 233},
  [7986] = {.lex_state = 0},
  [7987] = {.lex_state = 389},
  [7988] = {.lex_state = 230},
  [7989] = {.lex_state = 389},
  [7990] = {.lex_state = 113},
  [7991] = {.lex_state = 0},
  [7992] = {.lex_state = 233},
  [7993] = {.lex_state = 389},
  [7994] = {.lex_state = 389},
  [7995] = {.lex_state = 0},
  [7996] = {.lex_state = 0},
  [7997] = {.lex_state = 0},
  [7998] = {.lex_state = 230},
  [7999] = {.lex_state = 389},
  [8000] = {.lex_state = 0},
  [8001] = {.lex_state = 0},
  [8002] = {.lex_state = 389},
  [8003] = {.lex_state = 108},
  [8004] = {.lex_state = 389},
  [8005] = {.lex_state = 0},
  [8006] = {.lex_state = 0},
  [8007] = {.lex_state = 389},
  [8008] = {.lex_state = 230},
  [8009] = {.lex_state = 230},
  [8010] = {.lex_state = 0},
  [8011] = {.lex_state = 0},
  [8012] = {.lex_state = 233},
  [8013] = {.lex_state = 0},
  [8014] = {.lex_state = 0},
  [8015] = {.lex_state = 233},
  [8016] = {.lex_state = 230},
  [8017] = {.lex_state = 233},
  [8018] = {.lex_state = 389},
  [8019] = {.lex_state = 389},
  [8020] = {.lex_state = 389},
  [8021] = {.lex_state = 233},
  [8022] = {.lex_state = 233},
  [8023] = {.lex_state = 230},
  [8024] = {.lex_state = 108},
  [8025] = {.lex_state = 389},
  [8026] = {.lex_state = 389},
  [8027] = {.lex_state = 0},
  [8028] = {.lex_state = 230},
  [8029] = {.lex_state = 233},
  [8030] = {.lex_state = 201},
  [8031] = {.lex_state = 108},
  [8032] = {.lex_state = 0},
  [8033] = {.lex_state = 0},
  [8034] = {.lex_state = 233},
  [8035] = {.lex_state = 108},
  [8036] = {.lex_state = 201},
  [8037] = {.lex_state = 108},
  [8038] = {.lex_state = 108},
  [8039] = {.lex_state = 108},
  [8040] = {.lex_state = 230},
  [8041] = {.lex_state = 108},
  [8042] = {.lex_state = 389},
  [8043] = {.lex_state = 0},
  [8044] = {.lex_state = 0},
  [8045] = {.lex_state = 389},
  [8046] = {.lex_state = 233},
  [8047] = {.lex_state = 233},
  [8048] = {.lex_state = 389},
  [8049] = {.lex_state = 389},
  [8050] = {.lex_state = 389},
  [8051] = {.lex_state = 233},
  [8052] = {.lex_state = 0},
  [8053] = {.lex_state = 230},
  [8054] = {.lex_state = 233},
  [8055] = {.lex_state = 233},
  [8056] = {.lex_state = 0},
  [8057] = {.lex_state = 230},
  [8058] = {.lex_state = 0},
  [8059] = {.lex_state = 230},
  [8060] = {.lex_state = 0},
  [8061] = {.lex_state = 230},
  [8062] = {.lex_state = 389},
  [8063] = {.lex_state = 389},
  [8064] = {.lex_state = 201},
  [8065] = {.lex_state = 389},
  [8066] = {.lex_state = 389},
  [8067] = {.lex_state = 201},
  [8068] = {.lex_state = 389},
  [8069] = {.lex_state = 233},
  [8070] = {.lex_state = 233},
  [8071] = {.lex_state = 389},
  [8072] = {.lex_state = 233},
  [8073] = {.lex_state = 389},
  [8074] = {.lex_state = 0},
  [8075] = {.lex_state = 0},
  [8076] = {.lex_state = 0},
  [8077] = {.lex_state = 0},
  [8078] = {.lex_state = 0},
  [8079] = {.lex_state = 201},
  [8080] = {.lex_state = 389},
  [8081] = {.lex_state = 0},
  [8082] = {.lex_state = 201},
  [8083] = {.lex_state = 0},
  [8084] = {.lex_state = 0},
  [8085] = {.lex_state = 230},
  [8086] = {.lex_state = 0},
  [8087] = {.lex_state = 233},
  [8088] = {.lex_state = 230},
  [8089] = {.lex_state = 285},
  [8090] = {.lex_state = 230},
  [8091] = {.lex_state = 0},
  [8092] = {.lex_state = 389},
  [8093] = {.lex_state = 0},
  [8094] = {.lex_state = 0},
  [8095] = {.lex_state = 389},
  [8096] = {.lex_state = 389},
  [8097] = {.lex_state = 230},
  [8098] = {.lex_state = 230},
  [8099] = {.lex_state = 389},
  [8100] = {.lex_state = 205},
  [8101] = {.lex_state = 230},
  [8102] = {.lex_state = 233},
  [8103] = {.lex_state = 0},
  [8104] = {.lex_state = 0},
  [8105] = {.lex_state = 201},
  [8106] = {.lex_state = 0},
  [8107] = {.lex_state = 230},
  [8108] = {.lex_state = 233},
  [8109] = {.lex_state = 233},
  [8110] = {.lex_state = 389},
  [8111] = {.lex_state = 0},
  [8112] = {.lex_state = 0},
  [8113] = {.lex_state = 230},
  [8114] = {.lex_state = 233},
  [8115] = {.lex_state = 389},
  [8116] = {.lex_state = 389},
  [8117] = {.lex_state = 389},
  [8118] = {.lex_state = 389},
  [8119] = {.lex_state = 0},
  [8120] = {.lex_state = 230},
  [8121] = {.lex_state = 0},
  [8122] = {.lex_state = 0},
  [8123] = {.lex_state = 0},
  [8124] = {.lex_state = 201},
  [8125] = {.lex_state = 0},
  [8126] = {.lex_state = 233},
  [8127] = {.lex_state = 0},
  [8128] = {.lex_state = 233},
  [8129] = {.lex_state = 230},
  [8130] = {.lex_state = 233},
  [8131] = {.lex_state = 0},
  [8132] = {.lex_state = 0},
  [8133] = {.lex_state = 233},
  [8134] = {.lex_state = 233},
  [8135] = {.lex_state = 389},
  [8136] = {.lex_state = 230},
  [8137] = {.lex_state = 108},
  [8138] = {.lex_state = 0},
  [8139] = {.lex_state = 233},
  [8140] = {.lex_state = 233},
  [8141] = {.lex_state = 233},
  [8142] = {.lex_state = 389},
  [8143] = {.lex_state = 233},
  [8144] = {.lex_state = 0},
  [8145] = {.lex_state = 389},
  [8146] = {.lex_state = 113},
  [8147] = {.lex_state = 233},
  [8148] = {.lex_state = 233},
  [8149] = {.lex_state = 233},
  [8150] = {.lex_state = 0},
  [8151] = {.lex_state = 233},
  [8152] = {.lex_state = 0},
  [8153] = {.lex_state = 389},
  [8154] = {.lex_state = 389},
  [8155] = {.lex_state = 0},
  [8156] = {.lex_state = 230},
  [8157] = {.lex_state = 233},
  [8158] = {.lex_state = 205},
  [8159] = {.lex_state = 233},
  [8160] = {.lex_state = 389},
  [8161] = {.lex_state = 389},
  [8162] = {.lex_state = 389},
  [8163] = {.lex_state = 230},
  [8164] = {.lex_state = 233},
  [8165] = {.lex_state = 389},
  [8166] = {.lex_state = 0},
  [8167] = {.lex_state = 201},
  [8168] = {.lex_state = 0},
  [8169] = {.lex_state = 230},
  [8170] = {.lex_state = 0},
  [8171] = {.lex_state = 0},
  [8172] = {.lex_state = 389},
  [8173] = {.lex_state = 0},
  [8174] = {.lex_state = 0},
  [8175] = {.lex_state = 0},
  [8176] = {.lex_state = 0},
  [8177] = {.lex_state = 0},
  [8178] = {.lex_state = 201},
  [8179] = {.lex_state = 230},
  [8180] = {.lex_state = 389},
  [8181] = {.lex_state = 0},
  [8182] = {.lex_state = 230},
  [8183] = {.lex_state = 0},
  [8184] = {.lex_state = 230},
  [8185] = {.lex_state = 0},
  [8186] = {.lex_state = 389},
  [8187] = {.lex_state = 233},
  [8188] = {.lex_state = 233},
  [8189] = {.lex_state = 0},
  [8190] = {.lex_state = 233},
  [8191] = {.lex_state = 389},
  [8192] = {.lex_state = 113},
  [8193] = {.lex_state = 389},
  [8194] = {.lex_state = 0},
  [8195] = {.lex_state = 0},
  [8196] = {.lex_state = 0},
  [8197] = {.lex_state = 389},
  [8198] = {.lex_state = 0},
  [8199] = {.lex_state = 0},
  [8200] = {.lex_state = 201},
  [8201] = {.lex_state = 0},
  [8202] = {.lex_state = 0},
  [8203] = {.lex_state = 233},
  [8204] = {.lex_state = 201},
  [8205] = {.lex_state = 233},
  [8206] = {.lex_state = 0},
  [8207] = {.lex_state = 230},
  [8208] = {.lex_state = 389},
  [8209] = {.lex_state = 0},
  [8210] = {.lex_state = 0},
  [8211] = {.lex_state = 0},
  [8212] = {.lex_state = 0},
  [8213] = {.lex_state = 0},
  [8214] = {.lex_state = 0},
  [8215] = {.lex_state = 0},
  [8216] = {.lex_state = 0},
  [8217] = {.lex_state = 230},
  [8218] = {.lex_state = 389},
  [8219] = {.lex_state = 0},
  [8220] = {.lex_state = 389},
  [8221] = {.lex_state = 389},
  [8222] = {.lex_state = 389},
  [8223] = {.lex_state = 389},
  [8224] = {.lex_state = 0},
  [8225] = {.lex_state = 230},
  [8226] = {.lex_state = 0},
  [8227] = {.lex_state = 112},
  [8228] = {.lex_state = 0},
  [8229] = {.lex_state = 0},
  [8230] = {.lex_state = 230},
  [8231] = {.lex_state = 0},
  [8232] = {.lex_state = 389},
  [8233] = {.lex_state = 389},
  [8234] = {.lex_state = 112},
  [8235] = {.lex_state = 0},
  [8236] = {.lex_state = 0},
  [8237] = {.lex_state = 0},
  [8238] = {.lex_state = 0},
  [8239] = {.lex_state = 112},
  [8240] = {.lex_state = 0},
  [8241] = {.lex_state = 389},
  [8242] = {.lex_state = 0},
  [8243] = {.lex_state = 0},
  [8244] = {.lex_state = 0},
  [8245] = {.lex_state = 389},
  [8246] = {.lex_state = 0},
  [8247] = {.lex_state = 230},
  [8248] = {.lex_state = 0},
  [8249] = {.lex_state = 0},
  [8250] = {.lex_state = 0},
  [8251] = {.lex_state = 230},
  [8252] = {.lex_state = 0},
  [8253] = {.lex_state = 0},
  [8254] = {.lex_state = 0},
  [8255] = {.lex_state = 0},
  [8256] = {.lex_state = 0},
  [8257] = {.lex_state = 112},
  [8258] = {.lex_state = 0},
  [8259] = {.lex_state = 0},
  [8260] = {.lex_state = 389},
  [8261] = {.lex_state = 0},
  [8262] = {.lex_state = 0},
  [8263] = {.lex_state = 389},
  [8264] = {.lex_state = 0},
  [8265] = {.lex_state = 0},
  [8266] = {.lex_state = 0},
  [8267] = {.lex_state = 0},
  [8268] = {.lex_state = 0},
  [8269] = {.lex_state = 389},
  [8270] = {.lex_state = 0},
  [8271] = {.lex_state = 0},
  [8272] = {.lex_state = 112},
  [8273] = {.lex_state = 0},
  [8274] = {.lex_state = 0},
  [8275] = {.lex_state = 389},
  [8276] = {.lex_state = 389},
  [8277] = {.lex_state = 230},
  [8278] = {.lex_state = 0},
  [8279] = {.lex_state = 389},
  [8280] = {.lex_state = 0},
  [8281] = {.lex_state = 0},
  [8282] = {.lex_state = 0},
  [8283] = {.lex_state = 0},
  [8284] = {.lex_state = 0},
  [8285] = {.lex_state = 0},
  [8286] = {.lex_state = 0},
  [8287] = {.lex_state = 230},
  [8288] = {.lex_state = 112},
  [8289] = {.lex_state = 389},
  [8290] = {.lex_state = 389},
  [8291] = {.lex_state = 0},
  [8292] = {.lex_state = 0},
  [8293] = {.lex_state = 0},
  [8294] = {.lex_state = 112},
  [8295] = {.lex_state = 201},
  [8296] = {.lex_state = 112},
  [8297] = {.lex_state = 389},
  [8298] = {.lex_state = 0},
  [8299] = {.lex_state = 0},
  [8300] = {.lex_state = 0},
  [8301] = {.lex_state = 389},
  [8302] = {.lex_state = 0},
  [8303] = {.lex_state = 0},
  [8304] = {.lex_state = 112},
  [8305] = {.lex_state = 112},
  [8306] = {.lex_state = 0},
  [8307] = {.lex_state = 230},
  [8308] = {.lex_state = 389},
  [8309] = {.lex_state = 0},
  [8310] = {.lex_state = 0},
  [8311] = {.lex_state = 389},
  [8312] = {.lex_state = 0},
  [8313] = {.lex_state = 0},
  [8314] = {.lex_state = 0},
  [8315] = {.lex_state = 230},
  [8316] = {.lex_state = 389},
  [8317] = {.lex_state = 0},
  [8318] = {.lex_state = 389},
  [8319] = {.lex_state = 0},
  [8320] = {.lex_state = 0},
  [8321] = {.lex_state = 230},
  [8322] = {.lex_state = 389},
  [8323] = {.lex_state = 230},
  [8324] = {.lex_state = 0},
  [8325] = {.lex_state = 0},
  [8326] = {.lex_state = 389},
  [8327] = {.lex_state = 0},
  [8328] = {.lex_state = 389},
  [8329] = {.lex_state = 0},
  [8330] = {.lex_state = 112},
  [8331] = {.lex_state = 0},
  [8332] = {.lex_state = 0},
  [8333] = {.lex_state = 389},
  [8334] = {.lex_state = 0},
  [8335] = {.lex_state = 0},
  [8336] = {.lex_state = 389},
  [8337] = {.lex_state = 389},
  [8338] = {.lex_state = 389},
  [8339] = {.lex_state = 0},
  [8340] = {.lex_state = 389},
  [8341] = {.lex_state = 0},
  [8342] = {.lex_state = 0},
  [8343] = {.lex_state = 0},
  [8344] = {.lex_state = 0},
  [8345] = {.lex_state = 389},
  [8346] = {.lex_state = 0},
  [8347] = {.lex_state = 0},
  [8348] = {.lex_state = 0},
  [8349] = {.lex_state = 0},
  [8350] = {.lex_state = 0},
  [8351] = {.lex_state = 389},
  [8352] = {.lex_state = 0},
  [8353] = {.lex_state = 0},
  [8354] = {.lex_state = 230},
  [8355] = {.lex_state = 0},
  [8356] = {.lex_state = 0},
  [8357] = {.lex_state = 0},
  [8358] = {.lex_state = 230},
  [8359] = {.lex_state = 0},
  [8360] = {.lex_state = 389},
  [8361] = {.lex_state = 0},
  [8362] = {.lex_state = 230},
  [8363] = {.lex_state = 389},
  [8364] = {.lex_state = 389},
  [8365] = {.lex_state = 0},
  [8366] = {.lex_state = 0},
  [8367] = {.lex_state = 230},
  [8368] = {.lex_state = 0},
  [8369] = {.lex_state = 0},
  [8370] = {.lex_state = 389},
  [8371] = {.lex_state = 389},
  [8372] = {.lex_state = 0},
  [8373] = {.lex_state = 389},
  [8374] = {.lex_state = 0},
  [8375] = {.lex_state = 0},
  [8376] = {.lex_state = 0},
  [8377] = {.lex_state = 0},
  [8378] = {.lex_state = 0},
  [8379] = {.lex_state = 0},
  [8380] = {.lex_state = 389},
  [8381] = {.lex_state = 230},
  [8382] = {.lex_state = 389},
  [8383] = {.lex_state = 389},
  [8384] = {.lex_state = 0},
  [8385] = {.lex_state = 0},
  [8386] = {.lex_state = 389},
  [8387] = {.lex_state = 0},
  [8388] = {.lex_state = 0},
  [8389] = {.lex_state = 0},
  [8390] = {.lex_state = 0},
  [8391] = {.lex_state = 0},
  [8392] = {.lex_state = 0},
  [8393] = {.lex_state = 0},
  [8394] = {.lex_state = 230},
  [8395] = {.lex_state = 389},
  [8396] = {.lex_state = 0},
  [8397] = {.lex_state = 0},
  [8398] = {.lex_state = 230},
  [8399] = {.lex_state = 0},
  [8400] = {.lex_state = 389},
  [8401] = {.lex_state = 0},
  [8402] = {.lex_state = 0},
  [8403] = {.lex_state = 389},
  [8404] = {.lex_state = 389},
  [8405] = {.lex_state = 389},
  [8406] = {.lex_state = 0},
  [8407] = {.lex_state = 0},
  [8408] = {.lex_state = 0},
  [8409] = {.lex_state = 0},
  [8410] = {.lex_state = 389},
  [8411] = {.lex_state = 0},
  [8412] = {.lex_state = 230},
  [8413] = {.lex_state = 0},
  [8414] = {.lex_state = 0},
  [8415] = {.lex_state = 112},
  [8416] = {.lex_state = 389},
  [8417] = {.lex_state = 389},
  [8418] = {.lex_state = 389},
  [8419] = {.lex_state = 389},
  [8420] = {.lex_state = 0},
  [8421] = {.lex_state = 389},
  [8422] = {.lex_state = 389},
  [8423] = {.lex_state = 0},
  [8424] = {.lex_state = 201},
  [8425] = {.lex_state = 389},
  [8426] = {.lex_state = 230},
  [8427] = {.lex_state = 0},
  [8428] = {.lex_state = 0},
  [8429] = {.lex_state = 0},
  [8430] = {.lex_state = 0},
  [8431] = {.lex_state = 389},
  [8432] = {.lex_state = 230},
  [8433] = {.lex_state = 0},
  [8434] = {.lex_state = 389},
  [8435] = {.lex_state = 389},
  [8436] = {.lex_state = 0},
  [8437] = {.lex_state = 0},
  [8438] = {.lex_state = 389},
  [8439] = {.lex_state = 0},
  [8440] = {.lex_state = 389},
  [8441] = {.lex_state = 0},
  [8442] = {.lex_state = 0},
  [8443] = {.lex_state = 230},
  [8444] = {.lex_state = 0},
  [8445] = {.lex_state = 389},
  [8446] = {.lex_state = 112},
  [8447] = {.lex_state = 389},
  [8448] = {.lex_state = 389},
  [8449] = {.lex_state = 230},
  [8450] = {.lex_state = 0},
  [8451] = {.lex_state = 112},
  [8452] = {.lex_state = 389},
  [8453] = {.lex_state = 0},
  [8454] = {.lex_state = 389},
  [8455] = {.lex_state = 389},
  [8456] = {.lex_state = 0},
  [8457] = {.lex_state = 389},
  [8458] = {.lex_state = 389},
  [8459] = {.lex_state = 389},
  [8460] = {.lex_state = 230},
  [8461] = {.lex_state = 0},
  [8462] = {.lex_state = 0},
  [8463] = {.lex_state = 0},
  [8464] = {.lex_state = 389},
  [8465] = {.lex_state = 230},
  [8466] = {.lex_state = 389, .external_lex_state = 2},
  [8467] = {.lex_state = 0},
  [8468] = {.lex_state = 0},
  [8469] = {.lex_state = 0},
  [8470] = {.lex_state = 0},
  [8471] = {.lex_state = 0},
  [8472] = {.lex_state = 0},
  [8473] = {.lex_state = 389},
  [8474] = {.lex_state = 0},
  [8475] = {.lex_state = 389},
  [8476] = {.lex_state = 0},
  [8477] = {.lex_state = 0},
  [8478] = {.lex_state = 389},
  [8479] = {.lex_state = 389},
  [8480] = {.lex_state = 0},
  [8481] = {.lex_state = 0},
  [8482] = {.lex_state = 0},
  [8483] = {.lex_state = 0},
  [8484] = {.lex_state = 389},
  [8485] = {.lex_state = 0},
  [8486] = {.lex_state = 0},
  [8487] = {.lex_state = 389},
  [8488] = {.lex_state = 0},
  [8489] = {.lex_state = 0},
  [8490] = {.lex_state = 0},
  [8491] = {.lex_state = 0},
  [8492] = {.lex_state = 201},
  [8493] = {.lex_state = 112},
  [8494] = {.lex_state = 389},
  [8495] = {.lex_state = 0},
  [8496] = {.lex_state = 0},
  [8497] = {.lex_state = 0},
  [8498] = {.lex_state = 0},
  [8499] = {.lex_state = 0},
  [8500] = {.lex_state = 0},
  [8501] = {.lex_state = 389},
  [8502] = {.lex_state = 0},
  [8503] = {.lex_state = 0},
  [8504] = {.lex_state = 389},
  [8505] = {.lex_state = 0},
  [8506] = {.lex_state = 0},
  [8507] = {.lex_state = 389},
  [8508] = {.lex_state = 0},
  [8509] = {.lex_state = 0},
  [8510] = {.lex_state = 389},
  [8511] = {.lex_state = 0},
  [8512] = {.lex_state = 0},
  [8513] = {.lex_state = 0},
  [8514] = {.lex_state = 389},
  [8515] = {.lex_state = 0},
  [8516] = {.lex_state = 0},
  [8517] = {.lex_state = 230},
  [8518] = {.lex_state = 0},
  [8519] = {.lex_state = 389},
  [8520] = {.lex_state = 389},
  [8521] = {.lex_state = 0},
  [8522] = {.lex_state = 0},
  [8523] = {.lex_state = 0},
  [8524] = {.lex_state = 0},
  [8525] = {.lex_state = 0},
  [8526] = {.lex_state = 230},
  [8527] = {.lex_state = 230},
  [8528] = {.lex_state = 0},
  [8529] = {.lex_state = 112},
  [8530] = {.lex_state = 230},
  [8531] = {.lex_state = 389},
  [8532] = {.lex_state = 0},
  [8533] = {.lex_state = 0},
  [8534] = {.lex_state = 0},
  [8535] = {.lex_state = 389},
  [8536] = {.lex_state = 389, .external_lex_state = 2},
  [8537] = {.lex_state = 0},
  [8538] = {.lex_state = 0},
  [8539] = {.lex_state = 389},
  [8540] = {.lex_state = 0},
  [8541] = {.lex_state = 0},
  [8542] = {.lex_state = 0},
  [8543] = {.lex_state = 389},
  [8544] = {.lex_state = 0},
  [8545] = {.lex_state = 0},
  [8546] = {.lex_state = 112},
  [8547] = {.lex_state = 0},
  [8548] = {.lex_state = 0},
  [8549] = {.lex_state = 0},
  [8550] = {.lex_state = 389},
  [8551] = {.lex_state = 389},
  [8552] = {.lex_state = 230},
  [8553] = {.lex_state = 389, .external_lex_state = 2},
  [8554] = {.lex_state = 0},
  [8555] = {.lex_state = 389, .external_lex_state = 2},
  [8556] = {.lex_state = 0},
  [8557] = {.lex_state = 389, .external_lex_state = 2},
  [8558] = {.lex_state = 389, .external_lex_state = 2},
  [8559] = {.lex_state = 230},
  [8560] = {.lex_state = 389, .external_lex_state = 2},
  [8561] = {.lex_state = 389, .external_lex_state = 2},
  [8562] = {.lex_state = 0},
  [8563] = {.lex_state = 389, .external_lex_state = 2},
  [8564] = {.lex_state = 389, .external_lex_state = 2},
  [8565] = {.lex_state = 389, .external_lex_state = 2},
  [8566] = {.lex_state = 389, .external_lex_state = 2},
  [8567] = {.lex_state = 389, .external_lex_state = 2},
  [8568] = {.lex_state = 389, .external_lex_state = 2},
  [8569] = {.lex_state = 389, .external_lex_state = 2},
  [8570] = {.lex_state = 389, .external_lex_state = 2},
  [8571] = {.lex_state = 389, .external_lex_state = 2},
  [8572] = {.lex_state = 389, .external_lex_state = 2},
  [8573] = {.lex_state = 389, .external_lex_state = 2},
  [8574] = {.lex_state = 389, .external_lex_state = 2},
  [8575] = {.lex_state = 389, .external_lex_state = 2},
  [8576] = {.lex_state = 389},
  [8577] = {.lex_state = 0},
  [8578] = {.lex_state = 0},
  [8579] = {.lex_state = 230},
  [8580] = {.lex_state = 0, .external_lex_state = 2},
  [8581] = {.lex_state = 0},
  [8582] = {.lex_state = 203},
  [8583] = {.lex_state = 233},
  [8584] = {.lex_state = 233},
  [8585] = {.lex_state = 233},
  [8586] = {.lex_state = 0},
  [8587] = {.lex_state = 0},
  [8588] = {.lex_state = 0},
  [8589] = {.lex_state = 0},
  [8590] = {.lex_state = 0},
  [8591] = {.lex_state = 0},
  [8592] = {.lex_state = 0},
  [8593] = {.lex_state = 233},
  [8594] = {.lex_state = 230},
  [8595] = {.lex_state = 233},
  [8596] = {.lex_state = 0},
  [8597] = {.lex_state = 0},
  [8598] = {.lex_state = 0},
  [8599] = {.lex_state = 0},
  [8600] = {.lex_state = 203},
  [8601] = {.lex_state = 0},
  [8602] = {.lex_state = 0},
  [8603] = {.lex_state = 0},
  [8604] = {.lex_state = 230},
  [8605] = {.lex_state = 0},
  [8606] = {.lex_state = 0, .external_lex_state = 2},
  [8607] = {.lex_state = 0},
  [8608] = {.lex_state = 203},
  [8609] = {.lex_state = 389},
  [8610] = {.lex_state = 0},
  [8611] = {.lex_state = 0},
  [8612] = {.lex_state = 0},
  [8613] = {.lex_state = 389},
  [8614] = {.lex_state = 113},
  [8615] = {.lex_state = 0},
  [8616] = {.lex_state = 0},
  [8617] = {.lex_state = 0},
  [8618] = {.lex_state = 0},
  [8619] = {.lex_state = 0},
  [8620] = {.lex_state = 0},
  [8621] = {.lex_state = 389},
  [8622] = {.lex_state = 389},
  [8623] = {.lex_state = 203},
  [8624] = {.lex_state = 0},
  [8625] = {.lex_state = 0},
  [8626] = {.lex_state = 230},
  [8627] = {.lex_state = 203},
  [8628] = {.lex_state = 0},
  [8629] = {.lex_state = 0},
  [8630] = {.lex_state = 0},
  [8631] = {.lex_state = 0},
  [8632] = {.lex_state = 0},
  [8633] = {.lex_state = 0},
  [8634] = {.lex_state = 0},
  [8635] = {.lex_state = 0},
  [8636] = {.lex_state = 0},
  [8637] = {.lex_state = 0},
  [8638] = {.lex_state = 0},
  [8639] = {.lex_state = 0},
  [8640] = {.lex_state = 113},
  [8641] = {.lex_state = 0},
  [8642] = {.lex_state = 0},
  [8643] = {.lex_state = 230},
  [8644] = {.lex_state = 230},
  [8645] = {.lex_state = 203},
  [8646] = {.lex_state = 113},
  [8647] = {.lex_state = 0},
  [8648] = {.lex_state = 203},
  [8649] = {.lex_state = 389},
  [8650] = {.lex_state = 389},
  [8651] = {.lex_state = 113},
  [8652] = {.lex_state = 389},
  [8653] = {.lex_state = 230},
  [8654] = {.lex_state = 389},
  [8655] = {.lex_state = 0},
  [8656] = {.lex_state = 0},
  [8657] = {.lex_state = 230},
  [8658] = {.lex_state = 0},
  [8659] = {.lex_state = 0},
  [8660] = {.lex_state = 389},
  [8661] = {.lex_state = 233},
  [8662] = {.lex_state = 230},
  [8663] = {.lex_state = 0},
  [8664] = {.lex_state = 0},
  [8665] = {.lex_state = 0},
  [8666] = {.lex_state = 0},
  [8667] = {.lex_state = 0},
  [8668] = {.lex_state = 0},
  [8669] = {.lex_state = 0},
  [8670] = {.lex_state = 0},
  [8671] = {.lex_state = 0},
  [8672] = {.lex_state = 0},
  [8673] = {.lex_state = 389},
  [8674] = {.lex_state = 0},
  [8675] = {.lex_state = 230},
  [8676] = {.lex_state = 203},
  [8677] = {.lex_state = 0},
  [8678] = {.lex_state = 203},
  [8679] = {.lex_state = 0},
  [8680] = {.lex_state = 233},
  [8681] = {.lex_state = 0},
  [8682] = {.lex_state = 113},
  [8683] = {.lex_state = 0},
  [8684] = {.lex_state = 389},
  [8685] = {.lex_state = 0},
  [8686] = {.lex_state = 0},
  [8687] = {.lex_state = 0},
  [8688] = {.lex_state = 230},
  [8689] = {.lex_state = 230},
  [8690] = {.lex_state = 0},
  [8691] = {.lex_state = 0},
  [8692] = {.lex_state = 0},
  [8693] = {.lex_state = 0},
  [8694] = {.lex_state = 230},
  [8695] = {.lex_state = 0},
  [8696] = {.lex_state = 0},
  [8697] = {.lex_state = 0},
  [8698] = {.lex_state = 0},
  [8699] = {.lex_state = 0},
  [8700] = {.lex_state = 0},
  [8701] = {.lex_state = 0},
  [8702] = {.lex_state = 0},
  [8703] = {.lex_state = 203},
  [8704] = {.lex_state = 0},
  [8705] = {.lex_state = 0},
  [8706] = {.lex_state = 0},
  [8707] = {.lex_state = 230},
  [8708] = {.lex_state = 0},
  [8709] = {.lex_state = 0},
  [8710] = {.lex_state = 0},
  [8711] = {.lex_state = 0},
  [8712] = {.lex_state = 0},
  [8713] = {.lex_state = 230},
  [8714] = {.lex_state = 0},
  [8715] = {.lex_state = 203},
  [8716] = {.lex_state = 0},
  [8717] = {.lex_state = 0},
  [8718] = {.lex_state = 0},
  [8719] = {.lex_state = 0},
  [8720] = {.lex_state = 0},
  [8721] = {.lex_state = 0, .external_lex_state = 2},
  [8722] = {.lex_state = 113},
  [8723] = {.lex_state = 0},
  [8724] = {.lex_state = 0},
  [8725] = {.lex_state = 0},
  [8726] = {.lex_state = 0},
  [8727] = {.lex_state = 0},
  [8728] = {.lex_state = 230},
  [8729] = {.lex_state = 0},
  [8730] = {.lex_state = 0},
  [8731] = {.lex_state = 0},
  [8732] = {.lex_state = 0},
  [8733] = {.lex_state = 0},
  [8734] = {.lex_state = 0},
  [8735] = {.lex_state = 0},
  [8736] = {.lex_state = 0},
  [8737] = {.lex_state = 389},
  [8738] = {.lex_state = 0},
  [8739] = {.lex_state = 230},
  [8740] = {.lex_state = 0},
  [8741] = {.lex_state = 0},
  [8742] = {.lex_state = 0},
  [8743] = {.lex_state = 0},
  [8744] = {.lex_state = 230},
  [8745] = {.lex_state = 0},
  [8746] = {.lex_state = 230},
  [8747] = {.lex_state = 0},
  [8748] = {.lex_state = 0},
  [8749] = {.lex_state = 203},
  [8750] = {.lex_state = 389},
  [8751] = {.lex_state = 0},
  [8752] = {.lex_state = 0},
  [8753] = {.lex_state = 0},
  [8754] = {.lex_state = 230},
  [8755] = {.lex_state = 0},
  [8756] = {.lex_state = 0},
  [8757] = {.lex_state = 233},
  [8758] = {.lex_state = 0},
  [8759] = {.lex_state = 0},
  [8760] = {.lex_state = 233},
  [8761] = {.lex_state = 203},
  [8762] = {.lex_state = 0},
  [8763] = {.lex_state = 0},
  [8764] = {.lex_state = 0},
  [8765] = {.lex_state = 389},
  [8766] = {.lex_state = 0},
  [8767] = {.lex_state = 389},
  [8768] = {.lex_state = 230},
  [8769] = {.lex_state = 0},
  [8770] = {.lex_state = 0},
  [8771] = {.lex_state = 0},
  [8772] = {.lex_state = 0},
  [8773] = {.lex_state = 230},
  [8774] = {.lex_state = 0},
  [8775] = {.lex_state = 389},
  [8776] = {.lex_state = 0},
  [8777] = {.lex_state = 0},
  [8778] = {.lex_state = 230},
  [8779] = {.lex_state = 0},
  [8780] = {.lex_state = 0},
  [8781] = {.lex_state = 0},
  [8782] = {.lex_state = 389},
  [8783] = {.lex_state = 0},
  [8784] = {.lex_state = 0},
  [8785] = {.lex_state = 0},
  [8786] = {.lex_state = 0},
  [8787] = {.lex_state = 0},
  [8788] = {.lex_state = 0},
  [8789] = {.lex_state = 230},
  [8790] = {.lex_state = 0},
  [8791] = {.lex_state = 113},
  [8792] = {.lex_state = 0},
  [8793] = {.lex_state = 0},
  [8794] = {.lex_state = 0},
  [8795] = {.lex_state = 0},
  [8796] = {.lex_state = 0, .external_lex_state = 2},
  [8797] = {.lex_state = 0},
  [8798] = {.lex_state = 230},
  [8799] = {.lex_state = 233},
  [8800] = {.lex_state = 230},
  [8801] = {.lex_state = 0},
  [8802] = {.lex_state = 230},
  [8803] = {.lex_state = 230},
  [8804] = {.lex_state = 0},
  [8805] = {.lex_state = 389},
  [8806] = {.lex_state = 230},
  [8807] = {.lex_state = 389},
  [8808] = {.lex_state = 230},
  [8809] = {.lex_state = 0},
  [8810] = {.lex_state = 0},
  [8811] = {.lex_state = 233},
  [8812] = {.lex_state = 113},
  [8813] = {.lex_state = 0},
  [8814] = {.lex_state = 230},
  [8815] = {.lex_state = 0},
  [8816] = {.lex_state = 0},
  [8817] = {.lex_state = 233},
  [8818] = {.lex_state = 0},
  [8819] = {.lex_state = 389},
  [8820] = {.lex_state = 233},
  [8821] = {.lex_state = 0},
  [8822] = {.lex_state = 0},
  [8823] = {.lex_state = 203},
  [8824] = {.lex_state = 229},
  [8825] = {.lex_state = 230},
  [8826] = {.lex_state = 0},
  [8827] = {.lex_state = 0},
  [8828] = {.lex_state = 285},
  [8829] = {.lex_state = 203},
  [8830] = {.lex_state = 389},
  [8831] = {.lex_state = 0},
  [8832] = {.lex_state = 389},
  [8833] = {.lex_state = 0},
  [8834] = {.lex_state = 0},
  [8835] = {.lex_state = 0},
  [8836] = {.lex_state = 0},
  [8837] = {.lex_state = 389},
  [8838] = {.lex_state = 203},
  [8839] = {.lex_state = 203},
  [8840] = {.lex_state = 230},
  [8841] = {.lex_state = 0},
  [8842] = {.lex_state = 0},
  [8843] = {.lex_state = 0},
  [8844] = {.lex_state = 0},
  [8845] = {.lex_state = 0},
  [8846] = {.lex_state = 0},
  [8847] = {.lex_state = 0, .external_lex_state = 2},
  [8848] = {.lex_state = 0},
  [8849] = {.lex_state = 230},
  [8850] = {.lex_state = 0},
  [8851] = {.lex_state = 0},
  [8852] = {.lex_state = 0},
  [8853] = {.lex_state = 0},
  [8854] = {.lex_state = 0},
  [8855] = {.lex_state = 0},
  [8856] = {.lex_state = 389},
  [8857] = {.lex_state = 113},
  [8858] = {.lex_state = 0},
  [8859] = {.lex_state = 113},
  [8860] = {.lex_state = 0},
  [8861] = {.lex_state = 0},
  [8862] = {.lex_state = 0},
  [8863] = {.lex_state = 389},
  [8864] = {.lex_state = 203},
  [8865] = {.lex_state = 230},
  [8866] = {.lex_state = 230},
  [8867] = {.lex_state = 0},
  [8868] = {.lex_state = 0},
  [8869] = {.lex_state = 230},
  [8870] = {.lex_state = 389},
  [8871] = {.lex_state = 0},
  [8872] = {.lex_state = 233},
  [8873] = {.lex_state = 203},
  [8874] = {.lex_state = 230},
  [8875] = {.lex_state = 203},
  [8876] = {.lex_state = 230},
  [8877] = {.lex_state = 113},
  [8878] = {.lex_state = 230},
  [8879] = {.lex_state = 0},
  [8880] = {.lex_state = 0},
  [8881] = {.lex_state = 0},
  [8882] = {.lex_state = 0},
  [8883] = {.lex_state = 233},
  [8884] = {.lex_state = 230},
  [8885] = {.lex_state = 203},
  [8886] = {.lex_state = 0},
  [8887] = {.lex_state = 230},
  [8888] = {.lex_state = 230},
  [8889] = {.lex_state = 0},
  [8890] = {.lex_state = 389},
  [8891] = {.lex_state = 0},
  [8892] = {.lex_state = 113},
  [8893] = {.lex_state = 0},
  [8894] = {.lex_state = 0},
  [8895] = {.lex_state = 0, .external_lex_state = 2},
  [8896] = {.lex_state = 0},
  [8897] = {.lex_state = 203},
  [8898] = {.lex_state = 0},
  [8899] = {.lex_state = 0},
  [8900] = {.lex_state = 113},
  [8901] = {.lex_state = 0},
  [8902] = {.lex_state = 0},
  [8903] = {.lex_state = 0, .external_lex_state = 2},
  [8904] = {.lex_state = 0},
  [8905] = {.lex_state = 0},
  [8906] = {.lex_state = 389},
  [8907] = {.lex_state = 389},
  [8908] = {.lex_state = 230},
  [8909] = {.lex_state = 230},
  [8910] = {.lex_state = 0},
  [8911] = {.lex_state = 230},
  [8912] = {.lex_state = 0},
  [8913] = {.lex_state = 201},
  [8914] = {.lex_state = 230},
  [8915] = {.lex_state = 0},
  [8916] = {.lex_state = 389},
  [8917] = {.lex_state = 0, .external_lex_state = 2},
  [8918] = {.lex_state = 203},
  [8919] = {.lex_state = 0},
  [8920] = {.lex_state = 0},
  [8921] = {.lex_state = 0},
  [8922] = {.lex_state = 230},
  [8923] = {.lex_state = 0},
  [8924] = {.lex_state = 0},
  [8925] = {.lex_state = 0},
  [8926] = {.lex_state = 389},
  [8927] = {.lex_state = 0},
  [8928] = {.lex_state = 230},
  [8929] = {.lex_state = 0},
  [8930] = {.lex_state = 0},
  [8931] = {.lex_state = 203},
  [8932] = {.lex_state = 0},
  [8933] = {.lex_state = 0, .external_lex_state = 2},
  [8934] = {.lex_state = 0},
  [8935] = {.lex_state = 0},
  [8936] = {.lex_state = 203},
  [8937] = {.lex_state = 0},
  [8938] = {.lex_state = 389},
  [8939] = {.lex_state = 0},
  [8940] = {.lex_state = 0},
  [8941] = {.lex_state = 0, .external_lex_state = 2},
  [8942] = {.lex_state = 0},
  [8943] = {.lex_state = 230},
  [8944] = {.lex_state = 0},
  [8945] = {.lex_state = 0},
  [8946] = {.lex_state = 389},
  [8947] = {.lex_state = 0},
  [8948] = {.lex_state = 0, .external_lex_state = 2},
  [8949] = {.lex_state = 0},
  [8950] = {.lex_state = 0},
  [8951] = {.lex_state = 0},
  [8952] = {.lex_state = 204},
  [8953] = {.lex_state = 389},
  [8954] = {.lex_state = 0},
  [8955] = {.lex_state = 0, .external_lex_state = 2},
  [8956] = {.lex_state = 203},
  [8957] = {.lex_state = 0},
  [8958] = {.lex_state = 0},
  [8959] = {.lex_state = 0, .external_lex_state = 2},
  [8960] = {.lex_state = 203},
  [8961] = {.lex_state = 0},
  [8962] = {.lex_state = 0},
  [8963] = {.lex_state = 0, .external_lex_state = 2},
  [8964] = {.lex_state = 0},
  [8965] = {.lex_state = 0, .external_lex_state = 2},
  [8966] = {.lex_state = 0},
  [8967] = {.lex_state = 0, .external_lex_state = 2},
  [8968] = {.lex_state = 0},
  [8969] = {.lex_state = 0, .external_lex_state = 2},
  [8970] = {.lex_state = 0},
  [8971] = {.lex_state = 0, .external_lex_state = 2},
  [8972] = {.lex_state = 0},
  [8973] = {.lex_state = 0},
  [8974] = {.lex_state = 0},
  [8975] = {.lex_state = 0, .external_lex_state = 2},
  [8976] = {.lex_state = 0},
  [8977] = {.lex_state = 0, .external_lex_state = 2},
  [8978] = {.lex_state = 0},
  [8979] = {.lex_state = 0},
  [8980] = {.lex_state = 0},
  [8981] = {.lex_state = 389},
  [8982] = {.lex_state = 203},
  [8983] = {.lex_state = 389},
  [8984] = {.lex_state = 389},
  [8985] = {.lex_state = 389},
  [8986] = {.lex_state = 0},
  [8987] = {.lex_state = 0},
  [8988] = {.lex_state = 389},
  [8989] = {.lex_state = 0},
  [8990] = {.lex_state = 389},
  [8991] = {.lex_state = 0},
  [8992] = {.lex_state = 389},
  [8993] = {.lex_state = 389},
  [8994] = {.lex_state = 0},
  [8995] = {.lex_state = 0},
  [8996] = {.lex_state = 0},
  [8997] = {.lex_state = 0},
  [8998] = {.lex_state = 113},
  [8999] = {.lex_state = 0},
  [9000] = {.lex_state = 389},
  [9001] = {.lex_state = 230},
  [9002] = {.lex_state = 230},
  [9003] = {.lex_state = 203},
  [9004] = {.lex_state = 389},
  [9005] = {.lex_state = 201},
  [9006] = {.lex_state = 230},
  [9007] = {.lex_state = 0},
  [9008] = {.lex_state = 389},
  [9009] = {.lex_state = 0},
  [9010] = {.lex_state = 0},
  [9011] = {.lex_state = 0},
  [9012] = {.lex_state = 0},
  [9013] = {.lex_state = 389},
  [9014] = {.lex_state = 0, .external_lex_state = 3},
  [9015] = {.lex_state = 0},
  [9016] = {.lex_state = 0},
  [9017] = {.lex_state = 113},
  [9018] = {.lex_state = 389},
  [9019] = {.lex_state = 230},
  [9020] = {.lex_state = 203},
  [9021] = {.lex_state = 0},
  [9022] = {.lex_state = 0},
  [9023] = {.lex_state = 0},
  [9024] = {.lex_state = 0},
  [9025] = {.lex_state = 233},
  [9026] = {.lex_state = 230},
  [9027] = {.lex_state = 0},
  [9028] = {.lex_state = 230},
  [9029] = {.lex_state = 0},
  [9030] = {.lex_state = 0},
  [9031] = {.lex_state = 0},
  [9032] = {.lex_state = 0},
  [9033] = {.lex_state = 233},
  [9034] = {.lex_state = 0},
  [9035] = {.lex_state = 0},
  [9036] = {.lex_state = 0},
  [9037] = {.lex_state = 0},
  [9038] = {.lex_state = 201},
  [9039] = {.lex_state = 389},
  [9040] = {.lex_state = 201},
  [9041] = {.lex_state = 0},
  [9042] = {.lex_state = 203},
  [9043] = {.lex_state = 0},
  [9044] = {.lex_state = 0},
  [9045] = {.lex_state = 0},
  [9046] = {.lex_state = 0},
  [9047] = {.lex_state = 0},
  [9048] = {.lex_state = 0},
  [9049] = {.lex_state = 233},
  [9050] = {.lex_state = 389},
  [9051] = {.lex_state = 0},
  [9052] = {.lex_state = 230},
  [9053] = {.lex_state = 0},
  [9054] = {.lex_state = 0},
  [9055] = {.lex_state = 0},
  [9056] = {.lex_state = 0},
  [9057] = {.lex_state = 0},
  [9058] = {.lex_state = 389},
  [9059] = {.lex_state = 230},
  [9060] = {.lex_state = 0},
  [9061] = {.lex_state = 389},
  [9062] = {.lex_state = 0},
  [9063] = {.lex_state = 0},
  [9064] = {.lex_state = 0},
  [9065] = {.lex_state = 203},
  [9066] = {.lex_state = 0},
  [9067] = {.lex_state = 0},
  [9068] = {.lex_state = 233},
  [9069] = {.lex_state = 0},
  [9070] = {.lex_state = 0},
  [9071] = {.lex_state = 0},
  [9072] = {.lex_state = 0},
  [9073] = {.lex_state = 389},
  [9074] = {.lex_state = 0},
  [9075] = {.lex_state = 0},
  [9076] = {.lex_state = 0},
  [9077] = {.lex_state = 0},
  [9078] = {.lex_state = 0},
  [9079] = {.lex_state = 0},
  [9080] = {.lex_state = 389},
  [9081] = {.lex_state = 233},
  [9082] = {.lex_state = 0},
  [9083] = {.lex_state = 0},
  [9084] = {.lex_state = 0},
  [9085] = {.lex_state = 0},
  [9086] = {.lex_state = 0},
  [9087] = {.lex_state = 0},
  [9088] = {.lex_state = 230},
  [9089] = {.lex_state = 0},
  [9090] = {.lex_state = 0},
  [9091] = {.lex_state = 230},
  [9092] = {.lex_state = 0},
  [9093] = {.lex_state = 203},
  [9094] = {.lex_state = 0},
  [9095] = {.lex_state = 0},
  [9096] = {.lex_state = 0},
  [9097] = {.lex_state = 0},
  [9098] = {.lex_state = 0},
  [9099] = {.lex_state = 0},
  [9100] = {.lex_state = 0},
  [9101] = {.lex_state = 0},
  [9102] = {.lex_state = 201},
  [9103] = {.lex_state = 0},
  [9104] = {.lex_state = 0},
  [9105] = {.lex_state = 0},
  [9106] = {.lex_state = 0},
  [9107] = {.lex_state = 0},
  [9108] = {.lex_state = 389},
  [9109] = {.lex_state = 0},
  [9110] = {.lex_state = 0},
  [9111] = {.lex_state = 230},
  [9112] = {.lex_state = 0},
  [9113] = {.lex_state = 203},
  [9114] = {.lex_state = 0},
  [9115] = {.lex_state = 0},
  [9116] = {.lex_state = 203},
  [9117] = {.lex_state = 230},
  [9118] = {.lex_state = 0},
  [9119] = {.lex_state = 0},
  [9120] = {.lex_state = 0},
  [9121] = {.lex_state = 0},
  [9122] = {.lex_state = 203},
  [9123] = {.lex_state = 0},
  [9124] = {.lex_state = 230},
  [9125] = {.lex_state = 0},
  [9126] = {.lex_state = 0},
  [9127] = {.lex_state = 113},
  [9128] = {.lex_state = 0, .external_lex_state = 3},
  [9129] = {.lex_state = 0},
  [9130] = {.lex_state = 230},
  [9131] = {.lex_state = 0},
  [9132] = {.lex_state = 0},
  [9133] = {.lex_state = 0},
  [9134] = {.lex_state = 203},
  [9135] = {.lex_state = 0},
  [9136] = {.lex_state = 0},
  [9137] = {.lex_state = 0},
  [9138] = {.lex_state = 0},
  [9139] = {.lex_state = 0},
  [9140] = {.lex_state = 389},
  [9141] = {.lex_state = 230},
  [9142] = {.lex_state = 203},
  [9143] = {.lex_state = 0},
  [9144] = {.lex_state = 0},
  [9145] = {.lex_state = 0},
  [9146] = {.lex_state = 113},
  [9147] = {.lex_state = 0},
  [9148] = {.lex_state = 0},
  [9149] = {.lex_state = 0},
  [9150] = {.lex_state = 0},
  [9151] = {.lex_state = 203},
  [9152] = {.lex_state = 0},
  [9153] = {.lex_state = 0},
  [9154] = {.lex_state = 203},
  [9155] = {.lex_state = 0},
  [9156] = {.lex_state = 0},
  [9157] = {.lex_state = 230},
  [9158] = {.lex_state = 230},
  [9159] = {.lex_state = 0},
  [9160] = {.lex_state = 203},
  [9161] = {.lex_state = 230},
  [9162] = {.lex_state = 113},
  [9163] = {.lex_state = 203},
  [9164] = {.lex_state = 113},
  [9165] = {.lex_state = 0},
  [9166] = {.lex_state = 389},
  [9167] = {.lex_state = 0},
  [9168] = {.lex_state = 230},
  [9169] = {.lex_state = 0},
  [9170] = {.lex_state = 0},
  [9171] = {.lex_state = 0},
  [9172] = {.lex_state = 389},
  [9173] = {.lex_state = 0},
  [9174] = {.lex_state = 0},
  [9175] = {.lex_state = 0},
  [9176] = {.lex_state = 0},
  [9177] = {.lex_state = 0},
  [9178] = {.lex_state = 0},
  [9179] = {.lex_state = 0},
  [9180] = {.lex_state = 0},
  [9181] = {.lex_state = 230},
  [9182] = {.lex_state = 0},
  [9183] = {.lex_state = 0},
  [9184] = {.lex_state = 0},
  [9185] = {.lex_state = 0},
  [9186] = {.lex_state = 0},
  [9187] = {.lex_state = 389},
  [9188] = {.lex_state = 0},
  [9189] = {.lex_state = 0},
  [9190] = {.lex_state = 0},
  [9191] = {.lex_state = 0},
  [9192] = {.lex_state = 0},
  [9193] = {.lex_state = 230},
  [9194] = {.lex_state = 0},
  [9195] = {.lex_state = 0},
  [9196] = {.lex_state = 230},
  [9197] = {.lex_state = 230},
  [9198] = {.lex_state = 230},
  [9199] = {.lex_state = 230},
  [9200] = {.lex_state = 0},
  [9201] = {.lex_state = 203},
  [9202] = {.lex_state = 230},
  [9203] = {.lex_state = 389},
  [9204] = {.lex_state = 0},
  [9205] = {.lex_state = 389},
  [9206] = {.lex_state = 389},
  [9207] = {.lex_state = 203},
  [9208] = {.lex_state = 230},
  [9209] = {.lex_state = 389},
  [9210] = {.lex_state = 0},
  [9211] = {.lex_state = 389},
  [9212] = {.lex_state = 230},
  [9213] = {.lex_state = 0},
  [9214] = {.lex_state = 0},
  [9215] = {.lex_state = 0},
  [9216] = {.lex_state = 203},
  [9217] = {.lex_state = 0},
  [9218] = {.lex_state = 0},
  [9219] = {.lex_state = 230},
  [9220] = {.lex_state = 0},
  [9221] = {.lex_state = 389},
  [9222] = {.lex_state = 0},
  [9223] = {.lex_state = 113},
  [9224] = {.lex_state = 230},
  [9225] = {.lex_state = 230},
  [9226] = {.lex_state = 389},
  [9227] = {.lex_state = 0, .external_lex_state = 3},
  [9228] = {.lex_state = 389},
  [9229] = {.lex_state = 389},
  [9230] = {.lex_state = 233},
  [9231] = {.lex_state = 0},
  [9232] = {.lex_state = 0},
  [9233] = {.lex_state = 0},
  [9234] = {.lex_state = 389},
  [9235] = {.lex_state = 233},
  [9236] = {.lex_state = 233},
  [9237] = {.lex_state = 0},
  [9238] = {.lex_state = 0},
  [9239] = {.lex_state = 233},
  [9240] = {.lex_state = 0},
  [9241] = {.lex_state = 0, .external_lex_state = 3},
  [9242] = {.lex_state = 389},
  [9243] = {.lex_state = 389},
  [9244] = {.lex_state = 389},
  [9245] = {.lex_state = 203},
  [9246] = {.lex_state = 389},
  [9247] = {.lex_state = 0},
  [9248] = {.lex_state = 0},
  [9249] = {.lex_state = 230},
  [9250] = {.lex_state = 0},
  [9251] = {.lex_state = 389},
  [9252] = {.lex_state = 389},
  [9253] = {.lex_state = 230},
  [9254] = {.lex_state = 0},
  [9255] = {.lex_state = 389},
  [9256] = {.lex_state = 0, .external_lex_state = 3},
  [9257] = {.lex_state = 0},
  [9258] = {.lex_state = 233},
  [9259] = {.lex_state = 0},
  [9260] = {.lex_state = 0},
  [9261] = {.lex_state = 0},
  [9262] = {.lex_state = 233},
  [9263] = {.lex_state = 203},
  [9264] = {.lex_state = 389},
  [9265] = {.lex_state = 389},
  [9266] = {.lex_state = 389},
  [9267] = {.lex_state = 113},
  [9268] = {.lex_state = 389},
  [9269] = {.lex_state = 0},
  [9270] = {.lex_state = 0},
  [9271] = {.lex_state = 230},
  [9272] = {.lex_state = 389},
  [9273] = {.lex_state = 0},
  [9274] = {.lex_state = 0},
  [9275] = {.lex_state = 389},
  [9276] = {.lex_state = 0, .external_lex_state = 3},
  [9277] = {.lex_state = 0},
  [9278] = {.lex_state = 389},
  [9279] = {.lex_state = 0},
  [9280] = {.lex_state = 0},
  [9281] = {.lex_state = 0},
  [9282] = {.lex_state = 233},
  [9283] = {.lex_state = 113},
  [9284] = {.lex_state = 389},
  [9285] = {.lex_state = 389},
  [9286] = {.lex_state = 389},
  [9287] = {.lex_state = 0},
  [9288] = {.lex_state = 389},
  [9289] = {.lex_state = 0},
  [9290] = {.lex_state = 0},
  [9291] = {.lex_state = 389},
  [9292] = {.lex_state = 0},
  [9293] = {.lex_state = 0},
  [9294] = {.lex_state = 389},
  [9295] = {.lex_state = 0, .external_lex_state = 3},
  [9296] = {.lex_state = 0},
  [9297] = {.lex_state = 0},
  [9298] = {.lex_state = 113},
  [9299] = {.lex_state = 230},
  [9300] = {.lex_state = 0},
  [9301] = {.lex_state = 233},
  [9302] = {.lex_state = 0},
  [9303] = {.lex_state = 389},
  [9304] = {.lex_state = 389},
  [9305] = {.lex_state = 389},
  [9306] = {.lex_state = 0},
  [9307] = {.lex_state = 389},
  [9308] = {.lex_state = 203},
  [9309] = {.lex_state = 0},
  [9310] = {.lex_state = 389},
  [9311] = {.lex_state = 0},
  [9312] = {.lex_state = 0},
  [9313] = {.lex_state = 389},
  [9314] = {.lex_state = 0, .external_lex_state = 3},
  [9315] = {.lex_state = 0},
  [9316] = {.lex_state = 203},
  [9317] = {.lex_state = 113},
  [9318] = {.lex_state = 230},
  [9319] = {.lex_state = 0},
  [9320] = {.lex_state = 233},
  [9321] = {.lex_state = 0},
  [9322] = {.lex_state = 389},
  [9323] = {.lex_state = 389},
  [9324] = {.lex_state = 389},
  [9325] = {.lex_state = 0},
  [9326] = {.lex_state = 389},
  [9327] = {.lex_state = 0},
  [9328] = {.lex_state = 389},
  [9329] = {.lex_state = 0, .external_lex_state = 2},
  [9330] = {.lex_state = 0, .external_lex_state = 3},
  [9331] = {.lex_state = 0},
  [9332] = {.lex_state = 0},
  [9333] = {.lex_state = 0},
  [9334] = {.lex_state = 0},
  [9335] = {.lex_state = 233},
  [9336] = {.lex_state = 113},
  [9337] = {.lex_state = 389},
  [9338] = {.lex_state = 389},
  [9339] = {.lex_state = 230},
  [9340] = {.lex_state = 389},
  [9341] = {.lex_state = 0},
  [9342] = {.lex_state = 0},
  [9343] = {.lex_state = 0, .external_lex_state = 3},
  [9344] = {.lex_state = 0},
  [9345] = {.lex_state = 0},
  [9346] = {.lex_state = 389},
  [9347] = {.lex_state = 389},
  [9348] = {.lex_state = 389},
  [9349] = {.lex_state = 0, .external_lex_state = 3},
  [9350] = {.lex_state = 0},
  [9351] = {.lex_state = 389},
  [9352] = {.lex_state = 389},
  [9353] = {.lex_state = 389},
  [9354] = {.lex_state = 0, .external_lex_state = 3},
  [9355] = {.lex_state = 0},
  [9356] = {.lex_state = 389},
  [9357] = {.lex_state = 389},
  [9358] = {.lex_state = 389},
  [9359] = {.lex_state = 0, .external_lex_state = 3},
  [9360] = {.lex_state = 0},
  [9361] = {.lex_state = 389},
  [9362] = {.lex_state = 0, .external_lex_state = 3},
  [9363] = {.lex_state = 0},
  [9364] = {.lex_state = 389},
  [9365] = {.lex_state = 0, .external_lex_state = 3},
  [9366] = {.lex_state = 0},
  [9367] = {.lex_state = 0, .external_lex_state = 3},
  [9368] = {.lex_state = 0},
  [9369] = {.lex_state = 0, .external_lex_state = 3},
  [9370] = {.lex_state = 0},
  [9371] = {.lex_state = 0, .external_lex_state = 3},
  [9372] = {.lex_state = 0},
  [9373] = {.lex_state = 0, .external_lex_state = 3},
  [9374] = {.lex_state = 0},
  [9375] = {.lex_state = 0, .external_lex_state = 3},
  [9376] = {.lex_state = 0},
  [9377] = {.lex_state = 0, .external_lex_state = 3},
  [9378] = {.lex_state = 0},
  [9379] = {.lex_state = 0, .external_lex_state = 3},
  [9380] = {.lex_state = 0},
  [9381] = {.lex_state = 0},
  [9382] = {.lex_state = 0},
  [9383] = {.lex_state = 389},
  [9384] = {.lex_state = 389},
  [9385] = {.lex_state = 230},
  [9386] = {.lex_state = 0},
  [9387] = {.lex_state = 389},
  [9388] = {.lex_state = 0},
  [9389] = {.lex_state = 0},
  [9390] = {.lex_state = 0},
  [9391] = {.lex_state = 0},
  [9392] = {.lex_state = 233},
  [9393] = {.lex_state = 0},
  [9394] = {.lex_state = 203},
  [9395] = {.lex_state = 0},
  [9396] = {.lex_state = 230},
  [9397] = {.lex_state = 0, .external_lex_state = 3},
  [9398] = {.lex_state = 0},
  [9399] = {.lex_state = 113},
  [9400] = {.lex_state = 0},
  [9401] = {.lex_state = 0},
  [9402] = {.lex_state = 0},
  [9403] = {.lex_state = 0},
  [9404] = {.lex_state = 0},
  [9405] = {.lex_state = 0},
  [9406] = {.lex_state = 0},
  [9407] = {.lex_state = 0},
  [9408] = {.lex_state = 233},
  [9409] = {.lex_state = 230},
  [9410] = {.lex_state = 0},
  [9411] = {.lex_state = 0},
  [9412] = {.lex_state = 0},
  [9413] = {.lex_state = 0},
  [9414] = {.lex_state = 0},
  [9415] = {.lex_state = 0},
  [9416] = {.lex_state = 203},
  [9417] = {.lex_state = 0},
  [9418] = {.lex_state = 0},
  [9419] = {.lex_state = 0},
  [9420] = {.lex_state = 0},
  [9421] = {.lex_state = 230},
  [9422] = {.lex_state = 0},
  [9423] = {.lex_state = 389},
  [9424] = {.lex_state = 113},
  [9425] = {.lex_state = 389},
  [9426] = {.lex_state = 0},
  [9427] = {.lex_state = 0},
  [9428] = {.lex_state = 0},
  [9429] = {.lex_state = 233},
  [9430] = {.lex_state = 0},
  [9431] = {.lex_state = 113},
  [9432] = {.lex_state = 0},
  [9433] = {.lex_state = 389},
  [9434] = {.lex_state = 389},
  [9435] = {.lex_state = 230},
  [9436] = {.lex_state = 0},
  [9437] = {.lex_state = 0},
  [9438] = {.lex_state = 0},
  [9439] = {.lex_state = 230},
  [9440] = {.lex_state = 0, .external_lex_state = 3},
  [9441] = {.lex_state = 0},
  [9442] = {.lex_state = 230},
  [9443] = {.lex_state = 0},
  [9444] = {.lex_state = 0},
  [9445] = {.lex_state = 389},
  [9446] = {.lex_state = 389},
  [9447] = {.lex_state = 230},
  [9448] = {.lex_state = 0},
  [9449] = {.lex_state = 0},
  [9450] = {.lex_state = 230},
  [9451] = {.lex_state = 0, .external_lex_state = 3},
  [9452] = {.lex_state = 0},
  [9453] = {.lex_state = 0},
  [9454] = {.lex_state = 0},
  [9455] = {.lex_state = 389},
  [9456] = {.lex_state = 230},
  [9457] = {.lex_state = 0},
  [9458] = {.lex_state = 0},
  [9459] = {.lex_state = 230},
  [9460] = {.lex_state = 0, .external_lex_state = 3},
  [9461] = {.lex_state = 0},
  [9462] = {.lex_state = 0},
  [9463] = {.lex_state = 389},
  [9464] = {.lex_state = 230},
  [9465] = {.lex_state = 0},
  [9466] = {.lex_state = 230},
  [9467] = {.lex_state = 230},
  [9468] = {.lex_state = 0, .external_lex_state = 3},
  [9469] = {.lex_state = 0},
  [9470] = {.lex_state = 389},
  [9471] = {.lex_state = 230},
  [9472] = {.lex_state = 0},
  [9473] = {.lex_state = 0},
  [9474] = {.lex_state = 230},
  [9475] = {.lex_state = 0, .external_lex_state = 3},
  [9476] = {.lex_state = 230},
  [9477] = {.lex_state = 113},
  [9478] = {.lex_state = 0},
  [9479] = {.lex_state = 230},
  [9480] = {.lex_state = 0, .external_lex_state = 3},
  [9481] = {.lex_state = 230},
  [9482] = {.lex_state = 230},
  [9483] = {.lex_state = 0, .external_lex_state = 3},
  [9484] = {.lex_state = 0},
  [9485] = {.lex_state = 0, .external_lex_state = 3},
  [9486] = {.lex_state = 0},
  [9487] = {.lex_state = 0, .external_lex_state = 3},
  [9488] = {.lex_state = 230},
  [9489] = {.lex_state = 0, .external_lex_state = 3},
  [9490] = {.lex_state = 0},
  [9491] = {.lex_state = 0, .external_lex_state = 3},
  [9492] = {.lex_state = 0},
  [9493] = {.lex_state = 0, .external_lex_state = 3},
  [9494] = {.lex_state = 0},
  [9495] = {.lex_state = 0, .external_lex_state = 3},
  [9496] = {.lex_state = 0},
  [9497] = {.lex_state = 0, .external_lex_state = 3},
  [9498] = {.lex_state = 0},
  [9499] = {.lex_state = 0, .external_lex_state = 3},
  [9500] = {.lex_state = 230},
  [9501] = {.lex_state = 0, .external_lex_state = 3},
  [9502] = {.lex_state = 230},
  [9503] = {.lex_state = 0, .external_lex_state = 3},
  [9504] = {.lex_state = 0},
  [9505] = {.lex_state = 0, .external_lex_state = 3},
  [9506] = {.lex_state = 203},
  [9507] = {.lex_state = 0, .external_lex_state = 3},
  [9508] = {.lex_state = 389},
  [9509] = {.lex_state = 389},
  [9510] = {.lex_state = 113},
  [9511] = {.lex_state = 389},
  [9512] = {.lex_state = 389},
  [9513] = {.lex_state = 0},
  [9514] = {.lex_state = 389},
  [9515] = {.lex_state = 389},
  [9516] = {.lex_state = 389},
  [9517] = {.lex_state = 389},
  [9518] = {.lex_state = 389},
  [9519] = {.lex_state = 113},
  [9520] = {.lex_state = 389},
  [9521] = {.lex_state = 389},
  [9522] = {.lex_state = 203},
  [9523] = {.lex_state = 389},
  [9524] = {.lex_state = 389},
  [9525] = {.lex_state = 389},
  [9526] = {.lex_state = 389},
  [9527] = {.lex_state = 389},
  [9528] = {.lex_state = 0},
  [9529] = {.lex_state = 389},
  [9530] = {.lex_state = 389},
  [9531] = {.lex_state = 389},
  [9532] = {.lex_state = 389},
  [9533] = {.lex_state = 389},
  [9534] = {.lex_state = 389},
  [9535] = {.lex_state = 389},
  [9536] = {.lex_state = 389},
  [9537] = {.lex_state = 389},
  [9538] = {.lex_state = 389},
  [9539] = {.lex_state = 389},
  [9540] = {.lex_state = 389},
  [9541] = {.lex_state = 389},
  [9542] = {.lex_state = 203},
  [9543] = {.lex_state = 0},
  [9544] = {.lex_state = 0},
  [9545] = {.lex_state = 0},
  [9546] = {.lex_state = 230},
  [9547] = {.lex_state = 0},
  [9548] = {.lex_state = 0},
  [9549] = {.lex_state = 389},
  [9550] = {.lex_state = 389},
  [9551] = {.lex_state = 389},
  [9552] = {.lex_state = 389},
  [9553] = {.lex_state = 389},
  [9554] = {.lex_state = 389},
  [9555] = {.lex_state = 389},
  [9556] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [aux_sym_preproc_include_token1] = ACTIONS(1),
    [aux_sym_preproc_def_token1] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [aux_sym_preproc_if_token1] = ACTIONS(1),
    [aux_sym_preproc_if_token2] = ACTIONS(1),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1),
    [aux_sym_preproc_else_token1] = ACTIONS(1),
    [aux_sym_preproc_elif_token1] = ACTIONS(1),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1),
    [sym_preproc_directive] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [anon_sym_defined] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym___extension__] = ACTIONS(1),
    [anon_sym_typedef] = ACTIONS(1),
    [anon_sym___device__] = ACTIONS(1),
    [anon_sym___host__] = ACTIONS(1),
    [anon_sym___global__] = ACTIONS(1),
    [anon_sym___forceinline__] = ACTIONS(1),
    [anon_sym___noinline__] = ACTIONS(1),
    [anon_sym_virtual] = ACTIONS(1),
    [anon_sym_extern] = ACTIONS(1),
    [anon_sym___attribute__] = ACTIONS(1),
    [anon_sym___attribute] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1),
    [anon_sym___declspec] = ACTIONS(1),
    [anon_sym___based] = ACTIONS(1),
    [anon_sym___cdecl] = ACTIONS(1),
    [anon_sym___clrcall] = ACTIONS(1),
    [anon_sym___stdcall] = ACTIONS(1),
    [anon_sym___fastcall] = ACTIONS(1),
    [anon_sym___thiscall] = ACTIONS(1),
    [anon_sym___vectorcall] = ACTIONS(1),
    [sym_ms_restrict_modifier] = ACTIONS(1),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(1),
    [sym_ms_signed_ptr_modifier] = ACTIONS(1),
    [anon_sym__unaligned] = ACTIONS(1),
    [anon_sym___unaligned] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_signed] = ACTIONS(1),
    [anon_sym_unsigned] = ACTIONS(1),
    [anon_sym_long] = ACTIONS(1),
    [anon_sym_short] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_register] = ACTIONS(1),
    [anon_sym_inline] = ACTIONS(1),
    [anon_sym___inline] = ACTIONS(1),
    [anon_sym___inline__] = ACTIONS(1),
    [anon_sym___forceinline] = ACTIONS(1),
    [anon_sym_thread_local] = ACTIONS(1),
    [anon_sym___thread] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_constexpr] = ACTIONS(1),
    [anon_sym_volatile] = ACTIONS(1),
    [anon_sym_restrict] = ACTIONS(1),
    [anon_sym___restrict__] = ACTIONS(1),
    [anon_sym__Atomic] = ACTIONS(1),
    [anon_sym__Noreturn] = ACTIONS(1),
    [anon_sym_noreturn] = ACTIONS(1),
    [anon_sym__Nonnull] = ACTIONS(1),
    [anon_sym_mutable] = ACTIONS(1),
    [anon_sym_constinit] = ACTIONS(1),
    [anon_sym_consteval] = ACTIONS(1),
    [anon_sym___shared__] = ACTIONS(1),
    [anon_sym___local__] = ACTIONS(1),
    [anon_sym___constant__] = ACTIONS(1),
    [anon_sym___managed__] = ACTIONS(1),
    [anon_sym___grid_constant__] = ACTIONS(1),
    [anon_sym_alignas] = ACTIONS(1),
    [anon_sym__Alignas] = ACTIONS(1),
    [sym_primitive_type] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_goto] = ACTIONS(1),
    [anon_sym___try] = ACTIONS(1),
    [anon_sym___except] = ACTIONS(1),
    [anon_sym___finally] = ACTIONS(1),
    [anon_sym___leave] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_and_eq] = ACTIONS(1),
    [anon_sym_or_eq] = ACTIONS(1),
    [anon_sym_xor_eq] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_compl] = ACTIONS(1),
    [anon_sym_LT_EQ_GT] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_bitor] = ACTIONS(1),
    [anon_sym_xor] = ACTIONS(1),
    [anon_sym_bitand] = ACTIONS(1),
    [anon_sym_not_eq] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_sizeof] = ACTIONS(1),
    [anon_sym___alignof__] = ACTIONS(1),
    [anon_sym___alignof] = ACTIONS(1),
    [anon_sym__alignof] = ACTIONS(1),
    [anon_sym_alignof] = ACTIONS(1),
    [anon_sym__Alignof] = ACTIONS(1),
    [anon_sym_offsetof] = ACTIONS(1),
    [anon_sym__Generic] = ACTIONS(1),
    [anon_sym_asm] = ACTIONS(1),
    [anon_sym___asm__] = ACTIONS(1),
    [anon_sym___asm] = ACTIONS(1),
    [anon_sym___volatile__] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [sym_number_literal] = ACTIONS(1),
    [anon_sym_L_SQUOTE] = ACTIONS(1),
    [anon_sym_u_SQUOTE] = ACTIONS(1),
    [anon_sym_U_SQUOTE] = ACTIONS(1),
    [anon_sym_u8_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_L_DQUOTE] = ACTIONS(1),
    [anon_sym_u_DQUOTE] = ACTIONS(1),
    [anon_sym_U_DQUOTE] = ACTIONS(1),
    [anon_sym_u8_DQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [anon_sym_NULL] = ACTIONS(1),
    [anon_sym_nullptr] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1),
    [anon_sym_decltype] = ACTIONS(1),
    [anon_sym_final] = ACTIONS(1),
    [anon_sym_override] = ACTIONS(1),
    [anon_sym_explicit] = ACTIONS(1),
    [anon_sym_typename] = ACTIONS(1),
    [anon_sym_template] = ACTIONS(1),
    [anon_sym_GT2] = ACTIONS(1),
    [anon_sym_operator] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_delete] = ACTIONS(1),
    [aux_sym_pure_virtual_clause_token1] = ACTIONS(1),
    [anon_sym_friend] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_noexcept] = ACTIONS(1),
    [anon_sym_throw] = ACTIONS(1),
    [anon_sym_namespace] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_static_assert] = ACTIONS(1),
    [anon_sym_concept] = ACTIONS(1),
    [anon_sym_co_return] = ACTIONS(1),
    [anon_sym_co_yield] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_R_DQUOTE] = ACTIONS(1),
    [anon_sym_LR_DQUOTE] = ACTIONS(1),
    [anon_sym_uR_DQUOTE] = ACTIONS(1),
    [anon_sym_UR_DQUOTE] = ACTIONS(1),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1),
    [anon_sym_co_await] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_requires] = ACTIONS(1),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1),
    [anon_sym_LBRACK_RBRACK] = ACTIONS(1),
    [sym_this] = ACTIONS(1),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(1),
    [anon_sym___launch_bounds__] = ACTIONS(1),
    [sym_raw_string_delimiter] = ACTIONS(1),
    [sym_raw_string_content] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_translation_unit] = STATE(8690),
    [sym__top_level_item] = STATE(84),
    [sym_preproc_include] = STATE(84),
    [sym_preproc_def] = STATE(84),
    [sym_preproc_function_def] = STATE(84),
    [sym_preproc_call] = STATE(84),
    [sym_preproc_if] = STATE(84),
    [sym_preproc_ifdef] = STATE(84),
    [sym_function_definition] = STATE(84),
    [sym_declaration] = STATE(84),
    [sym_type_definition] = STATE(84),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5483),
    [sym_linkage_specification] = STATE(84),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1888),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6973),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(84),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2335),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(750),
    [sym__top_level_statement] = STATE(84),
    [sym_labeled_statement] = STATE(84),
    [sym__top_level_expression_statement] = STATE(84),
    [sym_if_statement] = STATE(84),
    [sym_switch_statement] = STATE(84),
    [sym_case_statement] = STATE(84),
    [sym_while_statement] = STATE(84),
    [sym_do_statement] = STATE(84),
    [sym_for_statement] = STATE(84),
    [sym_return_statement] = STATE(84),
    [sym_break_statement] = STATE(84),
    [sym_continue_statement] = STATE(84),
    [sym_goto_statement] = STATE(84),
    [sym_expression] = STATE(5394),
    [sym__string] = STATE(5527),
    [sym_conditional_expression] = STATE(5546),
    [sym_assignment_expression] = STATE(5546),
    [sym_pointer_expression] = STATE(4269),
    [sym_unary_expression] = STATE(5546),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(5546),
    [sym_cast_expression] = STATE(5546),
    [sym_sizeof_expression] = STATE(5546),
    [sym_alignof_expression] = STATE(5546),
    [sym_offsetof_expression] = STATE(5546),
    [sym_generic_expression] = STATE(5546),
    [sym_subscript_expression] = STATE(4269),
    [sym_call_expression] = STATE(4269),
    [sym_gnu_asm_expression] = STATE(5546),
    [sym_extension_expression] = STATE(5546),
    [sym_field_expression] = STATE(4269),
    [sym_compound_literal_expression] = STATE(5546),
    [sym_parenthesized_expression] = STATE(4269),
    [sym_char_literal] = STATE(5527),
    [sym_concatenated_string] = STATE(5527),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(5546),
    [sym__empty_declaration] = STATE(84),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1764),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(84),
    [sym_template_instantiation] = STATE(84),
    [sym_operator_cast] = STATE(7391),
    [sym__constructor_specifiers] = STATE(1764),
    [sym_operator_cast_definition] = STATE(84),
    [sym_operator_cast_declaration] = STATE(84),
    [sym_constructor_or_destructor_definition] = STATE(84),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5485),
    [sym_namespace_definition] = STATE(84),
    [sym_namespace_alias_definition] = STATE(84),
    [sym_using_declaration] = STATE(84),
    [sym_alias_declaration] = STATE(84),
    [sym_static_assert_declaration] = STATE(84),
    [sym_concept_definition] = STATE(84),
    [sym_for_range_loop] = STATE(84),
    [sym_co_return_statement] = STATE(84),
    [sym_co_yield_statement] = STATE(84),
    [sym_throw_statement] = STATE(84),
    [sym_try_statement] = STATE(84),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(5546),
    [sym_new_expression] = STATE(5546),
    [sym_delete_expression] = STATE(5546),
    [sym_requires_clause] = STATE(5546),
    [sym_requires_expression] = STATE(5546),
    [sym_lambda_expression] = STATE(5546),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(5546),
    [sym_parameter_pack_expansion] = STATE(5546),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(4253),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7391),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(4269),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_translation_unit_repeat1] = STATE(84),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1764),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_preproc_include_token1] = ACTIONS(9),
    [aux_sym_preproc_def_token1] = ACTIONS(11),
    [aux_sym_preproc_if_token1] = ACTIONS(13),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(15),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(15),
    [sym_preproc_directive] = ACTIONS(17),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym___extension__] = ACTIONS(35),
    [anon_sym_typedef] = ACTIONS(37),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(41),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(63),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(113),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(119),
    [sym_false] = ACTIONS(119),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(131),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_namespace] = ACTIONS(141),
    [anon_sym_using] = ACTIONS(143),
    [anon_sym_static_assert] = ACTIONS(145),
    [anon_sym_concept] = ACTIONS(147),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(119),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(2)] = {
    [sym__block_item] = STATE(52),
    [sym_preproc_include] = STATE(52),
    [sym_preproc_def] = STATE(52),
    [sym_preproc_function_def] = STATE(52),
    [sym_preproc_call] = STATE(52),
    [sym_preproc_if] = STATE(52),
    [sym_preproc_ifdef] = STATE(52),
    [sym_function_definition] = STATE(52),
    [sym_declaration] = STATE(52),
    [sym_type_definition] = STATE(52),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(52),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(52),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(52),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(52),
    [sym_template_instantiation] = STATE(52),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(52),
    [sym_operator_cast_declaration] = STATE(52),
    [sym_constructor_or_destructor_definition] = STATE(52),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(52),
    [sym_namespace_alias_definition] = STATE(52),
    [sym_using_declaration] = STATE(52),
    [sym_alias_declaration] = STATE(52),
    [sym_static_assert_declaration] = STATE(52),
    [sym_concept_definition] = STATE(52),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(52),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(187),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(3)] = {
    [sym__block_item] = STATE(64),
    [sym_preproc_include] = STATE(64),
    [sym_preproc_def] = STATE(64),
    [sym_preproc_function_def] = STATE(64),
    [sym_preproc_call] = STATE(64),
    [sym_preproc_if] = STATE(64),
    [sym_preproc_ifdef] = STATE(64),
    [sym_function_definition] = STATE(64),
    [sym_declaration] = STATE(64),
    [sym_type_definition] = STATE(64),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(64),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(64),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(64),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(64),
    [sym_template_instantiation] = STATE(64),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(64),
    [sym_operator_cast_declaration] = STATE(64),
    [sym_constructor_or_destructor_definition] = STATE(64),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(64),
    [sym_namespace_alias_definition] = STATE(64),
    [sym_using_declaration] = STATE(64),
    [sym_alias_declaration] = STATE(64),
    [sym_static_assert_declaration] = STATE(64),
    [sym_concept_definition] = STATE(64),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(64),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(243),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(4)] = {
    [sym__block_item] = STATE(44),
    [sym_preproc_include] = STATE(44),
    [sym_preproc_def] = STATE(44),
    [sym_preproc_function_def] = STATE(44),
    [sym_preproc_call] = STATE(44),
    [sym_preproc_if] = STATE(44),
    [sym_preproc_ifdef] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_declaration] = STATE(44),
    [sym_type_definition] = STATE(44),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(44),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(44),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(44),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(44),
    [sym_template_instantiation] = STATE(44),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(44),
    [sym_operator_cast_declaration] = STATE(44),
    [sym_constructor_or_destructor_definition] = STATE(44),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(44),
    [sym_namespace_alias_definition] = STATE(44),
    [sym_using_declaration] = STATE(44),
    [sym_alias_declaration] = STATE(44),
    [sym_static_assert_declaration] = STATE(44),
    [sym_concept_definition] = STATE(44),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(44),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(245),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(5)] = {
    [sym__block_item] = STATE(57),
    [sym_preproc_include] = STATE(57),
    [sym_preproc_def] = STATE(57),
    [sym_preproc_function_def] = STATE(57),
    [sym_preproc_call] = STATE(57),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_ifdef] = STATE(57),
    [sym_function_definition] = STATE(57),
    [sym_declaration] = STATE(57),
    [sym_type_definition] = STATE(57),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(57),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(57),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(57),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(57),
    [sym_template_instantiation] = STATE(57),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(57),
    [sym_operator_cast_declaration] = STATE(57),
    [sym_constructor_or_destructor_definition] = STATE(57),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(57),
    [sym_namespace_alias_definition] = STATE(57),
    [sym_using_declaration] = STATE(57),
    [sym_alias_declaration] = STATE(57),
    [sym_static_assert_declaration] = STATE(57),
    [sym_concept_definition] = STATE(57),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(57),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(247),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(6)] = {
    [sym__block_item] = STATE(57),
    [sym_preproc_include] = STATE(57),
    [sym_preproc_def] = STATE(57),
    [sym_preproc_function_def] = STATE(57),
    [sym_preproc_call] = STATE(57),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_ifdef] = STATE(57),
    [sym_function_definition] = STATE(57),
    [sym_declaration] = STATE(57),
    [sym_type_definition] = STATE(57),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(57),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(57),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(57),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(57),
    [sym_template_instantiation] = STATE(57),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(57),
    [sym_operator_cast_declaration] = STATE(57),
    [sym_constructor_or_destructor_definition] = STATE(57),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(57),
    [sym_namespace_alias_definition] = STATE(57),
    [sym_using_declaration] = STATE(57),
    [sym_alias_declaration] = STATE(57),
    [sym_static_assert_declaration] = STATE(57),
    [sym_concept_definition] = STATE(57),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(57),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(249),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(7)] = {
    [sym__block_item] = STATE(52),
    [sym_preproc_include] = STATE(52),
    [sym_preproc_def] = STATE(52),
    [sym_preproc_function_def] = STATE(52),
    [sym_preproc_call] = STATE(52),
    [sym_preproc_if] = STATE(52),
    [sym_preproc_ifdef] = STATE(52),
    [sym_function_definition] = STATE(52),
    [sym_declaration] = STATE(52),
    [sym_type_definition] = STATE(52),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(52),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(52),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(52),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(52),
    [sym_template_instantiation] = STATE(52),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(52),
    [sym_operator_cast_declaration] = STATE(52),
    [sym_constructor_or_destructor_definition] = STATE(52),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(52),
    [sym_namespace_alias_definition] = STATE(52),
    [sym_using_declaration] = STATE(52),
    [sym_alias_declaration] = STATE(52),
    [sym_static_assert_declaration] = STATE(52),
    [sym_concept_definition] = STATE(52),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(52),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(8)] = {
    [sym__block_item] = STATE(34),
    [sym_preproc_include] = STATE(34),
    [sym_preproc_def] = STATE(34),
    [sym_preproc_function_def] = STATE(34),
    [sym_preproc_call] = STATE(34),
    [sym_preproc_if] = STATE(34),
    [sym_preproc_ifdef] = STATE(34),
    [sym_function_definition] = STATE(34),
    [sym_declaration] = STATE(34),
    [sym_type_definition] = STATE(34),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(34),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(34),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(34),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(34),
    [sym_template_instantiation] = STATE(34),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(34),
    [sym_operator_cast_declaration] = STATE(34),
    [sym_constructor_or_destructor_definition] = STATE(34),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(34),
    [sym_namespace_alias_definition] = STATE(34),
    [sym_using_declaration] = STATE(34),
    [sym_alias_declaration] = STATE(34),
    [sym_static_assert_declaration] = STATE(34),
    [sym_concept_definition] = STATE(34),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(34),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(253),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(9)] = {
    [sym__block_item] = STATE(54),
    [sym_preproc_include] = STATE(54),
    [sym_preproc_def] = STATE(54),
    [sym_preproc_function_def] = STATE(54),
    [sym_preproc_call] = STATE(54),
    [sym_preproc_if] = STATE(54),
    [sym_preproc_ifdef] = STATE(54),
    [sym_function_definition] = STATE(54),
    [sym_declaration] = STATE(54),
    [sym_type_definition] = STATE(54),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(54),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(54),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(54),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(54),
    [sym_template_instantiation] = STATE(54),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(54),
    [sym_operator_cast_declaration] = STATE(54),
    [sym_constructor_or_destructor_definition] = STATE(54),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(54),
    [sym_namespace_alias_definition] = STATE(54),
    [sym_using_declaration] = STATE(54),
    [sym_alias_declaration] = STATE(54),
    [sym_static_assert_declaration] = STATE(54),
    [sym_concept_definition] = STATE(54),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(54),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(10)] = {
    [sym__block_item] = STATE(79),
    [sym_preproc_include] = STATE(79),
    [sym_preproc_def] = STATE(79),
    [sym_preproc_function_def] = STATE(79),
    [sym_preproc_call] = STATE(79),
    [sym_preproc_if] = STATE(79),
    [sym_preproc_ifdef] = STATE(79),
    [sym_function_definition] = STATE(79),
    [sym_declaration] = STATE(79),
    [sym_type_definition] = STATE(79),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(79),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(79),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(79),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(79),
    [sym_template_instantiation] = STATE(79),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(79),
    [sym_operator_cast_declaration] = STATE(79),
    [sym_constructor_or_destructor_definition] = STATE(79),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(79),
    [sym_namespace_alias_definition] = STATE(79),
    [sym_using_declaration] = STATE(79),
    [sym_alias_declaration] = STATE(79),
    [sym_static_assert_declaration] = STATE(79),
    [sym_concept_definition] = STATE(79),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(79),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(257),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(11)] = {
    [sym__block_item] = STATE(44),
    [sym_preproc_include] = STATE(44),
    [sym_preproc_def] = STATE(44),
    [sym_preproc_function_def] = STATE(44),
    [sym_preproc_call] = STATE(44),
    [sym_preproc_if] = STATE(44),
    [sym_preproc_ifdef] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_declaration] = STATE(44),
    [sym_type_definition] = STATE(44),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(44),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(44),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(44),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(44),
    [sym_template_instantiation] = STATE(44),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(44),
    [sym_operator_cast_declaration] = STATE(44),
    [sym_constructor_or_destructor_definition] = STATE(44),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(44),
    [sym_namespace_alias_definition] = STATE(44),
    [sym_using_declaration] = STATE(44),
    [sym_alias_declaration] = STATE(44),
    [sym_static_assert_declaration] = STATE(44),
    [sym_concept_definition] = STATE(44),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(44),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(259),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(12)] = {
    [sym__block_item] = STATE(79),
    [sym_preproc_include] = STATE(79),
    [sym_preproc_def] = STATE(79),
    [sym_preproc_function_def] = STATE(79),
    [sym_preproc_call] = STATE(79),
    [sym_preproc_if] = STATE(79),
    [sym_preproc_ifdef] = STATE(79),
    [sym_function_definition] = STATE(79),
    [sym_declaration] = STATE(79),
    [sym_type_definition] = STATE(79),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(79),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(79),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4874),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(79),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(79),
    [sym_template_instantiation] = STATE(79),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(79),
    [sym_operator_cast_declaration] = STATE(79),
    [sym_constructor_or_destructor_definition] = STATE(79),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(79),
    [sym_namespace_alias_definition] = STATE(79),
    [sym_using_declaration] = STATE(79),
    [sym_alias_declaration] = STATE(79),
    [sym_static_assert_declaration] = STATE(79),
    [sym_concept_definition] = STATE(79),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(79),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(163),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(169),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_RBRACE] = ACTIONS(261),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(13)] = {
    [sym__block_item] = STATE(21),
    [sym_preproc_include] = STATE(21),
    [sym_preproc_def] = STATE(21),
    [sym_preproc_function_def] = STATE(21),
    [sym_preproc_call] = STATE(21),
    [sym_preproc_if] = STATE(21),
    [sym_preproc_ifdef] = STATE(21),
    [sym_preproc_else] = STATE(8897),
    [sym_preproc_elif] = STATE(8897),
    [sym_preproc_elifdef] = STATE(8897),
    [sym_function_definition] = STATE(21),
    [sym_declaration] = STATE(21),
    [sym_type_definition] = STATE(21),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(21),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(21),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(21),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(21),
    [sym_template_instantiation] = STATE(21),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(21),
    [sym_operator_cast_declaration] = STATE(21),
    [sym_constructor_or_destructor_definition] = STATE(21),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(21),
    [sym_namespace_alias_definition] = STATE(21),
    [sym_using_declaration] = STATE(21),
    [sym_alias_declaration] = STATE(21),
    [sym_static_assert_declaration] = STATE(21),
    [sym_concept_definition] = STATE(21),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(21),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(271),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(14)] = {
    [sym__block_item] = STATE(15),
    [sym_preproc_include] = STATE(15),
    [sym_preproc_def] = STATE(15),
    [sym_preproc_function_def] = STATE(15),
    [sym_preproc_call] = STATE(15),
    [sym_preproc_if] = STATE(15),
    [sym_preproc_ifdef] = STATE(15),
    [sym_preproc_else] = STATE(9245),
    [sym_preproc_elif] = STATE(9245),
    [sym_preproc_elifdef] = STATE(9245),
    [sym_function_definition] = STATE(15),
    [sym_declaration] = STATE(15),
    [sym_type_definition] = STATE(15),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(15),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(15),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(15),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(15),
    [sym_template_instantiation] = STATE(15),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(15),
    [sym_operator_cast_declaration] = STATE(15),
    [sym_constructor_or_destructor_definition] = STATE(15),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(15),
    [sym_namespace_alias_definition] = STATE(15),
    [sym_using_declaration] = STATE(15),
    [sym_alias_declaration] = STATE(15),
    [sym_static_assert_declaration] = STATE(15),
    [sym_concept_definition] = STATE(15),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(15),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(339),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(15)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(9316),
    [sym_preproc_elif] = STATE(9316),
    [sym_preproc_elifdef] = STATE(9316),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(341),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(16)] = {
    [sym__block_item] = STATE(18),
    [sym_preproc_include] = STATE(18),
    [sym_preproc_def] = STATE(18),
    [sym_preproc_function_def] = STATE(18),
    [sym_preproc_call] = STATE(18),
    [sym_preproc_if] = STATE(18),
    [sym_preproc_ifdef] = STATE(18),
    [sym_preproc_else] = STATE(9542),
    [sym_preproc_elif] = STATE(9542),
    [sym_preproc_elifdef] = STATE(9542),
    [sym_function_definition] = STATE(18),
    [sym_declaration] = STATE(18),
    [sym_type_definition] = STATE(18),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(18),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(18),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(18),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(18),
    [sym_template_instantiation] = STATE(18),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(18),
    [sym_operator_cast_declaration] = STATE(18),
    [sym_constructor_or_destructor_definition] = STATE(18),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(18),
    [sym_namespace_alias_definition] = STATE(18),
    [sym_using_declaration] = STATE(18),
    [sym_alias_declaration] = STATE(18),
    [sym_static_assert_declaration] = STATE(18),
    [sym_concept_definition] = STATE(18),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(18),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(343),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(17)] = {
    [sym__block_item] = STATE(19),
    [sym_preproc_include] = STATE(19),
    [sym_preproc_def] = STATE(19),
    [sym_preproc_function_def] = STATE(19),
    [sym_preproc_call] = STATE(19),
    [sym_preproc_if] = STATE(19),
    [sym_preproc_ifdef] = STATE(19),
    [sym_preproc_else] = STATE(9065),
    [sym_preproc_elif] = STATE(9065),
    [sym_preproc_elifdef] = STATE(9065),
    [sym_function_definition] = STATE(19),
    [sym_declaration] = STATE(19),
    [sym_type_definition] = STATE(19),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(19),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(19),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(19),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(19),
    [sym_template_instantiation] = STATE(19),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(19),
    [sym_operator_cast_declaration] = STATE(19),
    [sym_constructor_or_destructor_definition] = STATE(19),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(19),
    [sym_namespace_alias_definition] = STATE(19),
    [sym_using_declaration] = STATE(19),
    [sym_alias_declaration] = STATE(19),
    [sym_static_assert_declaration] = STATE(19),
    [sym_concept_definition] = STATE(19),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(19),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(345),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(18)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(9093),
    [sym_preproc_elif] = STATE(9093),
    [sym_preproc_elifdef] = STATE(9093),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(19)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(9122),
    [sym_preproc_elif] = STATE(9122),
    [sym_preproc_elifdef] = STATE(9122),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(349),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(20)] = {
    [sym__block_item] = STATE(22),
    [sym_preproc_include] = STATE(22),
    [sym_preproc_def] = STATE(22),
    [sym_preproc_function_def] = STATE(22),
    [sym_preproc_call] = STATE(22),
    [sym_preproc_if] = STATE(22),
    [sym_preproc_ifdef] = STATE(22),
    [sym_preproc_else] = STATE(8715),
    [sym_preproc_elif] = STATE(8715),
    [sym_preproc_elifdef] = STATE(8715),
    [sym_function_definition] = STATE(22),
    [sym_declaration] = STATE(22),
    [sym_type_definition] = STATE(22),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(22),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(22),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(22),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(22),
    [sym_template_instantiation] = STATE(22),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(22),
    [sym_operator_cast_declaration] = STATE(22),
    [sym_constructor_or_destructor_definition] = STATE(22),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(22),
    [sym_namespace_alias_definition] = STATE(22),
    [sym_using_declaration] = STATE(22),
    [sym_alias_declaration] = STATE(22),
    [sym_static_assert_declaration] = STATE(22),
    [sym_concept_definition] = STATE(22),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(22),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(21)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8761),
    [sym_preproc_elif] = STATE(8761),
    [sym_preproc_elifdef] = STATE(8761),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(353),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(22)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8648),
    [sym_preproc_elif] = STATE(8648),
    [sym_preproc_elifdef] = STATE(8648),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(355),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(23)] = {
    [sym__block_item] = STATE(24),
    [sym_preproc_include] = STATE(24),
    [sym_preproc_def] = STATE(24),
    [sym_preproc_function_def] = STATE(24),
    [sym_preproc_call] = STATE(24),
    [sym_preproc_if] = STATE(24),
    [sym_preproc_ifdef] = STATE(24),
    [sym_preproc_else] = STATE(8645),
    [sym_preproc_elif] = STATE(8645),
    [sym_preproc_elifdef] = STATE(8645),
    [sym_function_definition] = STATE(24),
    [sym_declaration] = STATE(24),
    [sym_type_definition] = STATE(24),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(24),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(24),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(24),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(24),
    [sym_template_instantiation] = STATE(24),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(24),
    [sym_operator_cast_declaration] = STATE(24),
    [sym_constructor_or_destructor_definition] = STATE(24),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(24),
    [sym_namespace_alias_definition] = STATE(24),
    [sym_using_declaration] = STATE(24),
    [sym_alias_declaration] = STATE(24),
    [sym_static_assert_declaration] = STATE(24),
    [sym_concept_definition] = STATE(24),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(24),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(357),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(24)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8839),
    [sym_preproc_elif] = STATE(8839),
    [sym_preproc_elifdef] = STATE(8839),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(359),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(25)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(9113),
    [sym_preproc_elif] = STATE(9113),
    [sym_preproc_elifdef] = STATE(9113),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(361),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(26)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8875),
    [sym_preproc_elif] = STATE(8875),
    [sym_preproc_elifdef] = STATE(8875),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(363),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(27)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8600),
    [sym_preproc_elif] = STATE(8600),
    [sym_preproc_elifdef] = STATE(8600),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(365),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(28)] = {
    [sym__block_item] = STATE(29),
    [sym_preproc_include] = STATE(29),
    [sym_preproc_def] = STATE(29),
    [sym_preproc_function_def] = STATE(29),
    [sym_preproc_call] = STATE(29),
    [sym_preproc_if] = STATE(29),
    [sym_preproc_ifdef] = STATE(29),
    [sym_preproc_else] = STATE(8582),
    [sym_preproc_elif] = STATE(8582),
    [sym_preproc_elifdef] = STATE(8582),
    [sym_function_definition] = STATE(29),
    [sym_declaration] = STATE(29),
    [sym_type_definition] = STATE(29),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(29),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(29),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(29),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(29),
    [sym_template_instantiation] = STATE(29),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(29),
    [sym_operator_cast_declaration] = STATE(29),
    [sym_constructor_or_destructor_definition] = STATE(29),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(29),
    [sym_namespace_alias_definition] = STATE(29),
    [sym_using_declaration] = STATE(29),
    [sym_alias_declaration] = STATE(29),
    [sym_static_assert_declaration] = STATE(29),
    [sym_concept_definition] = STATE(29),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(29),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(367),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(29)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(9142),
    [sym_preproc_elif] = STATE(9142),
    [sym_preproc_elifdef] = STATE(9142),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(369),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(30)] = {
    [sym__block_item] = STATE(25),
    [sym_preproc_include] = STATE(25),
    [sym_preproc_def] = STATE(25),
    [sym_preproc_function_def] = STATE(25),
    [sym_preproc_call] = STATE(25),
    [sym_preproc_if] = STATE(25),
    [sym_preproc_ifdef] = STATE(25),
    [sym_preproc_else] = STATE(8623),
    [sym_preproc_elif] = STATE(8623),
    [sym_preproc_elifdef] = STATE(8623),
    [sym_function_definition] = STATE(25),
    [sym_declaration] = STATE(25),
    [sym_type_definition] = STATE(25),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(25),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(25),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(25),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(25),
    [sym_template_instantiation] = STATE(25),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(25),
    [sym_operator_cast_declaration] = STATE(25),
    [sym_constructor_or_destructor_definition] = STATE(25),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(25),
    [sym_namespace_alias_definition] = STATE(25),
    [sym_using_declaration] = STATE(25),
    [sym_alias_declaration] = STATE(25),
    [sym_static_assert_declaration] = STATE(25),
    [sym_concept_definition] = STATE(25),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(25),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(371),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(31)] = {
    [sym__block_item] = STATE(27),
    [sym_preproc_include] = STATE(27),
    [sym_preproc_def] = STATE(27),
    [sym_preproc_function_def] = STATE(27),
    [sym_preproc_call] = STATE(27),
    [sym_preproc_if] = STATE(27),
    [sym_preproc_ifdef] = STATE(27),
    [sym_preproc_else] = STATE(8838),
    [sym_preproc_elif] = STATE(8838),
    [sym_preproc_elifdef] = STATE(8838),
    [sym_function_definition] = STATE(27),
    [sym_declaration] = STATE(27),
    [sym_type_definition] = STATE(27),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(27),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(27),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(27),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(27),
    [sym_template_instantiation] = STATE(27),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(27),
    [sym_operator_cast_declaration] = STATE(27),
    [sym_constructor_or_destructor_definition] = STATE(27),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(27),
    [sym_namespace_alias_definition] = STATE(27),
    [sym_using_declaration] = STATE(27),
    [sym_alias_declaration] = STATE(27),
    [sym_static_assert_declaration] = STATE(27),
    [sym_concept_definition] = STATE(27),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(27),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(32)] = {
    [sym__block_item] = STATE(26),
    [sym_preproc_include] = STATE(26),
    [sym_preproc_def] = STATE(26),
    [sym_preproc_function_def] = STATE(26),
    [sym_preproc_call] = STATE(26),
    [sym_preproc_if] = STATE(26),
    [sym_preproc_ifdef] = STATE(26),
    [sym_preproc_else] = STATE(9416),
    [sym_preproc_elif] = STATE(9416),
    [sym_preproc_elifdef] = STATE(9416),
    [sym_function_definition] = STATE(26),
    [sym_declaration] = STATE(26),
    [sym_type_definition] = STATE(26),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(26),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(26),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(26),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(26),
    [sym_template_instantiation] = STATE(26),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(26),
    [sym_operator_cast_declaration] = STATE(26),
    [sym_constructor_or_destructor_definition] = STATE(26),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(26),
    [sym_namespace_alias_definition] = STATE(26),
    [sym_using_declaration] = STATE(26),
    [sym_alias_declaration] = STATE(26),
    [sym_static_assert_declaration] = STATE(26),
    [sym_concept_definition] = STATE(26),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(26),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(263),
    [aux_sym_preproc_include_token1] = ACTIONS(265),
    [aux_sym_preproc_def_token1] = ACTIONS(267),
    [aux_sym_preproc_if_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token2] = ACTIONS(375),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(273),
    [aux_sym_preproc_else_token1] = ACTIONS(275),
    [aux_sym_preproc_elif_token1] = ACTIONS(277),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(279),
    [sym_preproc_directive] = ACTIONS(281),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(285),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(289),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(293),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(321),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(327),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(331),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(33)] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6969),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(262),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1753),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1753),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(377),
    [aux_sym_preproc_include_token1] = ACTIONS(380),
    [aux_sym_preproc_def_token1] = ACTIONS(383),
    [aux_sym_preproc_if_token1] = ACTIONS(386),
    [aux_sym_preproc_if_token2] = ACTIONS(389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(391),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(391),
    [aux_sym_preproc_else_token1] = ACTIONS(389),
    [aux_sym_preproc_elif_token1] = ACTIONS(389),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(389),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(389),
    [sym_preproc_directive] = ACTIONS(394),
    [anon_sym_LPAREN2] = ACTIONS(397),
    [anon_sym_BANG] = ACTIONS(400),
    [anon_sym_TILDE] = ACTIONS(403),
    [anon_sym_DASH] = ACTIONS(406),
    [anon_sym_PLUS] = ACTIONS(406),
    [anon_sym_STAR] = ACTIONS(409),
    [anon_sym_AMP_AMP] = ACTIONS(412),
    [anon_sym_AMP] = ACTIONS(415),
    [anon_sym_SEMI] = ACTIONS(418),
    [anon_sym___extension__] = ACTIONS(421),
    [anon_sym_typedef] = ACTIONS(424),
    [anon_sym___device__] = ACTIONS(427),
    [anon_sym___host__] = ACTIONS(427),
    [anon_sym___global__] = ACTIONS(427),
    [anon_sym___forceinline__] = ACTIONS(427),
    [anon_sym___noinline__] = ACTIONS(427),
    [anon_sym_virtual] = ACTIONS(427),
    [anon_sym_extern] = ACTIONS(430),
    [anon_sym___attribute__] = ACTIONS(433),
    [anon_sym___attribute] = ACTIONS(433),
    [anon_sym_COLON_COLON] = ACTIONS(436),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(439),
    [anon_sym___declspec] = ACTIONS(442),
    [anon_sym___based] = ACTIONS(445),
    [anon_sym___cdecl] = ACTIONS(448),
    [anon_sym___clrcall] = ACTIONS(448),
    [anon_sym___stdcall] = ACTIONS(448),
    [anon_sym___fastcall] = ACTIONS(448),
    [anon_sym___thiscall] = ACTIONS(448),
    [anon_sym___vectorcall] = ACTIONS(448),
    [anon_sym_LBRACE] = ACTIONS(451),
    [anon_sym_signed] = ACTIONS(454),
    [anon_sym_unsigned] = ACTIONS(454),
    [anon_sym_long] = ACTIONS(454),
    [anon_sym_short] = ACTIONS(454),
    [anon_sym_LBRACK] = ACTIONS(457),
    [anon_sym_static] = ACTIONS(460),
    [anon_sym_register] = ACTIONS(460),
    [anon_sym_inline] = ACTIONS(463),
    [anon_sym___inline] = ACTIONS(460),
    [anon_sym___inline__] = ACTIONS(460),
    [anon_sym___forceinline] = ACTIONS(460),
    [anon_sym_thread_local] = ACTIONS(460),
    [anon_sym___thread] = ACTIONS(460),
    [anon_sym_const] = ACTIONS(466),
    [anon_sym_constexpr] = ACTIONS(466),
    [anon_sym_volatile] = ACTIONS(466),
    [anon_sym_restrict] = ACTIONS(466),
    [anon_sym___restrict__] = ACTIONS(466),
    [anon_sym__Atomic] = ACTIONS(466),
    [anon_sym__Noreturn] = ACTIONS(466),
    [anon_sym_noreturn] = ACTIONS(466),
    [anon_sym__Nonnull] = ACTIONS(466),
    [anon_sym_mutable] = ACTIONS(466),
    [anon_sym_constinit] = ACTIONS(466),
    [anon_sym_consteval] = ACTIONS(466),
    [anon_sym___shared__] = ACTIONS(466),
    [anon_sym___local__] = ACTIONS(466),
    [anon_sym___constant__] = ACTIONS(466),
    [anon_sym___managed__] = ACTIONS(466),
    [anon_sym___grid_constant__] = ACTIONS(466),
    [anon_sym_alignas] = ACTIONS(469),
    [anon_sym__Alignas] = ACTIONS(469),
    [sym_primitive_type] = ACTIONS(472),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_class] = ACTIONS(478),
    [anon_sym_struct] = ACTIONS(481),
    [anon_sym_union] = ACTIONS(484),
    [anon_sym_if] = ACTIONS(487),
    [anon_sym_switch] = ACTIONS(490),
    [anon_sym_case] = ACTIONS(493),
    [anon_sym_default] = ACTIONS(496),
    [anon_sym_while] = ACTIONS(499),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_return] = ACTIONS(508),
    [anon_sym_break] = ACTIONS(511),
    [anon_sym_continue] = ACTIONS(514),
    [anon_sym_goto] = ACTIONS(517),
    [anon_sym___try] = ACTIONS(520),
    [anon_sym___leave] = ACTIONS(523),
    [anon_sym_not] = ACTIONS(406),
    [anon_sym_compl] = ACTIONS(406),
    [anon_sym_DASH_DASH] = ACTIONS(526),
    [anon_sym_PLUS_PLUS] = ACTIONS(526),
    [anon_sym_sizeof] = ACTIONS(529),
    [anon_sym___alignof__] = ACTIONS(532),
    [anon_sym___alignof] = ACTIONS(532),
    [anon_sym__alignof] = ACTIONS(532),
    [anon_sym_alignof] = ACTIONS(532),
    [anon_sym__Alignof] = ACTIONS(532),
    [anon_sym_offsetof] = ACTIONS(535),
    [anon_sym__Generic] = ACTIONS(538),
    [anon_sym_asm] = ACTIONS(541),
    [anon_sym___asm__] = ACTIONS(541),
    [anon_sym___asm] = ACTIONS(541),
    [sym_number_literal] = ACTIONS(544),
    [anon_sym_L_SQUOTE] = ACTIONS(547),
    [anon_sym_u_SQUOTE] = ACTIONS(547),
    [anon_sym_U_SQUOTE] = ACTIONS(547),
    [anon_sym_u8_SQUOTE] = ACTIONS(547),
    [anon_sym_SQUOTE] = ACTIONS(547),
    [anon_sym_L_DQUOTE] = ACTIONS(550),
    [anon_sym_u_DQUOTE] = ACTIONS(550),
    [anon_sym_U_DQUOTE] = ACTIONS(550),
    [anon_sym_u8_DQUOTE] = ACTIONS(550),
    [anon_sym_DQUOTE] = ACTIONS(550),
    [sym_true] = ACTIONS(553),
    [sym_false] = ACTIONS(553),
    [anon_sym_NULL] = ACTIONS(556),
    [anon_sym_nullptr] = ACTIONS(556),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(559),
    [anon_sym_decltype] = ACTIONS(562),
    [anon_sym_explicit] = ACTIONS(565),
    [anon_sym_typename] = ACTIONS(568),
    [anon_sym_template] = ACTIONS(571),
    [anon_sym_operator] = ACTIONS(574),
    [anon_sym_try] = ACTIONS(577),
    [anon_sym_delete] = ACTIONS(580),
    [anon_sym_throw] = ACTIONS(583),
    [anon_sym_namespace] = ACTIONS(586),
    [anon_sym_using] = ACTIONS(589),
    [anon_sym_static_assert] = ACTIONS(592),
    [anon_sym_concept] = ACTIONS(595),
    [anon_sym_co_return] = ACTIONS(598),
    [anon_sym_co_yield] = ACTIONS(601),
    [anon_sym_R_DQUOTE] = ACTIONS(604),
    [anon_sym_LR_DQUOTE] = ACTIONS(604),
    [anon_sym_uR_DQUOTE] = ACTIONS(604),
    [anon_sym_UR_DQUOTE] = ACTIONS(604),
    [anon_sym_u8R_DQUOTE] = ACTIONS(604),
    [anon_sym_co_await] = ACTIONS(607),
    [anon_sym_new] = ACTIONS(610),
    [anon_sym_requires] = ACTIONS(613),
    [sym_this] = ACTIONS(553),
    [anon_sym___launch_bounds__] = ACTIONS(616),
  },
  [STATE(34)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(623),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(35)] = {
    [sym__block_item] = STATE(40),
    [sym_preproc_include] = STATE(40),
    [sym_preproc_def] = STATE(40),
    [sym_preproc_function_def] = STATE(40),
    [sym_preproc_call] = STATE(40),
    [sym_preproc_if] = STATE(40),
    [sym_preproc_ifdef] = STATE(40),
    [sym_function_definition] = STATE(40),
    [sym_declaration] = STATE(40),
    [sym_type_definition] = STATE(40),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(40),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(40),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(40),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(40),
    [sym_template_instantiation] = STATE(40),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(40),
    [sym_operator_cast_declaration] = STATE(40),
    [sym_constructor_or_destructor_definition] = STATE(40),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(40),
    [sym_namespace_alias_definition] = STATE(40),
    [sym_using_declaration] = STATE(40),
    [sym_alias_declaration] = STATE(40),
    [sym_static_assert_declaration] = STATE(40),
    [sym_concept_definition] = STATE(40),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(40),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(625),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(36)] = {
    [sym__block_item] = STATE(38),
    [sym_preproc_include] = STATE(38),
    [sym_preproc_def] = STATE(38),
    [sym_preproc_function_def] = STATE(38),
    [sym_preproc_call] = STATE(38),
    [sym_preproc_if] = STATE(38),
    [sym_preproc_ifdef] = STATE(38),
    [sym_function_definition] = STATE(38),
    [sym_declaration] = STATE(38),
    [sym_type_definition] = STATE(38),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(38),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(38),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(38),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(38),
    [sym_template_instantiation] = STATE(38),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(38),
    [sym_operator_cast_declaration] = STATE(38),
    [sym_constructor_or_destructor_definition] = STATE(38),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(38),
    [sym_namespace_alias_definition] = STATE(38),
    [sym_using_declaration] = STATE(38),
    [sym_alias_declaration] = STATE(38),
    [sym_static_assert_declaration] = STATE(38),
    [sym_concept_definition] = STATE(38),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(38),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(627),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(37)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(629),
    [aux_sym_preproc_include_token1] = ACTIONS(632),
    [aux_sym_preproc_def_token1] = ACTIONS(635),
    [aux_sym_preproc_if_token1] = ACTIONS(638),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(641),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(641),
    [sym_preproc_directive] = ACTIONS(644),
    [anon_sym_LPAREN2] = ACTIONS(397),
    [anon_sym_BANG] = ACTIONS(400),
    [anon_sym_TILDE] = ACTIONS(403),
    [anon_sym_DASH] = ACTIONS(406),
    [anon_sym_PLUS] = ACTIONS(406),
    [anon_sym_STAR] = ACTIONS(409),
    [anon_sym_AMP_AMP] = ACTIONS(412),
    [anon_sym_AMP] = ACTIONS(415),
    [anon_sym_SEMI] = ACTIONS(647),
    [anon_sym___extension__] = ACTIONS(650),
    [anon_sym_typedef] = ACTIONS(653),
    [anon_sym___device__] = ACTIONS(427),
    [anon_sym___host__] = ACTIONS(427),
    [anon_sym___global__] = ACTIONS(427),
    [anon_sym___forceinline__] = ACTIONS(427),
    [anon_sym___noinline__] = ACTIONS(427),
    [anon_sym_virtual] = ACTIONS(427),
    [anon_sym_extern] = ACTIONS(656),
    [anon_sym___attribute__] = ACTIONS(433),
    [anon_sym___attribute] = ACTIONS(433),
    [anon_sym_COLON_COLON] = ACTIONS(436),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(439),
    [anon_sym___declspec] = ACTIONS(442),
    [anon_sym___based] = ACTIONS(445),
    [anon_sym___cdecl] = ACTIONS(448),
    [anon_sym___clrcall] = ACTIONS(448),
    [anon_sym___stdcall] = ACTIONS(448),
    [anon_sym___fastcall] = ACTIONS(448),
    [anon_sym___thiscall] = ACTIONS(448),
    [anon_sym___vectorcall] = ACTIONS(448),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(662),
    [anon_sym_signed] = ACTIONS(454),
    [anon_sym_unsigned] = ACTIONS(454),
    [anon_sym_long] = ACTIONS(454),
    [anon_sym_short] = ACTIONS(454),
    [anon_sym_LBRACK] = ACTIONS(457),
    [anon_sym_static] = ACTIONS(460),
    [anon_sym_register] = ACTIONS(460),
    [anon_sym_inline] = ACTIONS(664),
    [anon_sym___inline] = ACTIONS(460),
    [anon_sym___inline__] = ACTIONS(460),
    [anon_sym___forceinline] = ACTIONS(460),
    [anon_sym_thread_local] = ACTIONS(460),
    [anon_sym___thread] = ACTIONS(460),
    [anon_sym_const] = ACTIONS(466),
    [anon_sym_constexpr] = ACTIONS(466),
    [anon_sym_volatile] = ACTIONS(466),
    [anon_sym_restrict] = ACTIONS(466),
    [anon_sym___restrict__] = ACTIONS(466),
    [anon_sym__Atomic] = ACTIONS(466),
    [anon_sym__Noreturn] = ACTIONS(466),
    [anon_sym_noreturn] = ACTIONS(466),
    [anon_sym__Nonnull] = ACTIONS(466),
    [anon_sym_mutable] = ACTIONS(466),
    [anon_sym_constinit] = ACTIONS(466),
    [anon_sym_consteval] = ACTIONS(466),
    [anon_sym___shared__] = ACTIONS(466),
    [anon_sym___local__] = ACTIONS(466),
    [anon_sym___constant__] = ACTIONS(466),
    [anon_sym___managed__] = ACTIONS(466),
    [anon_sym___grid_constant__] = ACTIONS(466),
    [anon_sym_alignas] = ACTIONS(469),
    [anon_sym__Alignas] = ACTIONS(469),
    [sym_primitive_type] = ACTIONS(472),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_class] = ACTIONS(478),
    [anon_sym_struct] = ACTIONS(481),
    [anon_sym_union] = ACTIONS(484),
    [anon_sym_if] = ACTIONS(667),
    [anon_sym_switch] = ACTIONS(670),
    [anon_sym_case] = ACTIONS(673),
    [anon_sym_default] = ACTIONS(676),
    [anon_sym_while] = ACTIONS(679),
    [anon_sym_do] = ACTIONS(682),
    [anon_sym_for] = ACTIONS(685),
    [anon_sym_return] = ACTIONS(688),
    [anon_sym_break] = ACTIONS(691),
    [anon_sym_continue] = ACTIONS(694),
    [anon_sym_goto] = ACTIONS(697),
    [anon_sym___try] = ACTIONS(700),
    [anon_sym___leave] = ACTIONS(703),
    [anon_sym_not] = ACTIONS(406),
    [anon_sym_compl] = ACTIONS(406),
    [anon_sym_DASH_DASH] = ACTIONS(526),
    [anon_sym_PLUS_PLUS] = ACTIONS(526),
    [anon_sym_sizeof] = ACTIONS(529),
    [anon_sym___alignof__] = ACTIONS(532),
    [anon_sym___alignof] = ACTIONS(532),
    [anon_sym__alignof] = ACTIONS(532),
    [anon_sym_alignof] = ACTIONS(532),
    [anon_sym__Alignof] = ACTIONS(532),
    [anon_sym_offsetof] = ACTIONS(535),
    [anon_sym__Generic] = ACTIONS(538),
    [anon_sym_asm] = ACTIONS(541),
    [anon_sym___asm__] = ACTIONS(541),
    [anon_sym___asm] = ACTIONS(541),
    [sym_number_literal] = ACTIONS(544),
    [anon_sym_L_SQUOTE] = ACTIONS(547),
    [anon_sym_u_SQUOTE] = ACTIONS(547),
    [anon_sym_U_SQUOTE] = ACTIONS(547),
    [anon_sym_u8_SQUOTE] = ACTIONS(547),
    [anon_sym_SQUOTE] = ACTIONS(547),
    [anon_sym_L_DQUOTE] = ACTIONS(550),
    [anon_sym_u_DQUOTE] = ACTIONS(550),
    [anon_sym_U_DQUOTE] = ACTIONS(550),
    [anon_sym_u8_DQUOTE] = ACTIONS(550),
    [anon_sym_DQUOTE] = ACTIONS(550),
    [sym_true] = ACTIONS(553),
    [sym_false] = ACTIONS(553),
    [anon_sym_NULL] = ACTIONS(556),
    [anon_sym_nullptr] = ACTIONS(556),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(559),
    [anon_sym_decltype] = ACTIONS(562),
    [anon_sym_explicit] = ACTIONS(565),
    [anon_sym_typename] = ACTIONS(568),
    [anon_sym_template] = ACTIONS(706),
    [anon_sym_operator] = ACTIONS(574),
    [anon_sym_try] = ACTIONS(709),
    [anon_sym_delete] = ACTIONS(580),
    [anon_sym_throw] = ACTIONS(712),
    [anon_sym_namespace] = ACTIONS(715),
    [anon_sym_using] = ACTIONS(718),
    [anon_sym_static_assert] = ACTIONS(721),
    [anon_sym_concept] = ACTIONS(724),
    [anon_sym_co_return] = ACTIONS(727),
    [anon_sym_co_yield] = ACTIONS(730),
    [anon_sym_R_DQUOTE] = ACTIONS(604),
    [anon_sym_LR_DQUOTE] = ACTIONS(604),
    [anon_sym_uR_DQUOTE] = ACTIONS(604),
    [anon_sym_UR_DQUOTE] = ACTIONS(604),
    [anon_sym_u8R_DQUOTE] = ACTIONS(604),
    [anon_sym_co_await] = ACTIONS(607),
    [anon_sym_new] = ACTIONS(610),
    [anon_sym_requires] = ACTIONS(613),
    [sym_this] = ACTIONS(553),
    [anon_sym___launch_bounds__] = ACTIONS(616),
  },
  [STATE(38)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(733),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(39)] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(735),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(40)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(737),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(41)] = {
    [sym__block_item] = STATE(41),
    [sym_preproc_include] = STATE(41),
    [sym_preproc_def] = STATE(41),
    [sym_preproc_function_def] = STATE(41),
    [sym_preproc_call] = STATE(41),
    [sym_preproc_if] = STATE(41),
    [sym_preproc_ifdef] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_declaration] = STATE(41),
    [sym_type_definition] = STATE(41),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5455),
    [sym_linkage_specification] = STATE(41),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1891),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6908),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(375),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2353),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(617),
    [sym_statement] = STATE(41),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(41),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1756),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(41),
    [sym_template_instantiation] = STATE(41),
    [sym_operator_cast] = STATE(7422),
    [sym__constructor_specifiers] = STATE(1756),
    [sym_operator_cast_definition] = STATE(41),
    [sym_operator_cast_declaration] = STATE(41),
    [sym_constructor_or_destructor_definition] = STATE(41),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(41),
    [sym_namespace_alias_definition] = STATE(41),
    [sym_using_declaration] = STATE(41),
    [sym_alias_declaration] = STATE(41),
    [sym_static_assert_declaration] = STATE(41),
    [sym_concept_definition] = STATE(41),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7422),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(41),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1756),
    [sym_identifier] = ACTIONS(739),
    [aux_sym_preproc_include_token1] = ACTIONS(742),
    [aux_sym_preproc_def_token1] = ACTIONS(745),
    [aux_sym_preproc_if_token1] = ACTIONS(748),
    [aux_sym_preproc_if_token2] = ACTIONS(389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(751),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(751),
    [sym_preproc_directive] = ACTIONS(754),
    [anon_sym_LPAREN2] = ACTIONS(397),
    [anon_sym_BANG] = ACTIONS(400),
    [anon_sym_TILDE] = ACTIONS(403),
    [anon_sym_DASH] = ACTIONS(406),
    [anon_sym_PLUS] = ACTIONS(406),
    [anon_sym_STAR] = ACTIONS(409),
    [anon_sym_AMP_AMP] = ACTIONS(412),
    [anon_sym_AMP] = ACTIONS(415),
    [anon_sym_SEMI] = ACTIONS(757),
    [anon_sym___extension__] = ACTIONS(760),
    [anon_sym_typedef] = ACTIONS(763),
    [anon_sym___device__] = ACTIONS(427),
    [anon_sym___host__] = ACTIONS(427),
    [anon_sym___global__] = ACTIONS(427),
    [anon_sym___forceinline__] = ACTIONS(427),
    [anon_sym___noinline__] = ACTIONS(427),
    [anon_sym_virtual] = ACTIONS(427),
    [anon_sym_extern] = ACTIONS(766),
    [anon_sym___attribute__] = ACTIONS(433),
    [anon_sym___attribute] = ACTIONS(433),
    [anon_sym_COLON_COLON] = ACTIONS(436),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(439),
    [anon_sym___declspec] = ACTIONS(442),
    [anon_sym___based] = ACTIONS(445),
    [anon_sym___cdecl] = ACTIONS(448),
    [anon_sym___clrcall] = ACTIONS(448),
    [anon_sym___stdcall] = ACTIONS(448),
    [anon_sym___fastcall] = ACTIONS(448),
    [anon_sym___thiscall] = ACTIONS(448),
    [anon_sym___vectorcall] = ACTIONS(448),
    [anon_sym_LBRACE] = ACTIONS(769),
    [anon_sym_signed] = ACTIONS(454),
    [anon_sym_unsigned] = ACTIONS(454),
    [anon_sym_long] = ACTIONS(454),
    [anon_sym_short] = ACTIONS(454),
    [anon_sym_LBRACK] = ACTIONS(457),
    [anon_sym_static] = ACTIONS(460),
    [anon_sym_register] = ACTIONS(460),
    [anon_sym_inline] = ACTIONS(772),
    [anon_sym___inline] = ACTIONS(460),
    [anon_sym___inline__] = ACTIONS(460),
    [anon_sym___forceinline] = ACTIONS(460),
    [anon_sym_thread_local] = ACTIONS(460),
    [anon_sym___thread] = ACTIONS(460),
    [anon_sym_const] = ACTIONS(466),
    [anon_sym_constexpr] = ACTIONS(466),
    [anon_sym_volatile] = ACTIONS(466),
    [anon_sym_restrict] = ACTIONS(466),
    [anon_sym___restrict__] = ACTIONS(466),
    [anon_sym__Atomic] = ACTIONS(466),
    [anon_sym__Noreturn] = ACTIONS(466),
    [anon_sym_noreturn] = ACTIONS(466),
    [anon_sym__Nonnull] = ACTIONS(466),
    [anon_sym_mutable] = ACTIONS(466),
    [anon_sym_constinit] = ACTIONS(466),
    [anon_sym_consteval] = ACTIONS(466),
    [anon_sym___shared__] = ACTIONS(466),
    [anon_sym___local__] = ACTIONS(466),
    [anon_sym___constant__] = ACTIONS(466),
    [anon_sym___managed__] = ACTIONS(466),
    [anon_sym___grid_constant__] = ACTIONS(466),
    [anon_sym_alignas] = ACTIONS(469),
    [anon_sym__Alignas] = ACTIONS(469),
    [sym_primitive_type] = ACTIONS(472),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_class] = ACTIONS(478),
    [anon_sym_struct] = ACTIONS(481),
    [anon_sym_union] = ACTIONS(484),
    [anon_sym_if] = ACTIONS(775),
    [anon_sym_switch] = ACTIONS(778),
    [anon_sym_case] = ACTIONS(781),
    [anon_sym_default] = ACTIONS(784),
    [anon_sym_while] = ACTIONS(787),
    [anon_sym_do] = ACTIONS(790),
    [anon_sym_for] = ACTIONS(793),
    [anon_sym_return] = ACTIONS(796),
    [anon_sym_break] = ACTIONS(799),
    [anon_sym_continue] = ACTIONS(802),
    [anon_sym_goto] = ACTIONS(805),
    [anon_sym___try] = ACTIONS(808),
    [anon_sym___leave] = ACTIONS(811),
    [anon_sym_not] = ACTIONS(406),
    [anon_sym_compl] = ACTIONS(406),
    [anon_sym_DASH_DASH] = ACTIONS(526),
    [anon_sym_PLUS_PLUS] = ACTIONS(526),
    [anon_sym_sizeof] = ACTIONS(529),
    [anon_sym___alignof__] = ACTIONS(532),
    [anon_sym___alignof] = ACTIONS(532),
    [anon_sym__alignof] = ACTIONS(532),
    [anon_sym_alignof] = ACTIONS(532),
    [anon_sym__Alignof] = ACTIONS(532),
    [anon_sym_offsetof] = ACTIONS(535),
    [anon_sym__Generic] = ACTIONS(538),
    [anon_sym_asm] = ACTIONS(541),
    [anon_sym___asm__] = ACTIONS(541),
    [anon_sym___asm] = ACTIONS(541),
    [sym_number_literal] = ACTIONS(544),
    [anon_sym_L_SQUOTE] = ACTIONS(547),
    [anon_sym_u_SQUOTE] = ACTIONS(547),
    [anon_sym_U_SQUOTE] = ACTIONS(547),
    [anon_sym_u8_SQUOTE] = ACTIONS(547),
    [anon_sym_SQUOTE] = ACTIONS(547),
    [anon_sym_L_DQUOTE] = ACTIONS(550),
    [anon_sym_u_DQUOTE] = ACTIONS(550),
    [anon_sym_U_DQUOTE] = ACTIONS(550),
    [anon_sym_u8_DQUOTE] = ACTIONS(550),
    [anon_sym_DQUOTE] = ACTIONS(550),
    [sym_true] = ACTIONS(553),
    [sym_false] = ACTIONS(553),
    [anon_sym_NULL] = ACTIONS(556),
    [anon_sym_nullptr] = ACTIONS(556),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(559),
    [anon_sym_decltype] = ACTIONS(562),
    [anon_sym_explicit] = ACTIONS(565),
    [anon_sym_typename] = ACTIONS(568),
    [anon_sym_template] = ACTIONS(814),
    [anon_sym_operator] = ACTIONS(574),
    [anon_sym_try] = ACTIONS(817),
    [anon_sym_delete] = ACTIONS(580),
    [anon_sym_throw] = ACTIONS(820),
    [anon_sym_namespace] = ACTIONS(823),
    [anon_sym_using] = ACTIONS(826),
    [anon_sym_static_assert] = ACTIONS(829),
    [anon_sym_concept] = ACTIONS(832),
    [anon_sym_co_return] = ACTIONS(835),
    [anon_sym_co_yield] = ACTIONS(838),
    [anon_sym_R_DQUOTE] = ACTIONS(604),
    [anon_sym_LR_DQUOTE] = ACTIONS(604),
    [anon_sym_uR_DQUOTE] = ACTIONS(604),
    [anon_sym_UR_DQUOTE] = ACTIONS(604),
    [anon_sym_u8R_DQUOTE] = ACTIONS(604),
    [anon_sym_co_await] = ACTIONS(607),
    [anon_sym_new] = ACTIONS(610),
    [anon_sym_requires] = ACTIONS(613),
    [sym_this] = ACTIONS(553),
    [anon_sym___launch_bounds__] = ACTIONS(616),
  },
  [STATE(42)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(841),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(43)] = {
    [sym__block_item] = STATE(34),
    [sym_preproc_include] = STATE(34),
    [sym_preproc_def] = STATE(34),
    [sym_preproc_function_def] = STATE(34),
    [sym_preproc_call] = STATE(34),
    [sym_preproc_if] = STATE(34),
    [sym_preproc_ifdef] = STATE(34),
    [sym_function_definition] = STATE(34),
    [sym_declaration] = STATE(34),
    [sym_type_definition] = STATE(34),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(34),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(34),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(34),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(34),
    [sym_template_instantiation] = STATE(34),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(34),
    [sym_operator_cast_declaration] = STATE(34),
    [sym_constructor_or_destructor_definition] = STATE(34),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(34),
    [sym_namespace_alias_definition] = STATE(34),
    [sym_using_declaration] = STATE(34),
    [sym_alias_declaration] = STATE(34),
    [sym_static_assert_declaration] = STATE(34),
    [sym_concept_definition] = STATE(34),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(34),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(843),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(44)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(45)] = {
    [sym__block_item] = STATE(46),
    [sym_preproc_include] = STATE(46),
    [sym_preproc_def] = STATE(46),
    [sym_preproc_function_def] = STATE(46),
    [sym_preproc_call] = STATE(46),
    [sym_preproc_if] = STATE(46),
    [sym_preproc_ifdef] = STATE(46),
    [sym_function_definition] = STATE(46),
    [sym_declaration] = STATE(46),
    [sym_type_definition] = STATE(46),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(46),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(46),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(46),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(46),
    [sym_template_instantiation] = STATE(46),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(46),
    [sym_operator_cast_declaration] = STATE(46),
    [sym_constructor_or_destructor_definition] = STATE(46),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(46),
    [sym_namespace_alias_definition] = STATE(46),
    [sym_using_declaration] = STATE(46),
    [sym_alias_declaration] = STATE(46),
    [sym_static_assert_declaration] = STATE(46),
    [sym_concept_definition] = STATE(46),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(46),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(847),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(46)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(47)] = {
    [sym__block_item] = STATE(52),
    [sym_preproc_include] = STATE(52),
    [sym_preproc_def] = STATE(52),
    [sym_preproc_function_def] = STATE(52),
    [sym_preproc_call] = STATE(52),
    [sym_preproc_if] = STATE(52),
    [sym_preproc_ifdef] = STATE(52),
    [sym_function_definition] = STATE(52),
    [sym_declaration] = STATE(52),
    [sym_type_definition] = STATE(52),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(52),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(52),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(52),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(52),
    [sym_template_instantiation] = STATE(52),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(52),
    [sym_operator_cast_declaration] = STATE(52),
    [sym_constructor_or_destructor_definition] = STATE(52),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(52),
    [sym_namespace_alias_definition] = STATE(52),
    [sym_using_declaration] = STATE(52),
    [sym_alias_declaration] = STATE(52),
    [sym_static_assert_declaration] = STATE(52),
    [sym_concept_definition] = STATE(52),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(52),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(851),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(48)] = {
    [sym__block_item] = STATE(49),
    [sym_preproc_include] = STATE(49),
    [sym_preproc_def] = STATE(49),
    [sym_preproc_function_def] = STATE(49),
    [sym_preproc_call] = STATE(49),
    [sym_preproc_if] = STATE(49),
    [sym_preproc_ifdef] = STATE(49),
    [sym_function_definition] = STATE(49),
    [sym_declaration] = STATE(49),
    [sym_type_definition] = STATE(49),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(49),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(49),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(49),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(49),
    [sym_template_instantiation] = STATE(49),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(49),
    [sym_operator_cast_declaration] = STATE(49),
    [sym_constructor_or_destructor_definition] = STATE(49),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(49),
    [sym_namespace_alias_definition] = STATE(49),
    [sym_using_declaration] = STATE(49),
    [sym_alias_declaration] = STATE(49),
    [sym_static_assert_declaration] = STATE(49),
    [sym_concept_definition] = STATE(49),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(49),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(853),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(49)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(50)] = {
    [sym__block_item] = STATE(51),
    [sym_preproc_include] = STATE(51),
    [sym_preproc_def] = STATE(51),
    [sym_preproc_function_def] = STATE(51),
    [sym_preproc_call] = STATE(51),
    [sym_preproc_if] = STATE(51),
    [sym_preproc_ifdef] = STATE(51),
    [sym_function_definition] = STATE(51),
    [sym_declaration] = STATE(51),
    [sym_type_definition] = STATE(51),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(51),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(51),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(51),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(51),
    [sym_template_instantiation] = STATE(51),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(51),
    [sym_operator_cast_declaration] = STATE(51),
    [sym_constructor_or_destructor_definition] = STATE(51),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(51),
    [sym_namespace_alias_definition] = STATE(51),
    [sym_using_declaration] = STATE(51),
    [sym_alias_declaration] = STATE(51),
    [sym_static_assert_declaration] = STATE(51),
    [sym_concept_definition] = STATE(51),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(51),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(857),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(51)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(859),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(52)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(861),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(53)] = {
    [sym__block_item] = STATE(54),
    [sym_preproc_include] = STATE(54),
    [sym_preproc_def] = STATE(54),
    [sym_preproc_function_def] = STATE(54),
    [sym_preproc_call] = STATE(54),
    [sym_preproc_if] = STATE(54),
    [sym_preproc_ifdef] = STATE(54),
    [sym_function_definition] = STATE(54),
    [sym_declaration] = STATE(54),
    [sym_type_definition] = STATE(54),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(54),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(54),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(54),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(54),
    [sym_template_instantiation] = STATE(54),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(54),
    [sym_operator_cast_declaration] = STATE(54),
    [sym_constructor_or_destructor_definition] = STATE(54),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(54),
    [sym_namespace_alias_definition] = STATE(54),
    [sym_using_declaration] = STATE(54),
    [sym_alias_declaration] = STATE(54),
    [sym_static_assert_declaration] = STATE(54),
    [sym_concept_definition] = STATE(54),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(54),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(863),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(54)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(865),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(55)] = {
    [sym__block_item] = STATE(64),
    [sym_preproc_include] = STATE(64),
    [sym_preproc_def] = STATE(64),
    [sym_preproc_function_def] = STATE(64),
    [sym_preproc_call] = STATE(64),
    [sym_preproc_if] = STATE(64),
    [sym_preproc_ifdef] = STATE(64),
    [sym_function_definition] = STATE(64),
    [sym_declaration] = STATE(64),
    [sym_type_definition] = STATE(64),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(64),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(64),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(64),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(64),
    [sym_template_instantiation] = STATE(64),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(64),
    [sym_operator_cast_declaration] = STATE(64),
    [sym_constructor_or_destructor_definition] = STATE(64),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(64),
    [sym_namespace_alias_definition] = STATE(64),
    [sym_using_declaration] = STATE(64),
    [sym_alias_declaration] = STATE(64),
    [sym_static_assert_declaration] = STATE(64),
    [sym_concept_definition] = STATE(64),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(64),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(867),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(56)] = {
    [sym__block_item] = STATE(57),
    [sym_preproc_include] = STATE(57),
    [sym_preproc_def] = STATE(57),
    [sym_preproc_function_def] = STATE(57),
    [sym_preproc_call] = STATE(57),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_ifdef] = STATE(57),
    [sym_function_definition] = STATE(57),
    [sym_declaration] = STATE(57),
    [sym_type_definition] = STATE(57),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(57),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(57),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(57),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(57),
    [sym_template_instantiation] = STATE(57),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(57),
    [sym_operator_cast_declaration] = STATE(57),
    [sym_constructor_or_destructor_definition] = STATE(57),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(57),
    [sym_namespace_alias_definition] = STATE(57),
    [sym_using_declaration] = STATE(57),
    [sym_alias_declaration] = STATE(57),
    [sym_static_assert_declaration] = STATE(57),
    [sym_concept_definition] = STATE(57),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(57),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(869),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(57)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(58)] = {
    [sym__block_item] = STATE(41),
    [sym_preproc_include] = STATE(41),
    [sym_preproc_def] = STATE(41),
    [sym_preproc_function_def] = STATE(41),
    [sym_preproc_call] = STATE(41),
    [sym_preproc_if] = STATE(41),
    [sym_preproc_ifdef] = STATE(41),
    [sym_function_definition] = STATE(41),
    [sym_declaration] = STATE(41),
    [sym_type_definition] = STATE(41),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5455),
    [sym_linkage_specification] = STATE(41),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1891),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6908),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(375),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2353),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(617),
    [sym_statement] = STATE(41),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(41),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1756),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(41),
    [sym_template_instantiation] = STATE(41),
    [sym_operator_cast] = STATE(7422),
    [sym__constructor_specifiers] = STATE(1756),
    [sym_operator_cast_definition] = STATE(41),
    [sym_operator_cast_declaration] = STATE(41),
    [sym_constructor_or_destructor_definition] = STATE(41),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(41),
    [sym_namespace_alias_definition] = STATE(41),
    [sym_using_declaration] = STATE(41),
    [sym_alias_declaration] = STATE(41),
    [sym_static_assert_declaration] = STATE(41),
    [sym_concept_definition] = STATE(41),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7422),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(41),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1756),
    [sym_identifier] = ACTIONS(873),
    [aux_sym_preproc_include_token1] = ACTIONS(875),
    [aux_sym_preproc_def_token1] = ACTIONS(877),
    [aux_sym_preproc_if_token1] = ACTIONS(879),
    [aux_sym_preproc_if_token2] = ACTIONS(881),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(883),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(883),
    [sym_preproc_directive] = ACTIONS(885),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(889),
    [anon_sym_typedef] = ACTIONS(891),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(893),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(897),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(925),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_namespace] = ACTIONS(931),
    [anon_sym_using] = ACTIONS(933),
    [anon_sym_static_assert] = ACTIONS(935),
    [anon_sym_concept] = ACTIONS(937),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(59)] = {
    [sym__block_item] = STATE(60),
    [sym_preproc_include] = STATE(60),
    [sym_preproc_def] = STATE(60),
    [sym_preproc_function_def] = STATE(60),
    [sym_preproc_call] = STATE(60),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_ifdef] = STATE(60),
    [sym_function_definition] = STATE(60),
    [sym_declaration] = STATE(60),
    [sym_type_definition] = STATE(60),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(60),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(60),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(60),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(60),
    [sym_template_instantiation] = STATE(60),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(60),
    [sym_operator_cast_declaration] = STATE(60),
    [sym_constructor_or_destructor_definition] = STATE(60),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(60),
    [sym_namespace_alias_definition] = STATE(60),
    [sym_using_declaration] = STATE(60),
    [sym_alias_declaration] = STATE(60),
    [sym_static_assert_declaration] = STATE(60),
    [sym_concept_definition] = STATE(60),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(60),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(943),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(60)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(945),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(61)] = {
    [sym__block_item] = STATE(58),
    [sym_preproc_include] = STATE(58),
    [sym_preproc_def] = STATE(58),
    [sym_preproc_function_def] = STATE(58),
    [sym_preproc_call] = STATE(58),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_ifdef] = STATE(58),
    [sym_function_definition] = STATE(58),
    [sym_declaration] = STATE(58),
    [sym_type_definition] = STATE(58),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5455),
    [sym_linkage_specification] = STATE(58),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1891),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6908),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(375),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2353),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(617),
    [sym_statement] = STATE(58),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(58),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1756),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(58),
    [sym_template_instantiation] = STATE(58),
    [sym_operator_cast] = STATE(7422),
    [sym__constructor_specifiers] = STATE(1756),
    [sym_operator_cast_definition] = STATE(58),
    [sym_operator_cast_declaration] = STATE(58),
    [sym_constructor_or_destructor_definition] = STATE(58),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(58),
    [sym_namespace_alias_definition] = STATE(58),
    [sym_using_declaration] = STATE(58),
    [sym_alias_declaration] = STATE(58),
    [sym_static_assert_declaration] = STATE(58),
    [sym_concept_definition] = STATE(58),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7422),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(58),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1756),
    [sym_identifier] = ACTIONS(873),
    [aux_sym_preproc_include_token1] = ACTIONS(875),
    [aux_sym_preproc_def_token1] = ACTIONS(877),
    [aux_sym_preproc_if_token1] = ACTIONS(879),
    [aux_sym_preproc_if_token2] = ACTIONS(947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(883),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(883),
    [sym_preproc_directive] = ACTIONS(885),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(889),
    [anon_sym_typedef] = ACTIONS(891),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(893),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(897),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(925),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_namespace] = ACTIONS(931),
    [anon_sym_using] = ACTIONS(933),
    [anon_sym_static_assert] = ACTIONS(935),
    [anon_sym_concept] = ACTIONS(937),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(62)] = {
    [sym__block_item] = STATE(63),
    [sym_preproc_include] = STATE(63),
    [sym_preproc_def] = STATE(63),
    [sym_preproc_function_def] = STATE(63),
    [sym_preproc_call] = STATE(63),
    [sym_preproc_if] = STATE(63),
    [sym_preproc_ifdef] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_declaration] = STATE(63),
    [sym_type_definition] = STATE(63),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(63),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(63),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(63),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(63),
    [sym_template_instantiation] = STATE(63),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(63),
    [sym_operator_cast_declaration] = STATE(63),
    [sym_constructor_or_destructor_definition] = STATE(63),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(63),
    [sym_namespace_alias_definition] = STATE(63),
    [sym_using_declaration] = STATE(63),
    [sym_alias_declaration] = STATE(63),
    [sym_static_assert_declaration] = STATE(63),
    [sym_concept_definition] = STATE(63),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(63),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(949),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(63)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(951),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(64)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(953),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(65)] = {
    [sym__block_item] = STATE(66),
    [sym_preproc_include] = STATE(66),
    [sym_preproc_def] = STATE(66),
    [sym_preproc_function_def] = STATE(66),
    [sym_preproc_call] = STATE(66),
    [sym_preproc_if] = STATE(66),
    [sym_preproc_ifdef] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_declaration] = STATE(66),
    [sym_type_definition] = STATE(66),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(66),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(66),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(66),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(66),
    [sym_template_instantiation] = STATE(66),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(66),
    [sym_operator_cast_declaration] = STATE(66),
    [sym_constructor_or_destructor_definition] = STATE(66),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(66),
    [sym_namespace_alias_definition] = STATE(66),
    [sym_using_declaration] = STATE(66),
    [sym_alias_declaration] = STATE(66),
    [sym_static_assert_declaration] = STATE(66),
    [sym_concept_definition] = STATE(66),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(66),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(955),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(66)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(957),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(67)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(959),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(68)] = {
    [sym__block_item] = STATE(69),
    [sym_preproc_include] = STATE(69),
    [sym_preproc_def] = STATE(69),
    [sym_preproc_function_def] = STATE(69),
    [sym_preproc_call] = STATE(69),
    [sym_preproc_if] = STATE(69),
    [sym_preproc_ifdef] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_declaration] = STATE(69),
    [sym_type_definition] = STATE(69),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(69),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(69),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(69),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(69),
    [sym_template_instantiation] = STATE(69),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(69),
    [sym_operator_cast_declaration] = STATE(69),
    [sym_constructor_or_destructor_definition] = STATE(69),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(69),
    [sym_namespace_alias_definition] = STATE(69),
    [sym_using_declaration] = STATE(69),
    [sym_alias_declaration] = STATE(69),
    [sym_static_assert_declaration] = STATE(69),
    [sym_concept_definition] = STATE(69),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(69),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(961),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(69)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(963),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(70)] = {
    [sym__block_item] = STATE(71),
    [sym_preproc_include] = STATE(71),
    [sym_preproc_def] = STATE(71),
    [sym_preproc_function_def] = STATE(71),
    [sym_preproc_call] = STATE(71),
    [sym_preproc_if] = STATE(71),
    [sym_preproc_ifdef] = STATE(71),
    [sym_function_definition] = STATE(71),
    [sym_declaration] = STATE(71),
    [sym_type_definition] = STATE(71),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(71),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(71),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(71),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(71),
    [sym_template_instantiation] = STATE(71),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(71),
    [sym_operator_cast_declaration] = STATE(71),
    [sym_constructor_or_destructor_definition] = STATE(71),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(71),
    [sym_namespace_alias_definition] = STATE(71),
    [sym_using_declaration] = STATE(71),
    [sym_alias_declaration] = STATE(71),
    [sym_static_assert_declaration] = STATE(71),
    [sym_concept_definition] = STATE(71),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(71),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(965),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(71)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(967),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(72)] = {
    [sym__block_item] = STATE(73),
    [sym_preproc_include] = STATE(73),
    [sym_preproc_def] = STATE(73),
    [sym_preproc_function_def] = STATE(73),
    [sym_preproc_call] = STATE(73),
    [sym_preproc_if] = STATE(73),
    [sym_preproc_ifdef] = STATE(73),
    [sym_function_definition] = STATE(73),
    [sym_declaration] = STATE(73),
    [sym_type_definition] = STATE(73),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(73),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(73),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(73),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(73),
    [sym_template_instantiation] = STATE(73),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(73),
    [sym_operator_cast_declaration] = STATE(73),
    [sym_constructor_or_destructor_definition] = STATE(73),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(73),
    [sym_namespace_alias_definition] = STATE(73),
    [sym_using_declaration] = STATE(73),
    [sym_alias_declaration] = STATE(73),
    [sym_static_assert_declaration] = STATE(73),
    [sym_concept_definition] = STATE(73),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(73),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(969),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(73)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(74)] = {
    [sym__block_item] = STATE(75),
    [sym_preproc_include] = STATE(75),
    [sym_preproc_def] = STATE(75),
    [sym_preproc_function_def] = STATE(75),
    [sym_preproc_call] = STATE(75),
    [sym_preproc_if] = STATE(75),
    [sym_preproc_ifdef] = STATE(75),
    [sym_function_definition] = STATE(75),
    [sym_declaration] = STATE(75),
    [sym_type_definition] = STATE(75),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(75),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(75),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(75),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(75),
    [sym_template_instantiation] = STATE(75),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(75),
    [sym_operator_cast_declaration] = STATE(75),
    [sym_constructor_or_destructor_definition] = STATE(75),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(75),
    [sym_namespace_alias_definition] = STATE(75),
    [sym_using_declaration] = STATE(75),
    [sym_alias_declaration] = STATE(75),
    [sym_static_assert_declaration] = STATE(75),
    [sym_concept_definition] = STATE(75),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(75),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(973),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(75)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(975),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(76)] = {
    [sym__block_item] = STATE(77),
    [sym_preproc_include] = STATE(77),
    [sym_preproc_def] = STATE(77),
    [sym_preproc_function_def] = STATE(77),
    [sym_preproc_call] = STATE(77),
    [sym_preproc_if] = STATE(77),
    [sym_preproc_ifdef] = STATE(77),
    [sym_function_definition] = STATE(77),
    [sym_declaration] = STATE(77),
    [sym_type_definition] = STATE(77),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(77),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(77),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(77),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(77),
    [sym_template_instantiation] = STATE(77),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(77),
    [sym_operator_cast_declaration] = STATE(77),
    [sym_constructor_or_destructor_definition] = STATE(77),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(77),
    [sym_namespace_alias_definition] = STATE(77),
    [sym_using_declaration] = STATE(77),
    [sym_alias_declaration] = STATE(77),
    [sym_static_assert_declaration] = STATE(77),
    [sym_concept_definition] = STATE(77),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(77),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(977),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(77)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(979),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(78)] = {
    [sym__block_item] = STATE(79),
    [sym_preproc_include] = STATE(79),
    [sym_preproc_def] = STATE(79),
    [sym_preproc_function_def] = STATE(79),
    [sym_preproc_call] = STATE(79),
    [sym_preproc_if] = STATE(79),
    [sym_preproc_ifdef] = STATE(79),
    [sym_function_definition] = STATE(79),
    [sym_declaration] = STATE(79),
    [sym_type_definition] = STATE(79),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(79),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(79),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(79),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(79),
    [sym_template_instantiation] = STATE(79),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(79),
    [sym_operator_cast_declaration] = STATE(79),
    [sym_constructor_or_destructor_definition] = STATE(79),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(79),
    [sym_namespace_alias_definition] = STATE(79),
    [sym_using_declaration] = STATE(79),
    [sym_alias_declaration] = STATE(79),
    [sym_static_assert_declaration] = STATE(79),
    [sym_concept_definition] = STATE(79),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(79),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(981),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(79)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(983),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(80)] = {
    [sym__block_item] = STATE(81),
    [sym_preproc_include] = STATE(81),
    [sym_preproc_def] = STATE(81),
    [sym_preproc_function_def] = STATE(81),
    [sym_preproc_call] = STATE(81),
    [sym_preproc_if] = STATE(81),
    [sym_preproc_ifdef] = STATE(81),
    [sym_function_definition] = STATE(81),
    [sym_declaration] = STATE(81),
    [sym_type_definition] = STATE(81),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(81),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(81),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(81),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(81),
    [sym_template_instantiation] = STATE(81),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(81),
    [sym_operator_cast_declaration] = STATE(81),
    [sym_constructor_or_destructor_definition] = STATE(81),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(81),
    [sym_namespace_alias_definition] = STATE(81),
    [sym_using_declaration] = STATE(81),
    [sym_alias_declaration] = STATE(81),
    [sym_static_assert_declaration] = STATE(81),
    [sym_concept_definition] = STATE(81),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(81),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(985),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(81)] = {
    [sym__block_item] = STATE(37),
    [sym_preproc_include] = STATE(37),
    [sym_preproc_def] = STATE(37),
    [sym_preproc_function_def] = STATE(37),
    [sym_preproc_call] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_ifdef] = STATE(37),
    [sym_function_definition] = STATE(37),
    [sym_declaration] = STATE(37),
    [sym_type_definition] = STATE(37),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(37),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(37),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(37),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(37),
    [sym_template_instantiation] = STATE(37),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(37),
    [sym_operator_cast_declaration] = STATE(37),
    [sym_constructor_or_destructor_definition] = STATE(37),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(37),
    [sym_namespace_alias_definition] = STATE(37),
    [sym_using_declaration] = STATE(37),
    [sym_alias_declaration] = STATE(37),
    [sym_static_assert_declaration] = STATE(37),
    [sym_concept_definition] = STATE(37),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(37),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(987),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(82)] = {
    [sym__block_item] = STATE(44),
    [sym_preproc_include] = STATE(44),
    [sym_preproc_def] = STATE(44),
    [sym_preproc_function_def] = STATE(44),
    [sym_preproc_call] = STATE(44),
    [sym_preproc_if] = STATE(44),
    [sym_preproc_ifdef] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_declaration] = STATE(44),
    [sym_type_definition] = STATE(44),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(44),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(44),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(44),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(44),
    [sym_template_instantiation] = STATE(44),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(44),
    [sym_operator_cast_declaration] = STATE(44),
    [sym_constructor_or_destructor_definition] = STATE(44),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(44),
    [sym_namespace_alias_definition] = STATE(44),
    [sym_using_declaration] = STATE(44),
    [sym_alias_declaration] = STATE(44),
    [sym_static_assert_declaration] = STATE(44),
    [sym_concept_definition] = STATE(44),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(44),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(989),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(83)] = {
    [sym__block_item] = STATE(67),
    [sym_preproc_include] = STATE(67),
    [sym_preproc_def] = STATE(67),
    [sym_preproc_function_def] = STATE(67),
    [sym_preproc_call] = STATE(67),
    [sym_preproc_if] = STATE(67),
    [sym_preproc_ifdef] = STATE(67),
    [sym_function_definition] = STATE(67),
    [sym_declaration] = STATE(67),
    [sym_type_definition] = STATE(67),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_linkage_specification] = STATE(67),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6953),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(615),
    [sym_statement] = STATE(67),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym__empty_declaration] = STATE(67),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1749),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(67),
    [sym_template_instantiation] = STATE(67),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1749),
    [sym_operator_cast_definition] = STATE(67),
    [sym_operator_cast_declaration] = STATE(67),
    [sym_constructor_or_destructor_definition] = STATE(67),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5318),
    [sym_namespace_definition] = STATE(67),
    [sym_namespace_alias_definition] = STATE(67),
    [sym_using_declaration] = STATE(67),
    [sym_alias_declaration] = STATE(67),
    [sym_static_assert_declaration] = STATE(67),
    [sym_concept_definition] = STATE(67),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(3733),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_repeat1] = STATE(67),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(619),
    [aux_sym_preproc_include_token1] = ACTIONS(165),
    [aux_sym_preproc_def_token1] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(173),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(173),
    [sym_preproc_directive] = ACTIONS(175),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(179),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(183),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(991),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(191),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(225),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(231),
    [anon_sym_using] = ACTIONS(233),
    [anon_sym_static_assert] = ACTIONS(235),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(84)] = {
    [sym__top_level_item] = STATE(85),
    [sym_preproc_include] = STATE(85),
    [sym_preproc_def] = STATE(85),
    [sym_preproc_function_def] = STATE(85),
    [sym_preproc_call] = STATE(85),
    [sym_preproc_if] = STATE(85),
    [sym_preproc_ifdef] = STATE(85),
    [sym_function_definition] = STATE(85),
    [sym_declaration] = STATE(85),
    [sym_type_definition] = STATE(85),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5483),
    [sym_linkage_specification] = STATE(85),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1888),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6973),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(85),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2335),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(750),
    [sym__top_level_statement] = STATE(85),
    [sym_labeled_statement] = STATE(85),
    [sym__top_level_expression_statement] = STATE(85),
    [sym_if_statement] = STATE(85),
    [sym_switch_statement] = STATE(85),
    [sym_case_statement] = STATE(85),
    [sym_while_statement] = STATE(85),
    [sym_do_statement] = STATE(85),
    [sym_for_statement] = STATE(85),
    [sym_return_statement] = STATE(85),
    [sym_break_statement] = STATE(85),
    [sym_continue_statement] = STATE(85),
    [sym_goto_statement] = STATE(85),
    [sym_expression] = STATE(5394),
    [sym__string] = STATE(5527),
    [sym_conditional_expression] = STATE(5546),
    [sym_assignment_expression] = STATE(5546),
    [sym_pointer_expression] = STATE(4269),
    [sym_unary_expression] = STATE(5546),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(5546),
    [sym_cast_expression] = STATE(5546),
    [sym_sizeof_expression] = STATE(5546),
    [sym_alignof_expression] = STATE(5546),
    [sym_offsetof_expression] = STATE(5546),
    [sym_generic_expression] = STATE(5546),
    [sym_subscript_expression] = STATE(4269),
    [sym_call_expression] = STATE(4269),
    [sym_gnu_asm_expression] = STATE(5546),
    [sym_extension_expression] = STATE(5546),
    [sym_field_expression] = STATE(4269),
    [sym_compound_literal_expression] = STATE(5546),
    [sym_parenthesized_expression] = STATE(4269),
    [sym_char_literal] = STATE(5527),
    [sym_concatenated_string] = STATE(5527),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(5546),
    [sym__empty_declaration] = STATE(85),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1764),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(85),
    [sym_template_instantiation] = STATE(85),
    [sym_operator_cast] = STATE(7391),
    [sym__constructor_specifiers] = STATE(1764),
    [sym_operator_cast_definition] = STATE(85),
    [sym_operator_cast_declaration] = STATE(85),
    [sym_constructor_or_destructor_definition] = STATE(85),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5485),
    [sym_namespace_definition] = STATE(85),
    [sym_namespace_alias_definition] = STATE(85),
    [sym_using_declaration] = STATE(85),
    [sym_alias_declaration] = STATE(85),
    [sym_static_assert_declaration] = STATE(85),
    [sym_concept_definition] = STATE(85),
    [sym_for_range_loop] = STATE(85),
    [sym_co_return_statement] = STATE(85),
    [sym_co_yield_statement] = STATE(85),
    [sym_throw_statement] = STATE(85),
    [sym_try_statement] = STATE(85),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(5546),
    [sym_new_expression] = STATE(5546),
    [sym_delete_expression] = STATE(5546),
    [sym_requires_clause] = STATE(5546),
    [sym_requires_expression] = STATE(5546),
    [sym_lambda_expression] = STATE(5546),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(5546),
    [sym_parameter_pack_expansion] = STATE(5546),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(4253),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7391),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(4269),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_translation_unit_repeat1] = STATE(85),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1764),
    [ts_builtin_sym_end] = ACTIONS(993),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_preproc_include_token1] = ACTIONS(9),
    [aux_sym_preproc_def_token1] = ACTIONS(11),
    [aux_sym_preproc_if_token1] = ACTIONS(13),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(15),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(15),
    [sym_preproc_directive] = ACTIONS(17),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym___extension__] = ACTIONS(35),
    [anon_sym_typedef] = ACTIONS(37),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(41),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(47),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(63),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(113),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(119),
    [sym_false] = ACTIONS(119),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(131),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_namespace] = ACTIONS(141),
    [anon_sym_using] = ACTIONS(143),
    [anon_sym_static_assert] = ACTIONS(145),
    [anon_sym_concept] = ACTIONS(147),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(119),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(85)] = {
    [sym__top_level_item] = STATE(85),
    [sym_preproc_include] = STATE(85),
    [sym_preproc_def] = STATE(85),
    [sym_preproc_function_def] = STATE(85),
    [sym_preproc_call] = STATE(85),
    [sym_preproc_if] = STATE(85),
    [sym_preproc_ifdef] = STATE(85),
    [sym_function_definition] = STATE(85),
    [sym_declaration] = STATE(85),
    [sym_type_definition] = STATE(85),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5483),
    [sym_linkage_specification] = STATE(85),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(830),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1888),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6973),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(85),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2335),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(750),
    [sym__top_level_statement] = STATE(85),
    [sym_labeled_statement] = STATE(85),
    [sym__top_level_expression_statement] = STATE(85),
    [sym_if_statement] = STATE(85),
    [sym_switch_statement] = STATE(85),
    [sym_case_statement] = STATE(85),
    [sym_while_statement] = STATE(85),
    [sym_do_statement] = STATE(85),
    [sym_for_statement] = STATE(85),
    [sym_return_statement] = STATE(85),
    [sym_break_statement] = STATE(85),
    [sym_continue_statement] = STATE(85),
    [sym_goto_statement] = STATE(85),
    [sym_expression] = STATE(5394),
    [sym__string] = STATE(5527),
    [sym_conditional_expression] = STATE(5546),
    [sym_assignment_expression] = STATE(5546),
    [sym_pointer_expression] = STATE(4269),
    [sym_unary_expression] = STATE(5546),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(5546),
    [sym_cast_expression] = STATE(5546),
    [sym_sizeof_expression] = STATE(5546),
    [sym_alignof_expression] = STATE(5546),
    [sym_offsetof_expression] = STATE(5546),
    [sym_generic_expression] = STATE(5546),
    [sym_subscript_expression] = STATE(4269),
    [sym_call_expression] = STATE(4269),
    [sym_gnu_asm_expression] = STATE(5546),
    [sym_extension_expression] = STATE(5546),
    [sym_field_expression] = STATE(4269),
    [sym_compound_literal_expression] = STATE(5546),
    [sym_parenthesized_expression] = STATE(4269),
    [sym_char_literal] = STATE(5527),
    [sym_concatenated_string] = STATE(5527),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(5546),
    [sym__empty_declaration] = STATE(85),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_explicit_function_specifier] = STATE(1764),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(85),
    [sym_template_instantiation] = STATE(85),
    [sym_operator_cast] = STATE(7391),
    [sym__constructor_specifiers] = STATE(1764),
    [sym_operator_cast_definition] = STATE(85),
    [sym_operator_cast_declaration] = STATE(85),
    [sym_constructor_or_destructor_definition] = STATE(85),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(5485),
    [sym_namespace_definition] = STATE(85),
    [sym_namespace_alias_definition] = STATE(85),
    [sym_using_declaration] = STATE(85),
    [sym_alias_declaration] = STATE(85),
    [sym_static_assert_declaration] = STATE(85),
    [sym_concept_definition] = STATE(85),
    [sym_for_range_loop] = STATE(85),
    [sym_co_return_statement] = STATE(85),
    [sym_co_yield_statement] = STATE(85),
    [sym_throw_statement] = STATE(85),
    [sym_try_statement] = STATE(85),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(5546),
    [sym_new_expression] = STATE(5546),
    [sym_delete_expression] = STATE(5546),
    [sym_requires_clause] = STATE(5546),
    [sym_requires_expression] = STATE(5546),
    [sym_lambda_expression] = STATE(5546),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(5546),
    [sym_parameter_pack_expansion] = STATE(5546),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5998),
    [sym_qualified_identifier] = STATE(4253),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_qualified_operator_cast_identifier] = STATE(7391),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(4269),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_translation_unit_repeat1] = STATE(85),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1764),
    [ts_builtin_sym_end] = ACTIONS(995),
    [sym_identifier] = ACTIONS(997),
    [aux_sym_preproc_include_token1] = ACTIONS(1000),
    [aux_sym_preproc_def_token1] = ACTIONS(1003),
    [aux_sym_preproc_if_token1] = ACTIONS(1006),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1009),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1009),
    [sym_preproc_directive] = ACTIONS(1012),
    [anon_sym_LPAREN2] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1018),
    [anon_sym_TILDE] = ACTIONS(1021),
    [anon_sym_DASH] = ACTIONS(1024),
    [anon_sym_PLUS] = ACTIONS(1024),
    [anon_sym_STAR] = ACTIONS(1027),
    [anon_sym_AMP_AMP] = ACTIONS(1030),
    [anon_sym_AMP] = ACTIONS(1033),
    [anon_sym_SEMI] = ACTIONS(1036),
    [anon_sym___extension__] = ACTIONS(1039),
    [anon_sym_typedef] = ACTIONS(1042),
    [anon_sym___device__] = ACTIONS(1045),
    [anon_sym___host__] = ACTIONS(1045),
    [anon_sym___global__] = ACTIONS(1045),
    [anon_sym___forceinline__] = ACTIONS(1045),
    [anon_sym___noinline__] = ACTIONS(1045),
    [anon_sym_virtual] = ACTIONS(1045),
    [anon_sym_extern] = ACTIONS(1048),
    [anon_sym___attribute__] = ACTIONS(1051),
    [anon_sym___attribute] = ACTIONS(1051),
    [anon_sym_COLON_COLON] = ACTIONS(1054),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1057),
    [anon_sym___declspec] = ACTIONS(1060),
    [anon_sym___based] = ACTIONS(1063),
    [anon_sym___cdecl] = ACTIONS(1066),
    [anon_sym___clrcall] = ACTIONS(1066),
    [anon_sym___stdcall] = ACTIONS(1066),
    [anon_sym___fastcall] = ACTIONS(1066),
    [anon_sym___thiscall] = ACTIONS(1066),
    [anon_sym___vectorcall] = ACTIONS(1066),
    [anon_sym_LBRACE] = ACTIONS(1069),
    [anon_sym_signed] = ACTIONS(1072),
    [anon_sym_unsigned] = ACTIONS(1072),
    [anon_sym_long] = ACTIONS(1072),
    [anon_sym_short] = ACTIONS(1072),
    [anon_sym_LBRACK] = ACTIONS(1075),
    [anon_sym_static] = ACTIONS(1078),
    [anon_sym_register] = ACTIONS(1078),
    [anon_sym_inline] = ACTIONS(1081),
    [anon_sym___inline] = ACTIONS(1078),
    [anon_sym___inline__] = ACTIONS(1078),
    [anon_sym___forceinline] = ACTIONS(1078),
    [anon_sym_thread_local] = ACTIONS(1078),
    [anon_sym___thread] = ACTIONS(1078),
    [anon_sym_const] = ACTIONS(1084),
    [anon_sym_constexpr] = ACTIONS(1084),
    [anon_sym_volatile] = ACTIONS(1084),
    [anon_sym_restrict] = ACTIONS(1084),
    [anon_sym___restrict__] = ACTIONS(1084),
    [anon_sym__Atomic] = ACTIONS(1084),
    [anon_sym__Noreturn] = ACTIONS(1084),
    [anon_sym_noreturn] = ACTIONS(1084),
    [anon_sym__Nonnull] = ACTIONS(1084),
    [anon_sym_mutable] = ACTIONS(1084),
    [anon_sym_constinit] = ACTIONS(1084),
    [anon_sym_consteval] = ACTIONS(1084),
    [anon_sym___shared__] = ACTIONS(1084),
    [anon_sym___local__] = ACTIONS(1084),
    [anon_sym___constant__] = ACTIONS(1084),
    [anon_sym___managed__] = ACTIONS(1084),
    [anon_sym___grid_constant__] = ACTIONS(1084),
    [anon_sym_alignas] = ACTIONS(1087),
    [anon_sym__Alignas] = ACTIONS(1087),
    [sym_primitive_type] = ACTIONS(1090),
    [anon_sym_enum] = ACTIONS(1093),
    [anon_sym_class] = ACTIONS(1096),
    [anon_sym_struct] = ACTIONS(1099),
    [anon_sym_union] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1105),
    [anon_sym_switch] = ACTIONS(1108),
    [anon_sym_case] = ACTIONS(1111),
    [anon_sym_default] = ACTIONS(1114),
    [anon_sym_while] = ACTIONS(1117),
    [anon_sym_do] = ACTIONS(1120),
    [anon_sym_for] = ACTIONS(1123),
    [anon_sym_return] = ACTIONS(1126),
    [anon_sym_break] = ACTIONS(1129),
    [anon_sym_continue] = ACTIONS(1132),
    [anon_sym_goto] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1024),
    [anon_sym_compl] = ACTIONS(1024),
    [anon_sym_DASH_DASH] = ACTIONS(1138),
    [anon_sym_PLUS_PLUS] = ACTIONS(1138),
    [anon_sym_sizeof] = ACTIONS(1141),
    [anon_sym___alignof__] = ACTIONS(1144),
    [anon_sym___alignof] = ACTIONS(1144),
    [anon_sym__alignof] = ACTIONS(1144),
    [anon_sym_alignof] = ACTIONS(1144),
    [anon_sym__Alignof] = ACTIONS(1144),
    [anon_sym_offsetof] = ACTIONS(1147),
    [anon_sym__Generic] = ACTIONS(1150),
    [anon_sym_asm] = ACTIONS(1153),
    [anon_sym___asm__] = ACTIONS(1153),
    [anon_sym___asm] = ACTIONS(1153),
    [sym_number_literal] = ACTIONS(1156),
    [anon_sym_L_SQUOTE] = ACTIONS(1159),
    [anon_sym_u_SQUOTE] = ACTIONS(1159),
    [anon_sym_U_SQUOTE] = ACTIONS(1159),
    [anon_sym_u8_SQUOTE] = ACTIONS(1159),
    [anon_sym_SQUOTE] = ACTIONS(1159),
    [anon_sym_L_DQUOTE] = ACTIONS(1162),
    [anon_sym_u_DQUOTE] = ACTIONS(1162),
    [anon_sym_U_DQUOTE] = ACTIONS(1162),
    [anon_sym_u8_DQUOTE] = ACTIONS(1162),
    [anon_sym_DQUOTE] = ACTIONS(1162),
    [sym_true] = ACTIONS(1165),
    [sym_false] = ACTIONS(1165),
    [anon_sym_NULL] = ACTIONS(1168),
    [anon_sym_nullptr] = ACTIONS(1168),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1171),
    [anon_sym_decltype] = ACTIONS(1174),
    [anon_sym_explicit] = ACTIONS(1177),
    [anon_sym_typename] = ACTIONS(1180),
    [anon_sym_template] = ACTIONS(1183),
    [anon_sym_operator] = ACTIONS(1186),
    [anon_sym_try] = ACTIONS(1189),
    [anon_sym_delete] = ACTIONS(1192),
    [anon_sym_throw] = ACTIONS(1195),
    [anon_sym_namespace] = ACTIONS(1198),
    [anon_sym_using] = ACTIONS(1201),
    [anon_sym_static_assert] = ACTIONS(1204),
    [anon_sym_concept] = ACTIONS(1207),
    [anon_sym_co_return] = ACTIONS(1210),
    [anon_sym_co_yield] = ACTIONS(1213),
    [anon_sym_R_DQUOTE] = ACTIONS(1216),
    [anon_sym_LR_DQUOTE] = ACTIONS(1216),
    [anon_sym_uR_DQUOTE] = ACTIONS(1216),
    [anon_sym_UR_DQUOTE] = ACTIONS(1216),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1216),
    [anon_sym_co_await] = ACTIONS(1219),
    [anon_sym_new] = ACTIONS(1222),
    [anon_sym_requires] = ACTIONS(1225),
    [sym_this] = ACTIONS(1165),
    [anon_sym___launch_bounds__] = ACTIONS(1228),
  },
  [STATE(86)] = {
    [sym_declaration] = STATE(87),
    [sym_type_definition] = STATE(87),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5798),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(87),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(87),
    [sym_labeled_statement] = STATE(87),
    [sym_expression_statement] = STATE(87),
    [sym_if_statement] = STATE(87),
    [sym_switch_statement] = STATE(87),
    [sym_while_statement] = STATE(87),
    [sym_do_statement] = STATE(87),
    [sym_for_statement] = STATE(87),
    [sym_return_statement] = STATE(87),
    [sym_break_statement] = STATE(87),
    [sym_continue_statement] = STATE(87),
    [sym_goto_statement] = STATE(87),
    [sym_seh_try_statement] = STATE(87),
    [sym_seh_leave_statement] = STATE(87),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(87),
    [sym_co_return_statement] = STATE(87),
    [sym_co_yield_statement] = STATE(87),
    [sym_throw_statement] = STATE(87),
    [sym_try_statement] = STATE(87),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(87),
    [sym_identifier] = ACTIONS(1231),
    [aux_sym_preproc_include_token1] = ACTIONS(1233),
    [aux_sym_preproc_def_token1] = ACTIONS(1233),
    [aux_sym_preproc_if_token1] = ACTIONS(1233),
    [aux_sym_preproc_if_token2] = ACTIONS(1233),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1233),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1233),
    [aux_sym_preproc_else_token1] = ACTIONS(1233),
    [aux_sym_preproc_elif_token1] = ACTIONS(1233),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1233),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1233),
    [sym_preproc_directive] = ACTIONS(1233),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1239),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(1243),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1233),
    [anon_sym___cdecl] = ACTIONS(1233),
    [anon_sym___clrcall] = ACTIONS(1233),
    [anon_sym___stdcall] = ACTIONS(1233),
    [anon_sym___fastcall] = ACTIONS(1233),
    [anon_sym___thiscall] = ACTIONS(1233),
    [anon_sym___vectorcall] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_else] = ACTIONS(1233),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(1233),
    [anon_sym_default] = ACTIONS(1233),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1233),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1233),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(1233),
    [anon_sym_using] = ACTIONS(1233),
    [anon_sym_static_assert] = ACTIONS(1233),
    [anon_sym_concept] = ACTIONS(1233),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(87)] = {
    [sym_declaration] = STATE(87),
    [sym_type_definition] = STATE(87),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5798),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(87),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(87),
    [sym_labeled_statement] = STATE(87),
    [sym_expression_statement] = STATE(87),
    [sym_if_statement] = STATE(87),
    [sym_switch_statement] = STATE(87),
    [sym_while_statement] = STATE(87),
    [sym_do_statement] = STATE(87),
    [sym_for_statement] = STATE(87),
    [sym_return_statement] = STATE(87),
    [sym_break_statement] = STATE(87),
    [sym_continue_statement] = STATE(87),
    [sym_goto_statement] = STATE(87),
    [sym_seh_try_statement] = STATE(87),
    [sym_seh_leave_statement] = STATE(87),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(87),
    [sym_co_return_statement] = STATE(87),
    [sym_co_yield_statement] = STATE(87),
    [sym_throw_statement] = STATE(87),
    [sym_try_statement] = STATE(87),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(87),
    [sym_identifier] = ACTIONS(1253),
    [aux_sym_preproc_include_token1] = ACTIONS(1256),
    [aux_sym_preproc_def_token1] = ACTIONS(1256),
    [aux_sym_preproc_if_token1] = ACTIONS(1256),
    [aux_sym_preproc_if_token2] = ACTIONS(1256),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1256),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1256),
    [aux_sym_preproc_else_token1] = ACTIONS(1256),
    [aux_sym_preproc_elif_token1] = ACTIONS(1256),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1256),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1256),
    [sym_preproc_directive] = ACTIONS(1256),
    [anon_sym_LPAREN2] = ACTIONS(1258),
    [anon_sym_BANG] = ACTIONS(1261),
    [anon_sym_TILDE] = ACTIONS(1261),
    [anon_sym_DASH] = ACTIONS(1264),
    [anon_sym_PLUS] = ACTIONS(1264),
    [anon_sym_STAR] = ACTIONS(1267),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_AMP] = ACTIONS(1272),
    [anon_sym_SEMI] = ACTIONS(1275),
    [anon_sym___extension__] = ACTIONS(1278),
    [anon_sym_typedef] = ACTIONS(1281),
    [anon_sym___device__] = ACTIONS(1284),
    [anon_sym___host__] = ACTIONS(1284),
    [anon_sym___global__] = ACTIONS(1284),
    [anon_sym___forceinline__] = ACTIONS(1284),
    [anon_sym___noinline__] = ACTIONS(1284),
    [anon_sym_virtual] = ACTIONS(1284),
    [anon_sym_extern] = ACTIONS(1287),
    [anon_sym___attribute__] = ACTIONS(1290),
    [anon_sym___attribute] = ACTIONS(1290),
    [anon_sym_COLON_COLON] = ACTIONS(1293),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1296),
    [anon_sym___declspec] = ACTIONS(1299),
    [anon_sym___based] = ACTIONS(1256),
    [anon_sym___cdecl] = ACTIONS(1256),
    [anon_sym___clrcall] = ACTIONS(1256),
    [anon_sym___stdcall] = ACTIONS(1256),
    [anon_sym___fastcall] = ACTIONS(1256),
    [anon_sym___thiscall] = ACTIONS(1256),
    [anon_sym___vectorcall] = ACTIONS(1256),
    [anon_sym_LBRACE] = ACTIONS(1302),
    [anon_sym_signed] = ACTIONS(1305),
    [anon_sym_unsigned] = ACTIONS(1305),
    [anon_sym_long] = ACTIONS(1305),
    [anon_sym_short] = ACTIONS(1305),
    [anon_sym_LBRACK] = ACTIONS(1308),
    [anon_sym_static] = ACTIONS(1287),
    [anon_sym_register] = ACTIONS(1287),
    [anon_sym_inline] = ACTIONS(1287),
    [anon_sym___inline] = ACTIONS(1287),
    [anon_sym___inline__] = ACTIONS(1287),
    [anon_sym___forceinline] = ACTIONS(1287),
    [anon_sym_thread_local] = ACTIONS(1287),
    [anon_sym___thread] = ACTIONS(1287),
    [anon_sym_const] = ACTIONS(1311),
    [anon_sym_constexpr] = ACTIONS(1311),
    [anon_sym_volatile] = ACTIONS(1311),
    [anon_sym_restrict] = ACTIONS(1311),
    [anon_sym___restrict__] = ACTIONS(1311),
    [anon_sym__Atomic] = ACTIONS(1311),
    [anon_sym__Noreturn] = ACTIONS(1311),
    [anon_sym_noreturn] = ACTIONS(1311),
    [anon_sym__Nonnull] = ACTIONS(1311),
    [anon_sym_mutable] = ACTIONS(1311),
    [anon_sym_constinit] = ACTIONS(1311),
    [anon_sym_consteval] = ACTIONS(1311),
    [anon_sym___shared__] = ACTIONS(1311),
    [anon_sym___local__] = ACTIONS(1311),
    [anon_sym___constant__] = ACTIONS(1311),
    [anon_sym___managed__] = ACTIONS(1311),
    [anon_sym___grid_constant__] = ACTIONS(1311),
    [anon_sym_alignas] = ACTIONS(1314),
    [anon_sym__Alignas] = ACTIONS(1314),
    [sym_primitive_type] = ACTIONS(1317),
    [anon_sym_enum] = ACTIONS(1320),
    [anon_sym_class] = ACTIONS(1323),
    [anon_sym_struct] = ACTIONS(1326),
    [anon_sym_union] = ACTIONS(1329),
    [anon_sym_if] = ACTIONS(1332),
    [anon_sym_else] = ACTIONS(1256),
    [anon_sym_switch] = ACTIONS(1335),
    [anon_sym_case] = ACTIONS(1256),
    [anon_sym_default] = ACTIONS(1256),
    [anon_sym_while] = ACTIONS(1338),
    [anon_sym_do] = ACTIONS(1341),
    [anon_sym_for] = ACTIONS(1344),
    [anon_sym_return] = ACTIONS(1347),
    [anon_sym_break] = ACTIONS(1350),
    [anon_sym_continue] = ACTIONS(1353),
    [anon_sym_goto] = ACTIONS(1356),
    [anon_sym___try] = ACTIONS(1359),
    [anon_sym___leave] = ACTIONS(1362),
    [anon_sym_not] = ACTIONS(1264),
    [anon_sym_compl] = ACTIONS(1264),
    [anon_sym_DASH_DASH] = ACTIONS(1365),
    [anon_sym_PLUS_PLUS] = ACTIONS(1365),
    [anon_sym_sizeof] = ACTIONS(1368),
    [anon_sym___alignof__] = ACTIONS(1371),
    [anon_sym___alignof] = ACTIONS(1371),
    [anon_sym__alignof] = ACTIONS(1371),
    [anon_sym_alignof] = ACTIONS(1371),
    [anon_sym__Alignof] = ACTIONS(1371),
    [anon_sym_offsetof] = ACTIONS(1374),
    [anon_sym__Generic] = ACTIONS(1377),
    [anon_sym_asm] = ACTIONS(1380),
    [anon_sym___asm__] = ACTIONS(1380),
    [anon_sym___asm] = ACTIONS(1380),
    [sym_number_literal] = ACTIONS(1383),
    [anon_sym_L_SQUOTE] = ACTIONS(1386),
    [anon_sym_u_SQUOTE] = ACTIONS(1386),
    [anon_sym_U_SQUOTE] = ACTIONS(1386),
    [anon_sym_u8_SQUOTE] = ACTIONS(1386),
    [anon_sym_SQUOTE] = ACTIONS(1386),
    [anon_sym_L_DQUOTE] = ACTIONS(1389),
    [anon_sym_u_DQUOTE] = ACTIONS(1389),
    [anon_sym_U_DQUOTE] = ACTIONS(1389),
    [anon_sym_u8_DQUOTE] = ACTIONS(1389),
    [anon_sym_DQUOTE] = ACTIONS(1389),
    [sym_true] = ACTIONS(1392),
    [sym_false] = ACTIONS(1392),
    [anon_sym_NULL] = ACTIONS(1395),
    [anon_sym_nullptr] = ACTIONS(1395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1398),
    [anon_sym_decltype] = ACTIONS(1401),
    [anon_sym_explicit] = ACTIONS(1256),
    [anon_sym_typename] = ACTIONS(1404),
    [anon_sym_template] = ACTIONS(1407),
    [anon_sym_operator] = ACTIONS(1256),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_delete] = ACTIONS(1413),
    [anon_sym_throw] = ACTIONS(1416),
    [anon_sym_namespace] = ACTIONS(1256),
    [anon_sym_using] = ACTIONS(1256),
    [anon_sym_static_assert] = ACTIONS(1256),
    [anon_sym_concept] = ACTIONS(1256),
    [anon_sym_co_return] = ACTIONS(1419),
    [anon_sym_co_yield] = ACTIONS(1422),
    [anon_sym_R_DQUOTE] = ACTIONS(1425),
    [anon_sym_LR_DQUOTE] = ACTIONS(1425),
    [anon_sym_uR_DQUOTE] = ACTIONS(1425),
    [anon_sym_UR_DQUOTE] = ACTIONS(1425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1425),
    [anon_sym_co_await] = ACTIONS(1428),
    [anon_sym_new] = ACTIONS(1431),
    [anon_sym_requires] = ACTIONS(1434),
    [sym_this] = ACTIONS(1392),
    [anon_sym___launch_bounds__] = ACTIONS(1437),
  },
  [STATE(88)] = {
    [sym_declaration] = STATE(87),
    [sym_type_definition] = STATE(87),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5798),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(87),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(87),
    [sym_labeled_statement] = STATE(87),
    [sym_expression_statement] = STATE(87),
    [sym_if_statement] = STATE(87),
    [sym_switch_statement] = STATE(87),
    [sym_while_statement] = STATE(87),
    [sym_do_statement] = STATE(87),
    [sym_for_statement] = STATE(87),
    [sym_return_statement] = STATE(87),
    [sym_break_statement] = STATE(87),
    [sym_continue_statement] = STATE(87),
    [sym_goto_statement] = STATE(87),
    [sym_seh_try_statement] = STATE(87),
    [sym_seh_leave_statement] = STATE(87),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(87),
    [sym_co_return_statement] = STATE(87),
    [sym_co_yield_statement] = STATE(87),
    [sym_throw_statement] = STATE(87),
    [sym_try_statement] = STATE(87),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(87),
    [sym_identifier] = ACTIONS(1231),
    [aux_sym_preproc_include_token1] = ACTIONS(1440),
    [aux_sym_preproc_def_token1] = ACTIONS(1440),
    [aux_sym_preproc_if_token1] = ACTIONS(1440),
    [aux_sym_preproc_if_token2] = ACTIONS(1440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1440),
    [aux_sym_preproc_else_token1] = ACTIONS(1440),
    [aux_sym_preproc_elif_token1] = ACTIONS(1440),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1440),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1440),
    [sym_preproc_directive] = ACTIONS(1440),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1442),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(1243),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1440),
    [anon_sym___cdecl] = ACTIONS(1440),
    [anon_sym___clrcall] = ACTIONS(1440),
    [anon_sym___stdcall] = ACTIONS(1440),
    [anon_sym___fastcall] = ACTIONS(1440),
    [anon_sym___thiscall] = ACTIONS(1440),
    [anon_sym___vectorcall] = ACTIONS(1440),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_else] = ACTIONS(1440),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(1440),
    [anon_sym_default] = ACTIONS(1440),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1440),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1440),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(1440),
    [anon_sym_using] = ACTIONS(1440),
    [anon_sym_static_assert] = ACTIONS(1440),
    [anon_sym_concept] = ACTIONS(1440),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(89)] = {
    [sym_declaration] = STATE(86),
    [sym_type_definition] = STATE(86),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5798),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(86),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(86),
    [sym_labeled_statement] = STATE(86),
    [sym_expression_statement] = STATE(86),
    [sym_if_statement] = STATE(86),
    [sym_switch_statement] = STATE(86),
    [sym_while_statement] = STATE(86),
    [sym_do_statement] = STATE(86),
    [sym_for_statement] = STATE(86),
    [sym_return_statement] = STATE(86),
    [sym_break_statement] = STATE(86),
    [sym_continue_statement] = STATE(86),
    [sym_goto_statement] = STATE(86),
    [sym_seh_try_statement] = STATE(86),
    [sym_seh_leave_statement] = STATE(86),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(86),
    [sym_co_return_statement] = STATE(86),
    [sym_co_yield_statement] = STATE(86),
    [sym_throw_statement] = STATE(86),
    [sym_try_statement] = STATE(86),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(86),
    [sym_identifier] = ACTIONS(1231),
    [aux_sym_preproc_include_token1] = ACTIONS(1444),
    [aux_sym_preproc_def_token1] = ACTIONS(1444),
    [aux_sym_preproc_if_token1] = ACTIONS(1444),
    [aux_sym_preproc_if_token2] = ACTIONS(1444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1444),
    [aux_sym_preproc_else_token1] = ACTIONS(1444),
    [aux_sym_preproc_elif_token1] = ACTIONS(1444),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1444),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1444),
    [sym_preproc_directive] = ACTIONS(1444),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1446),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(1243),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1444),
    [anon_sym___cdecl] = ACTIONS(1444),
    [anon_sym___clrcall] = ACTIONS(1444),
    [anon_sym___stdcall] = ACTIONS(1444),
    [anon_sym___fastcall] = ACTIONS(1444),
    [anon_sym___thiscall] = ACTIONS(1444),
    [anon_sym___vectorcall] = ACTIONS(1444),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_else] = ACTIONS(1444),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(1444),
    [anon_sym_default] = ACTIONS(1444),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1444),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1444),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(1444),
    [anon_sym_using] = ACTIONS(1444),
    [anon_sym_static_assert] = ACTIONS(1444),
    [anon_sym_concept] = ACTIONS(1444),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(90)] = {
    [sym_declaration] = STATE(88),
    [sym_type_definition] = STATE(88),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5798),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(88),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(88),
    [sym_labeled_statement] = STATE(88),
    [sym_expression_statement] = STATE(88),
    [sym_if_statement] = STATE(88),
    [sym_switch_statement] = STATE(88),
    [sym_while_statement] = STATE(88),
    [sym_do_statement] = STATE(88),
    [sym_for_statement] = STATE(88),
    [sym_return_statement] = STATE(88),
    [sym_break_statement] = STATE(88),
    [sym_continue_statement] = STATE(88),
    [sym_goto_statement] = STATE(88),
    [sym_seh_try_statement] = STATE(88),
    [sym_seh_leave_statement] = STATE(88),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(88),
    [sym_co_return_statement] = STATE(88),
    [sym_co_yield_statement] = STATE(88),
    [sym_throw_statement] = STATE(88),
    [sym_try_statement] = STATE(88),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(88),
    [sym_identifier] = ACTIONS(1231),
    [aux_sym_preproc_include_token1] = ACTIONS(1448),
    [aux_sym_preproc_def_token1] = ACTIONS(1448),
    [aux_sym_preproc_if_token1] = ACTIONS(1448),
    [aux_sym_preproc_if_token2] = ACTIONS(1448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1448),
    [aux_sym_preproc_else_token1] = ACTIONS(1448),
    [aux_sym_preproc_elif_token1] = ACTIONS(1448),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1448),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1448),
    [sym_preproc_directive] = ACTIONS(1448),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1450),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(1243),
    [anon_sym_typedef] = ACTIONS(287),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1448),
    [anon_sym___cdecl] = ACTIONS(1448),
    [anon_sym___clrcall] = ACTIONS(1448),
    [anon_sym___stdcall] = ACTIONS(1448),
    [anon_sym___fastcall] = ACTIONS(1448),
    [anon_sym___thiscall] = ACTIONS(1448),
    [anon_sym___vectorcall] = ACTIONS(1448),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_else] = ACTIONS(1448),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(1448),
    [anon_sym_default] = ACTIONS(1448),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1448),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1448),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_namespace] = ACTIONS(1448),
    [anon_sym_using] = ACTIONS(1448),
    [anon_sym_static_assert] = ACTIONS(1448),
    [anon_sym_concept] = ACTIONS(1448),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(91)] = {
    [sym_declaration] = STATE(95),
    [sym_type_definition] = STATE(95),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5794),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(95),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(95),
    [sym_labeled_statement] = STATE(95),
    [sym_expression_statement] = STATE(95),
    [sym_if_statement] = STATE(95),
    [sym_switch_statement] = STATE(95),
    [sym_while_statement] = STATE(95),
    [sym_do_statement] = STATE(95),
    [sym_for_statement] = STATE(95),
    [sym_return_statement] = STATE(95),
    [sym_break_statement] = STATE(95),
    [sym_continue_statement] = STATE(95),
    [sym_goto_statement] = STATE(95),
    [sym_seh_try_statement] = STATE(95),
    [sym_seh_leave_statement] = STATE(95),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(95),
    [sym_co_return_statement] = STATE(95),
    [sym_co_yield_statement] = STATE(95),
    [sym_throw_statement] = STATE(95),
    [sym_try_statement] = STATE(95),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(95),
    [sym_identifier] = ACTIONS(1452),
    [aux_sym_preproc_include_token1] = ACTIONS(1448),
    [aux_sym_preproc_def_token1] = ACTIONS(1448),
    [aux_sym_preproc_if_token1] = ACTIONS(1448),
    [aux_sym_preproc_if_token2] = ACTIONS(1448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1448),
    [sym_preproc_directive] = ACTIONS(1448),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1450),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(1454),
    [anon_sym_typedef] = ACTIONS(891),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1448),
    [anon_sym___cdecl] = ACTIONS(1448),
    [anon_sym___clrcall] = ACTIONS(1448),
    [anon_sym___stdcall] = ACTIONS(1448),
    [anon_sym___fastcall] = ACTIONS(1448),
    [anon_sym___thiscall] = ACTIONS(1448),
    [anon_sym___vectorcall] = ACTIONS(1448),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_else] = ACTIONS(1448),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(1448),
    [anon_sym_default] = ACTIONS(1448),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1448),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1448),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_namespace] = ACTIONS(1448),
    [anon_sym_using] = ACTIONS(1448),
    [anon_sym_static_assert] = ACTIONS(1448),
    [anon_sym_concept] = ACTIONS(1448),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(92)] = {
    [sym_declaration] = STATE(98),
    [sym_type_definition] = STATE(98),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5837),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(98),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(98),
    [sym_labeled_statement] = STATE(98),
    [sym_expression_statement] = STATE(98),
    [sym_if_statement] = STATE(98),
    [sym_switch_statement] = STATE(98),
    [sym_while_statement] = STATE(98),
    [sym_do_statement] = STATE(98),
    [sym_for_statement] = STATE(98),
    [sym_return_statement] = STATE(98),
    [sym_break_statement] = STATE(98),
    [sym_continue_statement] = STATE(98),
    [sym_goto_statement] = STATE(98),
    [sym_seh_try_statement] = STATE(98),
    [sym_seh_leave_statement] = STATE(98),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(98),
    [sym_co_return_statement] = STATE(98),
    [sym_co_yield_statement] = STATE(98),
    [sym_throw_statement] = STATE(98),
    [sym_try_statement] = STATE(98),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(98),
    [ts_builtin_sym_end] = ACTIONS(1446),
    [sym_identifier] = ACTIONS(1456),
    [aux_sym_preproc_include_token1] = ACTIONS(1444),
    [aux_sym_preproc_def_token1] = ACTIONS(1444),
    [aux_sym_preproc_if_token1] = ACTIONS(1444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1444),
    [sym_preproc_directive] = ACTIONS(1444),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1446),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(1460),
    [anon_sym_typedef] = ACTIONS(37),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1444),
    [anon_sym___cdecl] = ACTIONS(1444),
    [anon_sym___clrcall] = ACTIONS(1444),
    [anon_sym___stdcall] = ACTIONS(1444),
    [anon_sym___fastcall] = ACTIONS(1444),
    [anon_sym___thiscall] = ACTIONS(1444),
    [anon_sym___vectorcall] = ACTIONS(1444),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_else] = ACTIONS(1444),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1444),
    [anon_sym_default] = ACTIONS(1444),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1444),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1444),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_namespace] = ACTIONS(1444),
    [anon_sym_using] = ACTIONS(1444),
    [anon_sym_static_assert] = ACTIONS(1444),
    [anon_sym_concept] = ACTIONS(1444),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(93)] = {
    [sym_declaration] = STATE(96),
    [sym_type_definition] = STATE(96),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5794),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(96),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(96),
    [sym_labeled_statement] = STATE(96),
    [sym_expression_statement] = STATE(96),
    [sym_if_statement] = STATE(96),
    [sym_switch_statement] = STATE(96),
    [sym_while_statement] = STATE(96),
    [sym_do_statement] = STATE(96),
    [sym_for_statement] = STATE(96),
    [sym_return_statement] = STATE(96),
    [sym_break_statement] = STATE(96),
    [sym_continue_statement] = STATE(96),
    [sym_goto_statement] = STATE(96),
    [sym_seh_try_statement] = STATE(96),
    [sym_seh_leave_statement] = STATE(96),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(96),
    [sym_co_return_statement] = STATE(96),
    [sym_co_yield_statement] = STATE(96),
    [sym_throw_statement] = STATE(96),
    [sym_try_statement] = STATE(96),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(96),
    [sym_identifier] = ACTIONS(1452),
    [aux_sym_preproc_include_token1] = ACTIONS(1444),
    [aux_sym_preproc_def_token1] = ACTIONS(1444),
    [aux_sym_preproc_if_token1] = ACTIONS(1444),
    [aux_sym_preproc_if_token2] = ACTIONS(1444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1444),
    [sym_preproc_directive] = ACTIONS(1444),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1446),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(1454),
    [anon_sym_typedef] = ACTIONS(891),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1444),
    [anon_sym___cdecl] = ACTIONS(1444),
    [anon_sym___clrcall] = ACTIONS(1444),
    [anon_sym___stdcall] = ACTIONS(1444),
    [anon_sym___fastcall] = ACTIONS(1444),
    [anon_sym___thiscall] = ACTIONS(1444),
    [anon_sym___vectorcall] = ACTIONS(1444),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_else] = ACTIONS(1444),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(1444),
    [anon_sym_default] = ACTIONS(1444),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1444),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1444),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_namespace] = ACTIONS(1444),
    [anon_sym_using] = ACTIONS(1444),
    [anon_sym_static_assert] = ACTIONS(1444),
    [anon_sym_concept] = ACTIONS(1444),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(94)] = {
    [sym_declaration] = STATE(94),
    [sym_type_definition] = STATE(94),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5794),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(94),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(94),
    [sym_labeled_statement] = STATE(94),
    [sym_expression_statement] = STATE(94),
    [sym_if_statement] = STATE(94),
    [sym_switch_statement] = STATE(94),
    [sym_while_statement] = STATE(94),
    [sym_do_statement] = STATE(94),
    [sym_for_statement] = STATE(94),
    [sym_return_statement] = STATE(94),
    [sym_break_statement] = STATE(94),
    [sym_continue_statement] = STATE(94),
    [sym_goto_statement] = STATE(94),
    [sym_seh_try_statement] = STATE(94),
    [sym_seh_leave_statement] = STATE(94),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(94),
    [sym_co_return_statement] = STATE(94),
    [sym_co_yield_statement] = STATE(94),
    [sym_throw_statement] = STATE(94),
    [sym_try_statement] = STATE(94),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(94),
    [sym_identifier] = ACTIONS(1466),
    [aux_sym_preproc_include_token1] = ACTIONS(1256),
    [aux_sym_preproc_def_token1] = ACTIONS(1256),
    [aux_sym_preproc_if_token1] = ACTIONS(1256),
    [aux_sym_preproc_if_token2] = ACTIONS(1256),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1256),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1256),
    [sym_preproc_directive] = ACTIONS(1256),
    [anon_sym_LPAREN2] = ACTIONS(1258),
    [anon_sym_BANG] = ACTIONS(1261),
    [anon_sym_TILDE] = ACTIONS(1261),
    [anon_sym_DASH] = ACTIONS(1264),
    [anon_sym_PLUS] = ACTIONS(1264),
    [anon_sym_STAR] = ACTIONS(1267),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_AMP] = ACTIONS(1272),
    [anon_sym_SEMI] = ACTIONS(1469),
    [anon_sym___extension__] = ACTIONS(1472),
    [anon_sym_typedef] = ACTIONS(1475),
    [anon_sym___device__] = ACTIONS(1284),
    [anon_sym___host__] = ACTIONS(1284),
    [anon_sym___global__] = ACTIONS(1284),
    [anon_sym___forceinline__] = ACTIONS(1284),
    [anon_sym___noinline__] = ACTIONS(1284),
    [anon_sym_virtual] = ACTIONS(1284),
    [anon_sym_extern] = ACTIONS(1287),
    [anon_sym___attribute__] = ACTIONS(1290),
    [anon_sym___attribute] = ACTIONS(1290),
    [anon_sym_COLON_COLON] = ACTIONS(1293),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1296),
    [anon_sym___declspec] = ACTIONS(1299),
    [anon_sym___based] = ACTIONS(1256),
    [anon_sym___cdecl] = ACTIONS(1256),
    [anon_sym___clrcall] = ACTIONS(1256),
    [anon_sym___stdcall] = ACTIONS(1256),
    [anon_sym___fastcall] = ACTIONS(1256),
    [anon_sym___thiscall] = ACTIONS(1256),
    [anon_sym___vectorcall] = ACTIONS(1256),
    [anon_sym_LBRACE] = ACTIONS(1478),
    [anon_sym_signed] = ACTIONS(1305),
    [anon_sym_unsigned] = ACTIONS(1305),
    [anon_sym_long] = ACTIONS(1305),
    [anon_sym_short] = ACTIONS(1305),
    [anon_sym_LBRACK] = ACTIONS(1308),
    [anon_sym_static] = ACTIONS(1287),
    [anon_sym_register] = ACTIONS(1287),
    [anon_sym_inline] = ACTIONS(1287),
    [anon_sym___inline] = ACTIONS(1287),
    [anon_sym___inline__] = ACTIONS(1287),
    [anon_sym___forceinline] = ACTIONS(1287),
    [anon_sym_thread_local] = ACTIONS(1287),
    [anon_sym___thread] = ACTIONS(1287),
    [anon_sym_const] = ACTIONS(1311),
    [anon_sym_constexpr] = ACTIONS(1311),
    [anon_sym_volatile] = ACTIONS(1311),
    [anon_sym_restrict] = ACTIONS(1311),
    [anon_sym___restrict__] = ACTIONS(1311),
    [anon_sym__Atomic] = ACTIONS(1311),
    [anon_sym__Noreturn] = ACTIONS(1311),
    [anon_sym_noreturn] = ACTIONS(1311),
    [anon_sym__Nonnull] = ACTIONS(1311),
    [anon_sym_mutable] = ACTIONS(1311),
    [anon_sym_constinit] = ACTIONS(1311),
    [anon_sym_consteval] = ACTIONS(1311),
    [anon_sym___shared__] = ACTIONS(1311),
    [anon_sym___local__] = ACTIONS(1311),
    [anon_sym___constant__] = ACTIONS(1311),
    [anon_sym___managed__] = ACTIONS(1311),
    [anon_sym___grid_constant__] = ACTIONS(1311),
    [anon_sym_alignas] = ACTIONS(1314),
    [anon_sym__Alignas] = ACTIONS(1314),
    [sym_primitive_type] = ACTIONS(1317),
    [anon_sym_enum] = ACTIONS(1320),
    [anon_sym_class] = ACTIONS(1323),
    [anon_sym_struct] = ACTIONS(1326),
    [anon_sym_union] = ACTIONS(1329),
    [anon_sym_if] = ACTIONS(1481),
    [anon_sym_else] = ACTIONS(1256),
    [anon_sym_switch] = ACTIONS(1484),
    [anon_sym_case] = ACTIONS(1256),
    [anon_sym_default] = ACTIONS(1256),
    [anon_sym_while] = ACTIONS(1487),
    [anon_sym_do] = ACTIONS(1490),
    [anon_sym_for] = ACTIONS(1493),
    [anon_sym_return] = ACTIONS(1496),
    [anon_sym_break] = ACTIONS(1499),
    [anon_sym_continue] = ACTIONS(1502),
    [anon_sym_goto] = ACTIONS(1505),
    [anon_sym___try] = ACTIONS(1508),
    [anon_sym___leave] = ACTIONS(1511),
    [anon_sym_not] = ACTIONS(1264),
    [anon_sym_compl] = ACTIONS(1264),
    [anon_sym_DASH_DASH] = ACTIONS(1365),
    [anon_sym_PLUS_PLUS] = ACTIONS(1365),
    [anon_sym_sizeof] = ACTIONS(1368),
    [anon_sym___alignof__] = ACTIONS(1371),
    [anon_sym___alignof] = ACTIONS(1371),
    [anon_sym__alignof] = ACTIONS(1371),
    [anon_sym_alignof] = ACTIONS(1371),
    [anon_sym__Alignof] = ACTIONS(1371),
    [anon_sym_offsetof] = ACTIONS(1374),
    [anon_sym__Generic] = ACTIONS(1377),
    [anon_sym_asm] = ACTIONS(1380),
    [anon_sym___asm__] = ACTIONS(1380),
    [anon_sym___asm] = ACTIONS(1380),
    [sym_number_literal] = ACTIONS(1383),
    [anon_sym_L_SQUOTE] = ACTIONS(1386),
    [anon_sym_u_SQUOTE] = ACTIONS(1386),
    [anon_sym_U_SQUOTE] = ACTIONS(1386),
    [anon_sym_u8_SQUOTE] = ACTIONS(1386),
    [anon_sym_SQUOTE] = ACTIONS(1386),
    [anon_sym_L_DQUOTE] = ACTIONS(1389),
    [anon_sym_u_DQUOTE] = ACTIONS(1389),
    [anon_sym_U_DQUOTE] = ACTIONS(1389),
    [anon_sym_u8_DQUOTE] = ACTIONS(1389),
    [anon_sym_DQUOTE] = ACTIONS(1389),
    [sym_true] = ACTIONS(1392),
    [sym_false] = ACTIONS(1392),
    [anon_sym_NULL] = ACTIONS(1395),
    [anon_sym_nullptr] = ACTIONS(1395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1398),
    [anon_sym_decltype] = ACTIONS(1401),
    [anon_sym_explicit] = ACTIONS(1256),
    [anon_sym_typename] = ACTIONS(1404),
    [anon_sym_template] = ACTIONS(1407),
    [anon_sym_operator] = ACTIONS(1256),
    [anon_sym_try] = ACTIONS(1514),
    [anon_sym_delete] = ACTIONS(1413),
    [anon_sym_throw] = ACTIONS(1517),
    [anon_sym_namespace] = ACTIONS(1256),
    [anon_sym_using] = ACTIONS(1256),
    [anon_sym_static_assert] = ACTIONS(1256),
    [anon_sym_concept] = ACTIONS(1256),
    [anon_sym_co_return] = ACTIONS(1520),
    [anon_sym_co_yield] = ACTIONS(1523),
    [anon_sym_R_DQUOTE] = ACTIONS(1425),
    [anon_sym_LR_DQUOTE] = ACTIONS(1425),
    [anon_sym_uR_DQUOTE] = ACTIONS(1425),
    [anon_sym_UR_DQUOTE] = ACTIONS(1425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1425),
    [anon_sym_co_await] = ACTIONS(1428),
    [anon_sym_new] = ACTIONS(1431),
    [anon_sym_requires] = ACTIONS(1434),
    [sym_this] = ACTIONS(1392),
    [anon_sym___launch_bounds__] = ACTIONS(1437),
  },
  [STATE(95)] = {
    [sym_declaration] = STATE(94),
    [sym_type_definition] = STATE(94),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5794),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(94),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(94),
    [sym_labeled_statement] = STATE(94),
    [sym_expression_statement] = STATE(94),
    [sym_if_statement] = STATE(94),
    [sym_switch_statement] = STATE(94),
    [sym_while_statement] = STATE(94),
    [sym_do_statement] = STATE(94),
    [sym_for_statement] = STATE(94),
    [sym_return_statement] = STATE(94),
    [sym_break_statement] = STATE(94),
    [sym_continue_statement] = STATE(94),
    [sym_goto_statement] = STATE(94),
    [sym_seh_try_statement] = STATE(94),
    [sym_seh_leave_statement] = STATE(94),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(94),
    [sym_co_return_statement] = STATE(94),
    [sym_co_yield_statement] = STATE(94),
    [sym_throw_statement] = STATE(94),
    [sym_try_statement] = STATE(94),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(94),
    [sym_identifier] = ACTIONS(1452),
    [aux_sym_preproc_include_token1] = ACTIONS(1440),
    [aux_sym_preproc_def_token1] = ACTIONS(1440),
    [aux_sym_preproc_if_token1] = ACTIONS(1440),
    [aux_sym_preproc_if_token2] = ACTIONS(1440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1440),
    [sym_preproc_directive] = ACTIONS(1440),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1442),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(1454),
    [anon_sym_typedef] = ACTIONS(891),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1440),
    [anon_sym___cdecl] = ACTIONS(1440),
    [anon_sym___clrcall] = ACTIONS(1440),
    [anon_sym___stdcall] = ACTIONS(1440),
    [anon_sym___fastcall] = ACTIONS(1440),
    [anon_sym___thiscall] = ACTIONS(1440),
    [anon_sym___vectorcall] = ACTIONS(1440),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_else] = ACTIONS(1440),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(1440),
    [anon_sym_default] = ACTIONS(1440),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1440),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1440),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_namespace] = ACTIONS(1440),
    [anon_sym_using] = ACTIONS(1440),
    [anon_sym_static_assert] = ACTIONS(1440),
    [anon_sym_concept] = ACTIONS(1440),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(96)] = {
    [sym_declaration] = STATE(94),
    [sym_type_definition] = STATE(94),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5794),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(94),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(94),
    [sym_labeled_statement] = STATE(94),
    [sym_expression_statement] = STATE(94),
    [sym_if_statement] = STATE(94),
    [sym_switch_statement] = STATE(94),
    [sym_while_statement] = STATE(94),
    [sym_do_statement] = STATE(94),
    [sym_for_statement] = STATE(94),
    [sym_return_statement] = STATE(94),
    [sym_break_statement] = STATE(94),
    [sym_continue_statement] = STATE(94),
    [sym_goto_statement] = STATE(94),
    [sym_seh_try_statement] = STATE(94),
    [sym_seh_leave_statement] = STATE(94),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(94),
    [sym_co_return_statement] = STATE(94),
    [sym_co_yield_statement] = STATE(94),
    [sym_throw_statement] = STATE(94),
    [sym_try_statement] = STATE(94),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(94),
    [sym_identifier] = ACTIONS(1452),
    [aux_sym_preproc_include_token1] = ACTIONS(1233),
    [aux_sym_preproc_def_token1] = ACTIONS(1233),
    [aux_sym_preproc_if_token1] = ACTIONS(1233),
    [aux_sym_preproc_if_token2] = ACTIONS(1233),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1233),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1233),
    [sym_preproc_directive] = ACTIONS(1233),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1239),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(1454),
    [anon_sym_typedef] = ACTIONS(891),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1233),
    [anon_sym___cdecl] = ACTIONS(1233),
    [anon_sym___clrcall] = ACTIONS(1233),
    [anon_sym___stdcall] = ACTIONS(1233),
    [anon_sym___fastcall] = ACTIONS(1233),
    [anon_sym___thiscall] = ACTIONS(1233),
    [anon_sym___vectorcall] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_else] = ACTIONS(1233),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(1233),
    [anon_sym_default] = ACTIONS(1233),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1233),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1233),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_namespace] = ACTIONS(1233),
    [anon_sym_using] = ACTIONS(1233),
    [anon_sym_static_assert] = ACTIONS(1233),
    [anon_sym_concept] = ACTIONS(1233),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(97)] = {
    [sym_declaration] = STATE(99),
    [sym_type_definition] = STATE(99),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5837),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(99),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(99),
    [sym_labeled_statement] = STATE(99),
    [sym_expression_statement] = STATE(99),
    [sym_if_statement] = STATE(99),
    [sym_switch_statement] = STATE(99),
    [sym_while_statement] = STATE(99),
    [sym_do_statement] = STATE(99),
    [sym_for_statement] = STATE(99),
    [sym_return_statement] = STATE(99),
    [sym_break_statement] = STATE(99),
    [sym_continue_statement] = STATE(99),
    [sym_goto_statement] = STATE(99),
    [sym_seh_try_statement] = STATE(99),
    [sym_seh_leave_statement] = STATE(99),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(99),
    [sym_co_return_statement] = STATE(99),
    [sym_co_yield_statement] = STATE(99),
    [sym_throw_statement] = STATE(99),
    [sym_try_statement] = STATE(99),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(99),
    [ts_builtin_sym_end] = ACTIONS(1442),
    [sym_identifier] = ACTIONS(1456),
    [aux_sym_preproc_include_token1] = ACTIONS(1440),
    [aux_sym_preproc_def_token1] = ACTIONS(1440),
    [aux_sym_preproc_if_token1] = ACTIONS(1440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1440),
    [sym_preproc_directive] = ACTIONS(1440),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1442),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(1460),
    [anon_sym_typedef] = ACTIONS(37),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1440),
    [anon_sym___cdecl] = ACTIONS(1440),
    [anon_sym___clrcall] = ACTIONS(1440),
    [anon_sym___stdcall] = ACTIONS(1440),
    [anon_sym___fastcall] = ACTIONS(1440),
    [anon_sym___thiscall] = ACTIONS(1440),
    [anon_sym___vectorcall] = ACTIONS(1440),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_else] = ACTIONS(1440),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1440),
    [anon_sym_default] = ACTIONS(1440),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1440),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1440),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_namespace] = ACTIONS(1440),
    [anon_sym_using] = ACTIONS(1440),
    [anon_sym_static_assert] = ACTIONS(1440),
    [anon_sym_concept] = ACTIONS(1440),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(98)] = {
    [sym_declaration] = STATE(99),
    [sym_type_definition] = STATE(99),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5837),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(99),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(99),
    [sym_labeled_statement] = STATE(99),
    [sym_expression_statement] = STATE(99),
    [sym_if_statement] = STATE(99),
    [sym_switch_statement] = STATE(99),
    [sym_while_statement] = STATE(99),
    [sym_do_statement] = STATE(99),
    [sym_for_statement] = STATE(99),
    [sym_return_statement] = STATE(99),
    [sym_break_statement] = STATE(99),
    [sym_continue_statement] = STATE(99),
    [sym_goto_statement] = STATE(99),
    [sym_seh_try_statement] = STATE(99),
    [sym_seh_leave_statement] = STATE(99),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(99),
    [sym_co_return_statement] = STATE(99),
    [sym_co_yield_statement] = STATE(99),
    [sym_throw_statement] = STATE(99),
    [sym_try_statement] = STATE(99),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(99),
    [ts_builtin_sym_end] = ACTIONS(1239),
    [sym_identifier] = ACTIONS(1456),
    [aux_sym_preproc_include_token1] = ACTIONS(1233),
    [aux_sym_preproc_def_token1] = ACTIONS(1233),
    [aux_sym_preproc_if_token1] = ACTIONS(1233),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1233),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1233),
    [sym_preproc_directive] = ACTIONS(1233),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1239),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(1460),
    [anon_sym_typedef] = ACTIONS(37),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1233),
    [anon_sym___cdecl] = ACTIONS(1233),
    [anon_sym___clrcall] = ACTIONS(1233),
    [anon_sym___stdcall] = ACTIONS(1233),
    [anon_sym___fastcall] = ACTIONS(1233),
    [anon_sym___thiscall] = ACTIONS(1233),
    [anon_sym___vectorcall] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_else] = ACTIONS(1233),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1233),
    [anon_sym_default] = ACTIONS(1233),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1233),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1233),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_namespace] = ACTIONS(1233),
    [anon_sym_using] = ACTIONS(1233),
    [anon_sym_static_assert] = ACTIONS(1233),
    [anon_sym_concept] = ACTIONS(1233),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(99)] = {
    [sym_declaration] = STATE(99),
    [sym_type_definition] = STATE(99),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5837),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(99),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(99),
    [sym_labeled_statement] = STATE(99),
    [sym_expression_statement] = STATE(99),
    [sym_if_statement] = STATE(99),
    [sym_switch_statement] = STATE(99),
    [sym_while_statement] = STATE(99),
    [sym_do_statement] = STATE(99),
    [sym_for_statement] = STATE(99),
    [sym_return_statement] = STATE(99),
    [sym_break_statement] = STATE(99),
    [sym_continue_statement] = STATE(99),
    [sym_goto_statement] = STATE(99),
    [sym_seh_try_statement] = STATE(99),
    [sym_seh_leave_statement] = STATE(99),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(99),
    [sym_co_return_statement] = STATE(99),
    [sym_co_yield_statement] = STATE(99),
    [sym_throw_statement] = STATE(99),
    [sym_try_statement] = STATE(99),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(99),
    [ts_builtin_sym_end] = ACTIONS(1270),
    [sym_identifier] = ACTIONS(1526),
    [aux_sym_preproc_include_token1] = ACTIONS(1256),
    [aux_sym_preproc_def_token1] = ACTIONS(1256),
    [aux_sym_preproc_if_token1] = ACTIONS(1256),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1256),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1256),
    [sym_preproc_directive] = ACTIONS(1256),
    [anon_sym_LPAREN2] = ACTIONS(1258),
    [anon_sym_BANG] = ACTIONS(1261),
    [anon_sym_TILDE] = ACTIONS(1261),
    [anon_sym_DASH] = ACTIONS(1264),
    [anon_sym_PLUS] = ACTIONS(1264),
    [anon_sym_STAR] = ACTIONS(1267),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_AMP] = ACTIONS(1272),
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym___extension__] = ACTIONS(1532),
    [anon_sym_typedef] = ACTIONS(1535),
    [anon_sym___device__] = ACTIONS(1284),
    [anon_sym___host__] = ACTIONS(1284),
    [anon_sym___global__] = ACTIONS(1284),
    [anon_sym___forceinline__] = ACTIONS(1284),
    [anon_sym___noinline__] = ACTIONS(1284),
    [anon_sym_virtual] = ACTIONS(1284),
    [anon_sym_extern] = ACTIONS(1287),
    [anon_sym___attribute__] = ACTIONS(1290),
    [anon_sym___attribute] = ACTIONS(1290),
    [anon_sym_COLON_COLON] = ACTIONS(1293),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1296),
    [anon_sym___declspec] = ACTIONS(1299),
    [anon_sym___based] = ACTIONS(1256),
    [anon_sym___cdecl] = ACTIONS(1256),
    [anon_sym___clrcall] = ACTIONS(1256),
    [anon_sym___stdcall] = ACTIONS(1256),
    [anon_sym___fastcall] = ACTIONS(1256),
    [anon_sym___thiscall] = ACTIONS(1256),
    [anon_sym___vectorcall] = ACTIONS(1256),
    [anon_sym_LBRACE] = ACTIONS(1538),
    [anon_sym_signed] = ACTIONS(1305),
    [anon_sym_unsigned] = ACTIONS(1305),
    [anon_sym_long] = ACTIONS(1305),
    [anon_sym_short] = ACTIONS(1305),
    [anon_sym_LBRACK] = ACTIONS(1308),
    [anon_sym_static] = ACTIONS(1287),
    [anon_sym_register] = ACTIONS(1287),
    [anon_sym_inline] = ACTIONS(1287),
    [anon_sym___inline] = ACTIONS(1287),
    [anon_sym___inline__] = ACTIONS(1287),
    [anon_sym___forceinline] = ACTIONS(1287),
    [anon_sym_thread_local] = ACTIONS(1287),
    [anon_sym___thread] = ACTIONS(1287),
    [anon_sym_const] = ACTIONS(1311),
    [anon_sym_constexpr] = ACTIONS(1311),
    [anon_sym_volatile] = ACTIONS(1311),
    [anon_sym_restrict] = ACTIONS(1311),
    [anon_sym___restrict__] = ACTIONS(1311),
    [anon_sym__Atomic] = ACTIONS(1311),
    [anon_sym__Noreturn] = ACTIONS(1311),
    [anon_sym_noreturn] = ACTIONS(1311),
    [anon_sym__Nonnull] = ACTIONS(1311),
    [anon_sym_mutable] = ACTIONS(1311),
    [anon_sym_constinit] = ACTIONS(1311),
    [anon_sym_consteval] = ACTIONS(1311),
    [anon_sym___shared__] = ACTIONS(1311),
    [anon_sym___local__] = ACTIONS(1311),
    [anon_sym___constant__] = ACTIONS(1311),
    [anon_sym___managed__] = ACTIONS(1311),
    [anon_sym___grid_constant__] = ACTIONS(1311),
    [anon_sym_alignas] = ACTIONS(1314),
    [anon_sym__Alignas] = ACTIONS(1314),
    [sym_primitive_type] = ACTIONS(1317),
    [anon_sym_enum] = ACTIONS(1320),
    [anon_sym_class] = ACTIONS(1323),
    [anon_sym_struct] = ACTIONS(1326),
    [anon_sym_union] = ACTIONS(1329),
    [anon_sym_if] = ACTIONS(1541),
    [anon_sym_else] = ACTIONS(1256),
    [anon_sym_switch] = ACTIONS(1544),
    [anon_sym_case] = ACTIONS(1256),
    [anon_sym_default] = ACTIONS(1256),
    [anon_sym_while] = ACTIONS(1547),
    [anon_sym_do] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1553),
    [anon_sym_return] = ACTIONS(1556),
    [anon_sym_break] = ACTIONS(1559),
    [anon_sym_continue] = ACTIONS(1562),
    [anon_sym_goto] = ACTIONS(1565),
    [anon_sym___try] = ACTIONS(1568),
    [anon_sym___leave] = ACTIONS(1571),
    [anon_sym_not] = ACTIONS(1264),
    [anon_sym_compl] = ACTIONS(1264),
    [anon_sym_DASH_DASH] = ACTIONS(1365),
    [anon_sym_PLUS_PLUS] = ACTIONS(1365),
    [anon_sym_sizeof] = ACTIONS(1368),
    [anon_sym___alignof__] = ACTIONS(1371),
    [anon_sym___alignof] = ACTIONS(1371),
    [anon_sym__alignof] = ACTIONS(1371),
    [anon_sym_alignof] = ACTIONS(1371),
    [anon_sym__Alignof] = ACTIONS(1371),
    [anon_sym_offsetof] = ACTIONS(1374),
    [anon_sym__Generic] = ACTIONS(1377),
    [anon_sym_asm] = ACTIONS(1380),
    [anon_sym___asm__] = ACTIONS(1380),
    [anon_sym___asm] = ACTIONS(1380),
    [sym_number_literal] = ACTIONS(1383),
    [anon_sym_L_SQUOTE] = ACTIONS(1386),
    [anon_sym_u_SQUOTE] = ACTIONS(1386),
    [anon_sym_U_SQUOTE] = ACTIONS(1386),
    [anon_sym_u8_SQUOTE] = ACTIONS(1386),
    [anon_sym_SQUOTE] = ACTIONS(1386),
    [anon_sym_L_DQUOTE] = ACTIONS(1389),
    [anon_sym_u_DQUOTE] = ACTIONS(1389),
    [anon_sym_U_DQUOTE] = ACTIONS(1389),
    [anon_sym_u8_DQUOTE] = ACTIONS(1389),
    [anon_sym_DQUOTE] = ACTIONS(1389),
    [sym_true] = ACTIONS(1392),
    [sym_false] = ACTIONS(1392),
    [anon_sym_NULL] = ACTIONS(1395),
    [anon_sym_nullptr] = ACTIONS(1395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1398),
    [anon_sym_decltype] = ACTIONS(1401),
    [anon_sym_explicit] = ACTIONS(1256),
    [anon_sym_typename] = ACTIONS(1404),
    [anon_sym_template] = ACTIONS(1407),
    [anon_sym_operator] = ACTIONS(1256),
    [anon_sym_try] = ACTIONS(1574),
    [anon_sym_delete] = ACTIONS(1413),
    [anon_sym_throw] = ACTIONS(1577),
    [anon_sym_namespace] = ACTIONS(1256),
    [anon_sym_using] = ACTIONS(1256),
    [anon_sym_static_assert] = ACTIONS(1256),
    [anon_sym_concept] = ACTIONS(1256),
    [anon_sym_co_return] = ACTIONS(1580),
    [anon_sym_co_yield] = ACTIONS(1583),
    [anon_sym_R_DQUOTE] = ACTIONS(1425),
    [anon_sym_LR_DQUOTE] = ACTIONS(1425),
    [anon_sym_uR_DQUOTE] = ACTIONS(1425),
    [anon_sym_UR_DQUOTE] = ACTIONS(1425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1425),
    [anon_sym_co_await] = ACTIONS(1428),
    [anon_sym_new] = ACTIONS(1431),
    [anon_sym_requires] = ACTIONS(1434),
    [sym_this] = ACTIONS(1392),
    [anon_sym___launch_bounds__] = ACTIONS(1437),
  },
  [STATE(100)] = {
    [sym_declaration] = STATE(97),
    [sym_type_definition] = STATE(97),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5837),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(97),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(97),
    [sym_labeled_statement] = STATE(97),
    [sym_expression_statement] = STATE(97),
    [sym_if_statement] = STATE(97),
    [sym_switch_statement] = STATE(97),
    [sym_while_statement] = STATE(97),
    [sym_do_statement] = STATE(97),
    [sym_for_statement] = STATE(97),
    [sym_return_statement] = STATE(97),
    [sym_break_statement] = STATE(97),
    [sym_continue_statement] = STATE(97),
    [sym_goto_statement] = STATE(97),
    [sym_seh_try_statement] = STATE(97),
    [sym_seh_leave_statement] = STATE(97),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(97),
    [sym_co_return_statement] = STATE(97),
    [sym_co_yield_statement] = STATE(97),
    [sym_throw_statement] = STATE(97),
    [sym_try_statement] = STATE(97),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(1450),
    [sym_identifier] = ACTIONS(1456),
    [aux_sym_preproc_include_token1] = ACTIONS(1448),
    [aux_sym_preproc_def_token1] = ACTIONS(1448),
    [aux_sym_preproc_if_token1] = ACTIONS(1448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1448),
    [sym_preproc_directive] = ACTIONS(1448),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1450),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(1460),
    [anon_sym_typedef] = ACTIONS(37),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1448),
    [anon_sym___cdecl] = ACTIONS(1448),
    [anon_sym___clrcall] = ACTIONS(1448),
    [anon_sym___stdcall] = ACTIONS(1448),
    [anon_sym___fastcall] = ACTIONS(1448),
    [anon_sym___thiscall] = ACTIONS(1448),
    [anon_sym___vectorcall] = ACTIONS(1448),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_else] = ACTIONS(1448),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1448),
    [anon_sym_default] = ACTIONS(1448),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1448),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1448),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_namespace] = ACTIONS(1448),
    [anon_sym_using] = ACTIONS(1448),
    [anon_sym_static_assert] = ACTIONS(1448),
    [anon_sym_concept] = ACTIONS(1448),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(101)] = {
    [sym_declaration] = STATE(105),
    [sym_type_definition] = STATE(105),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5821),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(105),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(105),
    [sym_labeled_statement] = STATE(105),
    [sym_expression_statement] = STATE(105),
    [sym_if_statement] = STATE(105),
    [sym_switch_statement] = STATE(105),
    [sym_while_statement] = STATE(105),
    [sym_do_statement] = STATE(105),
    [sym_for_statement] = STATE(105),
    [sym_return_statement] = STATE(105),
    [sym_break_statement] = STATE(105),
    [sym_continue_statement] = STATE(105),
    [sym_goto_statement] = STATE(105),
    [sym_seh_try_statement] = STATE(105),
    [sym_seh_leave_statement] = STATE(105),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(105),
    [sym_co_return_statement] = STATE(105),
    [sym_co_yield_statement] = STATE(105),
    [sym_throw_statement] = STATE(105),
    [sym_try_statement] = STATE(105),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(105),
    [sym_identifier] = ACTIONS(1586),
    [aux_sym_preproc_include_token1] = ACTIONS(1444),
    [aux_sym_preproc_def_token1] = ACTIONS(1444),
    [aux_sym_preproc_if_token1] = ACTIONS(1444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1444),
    [sym_preproc_directive] = ACTIONS(1444),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1446),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(1588),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1444),
    [anon_sym___cdecl] = ACTIONS(1444),
    [anon_sym___clrcall] = ACTIONS(1444),
    [anon_sym___stdcall] = ACTIONS(1444),
    [anon_sym___fastcall] = ACTIONS(1444),
    [anon_sym___thiscall] = ACTIONS(1444),
    [anon_sym___vectorcall] = ACTIONS(1444),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(1446),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_else] = ACTIONS(1444),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(1444),
    [anon_sym_default] = ACTIONS(1444),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1444),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1444),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(1444),
    [anon_sym_using] = ACTIONS(1444),
    [anon_sym_static_assert] = ACTIONS(1444),
    [anon_sym_concept] = ACTIONS(1444),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(102)] = {
    [sym_declaration] = STATE(102),
    [sym_type_definition] = STATE(102),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5821),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(102),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(102),
    [sym_labeled_statement] = STATE(102),
    [sym_expression_statement] = STATE(102),
    [sym_if_statement] = STATE(102),
    [sym_switch_statement] = STATE(102),
    [sym_while_statement] = STATE(102),
    [sym_do_statement] = STATE(102),
    [sym_for_statement] = STATE(102),
    [sym_return_statement] = STATE(102),
    [sym_break_statement] = STATE(102),
    [sym_continue_statement] = STATE(102),
    [sym_goto_statement] = STATE(102),
    [sym_seh_try_statement] = STATE(102),
    [sym_seh_leave_statement] = STATE(102),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(102),
    [sym_co_return_statement] = STATE(102),
    [sym_co_yield_statement] = STATE(102),
    [sym_throw_statement] = STATE(102),
    [sym_try_statement] = STATE(102),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(102),
    [sym_identifier] = ACTIONS(1590),
    [aux_sym_preproc_include_token1] = ACTIONS(1256),
    [aux_sym_preproc_def_token1] = ACTIONS(1256),
    [aux_sym_preproc_if_token1] = ACTIONS(1256),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1256),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1256),
    [sym_preproc_directive] = ACTIONS(1256),
    [anon_sym_LPAREN2] = ACTIONS(1258),
    [anon_sym_BANG] = ACTIONS(1261),
    [anon_sym_TILDE] = ACTIONS(1261),
    [anon_sym_DASH] = ACTIONS(1264),
    [anon_sym_PLUS] = ACTIONS(1264),
    [anon_sym_STAR] = ACTIONS(1267),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_AMP] = ACTIONS(1272),
    [anon_sym_SEMI] = ACTIONS(1593),
    [anon_sym___extension__] = ACTIONS(1596),
    [anon_sym_typedef] = ACTIONS(1599),
    [anon_sym___device__] = ACTIONS(1284),
    [anon_sym___host__] = ACTIONS(1284),
    [anon_sym___global__] = ACTIONS(1284),
    [anon_sym___forceinline__] = ACTIONS(1284),
    [anon_sym___noinline__] = ACTIONS(1284),
    [anon_sym_virtual] = ACTIONS(1284),
    [anon_sym_extern] = ACTIONS(1287),
    [anon_sym___attribute__] = ACTIONS(1290),
    [anon_sym___attribute] = ACTIONS(1290),
    [anon_sym_COLON_COLON] = ACTIONS(1293),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1296),
    [anon_sym___declspec] = ACTIONS(1299),
    [anon_sym___based] = ACTIONS(1256),
    [anon_sym___cdecl] = ACTIONS(1256),
    [anon_sym___clrcall] = ACTIONS(1256),
    [anon_sym___stdcall] = ACTIONS(1256),
    [anon_sym___fastcall] = ACTIONS(1256),
    [anon_sym___thiscall] = ACTIONS(1256),
    [anon_sym___vectorcall] = ACTIONS(1256),
    [anon_sym_LBRACE] = ACTIONS(1602),
    [anon_sym_RBRACE] = ACTIONS(1270),
    [anon_sym_signed] = ACTIONS(1305),
    [anon_sym_unsigned] = ACTIONS(1305),
    [anon_sym_long] = ACTIONS(1305),
    [anon_sym_short] = ACTIONS(1305),
    [anon_sym_LBRACK] = ACTIONS(1308),
    [anon_sym_static] = ACTIONS(1287),
    [anon_sym_register] = ACTIONS(1287),
    [anon_sym_inline] = ACTIONS(1287),
    [anon_sym___inline] = ACTIONS(1287),
    [anon_sym___inline__] = ACTIONS(1287),
    [anon_sym___forceinline] = ACTIONS(1287),
    [anon_sym_thread_local] = ACTIONS(1287),
    [anon_sym___thread] = ACTIONS(1287),
    [anon_sym_const] = ACTIONS(1311),
    [anon_sym_constexpr] = ACTIONS(1311),
    [anon_sym_volatile] = ACTIONS(1311),
    [anon_sym_restrict] = ACTIONS(1311),
    [anon_sym___restrict__] = ACTIONS(1311),
    [anon_sym__Atomic] = ACTIONS(1311),
    [anon_sym__Noreturn] = ACTIONS(1311),
    [anon_sym_noreturn] = ACTIONS(1311),
    [anon_sym__Nonnull] = ACTIONS(1311),
    [anon_sym_mutable] = ACTIONS(1311),
    [anon_sym_constinit] = ACTIONS(1311),
    [anon_sym_consteval] = ACTIONS(1311),
    [anon_sym___shared__] = ACTIONS(1311),
    [anon_sym___local__] = ACTIONS(1311),
    [anon_sym___constant__] = ACTIONS(1311),
    [anon_sym___managed__] = ACTIONS(1311),
    [anon_sym___grid_constant__] = ACTIONS(1311),
    [anon_sym_alignas] = ACTIONS(1314),
    [anon_sym__Alignas] = ACTIONS(1314),
    [sym_primitive_type] = ACTIONS(1317),
    [anon_sym_enum] = ACTIONS(1320),
    [anon_sym_class] = ACTIONS(1323),
    [anon_sym_struct] = ACTIONS(1326),
    [anon_sym_union] = ACTIONS(1329),
    [anon_sym_if] = ACTIONS(1605),
    [anon_sym_else] = ACTIONS(1256),
    [anon_sym_switch] = ACTIONS(1608),
    [anon_sym_case] = ACTIONS(1256),
    [anon_sym_default] = ACTIONS(1256),
    [anon_sym_while] = ACTIONS(1611),
    [anon_sym_do] = ACTIONS(1614),
    [anon_sym_for] = ACTIONS(1617),
    [anon_sym_return] = ACTIONS(1620),
    [anon_sym_break] = ACTIONS(1623),
    [anon_sym_continue] = ACTIONS(1626),
    [anon_sym_goto] = ACTIONS(1629),
    [anon_sym___try] = ACTIONS(1632),
    [anon_sym___leave] = ACTIONS(1635),
    [anon_sym_not] = ACTIONS(1264),
    [anon_sym_compl] = ACTIONS(1264),
    [anon_sym_DASH_DASH] = ACTIONS(1365),
    [anon_sym_PLUS_PLUS] = ACTIONS(1365),
    [anon_sym_sizeof] = ACTIONS(1368),
    [anon_sym___alignof__] = ACTIONS(1371),
    [anon_sym___alignof] = ACTIONS(1371),
    [anon_sym__alignof] = ACTIONS(1371),
    [anon_sym_alignof] = ACTIONS(1371),
    [anon_sym__Alignof] = ACTIONS(1371),
    [anon_sym_offsetof] = ACTIONS(1374),
    [anon_sym__Generic] = ACTIONS(1377),
    [anon_sym_asm] = ACTIONS(1380),
    [anon_sym___asm__] = ACTIONS(1380),
    [anon_sym___asm] = ACTIONS(1380),
    [sym_number_literal] = ACTIONS(1383),
    [anon_sym_L_SQUOTE] = ACTIONS(1386),
    [anon_sym_u_SQUOTE] = ACTIONS(1386),
    [anon_sym_U_SQUOTE] = ACTIONS(1386),
    [anon_sym_u8_SQUOTE] = ACTIONS(1386),
    [anon_sym_SQUOTE] = ACTIONS(1386),
    [anon_sym_L_DQUOTE] = ACTIONS(1389),
    [anon_sym_u_DQUOTE] = ACTIONS(1389),
    [anon_sym_U_DQUOTE] = ACTIONS(1389),
    [anon_sym_u8_DQUOTE] = ACTIONS(1389),
    [anon_sym_DQUOTE] = ACTIONS(1389),
    [sym_true] = ACTIONS(1392),
    [sym_false] = ACTIONS(1392),
    [anon_sym_NULL] = ACTIONS(1395),
    [anon_sym_nullptr] = ACTIONS(1395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1398),
    [anon_sym_decltype] = ACTIONS(1401),
    [anon_sym_explicit] = ACTIONS(1256),
    [anon_sym_typename] = ACTIONS(1404),
    [anon_sym_template] = ACTIONS(1407),
    [anon_sym_operator] = ACTIONS(1256),
    [anon_sym_try] = ACTIONS(1638),
    [anon_sym_delete] = ACTIONS(1413),
    [anon_sym_throw] = ACTIONS(1641),
    [anon_sym_namespace] = ACTIONS(1256),
    [anon_sym_using] = ACTIONS(1256),
    [anon_sym_static_assert] = ACTIONS(1256),
    [anon_sym_concept] = ACTIONS(1256),
    [anon_sym_co_return] = ACTIONS(1644),
    [anon_sym_co_yield] = ACTIONS(1647),
    [anon_sym_R_DQUOTE] = ACTIONS(1425),
    [anon_sym_LR_DQUOTE] = ACTIONS(1425),
    [anon_sym_uR_DQUOTE] = ACTIONS(1425),
    [anon_sym_UR_DQUOTE] = ACTIONS(1425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1425),
    [anon_sym_co_await] = ACTIONS(1428),
    [anon_sym_new] = ACTIONS(1431),
    [anon_sym_requires] = ACTIONS(1434),
    [sym_this] = ACTIONS(1392),
    [anon_sym___launch_bounds__] = ACTIONS(1437),
  },
  [STATE(103)] = {
    [sym_declaration] = STATE(102),
    [sym_type_definition] = STATE(102),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5821),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(102),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(102),
    [sym_labeled_statement] = STATE(102),
    [sym_expression_statement] = STATE(102),
    [sym_if_statement] = STATE(102),
    [sym_switch_statement] = STATE(102),
    [sym_while_statement] = STATE(102),
    [sym_do_statement] = STATE(102),
    [sym_for_statement] = STATE(102),
    [sym_return_statement] = STATE(102),
    [sym_break_statement] = STATE(102),
    [sym_continue_statement] = STATE(102),
    [sym_goto_statement] = STATE(102),
    [sym_seh_try_statement] = STATE(102),
    [sym_seh_leave_statement] = STATE(102),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(102),
    [sym_co_return_statement] = STATE(102),
    [sym_co_yield_statement] = STATE(102),
    [sym_throw_statement] = STATE(102),
    [sym_try_statement] = STATE(102),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(102),
    [sym_identifier] = ACTIONS(1586),
    [aux_sym_preproc_include_token1] = ACTIONS(1440),
    [aux_sym_preproc_def_token1] = ACTIONS(1440),
    [aux_sym_preproc_if_token1] = ACTIONS(1440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1440),
    [sym_preproc_directive] = ACTIONS(1440),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1442),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(1588),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1440),
    [anon_sym___cdecl] = ACTIONS(1440),
    [anon_sym___clrcall] = ACTIONS(1440),
    [anon_sym___stdcall] = ACTIONS(1440),
    [anon_sym___fastcall] = ACTIONS(1440),
    [anon_sym___thiscall] = ACTIONS(1440),
    [anon_sym___vectorcall] = ACTIONS(1440),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(1442),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_else] = ACTIONS(1440),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(1440),
    [anon_sym_default] = ACTIONS(1440),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1440),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1440),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(1440),
    [anon_sym_using] = ACTIONS(1440),
    [anon_sym_static_assert] = ACTIONS(1440),
    [anon_sym_concept] = ACTIONS(1440),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(104)] = {
    [sym_declaration] = STATE(103),
    [sym_type_definition] = STATE(103),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5821),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(103),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(103),
    [sym_labeled_statement] = STATE(103),
    [sym_expression_statement] = STATE(103),
    [sym_if_statement] = STATE(103),
    [sym_switch_statement] = STATE(103),
    [sym_while_statement] = STATE(103),
    [sym_do_statement] = STATE(103),
    [sym_for_statement] = STATE(103),
    [sym_return_statement] = STATE(103),
    [sym_break_statement] = STATE(103),
    [sym_continue_statement] = STATE(103),
    [sym_goto_statement] = STATE(103),
    [sym_seh_try_statement] = STATE(103),
    [sym_seh_leave_statement] = STATE(103),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(103),
    [sym_co_return_statement] = STATE(103),
    [sym_co_yield_statement] = STATE(103),
    [sym_throw_statement] = STATE(103),
    [sym_try_statement] = STATE(103),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(103),
    [sym_identifier] = ACTIONS(1586),
    [aux_sym_preproc_include_token1] = ACTIONS(1448),
    [aux_sym_preproc_def_token1] = ACTIONS(1448),
    [aux_sym_preproc_if_token1] = ACTIONS(1448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1448),
    [sym_preproc_directive] = ACTIONS(1448),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1450),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(1588),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1448),
    [anon_sym___cdecl] = ACTIONS(1448),
    [anon_sym___clrcall] = ACTIONS(1448),
    [anon_sym___stdcall] = ACTIONS(1448),
    [anon_sym___fastcall] = ACTIONS(1448),
    [anon_sym___thiscall] = ACTIONS(1448),
    [anon_sym___vectorcall] = ACTIONS(1448),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(1450),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_else] = ACTIONS(1448),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(1448),
    [anon_sym_default] = ACTIONS(1448),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1448),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1448),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(1448),
    [anon_sym_using] = ACTIONS(1448),
    [anon_sym_static_assert] = ACTIONS(1448),
    [anon_sym_concept] = ACTIONS(1448),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(105)] = {
    [sym_declaration] = STATE(102),
    [sym_type_definition] = STATE(102),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5821),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(102),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(102),
    [sym_labeled_statement] = STATE(102),
    [sym_expression_statement] = STATE(102),
    [sym_if_statement] = STATE(102),
    [sym_switch_statement] = STATE(102),
    [sym_while_statement] = STATE(102),
    [sym_do_statement] = STATE(102),
    [sym_for_statement] = STATE(102),
    [sym_return_statement] = STATE(102),
    [sym_break_statement] = STATE(102),
    [sym_continue_statement] = STATE(102),
    [sym_goto_statement] = STATE(102),
    [sym_seh_try_statement] = STATE(102),
    [sym_seh_leave_statement] = STATE(102),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(102),
    [sym_co_return_statement] = STATE(102),
    [sym_co_yield_statement] = STATE(102),
    [sym_throw_statement] = STATE(102),
    [sym_try_statement] = STATE(102),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(102),
    [sym_identifier] = ACTIONS(1586),
    [aux_sym_preproc_include_token1] = ACTIONS(1233),
    [aux_sym_preproc_def_token1] = ACTIONS(1233),
    [aux_sym_preproc_if_token1] = ACTIONS(1233),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1233),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1233),
    [sym_preproc_directive] = ACTIONS(1233),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP_AMP] = ACTIONS(1239),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(1588),
    [anon_sym_typedef] = ACTIONS(181),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(1233),
    [anon_sym___cdecl] = ACTIONS(1233),
    [anon_sym___clrcall] = ACTIONS(1233),
    [anon_sym___stdcall] = ACTIONS(1233),
    [anon_sym___fastcall] = ACTIONS(1233),
    [anon_sym___thiscall] = ACTIONS(1233),
    [anon_sym___vectorcall] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(1239),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_else] = ACTIONS(1233),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(1233),
    [anon_sym_default] = ACTIONS(1233),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(1233),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1233),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_namespace] = ACTIONS(1233),
    [anon_sym_using] = ACTIONS(1233),
    [anon_sym_static_assert] = ACTIONS(1233),
    [anon_sym_concept] = ACTIONS(1233),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(106)] = {
    [sym_declaration] = STATE(415),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5821),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(415),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(4968),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8254),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1586),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(185),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(107)] = {
    [sym_declaration] = STATE(109),
    [sym_type_definition] = STATE(109),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5781),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(109),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(109),
    [sym_labeled_statement] = STATE(109),
    [sym_expression_statement] = STATE(109),
    [sym_if_statement] = STATE(109),
    [sym_switch_statement] = STATE(109),
    [sym_while_statement] = STATE(109),
    [sym_do_statement] = STATE(109),
    [sym_for_statement] = STATE(109),
    [sym_return_statement] = STATE(109),
    [sym_break_statement] = STATE(109),
    [sym_continue_statement] = STATE(109),
    [sym_goto_statement] = STATE(109),
    [sym_seh_try_statement] = STATE(109),
    [sym_seh_leave_statement] = STATE(109),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(109),
    [sym_co_return_statement] = STATE(109),
    [sym_co_yield_statement] = STATE(109),
    [sym_throw_statement] = STATE(109),
    [sym_try_statement] = STATE(109),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(109),
    [sym_identifier] = ACTIONS(1652),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(1656),
    [anon_sym_typedef] = ACTIONS(1658),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_else] = ACTIONS(1440),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(108)] = {
    [sym_declaration] = STATE(110),
    [sym_type_definition] = STATE(110),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5781),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(110),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(110),
    [sym_labeled_statement] = STATE(110),
    [sym_expression_statement] = STATE(110),
    [sym_if_statement] = STATE(110),
    [sym_switch_statement] = STATE(110),
    [sym_while_statement] = STATE(110),
    [sym_do_statement] = STATE(110),
    [sym_for_statement] = STATE(110),
    [sym_return_statement] = STATE(110),
    [sym_break_statement] = STATE(110),
    [sym_continue_statement] = STATE(110),
    [sym_goto_statement] = STATE(110),
    [sym_seh_try_statement] = STATE(110),
    [sym_seh_leave_statement] = STATE(110),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(110),
    [sym_co_return_statement] = STATE(110),
    [sym_co_yield_statement] = STATE(110),
    [sym_throw_statement] = STATE(110),
    [sym_try_statement] = STATE(110),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(110),
    [sym_identifier] = ACTIONS(1652),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(1656),
    [anon_sym_typedef] = ACTIONS(1658),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_else] = ACTIONS(1444),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(109)] = {
    [sym_declaration] = STATE(109),
    [sym_type_definition] = STATE(109),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5781),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(109),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(109),
    [sym_labeled_statement] = STATE(109),
    [sym_expression_statement] = STATE(109),
    [sym_if_statement] = STATE(109),
    [sym_switch_statement] = STATE(109),
    [sym_while_statement] = STATE(109),
    [sym_do_statement] = STATE(109),
    [sym_for_statement] = STATE(109),
    [sym_return_statement] = STATE(109),
    [sym_break_statement] = STATE(109),
    [sym_continue_statement] = STATE(109),
    [sym_goto_statement] = STATE(109),
    [sym_seh_try_statement] = STATE(109),
    [sym_seh_leave_statement] = STATE(109),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(109),
    [sym_co_return_statement] = STATE(109),
    [sym_co_yield_statement] = STATE(109),
    [sym_throw_statement] = STATE(109),
    [sym_try_statement] = STATE(109),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(109),
    [sym_identifier] = ACTIONS(1692),
    [anon_sym_LPAREN2] = ACTIONS(1258),
    [anon_sym_BANG] = ACTIONS(1261),
    [anon_sym_TILDE] = ACTIONS(1261),
    [anon_sym_DASH] = ACTIONS(1264),
    [anon_sym_PLUS] = ACTIONS(1264),
    [anon_sym_STAR] = ACTIONS(1267),
    [anon_sym_AMP] = ACTIONS(1267),
    [anon_sym_SEMI] = ACTIONS(1695),
    [anon_sym___extension__] = ACTIONS(1698),
    [anon_sym_typedef] = ACTIONS(1701),
    [anon_sym___device__] = ACTIONS(1284),
    [anon_sym___host__] = ACTIONS(1284),
    [anon_sym___global__] = ACTIONS(1284),
    [anon_sym___forceinline__] = ACTIONS(1284),
    [anon_sym___noinline__] = ACTIONS(1284),
    [anon_sym_virtual] = ACTIONS(1284),
    [anon_sym_extern] = ACTIONS(1287),
    [anon_sym___attribute__] = ACTIONS(1290),
    [anon_sym___attribute] = ACTIONS(1290),
    [anon_sym_COLON_COLON] = ACTIONS(1293),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1296),
    [anon_sym___declspec] = ACTIONS(1299),
    [anon_sym_LBRACE] = ACTIONS(1704),
    [anon_sym_signed] = ACTIONS(1305),
    [anon_sym_unsigned] = ACTIONS(1305),
    [anon_sym_long] = ACTIONS(1305),
    [anon_sym_short] = ACTIONS(1305),
    [anon_sym_LBRACK] = ACTIONS(1308),
    [anon_sym_static] = ACTIONS(1287),
    [anon_sym_register] = ACTIONS(1287),
    [anon_sym_inline] = ACTIONS(1287),
    [anon_sym___inline] = ACTIONS(1287),
    [anon_sym___inline__] = ACTIONS(1287),
    [anon_sym___forceinline] = ACTIONS(1287),
    [anon_sym_thread_local] = ACTIONS(1287),
    [anon_sym___thread] = ACTIONS(1287),
    [anon_sym_const] = ACTIONS(1311),
    [anon_sym_constexpr] = ACTIONS(1311),
    [anon_sym_volatile] = ACTIONS(1311),
    [anon_sym_restrict] = ACTIONS(1311),
    [anon_sym___restrict__] = ACTIONS(1311),
    [anon_sym__Atomic] = ACTIONS(1311),
    [anon_sym__Noreturn] = ACTIONS(1311),
    [anon_sym_noreturn] = ACTIONS(1311),
    [anon_sym__Nonnull] = ACTIONS(1311),
    [anon_sym_mutable] = ACTIONS(1311),
    [anon_sym_constinit] = ACTIONS(1311),
    [anon_sym_consteval] = ACTIONS(1311),
    [anon_sym___shared__] = ACTIONS(1311),
    [anon_sym___local__] = ACTIONS(1311),
    [anon_sym___constant__] = ACTIONS(1311),
    [anon_sym___managed__] = ACTIONS(1311),
    [anon_sym___grid_constant__] = ACTIONS(1311),
    [anon_sym_alignas] = ACTIONS(1314),
    [anon_sym__Alignas] = ACTIONS(1314),
    [sym_primitive_type] = ACTIONS(1317),
    [anon_sym_enum] = ACTIONS(1320),
    [anon_sym_class] = ACTIONS(1323),
    [anon_sym_struct] = ACTIONS(1326),
    [anon_sym_union] = ACTIONS(1329),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_else] = ACTIONS(1256),
    [anon_sym_switch] = ACTIONS(1710),
    [anon_sym_while] = ACTIONS(1713),
    [anon_sym_do] = ACTIONS(1716),
    [anon_sym_for] = ACTIONS(1719),
    [anon_sym_return] = ACTIONS(1722),
    [anon_sym_break] = ACTIONS(1725),
    [anon_sym_continue] = ACTIONS(1728),
    [anon_sym_goto] = ACTIONS(1731),
    [anon_sym___try] = ACTIONS(1734),
    [anon_sym___leave] = ACTIONS(1737),
    [anon_sym_not] = ACTIONS(1264),
    [anon_sym_compl] = ACTIONS(1264),
    [anon_sym_DASH_DASH] = ACTIONS(1365),
    [anon_sym_PLUS_PLUS] = ACTIONS(1365),
    [anon_sym_sizeof] = ACTIONS(1368),
    [anon_sym___alignof__] = ACTIONS(1371),
    [anon_sym___alignof] = ACTIONS(1371),
    [anon_sym__alignof] = ACTIONS(1371),
    [anon_sym_alignof] = ACTIONS(1371),
    [anon_sym__Alignof] = ACTIONS(1371),
    [anon_sym_offsetof] = ACTIONS(1374),
    [anon_sym__Generic] = ACTIONS(1377),
    [anon_sym_asm] = ACTIONS(1380),
    [anon_sym___asm__] = ACTIONS(1380),
    [anon_sym___asm] = ACTIONS(1380),
    [sym_number_literal] = ACTIONS(1383),
    [anon_sym_L_SQUOTE] = ACTIONS(1386),
    [anon_sym_u_SQUOTE] = ACTIONS(1386),
    [anon_sym_U_SQUOTE] = ACTIONS(1386),
    [anon_sym_u8_SQUOTE] = ACTIONS(1386),
    [anon_sym_SQUOTE] = ACTIONS(1386),
    [anon_sym_L_DQUOTE] = ACTIONS(1389),
    [anon_sym_u_DQUOTE] = ACTIONS(1389),
    [anon_sym_U_DQUOTE] = ACTIONS(1389),
    [anon_sym_u8_DQUOTE] = ACTIONS(1389),
    [anon_sym_DQUOTE] = ACTIONS(1389),
    [sym_true] = ACTIONS(1392),
    [sym_false] = ACTIONS(1392),
    [anon_sym_NULL] = ACTIONS(1395),
    [anon_sym_nullptr] = ACTIONS(1395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1398),
    [anon_sym_decltype] = ACTIONS(1401),
    [anon_sym_typename] = ACTIONS(1404),
    [anon_sym_template] = ACTIONS(1407),
    [anon_sym_try] = ACTIONS(1740),
    [anon_sym_delete] = ACTIONS(1413),
    [anon_sym_throw] = ACTIONS(1743),
    [anon_sym_co_return] = ACTIONS(1746),
    [anon_sym_co_yield] = ACTIONS(1749),
    [anon_sym_R_DQUOTE] = ACTIONS(1425),
    [anon_sym_LR_DQUOTE] = ACTIONS(1425),
    [anon_sym_uR_DQUOTE] = ACTIONS(1425),
    [anon_sym_UR_DQUOTE] = ACTIONS(1425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1425),
    [anon_sym_co_await] = ACTIONS(1428),
    [anon_sym_new] = ACTIONS(1431),
    [anon_sym_requires] = ACTIONS(1434),
    [sym_this] = ACTIONS(1392),
    [anon_sym___launch_bounds__] = ACTIONS(1437),
  },
  [STATE(110)] = {
    [sym_declaration] = STATE(109),
    [sym_type_definition] = STATE(109),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5781),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(109),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(109),
    [sym_labeled_statement] = STATE(109),
    [sym_expression_statement] = STATE(109),
    [sym_if_statement] = STATE(109),
    [sym_switch_statement] = STATE(109),
    [sym_while_statement] = STATE(109),
    [sym_do_statement] = STATE(109),
    [sym_for_statement] = STATE(109),
    [sym_return_statement] = STATE(109),
    [sym_break_statement] = STATE(109),
    [sym_continue_statement] = STATE(109),
    [sym_goto_statement] = STATE(109),
    [sym_seh_try_statement] = STATE(109),
    [sym_seh_leave_statement] = STATE(109),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(109),
    [sym_co_return_statement] = STATE(109),
    [sym_co_yield_statement] = STATE(109),
    [sym_throw_statement] = STATE(109),
    [sym_try_statement] = STATE(109),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(109),
    [sym_identifier] = ACTIONS(1652),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(1656),
    [anon_sym_typedef] = ACTIONS(1658),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_else] = ACTIONS(1233),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(111)] = {
    [sym_declaration] = STATE(437),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5837),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(368),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(437),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(112)] = {
    [sym_declaration] = STATE(195),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5798),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(201),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(195),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1231),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(113)] = {
    [sym_declaration] = STATE(437),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5837),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(437),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1752),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(114)] = {
    [sym_declaration] = STATE(387),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5794),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(375),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(387),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1452),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(115)] = {
    [sym_declaration] = STATE(415),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5821),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(423),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(415),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1586),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(116)] = {
    [sym_declaration] = STATE(897),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5781),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(885),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(897),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1652),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(117)] = {
    [sym_declaration] = STATE(107),
    [sym_type_definition] = STATE(107),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5781),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(876),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_compound_statement] = STATE(107),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_attributed_statement] = STATE(107),
    [sym_labeled_statement] = STATE(107),
    [sym_expression_statement] = STATE(107),
    [sym_if_statement] = STATE(107),
    [sym_switch_statement] = STATE(107),
    [sym_while_statement] = STATE(107),
    [sym_do_statement] = STATE(107),
    [sym_for_statement] = STATE(107),
    [sym_return_statement] = STATE(107),
    [sym_break_statement] = STATE(107),
    [sym_continue_statement] = STATE(107),
    [sym_goto_statement] = STATE(107),
    [sym_seh_try_statement] = STATE(107),
    [sym_seh_leave_statement] = STATE(107),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(107),
    [sym_co_return_statement] = STATE(107),
    [sym_co_yield_statement] = STATE(107),
    [sym_throw_statement] = STATE(107),
    [sym_try_statement] = STATE(107),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_case_statement_repeat1] = STATE(107),
    [sym_identifier] = ACTIONS(1652),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(1656),
    [anon_sym_typedef] = ACTIONS(1658),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_else] = ACTIONS(1448),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(118)] = {
    [sym_declaration] = STATE(199),
    [sym_type_definition] = STATE(3374),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5808),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_expression_statement] = STATE(3374),
    [sym__for_statement_body] = STATE(8589),
    [sym_expression] = STATE(5119),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8727),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_alias_declaration] = STATE(3374),
    [sym__for_range_loop_body] = STATE(8751),
    [sym_init_statement] = STATE(1887),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1766),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1768),
    [anon_sym___extension__] = ACTIONS(1770),
    [anon_sym_typedef] = ACTIONS(1772),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_using] = ACTIONS(1776),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(119)] = {
    [sym_declaration] = STATE(199),
    [sym_type_definition] = STATE(3374),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5808),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_expression_statement] = STATE(3374),
    [sym__for_statement_body] = STATE(9030),
    [sym_expression] = STATE(5119),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8727),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_alias_declaration] = STATE(3374),
    [sym__for_range_loop_body] = STATE(9053),
    [sym_init_statement] = STATE(1887),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1766),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1768),
    [anon_sym___extension__] = ACTIONS(1770),
    [anon_sym_typedef] = ACTIONS(1772),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_using] = ACTIONS(1776),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(120)] = {
    [sym_declaration] = STATE(199),
    [sym_type_definition] = STATE(3374),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5808),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_expression_statement] = STATE(3374),
    [sym__for_statement_body] = STATE(9125),
    [sym_expression] = STATE(5119),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8727),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_alias_declaration] = STATE(3374),
    [sym__for_range_loop_body] = STATE(9321),
    [sym_init_statement] = STATE(1887),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1766),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1768),
    [anon_sym___extension__] = ACTIONS(1770),
    [anon_sym_typedef] = ACTIONS(1772),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_using] = ACTIONS(1776),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(121)] = {
    [sym_declaration] = STATE(199),
    [sym_type_definition] = STATE(3374),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5808),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_expression_statement] = STATE(3374),
    [sym__for_statement_body] = STATE(8921),
    [sym_expression] = STATE(5119),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8727),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_alias_declaration] = STATE(3374),
    [sym__for_range_loop_body] = STATE(8927),
    [sym_init_statement] = STATE(1887),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1766),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1768),
    [anon_sym___extension__] = ACTIONS(1770),
    [anon_sym_typedef] = ACTIONS(1772),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_using] = ACTIONS(1776),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(122)] = {
    [sym_declaration] = STATE(199),
    [sym_type_definition] = STATE(3374),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5808),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_expression_statement] = STATE(3374),
    [sym__for_statement_body] = STATE(9484),
    [sym_expression] = STATE(5119),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8727),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_alias_declaration] = STATE(3374),
    [sym__for_range_loop_body] = STATE(9486),
    [sym_init_statement] = STATE(1887),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1766),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1768),
    [anon_sym___extension__] = ACTIONS(1770),
    [anon_sym_typedef] = ACTIONS(1772),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_using] = ACTIONS(1776),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(123)] = {
    [sym_declaration] = STATE(199),
    [sym_type_definition] = STATE(3374),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5808),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_expression_statement] = STATE(3374),
    [sym__for_statement_body] = STATE(8692),
    [sym_expression] = STATE(5119),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8727),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_alias_declaration] = STATE(3374),
    [sym__for_range_loop_body] = STATE(8693),
    [sym_init_statement] = STATE(1887),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1766),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1768),
    [anon_sym___extension__] = ACTIONS(1770),
    [anon_sym_typedef] = ACTIONS(1772),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_using] = ACTIONS(1776),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(124)] = {
    [sym_declaration] = STATE(985),
    [sym_type_definition] = STATE(985),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5829),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_expression_statement] = STATE(985),
    [sym_expression] = STATE(5004),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8528),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_alias_declaration] = STATE(985),
    [sym_init_statement] = STATE(137),
    [sym_condition_declaration] = STATE(9418),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1766),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(1656),
    [anon_sym_typedef] = ACTIONS(1658),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_using] = ACTIONS(1778),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(125)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_expression] = STATE(3502),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8242),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(8842),
    [sym__unary_right_fold] = STATE(8886),
    [sym__binary_fold] = STATE(8891),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6279),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1780),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1794),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1800),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(126)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_expression] = STATE(3533),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8242),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(8711),
    [sym__unary_right_fold] = STATE(8719),
    [sym__binary_fold] = STATE(8774),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6279),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1780),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1794),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1800),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(127)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_expression] = STATE(3511),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8242),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9222),
    [sym__unary_right_fold] = STATE(9260),
    [sym__binary_fold] = STATE(9292),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6279),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1780),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1794),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1800),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(128)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_expression] = STATE(3531),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8242),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9035),
    [sym__unary_right_fold] = STATE(9043),
    [sym__binary_fold] = STATE(9045),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6279),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1780),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1794),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1800),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(129)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_expression] = STATE(3539),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8242),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(8735),
    [sym__unary_right_fold] = STATE(8747),
    [sym__binary_fold] = STATE(8755),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6279),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1780),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1794),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1800),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(130)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_compound_statement] = STATE(8044),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(8202),
    [sym_expression] = STATE(5006),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8044),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(8202),
    [sym_variadic_parameter_declaration] = STATE(8202),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6285),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1844),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1846),
    [anon_sym_RPAREN] = ACTIONS(1848),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(131)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_expression] = STATE(3497),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8242),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6279),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1780),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1794),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1800),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(132)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_expression] = STATE(3489),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8242),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9403),
    [sym__unary_right_fold] = STATE(9405),
    [sym__binary_fold] = STATE(9406),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6279),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1780),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1794),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1800),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(133)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_expression] = STATE(3480),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8242),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6279),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1780),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1794),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1800),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(134)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(5877),
    [sym__declarator] = STATE(7291),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9114),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3726),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6246),
    [sym_qualified_identifier] = STATE(3729),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(1852),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1854),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1858),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1862),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(1864),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(1870),
    [anon_sym___clrcall] = ACTIONS(1870),
    [anon_sym___stdcall] = ACTIONS(1870),
    [anon_sym___fastcall] = ACTIONS(1870),
    [anon_sym___thiscall] = ACTIONS(1870),
    [anon_sym___vectorcall] = ACTIONS(1870),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(1874),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(135)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(5877),
    [sym__declarator] = STATE(7291),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9443),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3726),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6246),
    [sym_qualified_identifier] = STATE(3729),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(1852),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1854),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1858),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1862),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(1864),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(1870),
    [anon_sym___clrcall] = ACTIONS(1870),
    [anon_sym___stdcall] = ACTIONS(1870),
    [anon_sym___fastcall] = ACTIONS(1870),
    [anon_sym___thiscall] = ACTIONS(1870),
    [anon_sym___vectorcall] = ACTIONS(1870),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(1874),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(136)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(5877),
    [sym__declarator] = STATE(7291),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_compound_statement] = STATE(9333),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3185),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9333),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9391),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3726),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9403),
    [sym__unary_right_fold] = STATE(9405),
    [sym__binary_fold] = STATE(9406),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6246),
    [sym_qualified_identifier] = STATE(3729),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9415),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(1852),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1854),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1858),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1862),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(1864),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(1870),
    [anon_sym___clrcall] = ACTIONS(1870),
    [anon_sym___stdcall] = ACTIONS(1870),
    [anon_sym___fastcall] = ACTIONS(1870),
    [anon_sym___thiscall] = ACTIONS(1870),
    [anon_sym___vectorcall] = ACTIONS(1870),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(1874),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(137)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5875),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_expression] = STATE(5053),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9458),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2683),
    [sym_template_function] = STATE(4360),
    [sym_condition_declaration] = STATE(9458),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6266),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2688),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(1766),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1650),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(69),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(138)] = {
    [ts_builtin_sym_end] = ACTIONS(1926),
    [sym_identifier] = ACTIONS(1928),
    [aux_sym_preproc_include_token1] = ACTIONS(1928),
    [aux_sym_preproc_def_token1] = ACTIONS(1928),
    [anon_sym_COMMA] = ACTIONS(1926),
    [anon_sym_RPAREN] = ACTIONS(1926),
    [aux_sym_preproc_if_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1928),
    [sym_preproc_directive] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_BANG] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_DASH] = ACTIONS(1928),
    [anon_sym_PLUS] = ACTIONS(1928),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_PIPE_PIPE] = ACTIONS(1926),
    [anon_sym_AMP_AMP] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1928),
    [anon_sym_SEMI] = ACTIONS(1926),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym_typedef] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym___based] = ACTIONS(1928),
    [anon_sym___cdecl] = ACTIONS(1928),
    [anon_sym___clrcall] = ACTIONS(1928),
    [anon_sym___stdcall] = ACTIONS(1928),
    [anon_sym___fastcall] = ACTIONS(1928),
    [anon_sym___thiscall] = ACTIONS(1928),
    [anon_sym___vectorcall] = ACTIONS(1928),
    [anon_sym_LBRACE] = ACTIONS(1926),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_EQ] = ACTIONS(1926),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [anon_sym_if] = ACTIONS(1928),
    [anon_sym_else] = ACTIONS(1928),
    [anon_sym_switch] = ACTIONS(1928),
    [anon_sym_case] = ACTIONS(1928),
    [anon_sym_default] = ACTIONS(1928),
    [anon_sym_while] = ACTIONS(1928),
    [anon_sym_do] = ACTIONS(1928),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_return] = ACTIONS(1928),
    [anon_sym_break] = ACTIONS(1928),
    [anon_sym_continue] = ACTIONS(1928),
    [anon_sym_goto] = ACTIONS(1928),
    [anon_sym___try] = ACTIONS(1928),
    [anon_sym___except] = ACTIONS(1928),
    [anon_sym___finally] = ACTIONS(1928),
    [anon_sym___leave] = ACTIONS(1928),
    [anon_sym_not] = ACTIONS(1928),
    [anon_sym_compl] = ACTIONS(1928),
    [anon_sym_or] = ACTIONS(1928),
    [anon_sym_and] = ACTIONS(1928),
    [anon_sym_DASH_DASH] = ACTIONS(1926),
    [anon_sym_PLUS_PLUS] = ACTIONS(1926),
    [anon_sym_sizeof] = ACTIONS(1928),
    [anon_sym___alignof__] = ACTIONS(1928),
    [anon_sym___alignof] = ACTIONS(1928),
    [anon_sym__alignof] = ACTIONS(1928),
    [anon_sym_alignof] = ACTIONS(1928),
    [anon_sym__Alignof] = ACTIONS(1928),
    [anon_sym_offsetof] = ACTIONS(1928),
    [anon_sym__Generic] = ACTIONS(1928),
    [anon_sym_asm] = ACTIONS(1928),
    [anon_sym___asm__] = ACTIONS(1928),
    [anon_sym___asm] = ACTIONS(1928),
    [sym_number_literal] = ACTIONS(1926),
    [anon_sym_L_SQUOTE] = ACTIONS(1926),
    [anon_sym_u_SQUOTE] = ACTIONS(1926),
    [anon_sym_U_SQUOTE] = ACTIONS(1926),
    [anon_sym_u8_SQUOTE] = ACTIONS(1926),
    [anon_sym_SQUOTE] = ACTIONS(1926),
    [anon_sym_L_DQUOTE] = ACTIONS(1926),
    [anon_sym_u_DQUOTE] = ACTIONS(1926),
    [anon_sym_U_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8_DQUOTE] = ACTIONS(1926),
    [anon_sym_DQUOTE] = ACTIONS(1926),
    [sym_true] = ACTIONS(1928),
    [sym_false] = ACTIONS(1928),
    [anon_sym_NULL] = ACTIONS(1928),
    [anon_sym_nullptr] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_final] = ACTIONS(1928),
    [anon_sym_override] = ACTIONS(1928),
    [anon_sym_explicit] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_GT2] = ACTIONS(1926),
    [anon_sym_operator] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_delete] = ACTIONS(1928),
    [anon_sym_throw] = ACTIONS(1928),
    [anon_sym_namespace] = ACTIONS(1928),
    [anon_sym_using] = ACTIONS(1928),
    [anon_sym_static_assert] = ACTIONS(1928),
    [anon_sym_concept] = ACTIONS(1928),
    [anon_sym_co_return] = ACTIONS(1928),
    [anon_sym_co_yield] = ACTIONS(1928),
    [anon_sym_catch] = ACTIONS(1928),
    [anon_sym_R_DQUOTE] = ACTIONS(1926),
    [anon_sym_LR_DQUOTE] = ACTIONS(1926),
    [anon_sym_uR_DQUOTE] = ACTIONS(1926),
    [anon_sym_UR_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1926),
    [anon_sym_co_await] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1928),
    [anon_sym_requires] = ACTIONS(1928),
    [sym_this] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(139)] = {
    [ts_builtin_sym_end] = ACTIONS(1930),
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(1930),
    [anon_sym_RPAREN] = ACTIONS(1930),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_PIPE_PIPE] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_EQ] = ACTIONS(1930),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_else] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___except] = ACTIONS(1932),
    [anon_sym___finally] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_or] = ACTIONS(1932),
    [anon_sym_and] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_final] = ACTIONS(1932),
    [anon_sym_override] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_GT2] = ACTIONS(1930),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_catch] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(140)] = {
    [sym_catch_clause] = STATE(141),
    [aux_sym_constructor_try_statement_repeat1] = STATE(141),
    [sym_identifier] = ACTIONS(1934),
    [aux_sym_preproc_include_token1] = ACTIONS(1934),
    [aux_sym_preproc_def_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token2] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1934),
    [aux_sym_preproc_else_token1] = ACTIONS(1934),
    [aux_sym_preproc_elif_token1] = ACTIONS(1934),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1934),
    [sym_preproc_directive] = ACTIONS(1934),
    [anon_sym_LPAREN2] = ACTIONS(1936),
    [anon_sym_BANG] = ACTIONS(1936),
    [anon_sym_TILDE] = ACTIONS(1936),
    [anon_sym_DASH] = ACTIONS(1934),
    [anon_sym_PLUS] = ACTIONS(1934),
    [anon_sym_STAR] = ACTIONS(1936),
    [anon_sym_AMP_AMP] = ACTIONS(1936),
    [anon_sym_AMP] = ACTIONS(1934),
    [anon_sym_SEMI] = ACTIONS(1936),
    [anon_sym___extension__] = ACTIONS(1934),
    [anon_sym_typedef] = ACTIONS(1934),
    [anon_sym___device__] = ACTIONS(1934),
    [anon_sym___host__] = ACTIONS(1934),
    [anon_sym___global__] = ACTIONS(1934),
    [anon_sym___forceinline__] = ACTIONS(1934),
    [anon_sym___noinline__] = ACTIONS(1934),
    [anon_sym_virtual] = ACTIONS(1934),
    [anon_sym_extern] = ACTIONS(1934),
    [anon_sym___attribute__] = ACTIONS(1934),
    [anon_sym___attribute] = ACTIONS(1934),
    [anon_sym_COLON_COLON] = ACTIONS(1936),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1936),
    [anon_sym___declspec] = ACTIONS(1934),
    [anon_sym___based] = ACTIONS(1934),
    [anon_sym___cdecl] = ACTIONS(1934),
    [anon_sym___clrcall] = ACTIONS(1934),
    [anon_sym___stdcall] = ACTIONS(1934),
    [anon_sym___fastcall] = ACTIONS(1934),
    [anon_sym___thiscall] = ACTIONS(1934),
    [anon_sym___vectorcall] = ACTIONS(1934),
    [anon_sym_LBRACE] = ACTIONS(1936),
    [anon_sym_signed] = ACTIONS(1934),
    [anon_sym_unsigned] = ACTIONS(1934),
    [anon_sym_long] = ACTIONS(1934),
    [anon_sym_short] = ACTIONS(1934),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [anon_sym_static] = ACTIONS(1934),
    [anon_sym_register] = ACTIONS(1934),
    [anon_sym_inline] = ACTIONS(1934),
    [anon_sym___inline] = ACTIONS(1934),
    [anon_sym___inline__] = ACTIONS(1934),
    [anon_sym___forceinline] = ACTIONS(1934),
    [anon_sym_thread_local] = ACTIONS(1934),
    [anon_sym___thread] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1934),
    [anon_sym_constexpr] = ACTIONS(1934),
    [anon_sym_volatile] = ACTIONS(1934),
    [anon_sym_restrict] = ACTIONS(1934),
    [anon_sym___restrict__] = ACTIONS(1934),
    [anon_sym__Atomic] = ACTIONS(1934),
    [anon_sym__Noreturn] = ACTIONS(1934),
    [anon_sym_noreturn] = ACTIONS(1934),
    [anon_sym__Nonnull] = ACTIONS(1934),
    [anon_sym_mutable] = ACTIONS(1934),
    [anon_sym_constinit] = ACTIONS(1934),
    [anon_sym_consteval] = ACTIONS(1934),
    [anon_sym___shared__] = ACTIONS(1934),
    [anon_sym___local__] = ACTIONS(1934),
    [anon_sym___constant__] = ACTIONS(1934),
    [anon_sym___managed__] = ACTIONS(1934),
    [anon_sym___grid_constant__] = ACTIONS(1934),
    [anon_sym_alignas] = ACTIONS(1934),
    [anon_sym__Alignas] = ACTIONS(1934),
    [sym_primitive_type] = ACTIONS(1934),
    [anon_sym_enum] = ACTIONS(1934),
    [anon_sym_class] = ACTIONS(1934),
    [anon_sym_struct] = ACTIONS(1934),
    [anon_sym_union] = ACTIONS(1934),
    [anon_sym_if] = ACTIONS(1934),
    [anon_sym_else] = ACTIONS(1934),
    [anon_sym_switch] = ACTIONS(1934),
    [anon_sym_case] = ACTIONS(1934),
    [anon_sym_default] = ACTIONS(1934),
    [anon_sym_while] = ACTIONS(1934),
    [anon_sym_do] = ACTIONS(1934),
    [anon_sym_for] = ACTIONS(1934),
    [anon_sym_return] = ACTIONS(1934),
    [anon_sym_break] = ACTIONS(1934),
    [anon_sym_continue] = ACTIONS(1934),
    [anon_sym_goto] = ACTIONS(1934),
    [anon_sym___try] = ACTIONS(1934),
    [anon_sym___leave] = ACTIONS(1934),
    [anon_sym_not] = ACTIONS(1934),
    [anon_sym_compl] = ACTIONS(1934),
    [anon_sym_DASH_DASH] = ACTIONS(1936),
    [anon_sym_PLUS_PLUS] = ACTIONS(1936),
    [anon_sym_sizeof] = ACTIONS(1934),
    [anon_sym___alignof__] = ACTIONS(1934),
    [anon_sym___alignof] = ACTIONS(1934),
    [anon_sym__alignof] = ACTIONS(1934),
    [anon_sym_alignof] = ACTIONS(1934),
    [anon_sym__Alignof] = ACTIONS(1934),
    [anon_sym_offsetof] = ACTIONS(1934),
    [anon_sym__Generic] = ACTIONS(1934),
    [anon_sym_asm] = ACTIONS(1934),
    [anon_sym___asm__] = ACTIONS(1934),
    [anon_sym___asm] = ACTIONS(1934),
    [sym_number_literal] = ACTIONS(1936),
    [anon_sym_L_SQUOTE] = ACTIONS(1936),
    [anon_sym_u_SQUOTE] = ACTIONS(1936),
    [anon_sym_U_SQUOTE] = ACTIONS(1936),
    [anon_sym_u8_SQUOTE] = ACTIONS(1936),
    [anon_sym_SQUOTE] = ACTIONS(1936),
    [anon_sym_L_DQUOTE] = ACTIONS(1936),
    [anon_sym_u_DQUOTE] = ACTIONS(1936),
    [anon_sym_U_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8_DQUOTE] = ACTIONS(1936),
    [anon_sym_DQUOTE] = ACTIONS(1936),
    [sym_true] = ACTIONS(1934),
    [sym_false] = ACTIONS(1934),
    [anon_sym_NULL] = ACTIONS(1934),
    [anon_sym_nullptr] = ACTIONS(1934),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1934),
    [anon_sym_decltype] = ACTIONS(1934),
    [anon_sym_explicit] = ACTIONS(1934),
    [anon_sym_typename] = ACTIONS(1934),
    [anon_sym_template] = ACTIONS(1934),
    [anon_sym_operator] = ACTIONS(1934),
    [anon_sym_try] = ACTIONS(1934),
    [anon_sym_delete] = ACTIONS(1934),
    [anon_sym_throw] = ACTIONS(1934),
    [anon_sym_namespace] = ACTIONS(1934),
    [anon_sym_using] = ACTIONS(1934),
    [anon_sym_static_assert] = ACTIONS(1934),
    [anon_sym_concept] = ACTIONS(1934),
    [anon_sym_co_return] = ACTIONS(1934),
    [anon_sym_co_yield] = ACTIONS(1934),
    [anon_sym_catch] = ACTIONS(1938),
    [anon_sym_R_DQUOTE] = ACTIONS(1936),
    [anon_sym_LR_DQUOTE] = ACTIONS(1936),
    [anon_sym_uR_DQUOTE] = ACTIONS(1936),
    [anon_sym_UR_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1936),
    [anon_sym_co_await] = ACTIONS(1934),
    [anon_sym_new] = ACTIONS(1934),
    [anon_sym_requires] = ACTIONS(1934),
    [sym_this] = ACTIONS(1934),
    [anon_sym___launch_bounds__] = ACTIONS(1934),
  },
  [STATE(141)] = {
    [sym_catch_clause] = STATE(141),
    [aux_sym_constructor_try_statement_repeat1] = STATE(141),
    [sym_identifier] = ACTIONS(1940),
    [aux_sym_preproc_include_token1] = ACTIONS(1940),
    [aux_sym_preproc_def_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token2] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1940),
    [aux_sym_preproc_else_token1] = ACTIONS(1940),
    [aux_sym_preproc_elif_token1] = ACTIONS(1940),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1940),
    [sym_preproc_directive] = ACTIONS(1940),
    [anon_sym_LPAREN2] = ACTIONS(1942),
    [anon_sym_BANG] = ACTIONS(1942),
    [anon_sym_TILDE] = ACTIONS(1942),
    [anon_sym_DASH] = ACTIONS(1940),
    [anon_sym_PLUS] = ACTIONS(1940),
    [anon_sym_STAR] = ACTIONS(1942),
    [anon_sym_AMP_AMP] = ACTIONS(1942),
    [anon_sym_AMP] = ACTIONS(1940),
    [anon_sym_SEMI] = ACTIONS(1942),
    [anon_sym___extension__] = ACTIONS(1940),
    [anon_sym_typedef] = ACTIONS(1940),
    [anon_sym___device__] = ACTIONS(1940),
    [anon_sym___host__] = ACTIONS(1940),
    [anon_sym___global__] = ACTIONS(1940),
    [anon_sym___forceinline__] = ACTIONS(1940),
    [anon_sym___noinline__] = ACTIONS(1940),
    [anon_sym_virtual] = ACTIONS(1940),
    [anon_sym_extern] = ACTIONS(1940),
    [anon_sym___attribute__] = ACTIONS(1940),
    [anon_sym___attribute] = ACTIONS(1940),
    [anon_sym_COLON_COLON] = ACTIONS(1942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1942),
    [anon_sym___declspec] = ACTIONS(1940),
    [anon_sym___based] = ACTIONS(1940),
    [anon_sym___cdecl] = ACTIONS(1940),
    [anon_sym___clrcall] = ACTIONS(1940),
    [anon_sym___stdcall] = ACTIONS(1940),
    [anon_sym___fastcall] = ACTIONS(1940),
    [anon_sym___thiscall] = ACTIONS(1940),
    [anon_sym___vectorcall] = ACTIONS(1940),
    [anon_sym_LBRACE] = ACTIONS(1942),
    [anon_sym_signed] = ACTIONS(1940),
    [anon_sym_unsigned] = ACTIONS(1940),
    [anon_sym_long] = ACTIONS(1940),
    [anon_sym_short] = ACTIONS(1940),
    [anon_sym_LBRACK] = ACTIONS(1940),
    [anon_sym_static] = ACTIONS(1940),
    [anon_sym_register] = ACTIONS(1940),
    [anon_sym_inline] = ACTIONS(1940),
    [anon_sym___inline] = ACTIONS(1940),
    [anon_sym___inline__] = ACTIONS(1940),
    [anon_sym___forceinline] = ACTIONS(1940),
    [anon_sym_thread_local] = ACTIONS(1940),
    [anon_sym___thread] = ACTIONS(1940),
    [anon_sym_const] = ACTIONS(1940),
    [anon_sym_constexpr] = ACTIONS(1940),
    [anon_sym_volatile] = ACTIONS(1940),
    [anon_sym_restrict] = ACTIONS(1940),
    [anon_sym___restrict__] = ACTIONS(1940),
    [anon_sym__Atomic] = ACTIONS(1940),
    [anon_sym__Noreturn] = ACTIONS(1940),
    [anon_sym_noreturn] = ACTIONS(1940),
    [anon_sym__Nonnull] = ACTIONS(1940),
    [anon_sym_mutable] = ACTIONS(1940),
    [anon_sym_constinit] = ACTIONS(1940),
    [anon_sym_consteval] = ACTIONS(1940),
    [anon_sym___shared__] = ACTIONS(1940),
    [anon_sym___local__] = ACTIONS(1940),
    [anon_sym___constant__] = ACTIONS(1940),
    [anon_sym___managed__] = ACTIONS(1940),
    [anon_sym___grid_constant__] = ACTIONS(1940),
    [anon_sym_alignas] = ACTIONS(1940),
    [anon_sym__Alignas] = ACTIONS(1940),
    [sym_primitive_type] = ACTIONS(1940),
    [anon_sym_enum] = ACTIONS(1940),
    [anon_sym_class] = ACTIONS(1940),
    [anon_sym_struct] = ACTIONS(1940),
    [anon_sym_union] = ACTIONS(1940),
    [anon_sym_if] = ACTIONS(1940),
    [anon_sym_else] = ACTIONS(1940),
    [anon_sym_switch] = ACTIONS(1940),
    [anon_sym_case] = ACTIONS(1940),
    [anon_sym_default] = ACTIONS(1940),
    [anon_sym_while] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_for] = ACTIONS(1940),
    [anon_sym_return] = ACTIONS(1940),
    [anon_sym_break] = ACTIONS(1940),
    [anon_sym_continue] = ACTIONS(1940),
    [anon_sym_goto] = ACTIONS(1940),
    [anon_sym___try] = ACTIONS(1940),
    [anon_sym___leave] = ACTIONS(1940),
    [anon_sym_not] = ACTIONS(1940),
    [anon_sym_compl] = ACTIONS(1940),
    [anon_sym_DASH_DASH] = ACTIONS(1942),
    [anon_sym_PLUS_PLUS] = ACTIONS(1942),
    [anon_sym_sizeof] = ACTIONS(1940),
    [anon_sym___alignof__] = ACTIONS(1940),
    [anon_sym___alignof] = ACTIONS(1940),
    [anon_sym__alignof] = ACTIONS(1940),
    [anon_sym_alignof] = ACTIONS(1940),
    [anon_sym__Alignof] = ACTIONS(1940),
    [anon_sym_offsetof] = ACTIONS(1940),
    [anon_sym__Generic] = ACTIONS(1940),
    [anon_sym_asm] = ACTIONS(1940),
    [anon_sym___asm__] = ACTIONS(1940),
    [anon_sym___asm] = ACTIONS(1940),
    [sym_number_literal] = ACTIONS(1942),
    [anon_sym_L_SQUOTE] = ACTIONS(1942),
    [anon_sym_u_SQUOTE] = ACTIONS(1942),
    [anon_sym_U_SQUOTE] = ACTIONS(1942),
    [anon_sym_u8_SQUOTE] = ACTIONS(1942),
    [anon_sym_SQUOTE] = ACTIONS(1942),
    [anon_sym_L_DQUOTE] = ACTIONS(1942),
    [anon_sym_u_DQUOTE] = ACTIONS(1942),
    [anon_sym_U_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8_DQUOTE] = ACTIONS(1942),
    [anon_sym_DQUOTE] = ACTIONS(1942),
    [sym_true] = ACTIONS(1940),
    [sym_false] = ACTIONS(1940),
    [anon_sym_NULL] = ACTIONS(1940),
    [anon_sym_nullptr] = ACTIONS(1940),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1940),
    [anon_sym_decltype] = ACTIONS(1940),
    [anon_sym_explicit] = ACTIONS(1940),
    [anon_sym_typename] = ACTIONS(1940),
    [anon_sym_template] = ACTIONS(1940),
    [anon_sym_operator] = ACTIONS(1940),
    [anon_sym_try] = ACTIONS(1940),
    [anon_sym_delete] = ACTIONS(1940),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_namespace] = ACTIONS(1940),
    [anon_sym_using] = ACTIONS(1940),
    [anon_sym_static_assert] = ACTIONS(1940),
    [anon_sym_concept] = ACTIONS(1940),
    [anon_sym_co_return] = ACTIONS(1940),
    [anon_sym_co_yield] = ACTIONS(1940),
    [anon_sym_catch] = ACTIONS(1944),
    [anon_sym_R_DQUOTE] = ACTIONS(1942),
    [anon_sym_LR_DQUOTE] = ACTIONS(1942),
    [anon_sym_uR_DQUOTE] = ACTIONS(1942),
    [anon_sym_UR_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1942),
    [anon_sym_co_await] = ACTIONS(1940),
    [anon_sym_new] = ACTIONS(1940),
    [anon_sym_requires] = ACTIONS(1940),
    [sym_this] = ACTIONS(1940),
    [anon_sym___launch_bounds__] = ACTIONS(1940),
  },
  [STATE(142)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1950),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(1953),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1956),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(1967),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1974),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(143)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1950),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(1953),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1956),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(1986),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1974),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(144)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1950),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(1953),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1956),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(1988),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1974),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(145)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1950),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(1953),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1956),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1974),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(146)] = {
    [sym_catch_clause] = STATE(141),
    [aux_sym_constructor_try_statement_repeat1] = STATE(141),
    [sym_identifier] = ACTIONS(1992),
    [aux_sym_preproc_include_token1] = ACTIONS(1992),
    [aux_sym_preproc_def_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token2] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1992),
    [aux_sym_preproc_else_token1] = ACTIONS(1992),
    [aux_sym_preproc_elif_token1] = ACTIONS(1992),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1992),
    [sym_preproc_directive] = ACTIONS(1992),
    [anon_sym_LPAREN2] = ACTIONS(1994),
    [anon_sym_BANG] = ACTIONS(1994),
    [anon_sym_TILDE] = ACTIONS(1994),
    [anon_sym_DASH] = ACTIONS(1992),
    [anon_sym_PLUS] = ACTIONS(1992),
    [anon_sym_STAR] = ACTIONS(1994),
    [anon_sym_AMP_AMP] = ACTIONS(1994),
    [anon_sym_AMP] = ACTIONS(1992),
    [anon_sym_SEMI] = ACTIONS(1994),
    [anon_sym___extension__] = ACTIONS(1992),
    [anon_sym_typedef] = ACTIONS(1992),
    [anon_sym___device__] = ACTIONS(1992),
    [anon_sym___host__] = ACTIONS(1992),
    [anon_sym___global__] = ACTIONS(1992),
    [anon_sym___forceinline__] = ACTIONS(1992),
    [anon_sym___noinline__] = ACTIONS(1992),
    [anon_sym_virtual] = ACTIONS(1992),
    [anon_sym_extern] = ACTIONS(1992),
    [anon_sym___attribute__] = ACTIONS(1992),
    [anon_sym___attribute] = ACTIONS(1992),
    [anon_sym_COLON_COLON] = ACTIONS(1994),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1994),
    [anon_sym___declspec] = ACTIONS(1992),
    [anon_sym___based] = ACTIONS(1992),
    [anon_sym___cdecl] = ACTIONS(1992),
    [anon_sym___clrcall] = ACTIONS(1992),
    [anon_sym___stdcall] = ACTIONS(1992),
    [anon_sym___fastcall] = ACTIONS(1992),
    [anon_sym___thiscall] = ACTIONS(1992),
    [anon_sym___vectorcall] = ACTIONS(1992),
    [anon_sym_LBRACE] = ACTIONS(1994),
    [anon_sym_signed] = ACTIONS(1992),
    [anon_sym_unsigned] = ACTIONS(1992),
    [anon_sym_long] = ACTIONS(1992),
    [anon_sym_short] = ACTIONS(1992),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_static] = ACTIONS(1992),
    [anon_sym_register] = ACTIONS(1992),
    [anon_sym_inline] = ACTIONS(1992),
    [anon_sym___inline] = ACTIONS(1992),
    [anon_sym___inline__] = ACTIONS(1992),
    [anon_sym___forceinline] = ACTIONS(1992),
    [anon_sym_thread_local] = ACTIONS(1992),
    [anon_sym___thread] = ACTIONS(1992),
    [anon_sym_const] = ACTIONS(1992),
    [anon_sym_constexpr] = ACTIONS(1992),
    [anon_sym_volatile] = ACTIONS(1992),
    [anon_sym_restrict] = ACTIONS(1992),
    [anon_sym___restrict__] = ACTIONS(1992),
    [anon_sym__Atomic] = ACTIONS(1992),
    [anon_sym__Noreturn] = ACTIONS(1992),
    [anon_sym_noreturn] = ACTIONS(1992),
    [anon_sym__Nonnull] = ACTIONS(1992),
    [anon_sym_mutable] = ACTIONS(1992),
    [anon_sym_constinit] = ACTIONS(1992),
    [anon_sym_consteval] = ACTIONS(1992),
    [anon_sym___shared__] = ACTIONS(1992),
    [anon_sym___local__] = ACTIONS(1992),
    [anon_sym___constant__] = ACTIONS(1992),
    [anon_sym___managed__] = ACTIONS(1992),
    [anon_sym___grid_constant__] = ACTIONS(1992),
    [anon_sym_alignas] = ACTIONS(1992),
    [anon_sym__Alignas] = ACTIONS(1992),
    [sym_primitive_type] = ACTIONS(1992),
    [anon_sym_enum] = ACTIONS(1992),
    [anon_sym_class] = ACTIONS(1992),
    [anon_sym_struct] = ACTIONS(1992),
    [anon_sym_union] = ACTIONS(1992),
    [anon_sym_if] = ACTIONS(1992),
    [anon_sym_switch] = ACTIONS(1992),
    [anon_sym_case] = ACTIONS(1992),
    [anon_sym_default] = ACTIONS(1992),
    [anon_sym_while] = ACTIONS(1992),
    [anon_sym_do] = ACTIONS(1992),
    [anon_sym_for] = ACTIONS(1992),
    [anon_sym_return] = ACTIONS(1992),
    [anon_sym_break] = ACTIONS(1992),
    [anon_sym_continue] = ACTIONS(1992),
    [anon_sym_goto] = ACTIONS(1992),
    [anon_sym___try] = ACTIONS(1992),
    [anon_sym___leave] = ACTIONS(1992),
    [anon_sym_not] = ACTIONS(1992),
    [anon_sym_compl] = ACTIONS(1992),
    [anon_sym_DASH_DASH] = ACTIONS(1994),
    [anon_sym_PLUS_PLUS] = ACTIONS(1994),
    [anon_sym_sizeof] = ACTIONS(1992),
    [anon_sym___alignof__] = ACTIONS(1992),
    [anon_sym___alignof] = ACTIONS(1992),
    [anon_sym__alignof] = ACTIONS(1992),
    [anon_sym_alignof] = ACTIONS(1992),
    [anon_sym__Alignof] = ACTIONS(1992),
    [anon_sym_offsetof] = ACTIONS(1992),
    [anon_sym__Generic] = ACTIONS(1992),
    [anon_sym_asm] = ACTIONS(1992),
    [anon_sym___asm__] = ACTIONS(1992),
    [anon_sym___asm] = ACTIONS(1992),
    [sym_number_literal] = ACTIONS(1994),
    [anon_sym_L_SQUOTE] = ACTIONS(1994),
    [anon_sym_u_SQUOTE] = ACTIONS(1994),
    [anon_sym_U_SQUOTE] = ACTIONS(1994),
    [anon_sym_u8_SQUOTE] = ACTIONS(1994),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [anon_sym_L_DQUOTE] = ACTIONS(1994),
    [anon_sym_u_DQUOTE] = ACTIONS(1994),
    [anon_sym_U_DQUOTE] = ACTIONS(1994),
    [anon_sym_u8_DQUOTE] = ACTIONS(1994),
    [anon_sym_DQUOTE] = ACTIONS(1994),
    [sym_true] = ACTIONS(1992),
    [sym_false] = ACTIONS(1992),
    [anon_sym_NULL] = ACTIONS(1992),
    [anon_sym_nullptr] = ACTIONS(1992),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1992),
    [anon_sym_decltype] = ACTIONS(1992),
    [anon_sym_explicit] = ACTIONS(1992),
    [anon_sym_typename] = ACTIONS(1992),
    [anon_sym_template] = ACTIONS(1992),
    [anon_sym_operator] = ACTIONS(1992),
    [anon_sym_try] = ACTIONS(1992),
    [anon_sym_delete] = ACTIONS(1992),
    [anon_sym_throw] = ACTIONS(1992),
    [anon_sym_namespace] = ACTIONS(1992),
    [anon_sym_using] = ACTIONS(1992),
    [anon_sym_static_assert] = ACTIONS(1992),
    [anon_sym_concept] = ACTIONS(1992),
    [anon_sym_co_return] = ACTIONS(1992),
    [anon_sym_co_yield] = ACTIONS(1992),
    [anon_sym_catch] = ACTIONS(1938),
    [anon_sym_R_DQUOTE] = ACTIONS(1994),
    [anon_sym_LR_DQUOTE] = ACTIONS(1994),
    [anon_sym_uR_DQUOTE] = ACTIONS(1994),
    [anon_sym_UR_DQUOTE] = ACTIONS(1994),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1994),
    [anon_sym_co_await] = ACTIONS(1992),
    [anon_sym_new] = ACTIONS(1992),
    [anon_sym_requires] = ACTIONS(1992),
    [sym_this] = ACTIONS(1992),
    [anon_sym___launch_bounds__] = ACTIONS(1992),
  },
  [STATE(147)] = {
    [sym_catch_clause] = STATE(141),
    [aux_sym_constructor_try_statement_repeat1] = STATE(141),
    [sym_identifier] = ACTIONS(1996),
    [aux_sym_preproc_include_token1] = ACTIONS(1996),
    [aux_sym_preproc_def_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token2] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1996),
    [aux_sym_preproc_else_token1] = ACTIONS(1996),
    [aux_sym_preproc_elif_token1] = ACTIONS(1996),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1996),
    [sym_preproc_directive] = ACTIONS(1996),
    [anon_sym_LPAREN2] = ACTIONS(1998),
    [anon_sym_BANG] = ACTIONS(1998),
    [anon_sym_TILDE] = ACTIONS(1998),
    [anon_sym_DASH] = ACTIONS(1996),
    [anon_sym_PLUS] = ACTIONS(1996),
    [anon_sym_STAR] = ACTIONS(1998),
    [anon_sym_AMP_AMP] = ACTIONS(1998),
    [anon_sym_AMP] = ACTIONS(1996),
    [anon_sym_SEMI] = ACTIONS(1998),
    [anon_sym___extension__] = ACTIONS(1996),
    [anon_sym_typedef] = ACTIONS(1996),
    [anon_sym___device__] = ACTIONS(1996),
    [anon_sym___host__] = ACTIONS(1996),
    [anon_sym___global__] = ACTIONS(1996),
    [anon_sym___forceinline__] = ACTIONS(1996),
    [anon_sym___noinline__] = ACTIONS(1996),
    [anon_sym_virtual] = ACTIONS(1996),
    [anon_sym_extern] = ACTIONS(1996),
    [anon_sym___attribute__] = ACTIONS(1996),
    [anon_sym___attribute] = ACTIONS(1996),
    [anon_sym_COLON_COLON] = ACTIONS(1998),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1998),
    [anon_sym___declspec] = ACTIONS(1996),
    [anon_sym___based] = ACTIONS(1996),
    [anon_sym___cdecl] = ACTIONS(1996),
    [anon_sym___clrcall] = ACTIONS(1996),
    [anon_sym___stdcall] = ACTIONS(1996),
    [anon_sym___fastcall] = ACTIONS(1996),
    [anon_sym___thiscall] = ACTIONS(1996),
    [anon_sym___vectorcall] = ACTIONS(1996),
    [anon_sym_LBRACE] = ACTIONS(1998),
    [anon_sym_signed] = ACTIONS(1996),
    [anon_sym_unsigned] = ACTIONS(1996),
    [anon_sym_long] = ACTIONS(1996),
    [anon_sym_short] = ACTIONS(1996),
    [anon_sym_LBRACK] = ACTIONS(1996),
    [anon_sym_static] = ACTIONS(1996),
    [anon_sym_register] = ACTIONS(1996),
    [anon_sym_inline] = ACTIONS(1996),
    [anon_sym___inline] = ACTIONS(1996),
    [anon_sym___inline__] = ACTIONS(1996),
    [anon_sym___forceinline] = ACTIONS(1996),
    [anon_sym_thread_local] = ACTIONS(1996),
    [anon_sym___thread] = ACTIONS(1996),
    [anon_sym_const] = ACTIONS(1996),
    [anon_sym_constexpr] = ACTIONS(1996),
    [anon_sym_volatile] = ACTIONS(1996),
    [anon_sym_restrict] = ACTIONS(1996),
    [anon_sym___restrict__] = ACTIONS(1996),
    [anon_sym__Atomic] = ACTIONS(1996),
    [anon_sym__Noreturn] = ACTIONS(1996),
    [anon_sym_noreturn] = ACTIONS(1996),
    [anon_sym__Nonnull] = ACTIONS(1996),
    [anon_sym_mutable] = ACTIONS(1996),
    [anon_sym_constinit] = ACTIONS(1996),
    [anon_sym_consteval] = ACTIONS(1996),
    [anon_sym___shared__] = ACTIONS(1996),
    [anon_sym___local__] = ACTIONS(1996),
    [anon_sym___constant__] = ACTIONS(1996),
    [anon_sym___managed__] = ACTIONS(1996),
    [anon_sym___grid_constant__] = ACTIONS(1996),
    [anon_sym_alignas] = ACTIONS(1996),
    [anon_sym__Alignas] = ACTIONS(1996),
    [sym_primitive_type] = ACTIONS(1996),
    [anon_sym_enum] = ACTIONS(1996),
    [anon_sym_class] = ACTIONS(1996),
    [anon_sym_struct] = ACTIONS(1996),
    [anon_sym_union] = ACTIONS(1996),
    [anon_sym_if] = ACTIONS(1996),
    [anon_sym_switch] = ACTIONS(1996),
    [anon_sym_case] = ACTIONS(1996),
    [anon_sym_default] = ACTIONS(1996),
    [anon_sym_while] = ACTIONS(1996),
    [anon_sym_do] = ACTIONS(1996),
    [anon_sym_for] = ACTIONS(1996),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_break] = ACTIONS(1996),
    [anon_sym_continue] = ACTIONS(1996),
    [anon_sym_goto] = ACTIONS(1996),
    [anon_sym___try] = ACTIONS(1996),
    [anon_sym___leave] = ACTIONS(1996),
    [anon_sym_not] = ACTIONS(1996),
    [anon_sym_compl] = ACTIONS(1996),
    [anon_sym_DASH_DASH] = ACTIONS(1998),
    [anon_sym_PLUS_PLUS] = ACTIONS(1998),
    [anon_sym_sizeof] = ACTIONS(1996),
    [anon_sym___alignof__] = ACTIONS(1996),
    [anon_sym___alignof] = ACTIONS(1996),
    [anon_sym__alignof] = ACTIONS(1996),
    [anon_sym_alignof] = ACTIONS(1996),
    [anon_sym__Alignof] = ACTIONS(1996),
    [anon_sym_offsetof] = ACTIONS(1996),
    [anon_sym__Generic] = ACTIONS(1996),
    [anon_sym_asm] = ACTIONS(1996),
    [anon_sym___asm__] = ACTIONS(1996),
    [anon_sym___asm] = ACTIONS(1996),
    [sym_number_literal] = ACTIONS(1998),
    [anon_sym_L_SQUOTE] = ACTIONS(1998),
    [anon_sym_u_SQUOTE] = ACTIONS(1998),
    [anon_sym_U_SQUOTE] = ACTIONS(1998),
    [anon_sym_u8_SQUOTE] = ACTIONS(1998),
    [anon_sym_SQUOTE] = ACTIONS(1998),
    [anon_sym_L_DQUOTE] = ACTIONS(1998),
    [anon_sym_u_DQUOTE] = ACTIONS(1998),
    [anon_sym_U_DQUOTE] = ACTIONS(1998),
    [anon_sym_u8_DQUOTE] = ACTIONS(1998),
    [anon_sym_DQUOTE] = ACTIONS(1998),
    [sym_true] = ACTIONS(1996),
    [sym_false] = ACTIONS(1996),
    [anon_sym_NULL] = ACTIONS(1996),
    [anon_sym_nullptr] = ACTIONS(1996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1996),
    [anon_sym_decltype] = ACTIONS(1996),
    [anon_sym_explicit] = ACTIONS(1996),
    [anon_sym_typename] = ACTIONS(1996),
    [anon_sym_template] = ACTIONS(1996),
    [anon_sym_operator] = ACTIONS(1996),
    [anon_sym_try] = ACTIONS(1996),
    [anon_sym_delete] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1996),
    [anon_sym_namespace] = ACTIONS(1996),
    [anon_sym_using] = ACTIONS(1996),
    [anon_sym_static_assert] = ACTIONS(1996),
    [anon_sym_concept] = ACTIONS(1996),
    [anon_sym_co_return] = ACTIONS(1996),
    [anon_sym_co_yield] = ACTIONS(1996),
    [anon_sym_catch] = ACTIONS(1938),
    [anon_sym_R_DQUOTE] = ACTIONS(1998),
    [anon_sym_LR_DQUOTE] = ACTIONS(1998),
    [anon_sym_uR_DQUOTE] = ACTIONS(1998),
    [anon_sym_UR_DQUOTE] = ACTIONS(1998),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1998),
    [anon_sym_co_await] = ACTIONS(1996),
    [anon_sym_new] = ACTIONS(1996),
    [anon_sym_requires] = ACTIONS(1996),
    [sym_this] = ACTIONS(1996),
    [anon_sym___launch_bounds__] = ACTIONS(1996),
  },
  [STATE(148)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9063),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(149)] = {
    [sym_identifier] = ACTIONS(2006),
    [aux_sym_preproc_include_token1] = ACTIONS(2006),
    [aux_sym_preproc_def_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token2] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2006),
    [aux_sym_preproc_else_token1] = ACTIONS(2006),
    [aux_sym_preproc_elif_token1] = ACTIONS(2006),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2006),
    [sym_preproc_directive] = ACTIONS(2006),
    [anon_sym_LPAREN2] = ACTIONS(2008),
    [anon_sym_BANG] = ACTIONS(2008),
    [anon_sym_TILDE] = ACTIONS(2008),
    [anon_sym_DASH] = ACTIONS(2006),
    [anon_sym_PLUS] = ACTIONS(2006),
    [anon_sym_STAR] = ACTIONS(2008),
    [anon_sym_AMP_AMP] = ACTIONS(2008),
    [anon_sym_AMP] = ACTIONS(2006),
    [anon_sym_SEMI] = ACTIONS(2008),
    [anon_sym___extension__] = ACTIONS(2006),
    [anon_sym_typedef] = ACTIONS(2006),
    [anon_sym___device__] = ACTIONS(2006),
    [anon_sym___host__] = ACTIONS(2006),
    [anon_sym___global__] = ACTIONS(2006),
    [anon_sym___forceinline__] = ACTIONS(2006),
    [anon_sym___noinline__] = ACTIONS(2006),
    [anon_sym_virtual] = ACTIONS(2006),
    [anon_sym_extern] = ACTIONS(2006),
    [anon_sym___attribute__] = ACTIONS(2006),
    [anon_sym___attribute] = ACTIONS(2006),
    [anon_sym_COLON_COLON] = ACTIONS(2008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2008),
    [anon_sym___declspec] = ACTIONS(2006),
    [anon_sym___based] = ACTIONS(2006),
    [anon_sym___cdecl] = ACTIONS(2006),
    [anon_sym___clrcall] = ACTIONS(2006),
    [anon_sym___stdcall] = ACTIONS(2006),
    [anon_sym___fastcall] = ACTIONS(2006),
    [anon_sym___thiscall] = ACTIONS(2006),
    [anon_sym___vectorcall] = ACTIONS(2006),
    [anon_sym_LBRACE] = ACTIONS(2008),
    [anon_sym_signed] = ACTIONS(2006),
    [anon_sym_unsigned] = ACTIONS(2006),
    [anon_sym_long] = ACTIONS(2006),
    [anon_sym_short] = ACTIONS(2006),
    [anon_sym_LBRACK] = ACTIONS(2006),
    [anon_sym_static] = ACTIONS(2006),
    [anon_sym_register] = ACTIONS(2006),
    [anon_sym_inline] = ACTIONS(2006),
    [anon_sym___inline] = ACTIONS(2006),
    [anon_sym___inline__] = ACTIONS(2006),
    [anon_sym___forceinline] = ACTIONS(2006),
    [anon_sym_thread_local] = ACTIONS(2006),
    [anon_sym___thread] = ACTIONS(2006),
    [anon_sym_const] = ACTIONS(2006),
    [anon_sym_constexpr] = ACTIONS(2006),
    [anon_sym_volatile] = ACTIONS(2006),
    [anon_sym_restrict] = ACTIONS(2006),
    [anon_sym___restrict__] = ACTIONS(2006),
    [anon_sym__Atomic] = ACTIONS(2006),
    [anon_sym__Noreturn] = ACTIONS(2006),
    [anon_sym_noreturn] = ACTIONS(2006),
    [anon_sym__Nonnull] = ACTIONS(2006),
    [anon_sym_mutable] = ACTIONS(2006),
    [anon_sym_constinit] = ACTIONS(2006),
    [anon_sym_consteval] = ACTIONS(2006),
    [anon_sym___shared__] = ACTIONS(2006),
    [anon_sym___local__] = ACTIONS(2006),
    [anon_sym___constant__] = ACTIONS(2006),
    [anon_sym___managed__] = ACTIONS(2006),
    [anon_sym___grid_constant__] = ACTIONS(2006),
    [anon_sym_alignas] = ACTIONS(2006),
    [anon_sym__Alignas] = ACTIONS(2006),
    [sym_primitive_type] = ACTIONS(2006),
    [anon_sym_enum] = ACTIONS(2006),
    [anon_sym_class] = ACTIONS(2006),
    [anon_sym_struct] = ACTIONS(2006),
    [anon_sym_union] = ACTIONS(2006),
    [anon_sym_if] = ACTIONS(2006),
    [anon_sym_else] = ACTIONS(2006),
    [anon_sym_switch] = ACTIONS(2006),
    [anon_sym_case] = ACTIONS(2006),
    [anon_sym_default] = ACTIONS(2006),
    [anon_sym_while] = ACTIONS(2006),
    [anon_sym_do] = ACTIONS(2006),
    [anon_sym_for] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2006),
    [anon_sym_break] = ACTIONS(2006),
    [anon_sym_continue] = ACTIONS(2006),
    [anon_sym_goto] = ACTIONS(2006),
    [anon_sym___try] = ACTIONS(2006),
    [anon_sym___leave] = ACTIONS(2006),
    [anon_sym_not] = ACTIONS(2006),
    [anon_sym_compl] = ACTIONS(2006),
    [anon_sym_DASH_DASH] = ACTIONS(2008),
    [anon_sym_PLUS_PLUS] = ACTIONS(2008),
    [anon_sym_sizeof] = ACTIONS(2006),
    [anon_sym___alignof__] = ACTIONS(2006),
    [anon_sym___alignof] = ACTIONS(2006),
    [anon_sym__alignof] = ACTIONS(2006),
    [anon_sym_alignof] = ACTIONS(2006),
    [anon_sym__Alignof] = ACTIONS(2006),
    [anon_sym_offsetof] = ACTIONS(2006),
    [anon_sym__Generic] = ACTIONS(2006),
    [anon_sym_asm] = ACTIONS(2006),
    [anon_sym___asm__] = ACTIONS(2006),
    [anon_sym___asm] = ACTIONS(2006),
    [sym_number_literal] = ACTIONS(2008),
    [anon_sym_L_SQUOTE] = ACTIONS(2008),
    [anon_sym_u_SQUOTE] = ACTIONS(2008),
    [anon_sym_U_SQUOTE] = ACTIONS(2008),
    [anon_sym_u8_SQUOTE] = ACTIONS(2008),
    [anon_sym_SQUOTE] = ACTIONS(2008),
    [anon_sym_L_DQUOTE] = ACTIONS(2008),
    [anon_sym_u_DQUOTE] = ACTIONS(2008),
    [anon_sym_U_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8_DQUOTE] = ACTIONS(2008),
    [anon_sym_DQUOTE] = ACTIONS(2008),
    [sym_true] = ACTIONS(2006),
    [sym_false] = ACTIONS(2006),
    [anon_sym_NULL] = ACTIONS(2006),
    [anon_sym_nullptr] = ACTIONS(2006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2006),
    [anon_sym_decltype] = ACTIONS(2006),
    [anon_sym_explicit] = ACTIONS(2006),
    [anon_sym_typename] = ACTIONS(2006),
    [anon_sym_template] = ACTIONS(2006),
    [anon_sym_operator] = ACTIONS(2006),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_delete] = ACTIONS(2006),
    [anon_sym_throw] = ACTIONS(2006),
    [anon_sym_namespace] = ACTIONS(2006),
    [anon_sym_using] = ACTIONS(2006),
    [anon_sym_static_assert] = ACTIONS(2006),
    [anon_sym_concept] = ACTIONS(2006),
    [anon_sym_co_return] = ACTIONS(2006),
    [anon_sym_co_yield] = ACTIONS(2006),
    [anon_sym_catch] = ACTIONS(2006),
    [anon_sym_R_DQUOTE] = ACTIONS(2008),
    [anon_sym_LR_DQUOTE] = ACTIONS(2008),
    [anon_sym_uR_DQUOTE] = ACTIONS(2008),
    [anon_sym_UR_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2008),
    [anon_sym_co_await] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(2006),
    [anon_sym_requires] = ACTIONS(2006),
    [sym_this] = ACTIONS(2006),
    [anon_sym___launch_bounds__] = ACTIONS(2006),
  },
  [STATE(150)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [aux_sym_preproc_else_token1] = ACTIONS(1932),
    [aux_sym_preproc_elif_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_else] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_catch] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(151)] = {
    [sym_identifier] = ACTIONS(1928),
    [aux_sym_preproc_include_token1] = ACTIONS(1928),
    [aux_sym_preproc_def_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token2] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1928),
    [aux_sym_preproc_else_token1] = ACTIONS(1928),
    [aux_sym_preproc_elif_token1] = ACTIONS(1928),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1928),
    [sym_preproc_directive] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_BANG] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_DASH] = ACTIONS(1928),
    [anon_sym_PLUS] = ACTIONS(1928),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_AMP_AMP] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1928),
    [anon_sym_SEMI] = ACTIONS(1926),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym_typedef] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym___based] = ACTIONS(1928),
    [anon_sym___cdecl] = ACTIONS(1928),
    [anon_sym___clrcall] = ACTIONS(1928),
    [anon_sym___stdcall] = ACTIONS(1928),
    [anon_sym___fastcall] = ACTIONS(1928),
    [anon_sym___thiscall] = ACTIONS(1928),
    [anon_sym___vectorcall] = ACTIONS(1928),
    [anon_sym_LBRACE] = ACTIONS(1926),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [anon_sym_if] = ACTIONS(1928),
    [anon_sym_else] = ACTIONS(1928),
    [anon_sym_switch] = ACTIONS(1928),
    [anon_sym_case] = ACTIONS(1928),
    [anon_sym_default] = ACTIONS(1928),
    [anon_sym_while] = ACTIONS(1928),
    [anon_sym_do] = ACTIONS(1928),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_return] = ACTIONS(1928),
    [anon_sym_break] = ACTIONS(1928),
    [anon_sym_continue] = ACTIONS(1928),
    [anon_sym_goto] = ACTIONS(1928),
    [anon_sym___try] = ACTIONS(1928),
    [anon_sym___leave] = ACTIONS(1928),
    [anon_sym_not] = ACTIONS(1928),
    [anon_sym_compl] = ACTIONS(1928),
    [anon_sym_DASH_DASH] = ACTIONS(1926),
    [anon_sym_PLUS_PLUS] = ACTIONS(1926),
    [anon_sym_sizeof] = ACTIONS(1928),
    [anon_sym___alignof__] = ACTIONS(1928),
    [anon_sym___alignof] = ACTIONS(1928),
    [anon_sym__alignof] = ACTIONS(1928),
    [anon_sym_alignof] = ACTIONS(1928),
    [anon_sym__Alignof] = ACTIONS(1928),
    [anon_sym_offsetof] = ACTIONS(1928),
    [anon_sym__Generic] = ACTIONS(1928),
    [anon_sym_asm] = ACTIONS(1928),
    [anon_sym___asm__] = ACTIONS(1928),
    [anon_sym___asm] = ACTIONS(1928),
    [sym_number_literal] = ACTIONS(1926),
    [anon_sym_L_SQUOTE] = ACTIONS(1926),
    [anon_sym_u_SQUOTE] = ACTIONS(1926),
    [anon_sym_U_SQUOTE] = ACTIONS(1926),
    [anon_sym_u8_SQUOTE] = ACTIONS(1926),
    [anon_sym_SQUOTE] = ACTIONS(1926),
    [anon_sym_L_DQUOTE] = ACTIONS(1926),
    [anon_sym_u_DQUOTE] = ACTIONS(1926),
    [anon_sym_U_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8_DQUOTE] = ACTIONS(1926),
    [anon_sym_DQUOTE] = ACTIONS(1926),
    [sym_true] = ACTIONS(1928),
    [sym_false] = ACTIONS(1928),
    [anon_sym_NULL] = ACTIONS(1928),
    [anon_sym_nullptr] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_explicit] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_operator] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_delete] = ACTIONS(1928),
    [anon_sym_throw] = ACTIONS(1928),
    [anon_sym_namespace] = ACTIONS(1928),
    [anon_sym_using] = ACTIONS(1928),
    [anon_sym_static_assert] = ACTIONS(1928),
    [anon_sym_concept] = ACTIONS(1928),
    [anon_sym_co_return] = ACTIONS(1928),
    [anon_sym_co_yield] = ACTIONS(1928),
    [anon_sym_catch] = ACTIONS(1928),
    [anon_sym_R_DQUOTE] = ACTIONS(1926),
    [anon_sym_LR_DQUOTE] = ACTIONS(1926),
    [anon_sym_uR_DQUOTE] = ACTIONS(1926),
    [anon_sym_UR_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1926),
    [anon_sym_co_await] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1928),
    [anon_sym_requires] = ACTIONS(1928),
    [sym_this] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(152)] = {
    [sym_compound_statement] = STATE(9333),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3185),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9333),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9391),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9403),
    [sym__unary_right_fold] = STATE(9405),
    [sym__binary_fold] = STATE(9406),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9415),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(153)] = {
    [sym_compound_statement] = STATE(9333),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3185),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9333),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9060),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9403),
    [sym__unary_right_fold] = STATE(9405),
    [sym__binary_fold] = STATE(9406),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9415),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(154)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9114),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(155)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9443),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(156)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9015),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(157)] = {
    [sym_compound_statement] = STATE(9438),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3145),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9438),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(8841),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(8842),
    [sym__unary_right_fold] = STATE(8886),
    [sym__binary_fold] = STATE(8891),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9454),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(158)] = {
    [sym_compound_statement] = STATE(9438),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3145),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9438),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9417),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(8842),
    [sym__unary_right_fold] = STATE(8886),
    [sym__binary_fold] = STATE(8891),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9454),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(159)] = {
    [sym_compound_statement] = STATE(9333),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3185),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9333),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9188),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9222),
    [sym__unary_right_fold] = STATE(9260),
    [sym__binary_fold] = STATE(9292),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9415),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(160)] = {
    [sym_compound_statement] = STATE(9333),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3185),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9333),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9169),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9222),
    [sym__unary_right_fold] = STATE(9260),
    [sym__binary_fold] = STATE(9292),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9415),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(161)] = {
    [sym_compound_statement] = STATE(8697),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3148),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(8697),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9031),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9035),
    [sym__unary_right_fold] = STATE(9043),
    [sym__binary_fold] = STATE(9045),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9047),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(162)] = {
    [sym_compound_statement] = STATE(8697),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3148),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(8697),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9173),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9035),
    [sym__unary_right_fold] = STATE(9043),
    [sym__binary_fold] = STATE(9045),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9047),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(163)] = {
    [sym_compound_statement] = STATE(9438),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3145),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9438),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(8708),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(8711),
    [sym__unary_right_fold] = STATE(8719),
    [sym__binary_fold] = STATE(8774),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9454),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(164)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9051),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(165)] = {
    [sym_else_clause] = STATE(208),
    [sym_identifier] = ACTIONS(2010),
    [aux_sym_preproc_include_token1] = ACTIONS(2010),
    [aux_sym_preproc_def_token1] = ACTIONS(2010),
    [aux_sym_preproc_if_token1] = ACTIONS(2010),
    [aux_sym_preproc_if_token2] = ACTIONS(2010),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2010),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2010),
    [aux_sym_preproc_else_token1] = ACTIONS(2010),
    [aux_sym_preproc_elif_token1] = ACTIONS(2010),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2010),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2010),
    [sym_preproc_directive] = ACTIONS(2010),
    [anon_sym_LPAREN2] = ACTIONS(2012),
    [anon_sym_BANG] = ACTIONS(2012),
    [anon_sym_TILDE] = ACTIONS(2012),
    [anon_sym_DASH] = ACTIONS(2010),
    [anon_sym_PLUS] = ACTIONS(2010),
    [anon_sym_STAR] = ACTIONS(2012),
    [anon_sym_AMP_AMP] = ACTIONS(2012),
    [anon_sym_AMP] = ACTIONS(2010),
    [anon_sym_SEMI] = ACTIONS(2012),
    [anon_sym___extension__] = ACTIONS(2010),
    [anon_sym_typedef] = ACTIONS(2010),
    [anon_sym___device__] = ACTIONS(2010),
    [anon_sym___host__] = ACTIONS(2010),
    [anon_sym___global__] = ACTIONS(2010),
    [anon_sym___forceinline__] = ACTIONS(2010),
    [anon_sym___noinline__] = ACTIONS(2010),
    [anon_sym_virtual] = ACTIONS(2010),
    [anon_sym_extern] = ACTIONS(2010),
    [anon_sym___attribute__] = ACTIONS(2010),
    [anon_sym___attribute] = ACTIONS(2010),
    [anon_sym_COLON_COLON] = ACTIONS(2012),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2012),
    [anon_sym___declspec] = ACTIONS(2010),
    [anon_sym___based] = ACTIONS(2010),
    [anon_sym___cdecl] = ACTIONS(2010),
    [anon_sym___clrcall] = ACTIONS(2010),
    [anon_sym___stdcall] = ACTIONS(2010),
    [anon_sym___fastcall] = ACTIONS(2010),
    [anon_sym___thiscall] = ACTIONS(2010),
    [anon_sym___vectorcall] = ACTIONS(2010),
    [anon_sym_LBRACE] = ACTIONS(2012),
    [anon_sym_signed] = ACTIONS(2010),
    [anon_sym_unsigned] = ACTIONS(2010),
    [anon_sym_long] = ACTIONS(2010),
    [anon_sym_short] = ACTIONS(2010),
    [anon_sym_LBRACK] = ACTIONS(2010),
    [anon_sym_static] = ACTIONS(2010),
    [anon_sym_register] = ACTIONS(2010),
    [anon_sym_inline] = ACTIONS(2010),
    [anon_sym___inline] = ACTIONS(2010),
    [anon_sym___inline__] = ACTIONS(2010),
    [anon_sym___forceinline] = ACTIONS(2010),
    [anon_sym_thread_local] = ACTIONS(2010),
    [anon_sym___thread] = ACTIONS(2010),
    [anon_sym_const] = ACTIONS(2010),
    [anon_sym_constexpr] = ACTIONS(2010),
    [anon_sym_volatile] = ACTIONS(2010),
    [anon_sym_restrict] = ACTIONS(2010),
    [anon_sym___restrict__] = ACTIONS(2010),
    [anon_sym__Atomic] = ACTIONS(2010),
    [anon_sym__Noreturn] = ACTIONS(2010),
    [anon_sym_noreturn] = ACTIONS(2010),
    [anon_sym__Nonnull] = ACTIONS(2010),
    [anon_sym_mutable] = ACTIONS(2010),
    [anon_sym_constinit] = ACTIONS(2010),
    [anon_sym_consteval] = ACTIONS(2010),
    [anon_sym___shared__] = ACTIONS(2010),
    [anon_sym___local__] = ACTIONS(2010),
    [anon_sym___constant__] = ACTIONS(2010),
    [anon_sym___managed__] = ACTIONS(2010),
    [anon_sym___grid_constant__] = ACTIONS(2010),
    [anon_sym_alignas] = ACTIONS(2010),
    [anon_sym__Alignas] = ACTIONS(2010),
    [sym_primitive_type] = ACTIONS(2010),
    [anon_sym_enum] = ACTIONS(2010),
    [anon_sym_class] = ACTIONS(2010),
    [anon_sym_struct] = ACTIONS(2010),
    [anon_sym_union] = ACTIONS(2010),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_else] = ACTIONS(2014),
    [anon_sym_switch] = ACTIONS(2010),
    [anon_sym_case] = ACTIONS(2010),
    [anon_sym_default] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2010),
    [anon_sym_do] = ACTIONS(2010),
    [anon_sym_for] = ACTIONS(2010),
    [anon_sym_return] = ACTIONS(2010),
    [anon_sym_break] = ACTIONS(2010),
    [anon_sym_continue] = ACTIONS(2010),
    [anon_sym_goto] = ACTIONS(2010),
    [anon_sym___try] = ACTIONS(2010),
    [anon_sym___leave] = ACTIONS(2010),
    [anon_sym_not] = ACTIONS(2010),
    [anon_sym_compl] = ACTIONS(2010),
    [anon_sym_DASH_DASH] = ACTIONS(2012),
    [anon_sym_PLUS_PLUS] = ACTIONS(2012),
    [anon_sym_sizeof] = ACTIONS(2010),
    [anon_sym___alignof__] = ACTIONS(2010),
    [anon_sym___alignof] = ACTIONS(2010),
    [anon_sym__alignof] = ACTIONS(2010),
    [anon_sym_alignof] = ACTIONS(2010),
    [anon_sym__Alignof] = ACTIONS(2010),
    [anon_sym_offsetof] = ACTIONS(2010),
    [anon_sym__Generic] = ACTIONS(2010),
    [anon_sym_asm] = ACTIONS(2010),
    [anon_sym___asm__] = ACTIONS(2010),
    [anon_sym___asm] = ACTIONS(2010),
    [sym_number_literal] = ACTIONS(2012),
    [anon_sym_L_SQUOTE] = ACTIONS(2012),
    [anon_sym_u_SQUOTE] = ACTIONS(2012),
    [anon_sym_U_SQUOTE] = ACTIONS(2012),
    [anon_sym_u8_SQUOTE] = ACTIONS(2012),
    [anon_sym_SQUOTE] = ACTIONS(2012),
    [anon_sym_L_DQUOTE] = ACTIONS(2012),
    [anon_sym_u_DQUOTE] = ACTIONS(2012),
    [anon_sym_U_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8_DQUOTE] = ACTIONS(2012),
    [anon_sym_DQUOTE] = ACTIONS(2012),
    [sym_true] = ACTIONS(2010),
    [sym_false] = ACTIONS(2010),
    [anon_sym_NULL] = ACTIONS(2010),
    [anon_sym_nullptr] = ACTIONS(2010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2010),
    [anon_sym_decltype] = ACTIONS(2010),
    [anon_sym_explicit] = ACTIONS(2010),
    [anon_sym_typename] = ACTIONS(2010),
    [anon_sym_template] = ACTIONS(2010),
    [anon_sym_operator] = ACTIONS(2010),
    [anon_sym_try] = ACTIONS(2010),
    [anon_sym_delete] = ACTIONS(2010),
    [anon_sym_throw] = ACTIONS(2010),
    [anon_sym_namespace] = ACTIONS(2010),
    [anon_sym_using] = ACTIONS(2010),
    [anon_sym_static_assert] = ACTIONS(2010),
    [anon_sym_concept] = ACTIONS(2010),
    [anon_sym_co_return] = ACTIONS(2010),
    [anon_sym_co_yield] = ACTIONS(2010),
    [anon_sym_R_DQUOTE] = ACTIONS(2012),
    [anon_sym_LR_DQUOTE] = ACTIONS(2012),
    [anon_sym_uR_DQUOTE] = ACTIONS(2012),
    [anon_sym_UR_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2012),
    [anon_sym_co_await] = ACTIONS(2010),
    [anon_sym_new] = ACTIONS(2010),
    [anon_sym_requires] = ACTIONS(2010),
    [sym_this] = ACTIONS(2010),
    [anon_sym___launch_bounds__] = ACTIONS(2010),
  },
  [STATE(166)] = {
    [sym_compound_statement] = STATE(8697),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3148),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(8697),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9400),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(8735),
    [sym__unary_right_fold] = STATE(8747),
    [sym__binary_fold] = STATE(8755),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9047),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(167)] = {
    [sym_compound_statement] = STATE(8697),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3148),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(8697),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(8602),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(8735),
    [sym__unary_right_fold] = STATE(8747),
    [sym__binary_fold] = STATE(8755),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9047),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(168)] = {
    [sym_else_clause] = STATE(194),
    [sym_identifier] = ACTIONS(2016),
    [aux_sym_preproc_include_token1] = ACTIONS(2016),
    [aux_sym_preproc_def_token1] = ACTIONS(2016),
    [aux_sym_preproc_if_token1] = ACTIONS(2016),
    [aux_sym_preproc_if_token2] = ACTIONS(2016),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2016),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2016),
    [aux_sym_preproc_else_token1] = ACTIONS(2016),
    [aux_sym_preproc_elif_token1] = ACTIONS(2016),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2016),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2016),
    [sym_preproc_directive] = ACTIONS(2016),
    [anon_sym_LPAREN2] = ACTIONS(2018),
    [anon_sym_BANG] = ACTIONS(2018),
    [anon_sym_TILDE] = ACTIONS(2018),
    [anon_sym_DASH] = ACTIONS(2016),
    [anon_sym_PLUS] = ACTIONS(2016),
    [anon_sym_STAR] = ACTIONS(2018),
    [anon_sym_AMP_AMP] = ACTIONS(2018),
    [anon_sym_AMP] = ACTIONS(2016),
    [anon_sym_SEMI] = ACTIONS(2018),
    [anon_sym___extension__] = ACTIONS(2016),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym___device__] = ACTIONS(2016),
    [anon_sym___host__] = ACTIONS(2016),
    [anon_sym___global__] = ACTIONS(2016),
    [anon_sym___forceinline__] = ACTIONS(2016),
    [anon_sym___noinline__] = ACTIONS(2016),
    [anon_sym_virtual] = ACTIONS(2016),
    [anon_sym_extern] = ACTIONS(2016),
    [anon_sym___attribute__] = ACTIONS(2016),
    [anon_sym___attribute] = ACTIONS(2016),
    [anon_sym_COLON_COLON] = ACTIONS(2018),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2018),
    [anon_sym___declspec] = ACTIONS(2016),
    [anon_sym___based] = ACTIONS(2016),
    [anon_sym___cdecl] = ACTIONS(2016),
    [anon_sym___clrcall] = ACTIONS(2016),
    [anon_sym___stdcall] = ACTIONS(2016),
    [anon_sym___fastcall] = ACTIONS(2016),
    [anon_sym___thiscall] = ACTIONS(2016),
    [anon_sym___vectorcall] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2018),
    [anon_sym_signed] = ACTIONS(2016),
    [anon_sym_unsigned] = ACTIONS(2016),
    [anon_sym_long] = ACTIONS(2016),
    [anon_sym_short] = ACTIONS(2016),
    [anon_sym_LBRACK] = ACTIONS(2016),
    [anon_sym_static] = ACTIONS(2016),
    [anon_sym_register] = ACTIONS(2016),
    [anon_sym_inline] = ACTIONS(2016),
    [anon_sym___inline] = ACTIONS(2016),
    [anon_sym___inline__] = ACTIONS(2016),
    [anon_sym___forceinline] = ACTIONS(2016),
    [anon_sym_thread_local] = ACTIONS(2016),
    [anon_sym___thread] = ACTIONS(2016),
    [anon_sym_const] = ACTIONS(2016),
    [anon_sym_constexpr] = ACTIONS(2016),
    [anon_sym_volatile] = ACTIONS(2016),
    [anon_sym_restrict] = ACTIONS(2016),
    [anon_sym___restrict__] = ACTIONS(2016),
    [anon_sym__Atomic] = ACTIONS(2016),
    [anon_sym__Noreturn] = ACTIONS(2016),
    [anon_sym_noreturn] = ACTIONS(2016),
    [anon_sym__Nonnull] = ACTIONS(2016),
    [anon_sym_mutable] = ACTIONS(2016),
    [anon_sym_constinit] = ACTIONS(2016),
    [anon_sym_consteval] = ACTIONS(2016),
    [anon_sym___shared__] = ACTIONS(2016),
    [anon_sym___local__] = ACTIONS(2016),
    [anon_sym___constant__] = ACTIONS(2016),
    [anon_sym___managed__] = ACTIONS(2016),
    [anon_sym___grid_constant__] = ACTIONS(2016),
    [anon_sym_alignas] = ACTIONS(2016),
    [anon_sym__Alignas] = ACTIONS(2016),
    [sym_primitive_type] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2016),
    [anon_sym_class] = ACTIONS(2016),
    [anon_sym_struct] = ACTIONS(2016),
    [anon_sym_union] = ACTIONS(2016),
    [anon_sym_if] = ACTIONS(2016),
    [anon_sym_else] = ACTIONS(2014),
    [anon_sym_switch] = ACTIONS(2016),
    [anon_sym_case] = ACTIONS(2016),
    [anon_sym_default] = ACTIONS(2016),
    [anon_sym_while] = ACTIONS(2016),
    [anon_sym_do] = ACTIONS(2016),
    [anon_sym_for] = ACTIONS(2016),
    [anon_sym_return] = ACTIONS(2016),
    [anon_sym_break] = ACTIONS(2016),
    [anon_sym_continue] = ACTIONS(2016),
    [anon_sym_goto] = ACTIONS(2016),
    [anon_sym___try] = ACTIONS(2016),
    [anon_sym___leave] = ACTIONS(2016),
    [anon_sym_not] = ACTIONS(2016),
    [anon_sym_compl] = ACTIONS(2016),
    [anon_sym_DASH_DASH] = ACTIONS(2018),
    [anon_sym_PLUS_PLUS] = ACTIONS(2018),
    [anon_sym_sizeof] = ACTIONS(2016),
    [anon_sym___alignof__] = ACTIONS(2016),
    [anon_sym___alignof] = ACTIONS(2016),
    [anon_sym__alignof] = ACTIONS(2016),
    [anon_sym_alignof] = ACTIONS(2016),
    [anon_sym__Alignof] = ACTIONS(2016),
    [anon_sym_offsetof] = ACTIONS(2016),
    [anon_sym__Generic] = ACTIONS(2016),
    [anon_sym_asm] = ACTIONS(2016),
    [anon_sym___asm__] = ACTIONS(2016),
    [anon_sym___asm] = ACTIONS(2016),
    [sym_number_literal] = ACTIONS(2018),
    [anon_sym_L_SQUOTE] = ACTIONS(2018),
    [anon_sym_u_SQUOTE] = ACTIONS(2018),
    [anon_sym_U_SQUOTE] = ACTIONS(2018),
    [anon_sym_u8_SQUOTE] = ACTIONS(2018),
    [anon_sym_SQUOTE] = ACTIONS(2018),
    [anon_sym_L_DQUOTE] = ACTIONS(2018),
    [anon_sym_u_DQUOTE] = ACTIONS(2018),
    [anon_sym_U_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8_DQUOTE] = ACTIONS(2018),
    [anon_sym_DQUOTE] = ACTIONS(2018),
    [sym_true] = ACTIONS(2016),
    [sym_false] = ACTIONS(2016),
    [anon_sym_NULL] = ACTIONS(2016),
    [anon_sym_nullptr] = ACTIONS(2016),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2016),
    [anon_sym_decltype] = ACTIONS(2016),
    [anon_sym_explicit] = ACTIONS(2016),
    [anon_sym_typename] = ACTIONS(2016),
    [anon_sym_template] = ACTIONS(2016),
    [anon_sym_operator] = ACTIONS(2016),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_delete] = ACTIONS(2016),
    [anon_sym_throw] = ACTIONS(2016),
    [anon_sym_namespace] = ACTIONS(2016),
    [anon_sym_using] = ACTIONS(2016),
    [anon_sym_static_assert] = ACTIONS(2016),
    [anon_sym_concept] = ACTIONS(2016),
    [anon_sym_co_return] = ACTIONS(2016),
    [anon_sym_co_yield] = ACTIONS(2016),
    [anon_sym_R_DQUOTE] = ACTIONS(2018),
    [anon_sym_LR_DQUOTE] = ACTIONS(2018),
    [anon_sym_uR_DQUOTE] = ACTIONS(2018),
    [anon_sym_UR_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2018),
    [anon_sym_co_await] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(2016),
    [anon_sym_requires] = ACTIONS(2016),
    [sym_this] = ACTIONS(2016),
    [anon_sym___launch_bounds__] = ACTIONS(2016),
  },
  [STATE(169)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9009),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(170)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(8730),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(171)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9297),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(172)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9182),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(173)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(8696),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(174)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9287),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(175)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9419),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(176)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(8995),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(177)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9215),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(178)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9194),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(179)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9490),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(180)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9422),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(181)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3183),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9171),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(182)] = {
    [sym_compound_statement] = STATE(9438),
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(3145),
    [sym__string] = STATE(3751),
    [sym_comma_expression] = STATE(9438),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_type_descriptor] = STATE(9498),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8521),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym__unary_left_fold] = STATE(8711),
    [sym__unary_right_fold] = STATE(8719),
    [sym__binary_fold] = STATE(8774),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6235),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym__assignment_expression_lhs] = STATE(9454),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(2000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(1866),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(1876),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(183)] = {
    [sym_identifier] = ACTIONS(2020),
    [aux_sym_preproc_include_token1] = ACTIONS(2020),
    [aux_sym_preproc_def_token1] = ACTIONS(2020),
    [aux_sym_preproc_if_token1] = ACTIONS(2020),
    [aux_sym_preproc_if_token2] = ACTIONS(2020),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2020),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2020),
    [aux_sym_preproc_else_token1] = ACTIONS(2020),
    [aux_sym_preproc_elif_token1] = ACTIONS(2020),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2020),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2020),
    [sym_preproc_directive] = ACTIONS(2020),
    [anon_sym_LPAREN2] = ACTIONS(2022),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2020),
    [anon_sym_PLUS] = ACTIONS(2020),
    [anon_sym_STAR] = ACTIONS(2022),
    [anon_sym_AMP_AMP] = ACTIONS(2022),
    [anon_sym_AMP] = ACTIONS(2020),
    [anon_sym_SEMI] = ACTIONS(2022),
    [anon_sym___extension__] = ACTIONS(2020),
    [anon_sym_typedef] = ACTIONS(2020),
    [anon_sym___device__] = ACTIONS(2020),
    [anon_sym___host__] = ACTIONS(2020),
    [anon_sym___global__] = ACTIONS(2020),
    [anon_sym___forceinline__] = ACTIONS(2020),
    [anon_sym___noinline__] = ACTIONS(2020),
    [anon_sym_virtual] = ACTIONS(2020),
    [anon_sym_extern] = ACTIONS(2020),
    [anon_sym___attribute__] = ACTIONS(2020),
    [anon_sym___attribute] = ACTIONS(2020),
    [anon_sym_COLON_COLON] = ACTIONS(2022),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2022),
    [anon_sym___declspec] = ACTIONS(2020),
    [anon_sym___based] = ACTIONS(2020),
    [anon_sym___cdecl] = ACTIONS(2020),
    [anon_sym___clrcall] = ACTIONS(2020),
    [anon_sym___stdcall] = ACTIONS(2020),
    [anon_sym___fastcall] = ACTIONS(2020),
    [anon_sym___thiscall] = ACTIONS(2020),
    [anon_sym___vectorcall] = ACTIONS(2020),
    [anon_sym_LBRACE] = ACTIONS(2022),
    [anon_sym_signed] = ACTIONS(2020),
    [anon_sym_unsigned] = ACTIONS(2020),
    [anon_sym_long] = ACTIONS(2020),
    [anon_sym_short] = ACTIONS(2020),
    [anon_sym_LBRACK] = ACTIONS(2020),
    [anon_sym_static] = ACTIONS(2020),
    [anon_sym_register] = ACTIONS(2020),
    [anon_sym_inline] = ACTIONS(2020),
    [anon_sym___inline] = ACTIONS(2020),
    [anon_sym___inline__] = ACTIONS(2020),
    [anon_sym___forceinline] = ACTIONS(2020),
    [anon_sym_thread_local] = ACTIONS(2020),
    [anon_sym___thread] = ACTIONS(2020),
    [anon_sym_const] = ACTIONS(2020),
    [anon_sym_constexpr] = ACTIONS(2020),
    [anon_sym_volatile] = ACTIONS(2020),
    [anon_sym_restrict] = ACTIONS(2020),
    [anon_sym___restrict__] = ACTIONS(2020),
    [anon_sym__Atomic] = ACTIONS(2020),
    [anon_sym__Noreturn] = ACTIONS(2020),
    [anon_sym_noreturn] = ACTIONS(2020),
    [anon_sym__Nonnull] = ACTIONS(2020),
    [anon_sym_mutable] = ACTIONS(2020),
    [anon_sym_constinit] = ACTIONS(2020),
    [anon_sym_consteval] = ACTIONS(2020),
    [anon_sym___shared__] = ACTIONS(2020),
    [anon_sym___local__] = ACTIONS(2020),
    [anon_sym___constant__] = ACTIONS(2020),
    [anon_sym___managed__] = ACTIONS(2020),
    [anon_sym___grid_constant__] = ACTIONS(2020),
    [anon_sym_alignas] = ACTIONS(2020),
    [anon_sym__Alignas] = ACTIONS(2020),
    [sym_primitive_type] = ACTIONS(2020),
    [anon_sym_enum] = ACTIONS(2020),
    [anon_sym_class] = ACTIONS(2020),
    [anon_sym_struct] = ACTIONS(2020),
    [anon_sym_union] = ACTIONS(2020),
    [anon_sym_if] = ACTIONS(2020),
    [anon_sym_else] = ACTIONS(2020),
    [anon_sym_switch] = ACTIONS(2020),
    [anon_sym_case] = ACTIONS(2020),
    [anon_sym_default] = ACTIONS(2020),
    [anon_sym_while] = ACTIONS(2020),
    [anon_sym_do] = ACTIONS(2020),
    [anon_sym_for] = ACTIONS(2020),
    [anon_sym_return] = ACTIONS(2020),
    [anon_sym_break] = ACTIONS(2020),
    [anon_sym_continue] = ACTIONS(2020),
    [anon_sym_goto] = ACTIONS(2020),
    [anon_sym___try] = ACTIONS(2020),
    [anon_sym___leave] = ACTIONS(2020),
    [anon_sym_not] = ACTIONS(2020),
    [anon_sym_compl] = ACTIONS(2020),
    [anon_sym_DASH_DASH] = ACTIONS(2022),
    [anon_sym_PLUS_PLUS] = ACTIONS(2022),
    [anon_sym_sizeof] = ACTIONS(2020),
    [anon_sym___alignof__] = ACTIONS(2020),
    [anon_sym___alignof] = ACTIONS(2020),
    [anon_sym__alignof] = ACTIONS(2020),
    [anon_sym_alignof] = ACTIONS(2020),
    [anon_sym__Alignof] = ACTIONS(2020),
    [anon_sym_offsetof] = ACTIONS(2020),
    [anon_sym__Generic] = ACTIONS(2020),
    [anon_sym_asm] = ACTIONS(2020),
    [anon_sym___asm__] = ACTIONS(2020),
    [anon_sym___asm] = ACTIONS(2020),
    [sym_number_literal] = ACTIONS(2022),
    [anon_sym_L_SQUOTE] = ACTIONS(2022),
    [anon_sym_u_SQUOTE] = ACTIONS(2022),
    [anon_sym_U_SQUOTE] = ACTIONS(2022),
    [anon_sym_u8_SQUOTE] = ACTIONS(2022),
    [anon_sym_SQUOTE] = ACTIONS(2022),
    [anon_sym_L_DQUOTE] = ACTIONS(2022),
    [anon_sym_u_DQUOTE] = ACTIONS(2022),
    [anon_sym_U_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8_DQUOTE] = ACTIONS(2022),
    [anon_sym_DQUOTE] = ACTIONS(2022),
    [sym_true] = ACTIONS(2020),
    [sym_false] = ACTIONS(2020),
    [anon_sym_NULL] = ACTIONS(2020),
    [anon_sym_nullptr] = ACTIONS(2020),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2020),
    [anon_sym_decltype] = ACTIONS(2020),
    [anon_sym_explicit] = ACTIONS(2020),
    [anon_sym_typename] = ACTIONS(2020),
    [anon_sym_template] = ACTIONS(2020),
    [anon_sym_operator] = ACTIONS(2020),
    [anon_sym_try] = ACTIONS(2020),
    [anon_sym_delete] = ACTIONS(2020),
    [anon_sym_throw] = ACTIONS(2020),
    [anon_sym_namespace] = ACTIONS(2020),
    [anon_sym_using] = ACTIONS(2020),
    [anon_sym_static_assert] = ACTIONS(2020),
    [anon_sym_concept] = ACTIONS(2020),
    [anon_sym_co_return] = ACTIONS(2020),
    [anon_sym_co_yield] = ACTIONS(2020),
    [anon_sym_R_DQUOTE] = ACTIONS(2022),
    [anon_sym_LR_DQUOTE] = ACTIONS(2022),
    [anon_sym_uR_DQUOTE] = ACTIONS(2022),
    [anon_sym_UR_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2022),
    [anon_sym_co_await] = ACTIONS(2020),
    [anon_sym_new] = ACTIONS(2020),
    [anon_sym_requires] = ACTIONS(2020),
    [sym_this] = ACTIONS(2020),
    [anon_sym___launch_bounds__] = ACTIONS(2020),
  },
  [STATE(184)] = {
    [sym_identifier] = ACTIONS(2024),
    [aux_sym_preproc_include_token1] = ACTIONS(2024),
    [aux_sym_preproc_def_token1] = ACTIONS(2024),
    [aux_sym_preproc_if_token1] = ACTIONS(2024),
    [aux_sym_preproc_if_token2] = ACTIONS(2024),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2024),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2024),
    [aux_sym_preproc_else_token1] = ACTIONS(2024),
    [aux_sym_preproc_elif_token1] = ACTIONS(2024),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2024),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2024),
    [sym_preproc_directive] = ACTIONS(2024),
    [anon_sym_LPAREN2] = ACTIONS(2026),
    [anon_sym_BANG] = ACTIONS(2026),
    [anon_sym_TILDE] = ACTIONS(2026),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_STAR] = ACTIONS(2026),
    [anon_sym_AMP_AMP] = ACTIONS(2026),
    [anon_sym_AMP] = ACTIONS(2024),
    [anon_sym_SEMI] = ACTIONS(2026),
    [anon_sym___extension__] = ACTIONS(2024),
    [anon_sym_typedef] = ACTIONS(2024),
    [anon_sym___device__] = ACTIONS(2024),
    [anon_sym___host__] = ACTIONS(2024),
    [anon_sym___global__] = ACTIONS(2024),
    [anon_sym___forceinline__] = ACTIONS(2024),
    [anon_sym___noinline__] = ACTIONS(2024),
    [anon_sym_virtual] = ACTIONS(2024),
    [anon_sym_extern] = ACTIONS(2024),
    [anon_sym___attribute__] = ACTIONS(2024),
    [anon_sym___attribute] = ACTIONS(2024),
    [anon_sym_COLON_COLON] = ACTIONS(2026),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2026),
    [anon_sym___declspec] = ACTIONS(2024),
    [anon_sym___based] = ACTIONS(2024),
    [anon_sym___cdecl] = ACTIONS(2024),
    [anon_sym___clrcall] = ACTIONS(2024),
    [anon_sym___stdcall] = ACTIONS(2024),
    [anon_sym___fastcall] = ACTIONS(2024),
    [anon_sym___thiscall] = ACTIONS(2024),
    [anon_sym___vectorcall] = ACTIONS(2024),
    [anon_sym_LBRACE] = ACTIONS(2026),
    [anon_sym_signed] = ACTIONS(2024),
    [anon_sym_unsigned] = ACTIONS(2024),
    [anon_sym_long] = ACTIONS(2024),
    [anon_sym_short] = ACTIONS(2024),
    [anon_sym_LBRACK] = ACTIONS(2024),
    [anon_sym_static] = ACTIONS(2024),
    [anon_sym_register] = ACTIONS(2024),
    [anon_sym_inline] = ACTIONS(2024),
    [anon_sym___inline] = ACTIONS(2024),
    [anon_sym___inline__] = ACTIONS(2024),
    [anon_sym___forceinline] = ACTIONS(2024),
    [anon_sym_thread_local] = ACTIONS(2024),
    [anon_sym___thread] = ACTIONS(2024),
    [anon_sym_const] = ACTIONS(2024),
    [anon_sym_constexpr] = ACTIONS(2024),
    [anon_sym_volatile] = ACTIONS(2024),
    [anon_sym_restrict] = ACTIONS(2024),
    [anon_sym___restrict__] = ACTIONS(2024),
    [anon_sym__Atomic] = ACTIONS(2024),
    [anon_sym__Noreturn] = ACTIONS(2024),
    [anon_sym_noreturn] = ACTIONS(2024),
    [anon_sym__Nonnull] = ACTIONS(2024),
    [anon_sym_mutable] = ACTIONS(2024),
    [anon_sym_constinit] = ACTIONS(2024),
    [anon_sym_consteval] = ACTIONS(2024),
    [anon_sym___shared__] = ACTIONS(2024),
    [anon_sym___local__] = ACTIONS(2024),
    [anon_sym___constant__] = ACTIONS(2024),
    [anon_sym___managed__] = ACTIONS(2024),
    [anon_sym___grid_constant__] = ACTIONS(2024),
    [anon_sym_alignas] = ACTIONS(2024),
    [anon_sym__Alignas] = ACTIONS(2024),
    [sym_primitive_type] = ACTIONS(2024),
    [anon_sym_enum] = ACTIONS(2024),
    [anon_sym_class] = ACTIONS(2024),
    [anon_sym_struct] = ACTIONS(2024),
    [anon_sym_union] = ACTIONS(2024),
    [anon_sym_if] = ACTIONS(2024),
    [anon_sym_else] = ACTIONS(2024),
    [anon_sym_switch] = ACTIONS(2024),
    [anon_sym_case] = ACTIONS(2024),
    [anon_sym_default] = ACTIONS(2024),
    [anon_sym_while] = ACTIONS(2024),
    [anon_sym_do] = ACTIONS(2024),
    [anon_sym_for] = ACTIONS(2024),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_break] = ACTIONS(2024),
    [anon_sym_continue] = ACTIONS(2024),
    [anon_sym_goto] = ACTIONS(2024),
    [anon_sym___try] = ACTIONS(2024),
    [anon_sym___leave] = ACTIONS(2024),
    [anon_sym_not] = ACTIONS(2024),
    [anon_sym_compl] = ACTIONS(2024),
    [anon_sym_DASH_DASH] = ACTIONS(2026),
    [anon_sym_PLUS_PLUS] = ACTIONS(2026),
    [anon_sym_sizeof] = ACTIONS(2024),
    [anon_sym___alignof__] = ACTIONS(2024),
    [anon_sym___alignof] = ACTIONS(2024),
    [anon_sym__alignof] = ACTIONS(2024),
    [anon_sym_alignof] = ACTIONS(2024),
    [anon_sym__Alignof] = ACTIONS(2024),
    [anon_sym_offsetof] = ACTIONS(2024),
    [anon_sym__Generic] = ACTIONS(2024),
    [anon_sym_asm] = ACTIONS(2024),
    [anon_sym___asm__] = ACTIONS(2024),
    [anon_sym___asm] = ACTIONS(2024),
    [sym_number_literal] = ACTIONS(2026),
    [anon_sym_L_SQUOTE] = ACTIONS(2026),
    [anon_sym_u_SQUOTE] = ACTIONS(2026),
    [anon_sym_U_SQUOTE] = ACTIONS(2026),
    [anon_sym_u8_SQUOTE] = ACTIONS(2026),
    [anon_sym_SQUOTE] = ACTIONS(2026),
    [anon_sym_L_DQUOTE] = ACTIONS(2026),
    [anon_sym_u_DQUOTE] = ACTIONS(2026),
    [anon_sym_U_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8_DQUOTE] = ACTIONS(2026),
    [anon_sym_DQUOTE] = ACTIONS(2026),
    [sym_true] = ACTIONS(2024),
    [sym_false] = ACTIONS(2024),
    [anon_sym_NULL] = ACTIONS(2024),
    [anon_sym_nullptr] = ACTIONS(2024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2024),
    [anon_sym_decltype] = ACTIONS(2024),
    [anon_sym_explicit] = ACTIONS(2024),
    [anon_sym_typename] = ACTIONS(2024),
    [anon_sym_template] = ACTIONS(2024),
    [anon_sym_operator] = ACTIONS(2024),
    [anon_sym_try] = ACTIONS(2024),
    [anon_sym_delete] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2024),
    [anon_sym_namespace] = ACTIONS(2024),
    [anon_sym_using] = ACTIONS(2024),
    [anon_sym_static_assert] = ACTIONS(2024),
    [anon_sym_concept] = ACTIONS(2024),
    [anon_sym_co_return] = ACTIONS(2024),
    [anon_sym_co_yield] = ACTIONS(2024),
    [anon_sym_R_DQUOTE] = ACTIONS(2026),
    [anon_sym_LR_DQUOTE] = ACTIONS(2026),
    [anon_sym_uR_DQUOTE] = ACTIONS(2026),
    [anon_sym_UR_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2026),
    [anon_sym_co_await] = ACTIONS(2024),
    [anon_sym_new] = ACTIONS(2024),
    [anon_sym_requires] = ACTIONS(2024),
    [sym_this] = ACTIONS(2024),
    [anon_sym___launch_bounds__] = ACTIONS(2024),
  },
  [STATE(185)] = {
    [sym_identifier] = ACTIONS(2028),
    [aux_sym_preproc_include_token1] = ACTIONS(2028),
    [aux_sym_preproc_def_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token2] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2028),
    [aux_sym_preproc_else_token1] = ACTIONS(2028),
    [aux_sym_preproc_elif_token1] = ACTIONS(2028),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2028),
    [sym_preproc_directive] = ACTIONS(2028),
    [anon_sym_LPAREN2] = ACTIONS(2030),
    [anon_sym_BANG] = ACTIONS(2030),
    [anon_sym_TILDE] = ACTIONS(2030),
    [anon_sym_DASH] = ACTIONS(2028),
    [anon_sym_PLUS] = ACTIONS(2028),
    [anon_sym_STAR] = ACTIONS(2030),
    [anon_sym_AMP_AMP] = ACTIONS(2030),
    [anon_sym_AMP] = ACTIONS(2028),
    [anon_sym_SEMI] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(2028),
    [anon_sym_typedef] = ACTIONS(2028),
    [anon_sym___device__] = ACTIONS(2028),
    [anon_sym___host__] = ACTIONS(2028),
    [anon_sym___global__] = ACTIONS(2028),
    [anon_sym___forceinline__] = ACTIONS(2028),
    [anon_sym___noinline__] = ACTIONS(2028),
    [anon_sym_virtual] = ACTIONS(2028),
    [anon_sym_extern] = ACTIONS(2028),
    [anon_sym___attribute__] = ACTIONS(2028),
    [anon_sym___attribute] = ACTIONS(2028),
    [anon_sym_COLON_COLON] = ACTIONS(2030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2030),
    [anon_sym___declspec] = ACTIONS(2028),
    [anon_sym___based] = ACTIONS(2028),
    [anon_sym___cdecl] = ACTIONS(2028),
    [anon_sym___clrcall] = ACTIONS(2028),
    [anon_sym___stdcall] = ACTIONS(2028),
    [anon_sym___fastcall] = ACTIONS(2028),
    [anon_sym___thiscall] = ACTIONS(2028),
    [anon_sym___vectorcall] = ACTIONS(2028),
    [anon_sym_LBRACE] = ACTIONS(2030),
    [anon_sym_signed] = ACTIONS(2028),
    [anon_sym_unsigned] = ACTIONS(2028),
    [anon_sym_long] = ACTIONS(2028),
    [anon_sym_short] = ACTIONS(2028),
    [anon_sym_LBRACK] = ACTIONS(2028),
    [anon_sym_static] = ACTIONS(2028),
    [anon_sym_register] = ACTIONS(2028),
    [anon_sym_inline] = ACTIONS(2028),
    [anon_sym___inline] = ACTIONS(2028),
    [anon_sym___inline__] = ACTIONS(2028),
    [anon_sym___forceinline] = ACTIONS(2028),
    [anon_sym_thread_local] = ACTIONS(2028),
    [anon_sym___thread] = ACTIONS(2028),
    [anon_sym_const] = ACTIONS(2028),
    [anon_sym_constexpr] = ACTIONS(2028),
    [anon_sym_volatile] = ACTIONS(2028),
    [anon_sym_restrict] = ACTIONS(2028),
    [anon_sym___restrict__] = ACTIONS(2028),
    [anon_sym__Atomic] = ACTIONS(2028),
    [anon_sym__Noreturn] = ACTIONS(2028),
    [anon_sym_noreturn] = ACTIONS(2028),
    [anon_sym__Nonnull] = ACTIONS(2028),
    [anon_sym_mutable] = ACTIONS(2028),
    [anon_sym_constinit] = ACTIONS(2028),
    [anon_sym_consteval] = ACTIONS(2028),
    [anon_sym___shared__] = ACTIONS(2028),
    [anon_sym___local__] = ACTIONS(2028),
    [anon_sym___constant__] = ACTIONS(2028),
    [anon_sym___managed__] = ACTIONS(2028),
    [anon_sym___grid_constant__] = ACTIONS(2028),
    [anon_sym_alignas] = ACTIONS(2028),
    [anon_sym__Alignas] = ACTIONS(2028),
    [sym_primitive_type] = ACTIONS(2028),
    [anon_sym_enum] = ACTIONS(2028),
    [anon_sym_class] = ACTIONS(2028),
    [anon_sym_struct] = ACTIONS(2028),
    [anon_sym_union] = ACTIONS(2028),
    [anon_sym_if] = ACTIONS(2028),
    [anon_sym_else] = ACTIONS(2028),
    [anon_sym_switch] = ACTIONS(2028),
    [anon_sym_case] = ACTIONS(2028),
    [anon_sym_default] = ACTIONS(2028),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_do] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2028),
    [anon_sym_return] = ACTIONS(2028),
    [anon_sym_break] = ACTIONS(2028),
    [anon_sym_continue] = ACTIONS(2028),
    [anon_sym_goto] = ACTIONS(2028),
    [anon_sym___try] = ACTIONS(2028),
    [anon_sym___leave] = ACTIONS(2028),
    [anon_sym_not] = ACTIONS(2028),
    [anon_sym_compl] = ACTIONS(2028),
    [anon_sym_DASH_DASH] = ACTIONS(2030),
    [anon_sym_PLUS_PLUS] = ACTIONS(2030),
    [anon_sym_sizeof] = ACTIONS(2028),
    [anon_sym___alignof__] = ACTIONS(2028),
    [anon_sym___alignof] = ACTIONS(2028),
    [anon_sym__alignof] = ACTIONS(2028),
    [anon_sym_alignof] = ACTIONS(2028),
    [anon_sym__Alignof] = ACTIONS(2028),
    [anon_sym_offsetof] = ACTIONS(2028),
    [anon_sym__Generic] = ACTIONS(2028),
    [anon_sym_asm] = ACTIONS(2028),
    [anon_sym___asm__] = ACTIONS(2028),
    [anon_sym___asm] = ACTIONS(2028),
    [sym_number_literal] = ACTIONS(2030),
    [anon_sym_L_SQUOTE] = ACTIONS(2030),
    [anon_sym_u_SQUOTE] = ACTIONS(2030),
    [anon_sym_U_SQUOTE] = ACTIONS(2030),
    [anon_sym_u8_SQUOTE] = ACTIONS(2030),
    [anon_sym_SQUOTE] = ACTIONS(2030),
    [anon_sym_L_DQUOTE] = ACTIONS(2030),
    [anon_sym_u_DQUOTE] = ACTIONS(2030),
    [anon_sym_U_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8_DQUOTE] = ACTIONS(2030),
    [anon_sym_DQUOTE] = ACTIONS(2030),
    [sym_true] = ACTIONS(2028),
    [sym_false] = ACTIONS(2028),
    [anon_sym_NULL] = ACTIONS(2028),
    [anon_sym_nullptr] = ACTIONS(2028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2028),
    [anon_sym_decltype] = ACTIONS(2028),
    [anon_sym_explicit] = ACTIONS(2028),
    [anon_sym_typename] = ACTIONS(2028),
    [anon_sym_template] = ACTIONS(2028),
    [anon_sym_operator] = ACTIONS(2028),
    [anon_sym_try] = ACTIONS(2028),
    [anon_sym_delete] = ACTIONS(2028),
    [anon_sym_throw] = ACTIONS(2028),
    [anon_sym_namespace] = ACTIONS(2028),
    [anon_sym_using] = ACTIONS(2028),
    [anon_sym_static_assert] = ACTIONS(2028),
    [anon_sym_concept] = ACTIONS(2028),
    [anon_sym_co_return] = ACTIONS(2028),
    [anon_sym_co_yield] = ACTIONS(2028),
    [anon_sym_R_DQUOTE] = ACTIONS(2030),
    [anon_sym_LR_DQUOTE] = ACTIONS(2030),
    [anon_sym_uR_DQUOTE] = ACTIONS(2030),
    [anon_sym_UR_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2030),
    [anon_sym_co_await] = ACTIONS(2028),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_requires] = ACTIONS(2028),
    [sym_this] = ACTIONS(2028),
    [anon_sym___launch_bounds__] = ACTIONS(2028),
  },
  [STATE(186)] = {
    [sym_identifier] = ACTIONS(2032),
    [aux_sym_preproc_include_token1] = ACTIONS(2032),
    [aux_sym_preproc_def_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token2] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2032),
    [aux_sym_preproc_else_token1] = ACTIONS(2032),
    [aux_sym_preproc_elif_token1] = ACTIONS(2032),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2032),
    [sym_preproc_directive] = ACTIONS(2032),
    [anon_sym_LPAREN2] = ACTIONS(2034),
    [anon_sym_BANG] = ACTIONS(2034),
    [anon_sym_TILDE] = ACTIONS(2034),
    [anon_sym_DASH] = ACTIONS(2032),
    [anon_sym_PLUS] = ACTIONS(2032),
    [anon_sym_STAR] = ACTIONS(2034),
    [anon_sym_AMP_AMP] = ACTIONS(2034),
    [anon_sym_AMP] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(2034),
    [anon_sym___extension__] = ACTIONS(2032),
    [anon_sym_typedef] = ACTIONS(2032),
    [anon_sym___device__] = ACTIONS(2032),
    [anon_sym___host__] = ACTIONS(2032),
    [anon_sym___global__] = ACTIONS(2032),
    [anon_sym___forceinline__] = ACTIONS(2032),
    [anon_sym___noinline__] = ACTIONS(2032),
    [anon_sym_virtual] = ACTIONS(2032),
    [anon_sym_extern] = ACTIONS(2032),
    [anon_sym___attribute__] = ACTIONS(2032),
    [anon_sym___attribute] = ACTIONS(2032),
    [anon_sym_COLON_COLON] = ACTIONS(2034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2034),
    [anon_sym___declspec] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(2032),
    [anon_sym___cdecl] = ACTIONS(2032),
    [anon_sym___clrcall] = ACTIONS(2032),
    [anon_sym___stdcall] = ACTIONS(2032),
    [anon_sym___fastcall] = ACTIONS(2032),
    [anon_sym___thiscall] = ACTIONS(2032),
    [anon_sym___vectorcall] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2032),
    [anon_sym_unsigned] = ACTIONS(2032),
    [anon_sym_long] = ACTIONS(2032),
    [anon_sym_short] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(2032),
    [anon_sym_static] = ACTIONS(2032),
    [anon_sym_register] = ACTIONS(2032),
    [anon_sym_inline] = ACTIONS(2032),
    [anon_sym___inline] = ACTIONS(2032),
    [anon_sym___inline__] = ACTIONS(2032),
    [anon_sym___forceinline] = ACTIONS(2032),
    [anon_sym_thread_local] = ACTIONS(2032),
    [anon_sym___thread] = ACTIONS(2032),
    [anon_sym_const] = ACTIONS(2032),
    [anon_sym_constexpr] = ACTIONS(2032),
    [anon_sym_volatile] = ACTIONS(2032),
    [anon_sym_restrict] = ACTIONS(2032),
    [anon_sym___restrict__] = ACTIONS(2032),
    [anon_sym__Atomic] = ACTIONS(2032),
    [anon_sym__Noreturn] = ACTIONS(2032),
    [anon_sym_noreturn] = ACTIONS(2032),
    [anon_sym__Nonnull] = ACTIONS(2032),
    [anon_sym_mutable] = ACTIONS(2032),
    [anon_sym_constinit] = ACTIONS(2032),
    [anon_sym_consteval] = ACTIONS(2032),
    [anon_sym___shared__] = ACTIONS(2032),
    [anon_sym___local__] = ACTIONS(2032),
    [anon_sym___constant__] = ACTIONS(2032),
    [anon_sym___managed__] = ACTIONS(2032),
    [anon_sym___grid_constant__] = ACTIONS(2032),
    [anon_sym_alignas] = ACTIONS(2032),
    [anon_sym__Alignas] = ACTIONS(2032),
    [sym_primitive_type] = ACTIONS(2032),
    [anon_sym_enum] = ACTIONS(2032),
    [anon_sym_class] = ACTIONS(2032),
    [anon_sym_struct] = ACTIONS(2032),
    [anon_sym_union] = ACTIONS(2032),
    [anon_sym_if] = ACTIONS(2032),
    [anon_sym_else] = ACTIONS(2032),
    [anon_sym_switch] = ACTIONS(2032),
    [anon_sym_case] = ACTIONS(2032),
    [anon_sym_default] = ACTIONS(2032),
    [anon_sym_while] = ACTIONS(2032),
    [anon_sym_do] = ACTIONS(2032),
    [anon_sym_for] = ACTIONS(2032),
    [anon_sym_return] = ACTIONS(2032),
    [anon_sym_break] = ACTIONS(2032),
    [anon_sym_continue] = ACTIONS(2032),
    [anon_sym_goto] = ACTIONS(2032),
    [anon_sym___try] = ACTIONS(2032),
    [anon_sym___leave] = ACTIONS(2032),
    [anon_sym_not] = ACTIONS(2032),
    [anon_sym_compl] = ACTIONS(2032),
    [anon_sym_DASH_DASH] = ACTIONS(2034),
    [anon_sym_PLUS_PLUS] = ACTIONS(2034),
    [anon_sym_sizeof] = ACTIONS(2032),
    [anon_sym___alignof__] = ACTIONS(2032),
    [anon_sym___alignof] = ACTIONS(2032),
    [anon_sym__alignof] = ACTIONS(2032),
    [anon_sym_alignof] = ACTIONS(2032),
    [anon_sym__Alignof] = ACTIONS(2032),
    [anon_sym_offsetof] = ACTIONS(2032),
    [anon_sym__Generic] = ACTIONS(2032),
    [anon_sym_asm] = ACTIONS(2032),
    [anon_sym___asm__] = ACTIONS(2032),
    [anon_sym___asm] = ACTIONS(2032),
    [sym_number_literal] = ACTIONS(2034),
    [anon_sym_L_SQUOTE] = ACTIONS(2034),
    [anon_sym_u_SQUOTE] = ACTIONS(2034),
    [anon_sym_U_SQUOTE] = ACTIONS(2034),
    [anon_sym_u8_SQUOTE] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2034),
    [anon_sym_L_DQUOTE] = ACTIONS(2034),
    [anon_sym_u_DQUOTE] = ACTIONS(2034),
    [anon_sym_U_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8_DQUOTE] = ACTIONS(2034),
    [anon_sym_DQUOTE] = ACTIONS(2034),
    [sym_true] = ACTIONS(2032),
    [sym_false] = ACTIONS(2032),
    [anon_sym_NULL] = ACTIONS(2032),
    [anon_sym_nullptr] = ACTIONS(2032),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2032),
    [anon_sym_decltype] = ACTIONS(2032),
    [anon_sym_explicit] = ACTIONS(2032),
    [anon_sym_typename] = ACTIONS(2032),
    [anon_sym_template] = ACTIONS(2032),
    [anon_sym_operator] = ACTIONS(2032),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_delete] = ACTIONS(2032),
    [anon_sym_throw] = ACTIONS(2032),
    [anon_sym_namespace] = ACTIONS(2032),
    [anon_sym_using] = ACTIONS(2032),
    [anon_sym_static_assert] = ACTIONS(2032),
    [anon_sym_concept] = ACTIONS(2032),
    [anon_sym_co_return] = ACTIONS(2032),
    [anon_sym_co_yield] = ACTIONS(2032),
    [anon_sym_R_DQUOTE] = ACTIONS(2034),
    [anon_sym_LR_DQUOTE] = ACTIONS(2034),
    [anon_sym_uR_DQUOTE] = ACTIONS(2034),
    [anon_sym_UR_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2034),
    [anon_sym_co_await] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(2032),
    [anon_sym_requires] = ACTIONS(2032),
    [sym_this] = ACTIONS(2032),
    [anon_sym___launch_bounds__] = ACTIONS(2032),
  },
  [STATE(187)] = {
    [sym_identifier] = ACTIONS(2036),
    [aux_sym_preproc_include_token1] = ACTIONS(2036),
    [aux_sym_preproc_def_token1] = ACTIONS(2036),
    [aux_sym_preproc_if_token1] = ACTIONS(2036),
    [aux_sym_preproc_if_token2] = ACTIONS(2036),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2036),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2036),
    [aux_sym_preproc_else_token1] = ACTIONS(2036),
    [aux_sym_preproc_elif_token1] = ACTIONS(2036),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2036),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2036),
    [sym_preproc_directive] = ACTIONS(2036),
    [anon_sym_LPAREN2] = ACTIONS(2038),
    [anon_sym_BANG] = ACTIONS(2038),
    [anon_sym_TILDE] = ACTIONS(2038),
    [anon_sym_DASH] = ACTIONS(2036),
    [anon_sym_PLUS] = ACTIONS(2036),
    [anon_sym_STAR] = ACTIONS(2038),
    [anon_sym_AMP_AMP] = ACTIONS(2038),
    [anon_sym_AMP] = ACTIONS(2036),
    [anon_sym_SEMI] = ACTIONS(2038),
    [anon_sym___extension__] = ACTIONS(2036),
    [anon_sym_typedef] = ACTIONS(2036),
    [anon_sym___device__] = ACTIONS(2036),
    [anon_sym___host__] = ACTIONS(2036),
    [anon_sym___global__] = ACTIONS(2036),
    [anon_sym___forceinline__] = ACTIONS(2036),
    [anon_sym___noinline__] = ACTIONS(2036),
    [anon_sym_virtual] = ACTIONS(2036),
    [anon_sym_extern] = ACTIONS(2036),
    [anon_sym___attribute__] = ACTIONS(2036),
    [anon_sym___attribute] = ACTIONS(2036),
    [anon_sym_COLON_COLON] = ACTIONS(2038),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2038),
    [anon_sym___declspec] = ACTIONS(2036),
    [anon_sym___based] = ACTIONS(2036),
    [anon_sym___cdecl] = ACTIONS(2036),
    [anon_sym___clrcall] = ACTIONS(2036),
    [anon_sym___stdcall] = ACTIONS(2036),
    [anon_sym___fastcall] = ACTIONS(2036),
    [anon_sym___thiscall] = ACTIONS(2036),
    [anon_sym___vectorcall] = ACTIONS(2036),
    [anon_sym_LBRACE] = ACTIONS(2038),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(2036),
    [anon_sym_static] = ACTIONS(2036),
    [anon_sym_register] = ACTIONS(2036),
    [anon_sym_inline] = ACTIONS(2036),
    [anon_sym___inline] = ACTIONS(2036),
    [anon_sym___inline__] = ACTIONS(2036),
    [anon_sym___forceinline] = ACTIONS(2036),
    [anon_sym_thread_local] = ACTIONS(2036),
    [anon_sym___thread] = ACTIONS(2036),
    [anon_sym_const] = ACTIONS(2036),
    [anon_sym_constexpr] = ACTIONS(2036),
    [anon_sym_volatile] = ACTIONS(2036),
    [anon_sym_restrict] = ACTIONS(2036),
    [anon_sym___restrict__] = ACTIONS(2036),
    [anon_sym__Atomic] = ACTIONS(2036),
    [anon_sym__Noreturn] = ACTIONS(2036),
    [anon_sym_noreturn] = ACTIONS(2036),
    [anon_sym__Nonnull] = ACTIONS(2036),
    [anon_sym_mutable] = ACTIONS(2036),
    [anon_sym_constinit] = ACTIONS(2036),
    [anon_sym_consteval] = ACTIONS(2036),
    [anon_sym___shared__] = ACTIONS(2036),
    [anon_sym___local__] = ACTIONS(2036),
    [anon_sym___constant__] = ACTIONS(2036),
    [anon_sym___managed__] = ACTIONS(2036),
    [anon_sym___grid_constant__] = ACTIONS(2036),
    [anon_sym_alignas] = ACTIONS(2036),
    [anon_sym__Alignas] = ACTIONS(2036),
    [sym_primitive_type] = ACTIONS(2036),
    [anon_sym_enum] = ACTIONS(2036),
    [anon_sym_class] = ACTIONS(2036),
    [anon_sym_struct] = ACTIONS(2036),
    [anon_sym_union] = ACTIONS(2036),
    [anon_sym_if] = ACTIONS(2036),
    [anon_sym_else] = ACTIONS(2036),
    [anon_sym_switch] = ACTIONS(2036),
    [anon_sym_case] = ACTIONS(2036),
    [anon_sym_default] = ACTIONS(2036),
    [anon_sym_while] = ACTIONS(2036),
    [anon_sym_do] = ACTIONS(2036),
    [anon_sym_for] = ACTIONS(2036),
    [anon_sym_return] = ACTIONS(2036),
    [anon_sym_break] = ACTIONS(2036),
    [anon_sym_continue] = ACTIONS(2036),
    [anon_sym_goto] = ACTIONS(2036),
    [anon_sym___try] = ACTIONS(2036),
    [anon_sym___leave] = ACTIONS(2036),
    [anon_sym_not] = ACTIONS(2036),
    [anon_sym_compl] = ACTIONS(2036),
    [anon_sym_DASH_DASH] = ACTIONS(2038),
    [anon_sym_PLUS_PLUS] = ACTIONS(2038),
    [anon_sym_sizeof] = ACTIONS(2036),
    [anon_sym___alignof__] = ACTIONS(2036),
    [anon_sym___alignof] = ACTIONS(2036),
    [anon_sym__alignof] = ACTIONS(2036),
    [anon_sym_alignof] = ACTIONS(2036),
    [anon_sym__Alignof] = ACTIONS(2036),
    [anon_sym_offsetof] = ACTIONS(2036),
    [anon_sym__Generic] = ACTIONS(2036),
    [anon_sym_asm] = ACTIONS(2036),
    [anon_sym___asm__] = ACTIONS(2036),
    [anon_sym___asm] = ACTIONS(2036),
    [sym_number_literal] = ACTIONS(2038),
    [anon_sym_L_SQUOTE] = ACTIONS(2038),
    [anon_sym_u_SQUOTE] = ACTIONS(2038),
    [anon_sym_U_SQUOTE] = ACTIONS(2038),
    [anon_sym_u8_SQUOTE] = ACTIONS(2038),
    [anon_sym_SQUOTE] = ACTIONS(2038),
    [anon_sym_L_DQUOTE] = ACTIONS(2038),
    [anon_sym_u_DQUOTE] = ACTIONS(2038),
    [anon_sym_U_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8_DQUOTE] = ACTIONS(2038),
    [anon_sym_DQUOTE] = ACTIONS(2038),
    [sym_true] = ACTIONS(2036),
    [sym_false] = ACTIONS(2036),
    [anon_sym_NULL] = ACTIONS(2036),
    [anon_sym_nullptr] = ACTIONS(2036),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2036),
    [anon_sym_decltype] = ACTIONS(2036),
    [anon_sym_explicit] = ACTIONS(2036),
    [anon_sym_typename] = ACTIONS(2036),
    [anon_sym_template] = ACTIONS(2036),
    [anon_sym_operator] = ACTIONS(2036),
    [anon_sym_try] = ACTIONS(2036),
    [anon_sym_delete] = ACTIONS(2036),
    [anon_sym_throw] = ACTIONS(2036),
    [anon_sym_namespace] = ACTIONS(2036),
    [anon_sym_using] = ACTIONS(2036),
    [anon_sym_static_assert] = ACTIONS(2036),
    [anon_sym_concept] = ACTIONS(2036),
    [anon_sym_co_return] = ACTIONS(2036),
    [anon_sym_co_yield] = ACTIONS(2036),
    [anon_sym_R_DQUOTE] = ACTIONS(2038),
    [anon_sym_LR_DQUOTE] = ACTIONS(2038),
    [anon_sym_uR_DQUOTE] = ACTIONS(2038),
    [anon_sym_UR_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2038),
    [anon_sym_co_await] = ACTIONS(2036),
    [anon_sym_new] = ACTIONS(2036),
    [anon_sym_requires] = ACTIONS(2036),
    [sym_this] = ACTIONS(2036),
    [anon_sym___launch_bounds__] = ACTIONS(2036),
  },
  [STATE(188)] = {
    [sym_identifier] = ACTIONS(2040),
    [aux_sym_preproc_include_token1] = ACTIONS(2040),
    [aux_sym_preproc_def_token1] = ACTIONS(2040),
    [aux_sym_preproc_if_token1] = ACTIONS(2040),
    [aux_sym_preproc_if_token2] = ACTIONS(2040),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2040),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2040),
    [aux_sym_preproc_else_token1] = ACTIONS(2040),
    [aux_sym_preproc_elif_token1] = ACTIONS(2040),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2040),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2040),
    [sym_preproc_directive] = ACTIONS(2040),
    [anon_sym_LPAREN2] = ACTIONS(2042),
    [anon_sym_BANG] = ACTIONS(2042),
    [anon_sym_TILDE] = ACTIONS(2042),
    [anon_sym_DASH] = ACTIONS(2040),
    [anon_sym_PLUS] = ACTIONS(2040),
    [anon_sym_STAR] = ACTIONS(2042),
    [anon_sym_AMP_AMP] = ACTIONS(2042),
    [anon_sym_AMP] = ACTIONS(2040),
    [anon_sym_SEMI] = ACTIONS(2042),
    [anon_sym___extension__] = ACTIONS(2040),
    [anon_sym_typedef] = ACTIONS(2040),
    [anon_sym___device__] = ACTIONS(2040),
    [anon_sym___host__] = ACTIONS(2040),
    [anon_sym___global__] = ACTIONS(2040),
    [anon_sym___forceinline__] = ACTIONS(2040),
    [anon_sym___noinline__] = ACTIONS(2040),
    [anon_sym_virtual] = ACTIONS(2040),
    [anon_sym_extern] = ACTIONS(2040),
    [anon_sym___attribute__] = ACTIONS(2040),
    [anon_sym___attribute] = ACTIONS(2040),
    [anon_sym_COLON_COLON] = ACTIONS(2042),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2042),
    [anon_sym___declspec] = ACTIONS(2040),
    [anon_sym___based] = ACTIONS(2040),
    [anon_sym___cdecl] = ACTIONS(2040),
    [anon_sym___clrcall] = ACTIONS(2040),
    [anon_sym___stdcall] = ACTIONS(2040),
    [anon_sym___fastcall] = ACTIONS(2040),
    [anon_sym___thiscall] = ACTIONS(2040),
    [anon_sym___vectorcall] = ACTIONS(2040),
    [anon_sym_LBRACE] = ACTIONS(2042),
    [anon_sym_signed] = ACTIONS(2040),
    [anon_sym_unsigned] = ACTIONS(2040),
    [anon_sym_long] = ACTIONS(2040),
    [anon_sym_short] = ACTIONS(2040),
    [anon_sym_LBRACK] = ACTIONS(2040),
    [anon_sym_static] = ACTIONS(2040),
    [anon_sym_register] = ACTIONS(2040),
    [anon_sym_inline] = ACTIONS(2040),
    [anon_sym___inline] = ACTIONS(2040),
    [anon_sym___inline__] = ACTIONS(2040),
    [anon_sym___forceinline] = ACTIONS(2040),
    [anon_sym_thread_local] = ACTIONS(2040),
    [anon_sym___thread] = ACTIONS(2040),
    [anon_sym_const] = ACTIONS(2040),
    [anon_sym_constexpr] = ACTIONS(2040),
    [anon_sym_volatile] = ACTIONS(2040),
    [anon_sym_restrict] = ACTIONS(2040),
    [anon_sym___restrict__] = ACTIONS(2040),
    [anon_sym__Atomic] = ACTIONS(2040),
    [anon_sym__Noreturn] = ACTIONS(2040),
    [anon_sym_noreturn] = ACTIONS(2040),
    [anon_sym__Nonnull] = ACTIONS(2040),
    [anon_sym_mutable] = ACTIONS(2040),
    [anon_sym_constinit] = ACTIONS(2040),
    [anon_sym_consteval] = ACTIONS(2040),
    [anon_sym___shared__] = ACTIONS(2040),
    [anon_sym___local__] = ACTIONS(2040),
    [anon_sym___constant__] = ACTIONS(2040),
    [anon_sym___managed__] = ACTIONS(2040),
    [anon_sym___grid_constant__] = ACTIONS(2040),
    [anon_sym_alignas] = ACTIONS(2040),
    [anon_sym__Alignas] = ACTIONS(2040),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2040),
    [anon_sym_class] = ACTIONS(2040),
    [anon_sym_struct] = ACTIONS(2040),
    [anon_sym_union] = ACTIONS(2040),
    [anon_sym_if] = ACTIONS(2040),
    [anon_sym_else] = ACTIONS(2040),
    [anon_sym_switch] = ACTIONS(2040),
    [anon_sym_case] = ACTIONS(2040),
    [anon_sym_default] = ACTIONS(2040),
    [anon_sym_while] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(2040),
    [anon_sym_for] = ACTIONS(2040),
    [anon_sym_return] = ACTIONS(2040),
    [anon_sym_break] = ACTIONS(2040),
    [anon_sym_continue] = ACTIONS(2040),
    [anon_sym_goto] = ACTIONS(2040),
    [anon_sym___try] = ACTIONS(2040),
    [anon_sym___leave] = ACTIONS(2040),
    [anon_sym_not] = ACTIONS(2040),
    [anon_sym_compl] = ACTIONS(2040),
    [anon_sym_DASH_DASH] = ACTIONS(2042),
    [anon_sym_PLUS_PLUS] = ACTIONS(2042),
    [anon_sym_sizeof] = ACTIONS(2040),
    [anon_sym___alignof__] = ACTIONS(2040),
    [anon_sym___alignof] = ACTIONS(2040),
    [anon_sym__alignof] = ACTIONS(2040),
    [anon_sym_alignof] = ACTIONS(2040),
    [anon_sym__Alignof] = ACTIONS(2040),
    [anon_sym_offsetof] = ACTIONS(2040),
    [anon_sym__Generic] = ACTIONS(2040),
    [anon_sym_asm] = ACTIONS(2040),
    [anon_sym___asm__] = ACTIONS(2040),
    [anon_sym___asm] = ACTIONS(2040),
    [sym_number_literal] = ACTIONS(2042),
    [anon_sym_L_SQUOTE] = ACTIONS(2042),
    [anon_sym_u_SQUOTE] = ACTIONS(2042),
    [anon_sym_U_SQUOTE] = ACTIONS(2042),
    [anon_sym_u8_SQUOTE] = ACTIONS(2042),
    [anon_sym_SQUOTE] = ACTIONS(2042),
    [anon_sym_L_DQUOTE] = ACTIONS(2042),
    [anon_sym_u_DQUOTE] = ACTIONS(2042),
    [anon_sym_U_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8_DQUOTE] = ACTIONS(2042),
    [anon_sym_DQUOTE] = ACTIONS(2042),
    [sym_true] = ACTIONS(2040),
    [sym_false] = ACTIONS(2040),
    [anon_sym_NULL] = ACTIONS(2040),
    [anon_sym_nullptr] = ACTIONS(2040),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2040),
    [anon_sym_decltype] = ACTIONS(2040),
    [anon_sym_explicit] = ACTIONS(2040),
    [anon_sym_typename] = ACTIONS(2040),
    [anon_sym_template] = ACTIONS(2040),
    [anon_sym_operator] = ACTIONS(2040),
    [anon_sym_try] = ACTIONS(2040),
    [anon_sym_delete] = ACTIONS(2040),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_namespace] = ACTIONS(2040),
    [anon_sym_using] = ACTIONS(2040),
    [anon_sym_static_assert] = ACTIONS(2040),
    [anon_sym_concept] = ACTIONS(2040),
    [anon_sym_co_return] = ACTIONS(2040),
    [anon_sym_co_yield] = ACTIONS(2040),
    [anon_sym_R_DQUOTE] = ACTIONS(2042),
    [anon_sym_LR_DQUOTE] = ACTIONS(2042),
    [anon_sym_uR_DQUOTE] = ACTIONS(2042),
    [anon_sym_UR_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2042),
    [anon_sym_co_await] = ACTIONS(2040),
    [anon_sym_new] = ACTIONS(2040),
    [anon_sym_requires] = ACTIONS(2040),
    [sym_this] = ACTIONS(2040),
    [anon_sym___launch_bounds__] = ACTIONS(2040),
  },
  [STATE(189)] = {
    [sym_identifier] = ACTIONS(2044),
    [aux_sym_preproc_include_token1] = ACTIONS(2044),
    [aux_sym_preproc_def_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token2] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2044),
    [aux_sym_preproc_else_token1] = ACTIONS(2044),
    [aux_sym_preproc_elif_token1] = ACTIONS(2044),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2044),
    [sym_preproc_directive] = ACTIONS(2044),
    [anon_sym_LPAREN2] = ACTIONS(2046),
    [anon_sym_BANG] = ACTIONS(2046),
    [anon_sym_TILDE] = ACTIONS(2046),
    [anon_sym_DASH] = ACTIONS(2044),
    [anon_sym_PLUS] = ACTIONS(2044),
    [anon_sym_STAR] = ACTIONS(2046),
    [anon_sym_AMP_AMP] = ACTIONS(2046),
    [anon_sym_AMP] = ACTIONS(2044),
    [anon_sym_SEMI] = ACTIONS(2046),
    [anon_sym___extension__] = ACTIONS(2044),
    [anon_sym_typedef] = ACTIONS(2044),
    [anon_sym___device__] = ACTIONS(2044),
    [anon_sym___host__] = ACTIONS(2044),
    [anon_sym___global__] = ACTIONS(2044),
    [anon_sym___forceinline__] = ACTIONS(2044),
    [anon_sym___noinline__] = ACTIONS(2044),
    [anon_sym_virtual] = ACTIONS(2044),
    [anon_sym_extern] = ACTIONS(2044),
    [anon_sym___attribute__] = ACTIONS(2044),
    [anon_sym___attribute] = ACTIONS(2044),
    [anon_sym_COLON_COLON] = ACTIONS(2046),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2046),
    [anon_sym___declspec] = ACTIONS(2044),
    [anon_sym___based] = ACTIONS(2044),
    [anon_sym___cdecl] = ACTIONS(2044),
    [anon_sym___clrcall] = ACTIONS(2044),
    [anon_sym___stdcall] = ACTIONS(2044),
    [anon_sym___fastcall] = ACTIONS(2044),
    [anon_sym___thiscall] = ACTIONS(2044),
    [anon_sym___vectorcall] = ACTIONS(2044),
    [anon_sym_LBRACE] = ACTIONS(2046),
    [anon_sym_signed] = ACTIONS(2044),
    [anon_sym_unsigned] = ACTIONS(2044),
    [anon_sym_long] = ACTIONS(2044),
    [anon_sym_short] = ACTIONS(2044),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_static] = ACTIONS(2044),
    [anon_sym_register] = ACTIONS(2044),
    [anon_sym_inline] = ACTIONS(2044),
    [anon_sym___inline] = ACTIONS(2044),
    [anon_sym___inline__] = ACTIONS(2044),
    [anon_sym___forceinline] = ACTIONS(2044),
    [anon_sym_thread_local] = ACTIONS(2044),
    [anon_sym___thread] = ACTIONS(2044),
    [anon_sym_const] = ACTIONS(2044),
    [anon_sym_constexpr] = ACTIONS(2044),
    [anon_sym_volatile] = ACTIONS(2044),
    [anon_sym_restrict] = ACTIONS(2044),
    [anon_sym___restrict__] = ACTIONS(2044),
    [anon_sym__Atomic] = ACTIONS(2044),
    [anon_sym__Noreturn] = ACTIONS(2044),
    [anon_sym_noreturn] = ACTIONS(2044),
    [anon_sym__Nonnull] = ACTIONS(2044),
    [anon_sym_mutable] = ACTIONS(2044),
    [anon_sym_constinit] = ACTIONS(2044),
    [anon_sym_consteval] = ACTIONS(2044),
    [anon_sym___shared__] = ACTIONS(2044),
    [anon_sym___local__] = ACTIONS(2044),
    [anon_sym___constant__] = ACTIONS(2044),
    [anon_sym___managed__] = ACTIONS(2044),
    [anon_sym___grid_constant__] = ACTIONS(2044),
    [anon_sym_alignas] = ACTIONS(2044),
    [anon_sym__Alignas] = ACTIONS(2044),
    [sym_primitive_type] = ACTIONS(2044),
    [anon_sym_enum] = ACTIONS(2044),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2044),
    [anon_sym_union] = ACTIONS(2044),
    [anon_sym_if] = ACTIONS(2044),
    [anon_sym_else] = ACTIONS(2044),
    [anon_sym_switch] = ACTIONS(2044),
    [anon_sym_case] = ACTIONS(2044),
    [anon_sym_default] = ACTIONS(2044),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_do] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2044),
    [anon_sym_return] = ACTIONS(2044),
    [anon_sym_break] = ACTIONS(2044),
    [anon_sym_continue] = ACTIONS(2044),
    [anon_sym_goto] = ACTIONS(2044),
    [anon_sym___try] = ACTIONS(2044),
    [anon_sym___leave] = ACTIONS(2044),
    [anon_sym_not] = ACTIONS(2044),
    [anon_sym_compl] = ACTIONS(2044),
    [anon_sym_DASH_DASH] = ACTIONS(2046),
    [anon_sym_PLUS_PLUS] = ACTIONS(2046),
    [anon_sym_sizeof] = ACTIONS(2044),
    [anon_sym___alignof__] = ACTIONS(2044),
    [anon_sym___alignof] = ACTIONS(2044),
    [anon_sym__alignof] = ACTIONS(2044),
    [anon_sym_alignof] = ACTIONS(2044),
    [anon_sym__Alignof] = ACTIONS(2044),
    [anon_sym_offsetof] = ACTIONS(2044),
    [anon_sym__Generic] = ACTIONS(2044),
    [anon_sym_asm] = ACTIONS(2044),
    [anon_sym___asm__] = ACTIONS(2044),
    [anon_sym___asm] = ACTIONS(2044),
    [sym_number_literal] = ACTIONS(2046),
    [anon_sym_L_SQUOTE] = ACTIONS(2046),
    [anon_sym_u_SQUOTE] = ACTIONS(2046),
    [anon_sym_U_SQUOTE] = ACTIONS(2046),
    [anon_sym_u8_SQUOTE] = ACTIONS(2046),
    [anon_sym_SQUOTE] = ACTIONS(2046),
    [anon_sym_L_DQUOTE] = ACTIONS(2046),
    [anon_sym_u_DQUOTE] = ACTIONS(2046),
    [anon_sym_U_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8_DQUOTE] = ACTIONS(2046),
    [anon_sym_DQUOTE] = ACTIONS(2046),
    [sym_true] = ACTIONS(2044),
    [sym_false] = ACTIONS(2044),
    [anon_sym_NULL] = ACTIONS(2044),
    [anon_sym_nullptr] = ACTIONS(2044),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2044),
    [anon_sym_decltype] = ACTIONS(2044),
    [anon_sym_explicit] = ACTIONS(2044),
    [anon_sym_typename] = ACTIONS(2044),
    [anon_sym_template] = ACTIONS(2044),
    [anon_sym_operator] = ACTIONS(2044),
    [anon_sym_try] = ACTIONS(2044),
    [anon_sym_delete] = ACTIONS(2044),
    [anon_sym_throw] = ACTIONS(2044),
    [anon_sym_namespace] = ACTIONS(2044),
    [anon_sym_using] = ACTIONS(2044),
    [anon_sym_static_assert] = ACTIONS(2044),
    [anon_sym_concept] = ACTIONS(2044),
    [anon_sym_co_return] = ACTIONS(2044),
    [anon_sym_co_yield] = ACTIONS(2044),
    [anon_sym_R_DQUOTE] = ACTIONS(2046),
    [anon_sym_LR_DQUOTE] = ACTIONS(2046),
    [anon_sym_uR_DQUOTE] = ACTIONS(2046),
    [anon_sym_UR_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2046),
    [anon_sym_co_await] = ACTIONS(2044),
    [anon_sym_new] = ACTIONS(2044),
    [anon_sym_requires] = ACTIONS(2044),
    [sym_this] = ACTIONS(2044),
    [anon_sym___launch_bounds__] = ACTIONS(2044),
  },
  [STATE(190)] = {
    [sym_identifier] = ACTIONS(2048),
    [aux_sym_preproc_include_token1] = ACTIONS(2048),
    [aux_sym_preproc_def_token1] = ACTIONS(2048),
    [aux_sym_preproc_if_token1] = ACTIONS(2048),
    [aux_sym_preproc_if_token2] = ACTIONS(2048),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2048),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2048),
    [aux_sym_preproc_else_token1] = ACTIONS(2048),
    [aux_sym_preproc_elif_token1] = ACTIONS(2048),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2048),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2048),
    [sym_preproc_directive] = ACTIONS(2048),
    [anon_sym_LPAREN2] = ACTIONS(2050),
    [anon_sym_BANG] = ACTIONS(2050),
    [anon_sym_TILDE] = ACTIONS(2050),
    [anon_sym_DASH] = ACTIONS(2048),
    [anon_sym_PLUS] = ACTIONS(2048),
    [anon_sym_STAR] = ACTIONS(2050),
    [anon_sym_AMP_AMP] = ACTIONS(2050),
    [anon_sym_AMP] = ACTIONS(2048),
    [anon_sym_SEMI] = ACTIONS(2050),
    [anon_sym___extension__] = ACTIONS(2048),
    [anon_sym_typedef] = ACTIONS(2048),
    [anon_sym___device__] = ACTIONS(2048),
    [anon_sym___host__] = ACTIONS(2048),
    [anon_sym___global__] = ACTIONS(2048),
    [anon_sym___forceinline__] = ACTIONS(2048),
    [anon_sym___noinline__] = ACTIONS(2048),
    [anon_sym_virtual] = ACTIONS(2048),
    [anon_sym_extern] = ACTIONS(2048),
    [anon_sym___attribute__] = ACTIONS(2048),
    [anon_sym___attribute] = ACTIONS(2048),
    [anon_sym_COLON_COLON] = ACTIONS(2050),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2050),
    [anon_sym___declspec] = ACTIONS(2048),
    [anon_sym___based] = ACTIONS(2048),
    [anon_sym___cdecl] = ACTIONS(2048),
    [anon_sym___clrcall] = ACTIONS(2048),
    [anon_sym___stdcall] = ACTIONS(2048),
    [anon_sym___fastcall] = ACTIONS(2048),
    [anon_sym___thiscall] = ACTIONS(2048),
    [anon_sym___vectorcall] = ACTIONS(2048),
    [anon_sym_LBRACE] = ACTIONS(2050),
    [anon_sym_signed] = ACTIONS(2048),
    [anon_sym_unsigned] = ACTIONS(2048),
    [anon_sym_long] = ACTIONS(2048),
    [anon_sym_short] = ACTIONS(2048),
    [anon_sym_LBRACK] = ACTIONS(2048),
    [anon_sym_static] = ACTIONS(2048),
    [anon_sym_register] = ACTIONS(2048),
    [anon_sym_inline] = ACTIONS(2048),
    [anon_sym___inline] = ACTIONS(2048),
    [anon_sym___inline__] = ACTIONS(2048),
    [anon_sym___forceinline] = ACTIONS(2048),
    [anon_sym_thread_local] = ACTIONS(2048),
    [anon_sym___thread] = ACTIONS(2048),
    [anon_sym_const] = ACTIONS(2048),
    [anon_sym_constexpr] = ACTIONS(2048),
    [anon_sym_volatile] = ACTIONS(2048),
    [anon_sym_restrict] = ACTIONS(2048),
    [anon_sym___restrict__] = ACTIONS(2048),
    [anon_sym__Atomic] = ACTIONS(2048),
    [anon_sym__Noreturn] = ACTIONS(2048),
    [anon_sym_noreturn] = ACTIONS(2048),
    [anon_sym__Nonnull] = ACTIONS(2048),
    [anon_sym_mutable] = ACTIONS(2048),
    [anon_sym_constinit] = ACTIONS(2048),
    [anon_sym_consteval] = ACTIONS(2048),
    [anon_sym___shared__] = ACTIONS(2048),
    [anon_sym___local__] = ACTIONS(2048),
    [anon_sym___constant__] = ACTIONS(2048),
    [anon_sym___managed__] = ACTIONS(2048),
    [anon_sym___grid_constant__] = ACTIONS(2048),
    [anon_sym_alignas] = ACTIONS(2048),
    [anon_sym__Alignas] = ACTIONS(2048),
    [sym_primitive_type] = ACTIONS(2048),
    [anon_sym_enum] = ACTIONS(2048),
    [anon_sym_class] = ACTIONS(2048),
    [anon_sym_struct] = ACTIONS(2048),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_if] = ACTIONS(2048),
    [anon_sym_else] = ACTIONS(2048),
    [anon_sym_switch] = ACTIONS(2048),
    [anon_sym_case] = ACTIONS(2048),
    [anon_sym_default] = ACTIONS(2048),
    [anon_sym_while] = ACTIONS(2048),
    [anon_sym_do] = ACTIONS(2048),
    [anon_sym_for] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2048),
    [anon_sym_break] = ACTIONS(2048),
    [anon_sym_continue] = ACTIONS(2048),
    [anon_sym_goto] = ACTIONS(2048),
    [anon_sym___try] = ACTIONS(2048),
    [anon_sym___leave] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2048),
    [anon_sym_compl] = ACTIONS(2048),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2048),
    [anon_sym___alignof__] = ACTIONS(2048),
    [anon_sym___alignof] = ACTIONS(2048),
    [anon_sym__alignof] = ACTIONS(2048),
    [anon_sym_alignof] = ACTIONS(2048),
    [anon_sym__Alignof] = ACTIONS(2048),
    [anon_sym_offsetof] = ACTIONS(2048),
    [anon_sym__Generic] = ACTIONS(2048),
    [anon_sym_asm] = ACTIONS(2048),
    [anon_sym___asm__] = ACTIONS(2048),
    [anon_sym___asm] = ACTIONS(2048),
    [sym_number_literal] = ACTIONS(2050),
    [anon_sym_L_SQUOTE] = ACTIONS(2050),
    [anon_sym_u_SQUOTE] = ACTIONS(2050),
    [anon_sym_U_SQUOTE] = ACTIONS(2050),
    [anon_sym_u8_SQUOTE] = ACTIONS(2050),
    [anon_sym_SQUOTE] = ACTIONS(2050),
    [anon_sym_L_DQUOTE] = ACTIONS(2050),
    [anon_sym_u_DQUOTE] = ACTIONS(2050),
    [anon_sym_U_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8_DQUOTE] = ACTIONS(2050),
    [anon_sym_DQUOTE] = ACTIONS(2050),
    [sym_true] = ACTIONS(2048),
    [sym_false] = ACTIONS(2048),
    [anon_sym_NULL] = ACTIONS(2048),
    [anon_sym_nullptr] = ACTIONS(2048),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2048),
    [anon_sym_decltype] = ACTIONS(2048),
    [anon_sym_explicit] = ACTIONS(2048),
    [anon_sym_typename] = ACTIONS(2048),
    [anon_sym_template] = ACTIONS(2048),
    [anon_sym_operator] = ACTIONS(2048),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_delete] = ACTIONS(2048),
    [anon_sym_throw] = ACTIONS(2048),
    [anon_sym_namespace] = ACTIONS(2048),
    [anon_sym_using] = ACTIONS(2048),
    [anon_sym_static_assert] = ACTIONS(2048),
    [anon_sym_concept] = ACTIONS(2048),
    [anon_sym_co_return] = ACTIONS(2048),
    [anon_sym_co_yield] = ACTIONS(2048),
    [anon_sym_R_DQUOTE] = ACTIONS(2050),
    [anon_sym_LR_DQUOTE] = ACTIONS(2050),
    [anon_sym_uR_DQUOTE] = ACTIONS(2050),
    [anon_sym_UR_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2050),
    [anon_sym_co_await] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(2048),
    [anon_sym_requires] = ACTIONS(2048),
    [sym_this] = ACTIONS(2048),
    [anon_sym___launch_bounds__] = ACTIONS(2048),
  },
  [STATE(191)] = {
    [sym_identifier] = ACTIONS(2052),
    [aux_sym_preproc_include_token1] = ACTIONS(2052),
    [aux_sym_preproc_def_token1] = ACTIONS(2052),
    [aux_sym_preproc_if_token1] = ACTIONS(2052),
    [aux_sym_preproc_if_token2] = ACTIONS(2052),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2052),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2052),
    [aux_sym_preproc_else_token1] = ACTIONS(2052),
    [aux_sym_preproc_elif_token1] = ACTIONS(2052),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2052),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2052),
    [sym_preproc_directive] = ACTIONS(2052),
    [anon_sym_LPAREN2] = ACTIONS(2054),
    [anon_sym_BANG] = ACTIONS(2054),
    [anon_sym_TILDE] = ACTIONS(2054),
    [anon_sym_DASH] = ACTIONS(2052),
    [anon_sym_PLUS] = ACTIONS(2052),
    [anon_sym_STAR] = ACTIONS(2054),
    [anon_sym_AMP_AMP] = ACTIONS(2054),
    [anon_sym_AMP] = ACTIONS(2052),
    [anon_sym_SEMI] = ACTIONS(2054),
    [anon_sym___extension__] = ACTIONS(2052),
    [anon_sym_typedef] = ACTIONS(2052),
    [anon_sym___device__] = ACTIONS(2052),
    [anon_sym___host__] = ACTIONS(2052),
    [anon_sym___global__] = ACTIONS(2052),
    [anon_sym___forceinline__] = ACTIONS(2052),
    [anon_sym___noinline__] = ACTIONS(2052),
    [anon_sym_virtual] = ACTIONS(2052),
    [anon_sym_extern] = ACTIONS(2052),
    [anon_sym___attribute__] = ACTIONS(2052),
    [anon_sym___attribute] = ACTIONS(2052),
    [anon_sym_COLON_COLON] = ACTIONS(2054),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2054),
    [anon_sym___declspec] = ACTIONS(2052),
    [anon_sym___based] = ACTIONS(2052),
    [anon_sym___cdecl] = ACTIONS(2052),
    [anon_sym___clrcall] = ACTIONS(2052),
    [anon_sym___stdcall] = ACTIONS(2052),
    [anon_sym___fastcall] = ACTIONS(2052),
    [anon_sym___thiscall] = ACTIONS(2052),
    [anon_sym___vectorcall] = ACTIONS(2052),
    [anon_sym_LBRACE] = ACTIONS(2054),
    [anon_sym_signed] = ACTIONS(2052),
    [anon_sym_unsigned] = ACTIONS(2052),
    [anon_sym_long] = ACTIONS(2052),
    [anon_sym_short] = ACTIONS(2052),
    [anon_sym_LBRACK] = ACTIONS(2052),
    [anon_sym_static] = ACTIONS(2052),
    [anon_sym_register] = ACTIONS(2052),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym___inline] = ACTIONS(2052),
    [anon_sym___inline__] = ACTIONS(2052),
    [anon_sym___forceinline] = ACTIONS(2052),
    [anon_sym_thread_local] = ACTIONS(2052),
    [anon_sym___thread] = ACTIONS(2052),
    [anon_sym_const] = ACTIONS(2052),
    [anon_sym_constexpr] = ACTIONS(2052),
    [anon_sym_volatile] = ACTIONS(2052),
    [anon_sym_restrict] = ACTIONS(2052),
    [anon_sym___restrict__] = ACTIONS(2052),
    [anon_sym__Atomic] = ACTIONS(2052),
    [anon_sym__Noreturn] = ACTIONS(2052),
    [anon_sym_noreturn] = ACTIONS(2052),
    [anon_sym__Nonnull] = ACTIONS(2052),
    [anon_sym_mutable] = ACTIONS(2052),
    [anon_sym_constinit] = ACTIONS(2052),
    [anon_sym_consteval] = ACTIONS(2052),
    [anon_sym___shared__] = ACTIONS(2052),
    [anon_sym___local__] = ACTIONS(2052),
    [anon_sym___constant__] = ACTIONS(2052),
    [anon_sym___managed__] = ACTIONS(2052),
    [anon_sym___grid_constant__] = ACTIONS(2052),
    [anon_sym_alignas] = ACTIONS(2052),
    [anon_sym__Alignas] = ACTIONS(2052),
    [sym_primitive_type] = ACTIONS(2052),
    [anon_sym_enum] = ACTIONS(2052),
    [anon_sym_class] = ACTIONS(2052),
    [anon_sym_struct] = ACTIONS(2052),
    [anon_sym_union] = ACTIONS(2052),
    [anon_sym_if] = ACTIONS(2052),
    [anon_sym_else] = ACTIONS(2052),
    [anon_sym_switch] = ACTIONS(2052),
    [anon_sym_case] = ACTIONS(2052),
    [anon_sym_default] = ACTIONS(2052),
    [anon_sym_while] = ACTIONS(2052),
    [anon_sym_do] = ACTIONS(2052),
    [anon_sym_for] = ACTIONS(2052),
    [anon_sym_return] = ACTIONS(2052),
    [anon_sym_break] = ACTIONS(2052),
    [anon_sym_continue] = ACTIONS(2052),
    [anon_sym_goto] = ACTIONS(2052),
    [anon_sym___try] = ACTIONS(2052),
    [anon_sym___leave] = ACTIONS(2052),
    [anon_sym_not] = ACTIONS(2052),
    [anon_sym_compl] = ACTIONS(2052),
    [anon_sym_DASH_DASH] = ACTIONS(2054),
    [anon_sym_PLUS_PLUS] = ACTIONS(2054),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2052),
    [anon_sym___alignof] = ACTIONS(2052),
    [anon_sym__alignof] = ACTIONS(2052),
    [anon_sym_alignof] = ACTIONS(2052),
    [anon_sym__Alignof] = ACTIONS(2052),
    [anon_sym_offsetof] = ACTIONS(2052),
    [anon_sym__Generic] = ACTIONS(2052),
    [anon_sym_asm] = ACTIONS(2052),
    [anon_sym___asm__] = ACTIONS(2052),
    [anon_sym___asm] = ACTIONS(2052),
    [sym_number_literal] = ACTIONS(2054),
    [anon_sym_L_SQUOTE] = ACTIONS(2054),
    [anon_sym_u_SQUOTE] = ACTIONS(2054),
    [anon_sym_U_SQUOTE] = ACTIONS(2054),
    [anon_sym_u8_SQUOTE] = ACTIONS(2054),
    [anon_sym_SQUOTE] = ACTIONS(2054),
    [anon_sym_L_DQUOTE] = ACTIONS(2054),
    [anon_sym_u_DQUOTE] = ACTIONS(2054),
    [anon_sym_U_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8_DQUOTE] = ACTIONS(2054),
    [anon_sym_DQUOTE] = ACTIONS(2054),
    [sym_true] = ACTIONS(2052),
    [sym_false] = ACTIONS(2052),
    [anon_sym_NULL] = ACTIONS(2052),
    [anon_sym_nullptr] = ACTIONS(2052),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2052),
    [anon_sym_decltype] = ACTIONS(2052),
    [anon_sym_explicit] = ACTIONS(2052),
    [anon_sym_typename] = ACTIONS(2052),
    [anon_sym_template] = ACTIONS(2052),
    [anon_sym_operator] = ACTIONS(2052),
    [anon_sym_try] = ACTIONS(2052),
    [anon_sym_delete] = ACTIONS(2052),
    [anon_sym_throw] = ACTIONS(2052),
    [anon_sym_namespace] = ACTIONS(2052),
    [anon_sym_using] = ACTIONS(2052),
    [anon_sym_static_assert] = ACTIONS(2052),
    [anon_sym_concept] = ACTIONS(2052),
    [anon_sym_co_return] = ACTIONS(2052),
    [anon_sym_co_yield] = ACTIONS(2052),
    [anon_sym_R_DQUOTE] = ACTIONS(2054),
    [anon_sym_LR_DQUOTE] = ACTIONS(2054),
    [anon_sym_uR_DQUOTE] = ACTIONS(2054),
    [anon_sym_UR_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2054),
    [anon_sym_co_await] = ACTIONS(2052),
    [anon_sym_new] = ACTIONS(2052),
    [anon_sym_requires] = ACTIONS(2052),
    [sym_this] = ACTIONS(2052),
    [anon_sym___launch_bounds__] = ACTIONS(2052),
  },
  [STATE(192)] = {
    [sym_identifier] = ACTIONS(2056),
    [aux_sym_preproc_include_token1] = ACTIONS(2056),
    [aux_sym_preproc_def_token1] = ACTIONS(2056),
    [aux_sym_preproc_if_token1] = ACTIONS(2056),
    [aux_sym_preproc_if_token2] = ACTIONS(2056),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2056),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2056),
    [aux_sym_preproc_else_token1] = ACTIONS(2056),
    [aux_sym_preproc_elif_token1] = ACTIONS(2056),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2056),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2056),
    [sym_preproc_directive] = ACTIONS(2056),
    [anon_sym_LPAREN2] = ACTIONS(2058),
    [anon_sym_BANG] = ACTIONS(2058),
    [anon_sym_TILDE] = ACTIONS(2058),
    [anon_sym_DASH] = ACTIONS(2056),
    [anon_sym_PLUS] = ACTIONS(2056),
    [anon_sym_STAR] = ACTIONS(2058),
    [anon_sym_AMP_AMP] = ACTIONS(2058),
    [anon_sym_AMP] = ACTIONS(2056),
    [anon_sym_SEMI] = ACTIONS(2058),
    [anon_sym___extension__] = ACTIONS(2056),
    [anon_sym_typedef] = ACTIONS(2056),
    [anon_sym___device__] = ACTIONS(2056),
    [anon_sym___host__] = ACTIONS(2056),
    [anon_sym___global__] = ACTIONS(2056),
    [anon_sym___forceinline__] = ACTIONS(2056),
    [anon_sym___noinline__] = ACTIONS(2056),
    [anon_sym_virtual] = ACTIONS(2056),
    [anon_sym_extern] = ACTIONS(2056),
    [anon_sym___attribute__] = ACTIONS(2056),
    [anon_sym___attribute] = ACTIONS(2056),
    [anon_sym_COLON_COLON] = ACTIONS(2058),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2058),
    [anon_sym___declspec] = ACTIONS(2056),
    [anon_sym___based] = ACTIONS(2056),
    [anon_sym___cdecl] = ACTIONS(2056),
    [anon_sym___clrcall] = ACTIONS(2056),
    [anon_sym___stdcall] = ACTIONS(2056),
    [anon_sym___fastcall] = ACTIONS(2056),
    [anon_sym___thiscall] = ACTIONS(2056),
    [anon_sym___vectorcall] = ACTIONS(2056),
    [anon_sym_LBRACE] = ACTIONS(2058),
    [anon_sym_signed] = ACTIONS(2056),
    [anon_sym_unsigned] = ACTIONS(2056),
    [anon_sym_long] = ACTIONS(2056),
    [anon_sym_short] = ACTIONS(2056),
    [anon_sym_LBRACK] = ACTIONS(2056),
    [anon_sym_static] = ACTIONS(2056),
    [anon_sym_register] = ACTIONS(2056),
    [anon_sym_inline] = ACTIONS(2056),
    [anon_sym___inline] = ACTIONS(2056),
    [anon_sym___inline__] = ACTIONS(2056),
    [anon_sym___forceinline] = ACTIONS(2056),
    [anon_sym_thread_local] = ACTIONS(2056),
    [anon_sym___thread] = ACTIONS(2056),
    [anon_sym_const] = ACTIONS(2056),
    [anon_sym_constexpr] = ACTIONS(2056),
    [anon_sym_volatile] = ACTIONS(2056),
    [anon_sym_restrict] = ACTIONS(2056),
    [anon_sym___restrict__] = ACTIONS(2056),
    [anon_sym__Atomic] = ACTIONS(2056),
    [anon_sym__Noreturn] = ACTIONS(2056),
    [anon_sym_noreturn] = ACTIONS(2056),
    [anon_sym__Nonnull] = ACTIONS(2056),
    [anon_sym_mutable] = ACTIONS(2056),
    [anon_sym_constinit] = ACTIONS(2056),
    [anon_sym_consteval] = ACTIONS(2056),
    [anon_sym___shared__] = ACTIONS(2056),
    [anon_sym___local__] = ACTIONS(2056),
    [anon_sym___constant__] = ACTIONS(2056),
    [anon_sym___managed__] = ACTIONS(2056),
    [anon_sym___grid_constant__] = ACTIONS(2056),
    [anon_sym_alignas] = ACTIONS(2056),
    [anon_sym__Alignas] = ACTIONS(2056),
    [sym_primitive_type] = ACTIONS(2056),
    [anon_sym_enum] = ACTIONS(2056),
    [anon_sym_class] = ACTIONS(2056),
    [anon_sym_struct] = ACTIONS(2056),
    [anon_sym_union] = ACTIONS(2056),
    [anon_sym_if] = ACTIONS(2056),
    [anon_sym_else] = ACTIONS(2056),
    [anon_sym_switch] = ACTIONS(2056),
    [anon_sym_case] = ACTIONS(2056),
    [anon_sym_default] = ACTIONS(2056),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_do] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2056),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_break] = ACTIONS(2056),
    [anon_sym_continue] = ACTIONS(2056),
    [anon_sym_goto] = ACTIONS(2056),
    [anon_sym___try] = ACTIONS(2056),
    [anon_sym___leave] = ACTIONS(2056),
    [anon_sym_not] = ACTIONS(2056),
    [anon_sym_compl] = ACTIONS(2056),
    [anon_sym_DASH_DASH] = ACTIONS(2058),
    [anon_sym_PLUS_PLUS] = ACTIONS(2058),
    [anon_sym_sizeof] = ACTIONS(2056),
    [anon_sym___alignof__] = ACTIONS(2056),
    [anon_sym___alignof] = ACTIONS(2056),
    [anon_sym__alignof] = ACTIONS(2056),
    [anon_sym_alignof] = ACTIONS(2056),
    [anon_sym__Alignof] = ACTIONS(2056),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2056),
    [anon_sym_asm] = ACTIONS(2056),
    [anon_sym___asm__] = ACTIONS(2056),
    [anon_sym___asm] = ACTIONS(2056),
    [sym_number_literal] = ACTIONS(2058),
    [anon_sym_L_SQUOTE] = ACTIONS(2058),
    [anon_sym_u_SQUOTE] = ACTIONS(2058),
    [anon_sym_U_SQUOTE] = ACTIONS(2058),
    [anon_sym_u8_SQUOTE] = ACTIONS(2058),
    [anon_sym_SQUOTE] = ACTIONS(2058),
    [anon_sym_L_DQUOTE] = ACTIONS(2058),
    [anon_sym_u_DQUOTE] = ACTIONS(2058),
    [anon_sym_U_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8_DQUOTE] = ACTIONS(2058),
    [anon_sym_DQUOTE] = ACTIONS(2058),
    [sym_true] = ACTIONS(2056),
    [sym_false] = ACTIONS(2056),
    [anon_sym_NULL] = ACTIONS(2056),
    [anon_sym_nullptr] = ACTIONS(2056),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2056),
    [anon_sym_decltype] = ACTIONS(2056),
    [anon_sym_explicit] = ACTIONS(2056),
    [anon_sym_typename] = ACTIONS(2056),
    [anon_sym_template] = ACTIONS(2056),
    [anon_sym_operator] = ACTIONS(2056),
    [anon_sym_try] = ACTIONS(2056),
    [anon_sym_delete] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2056),
    [anon_sym_namespace] = ACTIONS(2056),
    [anon_sym_using] = ACTIONS(2056),
    [anon_sym_static_assert] = ACTIONS(2056),
    [anon_sym_concept] = ACTIONS(2056),
    [anon_sym_co_return] = ACTIONS(2056),
    [anon_sym_co_yield] = ACTIONS(2056),
    [anon_sym_R_DQUOTE] = ACTIONS(2058),
    [anon_sym_LR_DQUOTE] = ACTIONS(2058),
    [anon_sym_uR_DQUOTE] = ACTIONS(2058),
    [anon_sym_UR_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2058),
    [anon_sym_co_await] = ACTIONS(2056),
    [anon_sym_new] = ACTIONS(2056),
    [anon_sym_requires] = ACTIONS(2056),
    [sym_this] = ACTIONS(2056),
    [anon_sym___launch_bounds__] = ACTIONS(2056),
  },
  [STATE(193)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [aux_sym_preproc_else_token1] = ACTIONS(1932),
    [aux_sym_preproc_elif_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(194)] = {
    [sym_identifier] = ACTIONS(2062),
    [aux_sym_preproc_include_token1] = ACTIONS(2062),
    [aux_sym_preproc_def_token1] = ACTIONS(2062),
    [aux_sym_preproc_if_token1] = ACTIONS(2062),
    [aux_sym_preproc_if_token2] = ACTIONS(2062),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2062),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2062),
    [aux_sym_preproc_else_token1] = ACTIONS(2062),
    [aux_sym_preproc_elif_token1] = ACTIONS(2062),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2062),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2062),
    [sym_preproc_directive] = ACTIONS(2062),
    [anon_sym_LPAREN2] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(2064),
    [anon_sym_TILDE] = ACTIONS(2064),
    [anon_sym_DASH] = ACTIONS(2062),
    [anon_sym_PLUS] = ACTIONS(2062),
    [anon_sym_STAR] = ACTIONS(2064),
    [anon_sym_AMP_AMP] = ACTIONS(2064),
    [anon_sym_AMP] = ACTIONS(2062),
    [anon_sym_SEMI] = ACTIONS(2064),
    [anon_sym___extension__] = ACTIONS(2062),
    [anon_sym_typedef] = ACTIONS(2062),
    [anon_sym___device__] = ACTIONS(2062),
    [anon_sym___host__] = ACTIONS(2062),
    [anon_sym___global__] = ACTIONS(2062),
    [anon_sym___forceinline__] = ACTIONS(2062),
    [anon_sym___noinline__] = ACTIONS(2062),
    [anon_sym_virtual] = ACTIONS(2062),
    [anon_sym_extern] = ACTIONS(2062),
    [anon_sym___attribute__] = ACTIONS(2062),
    [anon_sym___attribute] = ACTIONS(2062),
    [anon_sym_COLON_COLON] = ACTIONS(2064),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2064),
    [anon_sym___declspec] = ACTIONS(2062),
    [anon_sym___based] = ACTIONS(2062),
    [anon_sym___cdecl] = ACTIONS(2062),
    [anon_sym___clrcall] = ACTIONS(2062),
    [anon_sym___stdcall] = ACTIONS(2062),
    [anon_sym___fastcall] = ACTIONS(2062),
    [anon_sym___thiscall] = ACTIONS(2062),
    [anon_sym___vectorcall] = ACTIONS(2062),
    [anon_sym_LBRACE] = ACTIONS(2064),
    [anon_sym_signed] = ACTIONS(2062),
    [anon_sym_unsigned] = ACTIONS(2062),
    [anon_sym_long] = ACTIONS(2062),
    [anon_sym_short] = ACTIONS(2062),
    [anon_sym_LBRACK] = ACTIONS(2062),
    [anon_sym_static] = ACTIONS(2062),
    [anon_sym_register] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym___inline] = ACTIONS(2062),
    [anon_sym___inline__] = ACTIONS(2062),
    [anon_sym___forceinline] = ACTIONS(2062),
    [anon_sym_thread_local] = ACTIONS(2062),
    [anon_sym___thread] = ACTIONS(2062),
    [anon_sym_const] = ACTIONS(2062),
    [anon_sym_constexpr] = ACTIONS(2062),
    [anon_sym_volatile] = ACTIONS(2062),
    [anon_sym_restrict] = ACTIONS(2062),
    [anon_sym___restrict__] = ACTIONS(2062),
    [anon_sym__Atomic] = ACTIONS(2062),
    [anon_sym__Noreturn] = ACTIONS(2062),
    [anon_sym_noreturn] = ACTIONS(2062),
    [anon_sym__Nonnull] = ACTIONS(2062),
    [anon_sym_mutable] = ACTIONS(2062),
    [anon_sym_constinit] = ACTIONS(2062),
    [anon_sym_consteval] = ACTIONS(2062),
    [anon_sym___shared__] = ACTIONS(2062),
    [anon_sym___local__] = ACTIONS(2062),
    [anon_sym___constant__] = ACTIONS(2062),
    [anon_sym___managed__] = ACTIONS(2062),
    [anon_sym___grid_constant__] = ACTIONS(2062),
    [anon_sym_alignas] = ACTIONS(2062),
    [anon_sym__Alignas] = ACTIONS(2062),
    [sym_primitive_type] = ACTIONS(2062),
    [anon_sym_enum] = ACTIONS(2062),
    [anon_sym_class] = ACTIONS(2062),
    [anon_sym_struct] = ACTIONS(2062),
    [anon_sym_union] = ACTIONS(2062),
    [anon_sym_if] = ACTIONS(2062),
    [anon_sym_else] = ACTIONS(2062),
    [anon_sym_switch] = ACTIONS(2062),
    [anon_sym_case] = ACTIONS(2062),
    [anon_sym_default] = ACTIONS(2062),
    [anon_sym_while] = ACTIONS(2062),
    [anon_sym_do] = ACTIONS(2062),
    [anon_sym_for] = ACTIONS(2062),
    [anon_sym_return] = ACTIONS(2062),
    [anon_sym_break] = ACTIONS(2062),
    [anon_sym_continue] = ACTIONS(2062),
    [anon_sym_goto] = ACTIONS(2062),
    [anon_sym___try] = ACTIONS(2062),
    [anon_sym___leave] = ACTIONS(2062),
    [anon_sym_not] = ACTIONS(2062),
    [anon_sym_compl] = ACTIONS(2062),
    [anon_sym_DASH_DASH] = ACTIONS(2064),
    [anon_sym_PLUS_PLUS] = ACTIONS(2064),
    [anon_sym_sizeof] = ACTIONS(2062),
    [anon_sym___alignof__] = ACTIONS(2062),
    [anon_sym___alignof] = ACTIONS(2062),
    [anon_sym__alignof] = ACTIONS(2062),
    [anon_sym_alignof] = ACTIONS(2062),
    [anon_sym__Alignof] = ACTIONS(2062),
    [anon_sym_offsetof] = ACTIONS(2062),
    [anon_sym__Generic] = ACTIONS(2062),
    [anon_sym_asm] = ACTIONS(2062),
    [anon_sym___asm__] = ACTIONS(2062),
    [anon_sym___asm] = ACTIONS(2062),
    [sym_number_literal] = ACTIONS(2064),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2064),
    [anon_sym_u_DQUOTE] = ACTIONS(2064),
    [anon_sym_U_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8_DQUOTE] = ACTIONS(2064),
    [anon_sym_DQUOTE] = ACTIONS(2064),
    [sym_true] = ACTIONS(2062),
    [sym_false] = ACTIONS(2062),
    [anon_sym_NULL] = ACTIONS(2062),
    [anon_sym_nullptr] = ACTIONS(2062),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2062),
    [anon_sym_decltype] = ACTIONS(2062),
    [anon_sym_explicit] = ACTIONS(2062),
    [anon_sym_typename] = ACTIONS(2062),
    [anon_sym_template] = ACTIONS(2062),
    [anon_sym_operator] = ACTIONS(2062),
    [anon_sym_try] = ACTIONS(2062),
    [anon_sym_delete] = ACTIONS(2062),
    [anon_sym_throw] = ACTIONS(2062),
    [anon_sym_namespace] = ACTIONS(2062),
    [anon_sym_using] = ACTIONS(2062),
    [anon_sym_static_assert] = ACTIONS(2062),
    [anon_sym_concept] = ACTIONS(2062),
    [anon_sym_co_return] = ACTIONS(2062),
    [anon_sym_co_yield] = ACTIONS(2062),
    [anon_sym_R_DQUOTE] = ACTIONS(2064),
    [anon_sym_LR_DQUOTE] = ACTIONS(2064),
    [anon_sym_uR_DQUOTE] = ACTIONS(2064),
    [anon_sym_UR_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2064),
    [anon_sym_co_await] = ACTIONS(2062),
    [anon_sym_new] = ACTIONS(2062),
    [anon_sym_requires] = ACTIONS(2062),
    [sym_this] = ACTIONS(2062),
    [anon_sym___launch_bounds__] = ACTIONS(2062),
  },
  [STATE(195)] = {
    [sym_identifier] = ACTIONS(2066),
    [aux_sym_preproc_include_token1] = ACTIONS(2066),
    [aux_sym_preproc_def_token1] = ACTIONS(2066),
    [aux_sym_preproc_if_token1] = ACTIONS(2066),
    [aux_sym_preproc_if_token2] = ACTIONS(2066),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2066),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2066),
    [aux_sym_preproc_else_token1] = ACTIONS(2066),
    [aux_sym_preproc_elif_token1] = ACTIONS(2066),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2066),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2066),
    [sym_preproc_directive] = ACTIONS(2066),
    [anon_sym_LPAREN2] = ACTIONS(2068),
    [anon_sym_BANG] = ACTIONS(2068),
    [anon_sym_TILDE] = ACTIONS(2068),
    [anon_sym_DASH] = ACTIONS(2066),
    [anon_sym_PLUS] = ACTIONS(2066),
    [anon_sym_STAR] = ACTIONS(2068),
    [anon_sym_AMP_AMP] = ACTIONS(2068),
    [anon_sym_AMP] = ACTIONS(2066),
    [anon_sym_SEMI] = ACTIONS(2068),
    [anon_sym___extension__] = ACTIONS(2066),
    [anon_sym_typedef] = ACTIONS(2066),
    [anon_sym___device__] = ACTIONS(2066),
    [anon_sym___host__] = ACTIONS(2066),
    [anon_sym___global__] = ACTIONS(2066),
    [anon_sym___forceinline__] = ACTIONS(2066),
    [anon_sym___noinline__] = ACTIONS(2066),
    [anon_sym_virtual] = ACTIONS(2066),
    [anon_sym_extern] = ACTIONS(2066),
    [anon_sym___attribute__] = ACTIONS(2066),
    [anon_sym___attribute] = ACTIONS(2066),
    [anon_sym_COLON_COLON] = ACTIONS(2068),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2068),
    [anon_sym___declspec] = ACTIONS(2066),
    [anon_sym___based] = ACTIONS(2066),
    [anon_sym___cdecl] = ACTIONS(2066),
    [anon_sym___clrcall] = ACTIONS(2066),
    [anon_sym___stdcall] = ACTIONS(2066),
    [anon_sym___fastcall] = ACTIONS(2066),
    [anon_sym___thiscall] = ACTIONS(2066),
    [anon_sym___vectorcall] = ACTIONS(2066),
    [anon_sym_LBRACE] = ACTIONS(2068),
    [anon_sym_signed] = ACTIONS(2066),
    [anon_sym_unsigned] = ACTIONS(2066),
    [anon_sym_long] = ACTIONS(2066),
    [anon_sym_short] = ACTIONS(2066),
    [anon_sym_LBRACK] = ACTIONS(2066),
    [anon_sym_static] = ACTIONS(2066),
    [anon_sym_register] = ACTIONS(2066),
    [anon_sym_inline] = ACTIONS(2066),
    [anon_sym___inline] = ACTIONS(2066),
    [anon_sym___inline__] = ACTIONS(2066),
    [anon_sym___forceinline] = ACTIONS(2066),
    [anon_sym_thread_local] = ACTIONS(2066),
    [anon_sym___thread] = ACTIONS(2066),
    [anon_sym_const] = ACTIONS(2066),
    [anon_sym_constexpr] = ACTIONS(2066),
    [anon_sym_volatile] = ACTIONS(2066),
    [anon_sym_restrict] = ACTIONS(2066),
    [anon_sym___restrict__] = ACTIONS(2066),
    [anon_sym__Atomic] = ACTIONS(2066),
    [anon_sym__Noreturn] = ACTIONS(2066),
    [anon_sym_noreturn] = ACTIONS(2066),
    [anon_sym__Nonnull] = ACTIONS(2066),
    [anon_sym_mutable] = ACTIONS(2066),
    [anon_sym_constinit] = ACTIONS(2066),
    [anon_sym_consteval] = ACTIONS(2066),
    [anon_sym___shared__] = ACTIONS(2066),
    [anon_sym___local__] = ACTIONS(2066),
    [anon_sym___constant__] = ACTIONS(2066),
    [anon_sym___managed__] = ACTIONS(2066),
    [anon_sym___grid_constant__] = ACTIONS(2066),
    [anon_sym_alignas] = ACTIONS(2066),
    [anon_sym__Alignas] = ACTIONS(2066),
    [sym_primitive_type] = ACTIONS(2066),
    [anon_sym_enum] = ACTIONS(2066),
    [anon_sym_class] = ACTIONS(2066),
    [anon_sym_struct] = ACTIONS(2066),
    [anon_sym_union] = ACTIONS(2066),
    [anon_sym_if] = ACTIONS(2066),
    [anon_sym_else] = ACTIONS(2066),
    [anon_sym_switch] = ACTIONS(2066),
    [anon_sym_case] = ACTIONS(2066),
    [anon_sym_default] = ACTIONS(2066),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_do] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2066),
    [anon_sym_return] = ACTIONS(2066),
    [anon_sym_break] = ACTIONS(2066),
    [anon_sym_continue] = ACTIONS(2066),
    [anon_sym_goto] = ACTIONS(2066),
    [anon_sym___try] = ACTIONS(2066),
    [anon_sym___leave] = ACTIONS(2066),
    [anon_sym_not] = ACTIONS(2066),
    [anon_sym_compl] = ACTIONS(2066),
    [anon_sym_DASH_DASH] = ACTIONS(2068),
    [anon_sym_PLUS_PLUS] = ACTIONS(2068),
    [anon_sym_sizeof] = ACTIONS(2066),
    [anon_sym___alignof__] = ACTIONS(2066),
    [anon_sym___alignof] = ACTIONS(2066),
    [anon_sym__alignof] = ACTIONS(2066),
    [anon_sym_alignof] = ACTIONS(2066),
    [anon_sym__Alignof] = ACTIONS(2066),
    [anon_sym_offsetof] = ACTIONS(2066),
    [anon_sym__Generic] = ACTIONS(2066),
    [anon_sym_asm] = ACTIONS(2066),
    [anon_sym___asm__] = ACTIONS(2066),
    [anon_sym___asm] = ACTIONS(2066),
    [sym_number_literal] = ACTIONS(2068),
    [anon_sym_L_SQUOTE] = ACTIONS(2068),
    [anon_sym_u_SQUOTE] = ACTIONS(2068),
    [anon_sym_U_SQUOTE] = ACTIONS(2068),
    [anon_sym_u8_SQUOTE] = ACTIONS(2068),
    [anon_sym_SQUOTE] = ACTIONS(2068),
    [anon_sym_L_DQUOTE] = ACTIONS(2068),
    [anon_sym_u_DQUOTE] = ACTIONS(2068),
    [anon_sym_U_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8_DQUOTE] = ACTIONS(2068),
    [anon_sym_DQUOTE] = ACTIONS(2068),
    [sym_true] = ACTIONS(2066),
    [sym_false] = ACTIONS(2066),
    [anon_sym_NULL] = ACTIONS(2066),
    [anon_sym_nullptr] = ACTIONS(2066),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2066),
    [anon_sym_decltype] = ACTIONS(2066),
    [anon_sym_explicit] = ACTIONS(2066),
    [anon_sym_typename] = ACTIONS(2066),
    [anon_sym_template] = ACTIONS(2066),
    [anon_sym_operator] = ACTIONS(2066),
    [anon_sym_try] = ACTIONS(2066),
    [anon_sym_delete] = ACTIONS(2066),
    [anon_sym_throw] = ACTIONS(2066),
    [anon_sym_namespace] = ACTIONS(2066),
    [anon_sym_using] = ACTIONS(2066),
    [anon_sym_static_assert] = ACTIONS(2066),
    [anon_sym_concept] = ACTIONS(2066),
    [anon_sym_co_return] = ACTIONS(2066),
    [anon_sym_co_yield] = ACTIONS(2066),
    [anon_sym_R_DQUOTE] = ACTIONS(2068),
    [anon_sym_LR_DQUOTE] = ACTIONS(2068),
    [anon_sym_uR_DQUOTE] = ACTIONS(2068),
    [anon_sym_UR_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2068),
    [anon_sym_co_await] = ACTIONS(2066),
    [anon_sym_new] = ACTIONS(2066),
    [anon_sym_requires] = ACTIONS(2066),
    [sym_this] = ACTIONS(2066),
    [anon_sym___launch_bounds__] = ACTIONS(2066),
  },
  [STATE(196)] = {
    [sym_expression] = STATE(5114),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9441),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(2070),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(2073),
    [anon_sym___extension__] = ACTIONS(2075),
    [anon_sym___device__] = ACTIONS(2078),
    [anon_sym___host__] = ACTIONS(2078),
    [anon_sym___global__] = ACTIONS(2078),
    [anon_sym___forceinline__] = ACTIONS(2078),
    [anon_sym___noinline__] = ACTIONS(2078),
    [anon_sym_virtual] = ACTIONS(2078),
    [anon_sym_extern] = ACTIONS(2078),
    [anon_sym___attribute__] = ACTIONS(2078),
    [anon_sym___attribute] = ACTIONS(2078),
    [anon_sym_COLON_COLON] = ACTIONS(2080),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2083),
    [anon_sym___declspec] = ACTIONS(2078),
    [anon_sym_signed] = ACTIONS(2078),
    [anon_sym_unsigned] = ACTIONS(2078),
    [anon_sym_long] = ACTIONS(2078),
    [anon_sym_short] = ACTIONS(2078),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(2078),
    [anon_sym_register] = ACTIONS(2078),
    [anon_sym_inline] = ACTIONS(2078),
    [anon_sym___inline] = ACTIONS(2078),
    [anon_sym___inline__] = ACTIONS(2078),
    [anon_sym___forceinline] = ACTIONS(2078),
    [anon_sym_thread_local] = ACTIONS(2078),
    [anon_sym___thread] = ACTIONS(2078),
    [anon_sym_const] = ACTIONS(2078),
    [anon_sym_constexpr] = ACTIONS(2078),
    [anon_sym_volatile] = ACTIONS(2078),
    [anon_sym_restrict] = ACTIONS(2078),
    [anon_sym___restrict__] = ACTIONS(2078),
    [anon_sym__Atomic] = ACTIONS(2078),
    [anon_sym__Noreturn] = ACTIONS(2078),
    [anon_sym_noreturn] = ACTIONS(2078),
    [anon_sym__Nonnull] = ACTIONS(2078),
    [anon_sym_mutable] = ACTIONS(2078),
    [anon_sym_constinit] = ACTIONS(2078),
    [anon_sym_consteval] = ACTIONS(2078),
    [anon_sym___shared__] = ACTIONS(2078),
    [anon_sym___local__] = ACTIONS(2078),
    [anon_sym___constant__] = ACTIONS(2078),
    [anon_sym___managed__] = ACTIONS(2078),
    [anon_sym___grid_constant__] = ACTIONS(2078),
    [anon_sym_alignas] = ACTIONS(2078),
    [anon_sym__Alignas] = ACTIONS(2078),
    [sym_primitive_type] = ACTIONS(2085),
    [anon_sym_enum] = ACTIONS(2078),
    [anon_sym_class] = ACTIONS(2078),
    [anon_sym_struct] = ACTIONS(2078),
    [anon_sym_union] = ACTIONS(2078),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2078),
    [anon_sym_decltype] = ACTIONS(2088),
    [anon_sym_typename] = ACTIONS(2078),
    [anon_sym_template] = ACTIONS(2091),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(2078),
  },
  [STATE(197)] = {
    [sym_identifier] = ACTIONS(2094),
    [aux_sym_preproc_include_token1] = ACTIONS(2094),
    [aux_sym_preproc_def_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token2] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2094),
    [aux_sym_preproc_else_token1] = ACTIONS(2094),
    [aux_sym_preproc_elif_token1] = ACTIONS(2094),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2094),
    [sym_preproc_directive] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP_AMP] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2094),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym___device__] = ACTIONS(2094),
    [anon_sym___host__] = ACTIONS(2094),
    [anon_sym___global__] = ACTIONS(2094),
    [anon_sym___forceinline__] = ACTIONS(2094),
    [anon_sym___noinline__] = ACTIONS(2094),
    [anon_sym_virtual] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym___attribute] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym___based] = ACTIONS(2094),
    [anon_sym___cdecl] = ACTIONS(2094),
    [anon_sym___clrcall] = ACTIONS(2094),
    [anon_sym___stdcall] = ACTIONS(2094),
    [anon_sym___fastcall] = ACTIONS(2094),
    [anon_sym___thiscall] = ACTIONS(2094),
    [anon_sym___vectorcall] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym__Nonnull] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym___shared__] = ACTIONS(2094),
    [anon_sym___local__] = ACTIONS(2094),
    [anon_sym___constant__] = ACTIONS(2094),
    [anon_sym___managed__] = ACTIONS(2094),
    [anon_sym___grid_constant__] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_case] = ACTIONS(2094),
    [anon_sym_default] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [anon_sym___asm] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [anon_sym_explicit] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_operator] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_namespace] = ACTIONS(2094),
    [anon_sym_using] = ACTIONS(2094),
    [anon_sym_static_assert] = ACTIONS(2094),
    [anon_sym_concept] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym___launch_bounds__] = ACTIONS(2094),
  },
  [STATE(198)] = {
    [sym_identifier] = ACTIONS(2098),
    [aux_sym_preproc_include_token1] = ACTIONS(2098),
    [aux_sym_preproc_def_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token2] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2098),
    [aux_sym_preproc_else_token1] = ACTIONS(2098),
    [aux_sym_preproc_elif_token1] = ACTIONS(2098),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2098),
    [sym_preproc_directive] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP_AMP] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2098),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym___device__] = ACTIONS(2098),
    [anon_sym___host__] = ACTIONS(2098),
    [anon_sym___global__] = ACTIONS(2098),
    [anon_sym___forceinline__] = ACTIONS(2098),
    [anon_sym___noinline__] = ACTIONS(2098),
    [anon_sym_virtual] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym___attribute] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym___based] = ACTIONS(2098),
    [anon_sym___cdecl] = ACTIONS(2098),
    [anon_sym___clrcall] = ACTIONS(2098),
    [anon_sym___stdcall] = ACTIONS(2098),
    [anon_sym___fastcall] = ACTIONS(2098),
    [anon_sym___thiscall] = ACTIONS(2098),
    [anon_sym___vectorcall] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym__Nonnull] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym___shared__] = ACTIONS(2098),
    [anon_sym___local__] = ACTIONS(2098),
    [anon_sym___constant__] = ACTIONS(2098),
    [anon_sym___managed__] = ACTIONS(2098),
    [anon_sym___grid_constant__] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_case] = ACTIONS(2098),
    [anon_sym_default] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [anon_sym___asm] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [anon_sym_explicit] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_operator] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_namespace] = ACTIONS(2098),
    [anon_sym_using] = ACTIONS(2098),
    [anon_sym_static_assert] = ACTIONS(2098),
    [anon_sym_concept] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym___launch_bounds__] = ACTIONS(2098),
  },
  [STATE(199)] = {
    [sym_expression] = STATE(5122),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9398),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(2102),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(2105),
    [anon_sym___extension__] = ACTIONS(2107),
    [anon_sym___device__] = ACTIONS(2110),
    [anon_sym___host__] = ACTIONS(2110),
    [anon_sym___global__] = ACTIONS(2110),
    [anon_sym___forceinline__] = ACTIONS(2110),
    [anon_sym___noinline__] = ACTIONS(2110),
    [anon_sym_virtual] = ACTIONS(2110),
    [anon_sym_extern] = ACTIONS(2110),
    [anon_sym___attribute__] = ACTIONS(2110),
    [anon_sym___attribute] = ACTIONS(2110),
    [anon_sym_COLON_COLON] = ACTIONS(2112),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2115),
    [anon_sym___declspec] = ACTIONS(2110),
    [anon_sym_signed] = ACTIONS(2110),
    [anon_sym_unsigned] = ACTIONS(2110),
    [anon_sym_long] = ACTIONS(2110),
    [anon_sym_short] = ACTIONS(2110),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(2110),
    [anon_sym_register] = ACTIONS(2110),
    [anon_sym_inline] = ACTIONS(2110),
    [anon_sym___inline] = ACTIONS(2110),
    [anon_sym___inline__] = ACTIONS(2110),
    [anon_sym___forceinline] = ACTIONS(2110),
    [anon_sym_thread_local] = ACTIONS(2110),
    [anon_sym___thread] = ACTIONS(2110),
    [anon_sym_const] = ACTIONS(2110),
    [anon_sym_constexpr] = ACTIONS(2110),
    [anon_sym_volatile] = ACTIONS(2110),
    [anon_sym_restrict] = ACTIONS(2110),
    [anon_sym___restrict__] = ACTIONS(2110),
    [anon_sym__Atomic] = ACTIONS(2110),
    [anon_sym__Noreturn] = ACTIONS(2110),
    [anon_sym_noreturn] = ACTIONS(2110),
    [anon_sym__Nonnull] = ACTIONS(2110),
    [anon_sym_mutable] = ACTIONS(2110),
    [anon_sym_constinit] = ACTIONS(2110),
    [anon_sym_consteval] = ACTIONS(2110),
    [anon_sym___shared__] = ACTIONS(2110),
    [anon_sym___local__] = ACTIONS(2110),
    [anon_sym___constant__] = ACTIONS(2110),
    [anon_sym___managed__] = ACTIONS(2110),
    [anon_sym___grid_constant__] = ACTIONS(2110),
    [anon_sym_alignas] = ACTIONS(2110),
    [anon_sym__Alignas] = ACTIONS(2110),
    [sym_primitive_type] = ACTIONS(2117),
    [anon_sym_enum] = ACTIONS(2110),
    [anon_sym_class] = ACTIONS(2110),
    [anon_sym_struct] = ACTIONS(2110),
    [anon_sym_union] = ACTIONS(2110),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2110),
    [anon_sym_decltype] = ACTIONS(2120),
    [anon_sym_typename] = ACTIONS(2110),
    [anon_sym_template] = ACTIONS(2123),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(2110),
  },
  [STATE(200)] = {
    [sym_identifier] = ACTIONS(2078),
    [aux_sym_preproc_include_token1] = ACTIONS(2078),
    [aux_sym_preproc_def_token1] = ACTIONS(2078),
    [aux_sym_preproc_if_token1] = ACTIONS(2078),
    [aux_sym_preproc_if_token2] = ACTIONS(2078),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2078),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2078),
    [aux_sym_preproc_else_token1] = ACTIONS(2078),
    [aux_sym_preproc_elif_token1] = ACTIONS(2078),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2078),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2078),
    [sym_preproc_directive] = ACTIONS(2078),
    [anon_sym_LPAREN2] = ACTIONS(2083),
    [anon_sym_BANG] = ACTIONS(2083),
    [anon_sym_TILDE] = ACTIONS(2083),
    [anon_sym_DASH] = ACTIONS(2078),
    [anon_sym_PLUS] = ACTIONS(2078),
    [anon_sym_STAR] = ACTIONS(2083),
    [anon_sym_AMP_AMP] = ACTIONS(2083),
    [anon_sym_AMP] = ACTIONS(2078),
    [anon_sym_SEMI] = ACTIONS(2083),
    [anon_sym___extension__] = ACTIONS(2078),
    [anon_sym_typedef] = ACTIONS(2078),
    [anon_sym___device__] = ACTIONS(2078),
    [anon_sym___host__] = ACTIONS(2078),
    [anon_sym___global__] = ACTIONS(2078),
    [anon_sym___forceinline__] = ACTIONS(2078),
    [anon_sym___noinline__] = ACTIONS(2078),
    [anon_sym_virtual] = ACTIONS(2078),
    [anon_sym_extern] = ACTIONS(2078),
    [anon_sym___attribute__] = ACTIONS(2078),
    [anon_sym___attribute] = ACTIONS(2078),
    [anon_sym_COLON_COLON] = ACTIONS(2083),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2083),
    [anon_sym___declspec] = ACTIONS(2078),
    [anon_sym___based] = ACTIONS(2078),
    [anon_sym___cdecl] = ACTIONS(2078),
    [anon_sym___clrcall] = ACTIONS(2078),
    [anon_sym___stdcall] = ACTIONS(2078),
    [anon_sym___fastcall] = ACTIONS(2078),
    [anon_sym___thiscall] = ACTIONS(2078),
    [anon_sym___vectorcall] = ACTIONS(2078),
    [anon_sym_LBRACE] = ACTIONS(2083),
    [anon_sym_signed] = ACTIONS(2078),
    [anon_sym_unsigned] = ACTIONS(2078),
    [anon_sym_long] = ACTIONS(2078),
    [anon_sym_short] = ACTIONS(2078),
    [anon_sym_LBRACK] = ACTIONS(2078),
    [anon_sym_static] = ACTIONS(2078),
    [anon_sym_register] = ACTIONS(2078),
    [anon_sym_inline] = ACTIONS(2078),
    [anon_sym___inline] = ACTIONS(2078),
    [anon_sym___inline__] = ACTIONS(2078),
    [anon_sym___forceinline] = ACTIONS(2078),
    [anon_sym_thread_local] = ACTIONS(2078),
    [anon_sym___thread] = ACTIONS(2078),
    [anon_sym_const] = ACTIONS(2078),
    [anon_sym_constexpr] = ACTIONS(2078),
    [anon_sym_volatile] = ACTIONS(2078),
    [anon_sym_restrict] = ACTIONS(2078),
    [anon_sym___restrict__] = ACTIONS(2078),
    [anon_sym__Atomic] = ACTIONS(2078),
    [anon_sym__Noreturn] = ACTIONS(2078),
    [anon_sym_noreturn] = ACTIONS(2078),
    [anon_sym__Nonnull] = ACTIONS(2078),
    [anon_sym_mutable] = ACTIONS(2078),
    [anon_sym_constinit] = ACTIONS(2078),
    [anon_sym_consteval] = ACTIONS(2078),
    [anon_sym___shared__] = ACTIONS(2078),
    [anon_sym___local__] = ACTIONS(2078),
    [anon_sym___constant__] = ACTIONS(2078),
    [anon_sym___managed__] = ACTIONS(2078),
    [anon_sym___grid_constant__] = ACTIONS(2078),
    [anon_sym_alignas] = ACTIONS(2078),
    [anon_sym__Alignas] = ACTIONS(2078),
    [sym_primitive_type] = ACTIONS(2078),
    [anon_sym_enum] = ACTIONS(2078),
    [anon_sym_class] = ACTIONS(2078),
    [anon_sym_struct] = ACTIONS(2078),
    [anon_sym_union] = ACTIONS(2078),
    [anon_sym_if] = ACTIONS(2078),
    [anon_sym_else] = ACTIONS(2078),
    [anon_sym_switch] = ACTIONS(2078),
    [anon_sym_case] = ACTIONS(2078),
    [anon_sym_default] = ACTIONS(2078),
    [anon_sym_while] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(2078),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_return] = ACTIONS(2078),
    [anon_sym_break] = ACTIONS(2078),
    [anon_sym_continue] = ACTIONS(2078),
    [anon_sym_goto] = ACTIONS(2078),
    [anon_sym___try] = ACTIONS(2078),
    [anon_sym___leave] = ACTIONS(2078),
    [anon_sym_not] = ACTIONS(2078),
    [anon_sym_compl] = ACTIONS(2078),
    [anon_sym_DASH_DASH] = ACTIONS(2083),
    [anon_sym_PLUS_PLUS] = ACTIONS(2083),
    [anon_sym_sizeof] = ACTIONS(2078),
    [anon_sym___alignof__] = ACTIONS(2078),
    [anon_sym___alignof] = ACTIONS(2078),
    [anon_sym__alignof] = ACTIONS(2078),
    [anon_sym_alignof] = ACTIONS(2078),
    [anon_sym__Alignof] = ACTIONS(2078),
    [anon_sym_offsetof] = ACTIONS(2078),
    [anon_sym__Generic] = ACTIONS(2078),
    [anon_sym_asm] = ACTIONS(2078),
    [anon_sym___asm__] = ACTIONS(2078),
    [anon_sym___asm] = ACTIONS(2078),
    [sym_number_literal] = ACTIONS(2083),
    [anon_sym_L_SQUOTE] = ACTIONS(2083),
    [anon_sym_u_SQUOTE] = ACTIONS(2083),
    [anon_sym_U_SQUOTE] = ACTIONS(2083),
    [anon_sym_u8_SQUOTE] = ACTIONS(2083),
    [anon_sym_SQUOTE] = ACTIONS(2083),
    [anon_sym_L_DQUOTE] = ACTIONS(2083),
    [anon_sym_u_DQUOTE] = ACTIONS(2083),
    [anon_sym_U_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8_DQUOTE] = ACTIONS(2083),
    [anon_sym_DQUOTE] = ACTIONS(2083),
    [sym_true] = ACTIONS(2078),
    [sym_false] = ACTIONS(2078),
    [anon_sym_NULL] = ACTIONS(2078),
    [anon_sym_nullptr] = ACTIONS(2078),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2078),
    [anon_sym_decltype] = ACTIONS(2078),
    [anon_sym_explicit] = ACTIONS(2078),
    [anon_sym_typename] = ACTIONS(2078),
    [anon_sym_template] = ACTIONS(2078),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2078),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_namespace] = ACTIONS(2078),
    [anon_sym_using] = ACTIONS(2078),
    [anon_sym_static_assert] = ACTIONS(2078),
    [anon_sym_concept] = ACTIONS(2078),
    [anon_sym_co_return] = ACTIONS(2078),
    [anon_sym_co_yield] = ACTIONS(2078),
    [anon_sym_R_DQUOTE] = ACTIONS(2083),
    [anon_sym_LR_DQUOTE] = ACTIONS(2083),
    [anon_sym_uR_DQUOTE] = ACTIONS(2083),
    [anon_sym_UR_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2083),
    [anon_sym_co_await] = ACTIONS(2078),
    [anon_sym_new] = ACTIONS(2078),
    [anon_sym_requires] = ACTIONS(2078),
    [sym_this] = ACTIONS(2078),
    [anon_sym___launch_bounds__] = ACTIONS(2078),
  },
  [STATE(201)] = {
    [sym_identifier] = ACTIONS(2126),
    [aux_sym_preproc_include_token1] = ACTIONS(2126),
    [aux_sym_preproc_def_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token2] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2126),
    [aux_sym_preproc_else_token1] = ACTIONS(2126),
    [aux_sym_preproc_elif_token1] = ACTIONS(2126),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2126),
    [sym_preproc_directive] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP_AMP] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2126),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym___device__] = ACTIONS(2126),
    [anon_sym___host__] = ACTIONS(2126),
    [anon_sym___global__] = ACTIONS(2126),
    [anon_sym___forceinline__] = ACTIONS(2126),
    [anon_sym___noinline__] = ACTIONS(2126),
    [anon_sym_virtual] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym___attribute] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym___based] = ACTIONS(2126),
    [anon_sym___cdecl] = ACTIONS(2126),
    [anon_sym___clrcall] = ACTIONS(2126),
    [anon_sym___stdcall] = ACTIONS(2126),
    [anon_sym___fastcall] = ACTIONS(2126),
    [anon_sym___thiscall] = ACTIONS(2126),
    [anon_sym___vectorcall] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym__Nonnull] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym___shared__] = ACTIONS(2126),
    [anon_sym___local__] = ACTIONS(2126),
    [anon_sym___constant__] = ACTIONS(2126),
    [anon_sym___managed__] = ACTIONS(2126),
    [anon_sym___grid_constant__] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_case] = ACTIONS(2126),
    [anon_sym_default] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [anon_sym___asm] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [anon_sym_explicit] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_operator] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_namespace] = ACTIONS(2126),
    [anon_sym_using] = ACTIONS(2126),
    [anon_sym_static_assert] = ACTIONS(2126),
    [anon_sym_concept] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym___launch_bounds__] = ACTIONS(2126),
  },
  [STATE(202)] = {
    [sym_identifier] = ACTIONS(2130),
    [aux_sym_preproc_include_token1] = ACTIONS(2130),
    [aux_sym_preproc_def_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token2] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2130),
    [aux_sym_preproc_else_token1] = ACTIONS(2130),
    [aux_sym_preproc_elif_token1] = ACTIONS(2130),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2130),
    [sym_preproc_directive] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP_AMP] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2130),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym___device__] = ACTIONS(2130),
    [anon_sym___host__] = ACTIONS(2130),
    [anon_sym___global__] = ACTIONS(2130),
    [anon_sym___forceinline__] = ACTIONS(2130),
    [anon_sym___noinline__] = ACTIONS(2130),
    [anon_sym_virtual] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym___attribute] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym___based] = ACTIONS(2130),
    [anon_sym___cdecl] = ACTIONS(2130),
    [anon_sym___clrcall] = ACTIONS(2130),
    [anon_sym___stdcall] = ACTIONS(2130),
    [anon_sym___fastcall] = ACTIONS(2130),
    [anon_sym___thiscall] = ACTIONS(2130),
    [anon_sym___vectorcall] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym__Nonnull] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym___shared__] = ACTIONS(2130),
    [anon_sym___local__] = ACTIONS(2130),
    [anon_sym___constant__] = ACTIONS(2130),
    [anon_sym___managed__] = ACTIONS(2130),
    [anon_sym___grid_constant__] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_case] = ACTIONS(2130),
    [anon_sym_default] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [anon_sym___asm] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [anon_sym_explicit] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_operator] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_namespace] = ACTIONS(2130),
    [anon_sym_using] = ACTIONS(2130),
    [anon_sym_static_assert] = ACTIONS(2130),
    [anon_sym_concept] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym___launch_bounds__] = ACTIONS(2130),
  },
  [STATE(203)] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_include_token1] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token2] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [aux_sym_preproc_else_token1] = ACTIONS(2134),
    [aux_sym_preproc_elif_token1] = ACTIONS(2134),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym___device__] = ACTIONS(2134),
    [anon_sym___host__] = ACTIONS(2134),
    [anon_sym___global__] = ACTIONS(2134),
    [anon_sym___forceinline__] = ACTIONS(2134),
    [anon_sym___noinline__] = ACTIONS(2134),
    [anon_sym_virtual] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym___attribute] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym___cdecl] = ACTIONS(2134),
    [anon_sym___clrcall] = ACTIONS(2134),
    [anon_sym___stdcall] = ACTIONS(2134),
    [anon_sym___fastcall] = ACTIONS(2134),
    [anon_sym___thiscall] = ACTIONS(2134),
    [anon_sym___vectorcall] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym__Nonnull] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym___shared__] = ACTIONS(2134),
    [anon_sym___local__] = ACTIONS(2134),
    [anon_sym___constant__] = ACTIONS(2134),
    [anon_sym___managed__] = ACTIONS(2134),
    [anon_sym___grid_constant__] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_case] = ACTIONS(2134),
    [anon_sym_default] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [anon_sym___asm] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_namespace] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_concept] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym___launch_bounds__] = ACTIONS(2134),
  },
  [STATE(204)] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_include_token1] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token2] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [aux_sym_preproc_else_token1] = ACTIONS(2138),
    [aux_sym_preproc_elif_token1] = ACTIONS(2138),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym___device__] = ACTIONS(2138),
    [anon_sym___host__] = ACTIONS(2138),
    [anon_sym___global__] = ACTIONS(2138),
    [anon_sym___forceinline__] = ACTIONS(2138),
    [anon_sym___noinline__] = ACTIONS(2138),
    [anon_sym_virtual] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym___attribute] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym___cdecl] = ACTIONS(2138),
    [anon_sym___clrcall] = ACTIONS(2138),
    [anon_sym___stdcall] = ACTIONS(2138),
    [anon_sym___fastcall] = ACTIONS(2138),
    [anon_sym___thiscall] = ACTIONS(2138),
    [anon_sym___vectorcall] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym__Nonnull] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym___shared__] = ACTIONS(2138),
    [anon_sym___local__] = ACTIONS(2138),
    [anon_sym___constant__] = ACTIONS(2138),
    [anon_sym___managed__] = ACTIONS(2138),
    [anon_sym___grid_constant__] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_case] = ACTIONS(2138),
    [anon_sym_default] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [anon_sym___asm] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_namespace] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_concept] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym___launch_bounds__] = ACTIONS(2138),
  },
  [STATE(205)] = {
    [sym_identifier] = ACTIONS(2142),
    [aux_sym_preproc_include_token1] = ACTIONS(2142),
    [aux_sym_preproc_def_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token2] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2142),
    [aux_sym_preproc_else_token1] = ACTIONS(2142),
    [aux_sym_preproc_elif_token1] = ACTIONS(2142),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2142),
    [sym_preproc_directive] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym___device__] = ACTIONS(2142),
    [anon_sym___host__] = ACTIONS(2142),
    [anon_sym___global__] = ACTIONS(2142),
    [anon_sym___forceinline__] = ACTIONS(2142),
    [anon_sym___noinline__] = ACTIONS(2142),
    [anon_sym_virtual] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym___attribute] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym__Nonnull] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym___shared__] = ACTIONS(2142),
    [anon_sym___local__] = ACTIONS(2142),
    [anon_sym___constant__] = ACTIONS(2142),
    [anon_sym___managed__] = ACTIONS(2142),
    [anon_sym___grid_constant__] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_case] = ACTIONS(2142),
    [anon_sym_default] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [anon_sym___asm] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [anon_sym_explicit] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_namespace] = ACTIONS(2142),
    [anon_sym_using] = ACTIONS(2142),
    [anon_sym_static_assert] = ACTIONS(2142),
    [anon_sym_concept] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym___launch_bounds__] = ACTIONS(2142),
  },
  [STATE(206)] = {
    [sym_identifier] = ACTIONS(2146),
    [aux_sym_preproc_include_token1] = ACTIONS(2146),
    [aux_sym_preproc_def_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token2] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2146),
    [aux_sym_preproc_else_token1] = ACTIONS(2146),
    [aux_sym_preproc_elif_token1] = ACTIONS(2146),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2146),
    [sym_preproc_directive] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP_AMP] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2146),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym___device__] = ACTIONS(2146),
    [anon_sym___host__] = ACTIONS(2146),
    [anon_sym___global__] = ACTIONS(2146),
    [anon_sym___forceinline__] = ACTIONS(2146),
    [anon_sym___noinline__] = ACTIONS(2146),
    [anon_sym_virtual] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym___attribute] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym___based] = ACTIONS(2146),
    [anon_sym___cdecl] = ACTIONS(2146),
    [anon_sym___clrcall] = ACTIONS(2146),
    [anon_sym___stdcall] = ACTIONS(2146),
    [anon_sym___fastcall] = ACTIONS(2146),
    [anon_sym___thiscall] = ACTIONS(2146),
    [anon_sym___vectorcall] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym__Nonnull] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym___shared__] = ACTIONS(2146),
    [anon_sym___local__] = ACTIONS(2146),
    [anon_sym___constant__] = ACTIONS(2146),
    [anon_sym___managed__] = ACTIONS(2146),
    [anon_sym___grid_constant__] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_case] = ACTIONS(2146),
    [anon_sym_default] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [anon_sym___asm] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [anon_sym_explicit] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_operator] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_namespace] = ACTIONS(2146),
    [anon_sym_using] = ACTIONS(2146),
    [anon_sym_static_assert] = ACTIONS(2146),
    [anon_sym_concept] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym___launch_bounds__] = ACTIONS(2146),
  },
  [STATE(207)] = {
    [sym_identifier] = ACTIONS(2150),
    [aux_sym_preproc_include_token1] = ACTIONS(2150),
    [aux_sym_preproc_def_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token2] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2150),
    [aux_sym_preproc_else_token1] = ACTIONS(2150),
    [aux_sym_preproc_elif_token1] = ACTIONS(2150),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2150),
    [sym_preproc_directive] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP_AMP] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2150),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym___device__] = ACTIONS(2150),
    [anon_sym___host__] = ACTIONS(2150),
    [anon_sym___global__] = ACTIONS(2150),
    [anon_sym___forceinline__] = ACTIONS(2150),
    [anon_sym___noinline__] = ACTIONS(2150),
    [anon_sym_virtual] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym___attribute] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym___based] = ACTIONS(2150),
    [anon_sym___cdecl] = ACTIONS(2150),
    [anon_sym___clrcall] = ACTIONS(2150),
    [anon_sym___stdcall] = ACTIONS(2150),
    [anon_sym___fastcall] = ACTIONS(2150),
    [anon_sym___thiscall] = ACTIONS(2150),
    [anon_sym___vectorcall] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym__Nonnull] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym___shared__] = ACTIONS(2150),
    [anon_sym___local__] = ACTIONS(2150),
    [anon_sym___constant__] = ACTIONS(2150),
    [anon_sym___managed__] = ACTIONS(2150),
    [anon_sym___grid_constant__] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_case] = ACTIONS(2150),
    [anon_sym_default] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [anon_sym___asm] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [anon_sym_explicit] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_operator] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_namespace] = ACTIONS(2150),
    [anon_sym_using] = ACTIONS(2150),
    [anon_sym_static_assert] = ACTIONS(2150),
    [anon_sym_concept] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym___launch_bounds__] = ACTIONS(2150),
  },
  [STATE(208)] = {
    [sym_identifier] = ACTIONS(2154),
    [aux_sym_preproc_include_token1] = ACTIONS(2154),
    [aux_sym_preproc_def_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token2] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2154),
    [aux_sym_preproc_else_token1] = ACTIONS(2154),
    [aux_sym_preproc_elif_token1] = ACTIONS(2154),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2154),
    [sym_preproc_directive] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP_AMP] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2154),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym___device__] = ACTIONS(2154),
    [anon_sym___host__] = ACTIONS(2154),
    [anon_sym___global__] = ACTIONS(2154),
    [anon_sym___forceinline__] = ACTIONS(2154),
    [anon_sym___noinline__] = ACTIONS(2154),
    [anon_sym_virtual] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym___attribute] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym___based] = ACTIONS(2154),
    [anon_sym___cdecl] = ACTIONS(2154),
    [anon_sym___clrcall] = ACTIONS(2154),
    [anon_sym___stdcall] = ACTIONS(2154),
    [anon_sym___fastcall] = ACTIONS(2154),
    [anon_sym___thiscall] = ACTIONS(2154),
    [anon_sym___vectorcall] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym__Nonnull] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym___shared__] = ACTIONS(2154),
    [anon_sym___local__] = ACTIONS(2154),
    [anon_sym___constant__] = ACTIONS(2154),
    [anon_sym___managed__] = ACTIONS(2154),
    [anon_sym___grid_constant__] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_case] = ACTIONS(2154),
    [anon_sym_default] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [anon_sym___asm] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [anon_sym_explicit] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_operator] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_namespace] = ACTIONS(2154),
    [anon_sym_using] = ACTIONS(2154),
    [anon_sym_static_assert] = ACTIONS(2154),
    [anon_sym_concept] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym___launch_bounds__] = ACTIONS(2154),
  },
  [STATE(209)] = {
    [sym_identifier] = ACTIONS(2158),
    [aux_sym_preproc_include_token1] = ACTIONS(2158),
    [aux_sym_preproc_def_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token2] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2158),
    [aux_sym_preproc_else_token1] = ACTIONS(2158),
    [aux_sym_preproc_elif_token1] = ACTIONS(2158),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2158),
    [sym_preproc_directive] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP_AMP] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2158),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym___device__] = ACTIONS(2158),
    [anon_sym___host__] = ACTIONS(2158),
    [anon_sym___global__] = ACTIONS(2158),
    [anon_sym___forceinline__] = ACTIONS(2158),
    [anon_sym___noinline__] = ACTIONS(2158),
    [anon_sym_virtual] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym___attribute] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym___based] = ACTIONS(2158),
    [anon_sym___cdecl] = ACTIONS(2158),
    [anon_sym___clrcall] = ACTIONS(2158),
    [anon_sym___stdcall] = ACTIONS(2158),
    [anon_sym___fastcall] = ACTIONS(2158),
    [anon_sym___thiscall] = ACTIONS(2158),
    [anon_sym___vectorcall] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym__Nonnull] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym___shared__] = ACTIONS(2158),
    [anon_sym___local__] = ACTIONS(2158),
    [anon_sym___constant__] = ACTIONS(2158),
    [anon_sym___managed__] = ACTIONS(2158),
    [anon_sym___grid_constant__] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_case] = ACTIONS(2158),
    [anon_sym_default] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [anon_sym___asm] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [anon_sym_explicit] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_operator] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_namespace] = ACTIONS(2158),
    [anon_sym_using] = ACTIONS(2158),
    [anon_sym_static_assert] = ACTIONS(2158),
    [anon_sym_concept] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym___launch_bounds__] = ACTIONS(2158),
  },
  [STATE(210)] = {
    [sym_identifier] = ACTIONS(2162),
    [aux_sym_preproc_include_token1] = ACTIONS(2162),
    [aux_sym_preproc_def_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token2] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2162),
    [aux_sym_preproc_else_token1] = ACTIONS(2162),
    [aux_sym_preproc_elif_token1] = ACTIONS(2162),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2162),
    [sym_preproc_directive] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP_AMP] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2162),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym___device__] = ACTIONS(2162),
    [anon_sym___host__] = ACTIONS(2162),
    [anon_sym___global__] = ACTIONS(2162),
    [anon_sym___forceinline__] = ACTIONS(2162),
    [anon_sym___noinline__] = ACTIONS(2162),
    [anon_sym_virtual] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym___attribute] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym___based] = ACTIONS(2162),
    [anon_sym___cdecl] = ACTIONS(2162),
    [anon_sym___clrcall] = ACTIONS(2162),
    [anon_sym___stdcall] = ACTIONS(2162),
    [anon_sym___fastcall] = ACTIONS(2162),
    [anon_sym___thiscall] = ACTIONS(2162),
    [anon_sym___vectorcall] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym__Nonnull] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym___shared__] = ACTIONS(2162),
    [anon_sym___local__] = ACTIONS(2162),
    [anon_sym___constant__] = ACTIONS(2162),
    [anon_sym___managed__] = ACTIONS(2162),
    [anon_sym___grid_constant__] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_case] = ACTIONS(2162),
    [anon_sym_default] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [anon_sym___asm] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [anon_sym_explicit] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_operator] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_namespace] = ACTIONS(2162),
    [anon_sym_using] = ACTIONS(2162),
    [anon_sym_static_assert] = ACTIONS(2162),
    [anon_sym_concept] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym___launch_bounds__] = ACTIONS(2162),
  },
  [STATE(211)] = {
    [sym_identifier] = ACTIONS(2166),
    [aux_sym_preproc_include_token1] = ACTIONS(2166),
    [aux_sym_preproc_def_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token2] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2166),
    [aux_sym_preproc_else_token1] = ACTIONS(2166),
    [aux_sym_preproc_elif_token1] = ACTIONS(2166),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2166),
    [sym_preproc_directive] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP_AMP] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2166),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym___device__] = ACTIONS(2166),
    [anon_sym___host__] = ACTIONS(2166),
    [anon_sym___global__] = ACTIONS(2166),
    [anon_sym___forceinline__] = ACTIONS(2166),
    [anon_sym___noinline__] = ACTIONS(2166),
    [anon_sym_virtual] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym___attribute] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym___based] = ACTIONS(2166),
    [anon_sym___cdecl] = ACTIONS(2166),
    [anon_sym___clrcall] = ACTIONS(2166),
    [anon_sym___stdcall] = ACTIONS(2166),
    [anon_sym___fastcall] = ACTIONS(2166),
    [anon_sym___thiscall] = ACTIONS(2166),
    [anon_sym___vectorcall] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym__Nonnull] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym___shared__] = ACTIONS(2166),
    [anon_sym___local__] = ACTIONS(2166),
    [anon_sym___constant__] = ACTIONS(2166),
    [anon_sym___managed__] = ACTIONS(2166),
    [anon_sym___grid_constant__] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym_default] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [anon_sym___asm] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [anon_sym_explicit] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_operator] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_namespace] = ACTIONS(2166),
    [anon_sym_using] = ACTIONS(2166),
    [anon_sym_static_assert] = ACTIONS(2166),
    [anon_sym_concept] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym___launch_bounds__] = ACTIONS(2166),
  },
  [STATE(212)] = {
    [sym_identifier] = ACTIONS(2170),
    [aux_sym_preproc_include_token1] = ACTIONS(2170),
    [aux_sym_preproc_def_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token2] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2170),
    [aux_sym_preproc_else_token1] = ACTIONS(2170),
    [aux_sym_preproc_elif_token1] = ACTIONS(2170),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2170),
    [sym_preproc_directive] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP_AMP] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2170),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym___device__] = ACTIONS(2170),
    [anon_sym___host__] = ACTIONS(2170),
    [anon_sym___global__] = ACTIONS(2170),
    [anon_sym___forceinline__] = ACTIONS(2170),
    [anon_sym___noinline__] = ACTIONS(2170),
    [anon_sym_virtual] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym___attribute] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym___based] = ACTIONS(2170),
    [anon_sym___cdecl] = ACTIONS(2170),
    [anon_sym___clrcall] = ACTIONS(2170),
    [anon_sym___stdcall] = ACTIONS(2170),
    [anon_sym___fastcall] = ACTIONS(2170),
    [anon_sym___thiscall] = ACTIONS(2170),
    [anon_sym___vectorcall] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym__Nonnull] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym___shared__] = ACTIONS(2170),
    [anon_sym___local__] = ACTIONS(2170),
    [anon_sym___constant__] = ACTIONS(2170),
    [anon_sym___managed__] = ACTIONS(2170),
    [anon_sym___grid_constant__] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_case] = ACTIONS(2170),
    [anon_sym_default] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [anon_sym___asm] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [anon_sym_explicit] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_operator] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_namespace] = ACTIONS(2170),
    [anon_sym_using] = ACTIONS(2170),
    [anon_sym_static_assert] = ACTIONS(2170),
    [anon_sym_concept] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym___launch_bounds__] = ACTIONS(2170),
  },
  [STATE(213)] = {
    [sym_identifier] = ACTIONS(2174),
    [aux_sym_preproc_include_token1] = ACTIONS(2174),
    [aux_sym_preproc_def_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token2] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2174),
    [aux_sym_preproc_else_token1] = ACTIONS(2174),
    [aux_sym_preproc_elif_token1] = ACTIONS(2174),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2174),
    [sym_preproc_directive] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP_AMP] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2174),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym___device__] = ACTIONS(2174),
    [anon_sym___host__] = ACTIONS(2174),
    [anon_sym___global__] = ACTIONS(2174),
    [anon_sym___forceinline__] = ACTIONS(2174),
    [anon_sym___noinline__] = ACTIONS(2174),
    [anon_sym_virtual] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym___attribute] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym___based] = ACTIONS(2174),
    [anon_sym___cdecl] = ACTIONS(2174),
    [anon_sym___clrcall] = ACTIONS(2174),
    [anon_sym___stdcall] = ACTIONS(2174),
    [anon_sym___fastcall] = ACTIONS(2174),
    [anon_sym___thiscall] = ACTIONS(2174),
    [anon_sym___vectorcall] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym__Nonnull] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym___shared__] = ACTIONS(2174),
    [anon_sym___local__] = ACTIONS(2174),
    [anon_sym___constant__] = ACTIONS(2174),
    [anon_sym___managed__] = ACTIONS(2174),
    [anon_sym___grid_constant__] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_case] = ACTIONS(2174),
    [anon_sym_default] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [anon_sym___asm] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [anon_sym_explicit] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_operator] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_namespace] = ACTIONS(2174),
    [anon_sym_using] = ACTIONS(2174),
    [anon_sym_static_assert] = ACTIONS(2174),
    [anon_sym_concept] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym___launch_bounds__] = ACTIONS(2174),
  },
  [STATE(214)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [aux_sym_preproc_else_token1] = ACTIONS(2178),
    [aux_sym_preproc_elif_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(215)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [aux_sym_preproc_else_token1] = ACTIONS(2182),
    [aux_sym_preproc_elif_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(216)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [aux_sym_preproc_else_token1] = ACTIONS(2178),
    [aux_sym_preproc_elif_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(217)] = {
    [sym_identifier] = ACTIONS(2186),
    [aux_sym_preproc_include_token1] = ACTIONS(2186),
    [aux_sym_preproc_def_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token2] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2186),
    [aux_sym_preproc_else_token1] = ACTIONS(2186),
    [aux_sym_preproc_elif_token1] = ACTIONS(2186),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2186),
    [sym_preproc_directive] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP_AMP] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2186),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym___device__] = ACTIONS(2186),
    [anon_sym___host__] = ACTIONS(2186),
    [anon_sym___global__] = ACTIONS(2186),
    [anon_sym___forceinline__] = ACTIONS(2186),
    [anon_sym___noinline__] = ACTIONS(2186),
    [anon_sym_virtual] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym___attribute] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym___based] = ACTIONS(2186),
    [anon_sym___cdecl] = ACTIONS(2186),
    [anon_sym___clrcall] = ACTIONS(2186),
    [anon_sym___stdcall] = ACTIONS(2186),
    [anon_sym___fastcall] = ACTIONS(2186),
    [anon_sym___thiscall] = ACTIONS(2186),
    [anon_sym___vectorcall] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym__Nonnull] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym___shared__] = ACTIONS(2186),
    [anon_sym___local__] = ACTIONS(2186),
    [anon_sym___constant__] = ACTIONS(2186),
    [anon_sym___managed__] = ACTIONS(2186),
    [anon_sym___grid_constant__] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_case] = ACTIONS(2186),
    [anon_sym_default] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [anon_sym___asm] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [anon_sym_explicit] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_operator] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_namespace] = ACTIONS(2186),
    [anon_sym_using] = ACTIONS(2186),
    [anon_sym_static_assert] = ACTIONS(2186),
    [anon_sym_concept] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym___launch_bounds__] = ACTIONS(2186),
  },
  [STATE(218)] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_include_token1] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token2] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [aux_sym_preproc_else_token1] = ACTIONS(2190),
    [aux_sym_preproc_elif_token1] = ACTIONS(2190),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym___device__] = ACTIONS(2190),
    [anon_sym___host__] = ACTIONS(2190),
    [anon_sym___global__] = ACTIONS(2190),
    [anon_sym___forceinline__] = ACTIONS(2190),
    [anon_sym___noinline__] = ACTIONS(2190),
    [anon_sym_virtual] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym___attribute] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym___cdecl] = ACTIONS(2190),
    [anon_sym___clrcall] = ACTIONS(2190),
    [anon_sym___stdcall] = ACTIONS(2190),
    [anon_sym___fastcall] = ACTIONS(2190),
    [anon_sym___thiscall] = ACTIONS(2190),
    [anon_sym___vectorcall] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym__Nonnull] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym___shared__] = ACTIONS(2190),
    [anon_sym___local__] = ACTIONS(2190),
    [anon_sym___constant__] = ACTIONS(2190),
    [anon_sym___managed__] = ACTIONS(2190),
    [anon_sym___grid_constant__] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym_default] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [anon_sym___asm] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_namespace] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym_concept] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym___launch_bounds__] = ACTIONS(2190),
  },
  [STATE(219)] = {
    [sym_expression] = STATE(5066),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8745),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(2194),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(2197),
    [anon_sym___extension__] = ACTIONS(2199),
    [anon_sym___device__] = ACTIONS(2166),
    [anon_sym___host__] = ACTIONS(2166),
    [anon_sym___global__] = ACTIONS(2166),
    [anon_sym___forceinline__] = ACTIONS(2166),
    [anon_sym___noinline__] = ACTIONS(2166),
    [anon_sym_virtual] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym___attribute] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2202),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym__Nonnull] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym___shared__] = ACTIONS(2166),
    [anon_sym___local__] = ACTIONS(2166),
    [anon_sym___constant__] = ACTIONS(2166),
    [anon_sym___managed__] = ACTIONS(2166),
    [anon_sym___grid_constant__] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2205),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2208),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2211),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(2166),
  },
  [STATE(220)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [aux_sym_preproc_else_token1] = ACTIONS(2182),
    [aux_sym_preproc_elif_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(221)] = {
    [sym_identifier] = ACTIONS(2214),
    [aux_sym_preproc_include_token1] = ACTIONS(2214),
    [aux_sym_preproc_def_token1] = ACTIONS(2214),
    [aux_sym_preproc_if_token1] = ACTIONS(2214),
    [aux_sym_preproc_if_token2] = ACTIONS(2214),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2214),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2214),
    [aux_sym_preproc_else_token1] = ACTIONS(2214),
    [aux_sym_preproc_elif_token1] = ACTIONS(2214),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2214),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2214),
    [sym_preproc_directive] = ACTIONS(2214),
    [anon_sym_LPAREN2] = ACTIONS(2216),
    [anon_sym_BANG] = ACTIONS(2216),
    [anon_sym_TILDE] = ACTIONS(2216),
    [anon_sym_DASH] = ACTIONS(2214),
    [anon_sym_PLUS] = ACTIONS(2214),
    [anon_sym_STAR] = ACTIONS(2216),
    [anon_sym_AMP_AMP] = ACTIONS(2216),
    [anon_sym_AMP] = ACTIONS(2214),
    [anon_sym_SEMI] = ACTIONS(2216),
    [anon_sym___extension__] = ACTIONS(2214),
    [anon_sym_typedef] = ACTIONS(2214),
    [anon_sym___device__] = ACTIONS(2214),
    [anon_sym___host__] = ACTIONS(2214),
    [anon_sym___global__] = ACTIONS(2214),
    [anon_sym___forceinline__] = ACTIONS(2214),
    [anon_sym___noinline__] = ACTIONS(2214),
    [anon_sym_virtual] = ACTIONS(2214),
    [anon_sym_extern] = ACTIONS(2214),
    [anon_sym___attribute__] = ACTIONS(2214),
    [anon_sym___attribute] = ACTIONS(2214),
    [anon_sym_COLON_COLON] = ACTIONS(2216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2216),
    [anon_sym___declspec] = ACTIONS(2214),
    [anon_sym___based] = ACTIONS(2214),
    [anon_sym___cdecl] = ACTIONS(2214),
    [anon_sym___clrcall] = ACTIONS(2214),
    [anon_sym___stdcall] = ACTIONS(2214),
    [anon_sym___fastcall] = ACTIONS(2214),
    [anon_sym___thiscall] = ACTIONS(2214),
    [anon_sym___vectorcall] = ACTIONS(2214),
    [anon_sym_LBRACE] = ACTIONS(2216),
    [anon_sym_signed] = ACTIONS(2214),
    [anon_sym_unsigned] = ACTIONS(2214),
    [anon_sym_long] = ACTIONS(2214),
    [anon_sym_short] = ACTIONS(2214),
    [anon_sym_LBRACK] = ACTIONS(2214),
    [anon_sym_static] = ACTIONS(2214),
    [anon_sym_register] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(2214),
    [anon_sym___inline] = ACTIONS(2214),
    [anon_sym___inline__] = ACTIONS(2214),
    [anon_sym___forceinline] = ACTIONS(2214),
    [anon_sym_thread_local] = ACTIONS(2214),
    [anon_sym___thread] = ACTIONS(2214),
    [anon_sym_const] = ACTIONS(2214),
    [anon_sym_constexpr] = ACTIONS(2214),
    [anon_sym_volatile] = ACTIONS(2214),
    [anon_sym_restrict] = ACTIONS(2214),
    [anon_sym___restrict__] = ACTIONS(2214),
    [anon_sym__Atomic] = ACTIONS(2214),
    [anon_sym__Noreturn] = ACTIONS(2214),
    [anon_sym_noreturn] = ACTIONS(2214),
    [anon_sym__Nonnull] = ACTIONS(2214),
    [anon_sym_mutable] = ACTIONS(2214),
    [anon_sym_constinit] = ACTIONS(2214),
    [anon_sym_consteval] = ACTIONS(2214),
    [anon_sym___shared__] = ACTIONS(2214),
    [anon_sym___local__] = ACTIONS(2214),
    [anon_sym___constant__] = ACTIONS(2214),
    [anon_sym___managed__] = ACTIONS(2214),
    [anon_sym___grid_constant__] = ACTIONS(2214),
    [anon_sym_alignas] = ACTIONS(2214),
    [anon_sym__Alignas] = ACTIONS(2214),
    [sym_primitive_type] = ACTIONS(2214),
    [anon_sym_enum] = ACTIONS(2214),
    [anon_sym_class] = ACTIONS(2214),
    [anon_sym_struct] = ACTIONS(2214),
    [anon_sym_union] = ACTIONS(2214),
    [anon_sym_if] = ACTIONS(2214),
    [anon_sym_else] = ACTIONS(2214),
    [anon_sym_switch] = ACTIONS(2214),
    [anon_sym_case] = ACTIONS(2214),
    [anon_sym_default] = ACTIONS(2214),
    [anon_sym_while] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2214),
    [anon_sym_for] = ACTIONS(2214),
    [anon_sym_return] = ACTIONS(2214),
    [anon_sym_break] = ACTIONS(2214),
    [anon_sym_continue] = ACTIONS(2214),
    [anon_sym_goto] = ACTIONS(2214),
    [anon_sym___try] = ACTIONS(2214),
    [anon_sym___leave] = ACTIONS(2214),
    [anon_sym_not] = ACTIONS(2214),
    [anon_sym_compl] = ACTIONS(2214),
    [anon_sym_DASH_DASH] = ACTIONS(2216),
    [anon_sym_PLUS_PLUS] = ACTIONS(2216),
    [anon_sym_sizeof] = ACTIONS(2214),
    [anon_sym___alignof__] = ACTIONS(2214),
    [anon_sym___alignof] = ACTIONS(2214),
    [anon_sym__alignof] = ACTIONS(2214),
    [anon_sym_alignof] = ACTIONS(2214),
    [anon_sym__Alignof] = ACTIONS(2214),
    [anon_sym_offsetof] = ACTIONS(2214),
    [anon_sym__Generic] = ACTIONS(2214),
    [anon_sym_asm] = ACTIONS(2214),
    [anon_sym___asm__] = ACTIONS(2214),
    [anon_sym___asm] = ACTIONS(2214),
    [sym_number_literal] = ACTIONS(2216),
    [anon_sym_L_SQUOTE] = ACTIONS(2216),
    [anon_sym_u_SQUOTE] = ACTIONS(2216),
    [anon_sym_U_SQUOTE] = ACTIONS(2216),
    [anon_sym_u8_SQUOTE] = ACTIONS(2216),
    [anon_sym_SQUOTE] = ACTIONS(2216),
    [anon_sym_L_DQUOTE] = ACTIONS(2216),
    [anon_sym_u_DQUOTE] = ACTIONS(2216),
    [anon_sym_U_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8_DQUOTE] = ACTIONS(2216),
    [anon_sym_DQUOTE] = ACTIONS(2216),
    [sym_true] = ACTIONS(2214),
    [sym_false] = ACTIONS(2214),
    [anon_sym_NULL] = ACTIONS(2214),
    [anon_sym_nullptr] = ACTIONS(2214),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2214),
    [anon_sym_decltype] = ACTIONS(2214),
    [anon_sym_explicit] = ACTIONS(2214),
    [anon_sym_typename] = ACTIONS(2214),
    [anon_sym_template] = ACTIONS(2214),
    [anon_sym_operator] = ACTIONS(2214),
    [anon_sym_try] = ACTIONS(2214),
    [anon_sym_delete] = ACTIONS(2214),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_namespace] = ACTIONS(2214),
    [anon_sym_using] = ACTIONS(2214),
    [anon_sym_static_assert] = ACTIONS(2214),
    [anon_sym_concept] = ACTIONS(2214),
    [anon_sym_co_return] = ACTIONS(2214),
    [anon_sym_co_yield] = ACTIONS(2214),
    [anon_sym_R_DQUOTE] = ACTIONS(2216),
    [anon_sym_LR_DQUOTE] = ACTIONS(2216),
    [anon_sym_uR_DQUOTE] = ACTIONS(2216),
    [anon_sym_UR_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2216),
    [anon_sym_co_await] = ACTIONS(2214),
    [anon_sym_new] = ACTIONS(2214),
    [anon_sym_requires] = ACTIONS(2214),
    [sym_this] = ACTIONS(2214),
    [anon_sym___launch_bounds__] = ACTIONS(2214),
  },
  [STATE(222)] = {
    [sym_identifier] = ACTIONS(2218),
    [aux_sym_preproc_include_token1] = ACTIONS(2218),
    [aux_sym_preproc_def_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token2] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2218),
    [aux_sym_preproc_else_token1] = ACTIONS(2218),
    [aux_sym_preproc_elif_token1] = ACTIONS(2218),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2218),
    [sym_preproc_directive] = ACTIONS(2218),
    [anon_sym_LPAREN2] = ACTIONS(2220),
    [anon_sym_BANG] = ACTIONS(2220),
    [anon_sym_TILDE] = ACTIONS(2220),
    [anon_sym_DASH] = ACTIONS(2218),
    [anon_sym_PLUS] = ACTIONS(2218),
    [anon_sym_STAR] = ACTIONS(2220),
    [anon_sym_AMP_AMP] = ACTIONS(2220),
    [anon_sym_AMP] = ACTIONS(2218),
    [anon_sym_SEMI] = ACTIONS(2220),
    [anon_sym___extension__] = ACTIONS(2218),
    [anon_sym_typedef] = ACTIONS(2218),
    [anon_sym___device__] = ACTIONS(2218),
    [anon_sym___host__] = ACTIONS(2218),
    [anon_sym___global__] = ACTIONS(2218),
    [anon_sym___forceinline__] = ACTIONS(2218),
    [anon_sym___noinline__] = ACTIONS(2218),
    [anon_sym_virtual] = ACTIONS(2218),
    [anon_sym_extern] = ACTIONS(2218),
    [anon_sym___attribute__] = ACTIONS(2218),
    [anon_sym___attribute] = ACTIONS(2218),
    [anon_sym_COLON_COLON] = ACTIONS(2220),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2220),
    [anon_sym___declspec] = ACTIONS(2218),
    [anon_sym___based] = ACTIONS(2218),
    [anon_sym___cdecl] = ACTIONS(2218),
    [anon_sym___clrcall] = ACTIONS(2218),
    [anon_sym___stdcall] = ACTIONS(2218),
    [anon_sym___fastcall] = ACTIONS(2218),
    [anon_sym___thiscall] = ACTIONS(2218),
    [anon_sym___vectorcall] = ACTIONS(2218),
    [anon_sym_LBRACE] = ACTIONS(2220),
    [anon_sym_signed] = ACTIONS(2218),
    [anon_sym_unsigned] = ACTIONS(2218),
    [anon_sym_long] = ACTIONS(2218),
    [anon_sym_short] = ACTIONS(2218),
    [anon_sym_LBRACK] = ACTIONS(2218),
    [anon_sym_static] = ACTIONS(2218),
    [anon_sym_register] = ACTIONS(2218),
    [anon_sym_inline] = ACTIONS(2218),
    [anon_sym___inline] = ACTIONS(2218),
    [anon_sym___inline__] = ACTIONS(2218),
    [anon_sym___forceinline] = ACTIONS(2218),
    [anon_sym_thread_local] = ACTIONS(2218),
    [anon_sym___thread] = ACTIONS(2218),
    [anon_sym_const] = ACTIONS(2218),
    [anon_sym_constexpr] = ACTIONS(2218),
    [anon_sym_volatile] = ACTIONS(2218),
    [anon_sym_restrict] = ACTIONS(2218),
    [anon_sym___restrict__] = ACTIONS(2218),
    [anon_sym__Atomic] = ACTIONS(2218),
    [anon_sym__Noreturn] = ACTIONS(2218),
    [anon_sym_noreturn] = ACTIONS(2218),
    [anon_sym__Nonnull] = ACTIONS(2218),
    [anon_sym_mutable] = ACTIONS(2218),
    [anon_sym_constinit] = ACTIONS(2218),
    [anon_sym_consteval] = ACTIONS(2218),
    [anon_sym___shared__] = ACTIONS(2218),
    [anon_sym___local__] = ACTIONS(2218),
    [anon_sym___constant__] = ACTIONS(2218),
    [anon_sym___managed__] = ACTIONS(2218),
    [anon_sym___grid_constant__] = ACTIONS(2218),
    [anon_sym_alignas] = ACTIONS(2218),
    [anon_sym__Alignas] = ACTIONS(2218),
    [sym_primitive_type] = ACTIONS(2218),
    [anon_sym_enum] = ACTIONS(2218),
    [anon_sym_class] = ACTIONS(2218),
    [anon_sym_struct] = ACTIONS(2218),
    [anon_sym_union] = ACTIONS(2218),
    [anon_sym_if] = ACTIONS(2218),
    [anon_sym_else] = ACTIONS(2218),
    [anon_sym_switch] = ACTIONS(2218),
    [anon_sym_case] = ACTIONS(2218),
    [anon_sym_default] = ACTIONS(2218),
    [anon_sym_while] = ACTIONS(2218),
    [anon_sym_do] = ACTIONS(2218),
    [anon_sym_for] = ACTIONS(2218),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_break] = ACTIONS(2218),
    [anon_sym_continue] = ACTIONS(2218),
    [anon_sym_goto] = ACTIONS(2218),
    [anon_sym___try] = ACTIONS(2218),
    [anon_sym___leave] = ACTIONS(2218),
    [anon_sym_not] = ACTIONS(2218),
    [anon_sym_compl] = ACTIONS(2218),
    [anon_sym_DASH_DASH] = ACTIONS(2220),
    [anon_sym_PLUS_PLUS] = ACTIONS(2220),
    [anon_sym_sizeof] = ACTIONS(2218),
    [anon_sym___alignof__] = ACTIONS(2218),
    [anon_sym___alignof] = ACTIONS(2218),
    [anon_sym__alignof] = ACTIONS(2218),
    [anon_sym_alignof] = ACTIONS(2218),
    [anon_sym__Alignof] = ACTIONS(2218),
    [anon_sym_offsetof] = ACTIONS(2218),
    [anon_sym__Generic] = ACTIONS(2218),
    [anon_sym_asm] = ACTIONS(2218),
    [anon_sym___asm__] = ACTIONS(2218),
    [anon_sym___asm] = ACTIONS(2218),
    [sym_number_literal] = ACTIONS(2220),
    [anon_sym_L_SQUOTE] = ACTIONS(2220),
    [anon_sym_u_SQUOTE] = ACTIONS(2220),
    [anon_sym_U_SQUOTE] = ACTIONS(2220),
    [anon_sym_u8_SQUOTE] = ACTIONS(2220),
    [anon_sym_SQUOTE] = ACTIONS(2220),
    [anon_sym_L_DQUOTE] = ACTIONS(2220),
    [anon_sym_u_DQUOTE] = ACTIONS(2220),
    [anon_sym_U_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8_DQUOTE] = ACTIONS(2220),
    [anon_sym_DQUOTE] = ACTIONS(2220),
    [sym_true] = ACTIONS(2218),
    [sym_false] = ACTIONS(2218),
    [anon_sym_NULL] = ACTIONS(2218),
    [anon_sym_nullptr] = ACTIONS(2218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2218),
    [anon_sym_decltype] = ACTIONS(2218),
    [anon_sym_explicit] = ACTIONS(2218),
    [anon_sym_typename] = ACTIONS(2218),
    [anon_sym_template] = ACTIONS(2218),
    [anon_sym_operator] = ACTIONS(2218),
    [anon_sym_try] = ACTIONS(2218),
    [anon_sym_delete] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2218),
    [anon_sym_namespace] = ACTIONS(2218),
    [anon_sym_using] = ACTIONS(2218),
    [anon_sym_static_assert] = ACTIONS(2218),
    [anon_sym_concept] = ACTIONS(2218),
    [anon_sym_co_return] = ACTIONS(2218),
    [anon_sym_co_yield] = ACTIONS(2218),
    [anon_sym_R_DQUOTE] = ACTIONS(2220),
    [anon_sym_LR_DQUOTE] = ACTIONS(2220),
    [anon_sym_uR_DQUOTE] = ACTIONS(2220),
    [anon_sym_UR_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2220),
    [anon_sym_co_await] = ACTIONS(2218),
    [anon_sym_new] = ACTIONS(2218),
    [anon_sym_requires] = ACTIONS(2218),
    [sym_this] = ACTIONS(2218),
    [anon_sym___launch_bounds__] = ACTIONS(2218),
  },
  [STATE(223)] = {
    [sym_identifier] = ACTIONS(2222),
    [aux_sym_preproc_include_token1] = ACTIONS(2222),
    [aux_sym_preproc_def_token1] = ACTIONS(2222),
    [aux_sym_preproc_if_token1] = ACTIONS(2222),
    [aux_sym_preproc_if_token2] = ACTIONS(2222),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2222),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2222),
    [aux_sym_preproc_else_token1] = ACTIONS(2222),
    [aux_sym_preproc_elif_token1] = ACTIONS(2222),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2222),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2222),
    [sym_preproc_directive] = ACTIONS(2222),
    [anon_sym_LPAREN2] = ACTIONS(2224),
    [anon_sym_BANG] = ACTIONS(2224),
    [anon_sym_TILDE] = ACTIONS(2224),
    [anon_sym_DASH] = ACTIONS(2222),
    [anon_sym_PLUS] = ACTIONS(2222),
    [anon_sym_STAR] = ACTIONS(2224),
    [anon_sym_AMP_AMP] = ACTIONS(2224),
    [anon_sym_AMP] = ACTIONS(2222),
    [anon_sym_SEMI] = ACTIONS(2224),
    [anon_sym___extension__] = ACTIONS(2222),
    [anon_sym_typedef] = ACTIONS(2222),
    [anon_sym___device__] = ACTIONS(2222),
    [anon_sym___host__] = ACTIONS(2222),
    [anon_sym___global__] = ACTIONS(2222),
    [anon_sym___forceinline__] = ACTIONS(2222),
    [anon_sym___noinline__] = ACTIONS(2222),
    [anon_sym_virtual] = ACTIONS(2222),
    [anon_sym_extern] = ACTIONS(2222),
    [anon_sym___attribute__] = ACTIONS(2222),
    [anon_sym___attribute] = ACTIONS(2222),
    [anon_sym_COLON_COLON] = ACTIONS(2224),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2224),
    [anon_sym___declspec] = ACTIONS(2222),
    [anon_sym___based] = ACTIONS(2222),
    [anon_sym___cdecl] = ACTIONS(2222),
    [anon_sym___clrcall] = ACTIONS(2222),
    [anon_sym___stdcall] = ACTIONS(2222),
    [anon_sym___fastcall] = ACTIONS(2222),
    [anon_sym___thiscall] = ACTIONS(2222),
    [anon_sym___vectorcall] = ACTIONS(2222),
    [anon_sym_LBRACE] = ACTIONS(2224),
    [anon_sym_signed] = ACTIONS(2222),
    [anon_sym_unsigned] = ACTIONS(2222),
    [anon_sym_long] = ACTIONS(2222),
    [anon_sym_short] = ACTIONS(2222),
    [anon_sym_LBRACK] = ACTIONS(2222),
    [anon_sym_static] = ACTIONS(2222),
    [anon_sym_register] = ACTIONS(2222),
    [anon_sym_inline] = ACTIONS(2222),
    [anon_sym___inline] = ACTIONS(2222),
    [anon_sym___inline__] = ACTIONS(2222),
    [anon_sym___forceinline] = ACTIONS(2222),
    [anon_sym_thread_local] = ACTIONS(2222),
    [anon_sym___thread] = ACTIONS(2222),
    [anon_sym_const] = ACTIONS(2222),
    [anon_sym_constexpr] = ACTIONS(2222),
    [anon_sym_volatile] = ACTIONS(2222),
    [anon_sym_restrict] = ACTIONS(2222),
    [anon_sym___restrict__] = ACTIONS(2222),
    [anon_sym__Atomic] = ACTIONS(2222),
    [anon_sym__Noreturn] = ACTIONS(2222),
    [anon_sym_noreturn] = ACTIONS(2222),
    [anon_sym__Nonnull] = ACTIONS(2222),
    [anon_sym_mutable] = ACTIONS(2222),
    [anon_sym_constinit] = ACTIONS(2222),
    [anon_sym_consteval] = ACTIONS(2222),
    [anon_sym___shared__] = ACTIONS(2222),
    [anon_sym___local__] = ACTIONS(2222),
    [anon_sym___constant__] = ACTIONS(2222),
    [anon_sym___managed__] = ACTIONS(2222),
    [anon_sym___grid_constant__] = ACTIONS(2222),
    [anon_sym_alignas] = ACTIONS(2222),
    [anon_sym__Alignas] = ACTIONS(2222),
    [sym_primitive_type] = ACTIONS(2222),
    [anon_sym_enum] = ACTIONS(2222),
    [anon_sym_class] = ACTIONS(2222),
    [anon_sym_struct] = ACTIONS(2222),
    [anon_sym_union] = ACTIONS(2222),
    [anon_sym_if] = ACTIONS(2222),
    [anon_sym_else] = ACTIONS(2222),
    [anon_sym_switch] = ACTIONS(2222),
    [anon_sym_case] = ACTIONS(2222),
    [anon_sym_default] = ACTIONS(2222),
    [anon_sym_while] = ACTIONS(2222),
    [anon_sym_do] = ACTIONS(2222),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_return] = ACTIONS(2222),
    [anon_sym_break] = ACTIONS(2222),
    [anon_sym_continue] = ACTIONS(2222),
    [anon_sym_goto] = ACTIONS(2222),
    [anon_sym___try] = ACTIONS(2222),
    [anon_sym___leave] = ACTIONS(2222),
    [anon_sym_not] = ACTIONS(2222),
    [anon_sym_compl] = ACTIONS(2222),
    [anon_sym_DASH_DASH] = ACTIONS(2224),
    [anon_sym_PLUS_PLUS] = ACTIONS(2224),
    [anon_sym_sizeof] = ACTIONS(2222),
    [anon_sym___alignof__] = ACTIONS(2222),
    [anon_sym___alignof] = ACTIONS(2222),
    [anon_sym__alignof] = ACTIONS(2222),
    [anon_sym_alignof] = ACTIONS(2222),
    [anon_sym__Alignof] = ACTIONS(2222),
    [anon_sym_offsetof] = ACTIONS(2222),
    [anon_sym__Generic] = ACTIONS(2222),
    [anon_sym_asm] = ACTIONS(2222),
    [anon_sym___asm__] = ACTIONS(2222),
    [anon_sym___asm] = ACTIONS(2222),
    [sym_number_literal] = ACTIONS(2224),
    [anon_sym_L_SQUOTE] = ACTIONS(2224),
    [anon_sym_u_SQUOTE] = ACTIONS(2224),
    [anon_sym_U_SQUOTE] = ACTIONS(2224),
    [anon_sym_u8_SQUOTE] = ACTIONS(2224),
    [anon_sym_SQUOTE] = ACTIONS(2224),
    [anon_sym_L_DQUOTE] = ACTIONS(2224),
    [anon_sym_u_DQUOTE] = ACTIONS(2224),
    [anon_sym_U_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8_DQUOTE] = ACTIONS(2224),
    [anon_sym_DQUOTE] = ACTIONS(2224),
    [sym_true] = ACTIONS(2222),
    [sym_false] = ACTIONS(2222),
    [anon_sym_NULL] = ACTIONS(2222),
    [anon_sym_nullptr] = ACTIONS(2222),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2222),
    [anon_sym_decltype] = ACTIONS(2222),
    [anon_sym_explicit] = ACTIONS(2222),
    [anon_sym_typename] = ACTIONS(2222),
    [anon_sym_template] = ACTIONS(2222),
    [anon_sym_operator] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2222),
    [anon_sym_delete] = ACTIONS(2222),
    [anon_sym_throw] = ACTIONS(2222),
    [anon_sym_namespace] = ACTIONS(2222),
    [anon_sym_using] = ACTIONS(2222),
    [anon_sym_static_assert] = ACTIONS(2222),
    [anon_sym_concept] = ACTIONS(2222),
    [anon_sym_co_return] = ACTIONS(2222),
    [anon_sym_co_yield] = ACTIONS(2222),
    [anon_sym_R_DQUOTE] = ACTIONS(2224),
    [anon_sym_LR_DQUOTE] = ACTIONS(2224),
    [anon_sym_uR_DQUOTE] = ACTIONS(2224),
    [anon_sym_UR_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2224),
    [anon_sym_co_await] = ACTIONS(2222),
    [anon_sym_new] = ACTIONS(2222),
    [anon_sym_requires] = ACTIONS(2222),
    [sym_this] = ACTIONS(2222),
    [anon_sym___launch_bounds__] = ACTIONS(2222),
  },
  [STATE(224)] = {
    [sym_identifier] = ACTIONS(2226),
    [aux_sym_preproc_include_token1] = ACTIONS(2226),
    [aux_sym_preproc_def_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token2] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2226),
    [aux_sym_preproc_else_token1] = ACTIONS(2226),
    [aux_sym_preproc_elif_token1] = ACTIONS(2226),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2226),
    [sym_preproc_directive] = ACTIONS(2226),
    [anon_sym_LPAREN2] = ACTIONS(2228),
    [anon_sym_BANG] = ACTIONS(2228),
    [anon_sym_TILDE] = ACTIONS(2228),
    [anon_sym_DASH] = ACTIONS(2226),
    [anon_sym_PLUS] = ACTIONS(2226),
    [anon_sym_STAR] = ACTIONS(2228),
    [anon_sym_AMP_AMP] = ACTIONS(2228),
    [anon_sym_AMP] = ACTIONS(2226),
    [anon_sym_SEMI] = ACTIONS(2228),
    [anon_sym___extension__] = ACTIONS(2226),
    [anon_sym_typedef] = ACTIONS(2226),
    [anon_sym___device__] = ACTIONS(2226),
    [anon_sym___host__] = ACTIONS(2226),
    [anon_sym___global__] = ACTIONS(2226),
    [anon_sym___forceinline__] = ACTIONS(2226),
    [anon_sym___noinline__] = ACTIONS(2226),
    [anon_sym_virtual] = ACTIONS(2226),
    [anon_sym_extern] = ACTIONS(2226),
    [anon_sym___attribute__] = ACTIONS(2226),
    [anon_sym___attribute] = ACTIONS(2226),
    [anon_sym_COLON_COLON] = ACTIONS(2228),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2228),
    [anon_sym___declspec] = ACTIONS(2226),
    [anon_sym___based] = ACTIONS(2226),
    [anon_sym___cdecl] = ACTIONS(2226),
    [anon_sym___clrcall] = ACTIONS(2226),
    [anon_sym___stdcall] = ACTIONS(2226),
    [anon_sym___fastcall] = ACTIONS(2226),
    [anon_sym___thiscall] = ACTIONS(2226),
    [anon_sym___vectorcall] = ACTIONS(2226),
    [anon_sym_LBRACE] = ACTIONS(2228),
    [anon_sym_signed] = ACTIONS(2226),
    [anon_sym_unsigned] = ACTIONS(2226),
    [anon_sym_long] = ACTIONS(2226),
    [anon_sym_short] = ACTIONS(2226),
    [anon_sym_LBRACK] = ACTIONS(2226),
    [anon_sym_static] = ACTIONS(2226),
    [anon_sym_register] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(2226),
    [anon_sym___inline] = ACTIONS(2226),
    [anon_sym___inline__] = ACTIONS(2226),
    [anon_sym___forceinline] = ACTIONS(2226),
    [anon_sym_thread_local] = ACTIONS(2226),
    [anon_sym___thread] = ACTIONS(2226),
    [anon_sym_const] = ACTIONS(2226),
    [anon_sym_constexpr] = ACTIONS(2226),
    [anon_sym_volatile] = ACTIONS(2226),
    [anon_sym_restrict] = ACTIONS(2226),
    [anon_sym___restrict__] = ACTIONS(2226),
    [anon_sym__Atomic] = ACTIONS(2226),
    [anon_sym__Noreturn] = ACTIONS(2226),
    [anon_sym_noreturn] = ACTIONS(2226),
    [anon_sym__Nonnull] = ACTIONS(2226),
    [anon_sym_mutable] = ACTIONS(2226),
    [anon_sym_constinit] = ACTIONS(2226),
    [anon_sym_consteval] = ACTIONS(2226),
    [anon_sym___shared__] = ACTIONS(2226),
    [anon_sym___local__] = ACTIONS(2226),
    [anon_sym___constant__] = ACTIONS(2226),
    [anon_sym___managed__] = ACTIONS(2226),
    [anon_sym___grid_constant__] = ACTIONS(2226),
    [anon_sym_alignas] = ACTIONS(2226),
    [anon_sym__Alignas] = ACTIONS(2226),
    [sym_primitive_type] = ACTIONS(2226),
    [anon_sym_enum] = ACTIONS(2226),
    [anon_sym_class] = ACTIONS(2226),
    [anon_sym_struct] = ACTIONS(2226),
    [anon_sym_union] = ACTIONS(2226),
    [anon_sym_if] = ACTIONS(2226),
    [anon_sym_switch] = ACTIONS(2226),
    [anon_sym_case] = ACTIONS(2226),
    [anon_sym_default] = ACTIONS(2226),
    [anon_sym_while] = ACTIONS(2226),
    [anon_sym_do] = ACTIONS(2226),
    [anon_sym_for] = ACTIONS(2226),
    [anon_sym_return] = ACTIONS(2226),
    [anon_sym_break] = ACTIONS(2226),
    [anon_sym_continue] = ACTIONS(2226),
    [anon_sym_goto] = ACTIONS(2226),
    [anon_sym___try] = ACTIONS(2226),
    [anon_sym___leave] = ACTIONS(2226),
    [anon_sym_not] = ACTIONS(2226),
    [anon_sym_compl] = ACTIONS(2226),
    [anon_sym_DASH_DASH] = ACTIONS(2228),
    [anon_sym_PLUS_PLUS] = ACTIONS(2228),
    [anon_sym_sizeof] = ACTIONS(2226),
    [anon_sym___alignof__] = ACTIONS(2226),
    [anon_sym___alignof] = ACTIONS(2226),
    [anon_sym__alignof] = ACTIONS(2226),
    [anon_sym_alignof] = ACTIONS(2226),
    [anon_sym__Alignof] = ACTIONS(2226),
    [anon_sym_offsetof] = ACTIONS(2226),
    [anon_sym__Generic] = ACTIONS(2226),
    [anon_sym_asm] = ACTIONS(2226),
    [anon_sym___asm__] = ACTIONS(2226),
    [anon_sym___asm] = ACTIONS(2226),
    [sym_number_literal] = ACTIONS(2228),
    [anon_sym_L_SQUOTE] = ACTIONS(2228),
    [anon_sym_u_SQUOTE] = ACTIONS(2228),
    [anon_sym_U_SQUOTE] = ACTIONS(2228),
    [anon_sym_u8_SQUOTE] = ACTIONS(2228),
    [anon_sym_SQUOTE] = ACTIONS(2228),
    [anon_sym_L_DQUOTE] = ACTIONS(2228),
    [anon_sym_u_DQUOTE] = ACTIONS(2228),
    [anon_sym_U_DQUOTE] = ACTIONS(2228),
    [anon_sym_u8_DQUOTE] = ACTIONS(2228),
    [anon_sym_DQUOTE] = ACTIONS(2228),
    [sym_true] = ACTIONS(2226),
    [sym_false] = ACTIONS(2226),
    [anon_sym_NULL] = ACTIONS(2226),
    [anon_sym_nullptr] = ACTIONS(2226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2226),
    [anon_sym_decltype] = ACTIONS(2226),
    [anon_sym_explicit] = ACTIONS(2226),
    [anon_sym_typename] = ACTIONS(2226),
    [anon_sym_template] = ACTIONS(2226),
    [anon_sym_operator] = ACTIONS(2226),
    [anon_sym_try] = ACTIONS(2226),
    [anon_sym_delete] = ACTIONS(2226),
    [anon_sym_throw] = ACTIONS(2226),
    [anon_sym_namespace] = ACTIONS(2226),
    [anon_sym_using] = ACTIONS(2226),
    [anon_sym_static_assert] = ACTIONS(2226),
    [anon_sym_concept] = ACTIONS(2226),
    [anon_sym_co_return] = ACTIONS(2226),
    [anon_sym_co_yield] = ACTIONS(2226),
    [anon_sym_R_DQUOTE] = ACTIONS(2228),
    [anon_sym_LR_DQUOTE] = ACTIONS(2228),
    [anon_sym_uR_DQUOTE] = ACTIONS(2228),
    [anon_sym_UR_DQUOTE] = ACTIONS(2228),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2228),
    [anon_sym_co_await] = ACTIONS(2226),
    [anon_sym_new] = ACTIONS(2226),
    [anon_sym_requires] = ACTIONS(2226),
    [sym_this] = ACTIONS(2226),
    [anon_sym___launch_bounds__] = ACTIONS(2226),
  },
  [STATE(225)] = {
    [sym_identifier] = ACTIONS(2230),
    [aux_sym_preproc_include_token1] = ACTIONS(2230),
    [aux_sym_preproc_def_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token2] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2230),
    [aux_sym_preproc_else_token1] = ACTIONS(2230),
    [aux_sym_preproc_elif_token1] = ACTIONS(2230),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2230),
    [sym_preproc_directive] = ACTIONS(2230),
    [anon_sym_LPAREN2] = ACTIONS(2232),
    [anon_sym_BANG] = ACTIONS(2232),
    [anon_sym_TILDE] = ACTIONS(2232),
    [anon_sym_DASH] = ACTIONS(2230),
    [anon_sym_PLUS] = ACTIONS(2230),
    [anon_sym_STAR] = ACTIONS(2232),
    [anon_sym_AMP_AMP] = ACTIONS(2232),
    [anon_sym_AMP] = ACTIONS(2230),
    [anon_sym_SEMI] = ACTIONS(2232),
    [anon_sym___extension__] = ACTIONS(2230),
    [anon_sym_typedef] = ACTIONS(2230),
    [anon_sym___device__] = ACTIONS(2230),
    [anon_sym___host__] = ACTIONS(2230),
    [anon_sym___global__] = ACTIONS(2230),
    [anon_sym___forceinline__] = ACTIONS(2230),
    [anon_sym___noinline__] = ACTIONS(2230),
    [anon_sym_virtual] = ACTIONS(2230),
    [anon_sym_extern] = ACTIONS(2230),
    [anon_sym___attribute__] = ACTIONS(2230),
    [anon_sym___attribute] = ACTIONS(2230),
    [anon_sym_COLON_COLON] = ACTIONS(2232),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2232),
    [anon_sym___declspec] = ACTIONS(2230),
    [anon_sym___based] = ACTIONS(2230),
    [anon_sym___cdecl] = ACTIONS(2230),
    [anon_sym___clrcall] = ACTIONS(2230),
    [anon_sym___stdcall] = ACTIONS(2230),
    [anon_sym___fastcall] = ACTIONS(2230),
    [anon_sym___thiscall] = ACTIONS(2230),
    [anon_sym___vectorcall] = ACTIONS(2230),
    [anon_sym_LBRACE] = ACTIONS(2232),
    [anon_sym_signed] = ACTIONS(2230),
    [anon_sym_unsigned] = ACTIONS(2230),
    [anon_sym_long] = ACTIONS(2230),
    [anon_sym_short] = ACTIONS(2230),
    [anon_sym_LBRACK] = ACTIONS(2230),
    [anon_sym_static] = ACTIONS(2230),
    [anon_sym_register] = ACTIONS(2230),
    [anon_sym_inline] = ACTIONS(2230),
    [anon_sym___inline] = ACTIONS(2230),
    [anon_sym___inline__] = ACTIONS(2230),
    [anon_sym___forceinline] = ACTIONS(2230),
    [anon_sym_thread_local] = ACTIONS(2230),
    [anon_sym___thread] = ACTIONS(2230),
    [anon_sym_const] = ACTIONS(2230),
    [anon_sym_constexpr] = ACTIONS(2230),
    [anon_sym_volatile] = ACTIONS(2230),
    [anon_sym_restrict] = ACTIONS(2230),
    [anon_sym___restrict__] = ACTIONS(2230),
    [anon_sym__Atomic] = ACTIONS(2230),
    [anon_sym__Noreturn] = ACTIONS(2230),
    [anon_sym_noreturn] = ACTIONS(2230),
    [anon_sym__Nonnull] = ACTIONS(2230),
    [anon_sym_mutable] = ACTIONS(2230),
    [anon_sym_constinit] = ACTIONS(2230),
    [anon_sym_consteval] = ACTIONS(2230),
    [anon_sym___shared__] = ACTIONS(2230),
    [anon_sym___local__] = ACTIONS(2230),
    [anon_sym___constant__] = ACTIONS(2230),
    [anon_sym___managed__] = ACTIONS(2230),
    [anon_sym___grid_constant__] = ACTIONS(2230),
    [anon_sym_alignas] = ACTIONS(2230),
    [anon_sym__Alignas] = ACTIONS(2230),
    [sym_primitive_type] = ACTIONS(2230),
    [anon_sym_enum] = ACTIONS(2230),
    [anon_sym_class] = ACTIONS(2230),
    [anon_sym_struct] = ACTIONS(2230),
    [anon_sym_union] = ACTIONS(2230),
    [anon_sym_if] = ACTIONS(2230),
    [anon_sym_switch] = ACTIONS(2230),
    [anon_sym_case] = ACTIONS(2230),
    [anon_sym_default] = ACTIONS(2230),
    [anon_sym_while] = ACTIONS(2230),
    [anon_sym_do] = ACTIONS(2230),
    [anon_sym_for] = ACTIONS(2230),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_break] = ACTIONS(2230),
    [anon_sym_continue] = ACTIONS(2230),
    [anon_sym_goto] = ACTIONS(2230),
    [anon_sym___try] = ACTIONS(2230),
    [anon_sym___leave] = ACTIONS(2230),
    [anon_sym_not] = ACTIONS(2230),
    [anon_sym_compl] = ACTIONS(2230),
    [anon_sym_DASH_DASH] = ACTIONS(2232),
    [anon_sym_PLUS_PLUS] = ACTIONS(2232),
    [anon_sym_sizeof] = ACTIONS(2230),
    [anon_sym___alignof__] = ACTIONS(2230),
    [anon_sym___alignof] = ACTIONS(2230),
    [anon_sym__alignof] = ACTIONS(2230),
    [anon_sym_alignof] = ACTIONS(2230),
    [anon_sym__Alignof] = ACTIONS(2230),
    [anon_sym_offsetof] = ACTIONS(2230),
    [anon_sym__Generic] = ACTIONS(2230),
    [anon_sym_asm] = ACTIONS(2230),
    [anon_sym___asm__] = ACTIONS(2230),
    [anon_sym___asm] = ACTIONS(2230),
    [sym_number_literal] = ACTIONS(2232),
    [anon_sym_L_SQUOTE] = ACTIONS(2232),
    [anon_sym_u_SQUOTE] = ACTIONS(2232),
    [anon_sym_U_SQUOTE] = ACTIONS(2232),
    [anon_sym_u8_SQUOTE] = ACTIONS(2232),
    [anon_sym_SQUOTE] = ACTIONS(2232),
    [anon_sym_L_DQUOTE] = ACTIONS(2232),
    [anon_sym_u_DQUOTE] = ACTIONS(2232),
    [anon_sym_U_DQUOTE] = ACTIONS(2232),
    [anon_sym_u8_DQUOTE] = ACTIONS(2232),
    [anon_sym_DQUOTE] = ACTIONS(2232),
    [sym_true] = ACTIONS(2230),
    [sym_false] = ACTIONS(2230),
    [anon_sym_NULL] = ACTIONS(2230),
    [anon_sym_nullptr] = ACTIONS(2230),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2230),
    [anon_sym_decltype] = ACTIONS(2230),
    [anon_sym_explicit] = ACTIONS(2230),
    [anon_sym_typename] = ACTIONS(2230),
    [anon_sym_template] = ACTIONS(2230),
    [anon_sym_operator] = ACTIONS(2230),
    [anon_sym_try] = ACTIONS(2230),
    [anon_sym_delete] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2230),
    [anon_sym_namespace] = ACTIONS(2230),
    [anon_sym_using] = ACTIONS(2230),
    [anon_sym_static_assert] = ACTIONS(2230),
    [anon_sym_concept] = ACTIONS(2230),
    [anon_sym_co_return] = ACTIONS(2230),
    [anon_sym_co_yield] = ACTIONS(2230),
    [anon_sym_R_DQUOTE] = ACTIONS(2232),
    [anon_sym_LR_DQUOTE] = ACTIONS(2232),
    [anon_sym_uR_DQUOTE] = ACTIONS(2232),
    [anon_sym_UR_DQUOTE] = ACTIONS(2232),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2232),
    [anon_sym_co_await] = ACTIONS(2230),
    [anon_sym_new] = ACTIONS(2230),
    [anon_sym_requires] = ACTIONS(2230),
    [sym_this] = ACTIONS(2230),
    [anon_sym___launch_bounds__] = ACTIONS(2230),
  },
  [STATE(226)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_include_token1] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token2] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [aux_sym_preproc_else_token1] = ACTIONS(2234),
    [aux_sym_preproc_elif_token1] = ACTIONS(2234),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_BANG] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_DASH] = ACTIONS(2234),
    [anon_sym_PLUS] = ACTIONS(2234),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym___cdecl] = ACTIONS(2234),
    [anon_sym___clrcall] = ACTIONS(2234),
    [anon_sym___stdcall] = ACTIONS(2234),
    [anon_sym___fastcall] = ACTIONS(2234),
    [anon_sym___thiscall] = ACTIONS(2234),
    [anon_sym___vectorcall] = ACTIONS(2234),
    [anon_sym_LBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [anon_sym_if] = ACTIONS(2234),
    [anon_sym_switch] = ACTIONS(2234),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym_default] = ACTIONS(2234),
    [anon_sym_while] = ACTIONS(2234),
    [anon_sym_do] = ACTIONS(2234),
    [anon_sym_for] = ACTIONS(2234),
    [anon_sym_return] = ACTIONS(2234),
    [anon_sym_break] = ACTIONS(2234),
    [anon_sym_continue] = ACTIONS(2234),
    [anon_sym_goto] = ACTIONS(2234),
    [anon_sym___try] = ACTIONS(2234),
    [anon_sym___leave] = ACTIONS(2234),
    [anon_sym_not] = ACTIONS(2234),
    [anon_sym_compl] = ACTIONS(2234),
    [anon_sym_DASH_DASH] = ACTIONS(2236),
    [anon_sym_PLUS_PLUS] = ACTIONS(2236),
    [anon_sym_sizeof] = ACTIONS(2234),
    [anon_sym___alignof__] = ACTIONS(2234),
    [anon_sym___alignof] = ACTIONS(2234),
    [anon_sym__alignof] = ACTIONS(2234),
    [anon_sym_alignof] = ACTIONS(2234),
    [anon_sym__Alignof] = ACTIONS(2234),
    [anon_sym_offsetof] = ACTIONS(2234),
    [anon_sym__Generic] = ACTIONS(2234),
    [anon_sym_asm] = ACTIONS(2234),
    [anon_sym___asm__] = ACTIONS(2234),
    [anon_sym___asm] = ACTIONS(2234),
    [sym_number_literal] = ACTIONS(2236),
    [anon_sym_L_SQUOTE] = ACTIONS(2236),
    [anon_sym_u_SQUOTE] = ACTIONS(2236),
    [anon_sym_U_SQUOTE] = ACTIONS(2236),
    [anon_sym_u8_SQUOTE] = ACTIONS(2236),
    [anon_sym_SQUOTE] = ACTIONS(2236),
    [anon_sym_L_DQUOTE] = ACTIONS(2236),
    [anon_sym_u_DQUOTE] = ACTIONS(2236),
    [anon_sym_U_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8_DQUOTE] = ACTIONS(2236),
    [anon_sym_DQUOTE] = ACTIONS(2236),
    [sym_true] = ACTIONS(2234),
    [sym_false] = ACTIONS(2234),
    [anon_sym_NULL] = ACTIONS(2234),
    [anon_sym_nullptr] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_try] = ACTIONS(2234),
    [anon_sym_delete] = ACTIONS(2234),
    [anon_sym_throw] = ACTIONS(2234),
    [anon_sym_namespace] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym_concept] = ACTIONS(2234),
    [anon_sym_co_return] = ACTIONS(2234),
    [anon_sym_co_yield] = ACTIONS(2234),
    [anon_sym_R_DQUOTE] = ACTIONS(2236),
    [anon_sym_LR_DQUOTE] = ACTIONS(2236),
    [anon_sym_uR_DQUOTE] = ACTIONS(2236),
    [anon_sym_UR_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2236),
    [anon_sym_co_await] = ACTIONS(2234),
    [anon_sym_new] = ACTIONS(2234),
    [anon_sym_requires] = ACTIONS(2234),
    [sym_this] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(227)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_include_token1] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token2] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [aux_sym_preproc_else_token1] = ACTIONS(2234),
    [aux_sym_preproc_elif_token1] = ACTIONS(2234),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_BANG] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_DASH] = ACTIONS(2234),
    [anon_sym_PLUS] = ACTIONS(2234),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym___cdecl] = ACTIONS(2234),
    [anon_sym___clrcall] = ACTIONS(2234),
    [anon_sym___stdcall] = ACTIONS(2234),
    [anon_sym___fastcall] = ACTIONS(2234),
    [anon_sym___thiscall] = ACTIONS(2234),
    [anon_sym___vectorcall] = ACTIONS(2234),
    [anon_sym_LBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [anon_sym_if] = ACTIONS(2234),
    [anon_sym_switch] = ACTIONS(2234),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym_default] = ACTIONS(2234),
    [anon_sym_while] = ACTIONS(2234),
    [anon_sym_do] = ACTIONS(2234),
    [anon_sym_for] = ACTIONS(2234),
    [anon_sym_return] = ACTIONS(2234),
    [anon_sym_break] = ACTIONS(2234),
    [anon_sym_continue] = ACTIONS(2234),
    [anon_sym_goto] = ACTIONS(2234),
    [anon_sym___try] = ACTIONS(2234),
    [anon_sym___leave] = ACTIONS(2234),
    [anon_sym_not] = ACTIONS(2234),
    [anon_sym_compl] = ACTIONS(2234),
    [anon_sym_DASH_DASH] = ACTIONS(2236),
    [anon_sym_PLUS_PLUS] = ACTIONS(2236),
    [anon_sym_sizeof] = ACTIONS(2234),
    [anon_sym___alignof__] = ACTIONS(2234),
    [anon_sym___alignof] = ACTIONS(2234),
    [anon_sym__alignof] = ACTIONS(2234),
    [anon_sym_alignof] = ACTIONS(2234),
    [anon_sym__Alignof] = ACTIONS(2234),
    [anon_sym_offsetof] = ACTIONS(2234),
    [anon_sym__Generic] = ACTIONS(2234),
    [anon_sym_asm] = ACTIONS(2234),
    [anon_sym___asm__] = ACTIONS(2234),
    [anon_sym___asm] = ACTIONS(2234),
    [sym_number_literal] = ACTIONS(2236),
    [anon_sym_L_SQUOTE] = ACTIONS(2236),
    [anon_sym_u_SQUOTE] = ACTIONS(2236),
    [anon_sym_U_SQUOTE] = ACTIONS(2236),
    [anon_sym_u8_SQUOTE] = ACTIONS(2236),
    [anon_sym_SQUOTE] = ACTIONS(2236),
    [anon_sym_L_DQUOTE] = ACTIONS(2236),
    [anon_sym_u_DQUOTE] = ACTIONS(2236),
    [anon_sym_U_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8_DQUOTE] = ACTIONS(2236),
    [anon_sym_DQUOTE] = ACTIONS(2236),
    [sym_true] = ACTIONS(2234),
    [sym_false] = ACTIONS(2234),
    [anon_sym_NULL] = ACTIONS(2234),
    [anon_sym_nullptr] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_try] = ACTIONS(2234),
    [anon_sym_delete] = ACTIONS(2234),
    [anon_sym_throw] = ACTIONS(2234),
    [anon_sym_namespace] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym_concept] = ACTIONS(2234),
    [anon_sym_co_return] = ACTIONS(2234),
    [anon_sym_co_yield] = ACTIONS(2234),
    [anon_sym_R_DQUOTE] = ACTIONS(2236),
    [anon_sym_LR_DQUOTE] = ACTIONS(2236),
    [anon_sym_uR_DQUOTE] = ACTIONS(2236),
    [anon_sym_UR_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2236),
    [anon_sym_co_await] = ACTIONS(2234),
    [anon_sym_new] = ACTIONS(2234),
    [anon_sym_requires] = ACTIONS(2234),
    [sym_this] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(228)] = {
    [sym_preproc_def] = STATE(246),
    [sym_preproc_function_def] = STATE(246),
    [sym_preproc_call] = STATE(246),
    [sym_preproc_if_in_field_declaration_list] = STATE(246),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(246),
    [sym_preproc_else_in_field_declaration_list] = STATE(8956),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8956),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8956),
    [sym_type_definition] = STATE(246),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(246),
    [sym_field_declaration] = STATE(246),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(246),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(246),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(246),
    [sym_operator_cast_declaration] = STATE(246),
    [sym_constructor_or_destructor_definition] = STATE(246),
    [sym_constructor_or_destructor_declaration] = STATE(246),
    [sym_friend_declaration] = STATE(246),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(246),
    [sym_alias_declaration] = STATE(246),
    [sym_static_assert_declaration] = STATE(246),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(246),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2264),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(229)] = {
    [sym_preproc_def] = STATE(231),
    [sym_preproc_function_def] = STATE(231),
    [sym_preproc_call] = STATE(231),
    [sym_preproc_if_in_field_declaration_list] = STATE(231),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(231),
    [sym_preproc_else_in_field_declaration_list] = STATE(8864),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8864),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8864),
    [sym_type_definition] = STATE(231),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(231),
    [sym_field_declaration] = STATE(231),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(231),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(231),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(231),
    [sym_operator_cast_declaration] = STATE(231),
    [sym_constructor_or_destructor_definition] = STATE(231),
    [sym_constructor_or_destructor_declaration] = STATE(231),
    [sym_friend_declaration] = STATE(231),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(231),
    [sym_alias_declaration] = STATE(231),
    [sym_static_assert_declaration] = STATE(231),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(231),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2298),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2300),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(230)] = {
    [sym_preproc_def] = STATE(232),
    [sym_preproc_function_def] = STATE(232),
    [sym_preproc_call] = STATE(232),
    [sym_preproc_if_in_field_declaration_list] = STATE(232),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(232),
    [sym_preproc_else_in_field_declaration_list] = STATE(8931),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8931),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8931),
    [sym_type_definition] = STATE(232),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(232),
    [sym_field_declaration] = STATE(232),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(232),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(232),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(232),
    [sym_operator_cast_declaration] = STATE(232),
    [sym_constructor_or_destructor_definition] = STATE(232),
    [sym_constructor_or_destructor_declaration] = STATE(232),
    [sym_friend_declaration] = STATE(232),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(232),
    [sym_alias_declaration] = STATE(232),
    [sym_static_assert_declaration] = STATE(232),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(232),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2302),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2304),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(231)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_preproc_else_in_field_declaration_list] = STATE(8936),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8936),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8936),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2306),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(232)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_preproc_else_in_field_declaration_list] = STATE(9003),
    [sym_preproc_elif_in_field_declaration_list] = STATE(9003),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(9003),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2310),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(233)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [aux_sym_preproc_else_token1] = ACTIONS(2312),
    [aux_sym_preproc_elif_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [anon_sym___asm] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(234)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [aux_sym_preproc_else_token1] = ACTIONS(2312),
    [aux_sym_preproc_elif_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [anon_sym___asm] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(235)] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_include_token1] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token2] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [aux_sym_preproc_else_token1] = ACTIONS(2316),
    [aux_sym_preproc_elif_token1] = ACTIONS(2316),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_BANG] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym___device__] = ACTIONS(2316),
    [anon_sym___host__] = ACTIONS(2316),
    [anon_sym___global__] = ACTIONS(2316),
    [anon_sym___forceinline__] = ACTIONS(2316),
    [anon_sym___noinline__] = ACTIONS(2316),
    [anon_sym_virtual] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym___attribute] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym___cdecl] = ACTIONS(2316),
    [anon_sym___clrcall] = ACTIONS(2316),
    [anon_sym___stdcall] = ACTIONS(2316),
    [anon_sym___fastcall] = ACTIONS(2316),
    [anon_sym___thiscall] = ACTIONS(2316),
    [anon_sym___vectorcall] = ACTIONS(2316),
    [anon_sym_LBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym__Nonnull] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym___shared__] = ACTIONS(2316),
    [anon_sym___local__] = ACTIONS(2316),
    [anon_sym___constant__] = ACTIONS(2316),
    [anon_sym___managed__] = ACTIONS(2316),
    [anon_sym___grid_constant__] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_switch] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_default] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_return] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_goto] = ACTIONS(2316),
    [anon_sym___try] = ACTIONS(2316),
    [anon_sym___leave] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_compl] = ACTIONS(2316),
    [anon_sym_DASH_DASH] = ACTIONS(2318),
    [anon_sym_PLUS_PLUS] = ACTIONS(2318),
    [anon_sym_sizeof] = ACTIONS(2316),
    [anon_sym___alignof__] = ACTIONS(2316),
    [anon_sym___alignof] = ACTIONS(2316),
    [anon_sym__alignof] = ACTIONS(2316),
    [anon_sym_alignof] = ACTIONS(2316),
    [anon_sym__Alignof] = ACTIONS(2316),
    [anon_sym_offsetof] = ACTIONS(2316),
    [anon_sym__Generic] = ACTIONS(2316),
    [anon_sym_asm] = ACTIONS(2316),
    [anon_sym___asm__] = ACTIONS(2316),
    [anon_sym___asm] = ACTIONS(2316),
    [sym_number_literal] = ACTIONS(2318),
    [anon_sym_L_SQUOTE] = ACTIONS(2318),
    [anon_sym_u_SQUOTE] = ACTIONS(2318),
    [anon_sym_U_SQUOTE] = ACTIONS(2318),
    [anon_sym_u8_SQUOTE] = ACTIONS(2318),
    [anon_sym_SQUOTE] = ACTIONS(2318),
    [anon_sym_L_DQUOTE] = ACTIONS(2318),
    [anon_sym_u_DQUOTE] = ACTIONS(2318),
    [anon_sym_U_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8_DQUOTE] = ACTIONS(2318),
    [anon_sym_DQUOTE] = ACTIONS(2318),
    [sym_true] = ACTIONS(2316),
    [sym_false] = ACTIONS(2316),
    [anon_sym_NULL] = ACTIONS(2316),
    [anon_sym_nullptr] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_try] = ACTIONS(2316),
    [anon_sym_delete] = ACTIONS(2316),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_namespace] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_concept] = ACTIONS(2316),
    [anon_sym_co_return] = ACTIONS(2316),
    [anon_sym_co_yield] = ACTIONS(2316),
    [anon_sym_R_DQUOTE] = ACTIONS(2318),
    [anon_sym_LR_DQUOTE] = ACTIONS(2318),
    [anon_sym_uR_DQUOTE] = ACTIONS(2318),
    [anon_sym_UR_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2318),
    [anon_sym_co_await] = ACTIONS(2316),
    [anon_sym_new] = ACTIONS(2316),
    [anon_sym_requires] = ACTIONS(2316),
    [sym_this] = ACTIONS(2316),
    [anon_sym___launch_bounds__] = ACTIONS(2316),
  },
  [STATE(236)] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_include_token1] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token2] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [aux_sym_preproc_else_token1] = ACTIONS(2320),
    [aux_sym_preproc_elif_token1] = ACTIONS(2320),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_BANG] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym___device__] = ACTIONS(2320),
    [anon_sym___host__] = ACTIONS(2320),
    [anon_sym___global__] = ACTIONS(2320),
    [anon_sym___forceinline__] = ACTIONS(2320),
    [anon_sym___noinline__] = ACTIONS(2320),
    [anon_sym_virtual] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym___attribute] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym___cdecl] = ACTIONS(2320),
    [anon_sym___clrcall] = ACTIONS(2320),
    [anon_sym___stdcall] = ACTIONS(2320),
    [anon_sym___fastcall] = ACTIONS(2320),
    [anon_sym___thiscall] = ACTIONS(2320),
    [anon_sym___vectorcall] = ACTIONS(2320),
    [anon_sym_LBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym__Nonnull] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym___shared__] = ACTIONS(2320),
    [anon_sym___local__] = ACTIONS(2320),
    [anon_sym___constant__] = ACTIONS(2320),
    [anon_sym___managed__] = ACTIONS(2320),
    [anon_sym___grid_constant__] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_switch] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_default] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_do] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_return] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_goto] = ACTIONS(2320),
    [anon_sym___try] = ACTIONS(2320),
    [anon_sym___leave] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_compl] = ACTIONS(2320),
    [anon_sym_DASH_DASH] = ACTIONS(2322),
    [anon_sym_PLUS_PLUS] = ACTIONS(2322),
    [anon_sym_sizeof] = ACTIONS(2320),
    [anon_sym___alignof__] = ACTIONS(2320),
    [anon_sym___alignof] = ACTIONS(2320),
    [anon_sym__alignof] = ACTIONS(2320),
    [anon_sym_alignof] = ACTIONS(2320),
    [anon_sym__Alignof] = ACTIONS(2320),
    [anon_sym_offsetof] = ACTIONS(2320),
    [anon_sym__Generic] = ACTIONS(2320),
    [anon_sym_asm] = ACTIONS(2320),
    [anon_sym___asm__] = ACTIONS(2320),
    [anon_sym___asm] = ACTIONS(2320),
    [sym_number_literal] = ACTIONS(2322),
    [anon_sym_L_SQUOTE] = ACTIONS(2322),
    [anon_sym_u_SQUOTE] = ACTIONS(2322),
    [anon_sym_U_SQUOTE] = ACTIONS(2322),
    [anon_sym_u8_SQUOTE] = ACTIONS(2322),
    [anon_sym_SQUOTE] = ACTIONS(2322),
    [anon_sym_L_DQUOTE] = ACTIONS(2322),
    [anon_sym_u_DQUOTE] = ACTIONS(2322),
    [anon_sym_U_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8_DQUOTE] = ACTIONS(2322),
    [anon_sym_DQUOTE] = ACTIONS(2322),
    [sym_true] = ACTIONS(2320),
    [sym_false] = ACTIONS(2320),
    [anon_sym_NULL] = ACTIONS(2320),
    [anon_sym_nullptr] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_delete] = ACTIONS(2320),
    [anon_sym_throw] = ACTIONS(2320),
    [anon_sym_namespace] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_concept] = ACTIONS(2320),
    [anon_sym_co_return] = ACTIONS(2320),
    [anon_sym_co_yield] = ACTIONS(2320),
    [anon_sym_R_DQUOTE] = ACTIONS(2322),
    [anon_sym_LR_DQUOTE] = ACTIONS(2322),
    [anon_sym_uR_DQUOTE] = ACTIONS(2322),
    [anon_sym_UR_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2322),
    [anon_sym_co_await] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(2320),
    [anon_sym_requires] = ACTIONS(2320),
    [sym_this] = ACTIONS(2320),
    [anon_sym___launch_bounds__] = ACTIONS(2320),
  },
  [STATE(237)] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym___device__] = ACTIONS(2324),
    [anon_sym___host__] = ACTIONS(2324),
    [anon_sym___global__] = ACTIONS(2324),
    [anon_sym___forceinline__] = ACTIONS(2324),
    [anon_sym___noinline__] = ACTIONS(2324),
    [anon_sym_virtual] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym___attribute] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym__Nonnull] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym___shared__] = ACTIONS(2324),
    [anon_sym___local__] = ACTIONS(2324),
    [anon_sym___constant__] = ACTIONS(2324),
    [anon_sym___managed__] = ACTIONS(2324),
    [anon_sym___grid_constant__] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [anon_sym___asm] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym___launch_bounds__] = ACTIONS(2324),
  },
  [STATE(238)] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_include_token1] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token2] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [aux_sym_preproc_else_token1] = ACTIONS(2328),
    [aux_sym_preproc_elif_token1] = ACTIONS(2328),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_BANG] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_DASH] = ACTIONS(2328),
    [anon_sym_PLUS] = ACTIONS(2328),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym___device__] = ACTIONS(2328),
    [anon_sym___host__] = ACTIONS(2328),
    [anon_sym___global__] = ACTIONS(2328),
    [anon_sym___forceinline__] = ACTIONS(2328),
    [anon_sym___noinline__] = ACTIONS(2328),
    [anon_sym_virtual] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym___attribute] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym___cdecl] = ACTIONS(2328),
    [anon_sym___clrcall] = ACTIONS(2328),
    [anon_sym___stdcall] = ACTIONS(2328),
    [anon_sym___fastcall] = ACTIONS(2328),
    [anon_sym___thiscall] = ACTIONS(2328),
    [anon_sym___vectorcall] = ACTIONS(2328),
    [anon_sym_LBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym__Nonnull] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym___shared__] = ACTIONS(2328),
    [anon_sym___local__] = ACTIONS(2328),
    [anon_sym___constant__] = ACTIONS(2328),
    [anon_sym___managed__] = ACTIONS(2328),
    [anon_sym___grid_constant__] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2328),
    [anon_sym_switch] = ACTIONS(2328),
    [anon_sym_case] = ACTIONS(2328),
    [anon_sym_default] = ACTIONS(2328),
    [anon_sym_while] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2328),
    [anon_sym_for] = ACTIONS(2328),
    [anon_sym_return] = ACTIONS(2328),
    [anon_sym_break] = ACTIONS(2328),
    [anon_sym_continue] = ACTIONS(2328),
    [anon_sym_goto] = ACTIONS(2328),
    [anon_sym___try] = ACTIONS(2328),
    [anon_sym___leave] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2328),
    [anon_sym_compl] = ACTIONS(2328),
    [anon_sym_DASH_DASH] = ACTIONS(2330),
    [anon_sym_PLUS_PLUS] = ACTIONS(2330),
    [anon_sym_sizeof] = ACTIONS(2328),
    [anon_sym___alignof__] = ACTIONS(2328),
    [anon_sym___alignof] = ACTIONS(2328),
    [anon_sym__alignof] = ACTIONS(2328),
    [anon_sym_alignof] = ACTIONS(2328),
    [anon_sym__Alignof] = ACTIONS(2328),
    [anon_sym_offsetof] = ACTIONS(2328),
    [anon_sym__Generic] = ACTIONS(2328),
    [anon_sym_asm] = ACTIONS(2328),
    [anon_sym___asm__] = ACTIONS(2328),
    [anon_sym___asm] = ACTIONS(2328),
    [sym_number_literal] = ACTIONS(2330),
    [anon_sym_L_SQUOTE] = ACTIONS(2330),
    [anon_sym_u_SQUOTE] = ACTIONS(2330),
    [anon_sym_U_SQUOTE] = ACTIONS(2330),
    [anon_sym_u8_SQUOTE] = ACTIONS(2330),
    [anon_sym_SQUOTE] = ACTIONS(2330),
    [anon_sym_L_DQUOTE] = ACTIONS(2330),
    [anon_sym_u_DQUOTE] = ACTIONS(2330),
    [anon_sym_U_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8_DQUOTE] = ACTIONS(2330),
    [anon_sym_DQUOTE] = ACTIONS(2330),
    [sym_true] = ACTIONS(2328),
    [sym_false] = ACTIONS(2328),
    [anon_sym_NULL] = ACTIONS(2328),
    [anon_sym_nullptr] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_delete] = ACTIONS(2328),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_namespace] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_concept] = ACTIONS(2328),
    [anon_sym_co_return] = ACTIONS(2328),
    [anon_sym_co_yield] = ACTIONS(2328),
    [anon_sym_R_DQUOTE] = ACTIONS(2330),
    [anon_sym_LR_DQUOTE] = ACTIONS(2330),
    [anon_sym_uR_DQUOTE] = ACTIONS(2330),
    [anon_sym_UR_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2330),
    [anon_sym_co_await] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(2328),
    [anon_sym_requires] = ACTIONS(2328),
    [sym_this] = ACTIONS(2328),
    [anon_sym___launch_bounds__] = ACTIONS(2328),
  },
  [STATE(239)] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym___device__] = ACTIONS(2332),
    [anon_sym___host__] = ACTIONS(2332),
    [anon_sym___global__] = ACTIONS(2332),
    [anon_sym___forceinline__] = ACTIONS(2332),
    [anon_sym___noinline__] = ACTIONS(2332),
    [anon_sym_virtual] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym___attribute] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym__Nonnull] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym___shared__] = ACTIONS(2332),
    [anon_sym___local__] = ACTIONS(2332),
    [anon_sym___constant__] = ACTIONS(2332),
    [anon_sym___managed__] = ACTIONS(2332),
    [anon_sym___grid_constant__] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [anon_sym___asm] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym___launch_bounds__] = ACTIONS(2332),
  },
  [STATE(240)] = {
    [sym_catch_clause] = STATE(240),
    [aux_sym_constructor_try_statement_repeat1] = STATE(240),
    [ts_builtin_sym_end] = ACTIONS(1942),
    [sym_identifier] = ACTIONS(1940),
    [aux_sym_preproc_include_token1] = ACTIONS(1940),
    [aux_sym_preproc_def_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1940),
    [sym_preproc_directive] = ACTIONS(1940),
    [anon_sym_LPAREN2] = ACTIONS(1942),
    [anon_sym_BANG] = ACTIONS(1942),
    [anon_sym_TILDE] = ACTIONS(1942),
    [anon_sym_DASH] = ACTIONS(1940),
    [anon_sym_PLUS] = ACTIONS(1940),
    [anon_sym_STAR] = ACTIONS(1942),
    [anon_sym_AMP_AMP] = ACTIONS(1942),
    [anon_sym_AMP] = ACTIONS(1940),
    [anon_sym_SEMI] = ACTIONS(1942),
    [anon_sym___extension__] = ACTIONS(1940),
    [anon_sym_typedef] = ACTIONS(1940),
    [anon_sym___device__] = ACTIONS(1940),
    [anon_sym___host__] = ACTIONS(1940),
    [anon_sym___global__] = ACTIONS(1940),
    [anon_sym___forceinline__] = ACTIONS(1940),
    [anon_sym___noinline__] = ACTIONS(1940),
    [anon_sym_virtual] = ACTIONS(1940),
    [anon_sym_extern] = ACTIONS(1940),
    [anon_sym___attribute__] = ACTIONS(1940),
    [anon_sym___attribute] = ACTIONS(1940),
    [anon_sym_COLON_COLON] = ACTIONS(1942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1942),
    [anon_sym___declspec] = ACTIONS(1940),
    [anon_sym___based] = ACTIONS(1940),
    [anon_sym___cdecl] = ACTIONS(1940),
    [anon_sym___clrcall] = ACTIONS(1940),
    [anon_sym___stdcall] = ACTIONS(1940),
    [anon_sym___fastcall] = ACTIONS(1940),
    [anon_sym___thiscall] = ACTIONS(1940),
    [anon_sym___vectorcall] = ACTIONS(1940),
    [anon_sym_LBRACE] = ACTIONS(1942),
    [anon_sym_signed] = ACTIONS(1940),
    [anon_sym_unsigned] = ACTIONS(1940),
    [anon_sym_long] = ACTIONS(1940),
    [anon_sym_short] = ACTIONS(1940),
    [anon_sym_LBRACK] = ACTIONS(1940),
    [anon_sym_static] = ACTIONS(1940),
    [anon_sym_register] = ACTIONS(1940),
    [anon_sym_inline] = ACTIONS(1940),
    [anon_sym___inline] = ACTIONS(1940),
    [anon_sym___inline__] = ACTIONS(1940),
    [anon_sym___forceinline] = ACTIONS(1940),
    [anon_sym_thread_local] = ACTIONS(1940),
    [anon_sym___thread] = ACTIONS(1940),
    [anon_sym_const] = ACTIONS(1940),
    [anon_sym_constexpr] = ACTIONS(1940),
    [anon_sym_volatile] = ACTIONS(1940),
    [anon_sym_restrict] = ACTIONS(1940),
    [anon_sym___restrict__] = ACTIONS(1940),
    [anon_sym__Atomic] = ACTIONS(1940),
    [anon_sym__Noreturn] = ACTIONS(1940),
    [anon_sym_noreturn] = ACTIONS(1940),
    [anon_sym__Nonnull] = ACTIONS(1940),
    [anon_sym_mutable] = ACTIONS(1940),
    [anon_sym_constinit] = ACTIONS(1940),
    [anon_sym_consteval] = ACTIONS(1940),
    [anon_sym___shared__] = ACTIONS(1940),
    [anon_sym___local__] = ACTIONS(1940),
    [anon_sym___constant__] = ACTIONS(1940),
    [anon_sym___managed__] = ACTIONS(1940),
    [anon_sym___grid_constant__] = ACTIONS(1940),
    [anon_sym_alignas] = ACTIONS(1940),
    [anon_sym__Alignas] = ACTIONS(1940),
    [sym_primitive_type] = ACTIONS(1940),
    [anon_sym_enum] = ACTIONS(1940),
    [anon_sym_class] = ACTIONS(1940),
    [anon_sym_struct] = ACTIONS(1940),
    [anon_sym_union] = ACTIONS(1940),
    [anon_sym_if] = ACTIONS(1940),
    [anon_sym_else] = ACTIONS(1940),
    [anon_sym_switch] = ACTIONS(1940),
    [anon_sym_case] = ACTIONS(1940),
    [anon_sym_default] = ACTIONS(1940),
    [anon_sym_while] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_for] = ACTIONS(1940),
    [anon_sym_return] = ACTIONS(1940),
    [anon_sym_break] = ACTIONS(1940),
    [anon_sym_continue] = ACTIONS(1940),
    [anon_sym_goto] = ACTIONS(1940),
    [anon_sym___try] = ACTIONS(1940),
    [anon_sym___leave] = ACTIONS(1940),
    [anon_sym_not] = ACTIONS(1940),
    [anon_sym_compl] = ACTIONS(1940),
    [anon_sym_DASH_DASH] = ACTIONS(1942),
    [anon_sym_PLUS_PLUS] = ACTIONS(1942),
    [anon_sym_sizeof] = ACTIONS(1940),
    [anon_sym___alignof__] = ACTIONS(1940),
    [anon_sym___alignof] = ACTIONS(1940),
    [anon_sym__alignof] = ACTIONS(1940),
    [anon_sym_alignof] = ACTIONS(1940),
    [anon_sym__Alignof] = ACTIONS(1940),
    [anon_sym_offsetof] = ACTIONS(1940),
    [anon_sym__Generic] = ACTIONS(1940),
    [anon_sym_asm] = ACTIONS(1940),
    [anon_sym___asm__] = ACTIONS(1940),
    [anon_sym___asm] = ACTIONS(1940),
    [sym_number_literal] = ACTIONS(1942),
    [anon_sym_L_SQUOTE] = ACTIONS(1942),
    [anon_sym_u_SQUOTE] = ACTIONS(1942),
    [anon_sym_U_SQUOTE] = ACTIONS(1942),
    [anon_sym_u8_SQUOTE] = ACTIONS(1942),
    [anon_sym_SQUOTE] = ACTIONS(1942),
    [anon_sym_L_DQUOTE] = ACTIONS(1942),
    [anon_sym_u_DQUOTE] = ACTIONS(1942),
    [anon_sym_U_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8_DQUOTE] = ACTIONS(1942),
    [anon_sym_DQUOTE] = ACTIONS(1942),
    [sym_true] = ACTIONS(1940),
    [sym_false] = ACTIONS(1940),
    [anon_sym_NULL] = ACTIONS(1940),
    [anon_sym_nullptr] = ACTIONS(1940),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1940),
    [anon_sym_decltype] = ACTIONS(1940),
    [anon_sym_explicit] = ACTIONS(1940),
    [anon_sym_typename] = ACTIONS(1940),
    [anon_sym_template] = ACTIONS(1940),
    [anon_sym_operator] = ACTIONS(1940),
    [anon_sym_try] = ACTIONS(1940),
    [anon_sym_delete] = ACTIONS(1940),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_namespace] = ACTIONS(1940),
    [anon_sym_using] = ACTIONS(1940),
    [anon_sym_static_assert] = ACTIONS(1940),
    [anon_sym_concept] = ACTIONS(1940),
    [anon_sym_co_return] = ACTIONS(1940),
    [anon_sym_co_yield] = ACTIONS(1940),
    [anon_sym_catch] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(1942),
    [anon_sym_LR_DQUOTE] = ACTIONS(1942),
    [anon_sym_uR_DQUOTE] = ACTIONS(1942),
    [anon_sym_UR_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1942),
    [anon_sym_co_await] = ACTIONS(1940),
    [anon_sym_new] = ACTIONS(1940),
    [anon_sym_requires] = ACTIONS(1940),
    [sym_this] = ACTIONS(1940),
    [anon_sym___launch_bounds__] = ACTIONS(1940),
  },
  [STATE(241)] = {
    [sym_identifier] = ACTIONS(2339),
    [aux_sym_preproc_include_token1] = ACTIONS(2339),
    [aux_sym_preproc_def_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token2] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2339),
    [aux_sym_preproc_else_token1] = ACTIONS(2339),
    [aux_sym_preproc_elif_token1] = ACTIONS(2339),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2339),
    [sym_preproc_directive] = ACTIONS(2339),
    [anon_sym_LPAREN2] = ACTIONS(2341),
    [anon_sym_BANG] = ACTIONS(2341),
    [anon_sym_TILDE] = ACTIONS(2341),
    [anon_sym_DASH] = ACTIONS(2339),
    [anon_sym_PLUS] = ACTIONS(2339),
    [anon_sym_STAR] = ACTIONS(2341),
    [anon_sym_AMP_AMP] = ACTIONS(2341),
    [anon_sym_AMP] = ACTIONS(2339),
    [anon_sym_SEMI] = ACTIONS(2341),
    [anon_sym___extension__] = ACTIONS(2339),
    [anon_sym_typedef] = ACTIONS(2339),
    [anon_sym___device__] = ACTIONS(2339),
    [anon_sym___host__] = ACTIONS(2339),
    [anon_sym___global__] = ACTIONS(2339),
    [anon_sym___forceinline__] = ACTIONS(2339),
    [anon_sym___noinline__] = ACTIONS(2339),
    [anon_sym_virtual] = ACTIONS(2339),
    [anon_sym_extern] = ACTIONS(2339),
    [anon_sym___attribute__] = ACTIONS(2339),
    [anon_sym___attribute] = ACTIONS(2339),
    [anon_sym_COLON_COLON] = ACTIONS(2341),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2341),
    [anon_sym___declspec] = ACTIONS(2339),
    [anon_sym___based] = ACTIONS(2339),
    [anon_sym___cdecl] = ACTIONS(2339),
    [anon_sym___clrcall] = ACTIONS(2339),
    [anon_sym___stdcall] = ACTIONS(2339),
    [anon_sym___fastcall] = ACTIONS(2339),
    [anon_sym___thiscall] = ACTIONS(2339),
    [anon_sym___vectorcall] = ACTIONS(2339),
    [anon_sym_LBRACE] = ACTIONS(2341),
    [anon_sym_signed] = ACTIONS(2339),
    [anon_sym_unsigned] = ACTIONS(2339),
    [anon_sym_long] = ACTIONS(2339),
    [anon_sym_short] = ACTIONS(2339),
    [anon_sym_LBRACK] = ACTIONS(2339),
    [anon_sym_static] = ACTIONS(2339),
    [anon_sym_register] = ACTIONS(2339),
    [anon_sym_inline] = ACTIONS(2339),
    [anon_sym___inline] = ACTIONS(2339),
    [anon_sym___inline__] = ACTIONS(2339),
    [anon_sym___forceinline] = ACTIONS(2339),
    [anon_sym_thread_local] = ACTIONS(2339),
    [anon_sym___thread] = ACTIONS(2339),
    [anon_sym_const] = ACTIONS(2339),
    [anon_sym_constexpr] = ACTIONS(2339),
    [anon_sym_volatile] = ACTIONS(2339),
    [anon_sym_restrict] = ACTIONS(2339),
    [anon_sym___restrict__] = ACTIONS(2339),
    [anon_sym__Atomic] = ACTIONS(2339),
    [anon_sym__Noreturn] = ACTIONS(2339),
    [anon_sym_noreturn] = ACTIONS(2339),
    [anon_sym__Nonnull] = ACTIONS(2339),
    [anon_sym_mutable] = ACTIONS(2339),
    [anon_sym_constinit] = ACTIONS(2339),
    [anon_sym_consteval] = ACTIONS(2339),
    [anon_sym___shared__] = ACTIONS(2339),
    [anon_sym___local__] = ACTIONS(2339),
    [anon_sym___constant__] = ACTIONS(2339),
    [anon_sym___managed__] = ACTIONS(2339),
    [anon_sym___grid_constant__] = ACTIONS(2339),
    [anon_sym_alignas] = ACTIONS(2339),
    [anon_sym__Alignas] = ACTIONS(2339),
    [sym_primitive_type] = ACTIONS(2339),
    [anon_sym_enum] = ACTIONS(2339),
    [anon_sym_class] = ACTIONS(2339),
    [anon_sym_struct] = ACTIONS(2339),
    [anon_sym_union] = ACTIONS(2339),
    [anon_sym_if] = ACTIONS(2339),
    [anon_sym_switch] = ACTIONS(2339),
    [anon_sym_case] = ACTIONS(2339),
    [anon_sym_default] = ACTIONS(2339),
    [anon_sym_while] = ACTIONS(2339),
    [anon_sym_do] = ACTIONS(2339),
    [anon_sym_for] = ACTIONS(2339),
    [anon_sym_return] = ACTIONS(2339),
    [anon_sym_break] = ACTIONS(2339),
    [anon_sym_continue] = ACTIONS(2339),
    [anon_sym_goto] = ACTIONS(2339),
    [anon_sym___try] = ACTIONS(2339),
    [anon_sym___leave] = ACTIONS(2339),
    [anon_sym_not] = ACTIONS(2339),
    [anon_sym_compl] = ACTIONS(2339),
    [anon_sym_DASH_DASH] = ACTIONS(2341),
    [anon_sym_PLUS_PLUS] = ACTIONS(2341),
    [anon_sym_sizeof] = ACTIONS(2339),
    [anon_sym___alignof__] = ACTIONS(2339),
    [anon_sym___alignof] = ACTIONS(2339),
    [anon_sym__alignof] = ACTIONS(2339),
    [anon_sym_alignof] = ACTIONS(2339),
    [anon_sym__Alignof] = ACTIONS(2339),
    [anon_sym_offsetof] = ACTIONS(2339),
    [anon_sym__Generic] = ACTIONS(2339),
    [anon_sym_asm] = ACTIONS(2339),
    [anon_sym___asm__] = ACTIONS(2339),
    [anon_sym___asm] = ACTIONS(2339),
    [sym_number_literal] = ACTIONS(2341),
    [anon_sym_L_SQUOTE] = ACTIONS(2341),
    [anon_sym_u_SQUOTE] = ACTIONS(2341),
    [anon_sym_U_SQUOTE] = ACTIONS(2341),
    [anon_sym_u8_SQUOTE] = ACTIONS(2341),
    [anon_sym_SQUOTE] = ACTIONS(2341),
    [anon_sym_L_DQUOTE] = ACTIONS(2341),
    [anon_sym_u_DQUOTE] = ACTIONS(2341),
    [anon_sym_U_DQUOTE] = ACTIONS(2341),
    [anon_sym_u8_DQUOTE] = ACTIONS(2341),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_true] = ACTIONS(2339),
    [sym_false] = ACTIONS(2339),
    [anon_sym_NULL] = ACTIONS(2339),
    [anon_sym_nullptr] = ACTIONS(2339),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2339),
    [anon_sym_decltype] = ACTIONS(2339),
    [anon_sym_explicit] = ACTIONS(2339),
    [anon_sym_typename] = ACTIONS(2339),
    [anon_sym_template] = ACTIONS(2339),
    [anon_sym_operator] = ACTIONS(2339),
    [anon_sym_try] = ACTIONS(2339),
    [anon_sym_delete] = ACTIONS(2339),
    [anon_sym_throw] = ACTIONS(2339),
    [anon_sym_namespace] = ACTIONS(2339),
    [anon_sym_using] = ACTIONS(2339),
    [anon_sym_static_assert] = ACTIONS(2339),
    [anon_sym_concept] = ACTIONS(2339),
    [anon_sym_co_return] = ACTIONS(2339),
    [anon_sym_co_yield] = ACTIONS(2339),
    [anon_sym_R_DQUOTE] = ACTIONS(2341),
    [anon_sym_LR_DQUOTE] = ACTIONS(2341),
    [anon_sym_uR_DQUOTE] = ACTIONS(2341),
    [anon_sym_UR_DQUOTE] = ACTIONS(2341),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2341),
    [anon_sym_co_await] = ACTIONS(2339),
    [anon_sym_new] = ACTIONS(2339),
    [anon_sym_requires] = ACTIONS(2339),
    [sym_this] = ACTIONS(2339),
    [anon_sym___launch_bounds__] = ACTIONS(2339),
  },
  [STATE(242)] = {
    [sym_identifier] = ACTIONS(2343),
    [aux_sym_preproc_include_token1] = ACTIONS(2343),
    [aux_sym_preproc_def_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token2] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2343),
    [aux_sym_preproc_else_token1] = ACTIONS(2343),
    [aux_sym_preproc_elif_token1] = ACTIONS(2343),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2343),
    [sym_preproc_directive] = ACTIONS(2343),
    [anon_sym_LPAREN2] = ACTIONS(2345),
    [anon_sym_BANG] = ACTIONS(2345),
    [anon_sym_TILDE] = ACTIONS(2345),
    [anon_sym_DASH] = ACTIONS(2343),
    [anon_sym_PLUS] = ACTIONS(2343),
    [anon_sym_STAR] = ACTIONS(2345),
    [anon_sym_AMP_AMP] = ACTIONS(2345),
    [anon_sym_AMP] = ACTIONS(2343),
    [anon_sym_SEMI] = ACTIONS(2345),
    [anon_sym___extension__] = ACTIONS(2343),
    [anon_sym_typedef] = ACTIONS(2343),
    [anon_sym___device__] = ACTIONS(2343),
    [anon_sym___host__] = ACTIONS(2343),
    [anon_sym___global__] = ACTIONS(2343),
    [anon_sym___forceinline__] = ACTIONS(2343),
    [anon_sym___noinline__] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2343),
    [anon_sym_extern] = ACTIONS(2343),
    [anon_sym___attribute__] = ACTIONS(2343),
    [anon_sym___attribute] = ACTIONS(2343),
    [anon_sym_COLON_COLON] = ACTIONS(2345),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2345),
    [anon_sym___declspec] = ACTIONS(2343),
    [anon_sym___based] = ACTIONS(2343),
    [anon_sym___cdecl] = ACTIONS(2343),
    [anon_sym___clrcall] = ACTIONS(2343),
    [anon_sym___stdcall] = ACTIONS(2343),
    [anon_sym___fastcall] = ACTIONS(2343),
    [anon_sym___thiscall] = ACTIONS(2343),
    [anon_sym___vectorcall] = ACTIONS(2343),
    [anon_sym_LBRACE] = ACTIONS(2345),
    [anon_sym_signed] = ACTIONS(2343),
    [anon_sym_unsigned] = ACTIONS(2343),
    [anon_sym_long] = ACTIONS(2343),
    [anon_sym_short] = ACTIONS(2343),
    [anon_sym_LBRACK] = ACTIONS(2343),
    [anon_sym_static] = ACTIONS(2343),
    [anon_sym_register] = ACTIONS(2343),
    [anon_sym_inline] = ACTIONS(2343),
    [anon_sym___inline] = ACTIONS(2343),
    [anon_sym___inline__] = ACTIONS(2343),
    [anon_sym___forceinline] = ACTIONS(2343),
    [anon_sym_thread_local] = ACTIONS(2343),
    [anon_sym___thread] = ACTIONS(2343),
    [anon_sym_const] = ACTIONS(2343),
    [anon_sym_constexpr] = ACTIONS(2343),
    [anon_sym_volatile] = ACTIONS(2343),
    [anon_sym_restrict] = ACTIONS(2343),
    [anon_sym___restrict__] = ACTIONS(2343),
    [anon_sym__Atomic] = ACTIONS(2343),
    [anon_sym__Noreturn] = ACTIONS(2343),
    [anon_sym_noreturn] = ACTIONS(2343),
    [anon_sym__Nonnull] = ACTIONS(2343),
    [anon_sym_mutable] = ACTIONS(2343),
    [anon_sym_constinit] = ACTIONS(2343),
    [anon_sym_consteval] = ACTIONS(2343),
    [anon_sym___shared__] = ACTIONS(2343),
    [anon_sym___local__] = ACTIONS(2343),
    [anon_sym___constant__] = ACTIONS(2343),
    [anon_sym___managed__] = ACTIONS(2343),
    [anon_sym___grid_constant__] = ACTIONS(2343),
    [anon_sym_alignas] = ACTIONS(2343),
    [anon_sym__Alignas] = ACTIONS(2343),
    [sym_primitive_type] = ACTIONS(2343),
    [anon_sym_enum] = ACTIONS(2343),
    [anon_sym_class] = ACTIONS(2343),
    [anon_sym_struct] = ACTIONS(2343),
    [anon_sym_union] = ACTIONS(2343),
    [anon_sym_if] = ACTIONS(2343),
    [anon_sym_switch] = ACTIONS(2343),
    [anon_sym_case] = ACTIONS(2343),
    [anon_sym_default] = ACTIONS(2343),
    [anon_sym_while] = ACTIONS(2343),
    [anon_sym_do] = ACTIONS(2343),
    [anon_sym_for] = ACTIONS(2343),
    [anon_sym_return] = ACTIONS(2343),
    [anon_sym_break] = ACTIONS(2343),
    [anon_sym_continue] = ACTIONS(2343),
    [anon_sym_goto] = ACTIONS(2343),
    [anon_sym___try] = ACTIONS(2343),
    [anon_sym___leave] = ACTIONS(2343),
    [anon_sym_not] = ACTIONS(2343),
    [anon_sym_compl] = ACTIONS(2343),
    [anon_sym_DASH_DASH] = ACTIONS(2345),
    [anon_sym_PLUS_PLUS] = ACTIONS(2345),
    [anon_sym_sizeof] = ACTIONS(2343),
    [anon_sym___alignof__] = ACTIONS(2343),
    [anon_sym___alignof] = ACTIONS(2343),
    [anon_sym__alignof] = ACTIONS(2343),
    [anon_sym_alignof] = ACTIONS(2343),
    [anon_sym__Alignof] = ACTIONS(2343),
    [anon_sym_offsetof] = ACTIONS(2343),
    [anon_sym__Generic] = ACTIONS(2343),
    [anon_sym_asm] = ACTIONS(2343),
    [anon_sym___asm__] = ACTIONS(2343),
    [anon_sym___asm] = ACTIONS(2343),
    [sym_number_literal] = ACTIONS(2345),
    [anon_sym_L_SQUOTE] = ACTIONS(2345),
    [anon_sym_u_SQUOTE] = ACTIONS(2345),
    [anon_sym_U_SQUOTE] = ACTIONS(2345),
    [anon_sym_u8_SQUOTE] = ACTIONS(2345),
    [anon_sym_SQUOTE] = ACTIONS(2345),
    [anon_sym_L_DQUOTE] = ACTIONS(2345),
    [anon_sym_u_DQUOTE] = ACTIONS(2345),
    [anon_sym_U_DQUOTE] = ACTIONS(2345),
    [anon_sym_u8_DQUOTE] = ACTIONS(2345),
    [anon_sym_DQUOTE] = ACTIONS(2345),
    [sym_true] = ACTIONS(2343),
    [sym_false] = ACTIONS(2343),
    [anon_sym_NULL] = ACTIONS(2343),
    [anon_sym_nullptr] = ACTIONS(2343),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2343),
    [anon_sym_decltype] = ACTIONS(2343),
    [anon_sym_explicit] = ACTIONS(2343),
    [anon_sym_typename] = ACTIONS(2343),
    [anon_sym_template] = ACTIONS(2343),
    [anon_sym_operator] = ACTIONS(2343),
    [anon_sym_try] = ACTIONS(2343),
    [anon_sym_delete] = ACTIONS(2343),
    [anon_sym_throw] = ACTIONS(2343),
    [anon_sym_namespace] = ACTIONS(2343),
    [anon_sym_using] = ACTIONS(2343),
    [anon_sym_static_assert] = ACTIONS(2343),
    [anon_sym_concept] = ACTIONS(2343),
    [anon_sym_co_return] = ACTIONS(2343),
    [anon_sym_co_yield] = ACTIONS(2343),
    [anon_sym_R_DQUOTE] = ACTIONS(2345),
    [anon_sym_LR_DQUOTE] = ACTIONS(2345),
    [anon_sym_uR_DQUOTE] = ACTIONS(2345),
    [anon_sym_UR_DQUOTE] = ACTIONS(2345),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2345),
    [anon_sym_co_await] = ACTIONS(2343),
    [anon_sym_new] = ACTIONS(2343),
    [anon_sym_requires] = ACTIONS(2343),
    [sym_this] = ACTIONS(2343),
    [anon_sym___launch_bounds__] = ACTIONS(2343),
  },
  [STATE(243)] = {
    [sym_identifier] = ACTIONS(2347),
    [aux_sym_preproc_include_token1] = ACTIONS(2347),
    [aux_sym_preproc_def_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token2] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2347),
    [aux_sym_preproc_else_token1] = ACTIONS(2347),
    [aux_sym_preproc_elif_token1] = ACTIONS(2347),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2347),
    [sym_preproc_directive] = ACTIONS(2347),
    [anon_sym_LPAREN2] = ACTIONS(2349),
    [anon_sym_BANG] = ACTIONS(2349),
    [anon_sym_TILDE] = ACTIONS(2349),
    [anon_sym_DASH] = ACTIONS(2347),
    [anon_sym_PLUS] = ACTIONS(2347),
    [anon_sym_STAR] = ACTIONS(2349),
    [anon_sym_AMP_AMP] = ACTIONS(2349),
    [anon_sym_AMP] = ACTIONS(2347),
    [anon_sym_SEMI] = ACTIONS(2349),
    [anon_sym___extension__] = ACTIONS(2347),
    [anon_sym_typedef] = ACTIONS(2347),
    [anon_sym___device__] = ACTIONS(2347),
    [anon_sym___host__] = ACTIONS(2347),
    [anon_sym___global__] = ACTIONS(2347),
    [anon_sym___forceinline__] = ACTIONS(2347),
    [anon_sym___noinline__] = ACTIONS(2347),
    [anon_sym_virtual] = ACTIONS(2347),
    [anon_sym_extern] = ACTIONS(2347),
    [anon_sym___attribute__] = ACTIONS(2347),
    [anon_sym___attribute] = ACTIONS(2347),
    [anon_sym_COLON_COLON] = ACTIONS(2349),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2349),
    [anon_sym___declspec] = ACTIONS(2347),
    [anon_sym___based] = ACTIONS(2347),
    [anon_sym___cdecl] = ACTIONS(2347),
    [anon_sym___clrcall] = ACTIONS(2347),
    [anon_sym___stdcall] = ACTIONS(2347),
    [anon_sym___fastcall] = ACTIONS(2347),
    [anon_sym___thiscall] = ACTIONS(2347),
    [anon_sym___vectorcall] = ACTIONS(2347),
    [anon_sym_LBRACE] = ACTIONS(2349),
    [anon_sym_signed] = ACTIONS(2347),
    [anon_sym_unsigned] = ACTIONS(2347),
    [anon_sym_long] = ACTIONS(2347),
    [anon_sym_short] = ACTIONS(2347),
    [anon_sym_LBRACK] = ACTIONS(2347),
    [anon_sym_static] = ACTIONS(2347),
    [anon_sym_register] = ACTIONS(2347),
    [anon_sym_inline] = ACTIONS(2347),
    [anon_sym___inline] = ACTIONS(2347),
    [anon_sym___inline__] = ACTIONS(2347),
    [anon_sym___forceinline] = ACTIONS(2347),
    [anon_sym_thread_local] = ACTIONS(2347),
    [anon_sym___thread] = ACTIONS(2347),
    [anon_sym_const] = ACTIONS(2347),
    [anon_sym_constexpr] = ACTIONS(2347),
    [anon_sym_volatile] = ACTIONS(2347),
    [anon_sym_restrict] = ACTIONS(2347),
    [anon_sym___restrict__] = ACTIONS(2347),
    [anon_sym__Atomic] = ACTIONS(2347),
    [anon_sym__Noreturn] = ACTIONS(2347),
    [anon_sym_noreturn] = ACTIONS(2347),
    [anon_sym__Nonnull] = ACTIONS(2347),
    [anon_sym_mutable] = ACTIONS(2347),
    [anon_sym_constinit] = ACTIONS(2347),
    [anon_sym_consteval] = ACTIONS(2347),
    [anon_sym___shared__] = ACTIONS(2347),
    [anon_sym___local__] = ACTIONS(2347),
    [anon_sym___constant__] = ACTIONS(2347),
    [anon_sym___managed__] = ACTIONS(2347),
    [anon_sym___grid_constant__] = ACTIONS(2347),
    [anon_sym_alignas] = ACTIONS(2347),
    [anon_sym__Alignas] = ACTIONS(2347),
    [sym_primitive_type] = ACTIONS(2347),
    [anon_sym_enum] = ACTIONS(2347),
    [anon_sym_class] = ACTIONS(2347),
    [anon_sym_struct] = ACTIONS(2347),
    [anon_sym_union] = ACTIONS(2347),
    [anon_sym_if] = ACTIONS(2347),
    [anon_sym_switch] = ACTIONS(2347),
    [anon_sym_case] = ACTIONS(2347),
    [anon_sym_default] = ACTIONS(2347),
    [anon_sym_while] = ACTIONS(2347),
    [anon_sym_do] = ACTIONS(2347),
    [anon_sym_for] = ACTIONS(2347),
    [anon_sym_return] = ACTIONS(2347),
    [anon_sym_break] = ACTIONS(2347),
    [anon_sym_continue] = ACTIONS(2347),
    [anon_sym_goto] = ACTIONS(2347),
    [anon_sym___try] = ACTIONS(2347),
    [anon_sym___leave] = ACTIONS(2347),
    [anon_sym_not] = ACTIONS(2347),
    [anon_sym_compl] = ACTIONS(2347),
    [anon_sym_DASH_DASH] = ACTIONS(2349),
    [anon_sym_PLUS_PLUS] = ACTIONS(2349),
    [anon_sym_sizeof] = ACTIONS(2347),
    [anon_sym___alignof__] = ACTIONS(2347),
    [anon_sym___alignof] = ACTIONS(2347),
    [anon_sym__alignof] = ACTIONS(2347),
    [anon_sym_alignof] = ACTIONS(2347),
    [anon_sym__Alignof] = ACTIONS(2347),
    [anon_sym_offsetof] = ACTIONS(2347),
    [anon_sym__Generic] = ACTIONS(2347),
    [anon_sym_asm] = ACTIONS(2347),
    [anon_sym___asm__] = ACTIONS(2347),
    [anon_sym___asm] = ACTIONS(2347),
    [sym_number_literal] = ACTIONS(2349),
    [anon_sym_L_SQUOTE] = ACTIONS(2349),
    [anon_sym_u_SQUOTE] = ACTIONS(2349),
    [anon_sym_U_SQUOTE] = ACTIONS(2349),
    [anon_sym_u8_SQUOTE] = ACTIONS(2349),
    [anon_sym_SQUOTE] = ACTIONS(2349),
    [anon_sym_L_DQUOTE] = ACTIONS(2349),
    [anon_sym_u_DQUOTE] = ACTIONS(2349),
    [anon_sym_U_DQUOTE] = ACTIONS(2349),
    [anon_sym_u8_DQUOTE] = ACTIONS(2349),
    [anon_sym_DQUOTE] = ACTIONS(2349),
    [sym_true] = ACTIONS(2347),
    [sym_false] = ACTIONS(2347),
    [anon_sym_NULL] = ACTIONS(2347),
    [anon_sym_nullptr] = ACTIONS(2347),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2347),
    [anon_sym_decltype] = ACTIONS(2347),
    [anon_sym_explicit] = ACTIONS(2347),
    [anon_sym_typename] = ACTIONS(2347),
    [anon_sym_template] = ACTIONS(2347),
    [anon_sym_operator] = ACTIONS(2347),
    [anon_sym_try] = ACTIONS(2347),
    [anon_sym_delete] = ACTIONS(2347),
    [anon_sym_throw] = ACTIONS(2347),
    [anon_sym_namespace] = ACTIONS(2347),
    [anon_sym_using] = ACTIONS(2347),
    [anon_sym_static_assert] = ACTIONS(2347),
    [anon_sym_concept] = ACTIONS(2347),
    [anon_sym_co_return] = ACTIONS(2347),
    [anon_sym_co_yield] = ACTIONS(2347),
    [anon_sym_R_DQUOTE] = ACTIONS(2349),
    [anon_sym_LR_DQUOTE] = ACTIONS(2349),
    [anon_sym_uR_DQUOTE] = ACTIONS(2349),
    [anon_sym_UR_DQUOTE] = ACTIONS(2349),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2349),
    [anon_sym_co_await] = ACTIONS(2347),
    [anon_sym_new] = ACTIONS(2347),
    [anon_sym_requires] = ACTIONS(2347),
    [sym_this] = ACTIONS(2347),
    [anon_sym___launch_bounds__] = ACTIONS(2347),
  },
  [STATE(244)] = {
    [sym_identifier] = ACTIONS(2351),
    [aux_sym_preproc_include_token1] = ACTIONS(2351),
    [aux_sym_preproc_def_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token2] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2351),
    [aux_sym_preproc_else_token1] = ACTIONS(2351),
    [aux_sym_preproc_elif_token1] = ACTIONS(2351),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2351),
    [sym_preproc_directive] = ACTIONS(2351),
    [anon_sym_LPAREN2] = ACTIONS(2353),
    [anon_sym_BANG] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(2353),
    [anon_sym_DASH] = ACTIONS(2351),
    [anon_sym_PLUS] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2353),
    [anon_sym_AMP_AMP] = ACTIONS(2353),
    [anon_sym_AMP] = ACTIONS(2351),
    [anon_sym_SEMI] = ACTIONS(2353),
    [anon_sym___extension__] = ACTIONS(2351),
    [anon_sym_typedef] = ACTIONS(2351),
    [anon_sym___device__] = ACTIONS(2351),
    [anon_sym___host__] = ACTIONS(2351),
    [anon_sym___global__] = ACTIONS(2351),
    [anon_sym___forceinline__] = ACTIONS(2351),
    [anon_sym___noinline__] = ACTIONS(2351),
    [anon_sym_virtual] = ACTIONS(2351),
    [anon_sym_extern] = ACTIONS(2351),
    [anon_sym___attribute__] = ACTIONS(2351),
    [anon_sym___attribute] = ACTIONS(2351),
    [anon_sym_COLON_COLON] = ACTIONS(2353),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2353),
    [anon_sym___declspec] = ACTIONS(2351),
    [anon_sym___based] = ACTIONS(2351),
    [anon_sym___cdecl] = ACTIONS(2351),
    [anon_sym___clrcall] = ACTIONS(2351),
    [anon_sym___stdcall] = ACTIONS(2351),
    [anon_sym___fastcall] = ACTIONS(2351),
    [anon_sym___thiscall] = ACTIONS(2351),
    [anon_sym___vectorcall] = ACTIONS(2351),
    [anon_sym_LBRACE] = ACTIONS(2353),
    [anon_sym_signed] = ACTIONS(2351),
    [anon_sym_unsigned] = ACTIONS(2351),
    [anon_sym_long] = ACTIONS(2351),
    [anon_sym_short] = ACTIONS(2351),
    [anon_sym_LBRACK] = ACTIONS(2351),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_register] = ACTIONS(2351),
    [anon_sym_inline] = ACTIONS(2351),
    [anon_sym___inline] = ACTIONS(2351),
    [anon_sym___inline__] = ACTIONS(2351),
    [anon_sym___forceinline] = ACTIONS(2351),
    [anon_sym_thread_local] = ACTIONS(2351),
    [anon_sym___thread] = ACTIONS(2351),
    [anon_sym_const] = ACTIONS(2351),
    [anon_sym_constexpr] = ACTIONS(2351),
    [anon_sym_volatile] = ACTIONS(2351),
    [anon_sym_restrict] = ACTIONS(2351),
    [anon_sym___restrict__] = ACTIONS(2351),
    [anon_sym__Atomic] = ACTIONS(2351),
    [anon_sym__Noreturn] = ACTIONS(2351),
    [anon_sym_noreturn] = ACTIONS(2351),
    [anon_sym__Nonnull] = ACTIONS(2351),
    [anon_sym_mutable] = ACTIONS(2351),
    [anon_sym_constinit] = ACTIONS(2351),
    [anon_sym_consteval] = ACTIONS(2351),
    [anon_sym___shared__] = ACTIONS(2351),
    [anon_sym___local__] = ACTIONS(2351),
    [anon_sym___constant__] = ACTIONS(2351),
    [anon_sym___managed__] = ACTIONS(2351),
    [anon_sym___grid_constant__] = ACTIONS(2351),
    [anon_sym_alignas] = ACTIONS(2351),
    [anon_sym__Alignas] = ACTIONS(2351),
    [sym_primitive_type] = ACTIONS(2351),
    [anon_sym_enum] = ACTIONS(2351),
    [anon_sym_class] = ACTIONS(2351),
    [anon_sym_struct] = ACTIONS(2351),
    [anon_sym_union] = ACTIONS(2351),
    [anon_sym_if] = ACTIONS(2351),
    [anon_sym_switch] = ACTIONS(2351),
    [anon_sym_case] = ACTIONS(2351),
    [anon_sym_default] = ACTIONS(2351),
    [anon_sym_while] = ACTIONS(2351),
    [anon_sym_do] = ACTIONS(2351),
    [anon_sym_for] = ACTIONS(2351),
    [anon_sym_return] = ACTIONS(2351),
    [anon_sym_break] = ACTIONS(2351),
    [anon_sym_continue] = ACTIONS(2351),
    [anon_sym_goto] = ACTIONS(2351),
    [anon_sym___try] = ACTIONS(2351),
    [anon_sym___leave] = ACTIONS(2351),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_compl] = ACTIONS(2351),
    [anon_sym_DASH_DASH] = ACTIONS(2353),
    [anon_sym_PLUS_PLUS] = ACTIONS(2353),
    [anon_sym_sizeof] = ACTIONS(2351),
    [anon_sym___alignof__] = ACTIONS(2351),
    [anon_sym___alignof] = ACTIONS(2351),
    [anon_sym__alignof] = ACTIONS(2351),
    [anon_sym_alignof] = ACTIONS(2351),
    [anon_sym__Alignof] = ACTIONS(2351),
    [anon_sym_offsetof] = ACTIONS(2351),
    [anon_sym__Generic] = ACTIONS(2351),
    [anon_sym_asm] = ACTIONS(2351),
    [anon_sym___asm__] = ACTIONS(2351),
    [anon_sym___asm] = ACTIONS(2351),
    [sym_number_literal] = ACTIONS(2353),
    [anon_sym_L_SQUOTE] = ACTIONS(2353),
    [anon_sym_u_SQUOTE] = ACTIONS(2353),
    [anon_sym_U_SQUOTE] = ACTIONS(2353),
    [anon_sym_u8_SQUOTE] = ACTIONS(2353),
    [anon_sym_SQUOTE] = ACTIONS(2353),
    [anon_sym_L_DQUOTE] = ACTIONS(2353),
    [anon_sym_u_DQUOTE] = ACTIONS(2353),
    [anon_sym_U_DQUOTE] = ACTIONS(2353),
    [anon_sym_u8_DQUOTE] = ACTIONS(2353),
    [anon_sym_DQUOTE] = ACTIONS(2353),
    [sym_true] = ACTIONS(2351),
    [sym_false] = ACTIONS(2351),
    [anon_sym_NULL] = ACTIONS(2351),
    [anon_sym_nullptr] = ACTIONS(2351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2351),
    [anon_sym_decltype] = ACTIONS(2351),
    [anon_sym_explicit] = ACTIONS(2351),
    [anon_sym_typename] = ACTIONS(2351),
    [anon_sym_template] = ACTIONS(2351),
    [anon_sym_operator] = ACTIONS(2351),
    [anon_sym_try] = ACTIONS(2351),
    [anon_sym_delete] = ACTIONS(2351),
    [anon_sym_throw] = ACTIONS(2351),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_using] = ACTIONS(2351),
    [anon_sym_static_assert] = ACTIONS(2351),
    [anon_sym_concept] = ACTIONS(2351),
    [anon_sym_co_return] = ACTIONS(2351),
    [anon_sym_co_yield] = ACTIONS(2351),
    [anon_sym_R_DQUOTE] = ACTIONS(2353),
    [anon_sym_LR_DQUOTE] = ACTIONS(2353),
    [anon_sym_uR_DQUOTE] = ACTIONS(2353),
    [anon_sym_UR_DQUOTE] = ACTIONS(2353),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2353),
    [anon_sym_co_await] = ACTIONS(2351),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_requires] = ACTIONS(2351),
    [sym_this] = ACTIONS(2351),
    [anon_sym___launch_bounds__] = ACTIONS(2351),
  },
  [STATE(245)] = {
    [sym_preproc_def] = STATE(253),
    [sym_preproc_function_def] = STATE(253),
    [sym_preproc_call] = STATE(253),
    [sym_preproc_if_in_field_declaration_list] = STATE(253),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(253),
    [sym_preproc_else_in_field_declaration_list] = STATE(8703),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8703),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8703),
    [sym_type_definition] = STATE(253),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(253),
    [sym_field_declaration] = STATE(253),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(253),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(253),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(253),
    [sym_operator_cast_declaration] = STATE(253),
    [sym_constructor_or_destructor_definition] = STATE(253),
    [sym_constructor_or_destructor_declaration] = STATE(253),
    [sym_friend_declaration] = STATE(253),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(253),
    [sym_alias_declaration] = STATE(253),
    [sym_static_assert_declaration] = STATE(253),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(253),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2355),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2357),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(246)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_preproc_else_in_field_declaration_list] = STATE(8749),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8749),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8749),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2359),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(247)] = {
    [sym_preproc_def] = STATE(249),
    [sym_preproc_function_def] = STATE(249),
    [sym_preproc_call] = STATE(249),
    [sym_preproc_if_in_field_declaration_list] = STATE(249),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(249),
    [sym_preproc_else_in_field_declaration_list] = STATE(8627),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8627),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8627),
    [sym_type_definition] = STATE(249),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(249),
    [sym_field_declaration] = STATE(249),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(249),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(249),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(249),
    [sym_operator_cast_declaration] = STATE(249),
    [sym_constructor_or_destructor_definition] = STATE(249),
    [sym_constructor_or_destructor_declaration] = STATE(249),
    [sym_friend_declaration] = STATE(249),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(249),
    [sym_alias_declaration] = STATE(249),
    [sym_static_assert_declaration] = STATE(249),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(249),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2361),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2363),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(248)] = {
    [sym_preproc_def] = STATE(250),
    [sym_preproc_function_def] = STATE(250),
    [sym_preproc_call] = STATE(250),
    [sym_preproc_if_in_field_declaration_list] = STATE(250),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(250),
    [sym_preproc_else_in_field_declaration_list] = STATE(9308),
    [sym_preproc_elif_in_field_declaration_list] = STATE(9308),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(9308),
    [sym_type_definition] = STATE(250),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(250),
    [sym_field_declaration] = STATE(250),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(250),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(250),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(250),
    [sym_operator_cast_declaration] = STATE(250),
    [sym_constructor_or_destructor_definition] = STATE(250),
    [sym_constructor_or_destructor_declaration] = STATE(250),
    [sym_friend_declaration] = STATE(250),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(250),
    [sym_alias_declaration] = STATE(250),
    [sym_static_assert_declaration] = STATE(250),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(250),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2365),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2367),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(249)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_preproc_else_in_field_declaration_list] = STATE(9394),
    [sym_preproc_elif_in_field_declaration_list] = STATE(9394),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(9394),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2369),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(250)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_preproc_else_in_field_declaration_list] = STATE(8678),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8678),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8678),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(251)] = {
    [sym_identifier] = ACTIONS(2373),
    [aux_sym_preproc_include_token1] = ACTIONS(2373),
    [aux_sym_preproc_def_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token2] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2373),
    [aux_sym_preproc_else_token1] = ACTIONS(2373),
    [aux_sym_preproc_elif_token1] = ACTIONS(2373),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2373),
    [sym_preproc_directive] = ACTIONS(2373),
    [anon_sym_LPAREN2] = ACTIONS(2375),
    [anon_sym_BANG] = ACTIONS(2375),
    [anon_sym_TILDE] = ACTIONS(2375),
    [anon_sym_DASH] = ACTIONS(2373),
    [anon_sym_PLUS] = ACTIONS(2373),
    [anon_sym_STAR] = ACTIONS(2375),
    [anon_sym_AMP_AMP] = ACTIONS(2375),
    [anon_sym_AMP] = ACTIONS(2373),
    [anon_sym_SEMI] = ACTIONS(2375),
    [anon_sym___extension__] = ACTIONS(2373),
    [anon_sym_typedef] = ACTIONS(2373),
    [anon_sym___device__] = ACTIONS(2373),
    [anon_sym___host__] = ACTIONS(2373),
    [anon_sym___global__] = ACTIONS(2373),
    [anon_sym___forceinline__] = ACTIONS(2373),
    [anon_sym___noinline__] = ACTIONS(2373),
    [anon_sym_virtual] = ACTIONS(2373),
    [anon_sym_extern] = ACTIONS(2373),
    [anon_sym___attribute__] = ACTIONS(2373),
    [anon_sym___attribute] = ACTIONS(2373),
    [anon_sym_COLON_COLON] = ACTIONS(2375),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2375),
    [anon_sym___declspec] = ACTIONS(2373),
    [anon_sym___based] = ACTIONS(2373),
    [anon_sym___cdecl] = ACTIONS(2373),
    [anon_sym___clrcall] = ACTIONS(2373),
    [anon_sym___stdcall] = ACTIONS(2373),
    [anon_sym___fastcall] = ACTIONS(2373),
    [anon_sym___thiscall] = ACTIONS(2373),
    [anon_sym___vectorcall] = ACTIONS(2373),
    [anon_sym_LBRACE] = ACTIONS(2375),
    [anon_sym_signed] = ACTIONS(2373),
    [anon_sym_unsigned] = ACTIONS(2373),
    [anon_sym_long] = ACTIONS(2373),
    [anon_sym_short] = ACTIONS(2373),
    [anon_sym_LBRACK] = ACTIONS(2373),
    [anon_sym_static] = ACTIONS(2373),
    [anon_sym_register] = ACTIONS(2373),
    [anon_sym_inline] = ACTIONS(2373),
    [anon_sym___inline] = ACTIONS(2373),
    [anon_sym___inline__] = ACTIONS(2373),
    [anon_sym___forceinline] = ACTIONS(2373),
    [anon_sym_thread_local] = ACTIONS(2373),
    [anon_sym___thread] = ACTIONS(2373),
    [anon_sym_const] = ACTIONS(2373),
    [anon_sym_constexpr] = ACTIONS(2373),
    [anon_sym_volatile] = ACTIONS(2373),
    [anon_sym_restrict] = ACTIONS(2373),
    [anon_sym___restrict__] = ACTIONS(2373),
    [anon_sym__Atomic] = ACTIONS(2373),
    [anon_sym__Noreturn] = ACTIONS(2373),
    [anon_sym_noreturn] = ACTIONS(2373),
    [anon_sym__Nonnull] = ACTIONS(2373),
    [anon_sym_mutable] = ACTIONS(2373),
    [anon_sym_constinit] = ACTIONS(2373),
    [anon_sym_consteval] = ACTIONS(2373),
    [anon_sym___shared__] = ACTIONS(2373),
    [anon_sym___local__] = ACTIONS(2373),
    [anon_sym___constant__] = ACTIONS(2373),
    [anon_sym___managed__] = ACTIONS(2373),
    [anon_sym___grid_constant__] = ACTIONS(2373),
    [anon_sym_alignas] = ACTIONS(2373),
    [anon_sym__Alignas] = ACTIONS(2373),
    [sym_primitive_type] = ACTIONS(2373),
    [anon_sym_enum] = ACTIONS(2373),
    [anon_sym_class] = ACTIONS(2373),
    [anon_sym_struct] = ACTIONS(2373),
    [anon_sym_union] = ACTIONS(2373),
    [anon_sym_if] = ACTIONS(2373),
    [anon_sym_switch] = ACTIONS(2373),
    [anon_sym_case] = ACTIONS(2373),
    [anon_sym_default] = ACTIONS(2373),
    [anon_sym_while] = ACTIONS(2373),
    [anon_sym_do] = ACTIONS(2373),
    [anon_sym_for] = ACTIONS(2373),
    [anon_sym_return] = ACTIONS(2373),
    [anon_sym_break] = ACTIONS(2373),
    [anon_sym_continue] = ACTIONS(2373),
    [anon_sym_goto] = ACTIONS(2373),
    [anon_sym___try] = ACTIONS(2373),
    [anon_sym___leave] = ACTIONS(2373),
    [anon_sym_not] = ACTIONS(2373),
    [anon_sym_compl] = ACTIONS(2373),
    [anon_sym_DASH_DASH] = ACTIONS(2375),
    [anon_sym_PLUS_PLUS] = ACTIONS(2375),
    [anon_sym_sizeof] = ACTIONS(2373),
    [anon_sym___alignof__] = ACTIONS(2373),
    [anon_sym___alignof] = ACTIONS(2373),
    [anon_sym__alignof] = ACTIONS(2373),
    [anon_sym_alignof] = ACTIONS(2373),
    [anon_sym__Alignof] = ACTIONS(2373),
    [anon_sym_offsetof] = ACTIONS(2373),
    [anon_sym__Generic] = ACTIONS(2373),
    [anon_sym_asm] = ACTIONS(2373),
    [anon_sym___asm__] = ACTIONS(2373),
    [anon_sym___asm] = ACTIONS(2373),
    [sym_number_literal] = ACTIONS(2375),
    [anon_sym_L_SQUOTE] = ACTIONS(2375),
    [anon_sym_u_SQUOTE] = ACTIONS(2375),
    [anon_sym_U_SQUOTE] = ACTIONS(2375),
    [anon_sym_u8_SQUOTE] = ACTIONS(2375),
    [anon_sym_SQUOTE] = ACTIONS(2375),
    [anon_sym_L_DQUOTE] = ACTIONS(2375),
    [anon_sym_u_DQUOTE] = ACTIONS(2375),
    [anon_sym_U_DQUOTE] = ACTIONS(2375),
    [anon_sym_u8_DQUOTE] = ACTIONS(2375),
    [anon_sym_DQUOTE] = ACTIONS(2375),
    [sym_true] = ACTIONS(2373),
    [sym_false] = ACTIONS(2373),
    [anon_sym_NULL] = ACTIONS(2373),
    [anon_sym_nullptr] = ACTIONS(2373),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2373),
    [anon_sym_decltype] = ACTIONS(2373),
    [anon_sym_explicit] = ACTIONS(2373),
    [anon_sym_typename] = ACTIONS(2373),
    [anon_sym_template] = ACTIONS(2373),
    [anon_sym_operator] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2373),
    [anon_sym_delete] = ACTIONS(2373),
    [anon_sym_throw] = ACTIONS(2373),
    [anon_sym_namespace] = ACTIONS(2373),
    [anon_sym_using] = ACTIONS(2373),
    [anon_sym_static_assert] = ACTIONS(2373),
    [anon_sym_concept] = ACTIONS(2373),
    [anon_sym_co_return] = ACTIONS(2373),
    [anon_sym_co_yield] = ACTIONS(2373),
    [anon_sym_R_DQUOTE] = ACTIONS(2375),
    [anon_sym_LR_DQUOTE] = ACTIONS(2375),
    [anon_sym_uR_DQUOTE] = ACTIONS(2375),
    [anon_sym_UR_DQUOTE] = ACTIONS(2375),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2375),
    [anon_sym_co_await] = ACTIONS(2373),
    [anon_sym_new] = ACTIONS(2373),
    [anon_sym_requires] = ACTIONS(2373),
    [sym_this] = ACTIONS(2373),
    [anon_sym___launch_bounds__] = ACTIONS(2373),
  },
  [STATE(252)] = {
    [sym_identifier] = ACTIONS(2377),
    [aux_sym_preproc_include_token1] = ACTIONS(2377),
    [aux_sym_preproc_def_token1] = ACTIONS(2377),
    [aux_sym_preproc_if_token1] = ACTIONS(2377),
    [aux_sym_preproc_if_token2] = ACTIONS(2377),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2377),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2377),
    [aux_sym_preproc_else_token1] = ACTIONS(2377),
    [aux_sym_preproc_elif_token1] = ACTIONS(2377),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2377),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2377),
    [sym_preproc_directive] = ACTIONS(2377),
    [anon_sym_LPAREN2] = ACTIONS(2379),
    [anon_sym_BANG] = ACTIONS(2379),
    [anon_sym_TILDE] = ACTIONS(2379),
    [anon_sym_DASH] = ACTIONS(2377),
    [anon_sym_PLUS] = ACTIONS(2377),
    [anon_sym_STAR] = ACTIONS(2379),
    [anon_sym_AMP_AMP] = ACTIONS(2379),
    [anon_sym_AMP] = ACTIONS(2377),
    [anon_sym_SEMI] = ACTIONS(2379),
    [anon_sym___extension__] = ACTIONS(2377),
    [anon_sym_typedef] = ACTIONS(2377),
    [anon_sym___device__] = ACTIONS(2377),
    [anon_sym___host__] = ACTIONS(2377),
    [anon_sym___global__] = ACTIONS(2377),
    [anon_sym___forceinline__] = ACTIONS(2377),
    [anon_sym___noinline__] = ACTIONS(2377),
    [anon_sym_virtual] = ACTIONS(2377),
    [anon_sym_extern] = ACTIONS(2377),
    [anon_sym___attribute__] = ACTIONS(2377),
    [anon_sym___attribute] = ACTIONS(2377),
    [anon_sym_COLON_COLON] = ACTIONS(2379),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2379),
    [anon_sym___declspec] = ACTIONS(2377),
    [anon_sym___based] = ACTIONS(2377),
    [anon_sym___cdecl] = ACTIONS(2377),
    [anon_sym___clrcall] = ACTIONS(2377),
    [anon_sym___stdcall] = ACTIONS(2377),
    [anon_sym___fastcall] = ACTIONS(2377),
    [anon_sym___thiscall] = ACTIONS(2377),
    [anon_sym___vectorcall] = ACTIONS(2377),
    [anon_sym_LBRACE] = ACTIONS(2379),
    [anon_sym_signed] = ACTIONS(2377),
    [anon_sym_unsigned] = ACTIONS(2377),
    [anon_sym_long] = ACTIONS(2377),
    [anon_sym_short] = ACTIONS(2377),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_static] = ACTIONS(2377),
    [anon_sym_register] = ACTIONS(2377),
    [anon_sym_inline] = ACTIONS(2377),
    [anon_sym___inline] = ACTIONS(2377),
    [anon_sym___inline__] = ACTIONS(2377),
    [anon_sym___forceinline] = ACTIONS(2377),
    [anon_sym_thread_local] = ACTIONS(2377),
    [anon_sym___thread] = ACTIONS(2377),
    [anon_sym_const] = ACTIONS(2377),
    [anon_sym_constexpr] = ACTIONS(2377),
    [anon_sym_volatile] = ACTIONS(2377),
    [anon_sym_restrict] = ACTIONS(2377),
    [anon_sym___restrict__] = ACTIONS(2377),
    [anon_sym__Atomic] = ACTIONS(2377),
    [anon_sym__Noreturn] = ACTIONS(2377),
    [anon_sym_noreturn] = ACTIONS(2377),
    [anon_sym__Nonnull] = ACTIONS(2377),
    [anon_sym_mutable] = ACTIONS(2377),
    [anon_sym_constinit] = ACTIONS(2377),
    [anon_sym_consteval] = ACTIONS(2377),
    [anon_sym___shared__] = ACTIONS(2377),
    [anon_sym___local__] = ACTIONS(2377),
    [anon_sym___constant__] = ACTIONS(2377),
    [anon_sym___managed__] = ACTIONS(2377),
    [anon_sym___grid_constant__] = ACTIONS(2377),
    [anon_sym_alignas] = ACTIONS(2377),
    [anon_sym__Alignas] = ACTIONS(2377),
    [sym_primitive_type] = ACTIONS(2377),
    [anon_sym_enum] = ACTIONS(2377),
    [anon_sym_class] = ACTIONS(2377),
    [anon_sym_struct] = ACTIONS(2377),
    [anon_sym_union] = ACTIONS(2377),
    [anon_sym_if] = ACTIONS(2377),
    [anon_sym_switch] = ACTIONS(2377),
    [anon_sym_case] = ACTIONS(2377),
    [anon_sym_default] = ACTIONS(2377),
    [anon_sym_while] = ACTIONS(2377),
    [anon_sym_do] = ACTIONS(2377),
    [anon_sym_for] = ACTIONS(2377),
    [anon_sym_return] = ACTIONS(2377),
    [anon_sym_break] = ACTIONS(2377),
    [anon_sym_continue] = ACTIONS(2377),
    [anon_sym_goto] = ACTIONS(2377),
    [anon_sym___try] = ACTIONS(2377),
    [anon_sym___leave] = ACTIONS(2377),
    [anon_sym_not] = ACTIONS(2377),
    [anon_sym_compl] = ACTIONS(2377),
    [anon_sym_DASH_DASH] = ACTIONS(2379),
    [anon_sym_PLUS_PLUS] = ACTIONS(2379),
    [anon_sym_sizeof] = ACTIONS(2377),
    [anon_sym___alignof__] = ACTIONS(2377),
    [anon_sym___alignof] = ACTIONS(2377),
    [anon_sym__alignof] = ACTIONS(2377),
    [anon_sym_alignof] = ACTIONS(2377),
    [anon_sym__Alignof] = ACTIONS(2377),
    [anon_sym_offsetof] = ACTIONS(2377),
    [anon_sym__Generic] = ACTIONS(2377),
    [anon_sym_asm] = ACTIONS(2377),
    [anon_sym___asm__] = ACTIONS(2377),
    [anon_sym___asm] = ACTIONS(2377),
    [sym_number_literal] = ACTIONS(2379),
    [anon_sym_L_SQUOTE] = ACTIONS(2379),
    [anon_sym_u_SQUOTE] = ACTIONS(2379),
    [anon_sym_U_SQUOTE] = ACTIONS(2379),
    [anon_sym_u8_SQUOTE] = ACTIONS(2379),
    [anon_sym_SQUOTE] = ACTIONS(2379),
    [anon_sym_L_DQUOTE] = ACTIONS(2379),
    [anon_sym_u_DQUOTE] = ACTIONS(2379),
    [anon_sym_U_DQUOTE] = ACTIONS(2379),
    [anon_sym_u8_DQUOTE] = ACTIONS(2379),
    [anon_sym_DQUOTE] = ACTIONS(2379),
    [sym_true] = ACTIONS(2377),
    [sym_false] = ACTIONS(2377),
    [anon_sym_NULL] = ACTIONS(2377),
    [anon_sym_nullptr] = ACTIONS(2377),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2377),
    [anon_sym_decltype] = ACTIONS(2377),
    [anon_sym_explicit] = ACTIONS(2377),
    [anon_sym_typename] = ACTIONS(2377),
    [anon_sym_template] = ACTIONS(2377),
    [anon_sym_operator] = ACTIONS(2377),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_delete] = ACTIONS(2377),
    [anon_sym_throw] = ACTIONS(2377),
    [anon_sym_namespace] = ACTIONS(2377),
    [anon_sym_using] = ACTIONS(2377),
    [anon_sym_static_assert] = ACTIONS(2377),
    [anon_sym_concept] = ACTIONS(2377),
    [anon_sym_co_return] = ACTIONS(2377),
    [anon_sym_co_yield] = ACTIONS(2377),
    [anon_sym_R_DQUOTE] = ACTIONS(2379),
    [anon_sym_LR_DQUOTE] = ACTIONS(2379),
    [anon_sym_uR_DQUOTE] = ACTIONS(2379),
    [anon_sym_UR_DQUOTE] = ACTIONS(2379),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2379),
    [anon_sym_co_await] = ACTIONS(2377),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_requires] = ACTIONS(2377),
    [sym_this] = ACTIONS(2377),
    [anon_sym___launch_bounds__] = ACTIONS(2377),
  },
  [STATE(253)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_preproc_else_in_field_declaration_list] = STATE(9201),
    [sym_preproc_elif_in_field_declaration_list] = STATE(9201),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(9201),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2381),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(254)] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_include_token1] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token2] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [aux_sym_preproc_else_token1] = ACTIONS(2383),
    [aux_sym_preproc_elif_token1] = ACTIONS(2383),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2385),
    [anon_sym_BANG] = ACTIONS(2385),
    [anon_sym_TILDE] = ACTIONS(2385),
    [anon_sym_DASH] = ACTIONS(2383),
    [anon_sym_PLUS] = ACTIONS(2383),
    [anon_sym_STAR] = ACTIONS(2385),
    [anon_sym_AMP_AMP] = ACTIONS(2385),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym___device__] = ACTIONS(2383),
    [anon_sym___host__] = ACTIONS(2383),
    [anon_sym___global__] = ACTIONS(2383),
    [anon_sym___forceinline__] = ACTIONS(2383),
    [anon_sym___noinline__] = ACTIONS(2383),
    [anon_sym_virtual] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym___attribute] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2385),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2385),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym___cdecl] = ACTIONS(2383),
    [anon_sym___clrcall] = ACTIONS(2383),
    [anon_sym___stdcall] = ACTIONS(2383),
    [anon_sym___fastcall] = ACTIONS(2383),
    [anon_sym___thiscall] = ACTIONS(2383),
    [anon_sym___vectorcall] = ACTIONS(2383),
    [anon_sym_LBRACE] = ACTIONS(2385),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym__Nonnull] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym___shared__] = ACTIONS(2383),
    [anon_sym___local__] = ACTIONS(2383),
    [anon_sym___constant__] = ACTIONS(2383),
    [anon_sym___managed__] = ACTIONS(2383),
    [anon_sym___grid_constant__] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [anon_sym_if] = ACTIONS(2383),
    [anon_sym_switch] = ACTIONS(2383),
    [anon_sym_case] = ACTIONS(2383),
    [anon_sym_default] = ACTIONS(2383),
    [anon_sym_while] = ACTIONS(2383),
    [anon_sym_do] = ACTIONS(2383),
    [anon_sym_for] = ACTIONS(2383),
    [anon_sym_return] = ACTIONS(2383),
    [anon_sym_break] = ACTIONS(2383),
    [anon_sym_continue] = ACTIONS(2383),
    [anon_sym_goto] = ACTIONS(2383),
    [anon_sym___try] = ACTIONS(2383),
    [anon_sym___leave] = ACTIONS(2383),
    [anon_sym_not] = ACTIONS(2383),
    [anon_sym_compl] = ACTIONS(2383),
    [anon_sym_DASH_DASH] = ACTIONS(2385),
    [anon_sym_PLUS_PLUS] = ACTIONS(2385),
    [anon_sym_sizeof] = ACTIONS(2383),
    [anon_sym___alignof__] = ACTIONS(2383),
    [anon_sym___alignof] = ACTIONS(2383),
    [anon_sym__alignof] = ACTIONS(2383),
    [anon_sym_alignof] = ACTIONS(2383),
    [anon_sym__Alignof] = ACTIONS(2383),
    [anon_sym_offsetof] = ACTIONS(2383),
    [anon_sym__Generic] = ACTIONS(2383),
    [anon_sym_asm] = ACTIONS(2383),
    [anon_sym___asm__] = ACTIONS(2383),
    [anon_sym___asm] = ACTIONS(2383),
    [sym_number_literal] = ACTIONS(2385),
    [anon_sym_L_SQUOTE] = ACTIONS(2385),
    [anon_sym_u_SQUOTE] = ACTIONS(2385),
    [anon_sym_U_SQUOTE] = ACTIONS(2385),
    [anon_sym_u8_SQUOTE] = ACTIONS(2385),
    [anon_sym_SQUOTE] = ACTIONS(2385),
    [anon_sym_L_DQUOTE] = ACTIONS(2385),
    [anon_sym_u_DQUOTE] = ACTIONS(2385),
    [anon_sym_U_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8_DQUOTE] = ACTIONS(2385),
    [anon_sym_DQUOTE] = ACTIONS(2385),
    [sym_true] = ACTIONS(2383),
    [sym_false] = ACTIONS(2383),
    [anon_sym_NULL] = ACTIONS(2383),
    [anon_sym_nullptr] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_try] = ACTIONS(2383),
    [anon_sym_delete] = ACTIONS(2383),
    [anon_sym_throw] = ACTIONS(2383),
    [anon_sym_namespace] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym_concept] = ACTIONS(2383),
    [anon_sym_co_return] = ACTIONS(2383),
    [anon_sym_co_yield] = ACTIONS(2383),
    [anon_sym_R_DQUOTE] = ACTIONS(2385),
    [anon_sym_LR_DQUOTE] = ACTIONS(2385),
    [anon_sym_uR_DQUOTE] = ACTIONS(2385),
    [anon_sym_UR_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2385),
    [anon_sym_co_await] = ACTIONS(2383),
    [anon_sym_new] = ACTIONS(2383),
    [anon_sym_requires] = ACTIONS(2383),
    [sym_this] = ACTIONS(2383),
    [anon_sym___launch_bounds__] = ACTIONS(2383),
  },
  [STATE(255)] = {
    [sym_identifier] = ACTIONS(2387),
    [aux_sym_preproc_include_token1] = ACTIONS(2387),
    [aux_sym_preproc_def_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token2] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2387),
    [aux_sym_preproc_else_token1] = ACTIONS(2387),
    [aux_sym_preproc_elif_token1] = ACTIONS(2387),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2387),
    [sym_preproc_directive] = ACTIONS(2387),
    [anon_sym_LPAREN2] = ACTIONS(2389),
    [anon_sym_BANG] = ACTIONS(2389),
    [anon_sym_TILDE] = ACTIONS(2389),
    [anon_sym_DASH] = ACTIONS(2387),
    [anon_sym_PLUS] = ACTIONS(2387),
    [anon_sym_STAR] = ACTIONS(2389),
    [anon_sym_AMP_AMP] = ACTIONS(2389),
    [anon_sym_AMP] = ACTIONS(2387),
    [anon_sym_SEMI] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2387),
    [anon_sym_typedef] = ACTIONS(2387),
    [anon_sym___device__] = ACTIONS(2387),
    [anon_sym___host__] = ACTIONS(2387),
    [anon_sym___global__] = ACTIONS(2387),
    [anon_sym___forceinline__] = ACTIONS(2387),
    [anon_sym___noinline__] = ACTIONS(2387),
    [anon_sym_virtual] = ACTIONS(2387),
    [anon_sym_extern] = ACTIONS(2387),
    [anon_sym___attribute__] = ACTIONS(2387),
    [anon_sym___attribute] = ACTIONS(2387),
    [anon_sym_COLON_COLON] = ACTIONS(2389),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2389),
    [anon_sym___declspec] = ACTIONS(2387),
    [anon_sym___based] = ACTIONS(2387),
    [anon_sym___cdecl] = ACTIONS(2387),
    [anon_sym___clrcall] = ACTIONS(2387),
    [anon_sym___stdcall] = ACTIONS(2387),
    [anon_sym___fastcall] = ACTIONS(2387),
    [anon_sym___thiscall] = ACTIONS(2387),
    [anon_sym___vectorcall] = ACTIONS(2387),
    [anon_sym_LBRACE] = ACTIONS(2389),
    [anon_sym_signed] = ACTIONS(2387),
    [anon_sym_unsigned] = ACTIONS(2387),
    [anon_sym_long] = ACTIONS(2387),
    [anon_sym_short] = ACTIONS(2387),
    [anon_sym_LBRACK] = ACTIONS(2387),
    [anon_sym_static] = ACTIONS(2387),
    [anon_sym_register] = ACTIONS(2387),
    [anon_sym_inline] = ACTIONS(2387),
    [anon_sym___inline] = ACTIONS(2387),
    [anon_sym___inline__] = ACTIONS(2387),
    [anon_sym___forceinline] = ACTIONS(2387),
    [anon_sym_thread_local] = ACTIONS(2387),
    [anon_sym___thread] = ACTIONS(2387),
    [anon_sym_const] = ACTIONS(2387),
    [anon_sym_constexpr] = ACTIONS(2387),
    [anon_sym_volatile] = ACTIONS(2387),
    [anon_sym_restrict] = ACTIONS(2387),
    [anon_sym___restrict__] = ACTIONS(2387),
    [anon_sym__Atomic] = ACTIONS(2387),
    [anon_sym__Noreturn] = ACTIONS(2387),
    [anon_sym_noreturn] = ACTIONS(2387),
    [anon_sym__Nonnull] = ACTIONS(2387),
    [anon_sym_mutable] = ACTIONS(2387),
    [anon_sym_constinit] = ACTIONS(2387),
    [anon_sym_consteval] = ACTIONS(2387),
    [anon_sym___shared__] = ACTIONS(2387),
    [anon_sym___local__] = ACTIONS(2387),
    [anon_sym___constant__] = ACTIONS(2387),
    [anon_sym___managed__] = ACTIONS(2387),
    [anon_sym___grid_constant__] = ACTIONS(2387),
    [anon_sym_alignas] = ACTIONS(2387),
    [anon_sym__Alignas] = ACTIONS(2387),
    [sym_primitive_type] = ACTIONS(2387),
    [anon_sym_enum] = ACTIONS(2387),
    [anon_sym_class] = ACTIONS(2387),
    [anon_sym_struct] = ACTIONS(2387),
    [anon_sym_union] = ACTIONS(2387),
    [anon_sym_if] = ACTIONS(2387),
    [anon_sym_switch] = ACTIONS(2387),
    [anon_sym_case] = ACTIONS(2387),
    [anon_sym_default] = ACTIONS(2387),
    [anon_sym_while] = ACTIONS(2387),
    [anon_sym_do] = ACTIONS(2387),
    [anon_sym_for] = ACTIONS(2387),
    [anon_sym_return] = ACTIONS(2387),
    [anon_sym_break] = ACTIONS(2387),
    [anon_sym_continue] = ACTIONS(2387),
    [anon_sym_goto] = ACTIONS(2387),
    [anon_sym___try] = ACTIONS(2387),
    [anon_sym___leave] = ACTIONS(2387),
    [anon_sym_not] = ACTIONS(2387),
    [anon_sym_compl] = ACTIONS(2387),
    [anon_sym_DASH_DASH] = ACTIONS(2389),
    [anon_sym_PLUS_PLUS] = ACTIONS(2389),
    [anon_sym_sizeof] = ACTIONS(2387),
    [anon_sym___alignof__] = ACTIONS(2387),
    [anon_sym___alignof] = ACTIONS(2387),
    [anon_sym__alignof] = ACTIONS(2387),
    [anon_sym_alignof] = ACTIONS(2387),
    [anon_sym__Alignof] = ACTIONS(2387),
    [anon_sym_offsetof] = ACTIONS(2387),
    [anon_sym__Generic] = ACTIONS(2387),
    [anon_sym_asm] = ACTIONS(2387),
    [anon_sym___asm__] = ACTIONS(2387),
    [anon_sym___asm] = ACTIONS(2387),
    [sym_number_literal] = ACTIONS(2389),
    [anon_sym_L_SQUOTE] = ACTIONS(2389),
    [anon_sym_u_SQUOTE] = ACTIONS(2389),
    [anon_sym_U_SQUOTE] = ACTIONS(2389),
    [anon_sym_u8_SQUOTE] = ACTIONS(2389),
    [anon_sym_SQUOTE] = ACTIONS(2389),
    [anon_sym_L_DQUOTE] = ACTIONS(2389),
    [anon_sym_u_DQUOTE] = ACTIONS(2389),
    [anon_sym_U_DQUOTE] = ACTIONS(2389),
    [anon_sym_u8_DQUOTE] = ACTIONS(2389),
    [anon_sym_DQUOTE] = ACTIONS(2389),
    [sym_true] = ACTIONS(2387),
    [sym_false] = ACTIONS(2387),
    [anon_sym_NULL] = ACTIONS(2387),
    [anon_sym_nullptr] = ACTIONS(2387),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2387),
    [anon_sym_decltype] = ACTIONS(2387),
    [anon_sym_explicit] = ACTIONS(2387),
    [anon_sym_typename] = ACTIONS(2387),
    [anon_sym_template] = ACTIONS(2387),
    [anon_sym_operator] = ACTIONS(2387),
    [anon_sym_try] = ACTIONS(2387),
    [anon_sym_delete] = ACTIONS(2387),
    [anon_sym_throw] = ACTIONS(2387),
    [anon_sym_namespace] = ACTIONS(2387),
    [anon_sym_using] = ACTIONS(2387),
    [anon_sym_static_assert] = ACTIONS(2387),
    [anon_sym_concept] = ACTIONS(2387),
    [anon_sym_co_return] = ACTIONS(2387),
    [anon_sym_co_yield] = ACTIONS(2387),
    [anon_sym_R_DQUOTE] = ACTIONS(2389),
    [anon_sym_LR_DQUOTE] = ACTIONS(2389),
    [anon_sym_uR_DQUOTE] = ACTIONS(2389),
    [anon_sym_UR_DQUOTE] = ACTIONS(2389),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2389),
    [anon_sym_co_await] = ACTIONS(2387),
    [anon_sym_new] = ACTIONS(2387),
    [anon_sym_requires] = ACTIONS(2387),
    [sym_this] = ACTIONS(2387),
    [anon_sym___launch_bounds__] = ACTIONS(2387),
  },
  [STATE(256)] = {
    [sym_preproc_def] = STATE(259),
    [sym_preproc_function_def] = STATE(259),
    [sym_preproc_call] = STATE(259),
    [sym_preproc_if_in_field_declaration_list] = STATE(259),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(259),
    [sym_preproc_else_in_field_declaration_list] = STATE(9207),
    [sym_preproc_elif_in_field_declaration_list] = STATE(9207),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(9207),
    [sym_type_definition] = STATE(259),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(259),
    [sym_field_declaration] = STATE(259),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(259),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(259),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(259),
    [sym_operator_cast_declaration] = STATE(259),
    [sym_constructor_or_destructor_definition] = STATE(259),
    [sym_constructor_or_destructor_declaration] = STATE(259),
    [sym_friend_declaration] = STATE(259),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(259),
    [sym_alias_declaration] = STATE(259),
    [sym_static_assert_declaration] = STATE(259),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(259),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2391),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2393),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(257)] = {
    [sym_identifier] = ACTIONS(2395),
    [aux_sym_preproc_include_token1] = ACTIONS(2395),
    [aux_sym_preproc_def_token1] = ACTIONS(2395),
    [aux_sym_preproc_if_token1] = ACTIONS(2395),
    [aux_sym_preproc_if_token2] = ACTIONS(2395),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2395),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2395),
    [aux_sym_preproc_else_token1] = ACTIONS(2395),
    [aux_sym_preproc_elif_token1] = ACTIONS(2395),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2395),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2395),
    [sym_preproc_directive] = ACTIONS(2395),
    [anon_sym_LPAREN2] = ACTIONS(2397),
    [anon_sym_BANG] = ACTIONS(2397),
    [anon_sym_TILDE] = ACTIONS(2397),
    [anon_sym_DASH] = ACTIONS(2395),
    [anon_sym_PLUS] = ACTIONS(2395),
    [anon_sym_STAR] = ACTIONS(2397),
    [anon_sym_AMP_AMP] = ACTIONS(2397),
    [anon_sym_AMP] = ACTIONS(2395),
    [anon_sym_SEMI] = ACTIONS(2397),
    [anon_sym___extension__] = ACTIONS(2395),
    [anon_sym_typedef] = ACTIONS(2395),
    [anon_sym___device__] = ACTIONS(2395),
    [anon_sym___host__] = ACTIONS(2395),
    [anon_sym___global__] = ACTIONS(2395),
    [anon_sym___forceinline__] = ACTIONS(2395),
    [anon_sym___noinline__] = ACTIONS(2395),
    [anon_sym_virtual] = ACTIONS(2395),
    [anon_sym_extern] = ACTIONS(2395),
    [anon_sym___attribute__] = ACTIONS(2395),
    [anon_sym___attribute] = ACTIONS(2395),
    [anon_sym_COLON_COLON] = ACTIONS(2397),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2397),
    [anon_sym___declspec] = ACTIONS(2395),
    [anon_sym___based] = ACTIONS(2395),
    [anon_sym___cdecl] = ACTIONS(2395),
    [anon_sym___clrcall] = ACTIONS(2395),
    [anon_sym___stdcall] = ACTIONS(2395),
    [anon_sym___fastcall] = ACTIONS(2395),
    [anon_sym___thiscall] = ACTIONS(2395),
    [anon_sym___vectorcall] = ACTIONS(2395),
    [anon_sym_LBRACE] = ACTIONS(2397),
    [anon_sym_signed] = ACTIONS(2395),
    [anon_sym_unsigned] = ACTIONS(2395),
    [anon_sym_long] = ACTIONS(2395),
    [anon_sym_short] = ACTIONS(2395),
    [anon_sym_LBRACK] = ACTIONS(2395),
    [anon_sym_static] = ACTIONS(2395),
    [anon_sym_register] = ACTIONS(2395),
    [anon_sym_inline] = ACTIONS(2395),
    [anon_sym___inline] = ACTIONS(2395),
    [anon_sym___inline__] = ACTIONS(2395),
    [anon_sym___forceinline] = ACTIONS(2395),
    [anon_sym_thread_local] = ACTIONS(2395),
    [anon_sym___thread] = ACTIONS(2395),
    [anon_sym_const] = ACTIONS(2395),
    [anon_sym_constexpr] = ACTIONS(2395),
    [anon_sym_volatile] = ACTIONS(2395),
    [anon_sym_restrict] = ACTIONS(2395),
    [anon_sym___restrict__] = ACTIONS(2395),
    [anon_sym__Atomic] = ACTIONS(2395),
    [anon_sym__Noreturn] = ACTIONS(2395),
    [anon_sym_noreturn] = ACTIONS(2395),
    [anon_sym__Nonnull] = ACTIONS(2395),
    [anon_sym_mutable] = ACTIONS(2395),
    [anon_sym_constinit] = ACTIONS(2395),
    [anon_sym_consteval] = ACTIONS(2395),
    [anon_sym___shared__] = ACTIONS(2395),
    [anon_sym___local__] = ACTIONS(2395),
    [anon_sym___constant__] = ACTIONS(2395),
    [anon_sym___managed__] = ACTIONS(2395),
    [anon_sym___grid_constant__] = ACTIONS(2395),
    [anon_sym_alignas] = ACTIONS(2395),
    [anon_sym__Alignas] = ACTIONS(2395),
    [sym_primitive_type] = ACTIONS(2395),
    [anon_sym_enum] = ACTIONS(2395),
    [anon_sym_class] = ACTIONS(2395),
    [anon_sym_struct] = ACTIONS(2395),
    [anon_sym_union] = ACTIONS(2395),
    [anon_sym_if] = ACTIONS(2395),
    [anon_sym_switch] = ACTIONS(2395),
    [anon_sym_case] = ACTIONS(2395),
    [anon_sym_default] = ACTIONS(2395),
    [anon_sym_while] = ACTIONS(2395),
    [anon_sym_do] = ACTIONS(2395),
    [anon_sym_for] = ACTIONS(2395),
    [anon_sym_return] = ACTIONS(2395),
    [anon_sym_break] = ACTIONS(2395),
    [anon_sym_continue] = ACTIONS(2395),
    [anon_sym_goto] = ACTIONS(2395),
    [anon_sym___try] = ACTIONS(2395),
    [anon_sym___leave] = ACTIONS(2395),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_compl] = ACTIONS(2395),
    [anon_sym_DASH_DASH] = ACTIONS(2397),
    [anon_sym_PLUS_PLUS] = ACTIONS(2397),
    [anon_sym_sizeof] = ACTIONS(2395),
    [anon_sym___alignof__] = ACTIONS(2395),
    [anon_sym___alignof] = ACTIONS(2395),
    [anon_sym__alignof] = ACTIONS(2395),
    [anon_sym_alignof] = ACTIONS(2395),
    [anon_sym__Alignof] = ACTIONS(2395),
    [anon_sym_offsetof] = ACTIONS(2395),
    [anon_sym__Generic] = ACTIONS(2395),
    [anon_sym_asm] = ACTIONS(2395),
    [anon_sym___asm__] = ACTIONS(2395),
    [anon_sym___asm] = ACTIONS(2395),
    [sym_number_literal] = ACTIONS(2397),
    [anon_sym_L_SQUOTE] = ACTIONS(2397),
    [anon_sym_u_SQUOTE] = ACTIONS(2397),
    [anon_sym_U_SQUOTE] = ACTIONS(2397),
    [anon_sym_u8_SQUOTE] = ACTIONS(2397),
    [anon_sym_SQUOTE] = ACTIONS(2397),
    [anon_sym_L_DQUOTE] = ACTIONS(2397),
    [anon_sym_u_DQUOTE] = ACTIONS(2397),
    [anon_sym_U_DQUOTE] = ACTIONS(2397),
    [anon_sym_u8_DQUOTE] = ACTIONS(2397),
    [anon_sym_DQUOTE] = ACTIONS(2397),
    [sym_true] = ACTIONS(2395),
    [sym_false] = ACTIONS(2395),
    [anon_sym_NULL] = ACTIONS(2395),
    [anon_sym_nullptr] = ACTIONS(2395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2395),
    [anon_sym_decltype] = ACTIONS(2395),
    [anon_sym_explicit] = ACTIONS(2395),
    [anon_sym_typename] = ACTIONS(2395),
    [anon_sym_template] = ACTIONS(2395),
    [anon_sym_operator] = ACTIONS(2395),
    [anon_sym_try] = ACTIONS(2395),
    [anon_sym_delete] = ACTIONS(2395),
    [anon_sym_throw] = ACTIONS(2395),
    [anon_sym_namespace] = ACTIONS(2395),
    [anon_sym_using] = ACTIONS(2395),
    [anon_sym_static_assert] = ACTIONS(2395),
    [anon_sym_concept] = ACTIONS(2395),
    [anon_sym_co_return] = ACTIONS(2395),
    [anon_sym_co_yield] = ACTIONS(2395),
    [anon_sym_R_DQUOTE] = ACTIONS(2397),
    [anon_sym_LR_DQUOTE] = ACTIONS(2397),
    [anon_sym_uR_DQUOTE] = ACTIONS(2397),
    [anon_sym_UR_DQUOTE] = ACTIONS(2397),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2397),
    [anon_sym_co_await] = ACTIONS(2395),
    [anon_sym_new] = ACTIONS(2395),
    [anon_sym_requires] = ACTIONS(2395),
    [sym_this] = ACTIONS(2395),
    [anon_sym___launch_bounds__] = ACTIONS(2395),
  },
  [STATE(258)] = {
    [sym_preproc_def] = STATE(260),
    [sym_preproc_function_def] = STATE(260),
    [sym_preproc_call] = STATE(260),
    [sym_preproc_if_in_field_declaration_list] = STATE(260),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(260),
    [sym_preproc_else_in_field_declaration_list] = STATE(8982),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8982),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8982),
    [sym_type_definition] = STATE(260),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(260),
    [sym_field_declaration] = STATE(260),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(260),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(260),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(260),
    [sym_operator_cast_declaration] = STATE(260),
    [sym_constructor_or_destructor_definition] = STATE(260),
    [sym_constructor_or_destructor_declaration] = STATE(260),
    [sym_friend_declaration] = STATE(260),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(260),
    [sym_alias_declaration] = STATE(260),
    [sym_static_assert_declaration] = STATE(260),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(260),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2399),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2401),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(259)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_preproc_else_in_field_declaration_list] = STATE(8873),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8873),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8873),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2403),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(260)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_preproc_else_in_field_declaration_list] = STATE(8960),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8960),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8960),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2242),
    [aux_sym_preproc_if_token2] = ACTIONS(2405),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2246),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2246),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2254),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2266),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2294),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(261)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(2407),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(262)] = {
    [sym_identifier] = ACTIONS(2409),
    [aux_sym_preproc_include_token1] = ACTIONS(2409),
    [aux_sym_preproc_def_token1] = ACTIONS(2409),
    [aux_sym_preproc_if_token1] = ACTIONS(2409),
    [aux_sym_preproc_if_token2] = ACTIONS(2409),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2409),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2409),
    [aux_sym_preproc_else_token1] = ACTIONS(2409),
    [aux_sym_preproc_elif_token1] = ACTIONS(2409),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2409),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2409),
    [sym_preproc_directive] = ACTIONS(2409),
    [anon_sym_LPAREN2] = ACTIONS(2412),
    [anon_sym_BANG] = ACTIONS(2412),
    [anon_sym_TILDE] = ACTIONS(2412),
    [anon_sym_DASH] = ACTIONS(2409),
    [anon_sym_PLUS] = ACTIONS(2409),
    [anon_sym_STAR] = ACTIONS(2412),
    [anon_sym_AMP_AMP] = ACTIONS(2412),
    [anon_sym_AMP] = ACTIONS(2409),
    [anon_sym_SEMI] = ACTIONS(2412),
    [anon_sym___extension__] = ACTIONS(2409),
    [anon_sym_typedef] = ACTIONS(2409),
    [anon_sym___device__] = ACTIONS(2409),
    [anon_sym___host__] = ACTIONS(2409),
    [anon_sym___global__] = ACTIONS(2409),
    [anon_sym___forceinline__] = ACTIONS(2409),
    [anon_sym___noinline__] = ACTIONS(2409),
    [anon_sym_virtual] = ACTIONS(2409),
    [anon_sym_extern] = ACTIONS(2409),
    [anon_sym___attribute__] = ACTIONS(2409),
    [anon_sym___attribute] = ACTIONS(2409),
    [anon_sym_COLON_COLON] = ACTIONS(2412),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2412),
    [anon_sym___declspec] = ACTIONS(2409),
    [anon_sym___based] = ACTIONS(2409),
    [anon_sym___cdecl] = ACTIONS(2409),
    [anon_sym___clrcall] = ACTIONS(2409),
    [anon_sym___stdcall] = ACTIONS(2409),
    [anon_sym___fastcall] = ACTIONS(2409),
    [anon_sym___thiscall] = ACTIONS(2409),
    [anon_sym___vectorcall] = ACTIONS(2409),
    [anon_sym_LBRACE] = ACTIONS(2412),
    [anon_sym_signed] = ACTIONS(2409),
    [anon_sym_unsigned] = ACTIONS(2409),
    [anon_sym_long] = ACTIONS(2409),
    [anon_sym_short] = ACTIONS(2409),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_static] = ACTIONS(2409),
    [anon_sym_register] = ACTIONS(2409),
    [anon_sym_inline] = ACTIONS(2409),
    [anon_sym___inline] = ACTIONS(2409),
    [anon_sym___inline__] = ACTIONS(2409),
    [anon_sym___forceinline] = ACTIONS(2409),
    [anon_sym_thread_local] = ACTIONS(2409),
    [anon_sym___thread] = ACTIONS(2409),
    [anon_sym_const] = ACTIONS(2409),
    [anon_sym_constexpr] = ACTIONS(2409),
    [anon_sym_volatile] = ACTIONS(2409),
    [anon_sym_restrict] = ACTIONS(2409),
    [anon_sym___restrict__] = ACTIONS(2409),
    [anon_sym__Atomic] = ACTIONS(2409),
    [anon_sym__Noreturn] = ACTIONS(2409),
    [anon_sym_noreturn] = ACTIONS(2409),
    [anon_sym__Nonnull] = ACTIONS(2409),
    [anon_sym_mutable] = ACTIONS(2409),
    [anon_sym_constinit] = ACTIONS(2409),
    [anon_sym_consteval] = ACTIONS(2409),
    [anon_sym___shared__] = ACTIONS(2409),
    [anon_sym___local__] = ACTIONS(2409),
    [anon_sym___constant__] = ACTIONS(2409),
    [anon_sym___managed__] = ACTIONS(2409),
    [anon_sym___grid_constant__] = ACTIONS(2409),
    [anon_sym_alignas] = ACTIONS(2409),
    [anon_sym__Alignas] = ACTIONS(2409),
    [sym_primitive_type] = ACTIONS(2409),
    [anon_sym_enum] = ACTIONS(2409),
    [anon_sym_class] = ACTIONS(2409),
    [anon_sym_struct] = ACTIONS(2409),
    [anon_sym_union] = ACTIONS(2409),
    [anon_sym_if] = ACTIONS(2409),
    [anon_sym_switch] = ACTIONS(2409),
    [anon_sym_case] = ACTIONS(2409),
    [anon_sym_default] = ACTIONS(2409),
    [anon_sym_while] = ACTIONS(2409),
    [anon_sym_do] = ACTIONS(2409),
    [anon_sym_for] = ACTIONS(2409),
    [anon_sym_return] = ACTIONS(2409),
    [anon_sym_break] = ACTIONS(2409),
    [anon_sym_continue] = ACTIONS(2409),
    [anon_sym_goto] = ACTIONS(2409),
    [anon_sym___try] = ACTIONS(2409),
    [anon_sym___leave] = ACTIONS(2409),
    [anon_sym_not] = ACTIONS(2409),
    [anon_sym_compl] = ACTIONS(2409),
    [anon_sym_DASH_DASH] = ACTIONS(2412),
    [anon_sym_PLUS_PLUS] = ACTIONS(2412),
    [anon_sym_sizeof] = ACTIONS(2409),
    [anon_sym___alignof__] = ACTIONS(2409),
    [anon_sym___alignof] = ACTIONS(2409),
    [anon_sym__alignof] = ACTIONS(2409),
    [anon_sym_alignof] = ACTIONS(2409),
    [anon_sym__Alignof] = ACTIONS(2409),
    [anon_sym_offsetof] = ACTIONS(2409),
    [anon_sym__Generic] = ACTIONS(2409),
    [anon_sym_asm] = ACTIONS(2409),
    [anon_sym___asm__] = ACTIONS(2409),
    [anon_sym___asm] = ACTIONS(2409),
    [sym_number_literal] = ACTIONS(2412),
    [anon_sym_L_SQUOTE] = ACTIONS(2412),
    [anon_sym_u_SQUOTE] = ACTIONS(2412),
    [anon_sym_U_SQUOTE] = ACTIONS(2412),
    [anon_sym_u8_SQUOTE] = ACTIONS(2412),
    [anon_sym_SQUOTE] = ACTIONS(2412),
    [anon_sym_L_DQUOTE] = ACTIONS(2412),
    [anon_sym_u_DQUOTE] = ACTIONS(2412),
    [anon_sym_U_DQUOTE] = ACTIONS(2412),
    [anon_sym_u8_DQUOTE] = ACTIONS(2412),
    [anon_sym_DQUOTE] = ACTIONS(2412),
    [sym_true] = ACTIONS(2409),
    [sym_false] = ACTIONS(2409),
    [anon_sym_NULL] = ACTIONS(2409),
    [anon_sym_nullptr] = ACTIONS(2409),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2409),
    [anon_sym_decltype] = ACTIONS(2409),
    [anon_sym_explicit] = ACTIONS(2409),
    [anon_sym_typename] = ACTIONS(2409),
    [anon_sym_template] = ACTIONS(2409),
    [anon_sym_operator] = ACTIONS(2409),
    [anon_sym_try] = ACTIONS(2409),
    [anon_sym_delete] = ACTIONS(2409),
    [anon_sym_throw] = ACTIONS(2409),
    [anon_sym_namespace] = ACTIONS(2409),
    [anon_sym_using] = ACTIONS(2409),
    [anon_sym_static_assert] = ACTIONS(2409),
    [anon_sym_concept] = ACTIONS(2409),
    [anon_sym_co_return] = ACTIONS(2409),
    [anon_sym_co_yield] = ACTIONS(2409),
    [anon_sym_R_DQUOTE] = ACTIONS(2412),
    [anon_sym_LR_DQUOTE] = ACTIONS(2412),
    [anon_sym_uR_DQUOTE] = ACTIONS(2412),
    [anon_sym_UR_DQUOTE] = ACTIONS(2412),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2412),
    [anon_sym_co_await] = ACTIONS(2409),
    [anon_sym_new] = ACTIONS(2409),
    [anon_sym_requires] = ACTIONS(2409),
    [sym_this] = ACTIONS(2409),
    [anon_sym___launch_bounds__] = ACTIONS(2409),
  },
  [STATE(263)] = {
    [sym_identifier] = ACTIONS(2415),
    [aux_sym_preproc_include_token1] = ACTIONS(2415),
    [aux_sym_preproc_def_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token2] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2415),
    [aux_sym_preproc_else_token1] = ACTIONS(2415),
    [aux_sym_preproc_elif_token1] = ACTIONS(2415),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2415),
    [sym_preproc_directive] = ACTIONS(2415),
    [anon_sym_LPAREN2] = ACTIONS(2417),
    [anon_sym_BANG] = ACTIONS(2417),
    [anon_sym_TILDE] = ACTIONS(2417),
    [anon_sym_DASH] = ACTIONS(2415),
    [anon_sym_PLUS] = ACTIONS(2415),
    [anon_sym_STAR] = ACTIONS(2417),
    [anon_sym_AMP_AMP] = ACTIONS(2417),
    [anon_sym_AMP] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(2417),
    [anon_sym___extension__] = ACTIONS(2415),
    [anon_sym_typedef] = ACTIONS(2415),
    [anon_sym___device__] = ACTIONS(2415),
    [anon_sym___host__] = ACTIONS(2415),
    [anon_sym___global__] = ACTIONS(2415),
    [anon_sym___forceinline__] = ACTIONS(2415),
    [anon_sym___noinline__] = ACTIONS(2415),
    [anon_sym_virtual] = ACTIONS(2415),
    [anon_sym_extern] = ACTIONS(2415),
    [anon_sym___attribute__] = ACTIONS(2415),
    [anon_sym___attribute] = ACTIONS(2415),
    [anon_sym_COLON_COLON] = ACTIONS(2417),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2417),
    [anon_sym___declspec] = ACTIONS(2415),
    [anon_sym___based] = ACTIONS(2415),
    [anon_sym___cdecl] = ACTIONS(2415),
    [anon_sym___clrcall] = ACTIONS(2415),
    [anon_sym___stdcall] = ACTIONS(2415),
    [anon_sym___fastcall] = ACTIONS(2415),
    [anon_sym___thiscall] = ACTIONS(2415),
    [anon_sym___vectorcall] = ACTIONS(2415),
    [anon_sym_LBRACE] = ACTIONS(2417),
    [anon_sym_signed] = ACTIONS(2415),
    [anon_sym_unsigned] = ACTIONS(2415),
    [anon_sym_long] = ACTIONS(2415),
    [anon_sym_short] = ACTIONS(2415),
    [anon_sym_LBRACK] = ACTIONS(2415),
    [anon_sym_static] = ACTIONS(2415),
    [anon_sym_register] = ACTIONS(2415),
    [anon_sym_inline] = ACTIONS(2415),
    [anon_sym___inline] = ACTIONS(2415),
    [anon_sym___inline__] = ACTIONS(2415),
    [anon_sym___forceinline] = ACTIONS(2415),
    [anon_sym_thread_local] = ACTIONS(2415),
    [anon_sym___thread] = ACTIONS(2415),
    [anon_sym_const] = ACTIONS(2415),
    [anon_sym_constexpr] = ACTIONS(2415),
    [anon_sym_volatile] = ACTIONS(2415),
    [anon_sym_restrict] = ACTIONS(2415),
    [anon_sym___restrict__] = ACTIONS(2415),
    [anon_sym__Atomic] = ACTIONS(2415),
    [anon_sym__Noreturn] = ACTIONS(2415),
    [anon_sym_noreturn] = ACTIONS(2415),
    [anon_sym__Nonnull] = ACTIONS(2415),
    [anon_sym_mutable] = ACTIONS(2415),
    [anon_sym_constinit] = ACTIONS(2415),
    [anon_sym_consteval] = ACTIONS(2415),
    [anon_sym___shared__] = ACTIONS(2415),
    [anon_sym___local__] = ACTIONS(2415),
    [anon_sym___constant__] = ACTIONS(2415),
    [anon_sym___managed__] = ACTIONS(2415),
    [anon_sym___grid_constant__] = ACTIONS(2415),
    [anon_sym_alignas] = ACTIONS(2415),
    [anon_sym__Alignas] = ACTIONS(2415),
    [sym_primitive_type] = ACTIONS(2415),
    [anon_sym_enum] = ACTIONS(2415),
    [anon_sym_class] = ACTIONS(2415),
    [anon_sym_struct] = ACTIONS(2415),
    [anon_sym_union] = ACTIONS(2415),
    [anon_sym_if] = ACTIONS(2415),
    [anon_sym_switch] = ACTIONS(2415),
    [anon_sym_case] = ACTIONS(2415),
    [anon_sym_default] = ACTIONS(2415),
    [anon_sym_while] = ACTIONS(2415),
    [anon_sym_do] = ACTIONS(2415),
    [anon_sym_for] = ACTIONS(2415),
    [anon_sym_return] = ACTIONS(2415),
    [anon_sym_break] = ACTIONS(2415),
    [anon_sym_continue] = ACTIONS(2415),
    [anon_sym_goto] = ACTIONS(2415),
    [anon_sym___try] = ACTIONS(2415),
    [anon_sym___leave] = ACTIONS(2415),
    [anon_sym_not] = ACTIONS(2415),
    [anon_sym_compl] = ACTIONS(2415),
    [anon_sym_DASH_DASH] = ACTIONS(2417),
    [anon_sym_PLUS_PLUS] = ACTIONS(2417),
    [anon_sym_sizeof] = ACTIONS(2415),
    [anon_sym___alignof__] = ACTIONS(2415),
    [anon_sym___alignof] = ACTIONS(2415),
    [anon_sym__alignof] = ACTIONS(2415),
    [anon_sym_alignof] = ACTIONS(2415),
    [anon_sym__Alignof] = ACTIONS(2415),
    [anon_sym_offsetof] = ACTIONS(2415),
    [anon_sym__Generic] = ACTIONS(2415),
    [anon_sym_asm] = ACTIONS(2415),
    [anon_sym___asm__] = ACTIONS(2415),
    [anon_sym___asm] = ACTIONS(2415),
    [sym_number_literal] = ACTIONS(2417),
    [anon_sym_L_SQUOTE] = ACTIONS(2417),
    [anon_sym_u_SQUOTE] = ACTIONS(2417),
    [anon_sym_U_SQUOTE] = ACTIONS(2417),
    [anon_sym_u8_SQUOTE] = ACTIONS(2417),
    [anon_sym_SQUOTE] = ACTIONS(2417),
    [anon_sym_L_DQUOTE] = ACTIONS(2417),
    [anon_sym_u_DQUOTE] = ACTIONS(2417),
    [anon_sym_U_DQUOTE] = ACTIONS(2417),
    [anon_sym_u8_DQUOTE] = ACTIONS(2417),
    [anon_sym_DQUOTE] = ACTIONS(2417),
    [sym_true] = ACTIONS(2415),
    [sym_false] = ACTIONS(2415),
    [anon_sym_NULL] = ACTIONS(2415),
    [anon_sym_nullptr] = ACTIONS(2415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2415),
    [anon_sym_decltype] = ACTIONS(2415),
    [anon_sym_explicit] = ACTIONS(2415),
    [anon_sym_typename] = ACTIONS(2415),
    [anon_sym_template] = ACTIONS(2415),
    [anon_sym_operator] = ACTIONS(2415),
    [anon_sym_try] = ACTIONS(2415),
    [anon_sym_delete] = ACTIONS(2415),
    [anon_sym_throw] = ACTIONS(2415),
    [anon_sym_namespace] = ACTIONS(2415),
    [anon_sym_using] = ACTIONS(2415),
    [anon_sym_static_assert] = ACTIONS(2415),
    [anon_sym_concept] = ACTIONS(2415),
    [anon_sym_co_return] = ACTIONS(2415),
    [anon_sym_co_yield] = ACTIONS(2415),
    [anon_sym_R_DQUOTE] = ACTIONS(2417),
    [anon_sym_LR_DQUOTE] = ACTIONS(2417),
    [anon_sym_uR_DQUOTE] = ACTIONS(2417),
    [anon_sym_UR_DQUOTE] = ACTIONS(2417),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2417),
    [anon_sym_co_await] = ACTIONS(2415),
    [anon_sym_new] = ACTIONS(2415),
    [anon_sym_requires] = ACTIONS(2415),
    [sym_this] = ACTIONS(2415),
    [anon_sym___launch_bounds__] = ACTIONS(2415),
  },
  [STATE(264)] = {
    [sym_identifier] = ACTIONS(2419),
    [aux_sym_preproc_include_token1] = ACTIONS(2419),
    [aux_sym_preproc_def_token1] = ACTIONS(2419),
    [aux_sym_preproc_if_token1] = ACTIONS(2419),
    [aux_sym_preproc_if_token2] = ACTIONS(2419),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2419),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2419),
    [aux_sym_preproc_else_token1] = ACTIONS(2419),
    [aux_sym_preproc_elif_token1] = ACTIONS(2419),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2419),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2419),
    [sym_preproc_directive] = ACTIONS(2419),
    [anon_sym_LPAREN2] = ACTIONS(2421),
    [anon_sym_BANG] = ACTIONS(2421),
    [anon_sym_TILDE] = ACTIONS(2421),
    [anon_sym_DASH] = ACTIONS(2419),
    [anon_sym_PLUS] = ACTIONS(2419),
    [anon_sym_STAR] = ACTIONS(2421),
    [anon_sym_AMP_AMP] = ACTIONS(2421),
    [anon_sym_AMP] = ACTIONS(2419),
    [anon_sym_SEMI] = ACTIONS(2421),
    [anon_sym___extension__] = ACTIONS(2419),
    [anon_sym_typedef] = ACTIONS(2419),
    [anon_sym___device__] = ACTIONS(2419),
    [anon_sym___host__] = ACTIONS(2419),
    [anon_sym___global__] = ACTIONS(2419),
    [anon_sym___forceinline__] = ACTIONS(2419),
    [anon_sym___noinline__] = ACTIONS(2419),
    [anon_sym_virtual] = ACTIONS(2419),
    [anon_sym_extern] = ACTIONS(2419),
    [anon_sym___attribute__] = ACTIONS(2419),
    [anon_sym___attribute] = ACTIONS(2419),
    [anon_sym_COLON_COLON] = ACTIONS(2421),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2421),
    [anon_sym___declspec] = ACTIONS(2419),
    [anon_sym___based] = ACTIONS(2419),
    [anon_sym___cdecl] = ACTIONS(2419),
    [anon_sym___clrcall] = ACTIONS(2419),
    [anon_sym___stdcall] = ACTIONS(2419),
    [anon_sym___fastcall] = ACTIONS(2419),
    [anon_sym___thiscall] = ACTIONS(2419),
    [anon_sym___vectorcall] = ACTIONS(2419),
    [anon_sym_LBRACE] = ACTIONS(2421),
    [anon_sym_signed] = ACTIONS(2419),
    [anon_sym_unsigned] = ACTIONS(2419),
    [anon_sym_long] = ACTIONS(2419),
    [anon_sym_short] = ACTIONS(2419),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_static] = ACTIONS(2419),
    [anon_sym_register] = ACTIONS(2419),
    [anon_sym_inline] = ACTIONS(2419),
    [anon_sym___inline] = ACTIONS(2419),
    [anon_sym___inline__] = ACTIONS(2419),
    [anon_sym___forceinline] = ACTIONS(2419),
    [anon_sym_thread_local] = ACTIONS(2419),
    [anon_sym___thread] = ACTIONS(2419),
    [anon_sym_const] = ACTIONS(2419),
    [anon_sym_constexpr] = ACTIONS(2419),
    [anon_sym_volatile] = ACTIONS(2419),
    [anon_sym_restrict] = ACTIONS(2419),
    [anon_sym___restrict__] = ACTIONS(2419),
    [anon_sym__Atomic] = ACTIONS(2419),
    [anon_sym__Noreturn] = ACTIONS(2419),
    [anon_sym_noreturn] = ACTIONS(2419),
    [anon_sym__Nonnull] = ACTIONS(2419),
    [anon_sym_mutable] = ACTIONS(2419),
    [anon_sym_constinit] = ACTIONS(2419),
    [anon_sym_consteval] = ACTIONS(2419),
    [anon_sym___shared__] = ACTIONS(2419),
    [anon_sym___local__] = ACTIONS(2419),
    [anon_sym___constant__] = ACTIONS(2419),
    [anon_sym___managed__] = ACTIONS(2419),
    [anon_sym___grid_constant__] = ACTIONS(2419),
    [anon_sym_alignas] = ACTIONS(2419),
    [anon_sym__Alignas] = ACTIONS(2419),
    [sym_primitive_type] = ACTIONS(2419),
    [anon_sym_enum] = ACTIONS(2419),
    [anon_sym_class] = ACTIONS(2419),
    [anon_sym_struct] = ACTIONS(2419),
    [anon_sym_union] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2419),
    [anon_sym_switch] = ACTIONS(2419),
    [anon_sym_case] = ACTIONS(2419),
    [anon_sym_default] = ACTIONS(2419),
    [anon_sym_while] = ACTIONS(2419),
    [anon_sym_do] = ACTIONS(2419),
    [anon_sym_for] = ACTIONS(2419),
    [anon_sym_return] = ACTIONS(2419),
    [anon_sym_break] = ACTIONS(2419),
    [anon_sym_continue] = ACTIONS(2419),
    [anon_sym_goto] = ACTIONS(2419),
    [anon_sym___try] = ACTIONS(2419),
    [anon_sym___leave] = ACTIONS(2419),
    [anon_sym_not] = ACTIONS(2419),
    [anon_sym_compl] = ACTIONS(2419),
    [anon_sym_DASH_DASH] = ACTIONS(2421),
    [anon_sym_PLUS_PLUS] = ACTIONS(2421),
    [anon_sym_sizeof] = ACTIONS(2419),
    [anon_sym___alignof__] = ACTIONS(2419),
    [anon_sym___alignof] = ACTIONS(2419),
    [anon_sym__alignof] = ACTIONS(2419),
    [anon_sym_alignof] = ACTIONS(2419),
    [anon_sym__Alignof] = ACTIONS(2419),
    [anon_sym_offsetof] = ACTIONS(2419),
    [anon_sym__Generic] = ACTIONS(2419),
    [anon_sym_asm] = ACTIONS(2419),
    [anon_sym___asm__] = ACTIONS(2419),
    [anon_sym___asm] = ACTIONS(2419),
    [sym_number_literal] = ACTIONS(2421),
    [anon_sym_L_SQUOTE] = ACTIONS(2421),
    [anon_sym_u_SQUOTE] = ACTIONS(2421),
    [anon_sym_U_SQUOTE] = ACTIONS(2421),
    [anon_sym_u8_SQUOTE] = ACTIONS(2421),
    [anon_sym_SQUOTE] = ACTIONS(2421),
    [anon_sym_L_DQUOTE] = ACTIONS(2421),
    [anon_sym_u_DQUOTE] = ACTIONS(2421),
    [anon_sym_U_DQUOTE] = ACTIONS(2421),
    [anon_sym_u8_DQUOTE] = ACTIONS(2421),
    [anon_sym_DQUOTE] = ACTIONS(2421),
    [sym_true] = ACTIONS(2419),
    [sym_false] = ACTIONS(2419),
    [anon_sym_NULL] = ACTIONS(2419),
    [anon_sym_nullptr] = ACTIONS(2419),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2419),
    [anon_sym_decltype] = ACTIONS(2419),
    [anon_sym_explicit] = ACTIONS(2419),
    [anon_sym_typename] = ACTIONS(2419),
    [anon_sym_template] = ACTIONS(2419),
    [anon_sym_operator] = ACTIONS(2419),
    [anon_sym_try] = ACTIONS(2419),
    [anon_sym_delete] = ACTIONS(2419),
    [anon_sym_throw] = ACTIONS(2419),
    [anon_sym_namespace] = ACTIONS(2419),
    [anon_sym_using] = ACTIONS(2419),
    [anon_sym_static_assert] = ACTIONS(2419),
    [anon_sym_concept] = ACTIONS(2419),
    [anon_sym_co_return] = ACTIONS(2419),
    [anon_sym_co_yield] = ACTIONS(2419),
    [anon_sym_R_DQUOTE] = ACTIONS(2421),
    [anon_sym_LR_DQUOTE] = ACTIONS(2421),
    [anon_sym_uR_DQUOTE] = ACTIONS(2421),
    [anon_sym_UR_DQUOTE] = ACTIONS(2421),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2421),
    [anon_sym_co_await] = ACTIONS(2419),
    [anon_sym_new] = ACTIONS(2419),
    [anon_sym_requires] = ACTIONS(2419),
    [sym_this] = ACTIONS(2419),
    [anon_sym___launch_bounds__] = ACTIONS(2419),
  },
  [STATE(265)] = {
    [sym_identifier] = ACTIONS(2423),
    [aux_sym_preproc_include_token1] = ACTIONS(2423),
    [aux_sym_preproc_def_token1] = ACTIONS(2423),
    [aux_sym_preproc_if_token1] = ACTIONS(2423),
    [aux_sym_preproc_if_token2] = ACTIONS(2423),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2423),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2423),
    [aux_sym_preproc_else_token1] = ACTIONS(2423),
    [aux_sym_preproc_elif_token1] = ACTIONS(2423),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2423),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2423),
    [sym_preproc_directive] = ACTIONS(2423),
    [anon_sym_LPAREN2] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(2425),
    [anon_sym_TILDE] = ACTIONS(2425),
    [anon_sym_DASH] = ACTIONS(2423),
    [anon_sym_PLUS] = ACTIONS(2423),
    [anon_sym_STAR] = ACTIONS(2425),
    [anon_sym_AMP_AMP] = ACTIONS(2425),
    [anon_sym_AMP] = ACTIONS(2423),
    [anon_sym_SEMI] = ACTIONS(2425),
    [anon_sym___extension__] = ACTIONS(2423),
    [anon_sym_typedef] = ACTIONS(2423),
    [anon_sym___device__] = ACTIONS(2423),
    [anon_sym___host__] = ACTIONS(2423),
    [anon_sym___global__] = ACTIONS(2423),
    [anon_sym___forceinline__] = ACTIONS(2423),
    [anon_sym___noinline__] = ACTIONS(2423),
    [anon_sym_virtual] = ACTIONS(2423),
    [anon_sym_extern] = ACTIONS(2423),
    [anon_sym___attribute__] = ACTIONS(2423),
    [anon_sym___attribute] = ACTIONS(2423),
    [anon_sym_COLON_COLON] = ACTIONS(2425),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2425),
    [anon_sym___declspec] = ACTIONS(2423),
    [anon_sym___based] = ACTIONS(2423),
    [anon_sym___cdecl] = ACTIONS(2423),
    [anon_sym___clrcall] = ACTIONS(2423),
    [anon_sym___stdcall] = ACTIONS(2423),
    [anon_sym___fastcall] = ACTIONS(2423),
    [anon_sym___thiscall] = ACTIONS(2423),
    [anon_sym___vectorcall] = ACTIONS(2423),
    [anon_sym_LBRACE] = ACTIONS(2425),
    [anon_sym_signed] = ACTIONS(2423),
    [anon_sym_unsigned] = ACTIONS(2423),
    [anon_sym_long] = ACTIONS(2423),
    [anon_sym_short] = ACTIONS(2423),
    [anon_sym_LBRACK] = ACTIONS(2423),
    [anon_sym_static] = ACTIONS(2423),
    [anon_sym_register] = ACTIONS(2423),
    [anon_sym_inline] = ACTIONS(2423),
    [anon_sym___inline] = ACTIONS(2423),
    [anon_sym___inline__] = ACTIONS(2423),
    [anon_sym___forceinline] = ACTIONS(2423),
    [anon_sym_thread_local] = ACTIONS(2423),
    [anon_sym___thread] = ACTIONS(2423),
    [anon_sym_const] = ACTIONS(2423),
    [anon_sym_constexpr] = ACTIONS(2423),
    [anon_sym_volatile] = ACTIONS(2423),
    [anon_sym_restrict] = ACTIONS(2423),
    [anon_sym___restrict__] = ACTIONS(2423),
    [anon_sym__Atomic] = ACTIONS(2423),
    [anon_sym__Noreturn] = ACTIONS(2423),
    [anon_sym_noreturn] = ACTIONS(2423),
    [anon_sym__Nonnull] = ACTIONS(2423),
    [anon_sym_mutable] = ACTIONS(2423),
    [anon_sym_constinit] = ACTIONS(2423),
    [anon_sym_consteval] = ACTIONS(2423),
    [anon_sym___shared__] = ACTIONS(2423),
    [anon_sym___local__] = ACTIONS(2423),
    [anon_sym___constant__] = ACTIONS(2423),
    [anon_sym___managed__] = ACTIONS(2423),
    [anon_sym___grid_constant__] = ACTIONS(2423),
    [anon_sym_alignas] = ACTIONS(2423),
    [anon_sym__Alignas] = ACTIONS(2423),
    [sym_primitive_type] = ACTIONS(2423),
    [anon_sym_enum] = ACTIONS(2423),
    [anon_sym_class] = ACTIONS(2423),
    [anon_sym_struct] = ACTIONS(2423),
    [anon_sym_union] = ACTIONS(2423),
    [anon_sym_if] = ACTIONS(2423),
    [anon_sym_switch] = ACTIONS(2423),
    [anon_sym_case] = ACTIONS(2423),
    [anon_sym_default] = ACTIONS(2423),
    [anon_sym_while] = ACTIONS(2423),
    [anon_sym_do] = ACTIONS(2423),
    [anon_sym_for] = ACTIONS(2423),
    [anon_sym_return] = ACTIONS(2423),
    [anon_sym_break] = ACTIONS(2423),
    [anon_sym_continue] = ACTIONS(2423),
    [anon_sym_goto] = ACTIONS(2423),
    [anon_sym___try] = ACTIONS(2423),
    [anon_sym___leave] = ACTIONS(2423),
    [anon_sym_not] = ACTIONS(2423),
    [anon_sym_compl] = ACTIONS(2423),
    [anon_sym_DASH_DASH] = ACTIONS(2425),
    [anon_sym_PLUS_PLUS] = ACTIONS(2425),
    [anon_sym_sizeof] = ACTIONS(2423),
    [anon_sym___alignof__] = ACTIONS(2423),
    [anon_sym___alignof] = ACTIONS(2423),
    [anon_sym__alignof] = ACTIONS(2423),
    [anon_sym_alignof] = ACTIONS(2423),
    [anon_sym__Alignof] = ACTIONS(2423),
    [anon_sym_offsetof] = ACTIONS(2423),
    [anon_sym__Generic] = ACTIONS(2423),
    [anon_sym_asm] = ACTIONS(2423),
    [anon_sym___asm__] = ACTIONS(2423),
    [anon_sym___asm] = ACTIONS(2423),
    [sym_number_literal] = ACTIONS(2425),
    [anon_sym_L_SQUOTE] = ACTIONS(2425),
    [anon_sym_u_SQUOTE] = ACTIONS(2425),
    [anon_sym_U_SQUOTE] = ACTIONS(2425),
    [anon_sym_u8_SQUOTE] = ACTIONS(2425),
    [anon_sym_SQUOTE] = ACTIONS(2425),
    [anon_sym_L_DQUOTE] = ACTIONS(2425),
    [anon_sym_u_DQUOTE] = ACTIONS(2425),
    [anon_sym_U_DQUOTE] = ACTIONS(2425),
    [anon_sym_u8_DQUOTE] = ACTIONS(2425),
    [anon_sym_DQUOTE] = ACTIONS(2425),
    [sym_true] = ACTIONS(2423),
    [sym_false] = ACTIONS(2423),
    [anon_sym_NULL] = ACTIONS(2423),
    [anon_sym_nullptr] = ACTIONS(2423),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2423),
    [anon_sym_decltype] = ACTIONS(2423),
    [anon_sym_explicit] = ACTIONS(2423),
    [anon_sym_typename] = ACTIONS(2423),
    [anon_sym_template] = ACTIONS(2423),
    [anon_sym_operator] = ACTIONS(2423),
    [anon_sym_try] = ACTIONS(2423),
    [anon_sym_delete] = ACTIONS(2423),
    [anon_sym_throw] = ACTIONS(2423),
    [anon_sym_namespace] = ACTIONS(2423),
    [anon_sym_using] = ACTIONS(2423),
    [anon_sym_static_assert] = ACTIONS(2423),
    [anon_sym_concept] = ACTIONS(2423),
    [anon_sym_co_return] = ACTIONS(2423),
    [anon_sym_co_yield] = ACTIONS(2423),
    [anon_sym_R_DQUOTE] = ACTIONS(2425),
    [anon_sym_LR_DQUOTE] = ACTIONS(2425),
    [anon_sym_uR_DQUOTE] = ACTIONS(2425),
    [anon_sym_UR_DQUOTE] = ACTIONS(2425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2425),
    [anon_sym_co_await] = ACTIONS(2423),
    [anon_sym_new] = ACTIONS(2423),
    [anon_sym_requires] = ACTIONS(2423),
    [sym_this] = ACTIONS(2423),
    [anon_sym___launch_bounds__] = ACTIONS(2423),
  },
  [STATE(266)] = {
    [sym_identifier] = ACTIONS(2427),
    [aux_sym_preproc_include_token1] = ACTIONS(2427),
    [aux_sym_preproc_def_token1] = ACTIONS(2427),
    [aux_sym_preproc_if_token1] = ACTIONS(2427),
    [aux_sym_preproc_if_token2] = ACTIONS(2427),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2427),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2427),
    [aux_sym_preproc_else_token1] = ACTIONS(2427),
    [aux_sym_preproc_elif_token1] = ACTIONS(2427),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2427),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2427),
    [sym_preproc_directive] = ACTIONS(2427),
    [anon_sym_LPAREN2] = ACTIONS(2429),
    [anon_sym_BANG] = ACTIONS(2429),
    [anon_sym_TILDE] = ACTIONS(2429),
    [anon_sym_DASH] = ACTIONS(2427),
    [anon_sym_PLUS] = ACTIONS(2427),
    [anon_sym_STAR] = ACTIONS(2429),
    [anon_sym_AMP_AMP] = ACTIONS(2429),
    [anon_sym_AMP] = ACTIONS(2427),
    [anon_sym_SEMI] = ACTIONS(2429),
    [anon_sym___extension__] = ACTIONS(2427),
    [anon_sym_typedef] = ACTIONS(2427),
    [anon_sym___device__] = ACTIONS(2427),
    [anon_sym___host__] = ACTIONS(2427),
    [anon_sym___global__] = ACTIONS(2427),
    [anon_sym___forceinline__] = ACTIONS(2427),
    [anon_sym___noinline__] = ACTIONS(2427),
    [anon_sym_virtual] = ACTIONS(2427),
    [anon_sym_extern] = ACTIONS(2427),
    [anon_sym___attribute__] = ACTIONS(2427),
    [anon_sym___attribute] = ACTIONS(2427),
    [anon_sym_COLON_COLON] = ACTIONS(2429),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2429),
    [anon_sym___declspec] = ACTIONS(2427),
    [anon_sym___based] = ACTIONS(2427),
    [anon_sym___cdecl] = ACTIONS(2427),
    [anon_sym___clrcall] = ACTIONS(2427),
    [anon_sym___stdcall] = ACTIONS(2427),
    [anon_sym___fastcall] = ACTIONS(2427),
    [anon_sym___thiscall] = ACTIONS(2427),
    [anon_sym___vectorcall] = ACTIONS(2427),
    [anon_sym_LBRACE] = ACTIONS(2429),
    [anon_sym_signed] = ACTIONS(2427),
    [anon_sym_unsigned] = ACTIONS(2427),
    [anon_sym_long] = ACTIONS(2427),
    [anon_sym_short] = ACTIONS(2427),
    [anon_sym_LBRACK] = ACTIONS(2427),
    [anon_sym_static] = ACTIONS(2427),
    [anon_sym_register] = ACTIONS(2427),
    [anon_sym_inline] = ACTIONS(2427),
    [anon_sym___inline] = ACTIONS(2427),
    [anon_sym___inline__] = ACTIONS(2427),
    [anon_sym___forceinline] = ACTIONS(2427),
    [anon_sym_thread_local] = ACTIONS(2427),
    [anon_sym___thread] = ACTIONS(2427),
    [anon_sym_const] = ACTIONS(2427),
    [anon_sym_constexpr] = ACTIONS(2427),
    [anon_sym_volatile] = ACTIONS(2427),
    [anon_sym_restrict] = ACTIONS(2427),
    [anon_sym___restrict__] = ACTIONS(2427),
    [anon_sym__Atomic] = ACTIONS(2427),
    [anon_sym__Noreturn] = ACTIONS(2427),
    [anon_sym_noreturn] = ACTIONS(2427),
    [anon_sym__Nonnull] = ACTIONS(2427),
    [anon_sym_mutable] = ACTIONS(2427),
    [anon_sym_constinit] = ACTIONS(2427),
    [anon_sym_consteval] = ACTIONS(2427),
    [anon_sym___shared__] = ACTIONS(2427),
    [anon_sym___local__] = ACTIONS(2427),
    [anon_sym___constant__] = ACTIONS(2427),
    [anon_sym___managed__] = ACTIONS(2427),
    [anon_sym___grid_constant__] = ACTIONS(2427),
    [anon_sym_alignas] = ACTIONS(2427),
    [anon_sym__Alignas] = ACTIONS(2427),
    [sym_primitive_type] = ACTIONS(2427),
    [anon_sym_enum] = ACTIONS(2427),
    [anon_sym_class] = ACTIONS(2427),
    [anon_sym_struct] = ACTIONS(2427),
    [anon_sym_union] = ACTIONS(2427),
    [anon_sym_if] = ACTIONS(2427),
    [anon_sym_switch] = ACTIONS(2427),
    [anon_sym_case] = ACTIONS(2427),
    [anon_sym_default] = ACTIONS(2427),
    [anon_sym_while] = ACTIONS(2427),
    [anon_sym_do] = ACTIONS(2427),
    [anon_sym_for] = ACTIONS(2427),
    [anon_sym_return] = ACTIONS(2427),
    [anon_sym_break] = ACTIONS(2427),
    [anon_sym_continue] = ACTIONS(2427),
    [anon_sym_goto] = ACTIONS(2427),
    [anon_sym___try] = ACTIONS(2427),
    [anon_sym___leave] = ACTIONS(2427),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_compl] = ACTIONS(2427),
    [anon_sym_DASH_DASH] = ACTIONS(2429),
    [anon_sym_PLUS_PLUS] = ACTIONS(2429),
    [anon_sym_sizeof] = ACTIONS(2427),
    [anon_sym___alignof__] = ACTIONS(2427),
    [anon_sym___alignof] = ACTIONS(2427),
    [anon_sym__alignof] = ACTIONS(2427),
    [anon_sym_alignof] = ACTIONS(2427),
    [anon_sym__Alignof] = ACTIONS(2427),
    [anon_sym_offsetof] = ACTIONS(2427),
    [anon_sym__Generic] = ACTIONS(2427),
    [anon_sym_asm] = ACTIONS(2427),
    [anon_sym___asm__] = ACTIONS(2427),
    [anon_sym___asm] = ACTIONS(2427),
    [sym_number_literal] = ACTIONS(2429),
    [anon_sym_L_SQUOTE] = ACTIONS(2429),
    [anon_sym_u_SQUOTE] = ACTIONS(2429),
    [anon_sym_U_SQUOTE] = ACTIONS(2429),
    [anon_sym_u8_SQUOTE] = ACTIONS(2429),
    [anon_sym_SQUOTE] = ACTIONS(2429),
    [anon_sym_L_DQUOTE] = ACTIONS(2429),
    [anon_sym_u_DQUOTE] = ACTIONS(2429),
    [anon_sym_U_DQUOTE] = ACTIONS(2429),
    [anon_sym_u8_DQUOTE] = ACTIONS(2429),
    [anon_sym_DQUOTE] = ACTIONS(2429),
    [sym_true] = ACTIONS(2427),
    [sym_false] = ACTIONS(2427),
    [anon_sym_NULL] = ACTIONS(2427),
    [anon_sym_nullptr] = ACTIONS(2427),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2427),
    [anon_sym_decltype] = ACTIONS(2427),
    [anon_sym_explicit] = ACTIONS(2427),
    [anon_sym_typename] = ACTIONS(2427),
    [anon_sym_template] = ACTIONS(2427),
    [anon_sym_operator] = ACTIONS(2427),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_delete] = ACTIONS(2427),
    [anon_sym_throw] = ACTIONS(2427),
    [anon_sym_namespace] = ACTIONS(2427),
    [anon_sym_using] = ACTIONS(2427),
    [anon_sym_static_assert] = ACTIONS(2427),
    [anon_sym_concept] = ACTIONS(2427),
    [anon_sym_co_return] = ACTIONS(2427),
    [anon_sym_co_yield] = ACTIONS(2427),
    [anon_sym_R_DQUOTE] = ACTIONS(2429),
    [anon_sym_LR_DQUOTE] = ACTIONS(2429),
    [anon_sym_uR_DQUOTE] = ACTIONS(2429),
    [anon_sym_UR_DQUOTE] = ACTIONS(2429),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2429),
    [anon_sym_co_await] = ACTIONS(2427),
    [anon_sym_new] = ACTIONS(2427),
    [anon_sym_requires] = ACTIONS(2427),
    [sym_this] = ACTIONS(2427),
    [anon_sym___launch_bounds__] = ACTIONS(2427),
  },
  [STATE(267)] = {
    [sym_identifier] = ACTIONS(2431),
    [aux_sym_preproc_include_token1] = ACTIONS(2431),
    [aux_sym_preproc_def_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token2] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2431),
    [aux_sym_preproc_else_token1] = ACTIONS(2431),
    [aux_sym_preproc_elif_token1] = ACTIONS(2431),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2431),
    [sym_preproc_directive] = ACTIONS(2431),
    [anon_sym_LPAREN2] = ACTIONS(2433),
    [anon_sym_BANG] = ACTIONS(2433),
    [anon_sym_TILDE] = ACTIONS(2433),
    [anon_sym_DASH] = ACTIONS(2431),
    [anon_sym_PLUS] = ACTIONS(2431),
    [anon_sym_STAR] = ACTIONS(2433),
    [anon_sym_AMP_AMP] = ACTIONS(2433),
    [anon_sym_AMP] = ACTIONS(2431),
    [anon_sym_SEMI] = ACTIONS(2433),
    [anon_sym___extension__] = ACTIONS(2431),
    [anon_sym_typedef] = ACTIONS(2431),
    [anon_sym___device__] = ACTIONS(2431),
    [anon_sym___host__] = ACTIONS(2431),
    [anon_sym___global__] = ACTIONS(2431),
    [anon_sym___forceinline__] = ACTIONS(2431),
    [anon_sym___noinline__] = ACTIONS(2431),
    [anon_sym_virtual] = ACTIONS(2431),
    [anon_sym_extern] = ACTIONS(2431),
    [anon_sym___attribute__] = ACTIONS(2431),
    [anon_sym___attribute] = ACTIONS(2431),
    [anon_sym_COLON_COLON] = ACTIONS(2433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2433),
    [anon_sym___declspec] = ACTIONS(2431),
    [anon_sym___based] = ACTIONS(2431),
    [anon_sym___cdecl] = ACTIONS(2431),
    [anon_sym___clrcall] = ACTIONS(2431),
    [anon_sym___stdcall] = ACTIONS(2431),
    [anon_sym___fastcall] = ACTIONS(2431),
    [anon_sym___thiscall] = ACTIONS(2431),
    [anon_sym___vectorcall] = ACTIONS(2431),
    [anon_sym_LBRACE] = ACTIONS(2433),
    [anon_sym_signed] = ACTIONS(2431),
    [anon_sym_unsigned] = ACTIONS(2431),
    [anon_sym_long] = ACTIONS(2431),
    [anon_sym_short] = ACTIONS(2431),
    [anon_sym_LBRACK] = ACTIONS(2431),
    [anon_sym_static] = ACTIONS(2431),
    [anon_sym_register] = ACTIONS(2431),
    [anon_sym_inline] = ACTIONS(2431),
    [anon_sym___inline] = ACTIONS(2431),
    [anon_sym___inline__] = ACTIONS(2431),
    [anon_sym___forceinline] = ACTIONS(2431),
    [anon_sym_thread_local] = ACTIONS(2431),
    [anon_sym___thread] = ACTIONS(2431),
    [anon_sym_const] = ACTIONS(2431),
    [anon_sym_constexpr] = ACTIONS(2431),
    [anon_sym_volatile] = ACTIONS(2431),
    [anon_sym_restrict] = ACTIONS(2431),
    [anon_sym___restrict__] = ACTIONS(2431),
    [anon_sym__Atomic] = ACTIONS(2431),
    [anon_sym__Noreturn] = ACTIONS(2431),
    [anon_sym_noreturn] = ACTIONS(2431),
    [anon_sym__Nonnull] = ACTIONS(2431),
    [anon_sym_mutable] = ACTIONS(2431),
    [anon_sym_constinit] = ACTIONS(2431),
    [anon_sym_consteval] = ACTIONS(2431),
    [anon_sym___shared__] = ACTIONS(2431),
    [anon_sym___local__] = ACTIONS(2431),
    [anon_sym___constant__] = ACTIONS(2431),
    [anon_sym___managed__] = ACTIONS(2431),
    [anon_sym___grid_constant__] = ACTIONS(2431),
    [anon_sym_alignas] = ACTIONS(2431),
    [anon_sym__Alignas] = ACTIONS(2431),
    [sym_primitive_type] = ACTIONS(2431),
    [anon_sym_enum] = ACTIONS(2431),
    [anon_sym_class] = ACTIONS(2431),
    [anon_sym_struct] = ACTIONS(2431),
    [anon_sym_union] = ACTIONS(2431),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_switch] = ACTIONS(2431),
    [anon_sym_case] = ACTIONS(2431),
    [anon_sym_default] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(2431),
    [anon_sym_do] = ACTIONS(2431),
    [anon_sym_for] = ACTIONS(2431),
    [anon_sym_return] = ACTIONS(2431),
    [anon_sym_break] = ACTIONS(2431),
    [anon_sym_continue] = ACTIONS(2431),
    [anon_sym_goto] = ACTIONS(2431),
    [anon_sym___try] = ACTIONS(2431),
    [anon_sym___leave] = ACTIONS(2431),
    [anon_sym_not] = ACTIONS(2431),
    [anon_sym_compl] = ACTIONS(2431),
    [anon_sym_DASH_DASH] = ACTIONS(2433),
    [anon_sym_PLUS_PLUS] = ACTIONS(2433),
    [anon_sym_sizeof] = ACTIONS(2431),
    [anon_sym___alignof__] = ACTIONS(2431),
    [anon_sym___alignof] = ACTIONS(2431),
    [anon_sym__alignof] = ACTIONS(2431),
    [anon_sym_alignof] = ACTIONS(2431),
    [anon_sym__Alignof] = ACTIONS(2431),
    [anon_sym_offsetof] = ACTIONS(2431),
    [anon_sym__Generic] = ACTIONS(2431),
    [anon_sym_asm] = ACTIONS(2431),
    [anon_sym___asm__] = ACTIONS(2431),
    [anon_sym___asm] = ACTIONS(2431),
    [sym_number_literal] = ACTIONS(2433),
    [anon_sym_L_SQUOTE] = ACTIONS(2433),
    [anon_sym_u_SQUOTE] = ACTIONS(2433),
    [anon_sym_U_SQUOTE] = ACTIONS(2433),
    [anon_sym_u8_SQUOTE] = ACTIONS(2433),
    [anon_sym_SQUOTE] = ACTIONS(2433),
    [anon_sym_L_DQUOTE] = ACTIONS(2433),
    [anon_sym_u_DQUOTE] = ACTIONS(2433),
    [anon_sym_U_DQUOTE] = ACTIONS(2433),
    [anon_sym_u8_DQUOTE] = ACTIONS(2433),
    [anon_sym_DQUOTE] = ACTIONS(2433),
    [sym_true] = ACTIONS(2431),
    [sym_false] = ACTIONS(2431),
    [anon_sym_NULL] = ACTIONS(2431),
    [anon_sym_nullptr] = ACTIONS(2431),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2431),
    [anon_sym_decltype] = ACTIONS(2431),
    [anon_sym_explicit] = ACTIONS(2431),
    [anon_sym_typename] = ACTIONS(2431),
    [anon_sym_template] = ACTIONS(2431),
    [anon_sym_operator] = ACTIONS(2431),
    [anon_sym_try] = ACTIONS(2431),
    [anon_sym_delete] = ACTIONS(2431),
    [anon_sym_throw] = ACTIONS(2431),
    [anon_sym_namespace] = ACTIONS(2431),
    [anon_sym_using] = ACTIONS(2431),
    [anon_sym_static_assert] = ACTIONS(2431),
    [anon_sym_concept] = ACTIONS(2431),
    [anon_sym_co_return] = ACTIONS(2431),
    [anon_sym_co_yield] = ACTIONS(2431),
    [anon_sym_R_DQUOTE] = ACTIONS(2433),
    [anon_sym_LR_DQUOTE] = ACTIONS(2433),
    [anon_sym_uR_DQUOTE] = ACTIONS(2433),
    [anon_sym_UR_DQUOTE] = ACTIONS(2433),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2433),
    [anon_sym_co_await] = ACTIONS(2431),
    [anon_sym_new] = ACTIONS(2431),
    [anon_sym_requires] = ACTIONS(2431),
    [sym_this] = ACTIONS(2431),
    [anon_sym___launch_bounds__] = ACTIONS(2431),
  },
  [STATE(268)] = {
    [sym_identifier] = ACTIONS(2435),
    [aux_sym_preproc_include_token1] = ACTIONS(2435),
    [aux_sym_preproc_def_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token2] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2435),
    [aux_sym_preproc_else_token1] = ACTIONS(2435),
    [aux_sym_preproc_elif_token1] = ACTIONS(2435),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2435),
    [sym_preproc_directive] = ACTIONS(2435),
    [anon_sym_LPAREN2] = ACTIONS(2437),
    [anon_sym_BANG] = ACTIONS(2437),
    [anon_sym_TILDE] = ACTIONS(2437),
    [anon_sym_DASH] = ACTIONS(2435),
    [anon_sym_PLUS] = ACTIONS(2435),
    [anon_sym_STAR] = ACTIONS(2437),
    [anon_sym_AMP_AMP] = ACTIONS(2437),
    [anon_sym_AMP] = ACTIONS(2435),
    [anon_sym_SEMI] = ACTIONS(2437),
    [anon_sym___extension__] = ACTIONS(2435),
    [anon_sym_typedef] = ACTIONS(2435),
    [anon_sym___device__] = ACTIONS(2435),
    [anon_sym___host__] = ACTIONS(2435),
    [anon_sym___global__] = ACTIONS(2435),
    [anon_sym___forceinline__] = ACTIONS(2435),
    [anon_sym___noinline__] = ACTIONS(2435),
    [anon_sym_virtual] = ACTIONS(2435),
    [anon_sym_extern] = ACTIONS(2435),
    [anon_sym___attribute__] = ACTIONS(2435),
    [anon_sym___attribute] = ACTIONS(2435),
    [anon_sym_COLON_COLON] = ACTIONS(2437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2437),
    [anon_sym___declspec] = ACTIONS(2435),
    [anon_sym___based] = ACTIONS(2435),
    [anon_sym___cdecl] = ACTIONS(2435),
    [anon_sym___clrcall] = ACTIONS(2435),
    [anon_sym___stdcall] = ACTIONS(2435),
    [anon_sym___fastcall] = ACTIONS(2435),
    [anon_sym___thiscall] = ACTIONS(2435),
    [anon_sym___vectorcall] = ACTIONS(2435),
    [anon_sym_LBRACE] = ACTIONS(2437),
    [anon_sym_signed] = ACTIONS(2435),
    [anon_sym_unsigned] = ACTIONS(2435),
    [anon_sym_long] = ACTIONS(2435),
    [anon_sym_short] = ACTIONS(2435),
    [anon_sym_LBRACK] = ACTIONS(2435),
    [anon_sym_static] = ACTIONS(2435),
    [anon_sym_register] = ACTIONS(2435),
    [anon_sym_inline] = ACTIONS(2435),
    [anon_sym___inline] = ACTIONS(2435),
    [anon_sym___inline__] = ACTIONS(2435),
    [anon_sym___forceinline] = ACTIONS(2435),
    [anon_sym_thread_local] = ACTIONS(2435),
    [anon_sym___thread] = ACTIONS(2435),
    [anon_sym_const] = ACTIONS(2435),
    [anon_sym_constexpr] = ACTIONS(2435),
    [anon_sym_volatile] = ACTIONS(2435),
    [anon_sym_restrict] = ACTIONS(2435),
    [anon_sym___restrict__] = ACTIONS(2435),
    [anon_sym__Atomic] = ACTIONS(2435),
    [anon_sym__Noreturn] = ACTIONS(2435),
    [anon_sym_noreturn] = ACTIONS(2435),
    [anon_sym__Nonnull] = ACTIONS(2435),
    [anon_sym_mutable] = ACTIONS(2435),
    [anon_sym_constinit] = ACTIONS(2435),
    [anon_sym_consteval] = ACTIONS(2435),
    [anon_sym___shared__] = ACTIONS(2435),
    [anon_sym___local__] = ACTIONS(2435),
    [anon_sym___constant__] = ACTIONS(2435),
    [anon_sym___managed__] = ACTIONS(2435),
    [anon_sym___grid_constant__] = ACTIONS(2435),
    [anon_sym_alignas] = ACTIONS(2435),
    [anon_sym__Alignas] = ACTIONS(2435),
    [sym_primitive_type] = ACTIONS(2435),
    [anon_sym_enum] = ACTIONS(2435),
    [anon_sym_class] = ACTIONS(2435),
    [anon_sym_struct] = ACTIONS(2435),
    [anon_sym_union] = ACTIONS(2435),
    [anon_sym_if] = ACTIONS(2435),
    [anon_sym_switch] = ACTIONS(2435),
    [anon_sym_case] = ACTIONS(2435),
    [anon_sym_default] = ACTIONS(2435),
    [anon_sym_while] = ACTIONS(2435),
    [anon_sym_do] = ACTIONS(2435),
    [anon_sym_for] = ACTIONS(2435),
    [anon_sym_return] = ACTIONS(2435),
    [anon_sym_break] = ACTIONS(2435),
    [anon_sym_continue] = ACTIONS(2435),
    [anon_sym_goto] = ACTIONS(2435),
    [anon_sym___try] = ACTIONS(2435),
    [anon_sym___leave] = ACTIONS(2435),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_compl] = ACTIONS(2435),
    [anon_sym_DASH_DASH] = ACTIONS(2437),
    [anon_sym_PLUS_PLUS] = ACTIONS(2437),
    [anon_sym_sizeof] = ACTIONS(2435),
    [anon_sym___alignof__] = ACTIONS(2435),
    [anon_sym___alignof] = ACTIONS(2435),
    [anon_sym__alignof] = ACTIONS(2435),
    [anon_sym_alignof] = ACTIONS(2435),
    [anon_sym__Alignof] = ACTIONS(2435),
    [anon_sym_offsetof] = ACTIONS(2435),
    [anon_sym__Generic] = ACTIONS(2435),
    [anon_sym_asm] = ACTIONS(2435),
    [anon_sym___asm__] = ACTIONS(2435),
    [anon_sym___asm] = ACTIONS(2435),
    [sym_number_literal] = ACTIONS(2437),
    [anon_sym_L_SQUOTE] = ACTIONS(2437),
    [anon_sym_u_SQUOTE] = ACTIONS(2437),
    [anon_sym_U_SQUOTE] = ACTIONS(2437),
    [anon_sym_u8_SQUOTE] = ACTIONS(2437),
    [anon_sym_SQUOTE] = ACTIONS(2437),
    [anon_sym_L_DQUOTE] = ACTIONS(2437),
    [anon_sym_u_DQUOTE] = ACTIONS(2437),
    [anon_sym_U_DQUOTE] = ACTIONS(2437),
    [anon_sym_u8_DQUOTE] = ACTIONS(2437),
    [anon_sym_DQUOTE] = ACTIONS(2437),
    [sym_true] = ACTIONS(2435),
    [sym_false] = ACTIONS(2435),
    [anon_sym_NULL] = ACTIONS(2435),
    [anon_sym_nullptr] = ACTIONS(2435),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2435),
    [anon_sym_decltype] = ACTIONS(2435),
    [anon_sym_explicit] = ACTIONS(2435),
    [anon_sym_typename] = ACTIONS(2435),
    [anon_sym_template] = ACTIONS(2435),
    [anon_sym_operator] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2435),
    [anon_sym_delete] = ACTIONS(2435),
    [anon_sym_throw] = ACTIONS(2435),
    [anon_sym_namespace] = ACTIONS(2435),
    [anon_sym_using] = ACTIONS(2435),
    [anon_sym_static_assert] = ACTIONS(2435),
    [anon_sym_concept] = ACTIONS(2435),
    [anon_sym_co_return] = ACTIONS(2435),
    [anon_sym_co_yield] = ACTIONS(2435),
    [anon_sym_R_DQUOTE] = ACTIONS(2437),
    [anon_sym_LR_DQUOTE] = ACTIONS(2437),
    [anon_sym_uR_DQUOTE] = ACTIONS(2437),
    [anon_sym_UR_DQUOTE] = ACTIONS(2437),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2437),
    [anon_sym_co_await] = ACTIONS(2435),
    [anon_sym_new] = ACTIONS(2435),
    [anon_sym_requires] = ACTIONS(2435),
    [sym_this] = ACTIONS(2435),
    [anon_sym___launch_bounds__] = ACTIONS(2435),
  },
  [STATE(269)] = {
    [sym_identifier] = ACTIONS(2439),
    [aux_sym_preproc_include_token1] = ACTIONS(2439),
    [aux_sym_preproc_def_token1] = ACTIONS(2439),
    [aux_sym_preproc_if_token1] = ACTIONS(2439),
    [aux_sym_preproc_if_token2] = ACTIONS(2439),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2439),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2439),
    [aux_sym_preproc_else_token1] = ACTIONS(2439),
    [aux_sym_preproc_elif_token1] = ACTIONS(2439),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2439),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2439),
    [sym_preproc_directive] = ACTIONS(2439),
    [anon_sym_LPAREN2] = ACTIONS(2441),
    [anon_sym_BANG] = ACTIONS(2441),
    [anon_sym_TILDE] = ACTIONS(2441),
    [anon_sym_DASH] = ACTIONS(2439),
    [anon_sym_PLUS] = ACTIONS(2439),
    [anon_sym_STAR] = ACTIONS(2441),
    [anon_sym_AMP_AMP] = ACTIONS(2441),
    [anon_sym_AMP] = ACTIONS(2439),
    [anon_sym_SEMI] = ACTIONS(2441),
    [anon_sym___extension__] = ACTIONS(2439),
    [anon_sym_typedef] = ACTIONS(2439),
    [anon_sym___device__] = ACTIONS(2439),
    [anon_sym___host__] = ACTIONS(2439),
    [anon_sym___global__] = ACTIONS(2439),
    [anon_sym___forceinline__] = ACTIONS(2439),
    [anon_sym___noinline__] = ACTIONS(2439),
    [anon_sym_virtual] = ACTIONS(2439),
    [anon_sym_extern] = ACTIONS(2439),
    [anon_sym___attribute__] = ACTIONS(2439),
    [anon_sym___attribute] = ACTIONS(2439),
    [anon_sym_COLON_COLON] = ACTIONS(2441),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2441),
    [anon_sym___declspec] = ACTIONS(2439),
    [anon_sym___based] = ACTIONS(2439),
    [anon_sym___cdecl] = ACTIONS(2439),
    [anon_sym___clrcall] = ACTIONS(2439),
    [anon_sym___stdcall] = ACTIONS(2439),
    [anon_sym___fastcall] = ACTIONS(2439),
    [anon_sym___thiscall] = ACTIONS(2439),
    [anon_sym___vectorcall] = ACTIONS(2439),
    [anon_sym_LBRACE] = ACTIONS(2441),
    [anon_sym_signed] = ACTIONS(2439),
    [anon_sym_unsigned] = ACTIONS(2439),
    [anon_sym_long] = ACTIONS(2439),
    [anon_sym_short] = ACTIONS(2439),
    [anon_sym_LBRACK] = ACTIONS(2439),
    [anon_sym_static] = ACTIONS(2439),
    [anon_sym_register] = ACTIONS(2439),
    [anon_sym_inline] = ACTIONS(2439),
    [anon_sym___inline] = ACTIONS(2439),
    [anon_sym___inline__] = ACTIONS(2439),
    [anon_sym___forceinline] = ACTIONS(2439),
    [anon_sym_thread_local] = ACTIONS(2439),
    [anon_sym___thread] = ACTIONS(2439),
    [anon_sym_const] = ACTIONS(2439),
    [anon_sym_constexpr] = ACTIONS(2439),
    [anon_sym_volatile] = ACTIONS(2439),
    [anon_sym_restrict] = ACTIONS(2439),
    [anon_sym___restrict__] = ACTIONS(2439),
    [anon_sym__Atomic] = ACTIONS(2439),
    [anon_sym__Noreturn] = ACTIONS(2439),
    [anon_sym_noreturn] = ACTIONS(2439),
    [anon_sym__Nonnull] = ACTIONS(2439),
    [anon_sym_mutable] = ACTIONS(2439),
    [anon_sym_constinit] = ACTIONS(2439),
    [anon_sym_consteval] = ACTIONS(2439),
    [anon_sym___shared__] = ACTIONS(2439),
    [anon_sym___local__] = ACTIONS(2439),
    [anon_sym___constant__] = ACTIONS(2439),
    [anon_sym___managed__] = ACTIONS(2439),
    [anon_sym___grid_constant__] = ACTIONS(2439),
    [anon_sym_alignas] = ACTIONS(2439),
    [anon_sym__Alignas] = ACTIONS(2439),
    [sym_primitive_type] = ACTIONS(2439),
    [anon_sym_enum] = ACTIONS(2439),
    [anon_sym_class] = ACTIONS(2439),
    [anon_sym_struct] = ACTIONS(2439),
    [anon_sym_union] = ACTIONS(2439),
    [anon_sym_if] = ACTIONS(2439),
    [anon_sym_switch] = ACTIONS(2439),
    [anon_sym_case] = ACTIONS(2439),
    [anon_sym_default] = ACTIONS(2439),
    [anon_sym_while] = ACTIONS(2439),
    [anon_sym_do] = ACTIONS(2439),
    [anon_sym_for] = ACTIONS(2439),
    [anon_sym_return] = ACTIONS(2439),
    [anon_sym_break] = ACTIONS(2439),
    [anon_sym_continue] = ACTIONS(2439),
    [anon_sym_goto] = ACTIONS(2439),
    [anon_sym___try] = ACTIONS(2439),
    [anon_sym___leave] = ACTIONS(2439),
    [anon_sym_not] = ACTIONS(2439),
    [anon_sym_compl] = ACTIONS(2439),
    [anon_sym_DASH_DASH] = ACTIONS(2441),
    [anon_sym_PLUS_PLUS] = ACTIONS(2441),
    [anon_sym_sizeof] = ACTIONS(2439),
    [anon_sym___alignof__] = ACTIONS(2439),
    [anon_sym___alignof] = ACTIONS(2439),
    [anon_sym__alignof] = ACTIONS(2439),
    [anon_sym_alignof] = ACTIONS(2439),
    [anon_sym__Alignof] = ACTIONS(2439),
    [anon_sym_offsetof] = ACTIONS(2439),
    [anon_sym__Generic] = ACTIONS(2439),
    [anon_sym_asm] = ACTIONS(2439),
    [anon_sym___asm__] = ACTIONS(2439),
    [anon_sym___asm] = ACTIONS(2439),
    [sym_number_literal] = ACTIONS(2441),
    [anon_sym_L_SQUOTE] = ACTIONS(2441),
    [anon_sym_u_SQUOTE] = ACTIONS(2441),
    [anon_sym_U_SQUOTE] = ACTIONS(2441),
    [anon_sym_u8_SQUOTE] = ACTIONS(2441),
    [anon_sym_SQUOTE] = ACTIONS(2441),
    [anon_sym_L_DQUOTE] = ACTIONS(2441),
    [anon_sym_u_DQUOTE] = ACTIONS(2441),
    [anon_sym_U_DQUOTE] = ACTIONS(2441),
    [anon_sym_u8_DQUOTE] = ACTIONS(2441),
    [anon_sym_DQUOTE] = ACTIONS(2441),
    [sym_true] = ACTIONS(2439),
    [sym_false] = ACTIONS(2439),
    [anon_sym_NULL] = ACTIONS(2439),
    [anon_sym_nullptr] = ACTIONS(2439),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2439),
    [anon_sym_decltype] = ACTIONS(2439),
    [anon_sym_explicit] = ACTIONS(2439),
    [anon_sym_typename] = ACTIONS(2439),
    [anon_sym_template] = ACTIONS(2439),
    [anon_sym_operator] = ACTIONS(2439),
    [anon_sym_try] = ACTIONS(2439),
    [anon_sym_delete] = ACTIONS(2439),
    [anon_sym_throw] = ACTIONS(2439),
    [anon_sym_namespace] = ACTIONS(2439),
    [anon_sym_using] = ACTIONS(2439),
    [anon_sym_static_assert] = ACTIONS(2439),
    [anon_sym_concept] = ACTIONS(2439),
    [anon_sym_co_return] = ACTIONS(2439),
    [anon_sym_co_yield] = ACTIONS(2439),
    [anon_sym_R_DQUOTE] = ACTIONS(2441),
    [anon_sym_LR_DQUOTE] = ACTIONS(2441),
    [anon_sym_uR_DQUOTE] = ACTIONS(2441),
    [anon_sym_UR_DQUOTE] = ACTIONS(2441),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2441),
    [anon_sym_co_await] = ACTIONS(2439),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_requires] = ACTIONS(2439),
    [sym_this] = ACTIONS(2439),
    [anon_sym___launch_bounds__] = ACTIONS(2439),
  },
  [STATE(270)] = {
    [sym_identifier] = ACTIONS(2443),
    [aux_sym_preproc_include_token1] = ACTIONS(2443),
    [aux_sym_preproc_def_token1] = ACTIONS(2443),
    [aux_sym_preproc_if_token1] = ACTIONS(2443),
    [aux_sym_preproc_if_token2] = ACTIONS(2443),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2443),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2443),
    [aux_sym_preproc_else_token1] = ACTIONS(2443),
    [aux_sym_preproc_elif_token1] = ACTIONS(2443),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2443),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2443),
    [sym_preproc_directive] = ACTIONS(2443),
    [anon_sym_LPAREN2] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(2445),
    [anon_sym_TILDE] = ACTIONS(2445),
    [anon_sym_DASH] = ACTIONS(2443),
    [anon_sym_PLUS] = ACTIONS(2443),
    [anon_sym_STAR] = ACTIONS(2445),
    [anon_sym_AMP_AMP] = ACTIONS(2445),
    [anon_sym_AMP] = ACTIONS(2443),
    [anon_sym_SEMI] = ACTIONS(2445),
    [anon_sym___extension__] = ACTIONS(2443),
    [anon_sym_typedef] = ACTIONS(2443),
    [anon_sym___device__] = ACTIONS(2443),
    [anon_sym___host__] = ACTIONS(2443),
    [anon_sym___global__] = ACTIONS(2443),
    [anon_sym___forceinline__] = ACTIONS(2443),
    [anon_sym___noinline__] = ACTIONS(2443),
    [anon_sym_virtual] = ACTIONS(2443),
    [anon_sym_extern] = ACTIONS(2443),
    [anon_sym___attribute__] = ACTIONS(2443),
    [anon_sym___attribute] = ACTIONS(2443),
    [anon_sym_COLON_COLON] = ACTIONS(2445),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2445),
    [anon_sym___declspec] = ACTIONS(2443),
    [anon_sym___based] = ACTIONS(2443),
    [anon_sym___cdecl] = ACTIONS(2443),
    [anon_sym___clrcall] = ACTIONS(2443),
    [anon_sym___stdcall] = ACTIONS(2443),
    [anon_sym___fastcall] = ACTIONS(2443),
    [anon_sym___thiscall] = ACTIONS(2443),
    [anon_sym___vectorcall] = ACTIONS(2443),
    [anon_sym_LBRACE] = ACTIONS(2445),
    [anon_sym_signed] = ACTIONS(2443),
    [anon_sym_unsigned] = ACTIONS(2443),
    [anon_sym_long] = ACTIONS(2443),
    [anon_sym_short] = ACTIONS(2443),
    [anon_sym_LBRACK] = ACTIONS(2443),
    [anon_sym_static] = ACTIONS(2443),
    [anon_sym_register] = ACTIONS(2443),
    [anon_sym_inline] = ACTIONS(2443),
    [anon_sym___inline] = ACTIONS(2443),
    [anon_sym___inline__] = ACTIONS(2443),
    [anon_sym___forceinline] = ACTIONS(2443),
    [anon_sym_thread_local] = ACTIONS(2443),
    [anon_sym___thread] = ACTIONS(2443),
    [anon_sym_const] = ACTIONS(2443),
    [anon_sym_constexpr] = ACTIONS(2443),
    [anon_sym_volatile] = ACTIONS(2443),
    [anon_sym_restrict] = ACTIONS(2443),
    [anon_sym___restrict__] = ACTIONS(2443),
    [anon_sym__Atomic] = ACTIONS(2443),
    [anon_sym__Noreturn] = ACTIONS(2443),
    [anon_sym_noreturn] = ACTIONS(2443),
    [anon_sym__Nonnull] = ACTIONS(2443),
    [anon_sym_mutable] = ACTIONS(2443),
    [anon_sym_constinit] = ACTIONS(2443),
    [anon_sym_consteval] = ACTIONS(2443),
    [anon_sym___shared__] = ACTIONS(2443),
    [anon_sym___local__] = ACTIONS(2443),
    [anon_sym___constant__] = ACTIONS(2443),
    [anon_sym___managed__] = ACTIONS(2443),
    [anon_sym___grid_constant__] = ACTIONS(2443),
    [anon_sym_alignas] = ACTIONS(2443),
    [anon_sym__Alignas] = ACTIONS(2443),
    [sym_primitive_type] = ACTIONS(2443),
    [anon_sym_enum] = ACTIONS(2443),
    [anon_sym_class] = ACTIONS(2443),
    [anon_sym_struct] = ACTIONS(2443),
    [anon_sym_union] = ACTIONS(2443),
    [anon_sym_if] = ACTIONS(2443),
    [anon_sym_switch] = ACTIONS(2443),
    [anon_sym_case] = ACTIONS(2443),
    [anon_sym_default] = ACTIONS(2443),
    [anon_sym_while] = ACTIONS(2443),
    [anon_sym_do] = ACTIONS(2443),
    [anon_sym_for] = ACTIONS(2443),
    [anon_sym_return] = ACTIONS(2443),
    [anon_sym_break] = ACTIONS(2443),
    [anon_sym_continue] = ACTIONS(2443),
    [anon_sym_goto] = ACTIONS(2443),
    [anon_sym___try] = ACTIONS(2443),
    [anon_sym___leave] = ACTIONS(2443),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_compl] = ACTIONS(2443),
    [anon_sym_DASH_DASH] = ACTIONS(2445),
    [anon_sym_PLUS_PLUS] = ACTIONS(2445),
    [anon_sym_sizeof] = ACTIONS(2443),
    [anon_sym___alignof__] = ACTIONS(2443),
    [anon_sym___alignof] = ACTIONS(2443),
    [anon_sym__alignof] = ACTIONS(2443),
    [anon_sym_alignof] = ACTIONS(2443),
    [anon_sym__Alignof] = ACTIONS(2443),
    [anon_sym_offsetof] = ACTIONS(2443),
    [anon_sym__Generic] = ACTIONS(2443),
    [anon_sym_asm] = ACTIONS(2443),
    [anon_sym___asm__] = ACTIONS(2443),
    [anon_sym___asm] = ACTIONS(2443),
    [sym_number_literal] = ACTIONS(2445),
    [anon_sym_L_SQUOTE] = ACTIONS(2445),
    [anon_sym_u_SQUOTE] = ACTIONS(2445),
    [anon_sym_U_SQUOTE] = ACTIONS(2445),
    [anon_sym_u8_SQUOTE] = ACTIONS(2445),
    [anon_sym_SQUOTE] = ACTIONS(2445),
    [anon_sym_L_DQUOTE] = ACTIONS(2445),
    [anon_sym_u_DQUOTE] = ACTIONS(2445),
    [anon_sym_U_DQUOTE] = ACTIONS(2445),
    [anon_sym_u8_DQUOTE] = ACTIONS(2445),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_true] = ACTIONS(2443),
    [sym_false] = ACTIONS(2443),
    [anon_sym_NULL] = ACTIONS(2443),
    [anon_sym_nullptr] = ACTIONS(2443),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2443),
    [anon_sym_decltype] = ACTIONS(2443),
    [anon_sym_explicit] = ACTIONS(2443),
    [anon_sym_typename] = ACTIONS(2443),
    [anon_sym_template] = ACTIONS(2443),
    [anon_sym_operator] = ACTIONS(2443),
    [anon_sym_try] = ACTIONS(2443),
    [anon_sym_delete] = ACTIONS(2443),
    [anon_sym_throw] = ACTIONS(2443),
    [anon_sym_namespace] = ACTIONS(2443),
    [anon_sym_using] = ACTIONS(2443),
    [anon_sym_static_assert] = ACTIONS(2443),
    [anon_sym_concept] = ACTIONS(2443),
    [anon_sym_co_return] = ACTIONS(2443),
    [anon_sym_co_yield] = ACTIONS(2443),
    [anon_sym_R_DQUOTE] = ACTIONS(2445),
    [anon_sym_LR_DQUOTE] = ACTIONS(2445),
    [anon_sym_uR_DQUOTE] = ACTIONS(2445),
    [anon_sym_UR_DQUOTE] = ACTIONS(2445),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2445),
    [anon_sym_co_await] = ACTIONS(2443),
    [anon_sym_new] = ACTIONS(2443),
    [anon_sym_requires] = ACTIONS(2443),
    [sym_this] = ACTIONS(2443),
    [anon_sym___launch_bounds__] = ACTIONS(2443),
  },
  [STATE(271)] = {
    [sym_identifier] = ACTIONS(2447),
    [aux_sym_preproc_include_token1] = ACTIONS(2447),
    [aux_sym_preproc_def_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token2] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2447),
    [aux_sym_preproc_else_token1] = ACTIONS(2447),
    [aux_sym_preproc_elif_token1] = ACTIONS(2447),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2447),
    [sym_preproc_directive] = ACTIONS(2447),
    [anon_sym_LPAREN2] = ACTIONS(2449),
    [anon_sym_BANG] = ACTIONS(2449),
    [anon_sym_TILDE] = ACTIONS(2449),
    [anon_sym_DASH] = ACTIONS(2447),
    [anon_sym_PLUS] = ACTIONS(2447),
    [anon_sym_STAR] = ACTIONS(2449),
    [anon_sym_AMP_AMP] = ACTIONS(2449),
    [anon_sym_AMP] = ACTIONS(2447),
    [anon_sym_SEMI] = ACTIONS(2449),
    [anon_sym___extension__] = ACTIONS(2447),
    [anon_sym_typedef] = ACTIONS(2447),
    [anon_sym___device__] = ACTIONS(2447),
    [anon_sym___host__] = ACTIONS(2447),
    [anon_sym___global__] = ACTIONS(2447),
    [anon_sym___forceinline__] = ACTIONS(2447),
    [anon_sym___noinline__] = ACTIONS(2447),
    [anon_sym_virtual] = ACTIONS(2447),
    [anon_sym_extern] = ACTIONS(2447),
    [anon_sym___attribute__] = ACTIONS(2447),
    [anon_sym___attribute] = ACTIONS(2447),
    [anon_sym_COLON_COLON] = ACTIONS(2449),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2449),
    [anon_sym___declspec] = ACTIONS(2447),
    [anon_sym___based] = ACTIONS(2447),
    [anon_sym___cdecl] = ACTIONS(2447),
    [anon_sym___clrcall] = ACTIONS(2447),
    [anon_sym___stdcall] = ACTIONS(2447),
    [anon_sym___fastcall] = ACTIONS(2447),
    [anon_sym___thiscall] = ACTIONS(2447),
    [anon_sym___vectorcall] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2449),
    [anon_sym_signed] = ACTIONS(2447),
    [anon_sym_unsigned] = ACTIONS(2447),
    [anon_sym_long] = ACTIONS(2447),
    [anon_sym_short] = ACTIONS(2447),
    [anon_sym_LBRACK] = ACTIONS(2447),
    [anon_sym_static] = ACTIONS(2447),
    [anon_sym_register] = ACTIONS(2447),
    [anon_sym_inline] = ACTIONS(2447),
    [anon_sym___inline] = ACTIONS(2447),
    [anon_sym___inline__] = ACTIONS(2447),
    [anon_sym___forceinline] = ACTIONS(2447),
    [anon_sym_thread_local] = ACTIONS(2447),
    [anon_sym___thread] = ACTIONS(2447),
    [anon_sym_const] = ACTIONS(2447),
    [anon_sym_constexpr] = ACTIONS(2447),
    [anon_sym_volatile] = ACTIONS(2447),
    [anon_sym_restrict] = ACTIONS(2447),
    [anon_sym___restrict__] = ACTIONS(2447),
    [anon_sym__Atomic] = ACTIONS(2447),
    [anon_sym__Noreturn] = ACTIONS(2447),
    [anon_sym_noreturn] = ACTIONS(2447),
    [anon_sym__Nonnull] = ACTIONS(2447),
    [anon_sym_mutable] = ACTIONS(2447),
    [anon_sym_constinit] = ACTIONS(2447),
    [anon_sym_consteval] = ACTIONS(2447),
    [anon_sym___shared__] = ACTIONS(2447),
    [anon_sym___local__] = ACTIONS(2447),
    [anon_sym___constant__] = ACTIONS(2447),
    [anon_sym___managed__] = ACTIONS(2447),
    [anon_sym___grid_constant__] = ACTIONS(2447),
    [anon_sym_alignas] = ACTIONS(2447),
    [anon_sym__Alignas] = ACTIONS(2447),
    [sym_primitive_type] = ACTIONS(2447),
    [anon_sym_enum] = ACTIONS(2447),
    [anon_sym_class] = ACTIONS(2447),
    [anon_sym_struct] = ACTIONS(2447),
    [anon_sym_union] = ACTIONS(2447),
    [anon_sym_if] = ACTIONS(2447),
    [anon_sym_switch] = ACTIONS(2447),
    [anon_sym_case] = ACTIONS(2447),
    [anon_sym_default] = ACTIONS(2447),
    [anon_sym_while] = ACTIONS(2447),
    [anon_sym_do] = ACTIONS(2447),
    [anon_sym_for] = ACTIONS(2447),
    [anon_sym_return] = ACTIONS(2447),
    [anon_sym_break] = ACTIONS(2447),
    [anon_sym_continue] = ACTIONS(2447),
    [anon_sym_goto] = ACTIONS(2447),
    [anon_sym___try] = ACTIONS(2447),
    [anon_sym___leave] = ACTIONS(2447),
    [anon_sym_not] = ACTIONS(2447),
    [anon_sym_compl] = ACTIONS(2447),
    [anon_sym_DASH_DASH] = ACTIONS(2449),
    [anon_sym_PLUS_PLUS] = ACTIONS(2449),
    [anon_sym_sizeof] = ACTIONS(2447),
    [anon_sym___alignof__] = ACTIONS(2447),
    [anon_sym___alignof] = ACTIONS(2447),
    [anon_sym__alignof] = ACTIONS(2447),
    [anon_sym_alignof] = ACTIONS(2447),
    [anon_sym__Alignof] = ACTIONS(2447),
    [anon_sym_offsetof] = ACTIONS(2447),
    [anon_sym__Generic] = ACTIONS(2447),
    [anon_sym_asm] = ACTIONS(2447),
    [anon_sym___asm__] = ACTIONS(2447),
    [anon_sym___asm] = ACTIONS(2447),
    [sym_number_literal] = ACTIONS(2449),
    [anon_sym_L_SQUOTE] = ACTIONS(2449),
    [anon_sym_u_SQUOTE] = ACTIONS(2449),
    [anon_sym_U_SQUOTE] = ACTIONS(2449),
    [anon_sym_u8_SQUOTE] = ACTIONS(2449),
    [anon_sym_SQUOTE] = ACTIONS(2449),
    [anon_sym_L_DQUOTE] = ACTIONS(2449),
    [anon_sym_u_DQUOTE] = ACTIONS(2449),
    [anon_sym_U_DQUOTE] = ACTIONS(2449),
    [anon_sym_u8_DQUOTE] = ACTIONS(2449),
    [anon_sym_DQUOTE] = ACTIONS(2449),
    [sym_true] = ACTIONS(2447),
    [sym_false] = ACTIONS(2447),
    [anon_sym_NULL] = ACTIONS(2447),
    [anon_sym_nullptr] = ACTIONS(2447),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2447),
    [anon_sym_decltype] = ACTIONS(2447),
    [anon_sym_explicit] = ACTIONS(2447),
    [anon_sym_typename] = ACTIONS(2447),
    [anon_sym_template] = ACTIONS(2447),
    [anon_sym_operator] = ACTIONS(2447),
    [anon_sym_try] = ACTIONS(2447),
    [anon_sym_delete] = ACTIONS(2447),
    [anon_sym_throw] = ACTIONS(2447),
    [anon_sym_namespace] = ACTIONS(2447),
    [anon_sym_using] = ACTIONS(2447),
    [anon_sym_static_assert] = ACTIONS(2447),
    [anon_sym_concept] = ACTIONS(2447),
    [anon_sym_co_return] = ACTIONS(2447),
    [anon_sym_co_yield] = ACTIONS(2447),
    [anon_sym_R_DQUOTE] = ACTIONS(2449),
    [anon_sym_LR_DQUOTE] = ACTIONS(2449),
    [anon_sym_uR_DQUOTE] = ACTIONS(2449),
    [anon_sym_UR_DQUOTE] = ACTIONS(2449),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2449),
    [anon_sym_co_await] = ACTIONS(2447),
    [anon_sym_new] = ACTIONS(2447),
    [anon_sym_requires] = ACTIONS(2447),
    [sym_this] = ACTIONS(2447),
    [anon_sym___launch_bounds__] = ACTIONS(2447),
  },
  [STATE(272)] = {
    [sym_identifier] = ACTIONS(2451),
    [aux_sym_preproc_include_token1] = ACTIONS(2451),
    [aux_sym_preproc_def_token1] = ACTIONS(2451),
    [aux_sym_preproc_if_token1] = ACTIONS(2451),
    [aux_sym_preproc_if_token2] = ACTIONS(2451),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2451),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2451),
    [aux_sym_preproc_else_token1] = ACTIONS(2451),
    [aux_sym_preproc_elif_token1] = ACTIONS(2451),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2451),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2451),
    [sym_preproc_directive] = ACTIONS(2451),
    [anon_sym_LPAREN2] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(2453),
    [anon_sym_TILDE] = ACTIONS(2453),
    [anon_sym_DASH] = ACTIONS(2451),
    [anon_sym_PLUS] = ACTIONS(2451),
    [anon_sym_STAR] = ACTIONS(2453),
    [anon_sym_AMP_AMP] = ACTIONS(2453),
    [anon_sym_AMP] = ACTIONS(2451),
    [anon_sym_SEMI] = ACTIONS(2453),
    [anon_sym___extension__] = ACTIONS(2451),
    [anon_sym_typedef] = ACTIONS(2451),
    [anon_sym___device__] = ACTIONS(2451),
    [anon_sym___host__] = ACTIONS(2451),
    [anon_sym___global__] = ACTIONS(2451),
    [anon_sym___forceinline__] = ACTIONS(2451),
    [anon_sym___noinline__] = ACTIONS(2451),
    [anon_sym_virtual] = ACTIONS(2451),
    [anon_sym_extern] = ACTIONS(2451),
    [anon_sym___attribute__] = ACTIONS(2451),
    [anon_sym___attribute] = ACTIONS(2451),
    [anon_sym_COLON_COLON] = ACTIONS(2453),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2453),
    [anon_sym___declspec] = ACTIONS(2451),
    [anon_sym___based] = ACTIONS(2451),
    [anon_sym___cdecl] = ACTIONS(2451),
    [anon_sym___clrcall] = ACTIONS(2451),
    [anon_sym___stdcall] = ACTIONS(2451),
    [anon_sym___fastcall] = ACTIONS(2451),
    [anon_sym___thiscall] = ACTIONS(2451),
    [anon_sym___vectorcall] = ACTIONS(2451),
    [anon_sym_LBRACE] = ACTIONS(2453),
    [anon_sym_signed] = ACTIONS(2451),
    [anon_sym_unsigned] = ACTIONS(2451),
    [anon_sym_long] = ACTIONS(2451),
    [anon_sym_short] = ACTIONS(2451),
    [anon_sym_LBRACK] = ACTIONS(2451),
    [anon_sym_static] = ACTIONS(2451),
    [anon_sym_register] = ACTIONS(2451),
    [anon_sym_inline] = ACTIONS(2451),
    [anon_sym___inline] = ACTIONS(2451),
    [anon_sym___inline__] = ACTIONS(2451),
    [anon_sym___forceinline] = ACTIONS(2451),
    [anon_sym_thread_local] = ACTIONS(2451),
    [anon_sym___thread] = ACTIONS(2451),
    [anon_sym_const] = ACTIONS(2451),
    [anon_sym_constexpr] = ACTIONS(2451),
    [anon_sym_volatile] = ACTIONS(2451),
    [anon_sym_restrict] = ACTIONS(2451),
    [anon_sym___restrict__] = ACTIONS(2451),
    [anon_sym__Atomic] = ACTIONS(2451),
    [anon_sym__Noreturn] = ACTIONS(2451),
    [anon_sym_noreturn] = ACTIONS(2451),
    [anon_sym__Nonnull] = ACTIONS(2451),
    [anon_sym_mutable] = ACTIONS(2451),
    [anon_sym_constinit] = ACTIONS(2451),
    [anon_sym_consteval] = ACTIONS(2451),
    [anon_sym___shared__] = ACTIONS(2451),
    [anon_sym___local__] = ACTIONS(2451),
    [anon_sym___constant__] = ACTIONS(2451),
    [anon_sym___managed__] = ACTIONS(2451),
    [anon_sym___grid_constant__] = ACTIONS(2451),
    [anon_sym_alignas] = ACTIONS(2451),
    [anon_sym__Alignas] = ACTIONS(2451),
    [sym_primitive_type] = ACTIONS(2451),
    [anon_sym_enum] = ACTIONS(2451),
    [anon_sym_class] = ACTIONS(2451),
    [anon_sym_struct] = ACTIONS(2451),
    [anon_sym_union] = ACTIONS(2451),
    [anon_sym_if] = ACTIONS(2451),
    [anon_sym_switch] = ACTIONS(2451),
    [anon_sym_case] = ACTIONS(2451),
    [anon_sym_default] = ACTIONS(2451),
    [anon_sym_while] = ACTIONS(2451),
    [anon_sym_do] = ACTIONS(2451),
    [anon_sym_for] = ACTIONS(2451),
    [anon_sym_return] = ACTIONS(2451),
    [anon_sym_break] = ACTIONS(2451),
    [anon_sym_continue] = ACTIONS(2451),
    [anon_sym_goto] = ACTIONS(2451),
    [anon_sym___try] = ACTIONS(2451),
    [anon_sym___leave] = ACTIONS(2451),
    [anon_sym_not] = ACTIONS(2451),
    [anon_sym_compl] = ACTIONS(2451),
    [anon_sym_DASH_DASH] = ACTIONS(2453),
    [anon_sym_PLUS_PLUS] = ACTIONS(2453),
    [anon_sym_sizeof] = ACTIONS(2451),
    [anon_sym___alignof__] = ACTIONS(2451),
    [anon_sym___alignof] = ACTIONS(2451),
    [anon_sym__alignof] = ACTIONS(2451),
    [anon_sym_alignof] = ACTIONS(2451),
    [anon_sym__Alignof] = ACTIONS(2451),
    [anon_sym_offsetof] = ACTIONS(2451),
    [anon_sym__Generic] = ACTIONS(2451),
    [anon_sym_asm] = ACTIONS(2451),
    [anon_sym___asm__] = ACTIONS(2451),
    [anon_sym___asm] = ACTIONS(2451),
    [sym_number_literal] = ACTIONS(2453),
    [anon_sym_L_SQUOTE] = ACTIONS(2453),
    [anon_sym_u_SQUOTE] = ACTIONS(2453),
    [anon_sym_U_SQUOTE] = ACTIONS(2453),
    [anon_sym_u8_SQUOTE] = ACTIONS(2453),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_L_DQUOTE] = ACTIONS(2453),
    [anon_sym_u_DQUOTE] = ACTIONS(2453),
    [anon_sym_U_DQUOTE] = ACTIONS(2453),
    [anon_sym_u8_DQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2453),
    [sym_true] = ACTIONS(2451),
    [sym_false] = ACTIONS(2451),
    [anon_sym_NULL] = ACTIONS(2451),
    [anon_sym_nullptr] = ACTIONS(2451),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2451),
    [anon_sym_decltype] = ACTIONS(2451),
    [anon_sym_explicit] = ACTIONS(2451),
    [anon_sym_typename] = ACTIONS(2451),
    [anon_sym_template] = ACTIONS(2451),
    [anon_sym_operator] = ACTIONS(2451),
    [anon_sym_try] = ACTIONS(2451),
    [anon_sym_delete] = ACTIONS(2451),
    [anon_sym_throw] = ACTIONS(2451),
    [anon_sym_namespace] = ACTIONS(2451),
    [anon_sym_using] = ACTIONS(2451),
    [anon_sym_static_assert] = ACTIONS(2451),
    [anon_sym_concept] = ACTIONS(2451),
    [anon_sym_co_return] = ACTIONS(2451),
    [anon_sym_co_yield] = ACTIONS(2451),
    [anon_sym_R_DQUOTE] = ACTIONS(2453),
    [anon_sym_LR_DQUOTE] = ACTIONS(2453),
    [anon_sym_uR_DQUOTE] = ACTIONS(2453),
    [anon_sym_UR_DQUOTE] = ACTIONS(2453),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2453),
    [anon_sym_co_await] = ACTIONS(2451),
    [anon_sym_new] = ACTIONS(2451),
    [anon_sym_requires] = ACTIONS(2451),
    [sym_this] = ACTIONS(2451),
    [anon_sym___launch_bounds__] = ACTIONS(2451),
  },
  [STATE(273)] = {
    [sym_catch_clause] = STATE(281),
    [aux_sym_constructor_try_statement_repeat1] = STATE(281),
    [sym_identifier] = ACTIONS(1934),
    [aux_sym_preproc_include_token1] = ACTIONS(1934),
    [aux_sym_preproc_def_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token2] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1934),
    [sym_preproc_directive] = ACTIONS(1934),
    [anon_sym_LPAREN2] = ACTIONS(1936),
    [anon_sym_BANG] = ACTIONS(1936),
    [anon_sym_TILDE] = ACTIONS(1936),
    [anon_sym_DASH] = ACTIONS(1934),
    [anon_sym_PLUS] = ACTIONS(1934),
    [anon_sym_STAR] = ACTIONS(1936),
    [anon_sym_AMP_AMP] = ACTIONS(1936),
    [anon_sym_AMP] = ACTIONS(1934),
    [anon_sym_SEMI] = ACTIONS(1936),
    [anon_sym___extension__] = ACTIONS(1934),
    [anon_sym_typedef] = ACTIONS(1934),
    [anon_sym___device__] = ACTIONS(1934),
    [anon_sym___host__] = ACTIONS(1934),
    [anon_sym___global__] = ACTIONS(1934),
    [anon_sym___forceinline__] = ACTIONS(1934),
    [anon_sym___noinline__] = ACTIONS(1934),
    [anon_sym_virtual] = ACTIONS(1934),
    [anon_sym_extern] = ACTIONS(1934),
    [anon_sym___attribute__] = ACTIONS(1934),
    [anon_sym___attribute] = ACTIONS(1934),
    [anon_sym_COLON_COLON] = ACTIONS(1936),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1936),
    [anon_sym___declspec] = ACTIONS(1934),
    [anon_sym___based] = ACTIONS(1934),
    [anon_sym___cdecl] = ACTIONS(1934),
    [anon_sym___clrcall] = ACTIONS(1934),
    [anon_sym___stdcall] = ACTIONS(1934),
    [anon_sym___fastcall] = ACTIONS(1934),
    [anon_sym___thiscall] = ACTIONS(1934),
    [anon_sym___vectorcall] = ACTIONS(1934),
    [anon_sym_LBRACE] = ACTIONS(1936),
    [anon_sym_signed] = ACTIONS(1934),
    [anon_sym_unsigned] = ACTIONS(1934),
    [anon_sym_long] = ACTIONS(1934),
    [anon_sym_short] = ACTIONS(1934),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [anon_sym_static] = ACTIONS(1934),
    [anon_sym_register] = ACTIONS(1934),
    [anon_sym_inline] = ACTIONS(1934),
    [anon_sym___inline] = ACTIONS(1934),
    [anon_sym___inline__] = ACTIONS(1934),
    [anon_sym___forceinline] = ACTIONS(1934),
    [anon_sym_thread_local] = ACTIONS(1934),
    [anon_sym___thread] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1934),
    [anon_sym_constexpr] = ACTIONS(1934),
    [anon_sym_volatile] = ACTIONS(1934),
    [anon_sym_restrict] = ACTIONS(1934),
    [anon_sym___restrict__] = ACTIONS(1934),
    [anon_sym__Atomic] = ACTIONS(1934),
    [anon_sym__Noreturn] = ACTIONS(1934),
    [anon_sym_noreturn] = ACTIONS(1934),
    [anon_sym__Nonnull] = ACTIONS(1934),
    [anon_sym_mutable] = ACTIONS(1934),
    [anon_sym_constinit] = ACTIONS(1934),
    [anon_sym_consteval] = ACTIONS(1934),
    [anon_sym___shared__] = ACTIONS(1934),
    [anon_sym___local__] = ACTIONS(1934),
    [anon_sym___constant__] = ACTIONS(1934),
    [anon_sym___managed__] = ACTIONS(1934),
    [anon_sym___grid_constant__] = ACTIONS(1934),
    [anon_sym_alignas] = ACTIONS(1934),
    [anon_sym__Alignas] = ACTIONS(1934),
    [sym_primitive_type] = ACTIONS(1934),
    [anon_sym_enum] = ACTIONS(1934),
    [anon_sym_class] = ACTIONS(1934),
    [anon_sym_struct] = ACTIONS(1934),
    [anon_sym_union] = ACTIONS(1934),
    [anon_sym_if] = ACTIONS(1934),
    [anon_sym_else] = ACTIONS(1934),
    [anon_sym_switch] = ACTIONS(1934),
    [anon_sym_case] = ACTIONS(1934),
    [anon_sym_default] = ACTIONS(1934),
    [anon_sym_while] = ACTIONS(1934),
    [anon_sym_do] = ACTIONS(1934),
    [anon_sym_for] = ACTIONS(1934),
    [anon_sym_return] = ACTIONS(1934),
    [anon_sym_break] = ACTIONS(1934),
    [anon_sym_continue] = ACTIONS(1934),
    [anon_sym_goto] = ACTIONS(1934),
    [anon_sym___try] = ACTIONS(1934),
    [anon_sym___leave] = ACTIONS(1934),
    [anon_sym_not] = ACTIONS(1934),
    [anon_sym_compl] = ACTIONS(1934),
    [anon_sym_DASH_DASH] = ACTIONS(1936),
    [anon_sym_PLUS_PLUS] = ACTIONS(1936),
    [anon_sym_sizeof] = ACTIONS(1934),
    [anon_sym___alignof__] = ACTIONS(1934),
    [anon_sym___alignof] = ACTIONS(1934),
    [anon_sym__alignof] = ACTIONS(1934),
    [anon_sym_alignof] = ACTIONS(1934),
    [anon_sym__Alignof] = ACTIONS(1934),
    [anon_sym_offsetof] = ACTIONS(1934),
    [anon_sym__Generic] = ACTIONS(1934),
    [anon_sym_asm] = ACTIONS(1934),
    [anon_sym___asm__] = ACTIONS(1934),
    [anon_sym___asm] = ACTIONS(1934),
    [sym_number_literal] = ACTIONS(1936),
    [anon_sym_L_SQUOTE] = ACTIONS(1936),
    [anon_sym_u_SQUOTE] = ACTIONS(1936),
    [anon_sym_U_SQUOTE] = ACTIONS(1936),
    [anon_sym_u8_SQUOTE] = ACTIONS(1936),
    [anon_sym_SQUOTE] = ACTIONS(1936),
    [anon_sym_L_DQUOTE] = ACTIONS(1936),
    [anon_sym_u_DQUOTE] = ACTIONS(1936),
    [anon_sym_U_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8_DQUOTE] = ACTIONS(1936),
    [anon_sym_DQUOTE] = ACTIONS(1936),
    [sym_true] = ACTIONS(1934),
    [sym_false] = ACTIONS(1934),
    [anon_sym_NULL] = ACTIONS(1934),
    [anon_sym_nullptr] = ACTIONS(1934),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1934),
    [anon_sym_decltype] = ACTIONS(1934),
    [anon_sym_explicit] = ACTIONS(1934),
    [anon_sym_typename] = ACTIONS(1934),
    [anon_sym_template] = ACTIONS(1934),
    [anon_sym_operator] = ACTIONS(1934),
    [anon_sym_try] = ACTIONS(1934),
    [anon_sym_delete] = ACTIONS(1934),
    [anon_sym_throw] = ACTIONS(1934),
    [anon_sym_namespace] = ACTIONS(1934),
    [anon_sym_using] = ACTIONS(1934),
    [anon_sym_static_assert] = ACTIONS(1934),
    [anon_sym_concept] = ACTIONS(1934),
    [anon_sym_co_return] = ACTIONS(1934),
    [anon_sym_co_yield] = ACTIONS(1934),
    [anon_sym_catch] = ACTIONS(2455),
    [anon_sym_R_DQUOTE] = ACTIONS(1936),
    [anon_sym_LR_DQUOTE] = ACTIONS(1936),
    [anon_sym_uR_DQUOTE] = ACTIONS(1936),
    [anon_sym_UR_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1936),
    [anon_sym_co_await] = ACTIONS(1934),
    [anon_sym_new] = ACTIONS(1934),
    [anon_sym_requires] = ACTIONS(1934),
    [sym_this] = ACTIONS(1934),
    [anon_sym___launch_bounds__] = ACTIONS(1934),
  },
  [STATE(274)] = {
    [sym_identifier] = ACTIONS(2457),
    [aux_sym_preproc_include_token1] = ACTIONS(2457),
    [aux_sym_preproc_def_token1] = ACTIONS(2457),
    [aux_sym_preproc_if_token1] = ACTIONS(2457),
    [aux_sym_preproc_if_token2] = ACTIONS(2457),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2457),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2457),
    [aux_sym_preproc_else_token1] = ACTIONS(2457),
    [aux_sym_preproc_elif_token1] = ACTIONS(2457),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2457),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2457),
    [sym_preproc_directive] = ACTIONS(2457),
    [anon_sym_LPAREN2] = ACTIONS(2459),
    [anon_sym_BANG] = ACTIONS(2459),
    [anon_sym_TILDE] = ACTIONS(2459),
    [anon_sym_DASH] = ACTIONS(2457),
    [anon_sym_PLUS] = ACTIONS(2457),
    [anon_sym_STAR] = ACTIONS(2459),
    [anon_sym_AMP_AMP] = ACTIONS(2459),
    [anon_sym_AMP] = ACTIONS(2457),
    [anon_sym_SEMI] = ACTIONS(2459),
    [anon_sym___extension__] = ACTIONS(2457),
    [anon_sym_typedef] = ACTIONS(2457),
    [anon_sym___device__] = ACTIONS(2457),
    [anon_sym___host__] = ACTIONS(2457),
    [anon_sym___global__] = ACTIONS(2457),
    [anon_sym___forceinline__] = ACTIONS(2457),
    [anon_sym___noinline__] = ACTIONS(2457),
    [anon_sym_virtual] = ACTIONS(2457),
    [anon_sym_extern] = ACTIONS(2457),
    [anon_sym___attribute__] = ACTIONS(2457),
    [anon_sym___attribute] = ACTIONS(2457),
    [anon_sym_COLON_COLON] = ACTIONS(2459),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2459),
    [anon_sym___declspec] = ACTIONS(2457),
    [anon_sym___based] = ACTIONS(2457),
    [anon_sym___cdecl] = ACTIONS(2457),
    [anon_sym___clrcall] = ACTIONS(2457),
    [anon_sym___stdcall] = ACTIONS(2457),
    [anon_sym___fastcall] = ACTIONS(2457),
    [anon_sym___thiscall] = ACTIONS(2457),
    [anon_sym___vectorcall] = ACTIONS(2457),
    [anon_sym_LBRACE] = ACTIONS(2459),
    [anon_sym_signed] = ACTIONS(2457),
    [anon_sym_unsigned] = ACTIONS(2457),
    [anon_sym_long] = ACTIONS(2457),
    [anon_sym_short] = ACTIONS(2457),
    [anon_sym_LBRACK] = ACTIONS(2457),
    [anon_sym_static] = ACTIONS(2457),
    [anon_sym_register] = ACTIONS(2457),
    [anon_sym_inline] = ACTIONS(2457),
    [anon_sym___inline] = ACTIONS(2457),
    [anon_sym___inline__] = ACTIONS(2457),
    [anon_sym___forceinline] = ACTIONS(2457),
    [anon_sym_thread_local] = ACTIONS(2457),
    [anon_sym___thread] = ACTIONS(2457),
    [anon_sym_const] = ACTIONS(2457),
    [anon_sym_constexpr] = ACTIONS(2457),
    [anon_sym_volatile] = ACTIONS(2457),
    [anon_sym_restrict] = ACTIONS(2457),
    [anon_sym___restrict__] = ACTIONS(2457),
    [anon_sym__Atomic] = ACTIONS(2457),
    [anon_sym__Noreturn] = ACTIONS(2457),
    [anon_sym_noreturn] = ACTIONS(2457),
    [anon_sym__Nonnull] = ACTIONS(2457),
    [anon_sym_mutable] = ACTIONS(2457),
    [anon_sym_constinit] = ACTIONS(2457),
    [anon_sym_consteval] = ACTIONS(2457),
    [anon_sym___shared__] = ACTIONS(2457),
    [anon_sym___local__] = ACTIONS(2457),
    [anon_sym___constant__] = ACTIONS(2457),
    [anon_sym___managed__] = ACTIONS(2457),
    [anon_sym___grid_constant__] = ACTIONS(2457),
    [anon_sym_alignas] = ACTIONS(2457),
    [anon_sym__Alignas] = ACTIONS(2457),
    [sym_primitive_type] = ACTIONS(2457),
    [anon_sym_enum] = ACTIONS(2457),
    [anon_sym_class] = ACTIONS(2457),
    [anon_sym_struct] = ACTIONS(2457),
    [anon_sym_union] = ACTIONS(2457),
    [anon_sym_if] = ACTIONS(2457),
    [anon_sym_switch] = ACTIONS(2457),
    [anon_sym_case] = ACTIONS(2457),
    [anon_sym_default] = ACTIONS(2457),
    [anon_sym_while] = ACTIONS(2457),
    [anon_sym_do] = ACTIONS(2457),
    [anon_sym_for] = ACTIONS(2457),
    [anon_sym_return] = ACTIONS(2457),
    [anon_sym_break] = ACTIONS(2457),
    [anon_sym_continue] = ACTIONS(2457),
    [anon_sym_goto] = ACTIONS(2457),
    [anon_sym___try] = ACTIONS(2457),
    [anon_sym___leave] = ACTIONS(2457),
    [anon_sym_not] = ACTIONS(2457),
    [anon_sym_compl] = ACTIONS(2457),
    [anon_sym_DASH_DASH] = ACTIONS(2459),
    [anon_sym_PLUS_PLUS] = ACTIONS(2459),
    [anon_sym_sizeof] = ACTIONS(2457),
    [anon_sym___alignof__] = ACTIONS(2457),
    [anon_sym___alignof] = ACTIONS(2457),
    [anon_sym__alignof] = ACTIONS(2457),
    [anon_sym_alignof] = ACTIONS(2457),
    [anon_sym__Alignof] = ACTIONS(2457),
    [anon_sym_offsetof] = ACTIONS(2457),
    [anon_sym__Generic] = ACTIONS(2457),
    [anon_sym_asm] = ACTIONS(2457),
    [anon_sym___asm__] = ACTIONS(2457),
    [anon_sym___asm] = ACTIONS(2457),
    [sym_number_literal] = ACTIONS(2459),
    [anon_sym_L_SQUOTE] = ACTIONS(2459),
    [anon_sym_u_SQUOTE] = ACTIONS(2459),
    [anon_sym_U_SQUOTE] = ACTIONS(2459),
    [anon_sym_u8_SQUOTE] = ACTIONS(2459),
    [anon_sym_SQUOTE] = ACTIONS(2459),
    [anon_sym_L_DQUOTE] = ACTIONS(2459),
    [anon_sym_u_DQUOTE] = ACTIONS(2459),
    [anon_sym_U_DQUOTE] = ACTIONS(2459),
    [anon_sym_u8_DQUOTE] = ACTIONS(2459),
    [anon_sym_DQUOTE] = ACTIONS(2459),
    [sym_true] = ACTIONS(2457),
    [sym_false] = ACTIONS(2457),
    [anon_sym_NULL] = ACTIONS(2457),
    [anon_sym_nullptr] = ACTIONS(2457),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2457),
    [anon_sym_decltype] = ACTIONS(2457),
    [anon_sym_explicit] = ACTIONS(2457),
    [anon_sym_typename] = ACTIONS(2457),
    [anon_sym_template] = ACTIONS(2457),
    [anon_sym_operator] = ACTIONS(2457),
    [anon_sym_try] = ACTIONS(2457),
    [anon_sym_delete] = ACTIONS(2457),
    [anon_sym_throw] = ACTIONS(2457),
    [anon_sym_namespace] = ACTIONS(2457),
    [anon_sym_using] = ACTIONS(2457),
    [anon_sym_static_assert] = ACTIONS(2457),
    [anon_sym_concept] = ACTIONS(2457),
    [anon_sym_co_return] = ACTIONS(2457),
    [anon_sym_co_yield] = ACTIONS(2457),
    [anon_sym_R_DQUOTE] = ACTIONS(2459),
    [anon_sym_LR_DQUOTE] = ACTIONS(2459),
    [anon_sym_uR_DQUOTE] = ACTIONS(2459),
    [anon_sym_UR_DQUOTE] = ACTIONS(2459),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2459),
    [anon_sym_co_await] = ACTIONS(2457),
    [anon_sym_new] = ACTIONS(2457),
    [anon_sym_requires] = ACTIONS(2457),
    [sym_this] = ACTIONS(2457),
    [anon_sym___launch_bounds__] = ACTIONS(2457),
  },
  [STATE(275)] = {
    [sym_catch_clause] = STATE(280),
    [aux_sym_constructor_try_statement_repeat1] = STATE(280),
    [sym_identifier] = ACTIONS(1934),
    [aux_sym_preproc_include_token1] = ACTIONS(1934),
    [aux_sym_preproc_def_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1934),
    [sym_preproc_directive] = ACTIONS(1934),
    [anon_sym_LPAREN2] = ACTIONS(1936),
    [anon_sym_BANG] = ACTIONS(1936),
    [anon_sym_TILDE] = ACTIONS(1936),
    [anon_sym_DASH] = ACTIONS(1934),
    [anon_sym_PLUS] = ACTIONS(1934),
    [anon_sym_STAR] = ACTIONS(1936),
    [anon_sym_AMP_AMP] = ACTIONS(1936),
    [anon_sym_AMP] = ACTIONS(1934),
    [anon_sym_SEMI] = ACTIONS(1936),
    [anon_sym___extension__] = ACTIONS(1934),
    [anon_sym_typedef] = ACTIONS(1934),
    [anon_sym___device__] = ACTIONS(1934),
    [anon_sym___host__] = ACTIONS(1934),
    [anon_sym___global__] = ACTIONS(1934),
    [anon_sym___forceinline__] = ACTIONS(1934),
    [anon_sym___noinline__] = ACTIONS(1934),
    [anon_sym_virtual] = ACTIONS(1934),
    [anon_sym_extern] = ACTIONS(1934),
    [anon_sym___attribute__] = ACTIONS(1934),
    [anon_sym___attribute] = ACTIONS(1934),
    [anon_sym_COLON_COLON] = ACTIONS(1936),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1936),
    [anon_sym___declspec] = ACTIONS(1934),
    [anon_sym___based] = ACTIONS(1934),
    [anon_sym___cdecl] = ACTIONS(1934),
    [anon_sym___clrcall] = ACTIONS(1934),
    [anon_sym___stdcall] = ACTIONS(1934),
    [anon_sym___fastcall] = ACTIONS(1934),
    [anon_sym___thiscall] = ACTIONS(1934),
    [anon_sym___vectorcall] = ACTIONS(1934),
    [anon_sym_LBRACE] = ACTIONS(1936),
    [anon_sym_RBRACE] = ACTIONS(1936),
    [anon_sym_signed] = ACTIONS(1934),
    [anon_sym_unsigned] = ACTIONS(1934),
    [anon_sym_long] = ACTIONS(1934),
    [anon_sym_short] = ACTIONS(1934),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [anon_sym_static] = ACTIONS(1934),
    [anon_sym_register] = ACTIONS(1934),
    [anon_sym_inline] = ACTIONS(1934),
    [anon_sym___inline] = ACTIONS(1934),
    [anon_sym___inline__] = ACTIONS(1934),
    [anon_sym___forceinline] = ACTIONS(1934),
    [anon_sym_thread_local] = ACTIONS(1934),
    [anon_sym___thread] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1934),
    [anon_sym_constexpr] = ACTIONS(1934),
    [anon_sym_volatile] = ACTIONS(1934),
    [anon_sym_restrict] = ACTIONS(1934),
    [anon_sym___restrict__] = ACTIONS(1934),
    [anon_sym__Atomic] = ACTIONS(1934),
    [anon_sym__Noreturn] = ACTIONS(1934),
    [anon_sym_noreturn] = ACTIONS(1934),
    [anon_sym__Nonnull] = ACTIONS(1934),
    [anon_sym_mutable] = ACTIONS(1934),
    [anon_sym_constinit] = ACTIONS(1934),
    [anon_sym_consteval] = ACTIONS(1934),
    [anon_sym___shared__] = ACTIONS(1934),
    [anon_sym___local__] = ACTIONS(1934),
    [anon_sym___constant__] = ACTIONS(1934),
    [anon_sym___managed__] = ACTIONS(1934),
    [anon_sym___grid_constant__] = ACTIONS(1934),
    [anon_sym_alignas] = ACTIONS(1934),
    [anon_sym__Alignas] = ACTIONS(1934),
    [sym_primitive_type] = ACTIONS(1934),
    [anon_sym_enum] = ACTIONS(1934),
    [anon_sym_class] = ACTIONS(1934),
    [anon_sym_struct] = ACTIONS(1934),
    [anon_sym_union] = ACTIONS(1934),
    [anon_sym_if] = ACTIONS(1934),
    [anon_sym_else] = ACTIONS(1934),
    [anon_sym_switch] = ACTIONS(1934),
    [anon_sym_case] = ACTIONS(1934),
    [anon_sym_default] = ACTIONS(1934),
    [anon_sym_while] = ACTIONS(1934),
    [anon_sym_do] = ACTIONS(1934),
    [anon_sym_for] = ACTIONS(1934),
    [anon_sym_return] = ACTIONS(1934),
    [anon_sym_break] = ACTIONS(1934),
    [anon_sym_continue] = ACTIONS(1934),
    [anon_sym_goto] = ACTIONS(1934),
    [anon_sym___try] = ACTIONS(1934),
    [anon_sym___leave] = ACTIONS(1934),
    [anon_sym_not] = ACTIONS(1934),
    [anon_sym_compl] = ACTIONS(1934),
    [anon_sym_DASH_DASH] = ACTIONS(1936),
    [anon_sym_PLUS_PLUS] = ACTIONS(1936),
    [anon_sym_sizeof] = ACTIONS(1934),
    [anon_sym___alignof__] = ACTIONS(1934),
    [anon_sym___alignof] = ACTIONS(1934),
    [anon_sym__alignof] = ACTIONS(1934),
    [anon_sym_alignof] = ACTIONS(1934),
    [anon_sym__Alignof] = ACTIONS(1934),
    [anon_sym_offsetof] = ACTIONS(1934),
    [anon_sym__Generic] = ACTIONS(1934),
    [anon_sym_asm] = ACTIONS(1934),
    [anon_sym___asm__] = ACTIONS(1934),
    [anon_sym___asm] = ACTIONS(1934),
    [sym_number_literal] = ACTIONS(1936),
    [anon_sym_L_SQUOTE] = ACTIONS(1936),
    [anon_sym_u_SQUOTE] = ACTIONS(1936),
    [anon_sym_U_SQUOTE] = ACTIONS(1936),
    [anon_sym_u8_SQUOTE] = ACTIONS(1936),
    [anon_sym_SQUOTE] = ACTIONS(1936),
    [anon_sym_L_DQUOTE] = ACTIONS(1936),
    [anon_sym_u_DQUOTE] = ACTIONS(1936),
    [anon_sym_U_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8_DQUOTE] = ACTIONS(1936),
    [anon_sym_DQUOTE] = ACTIONS(1936),
    [sym_true] = ACTIONS(1934),
    [sym_false] = ACTIONS(1934),
    [anon_sym_NULL] = ACTIONS(1934),
    [anon_sym_nullptr] = ACTIONS(1934),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1934),
    [anon_sym_decltype] = ACTIONS(1934),
    [anon_sym_explicit] = ACTIONS(1934),
    [anon_sym_typename] = ACTIONS(1934),
    [anon_sym_template] = ACTIONS(1934),
    [anon_sym_operator] = ACTIONS(1934),
    [anon_sym_try] = ACTIONS(1934),
    [anon_sym_delete] = ACTIONS(1934),
    [anon_sym_throw] = ACTIONS(1934),
    [anon_sym_namespace] = ACTIONS(1934),
    [anon_sym_using] = ACTIONS(1934),
    [anon_sym_static_assert] = ACTIONS(1934),
    [anon_sym_concept] = ACTIONS(1934),
    [anon_sym_co_return] = ACTIONS(1934),
    [anon_sym_co_yield] = ACTIONS(1934),
    [anon_sym_catch] = ACTIONS(2461),
    [anon_sym_R_DQUOTE] = ACTIONS(1936),
    [anon_sym_LR_DQUOTE] = ACTIONS(1936),
    [anon_sym_uR_DQUOTE] = ACTIONS(1936),
    [anon_sym_UR_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1936),
    [anon_sym_co_await] = ACTIONS(1934),
    [anon_sym_new] = ACTIONS(1934),
    [anon_sym_requires] = ACTIONS(1934),
    [sym_this] = ACTIONS(1934),
    [anon_sym___launch_bounds__] = ACTIONS(1934),
  },
  [STATE(276)] = {
    [sym_identifier] = ACTIONS(2463),
    [aux_sym_preproc_include_token1] = ACTIONS(2463),
    [aux_sym_preproc_def_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token2] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2463),
    [aux_sym_preproc_else_token1] = ACTIONS(2463),
    [aux_sym_preproc_elif_token1] = ACTIONS(2463),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2463),
    [sym_preproc_directive] = ACTIONS(2463),
    [anon_sym_LPAREN2] = ACTIONS(2465),
    [anon_sym_BANG] = ACTIONS(2465),
    [anon_sym_TILDE] = ACTIONS(2465),
    [anon_sym_DASH] = ACTIONS(2463),
    [anon_sym_PLUS] = ACTIONS(2463),
    [anon_sym_STAR] = ACTIONS(2465),
    [anon_sym_AMP_AMP] = ACTIONS(2465),
    [anon_sym_AMP] = ACTIONS(2463),
    [anon_sym_SEMI] = ACTIONS(2465),
    [anon_sym___extension__] = ACTIONS(2463),
    [anon_sym_typedef] = ACTIONS(2463),
    [anon_sym___device__] = ACTIONS(2463),
    [anon_sym___host__] = ACTIONS(2463),
    [anon_sym___global__] = ACTIONS(2463),
    [anon_sym___forceinline__] = ACTIONS(2463),
    [anon_sym___noinline__] = ACTIONS(2463),
    [anon_sym_virtual] = ACTIONS(2463),
    [anon_sym_extern] = ACTIONS(2463),
    [anon_sym___attribute__] = ACTIONS(2463),
    [anon_sym___attribute] = ACTIONS(2463),
    [anon_sym_COLON_COLON] = ACTIONS(2465),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2465),
    [anon_sym___declspec] = ACTIONS(2463),
    [anon_sym___based] = ACTIONS(2463),
    [anon_sym___cdecl] = ACTIONS(2463),
    [anon_sym___clrcall] = ACTIONS(2463),
    [anon_sym___stdcall] = ACTIONS(2463),
    [anon_sym___fastcall] = ACTIONS(2463),
    [anon_sym___thiscall] = ACTIONS(2463),
    [anon_sym___vectorcall] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_signed] = ACTIONS(2463),
    [anon_sym_unsigned] = ACTIONS(2463),
    [anon_sym_long] = ACTIONS(2463),
    [anon_sym_short] = ACTIONS(2463),
    [anon_sym_LBRACK] = ACTIONS(2463),
    [anon_sym_static] = ACTIONS(2463),
    [anon_sym_register] = ACTIONS(2463),
    [anon_sym_inline] = ACTIONS(2463),
    [anon_sym___inline] = ACTIONS(2463),
    [anon_sym___inline__] = ACTIONS(2463),
    [anon_sym___forceinline] = ACTIONS(2463),
    [anon_sym_thread_local] = ACTIONS(2463),
    [anon_sym___thread] = ACTIONS(2463),
    [anon_sym_const] = ACTIONS(2463),
    [anon_sym_constexpr] = ACTIONS(2463),
    [anon_sym_volatile] = ACTIONS(2463),
    [anon_sym_restrict] = ACTIONS(2463),
    [anon_sym___restrict__] = ACTIONS(2463),
    [anon_sym__Atomic] = ACTIONS(2463),
    [anon_sym__Noreturn] = ACTIONS(2463),
    [anon_sym_noreturn] = ACTIONS(2463),
    [anon_sym__Nonnull] = ACTIONS(2463),
    [anon_sym_mutable] = ACTIONS(2463),
    [anon_sym_constinit] = ACTIONS(2463),
    [anon_sym_consteval] = ACTIONS(2463),
    [anon_sym___shared__] = ACTIONS(2463),
    [anon_sym___local__] = ACTIONS(2463),
    [anon_sym___constant__] = ACTIONS(2463),
    [anon_sym___managed__] = ACTIONS(2463),
    [anon_sym___grid_constant__] = ACTIONS(2463),
    [anon_sym_alignas] = ACTIONS(2463),
    [anon_sym__Alignas] = ACTIONS(2463),
    [sym_primitive_type] = ACTIONS(2463),
    [anon_sym_enum] = ACTIONS(2463),
    [anon_sym_class] = ACTIONS(2463),
    [anon_sym_struct] = ACTIONS(2463),
    [anon_sym_union] = ACTIONS(2463),
    [anon_sym_if] = ACTIONS(2463),
    [anon_sym_switch] = ACTIONS(2463),
    [anon_sym_case] = ACTIONS(2463),
    [anon_sym_default] = ACTIONS(2463),
    [anon_sym_while] = ACTIONS(2463),
    [anon_sym_do] = ACTIONS(2463),
    [anon_sym_for] = ACTIONS(2463),
    [anon_sym_return] = ACTIONS(2463),
    [anon_sym_break] = ACTIONS(2463),
    [anon_sym_continue] = ACTIONS(2463),
    [anon_sym_goto] = ACTIONS(2463),
    [anon_sym___try] = ACTIONS(2463),
    [anon_sym___leave] = ACTIONS(2463),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_compl] = ACTIONS(2463),
    [anon_sym_DASH_DASH] = ACTIONS(2465),
    [anon_sym_PLUS_PLUS] = ACTIONS(2465),
    [anon_sym_sizeof] = ACTIONS(2463),
    [anon_sym___alignof__] = ACTIONS(2463),
    [anon_sym___alignof] = ACTIONS(2463),
    [anon_sym__alignof] = ACTIONS(2463),
    [anon_sym_alignof] = ACTIONS(2463),
    [anon_sym__Alignof] = ACTIONS(2463),
    [anon_sym_offsetof] = ACTIONS(2463),
    [anon_sym__Generic] = ACTIONS(2463),
    [anon_sym_asm] = ACTIONS(2463),
    [anon_sym___asm__] = ACTIONS(2463),
    [anon_sym___asm] = ACTIONS(2463),
    [sym_number_literal] = ACTIONS(2465),
    [anon_sym_L_SQUOTE] = ACTIONS(2465),
    [anon_sym_u_SQUOTE] = ACTIONS(2465),
    [anon_sym_U_SQUOTE] = ACTIONS(2465),
    [anon_sym_u8_SQUOTE] = ACTIONS(2465),
    [anon_sym_SQUOTE] = ACTIONS(2465),
    [anon_sym_L_DQUOTE] = ACTIONS(2465),
    [anon_sym_u_DQUOTE] = ACTIONS(2465),
    [anon_sym_U_DQUOTE] = ACTIONS(2465),
    [anon_sym_u8_DQUOTE] = ACTIONS(2465),
    [anon_sym_DQUOTE] = ACTIONS(2465),
    [sym_true] = ACTIONS(2463),
    [sym_false] = ACTIONS(2463),
    [anon_sym_NULL] = ACTIONS(2463),
    [anon_sym_nullptr] = ACTIONS(2463),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2463),
    [anon_sym_decltype] = ACTIONS(2463),
    [anon_sym_explicit] = ACTIONS(2463),
    [anon_sym_typename] = ACTIONS(2463),
    [anon_sym_template] = ACTIONS(2463),
    [anon_sym_operator] = ACTIONS(2463),
    [anon_sym_try] = ACTIONS(2463),
    [anon_sym_delete] = ACTIONS(2463),
    [anon_sym_throw] = ACTIONS(2463),
    [anon_sym_namespace] = ACTIONS(2463),
    [anon_sym_using] = ACTIONS(2463),
    [anon_sym_static_assert] = ACTIONS(2463),
    [anon_sym_concept] = ACTIONS(2463),
    [anon_sym_co_return] = ACTIONS(2463),
    [anon_sym_co_yield] = ACTIONS(2463),
    [anon_sym_R_DQUOTE] = ACTIONS(2465),
    [anon_sym_LR_DQUOTE] = ACTIONS(2465),
    [anon_sym_uR_DQUOTE] = ACTIONS(2465),
    [anon_sym_UR_DQUOTE] = ACTIONS(2465),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2465),
    [anon_sym_co_await] = ACTIONS(2463),
    [anon_sym_new] = ACTIONS(2463),
    [anon_sym_requires] = ACTIONS(2463),
    [sym_this] = ACTIONS(2463),
    [anon_sym___launch_bounds__] = ACTIONS(2463),
  },
  [STATE(277)] = {
    [sym_identifier] = ACTIONS(2467),
    [aux_sym_preproc_include_token1] = ACTIONS(2467),
    [aux_sym_preproc_def_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token2] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2467),
    [aux_sym_preproc_else_token1] = ACTIONS(2467),
    [aux_sym_preproc_elif_token1] = ACTIONS(2467),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2467),
    [sym_preproc_directive] = ACTIONS(2467),
    [anon_sym_LPAREN2] = ACTIONS(2469),
    [anon_sym_BANG] = ACTIONS(2469),
    [anon_sym_TILDE] = ACTIONS(2469),
    [anon_sym_DASH] = ACTIONS(2467),
    [anon_sym_PLUS] = ACTIONS(2467),
    [anon_sym_STAR] = ACTIONS(2469),
    [anon_sym_AMP_AMP] = ACTIONS(2469),
    [anon_sym_AMP] = ACTIONS(2467),
    [anon_sym_SEMI] = ACTIONS(2469),
    [anon_sym___extension__] = ACTIONS(2467),
    [anon_sym_typedef] = ACTIONS(2467),
    [anon_sym___device__] = ACTIONS(2467),
    [anon_sym___host__] = ACTIONS(2467),
    [anon_sym___global__] = ACTIONS(2467),
    [anon_sym___forceinline__] = ACTIONS(2467),
    [anon_sym___noinline__] = ACTIONS(2467),
    [anon_sym_virtual] = ACTIONS(2467),
    [anon_sym_extern] = ACTIONS(2467),
    [anon_sym___attribute__] = ACTIONS(2467),
    [anon_sym___attribute] = ACTIONS(2467),
    [anon_sym_COLON_COLON] = ACTIONS(2469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2469),
    [anon_sym___declspec] = ACTIONS(2467),
    [anon_sym___based] = ACTIONS(2467),
    [anon_sym___cdecl] = ACTIONS(2467),
    [anon_sym___clrcall] = ACTIONS(2467),
    [anon_sym___stdcall] = ACTIONS(2467),
    [anon_sym___fastcall] = ACTIONS(2467),
    [anon_sym___thiscall] = ACTIONS(2467),
    [anon_sym___vectorcall] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2469),
    [anon_sym_signed] = ACTIONS(2467),
    [anon_sym_unsigned] = ACTIONS(2467),
    [anon_sym_long] = ACTIONS(2467),
    [anon_sym_short] = ACTIONS(2467),
    [anon_sym_LBRACK] = ACTIONS(2467),
    [anon_sym_static] = ACTIONS(2467),
    [anon_sym_register] = ACTIONS(2467),
    [anon_sym_inline] = ACTIONS(2467),
    [anon_sym___inline] = ACTIONS(2467),
    [anon_sym___inline__] = ACTIONS(2467),
    [anon_sym___forceinline] = ACTIONS(2467),
    [anon_sym_thread_local] = ACTIONS(2467),
    [anon_sym___thread] = ACTIONS(2467),
    [anon_sym_const] = ACTIONS(2467),
    [anon_sym_constexpr] = ACTIONS(2467),
    [anon_sym_volatile] = ACTIONS(2467),
    [anon_sym_restrict] = ACTIONS(2467),
    [anon_sym___restrict__] = ACTIONS(2467),
    [anon_sym__Atomic] = ACTIONS(2467),
    [anon_sym__Noreturn] = ACTIONS(2467),
    [anon_sym_noreturn] = ACTIONS(2467),
    [anon_sym__Nonnull] = ACTIONS(2467),
    [anon_sym_mutable] = ACTIONS(2467),
    [anon_sym_constinit] = ACTIONS(2467),
    [anon_sym_consteval] = ACTIONS(2467),
    [anon_sym___shared__] = ACTIONS(2467),
    [anon_sym___local__] = ACTIONS(2467),
    [anon_sym___constant__] = ACTIONS(2467),
    [anon_sym___managed__] = ACTIONS(2467),
    [anon_sym___grid_constant__] = ACTIONS(2467),
    [anon_sym_alignas] = ACTIONS(2467),
    [anon_sym__Alignas] = ACTIONS(2467),
    [sym_primitive_type] = ACTIONS(2467),
    [anon_sym_enum] = ACTIONS(2467),
    [anon_sym_class] = ACTIONS(2467),
    [anon_sym_struct] = ACTIONS(2467),
    [anon_sym_union] = ACTIONS(2467),
    [anon_sym_if] = ACTIONS(2467),
    [anon_sym_switch] = ACTIONS(2467),
    [anon_sym_case] = ACTIONS(2467),
    [anon_sym_default] = ACTIONS(2467),
    [anon_sym_while] = ACTIONS(2467),
    [anon_sym_do] = ACTIONS(2467),
    [anon_sym_for] = ACTIONS(2467),
    [anon_sym_return] = ACTIONS(2467),
    [anon_sym_break] = ACTIONS(2467),
    [anon_sym_continue] = ACTIONS(2467),
    [anon_sym_goto] = ACTIONS(2467),
    [anon_sym___try] = ACTIONS(2467),
    [anon_sym___leave] = ACTIONS(2467),
    [anon_sym_not] = ACTIONS(2467),
    [anon_sym_compl] = ACTIONS(2467),
    [anon_sym_DASH_DASH] = ACTIONS(2469),
    [anon_sym_PLUS_PLUS] = ACTIONS(2469),
    [anon_sym_sizeof] = ACTIONS(2467),
    [anon_sym___alignof__] = ACTIONS(2467),
    [anon_sym___alignof] = ACTIONS(2467),
    [anon_sym__alignof] = ACTIONS(2467),
    [anon_sym_alignof] = ACTIONS(2467),
    [anon_sym__Alignof] = ACTIONS(2467),
    [anon_sym_offsetof] = ACTIONS(2467),
    [anon_sym__Generic] = ACTIONS(2467),
    [anon_sym_asm] = ACTIONS(2467),
    [anon_sym___asm__] = ACTIONS(2467),
    [anon_sym___asm] = ACTIONS(2467),
    [sym_number_literal] = ACTIONS(2469),
    [anon_sym_L_SQUOTE] = ACTIONS(2469),
    [anon_sym_u_SQUOTE] = ACTIONS(2469),
    [anon_sym_U_SQUOTE] = ACTIONS(2469),
    [anon_sym_u8_SQUOTE] = ACTIONS(2469),
    [anon_sym_SQUOTE] = ACTIONS(2469),
    [anon_sym_L_DQUOTE] = ACTIONS(2469),
    [anon_sym_u_DQUOTE] = ACTIONS(2469),
    [anon_sym_U_DQUOTE] = ACTIONS(2469),
    [anon_sym_u8_DQUOTE] = ACTIONS(2469),
    [anon_sym_DQUOTE] = ACTIONS(2469),
    [sym_true] = ACTIONS(2467),
    [sym_false] = ACTIONS(2467),
    [anon_sym_NULL] = ACTIONS(2467),
    [anon_sym_nullptr] = ACTIONS(2467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2467),
    [anon_sym_decltype] = ACTIONS(2467),
    [anon_sym_explicit] = ACTIONS(2467),
    [anon_sym_typename] = ACTIONS(2467),
    [anon_sym_template] = ACTIONS(2467),
    [anon_sym_operator] = ACTIONS(2467),
    [anon_sym_try] = ACTIONS(2467),
    [anon_sym_delete] = ACTIONS(2467),
    [anon_sym_throw] = ACTIONS(2467),
    [anon_sym_namespace] = ACTIONS(2467),
    [anon_sym_using] = ACTIONS(2467),
    [anon_sym_static_assert] = ACTIONS(2467),
    [anon_sym_concept] = ACTIONS(2467),
    [anon_sym_co_return] = ACTIONS(2467),
    [anon_sym_co_yield] = ACTIONS(2467),
    [anon_sym_R_DQUOTE] = ACTIONS(2469),
    [anon_sym_LR_DQUOTE] = ACTIONS(2469),
    [anon_sym_uR_DQUOTE] = ACTIONS(2469),
    [anon_sym_UR_DQUOTE] = ACTIONS(2469),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2469),
    [anon_sym_co_await] = ACTIONS(2467),
    [anon_sym_new] = ACTIONS(2467),
    [anon_sym_requires] = ACTIONS(2467),
    [sym_this] = ACTIONS(2467),
    [anon_sym___launch_bounds__] = ACTIONS(2467),
  },
  [STATE(278)] = {
    [sym_identifier] = ACTIONS(2471),
    [aux_sym_preproc_include_token1] = ACTIONS(2471),
    [aux_sym_preproc_def_token1] = ACTIONS(2471),
    [aux_sym_preproc_if_token1] = ACTIONS(2471),
    [aux_sym_preproc_if_token2] = ACTIONS(2471),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2471),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2471),
    [aux_sym_preproc_else_token1] = ACTIONS(2471),
    [aux_sym_preproc_elif_token1] = ACTIONS(2471),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2471),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2471),
    [sym_preproc_directive] = ACTIONS(2471),
    [anon_sym_LPAREN2] = ACTIONS(2473),
    [anon_sym_BANG] = ACTIONS(2473),
    [anon_sym_TILDE] = ACTIONS(2473),
    [anon_sym_DASH] = ACTIONS(2471),
    [anon_sym_PLUS] = ACTIONS(2471),
    [anon_sym_STAR] = ACTIONS(2473),
    [anon_sym_AMP_AMP] = ACTIONS(2473),
    [anon_sym_AMP] = ACTIONS(2471),
    [anon_sym_SEMI] = ACTIONS(2473),
    [anon_sym___extension__] = ACTIONS(2471),
    [anon_sym_typedef] = ACTIONS(2471),
    [anon_sym___device__] = ACTIONS(2471),
    [anon_sym___host__] = ACTIONS(2471),
    [anon_sym___global__] = ACTIONS(2471),
    [anon_sym___forceinline__] = ACTIONS(2471),
    [anon_sym___noinline__] = ACTIONS(2471),
    [anon_sym_virtual] = ACTIONS(2471),
    [anon_sym_extern] = ACTIONS(2471),
    [anon_sym___attribute__] = ACTIONS(2471),
    [anon_sym___attribute] = ACTIONS(2471),
    [anon_sym_COLON_COLON] = ACTIONS(2473),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2473),
    [anon_sym___declspec] = ACTIONS(2471),
    [anon_sym___based] = ACTIONS(2471),
    [anon_sym___cdecl] = ACTIONS(2471),
    [anon_sym___clrcall] = ACTIONS(2471),
    [anon_sym___stdcall] = ACTIONS(2471),
    [anon_sym___fastcall] = ACTIONS(2471),
    [anon_sym___thiscall] = ACTIONS(2471),
    [anon_sym___vectorcall] = ACTIONS(2471),
    [anon_sym_LBRACE] = ACTIONS(2473),
    [anon_sym_signed] = ACTIONS(2471),
    [anon_sym_unsigned] = ACTIONS(2471),
    [anon_sym_long] = ACTIONS(2471),
    [anon_sym_short] = ACTIONS(2471),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_static] = ACTIONS(2471),
    [anon_sym_register] = ACTIONS(2471),
    [anon_sym_inline] = ACTIONS(2471),
    [anon_sym___inline] = ACTIONS(2471),
    [anon_sym___inline__] = ACTIONS(2471),
    [anon_sym___forceinline] = ACTIONS(2471),
    [anon_sym_thread_local] = ACTIONS(2471),
    [anon_sym___thread] = ACTIONS(2471),
    [anon_sym_const] = ACTIONS(2471),
    [anon_sym_constexpr] = ACTIONS(2471),
    [anon_sym_volatile] = ACTIONS(2471),
    [anon_sym_restrict] = ACTIONS(2471),
    [anon_sym___restrict__] = ACTIONS(2471),
    [anon_sym__Atomic] = ACTIONS(2471),
    [anon_sym__Noreturn] = ACTIONS(2471),
    [anon_sym_noreturn] = ACTIONS(2471),
    [anon_sym__Nonnull] = ACTIONS(2471),
    [anon_sym_mutable] = ACTIONS(2471),
    [anon_sym_constinit] = ACTIONS(2471),
    [anon_sym_consteval] = ACTIONS(2471),
    [anon_sym___shared__] = ACTIONS(2471),
    [anon_sym___local__] = ACTIONS(2471),
    [anon_sym___constant__] = ACTIONS(2471),
    [anon_sym___managed__] = ACTIONS(2471),
    [anon_sym___grid_constant__] = ACTIONS(2471),
    [anon_sym_alignas] = ACTIONS(2471),
    [anon_sym__Alignas] = ACTIONS(2471),
    [sym_primitive_type] = ACTIONS(2471),
    [anon_sym_enum] = ACTIONS(2471),
    [anon_sym_class] = ACTIONS(2471),
    [anon_sym_struct] = ACTIONS(2471),
    [anon_sym_union] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2471),
    [anon_sym_switch] = ACTIONS(2471),
    [anon_sym_case] = ACTIONS(2471),
    [anon_sym_default] = ACTIONS(2471),
    [anon_sym_while] = ACTIONS(2471),
    [anon_sym_do] = ACTIONS(2471),
    [anon_sym_for] = ACTIONS(2471),
    [anon_sym_return] = ACTIONS(2471),
    [anon_sym_break] = ACTIONS(2471),
    [anon_sym_continue] = ACTIONS(2471),
    [anon_sym_goto] = ACTIONS(2471),
    [anon_sym___try] = ACTIONS(2471),
    [anon_sym___leave] = ACTIONS(2471),
    [anon_sym_not] = ACTIONS(2471),
    [anon_sym_compl] = ACTIONS(2471),
    [anon_sym_DASH_DASH] = ACTIONS(2473),
    [anon_sym_PLUS_PLUS] = ACTIONS(2473),
    [anon_sym_sizeof] = ACTIONS(2471),
    [anon_sym___alignof__] = ACTIONS(2471),
    [anon_sym___alignof] = ACTIONS(2471),
    [anon_sym__alignof] = ACTIONS(2471),
    [anon_sym_alignof] = ACTIONS(2471),
    [anon_sym__Alignof] = ACTIONS(2471),
    [anon_sym_offsetof] = ACTIONS(2471),
    [anon_sym__Generic] = ACTIONS(2471),
    [anon_sym_asm] = ACTIONS(2471),
    [anon_sym___asm__] = ACTIONS(2471),
    [anon_sym___asm] = ACTIONS(2471),
    [sym_number_literal] = ACTIONS(2473),
    [anon_sym_L_SQUOTE] = ACTIONS(2473),
    [anon_sym_u_SQUOTE] = ACTIONS(2473),
    [anon_sym_U_SQUOTE] = ACTIONS(2473),
    [anon_sym_u8_SQUOTE] = ACTIONS(2473),
    [anon_sym_SQUOTE] = ACTIONS(2473),
    [anon_sym_L_DQUOTE] = ACTIONS(2473),
    [anon_sym_u_DQUOTE] = ACTIONS(2473),
    [anon_sym_U_DQUOTE] = ACTIONS(2473),
    [anon_sym_u8_DQUOTE] = ACTIONS(2473),
    [anon_sym_DQUOTE] = ACTIONS(2473),
    [sym_true] = ACTIONS(2471),
    [sym_false] = ACTIONS(2471),
    [anon_sym_NULL] = ACTIONS(2471),
    [anon_sym_nullptr] = ACTIONS(2471),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2471),
    [anon_sym_decltype] = ACTIONS(2471),
    [anon_sym_explicit] = ACTIONS(2471),
    [anon_sym_typename] = ACTIONS(2471),
    [anon_sym_template] = ACTIONS(2471),
    [anon_sym_operator] = ACTIONS(2471),
    [anon_sym_try] = ACTIONS(2471),
    [anon_sym_delete] = ACTIONS(2471),
    [anon_sym_throw] = ACTIONS(2471),
    [anon_sym_namespace] = ACTIONS(2471),
    [anon_sym_using] = ACTIONS(2471),
    [anon_sym_static_assert] = ACTIONS(2471),
    [anon_sym_concept] = ACTIONS(2471),
    [anon_sym_co_return] = ACTIONS(2471),
    [anon_sym_co_yield] = ACTIONS(2471),
    [anon_sym_R_DQUOTE] = ACTIONS(2473),
    [anon_sym_LR_DQUOTE] = ACTIONS(2473),
    [anon_sym_uR_DQUOTE] = ACTIONS(2473),
    [anon_sym_UR_DQUOTE] = ACTIONS(2473),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2473),
    [anon_sym_co_await] = ACTIONS(2471),
    [anon_sym_new] = ACTIONS(2471),
    [anon_sym_requires] = ACTIONS(2471),
    [sym_this] = ACTIONS(2471),
    [anon_sym___launch_bounds__] = ACTIONS(2471),
  },
  [STATE(279)] = {
    [sym_identifier] = ACTIONS(2475),
    [aux_sym_preproc_include_token1] = ACTIONS(2475),
    [aux_sym_preproc_def_token1] = ACTIONS(2475),
    [aux_sym_preproc_if_token1] = ACTIONS(2475),
    [aux_sym_preproc_if_token2] = ACTIONS(2475),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2475),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2475),
    [aux_sym_preproc_else_token1] = ACTIONS(2475),
    [aux_sym_preproc_elif_token1] = ACTIONS(2475),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2475),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2475),
    [sym_preproc_directive] = ACTIONS(2475),
    [anon_sym_LPAREN2] = ACTIONS(2477),
    [anon_sym_BANG] = ACTIONS(2477),
    [anon_sym_TILDE] = ACTIONS(2477),
    [anon_sym_DASH] = ACTIONS(2475),
    [anon_sym_PLUS] = ACTIONS(2475),
    [anon_sym_STAR] = ACTIONS(2477),
    [anon_sym_AMP_AMP] = ACTIONS(2477),
    [anon_sym_AMP] = ACTIONS(2475),
    [anon_sym_SEMI] = ACTIONS(2477),
    [anon_sym___extension__] = ACTIONS(2475),
    [anon_sym_typedef] = ACTIONS(2475),
    [anon_sym___device__] = ACTIONS(2475),
    [anon_sym___host__] = ACTIONS(2475),
    [anon_sym___global__] = ACTIONS(2475),
    [anon_sym___forceinline__] = ACTIONS(2475),
    [anon_sym___noinline__] = ACTIONS(2475),
    [anon_sym_virtual] = ACTIONS(2475),
    [anon_sym_extern] = ACTIONS(2475),
    [anon_sym___attribute__] = ACTIONS(2475),
    [anon_sym___attribute] = ACTIONS(2475),
    [anon_sym_COLON_COLON] = ACTIONS(2477),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2477),
    [anon_sym___declspec] = ACTIONS(2475),
    [anon_sym___based] = ACTIONS(2475),
    [anon_sym___cdecl] = ACTIONS(2475),
    [anon_sym___clrcall] = ACTIONS(2475),
    [anon_sym___stdcall] = ACTIONS(2475),
    [anon_sym___fastcall] = ACTIONS(2475),
    [anon_sym___thiscall] = ACTIONS(2475),
    [anon_sym___vectorcall] = ACTIONS(2475),
    [anon_sym_LBRACE] = ACTIONS(2477),
    [anon_sym_signed] = ACTIONS(2475),
    [anon_sym_unsigned] = ACTIONS(2475),
    [anon_sym_long] = ACTIONS(2475),
    [anon_sym_short] = ACTIONS(2475),
    [anon_sym_LBRACK] = ACTIONS(2475),
    [anon_sym_static] = ACTIONS(2475),
    [anon_sym_register] = ACTIONS(2475),
    [anon_sym_inline] = ACTIONS(2475),
    [anon_sym___inline] = ACTIONS(2475),
    [anon_sym___inline__] = ACTIONS(2475),
    [anon_sym___forceinline] = ACTIONS(2475),
    [anon_sym_thread_local] = ACTIONS(2475),
    [anon_sym___thread] = ACTIONS(2475),
    [anon_sym_const] = ACTIONS(2475),
    [anon_sym_constexpr] = ACTIONS(2475),
    [anon_sym_volatile] = ACTIONS(2475),
    [anon_sym_restrict] = ACTIONS(2475),
    [anon_sym___restrict__] = ACTIONS(2475),
    [anon_sym__Atomic] = ACTIONS(2475),
    [anon_sym__Noreturn] = ACTIONS(2475),
    [anon_sym_noreturn] = ACTIONS(2475),
    [anon_sym__Nonnull] = ACTIONS(2475),
    [anon_sym_mutable] = ACTIONS(2475),
    [anon_sym_constinit] = ACTIONS(2475),
    [anon_sym_consteval] = ACTIONS(2475),
    [anon_sym___shared__] = ACTIONS(2475),
    [anon_sym___local__] = ACTIONS(2475),
    [anon_sym___constant__] = ACTIONS(2475),
    [anon_sym___managed__] = ACTIONS(2475),
    [anon_sym___grid_constant__] = ACTIONS(2475),
    [anon_sym_alignas] = ACTIONS(2475),
    [anon_sym__Alignas] = ACTIONS(2475),
    [sym_primitive_type] = ACTIONS(2475),
    [anon_sym_enum] = ACTIONS(2475),
    [anon_sym_class] = ACTIONS(2475),
    [anon_sym_struct] = ACTIONS(2475),
    [anon_sym_union] = ACTIONS(2475),
    [anon_sym_if] = ACTIONS(2475),
    [anon_sym_switch] = ACTIONS(2475),
    [anon_sym_case] = ACTIONS(2475),
    [anon_sym_default] = ACTIONS(2475),
    [anon_sym_while] = ACTIONS(2475),
    [anon_sym_do] = ACTIONS(2475),
    [anon_sym_for] = ACTIONS(2475),
    [anon_sym_return] = ACTIONS(2475),
    [anon_sym_break] = ACTIONS(2475),
    [anon_sym_continue] = ACTIONS(2475),
    [anon_sym_goto] = ACTIONS(2475),
    [anon_sym___try] = ACTIONS(2475),
    [anon_sym___leave] = ACTIONS(2475),
    [anon_sym_not] = ACTIONS(2475),
    [anon_sym_compl] = ACTIONS(2475),
    [anon_sym_DASH_DASH] = ACTIONS(2477),
    [anon_sym_PLUS_PLUS] = ACTIONS(2477),
    [anon_sym_sizeof] = ACTIONS(2475),
    [anon_sym___alignof__] = ACTIONS(2475),
    [anon_sym___alignof] = ACTIONS(2475),
    [anon_sym__alignof] = ACTIONS(2475),
    [anon_sym_alignof] = ACTIONS(2475),
    [anon_sym__Alignof] = ACTIONS(2475),
    [anon_sym_offsetof] = ACTIONS(2475),
    [anon_sym__Generic] = ACTIONS(2475),
    [anon_sym_asm] = ACTIONS(2475),
    [anon_sym___asm__] = ACTIONS(2475),
    [anon_sym___asm] = ACTIONS(2475),
    [sym_number_literal] = ACTIONS(2477),
    [anon_sym_L_SQUOTE] = ACTIONS(2477),
    [anon_sym_u_SQUOTE] = ACTIONS(2477),
    [anon_sym_U_SQUOTE] = ACTIONS(2477),
    [anon_sym_u8_SQUOTE] = ACTIONS(2477),
    [anon_sym_SQUOTE] = ACTIONS(2477),
    [anon_sym_L_DQUOTE] = ACTIONS(2477),
    [anon_sym_u_DQUOTE] = ACTIONS(2477),
    [anon_sym_U_DQUOTE] = ACTIONS(2477),
    [anon_sym_u8_DQUOTE] = ACTIONS(2477),
    [anon_sym_DQUOTE] = ACTIONS(2477),
    [sym_true] = ACTIONS(2475),
    [sym_false] = ACTIONS(2475),
    [anon_sym_NULL] = ACTIONS(2475),
    [anon_sym_nullptr] = ACTIONS(2475),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2475),
    [anon_sym_decltype] = ACTIONS(2475),
    [anon_sym_explicit] = ACTIONS(2475),
    [anon_sym_typename] = ACTIONS(2475),
    [anon_sym_template] = ACTIONS(2475),
    [anon_sym_operator] = ACTIONS(2475),
    [anon_sym_try] = ACTIONS(2475),
    [anon_sym_delete] = ACTIONS(2475),
    [anon_sym_throw] = ACTIONS(2475),
    [anon_sym_namespace] = ACTIONS(2475),
    [anon_sym_using] = ACTIONS(2475),
    [anon_sym_static_assert] = ACTIONS(2475),
    [anon_sym_concept] = ACTIONS(2475),
    [anon_sym_co_return] = ACTIONS(2475),
    [anon_sym_co_yield] = ACTIONS(2475),
    [anon_sym_R_DQUOTE] = ACTIONS(2477),
    [anon_sym_LR_DQUOTE] = ACTIONS(2477),
    [anon_sym_uR_DQUOTE] = ACTIONS(2477),
    [anon_sym_UR_DQUOTE] = ACTIONS(2477),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2477),
    [anon_sym_co_await] = ACTIONS(2475),
    [anon_sym_new] = ACTIONS(2475),
    [anon_sym_requires] = ACTIONS(2475),
    [sym_this] = ACTIONS(2475),
    [anon_sym___launch_bounds__] = ACTIONS(2475),
  },
  [STATE(280)] = {
    [sym_catch_clause] = STATE(280),
    [aux_sym_constructor_try_statement_repeat1] = STATE(280),
    [sym_identifier] = ACTIONS(1940),
    [aux_sym_preproc_include_token1] = ACTIONS(1940),
    [aux_sym_preproc_def_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1940),
    [sym_preproc_directive] = ACTIONS(1940),
    [anon_sym_LPAREN2] = ACTIONS(1942),
    [anon_sym_BANG] = ACTIONS(1942),
    [anon_sym_TILDE] = ACTIONS(1942),
    [anon_sym_DASH] = ACTIONS(1940),
    [anon_sym_PLUS] = ACTIONS(1940),
    [anon_sym_STAR] = ACTIONS(1942),
    [anon_sym_AMP_AMP] = ACTIONS(1942),
    [anon_sym_AMP] = ACTIONS(1940),
    [anon_sym_SEMI] = ACTIONS(1942),
    [anon_sym___extension__] = ACTIONS(1940),
    [anon_sym_typedef] = ACTIONS(1940),
    [anon_sym___device__] = ACTIONS(1940),
    [anon_sym___host__] = ACTIONS(1940),
    [anon_sym___global__] = ACTIONS(1940),
    [anon_sym___forceinline__] = ACTIONS(1940),
    [anon_sym___noinline__] = ACTIONS(1940),
    [anon_sym_virtual] = ACTIONS(1940),
    [anon_sym_extern] = ACTIONS(1940),
    [anon_sym___attribute__] = ACTIONS(1940),
    [anon_sym___attribute] = ACTIONS(1940),
    [anon_sym_COLON_COLON] = ACTIONS(1942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1942),
    [anon_sym___declspec] = ACTIONS(1940),
    [anon_sym___based] = ACTIONS(1940),
    [anon_sym___cdecl] = ACTIONS(1940),
    [anon_sym___clrcall] = ACTIONS(1940),
    [anon_sym___stdcall] = ACTIONS(1940),
    [anon_sym___fastcall] = ACTIONS(1940),
    [anon_sym___thiscall] = ACTIONS(1940),
    [anon_sym___vectorcall] = ACTIONS(1940),
    [anon_sym_LBRACE] = ACTIONS(1942),
    [anon_sym_RBRACE] = ACTIONS(1942),
    [anon_sym_signed] = ACTIONS(1940),
    [anon_sym_unsigned] = ACTIONS(1940),
    [anon_sym_long] = ACTIONS(1940),
    [anon_sym_short] = ACTIONS(1940),
    [anon_sym_LBRACK] = ACTIONS(1940),
    [anon_sym_static] = ACTIONS(1940),
    [anon_sym_register] = ACTIONS(1940),
    [anon_sym_inline] = ACTIONS(1940),
    [anon_sym___inline] = ACTIONS(1940),
    [anon_sym___inline__] = ACTIONS(1940),
    [anon_sym___forceinline] = ACTIONS(1940),
    [anon_sym_thread_local] = ACTIONS(1940),
    [anon_sym___thread] = ACTIONS(1940),
    [anon_sym_const] = ACTIONS(1940),
    [anon_sym_constexpr] = ACTIONS(1940),
    [anon_sym_volatile] = ACTIONS(1940),
    [anon_sym_restrict] = ACTIONS(1940),
    [anon_sym___restrict__] = ACTIONS(1940),
    [anon_sym__Atomic] = ACTIONS(1940),
    [anon_sym__Noreturn] = ACTIONS(1940),
    [anon_sym_noreturn] = ACTIONS(1940),
    [anon_sym__Nonnull] = ACTIONS(1940),
    [anon_sym_mutable] = ACTIONS(1940),
    [anon_sym_constinit] = ACTIONS(1940),
    [anon_sym_consteval] = ACTIONS(1940),
    [anon_sym___shared__] = ACTIONS(1940),
    [anon_sym___local__] = ACTIONS(1940),
    [anon_sym___constant__] = ACTIONS(1940),
    [anon_sym___managed__] = ACTIONS(1940),
    [anon_sym___grid_constant__] = ACTIONS(1940),
    [anon_sym_alignas] = ACTIONS(1940),
    [anon_sym__Alignas] = ACTIONS(1940),
    [sym_primitive_type] = ACTIONS(1940),
    [anon_sym_enum] = ACTIONS(1940),
    [anon_sym_class] = ACTIONS(1940),
    [anon_sym_struct] = ACTIONS(1940),
    [anon_sym_union] = ACTIONS(1940),
    [anon_sym_if] = ACTIONS(1940),
    [anon_sym_else] = ACTIONS(1940),
    [anon_sym_switch] = ACTIONS(1940),
    [anon_sym_case] = ACTIONS(1940),
    [anon_sym_default] = ACTIONS(1940),
    [anon_sym_while] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_for] = ACTIONS(1940),
    [anon_sym_return] = ACTIONS(1940),
    [anon_sym_break] = ACTIONS(1940),
    [anon_sym_continue] = ACTIONS(1940),
    [anon_sym_goto] = ACTIONS(1940),
    [anon_sym___try] = ACTIONS(1940),
    [anon_sym___leave] = ACTIONS(1940),
    [anon_sym_not] = ACTIONS(1940),
    [anon_sym_compl] = ACTIONS(1940),
    [anon_sym_DASH_DASH] = ACTIONS(1942),
    [anon_sym_PLUS_PLUS] = ACTIONS(1942),
    [anon_sym_sizeof] = ACTIONS(1940),
    [anon_sym___alignof__] = ACTIONS(1940),
    [anon_sym___alignof] = ACTIONS(1940),
    [anon_sym__alignof] = ACTIONS(1940),
    [anon_sym_alignof] = ACTIONS(1940),
    [anon_sym__Alignof] = ACTIONS(1940),
    [anon_sym_offsetof] = ACTIONS(1940),
    [anon_sym__Generic] = ACTIONS(1940),
    [anon_sym_asm] = ACTIONS(1940),
    [anon_sym___asm__] = ACTIONS(1940),
    [anon_sym___asm] = ACTIONS(1940),
    [sym_number_literal] = ACTIONS(1942),
    [anon_sym_L_SQUOTE] = ACTIONS(1942),
    [anon_sym_u_SQUOTE] = ACTIONS(1942),
    [anon_sym_U_SQUOTE] = ACTIONS(1942),
    [anon_sym_u8_SQUOTE] = ACTIONS(1942),
    [anon_sym_SQUOTE] = ACTIONS(1942),
    [anon_sym_L_DQUOTE] = ACTIONS(1942),
    [anon_sym_u_DQUOTE] = ACTIONS(1942),
    [anon_sym_U_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8_DQUOTE] = ACTIONS(1942),
    [anon_sym_DQUOTE] = ACTIONS(1942),
    [sym_true] = ACTIONS(1940),
    [sym_false] = ACTIONS(1940),
    [anon_sym_NULL] = ACTIONS(1940),
    [anon_sym_nullptr] = ACTIONS(1940),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1940),
    [anon_sym_decltype] = ACTIONS(1940),
    [anon_sym_explicit] = ACTIONS(1940),
    [anon_sym_typename] = ACTIONS(1940),
    [anon_sym_template] = ACTIONS(1940),
    [anon_sym_operator] = ACTIONS(1940),
    [anon_sym_try] = ACTIONS(1940),
    [anon_sym_delete] = ACTIONS(1940),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_namespace] = ACTIONS(1940),
    [anon_sym_using] = ACTIONS(1940),
    [anon_sym_static_assert] = ACTIONS(1940),
    [anon_sym_concept] = ACTIONS(1940),
    [anon_sym_co_return] = ACTIONS(1940),
    [anon_sym_co_yield] = ACTIONS(1940),
    [anon_sym_catch] = ACTIONS(2479),
    [anon_sym_R_DQUOTE] = ACTIONS(1942),
    [anon_sym_LR_DQUOTE] = ACTIONS(1942),
    [anon_sym_uR_DQUOTE] = ACTIONS(1942),
    [anon_sym_UR_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1942),
    [anon_sym_co_await] = ACTIONS(1940),
    [anon_sym_new] = ACTIONS(1940),
    [anon_sym_requires] = ACTIONS(1940),
    [sym_this] = ACTIONS(1940),
    [anon_sym___launch_bounds__] = ACTIONS(1940),
  },
  [STATE(281)] = {
    [sym_catch_clause] = STATE(281),
    [aux_sym_constructor_try_statement_repeat1] = STATE(281),
    [sym_identifier] = ACTIONS(1940),
    [aux_sym_preproc_include_token1] = ACTIONS(1940),
    [aux_sym_preproc_def_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token2] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1940),
    [sym_preproc_directive] = ACTIONS(1940),
    [anon_sym_LPAREN2] = ACTIONS(1942),
    [anon_sym_BANG] = ACTIONS(1942),
    [anon_sym_TILDE] = ACTIONS(1942),
    [anon_sym_DASH] = ACTIONS(1940),
    [anon_sym_PLUS] = ACTIONS(1940),
    [anon_sym_STAR] = ACTIONS(1942),
    [anon_sym_AMP_AMP] = ACTIONS(1942),
    [anon_sym_AMP] = ACTIONS(1940),
    [anon_sym_SEMI] = ACTIONS(1942),
    [anon_sym___extension__] = ACTIONS(1940),
    [anon_sym_typedef] = ACTIONS(1940),
    [anon_sym___device__] = ACTIONS(1940),
    [anon_sym___host__] = ACTIONS(1940),
    [anon_sym___global__] = ACTIONS(1940),
    [anon_sym___forceinline__] = ACTIONS(1940),
    [anon_sym___noinline__] = ACTIONS(1940),
    [anon_sym_virtual] = ACTIONS(1940),
    [anon_sym_extern] = ACTIONS(1940),
    [anon_sym___attribute__] = ACTIONS(1940),
    [anon_sym___attribute] = ACTIONS(1940),
    [anon_sym_COLON_COLON] = ACTIONS(1942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1942),
    [anon_sym___declspec] = ACTIONS(1940),
    [anon_sym___based] = ACTIONS(1940),
    [anon_sym___cdecl] = ACTIONS(1940),
    [anon_sym___clrcall] = ACTIONS(1940),
    [anon_sym___stdcall] = ACTIONS(1940),
    [anon_sym___fastcall] = ACTIONS(1940),
    [anon_sym___thiscall] = ACTIONS(1940),
    [anon_sym___vectorcall] = ACTIONS(1940),
    [anon_sym_LBRACE] = ACTIONS(1942),
    [anon_sym_signed] = ACTIONS(1940),
    [anon_sym_unsigned] = ACTIONS(1940),
    [anon_sym_long] = ACTIONS(1940),
    [anon_sym_short] = ACTIONS(1940),
    [anon_sym_LBRACK] = ACTIONS(1940),
    [anon_sym_static] = ACTIONS(1940),
    [anon_sym_register] = ACTIONS(1940),
    [anon_sym_inline] = ACTIONS(1940),
    [anon_sym___inline] = ACTIONS(1940),
    [anon_sym___inline__] = ACTIONS(1940),
    [anon_sym___forceinline] = ACTIONS(1940),
    [anon_sym_thread_local] = ACTIONS(1940),
    [anon_sym___thread] = ACTIONS(1940),
    [anon_sym_const] = ACTIONS(1940),
    [anon_sym_constexpr] = ACTIONS(1940),
    [anon_sym_volatile] = ACTIONS(1940),
    [anon_sym_restrict] = ACTIONS(1940),
    [anon_sym___restrict__] = ACTIONS(1940),
    [anon_sym__Atomic] = ACTIONS(1940),
    [anon_sym__Noreturn] = ACTIONS(1940),
    [anon_sym_noreturn] = ACTIONS(1940),
    [anon_sym__Nonnull] = ACTIONS(1940),
    [anon_sym_mutable] = ACTIONS(1940),
    [anon_sym_constinit] = ACTIONS(1940),
    [anon_sym_consteval] = ACTIONS(1940),
    [anon_sym___shared__] = ACTIONS(1940),
    [anon_sym___local__] = ACTIONS(1940),
    [anon_sym___constant__] = ACTIONS(1940),
    [anon_sym___managed__] = ACTIONS(1940),
    [anon_sym___grid_constant__] = ACTIONS(1940),
    [anon_sym_alignas] = ACTIONS(1940),
    [anon_sym__Alignas] = ACTIONS(1940),
    [sym_primitive_type] = ACTIONS(1940),
    [anon_sym_enum] = ACTIONS(1940),
    [anon_sym_class] = ACTIONS(1940),
    [anon_sym_struct] = ACTIONS(1940),
    [anon_sym_union] = ACTIONS(1940),
    [anon_sym_if] = ACTIONS(1940),
    [anon_sym_else] = ACTIONS(1940),
    [anon_sym_switch] = ACTIONS(1940),
    [anon_sym_case] = ACTIONS(1940),
    [anon_sym_default] = ACTIONS(1940),
    [anon_sym_while] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_for] = ACTIONS(1940),
    [anon_sym_return] = ACTIONS(1940),
    [anon_sym_break] = ACTIONS(1940),
    [anon_sym_continue] = ACTIONS(1940),
    [anon_sym_goto] = ACTIONS(1940),
    [anon_sym___try] = ACTIONS(1940),
    [anon_sym___leave] = ACTIONS(1940),
    [anon_sym_not] = ACTIONS(1940),
    [anon_sym_compl] = ACTIONS(1940),
    [anon_sym_DASH_DASH] = ACTIONS(1942),
    [anon_sym_PLUS_PLUS] = ACTIONS(1942),
    [anon_sym_sizeof] = ACTIONS(1940),
    [anon_sym___alignof__] = ACTIONS(1940),
    [anon_sym___alignof] = ACTIONS(1940),
    [anon_sym__alignof] = ACTIONS(1940),
    [anon_sym_alignof] = ACTIONS(1940),
    [anon_sym__Alignof] = ACTIONS(1940),
    [anon_sym_offsetof] = ACTIONS(1940),
    [anon_sym__Generic] = ACTIONS(1940),
    [anon_sym_asm] = ACTIONS(1940),
    [anon_sym___asm__] = ACTIONS(1940),
    [anon_sym___asm] = ACTIONS(1940),
    [sym_number_literal] = ACTIONS(1942),
    [anon_sym_L_SQUOTE] = ACTIONS(1942),
    [anon_sym_u_SQUOTE] = ACTIONS(1942),
    [anon_sym_U_SQUOTE] = ACTIONS(1942),
    [anon_sym_u8_SQUOTE] = ACTIONS(1942),
    [anon_sym_SQUOTE] = ACTIONS(1942),
    [anon_sym_L_DQUOTE] = ACTIONS(1942),
    [anon_sym_u_DQUOTE] = ACTIONS(1942),
    [anon_sym_U_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8_DQUOTE] = ACTIONS(1942),
    [anon_sym_DQUOTE] = ACTIONS(1942),
    [sym_true] = ACTIONS(1940),
    [sym_false] = ACTIONS(1940),
    [anon_sym_NULL] = ACTIONS(1940),
    [anon_sym_nullptr] = ACTIONS(1940),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1940),
    [anon_sym_decltype] = ACTIONS(1940),
    [anon_sym_explicit] = ACTIONS(1940),
    [anon_sym_typename] = ACTIONS(1940),
    [anon_sym_template] = ACTIONS(1940),
    [anon_sym_operator] = ACTIONS(1940),
    [anon_sym_try] = ACTIONS(1940),
    [anon_sym_delete] = ACTIONS(1940),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_namespace] = ACTIONS(1940),
    [anon_sym_using] = ACTIONS(1940),
    [anon_sym_static_assert] = ACTIONS(1940),
    [anon_sym_concept] = ACTIONS(1940),
    [anon_sym_co_return] = ACTIONS(1940),
    [anon_sym_co_yield] = ACTIONS(1940),
    [anon_sym_catch] = ACTIONS(2482),
    [anon_sym_R_DQUOTE] = ACTIONS(1942),
    [anon_sym_LR_DQUOTE] = ACTIONS(1942),
    [anon_sym_uR_DQUOTE] = ACTIONS(1942),
    [anon_sym_UR_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1942),
    [anon_sym_co_await] = ACTIONS(1940),
    [anon_sym_new] = ACTIONS(1940),
    [anon_sym_requires] = ACTIONS(1940),
    [sym_this] = ACTIONS(1940),
    [anon_sym___launch_bounds__] = ACTIONS(1940),
  },
  [STATE(282)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(1967),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(283)] = {
    [sym_identifier] = ACTIONS(2485),
    [aux_sym_preproc_include_token1] = ACTIONS(2485),
    [aux_sym_preproc_def_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token2] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2485),
    [aux_sym_preproc_else_token1] = ACTIONS(2485),
    [aux_sym_preproc_elif_token1] = ACTIONS(2485),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2485),
    [sym_preproc_directive] = ACTIONS(2485),
    [anon_sym_LPAREN2] = ACTIONS(2487),
    [anon_sym_BANG] = ACTIONS(2487),
    [anon_sym_TILDE] = ACTIONS(2487),
    [anon_sym_DASH] = ACTIONS(2485),
    [anon_sym_PLUS] = ACTIONS(2485),
    [anon_sym_STAR] = ACTIONS(2487),
    [anon_sym_AMP_AMP] = ACTIONS(2487),
    [anon_sym_AMP] = ACTIONS(2485),
    [anon_sym_SEMI] = ACTIONS(2487),
    [anon_sym___extension__] = ACTIONS(2485),
    [anon_sym_typedef] = ACTIONS(2485),
    [anon_sym___device__] = ACTIONS(2485),
    [anon_sym___host__] = ACTIONS(2485),
    [anon_sym___global__] = ACTIONS(2485),
    [anon_sym___forceinline__] = ACTIONS(2485),
    [anon_sym___noinline__] = ACTIONS(2485),
    [anon_sym_virtual] = ACTIONS(2485),
    [anon_sym_extern] = ACTIONS(2485),
    [anon_sym___attribute__] = ACTIONS(2485),
    [anon_sym___attribute] = ACTIONS(2485),
    [anon_sym_COLON_COLON] = ACTIONS(2487),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2487),
    [anon_sym___declspec] = ACTIONS(2485),
    [anon_sym___based] = ACTIONS(2485),
    [anon_sym___cdecl] = ACTIONS(2485),
    [anon_sym___clrcall] = ACTIONS(2485),
    [anon_sym___stdcall] = ACTIONS(2485),
    [anon_sym___fastcall] = ACTIONS(2485),
    [anon_sym___thiscall] = ACTIONS(2485),
    [anon_sym___vectorcall] = ACTIONS(2485),
    [anon_sym_LBRACE] = ACTIONS(2487),
    [anon_sym_signed] = ACTIONS(2485),
    [anon_sym_unsigned] = ACTIONS(2485),
    [anon_sym_long] = ACTIONS(2485),
    [anon_sym_short] = ACTIONS(2485),
    [anon_sym_LBRACK] = ACTIONS(2485),
    [anon_sym_static] = ACTIONS(2485),
    [anon_sym_register] = ACTIONS(2485),
    [anon_sym_inline] = ACTIONS(2485),
    [anon_sym___inline] = ACTIONS(2485),
    [anon_sym___inline__] = ACTIONS(2485),
    [anon_sym___forceinline] = ACTIONS(2485),
    [anon_sym_thread_local] = ACTIONS(2485),
    [anon_sym___thread] = ACTIONS(2485),
    [anon_sym_const] = ACTIONS(2485),
    [anon_sym_constexpr] = ACTIONS(2485),
    [anon_sym_volatile] = ACTIONS(2485),
    [anon_sym_restrict] = ACTIONS(2485),
    [anon_sym___restrict__] = ACTIONS(2485),
    [anon_sym__Atomic] = ACTIONS(2485),
    [anon_sym__Noreturn] = ACTIONS(2485),
    [anon_sym_noreturn] = ACTIONS(2485),
    [anon_sym__Nonnull] = ACTIONS(2485),
    [anon_sym_mutable] = ACTIONS(2485),
    [anon_sym_constinit] = ACTIONS(2485),
    [anon_sym_consteval] = ACTIONS(2485),
    [anon_sym___shared__] = ACTIONS(2485),
    [anon_sym___local__] = ACTIONS(2485),
    [anon_sym___constant__] = ACTIONS(2485),
    [anon_sym___managed__] = ACTIONS(2485),
    [anon_sym___grid_constant__] = ACTIONS(2485),
    [anon_sym_alignas] = ACTIONS(2485),
    [anon_sym__Alignas] = ACTIONS(2485),
    [sym_primitive_type] = ACTIONS(2485),
    [anon_sym_enum] = ACTIONS(2485),
    [anon_sym_class] = ACTIONS(2485),
    [anon_sym_struct] = ACTIONS(2485),
    [anon_sym_union] = ACTIONS(2485),
    [anon_sym_if] = ACTIONS(2485),
    [anon_sym_switch] = ACTIONS(2485),
    [anon_sym_case] = ACTIONS(2485),
    [anon_sym_default] = ACTIONS(2485),
    [anon_sym_while] = ACTIONS(2485),
    [anon_sym_do] = ACTIONS(2485),
    [anon_sym_for] = ACTIONS(2485),
    [anon_sym_return] = ACTIONS(2485),
    [anon_sym_break] = ACTIONS(2485),
    [anon_sym_continue] = ACTIONS(2485),
    [anon_sym_goto] = ACTIONS(2485),
    [anon_sym___try] = ACTIONS(2485),
    [anon_sym___leave] = ACTIONS(2485),
    [anon_sym_not] = ACTIONS(2485),
    [anon_sym_compl] = ACTIONS(2485),
    [anon_sym_DASH_DASH] = ACTIONS(2487),
    [anon_sym_PLUS_PLUS] = ACTIONS(2487),
    [anon_sym_sizeof] = ACTIONS(2485),
    [anon_sym___alignof__] = ACTIONS(2485),
    [anon_sym___alignof] = ACTIONS(2485),
    [anon_sym__alignof] = ACTIONS(2485),
    [anon_sym_alignof] = ACTIONS(2485),
    [anon_sym__Alignof] = ACTIONS(2485),
    [anon_sym_offsetof] = ACTIONS(2485),
    [anon_sym__Generic] = ACTIONS(2485),
    [anon_sym_asm] = ACTIONS(2485),
    [anon_sym___asm__] = ACTIONS(2485),
    [anon_sym___asm] = ACTIONS(2485),
    [sym_number_literal] = ACTIONS(2487),
    [anon_sym_L_SQUOTE] = ACTIONS(2487),
    [anon_sym_u_SQUOTE] = ACTIONS(2487),
    [anon_sym_U_SQUOTE] = ACTIONS(2487),
    [anon_sym_u8_SQUOTE] = ACTIONS(2487),
    [anon_sym_SQUOTE] = ACTIONS(2487),
    [anon_sym_L_DQUOTE] = ACTIONS(2487),
    [anon_sym_u_DQUOTE] = ACTIONS(2487),
    [anon_sym_U_DQUOTE] = ACTIONS(2487),
    [anon_sym_u8_DQUOTE] = ACTIONS(2487),
    [anon_sym_DQUOTE] = ACTIONS(2487),
    [sym_true] = ACTIONS(2485),
    [sym_false] = ACTIONS(2485),
    [anon_sym_NULL] = ACTIONS(2485),
    [anon_sym_nullptr] = ACTIONS(2485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2485),
    [anon_sym_decltype] = ACTIONS(2485),
    [anon_sym_explicit] = ACTIONS(2485),
    [anon_sym_typename] = ACTIONS(2485),
    [anon_sym_template] = ACTIONS(2485),
    [anon_sym_operator] = ACTIONS(2485),
    [anon_sym_try] = ACTIONS(2485),
    [anon_sym_delete] = ACTIONS(2485),
    [anon_sym_throw] = ACTIONS(2485),
    [anon_sym_namespace] = ACTIONS(2485),
    [anon_sym_using] = ACTIONS(2485),
    [anon_sym_static_assert] = ACTIONS(2485),
    [anon_sym_concept] = ACTIONS(2485),
    [anon_sym_co_return] = ACTIONS(2485),
    [anon_sym_co_yield] = ACTIONS(2485),
    [anon_sym_R_DQUOTE] = ACTIONS(2487),
    [anon_sym_LR_DQUOTE] = ACTIONS(2487),
    [anon_sym_uR_DQUOTE] = ACTIONS(2487),
    [anon_sym_UR_DQUOTE] = ACTIONS(2487),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2487),
    [anon_sym_co_await] = ACTIONS(2485),
    [anon_sym_new] = ACTIONS(2485),
    [anon_sym_requires] = ACTIONS(2485),
    [sym_this] = ACTIONS(2485),
    [anon_sym___launch_bounds__] = ACTIONS(2485),
  },
  [STATE(284)] = {
    [sym_identifier] = ACTIONS(2489),
    [aux_sym_preproc_include_token1] = ACTIONS(2489),
    [aux_sym_preproc_def_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token2] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2489),
    [aux_sym_preproc_else_token1] = ACTIONS(2489),
    [aux_sym_preproc_elif_token1] = ACTIONS(2489),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2489),
    [sym_preproc_directive] = ACTIONS(2489),
    [anon_sym_LPAREN2] = ACTIONS(2491),
    [anon_sym_BANG] = ACTIONS(2491),
    [anon_sym_TILDE] = ACTIONS(2491),
    [anon_sym_DASH] = ACTIONS(2489),
    [anon_sym_PLUS] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(2491),
    [anon_sym_AMP_AMP] = ACTIONS(2491),
    [anon_sym_AMP] = ACTIONS(2489),
    [anon_sym_SEMI] = ACTIONS(2491),
    [anon_sym___extension__] = ACTIONS(2489),
    [anon_sym_typedef] = ACTIONS(2489),
    [anon_sym___device__] = ACTIONS(2489),
    [anon_sym___host__] = ACTIONS(2489),
    [anon_sym___global__] = ACTIONS(2489),
    [anon_sym___forceinline__] = ACTIONS(2489),
    [anon_sym___noinline__] = ACTIONS(2489),
    [anon_sym_virtual] = ACTIONS(2489),
    [anon_sym_extern] = ACTIONS(2489),
    [anon_sym___attribute__] = ACTIONS(2489),
    [anon_sym___attribute] = ACTIONS(2489),
    [anon_sym_COLON_COLON] = ACTIONS(2491),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2491),
    [anon_sym___declspec] = ACTIONS(2489),
    [anon_sym___based] = ACTIONS(2489),
    [anon_sym___cdecl] = ACTIONS(2489),
    [anon_sym___clrcall] = ACTIONS(2489),
    [anon_sym___stdcall] = ACTIONS(2489),
    [anon_sym___fastcall] = ACTIONS(2489),
    [anon_sym___thiscall] = ACTIONS(2489),
    [anon_sym___vectorcall] = ACTIONS(2489),
    [anon_sym_LBRACE] = ACTIONS(2491),
    [anon_sym_signed] = ACTIONS(2489),
    [anon_sym_unsigned] = ACTIONS(2489),
    [anon_sym_long] = ACTIONS(2489),
    [anon_sym_short] = ACTIONS(2489),
    [anon_sym_LBRACK] = ACTIONS(2489),
    [anon_sym_static] = ACTIONS(2489),
    [anon_sym_register] = ACTIONS(2489),
    [anon_sym_inline] = ACTIONS(2489),
    [anon_sym___inline] = ACTIONS(2489),
    [anon_sym___inline__] = ACTIONS(2489),
    [anon_sym___forceinline] = ACTIONS(2489),
    [anon_sym_thread_local] = ACTIONS(2489),
    [anon_sym___thread] = ACTIONS(2489),
    [anon_sym_const] = ACTIONS(2489),
    [anon_sym_constexpr] = ACTIONS(2489),
    [anon_sym_volatile] = ACTIONS(2489),
    [anon_sym_restrict] = ACTIONS(2489),
    [anon_sym___restrict__] = ACTIONS(2489),
    [anon_sym__Atomic] = ACTIONS(2489),
    [anon_sym__Noreturn] = ACTIONS(2489),
    [anon_sym_noreturn] = ACTIONS(2489),
    [anon_sym__Nonnull] = ACTIONS(2489),
    [anon_sym_mutable] = ACTIONS(2489),
    [anon_sym_constinit] = ACTIONS(2489),
    [anon_sym_consteval] = ACTIONS(2489),
    [anon_sym___shared__] = ACTIONS(2489),
    [anon_sym___local__] = ACTIONS(2489),
    [anon_sym___constant__] = ACTIONS(2489),
    [anon_sym___managed__] = ACTIONS(2489),
    [anon_sym___grid_constant__] = ACTIONS(2489),
    [anon_sym_alignas] = ACTIONS(2489),
    [anon_sym__Alignas] = ACTIONS(2489),
    [sym_primitive_type] = ACTIONS(2489),
    [anon_sym_enum] = ACTIONS(2489),
    [anon_sym_class] = ACTIONS(2489),
    [anon_sym_struct] = ACTIONS(2489),
    [anon_sym_union] = ACTIONS(2489),
    [anon_sym_if] = ACTIONS(2489),
    [anon_sym_switch] = ACTIONS(2489),
    [anon_sym_case] = ACTIONS(2489),
    [anon_sym_default] = ACTIONS(2489),
    [anon_sym_while] = ACTIONS(2489),
    [anon_sym_do] = ACTIONS(2489),
    [anon_sym_for] = ACTIONS(2489),
    [anon_sym_return] = ACTIONS(2489),
    [anon_sym_break] = ACTIONS(2489),
    [anon_sym_continue] = ACTIONS(2489),
    [anon_sym_goto] = ACTIONS(2489),
    [anon_sym___try] = ACTIONS(2489),
    [anon_sym___leave] = ACTIONS(2489),
    [anon_sym_not] = ACTIONS(2489),
    [anon_sym_compl] = ACTIONS(2489),
    [anon_sym_DASH_DASH] = ACTIONS(2491),
    [anon_sym_PLUS_PLUS] = ACTIONS(2491),
    [anon_sym_sizeof] = ACTIONS(2489),
    [anon_sym___alignof__] = ACTIONS(2489),
    [anon_sym___alignof] = ACTIONS(2489),
    [anon_sym__alignof] = ACTIONS(2489),
    [anon_sym_alignof] = ACTIONS(2489),
    [anon_sym__Alignof] = ACTIONS(2489),
    [anon_sym_offsetof] = ACTIONS(2489),
    [anon_sym__Generic] = ACTIONS(2489),
    [anon_sym_asm] = ACTIONS(2489),
    [anon_sym___asm__] = ACTIONS(2489),
    [anon_sym___asm] = ACTIONS(2489),
    [sym_number_literal] = ACTIONS(2491),
    [anon_sym_L_SQUOTE] = ACTIONS(2491),
    [anon_sym_u_SQUOTE] = ACTIONS(2491),
    [anon_sym_U_SQUOTE] = ACTIONS(2491),
    [anon_sym_u8_SQUOTE] = ACTIONS(2491),
    [anon_sym_SQUOTE] = ACTIONS(2491),
    [anon_sym_L_DQUOTE] = ACTIONS(2491),
    [anon_sym_u_DQUOTE] = ACTIONS(2491),
    [anon_sym_U_DQUOTE] = ACTIONS(2491),
    [anon_sym_u8_DQUOTE] = ACTIONS(2491),
    [anon_sym_DQUOTE] = ACTIONS(2491),
    [sym_true] = ACTIONS(2489),
    [sym_false] = ACTIONS(2489),
    [anon_sym_NULL] = ACTIONS(2489),
    [anon_sym_nullptr] = ACTIONS(2489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2489),
    [anon_sym_decltype] = ACTIONS(2489),
    [anon_sym_explicit] = ACTIONS(2489),
    [anon_sym_typename] = ACTIONS(2489),
    [anon_sym_template] = ACTIONS(2489),
    [anon_sym_operator] = ACTIONS(2489),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_delete] = ACTIONS(2489),
    [anon_sym_throw] = ACTIONS(2489),
    [anon_sym_namespace] = ACTIONS(2489),
    [anon_sym_using] = ACTIONS(2489),
    [anon_sym_static_assert] = ACTIONS(2489),
    [anon_sym_concept] = ACTIONS(2489),
    [anon_sym_co_return] = ACTIONS(2489),
    [anon_sym_co_yield] = ACTIONS(2489),
    [anon_sym_R_DQUOTE] = ACTIONS(2491),
    [anon_sym_LR_DQUOTE] = ACTIONS(2491),
    [anon_sym_uR_DQUOTE] = ACTIONS(2491),
    [anon_sym_UR_DQUOTE] = ACTIONS(2491),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2491),
    [anon_sym_co_await] = ACTIONS(2489),
    [anon_sym_new] = ACTIONS(2489),
    [anon_sym_requires] = ACTIONS(2489),
    [sym_this] = ACTIONS(2489),
    [anon_sym___launch_bounds__] = ACTIONS(2489),
  },
  [STATE(285)] = {
    [sym_identifier] = ACTIONS(2493),
    [aux_sym_preproc_include_token1] = ACTIONS(2493),
    [aux_sym_preproc_def_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token2] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2493),
    [aux_sym_preproc_else_token1] = ACTIONS(2493),
    [aux_sym_preproc_elif_token1] = ACTIONS(2493),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2493),
    [sym_preproc_directive] = ACTIONS(2493),
    [anon_sym_LPAREN2] = ACTIONS(2495),
    [anon_sym_BANG] = ACTIONS(2495),
    [anon_sym_TILDE] = ACTIONS(2495),
    [anon_sym_DASH] = ACTIONS(2493),
    [anon_sym_PLUS] = ACTIONS(2493),
    [anon_sym_STAR] = ACTIONS(2495),
    [anon_sym_AMP_AMP] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(2493),
    [anon_sym_SEMI] = ACTIONS(2495),
    [anon_sym___extension__] = ACTIONS(2493),
    [anon_sym_typedef] = ACTIONS(2493),
    [anon_sym___device__] = ACTIONS(2493),
    [anon_sym___host__] = ACTIONS(2493),
    [anon_sym___global__] = ACTIONS(2493),
    [anon_sym___forceinline__] = ACTIONS(2493),
    [anon_sym___noinline__] = ACTIONS(2493),
    [anon_sym_virtual] = ACTIONS(2493),
    [anon_sym_extern] = ACTIONS(2493),
    [anon_sym___attribute__] = ACTIONS(2493),
    [anon_sym___attribute] = ACTIONS(2493),
    [anon_sym_COLON_COLON] = ACTIONS(2495),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2495),
    [anon_sym___declspec] = ACTIONS(2493),
    [anon_sym___based] = ACTIONS(2493),
    [anon_sym___cdecl] = ACTIONS(2493),
    [anon_sym___clrcall] = ACTIONS(2493),
    [anon_sym___stdcall] = ACTIONS(2493),
    [anon_sym___fastcall] = ACTIONS(2493),
    [anon_sym___thiscall] = ACTIONS(2493),
    [anon_sym___vectorcall] = ACTIONS(2493),
    [anon_sym_LBRACE] = ACTIONS(2495),
    [anon_sym_signed] = ACTIONS(2493),
    [anon_sym_unsigned] = ACTIONS(2493),
    [anon_sym_long] = ACTIONS(2493),
    [anon_sym_short] = ACTIONS(2493),
    [anon_sym_LBRACK] = ACTIONS(2493),
    [anon_sym_static] = ACTIONS(2493),
    [anon_sym_register] = ACTIONS(2493),
    [anon_sym_inline] = ACTIONS(2493),
    [anon_sym___inline] = ACTIONS(2493),
    [anon_sym___inline__] = ACTIONS(2493),
    [anon_sym___forceinline] = ACTIONS(2493),
    [anon_sym_thread_local] = ACTIONS(2493),
    [anon_sym___thread] = ACTIONS(2493),
    [anon_sym_const] = ACTIONS(2493),
    [anon_sym_constexpr] = ACTIONS(2493),
    [anon_sym_volatile] = ACTIONS(2493),
    [anon_sym_restrict] = ACTIONS(2493),
    [anon_sym___restrict__] = ACTIONS(2493),
    [anon_sym__Atomic] = ACTIONS(2493),
    [anon_sym__Noreturn] = ACTIONS(2493),
    [anon_sym_noreturn] = ACTIONS(2493),
    [anon_sym__Nonnull] = ACTIONS(2493),
    [anon_sym_mutable] = ACTIONS(2493),
    [anon_sym_constinit] = ACTIONS(2493),
    [anon_sym_consteval] = ACTIONS(2493),
    [anon_sym___shared__] = ACTIONS(2493),
    [anon_sym___local__] = ACTIONS(2493),
    [anon_sym___constant__] = ACTIONS(2493),
    [anon_sym___managed__] = ACTIONS(2493),
    [anon_sym___grid_constant__] = ACTIONS(2493),
    [anon_sym_alignas] = ACTIONS(2493),
    [anon_sym__Alignas] = ACTIONS(2493),
    [sym_primitive_type] = ACTIONS(2493),
    [anon_sym_enum] = ACTIONS(2493),
    [anon_sym_class] = ACTIONS(2493),
    [anon_sym_struct] = ACTIONS(2493),
    [anon_sym_union] = ACTIONS(2493),
    [anon_sym_if] = ACTIONS(2493),
    [anon_sym_switch] = ACTIONS(2493),
    [anon_sym_case] = ACTIONS(2493),
    [anon_sym_default] = ACTIONS(2493),
    [anon_sym_while] = ACTIONS(2493),
    [anon_sym_do] = ACTIONS(2493),
    [anon_sym_for] = ACTIONS(2493),
    [anon_sym_return] = ACTIONS(2493),
    [anon_sym_break] = ACTIONS(2493),
    [anon_sym_continue] = ACTIONS(2493),
    [anon_sym_goto] = ACTIONS(2493),
    [anon_sym___try] = ACTIONS(2493),
    [anon_sym___leave] = ACTIONS(2493),
    [anon_sym_not] = ACTIONS(2493),
    [anon_sym_compl] = ACTIONS(2493),
    [anon_sym_DASH_DASH] = ACTIONS(2495),
    [anon_sym_PLUS_PLUS] = ACTIONS(2495),
    [anon_sym_sizeof] = ACTIONS(2493),
    [anon_sym___alignof__] = ACTIONS(2493),
    [anon_sym___alignof] = ACTIONS(2493),
    [anon_sym__alignof] = ACTIONS(2493),
    [anon_sym_alignof] = ACTIONS(2493),
    [anon_sym__Alignof] = ACTIONS(2493),
    [anon_sym_offsetof] = ACTIONS(2493),
    [anon_sym__Generic] = ACTIONS(2493),
    [anon_sym_asm] = ACTIONS(2493),
    [anon_sym___asm__] = ACTIONS(2493),
    [anon_sym___asm] = ACTIONS(2493),
    [sym_number_literal] = ACTIONS(2495),
    [anon_sym_L_SQUOTE] = ACTIONS(2495),
    [anon_sym_u_SQUOTE] = ACTIONS(2495),
    [anon_sym_U_SQUOTE] = ACTIONS(2495),
    [anon_sym_u8_SQUOTE] = ACTIONS(2495),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_L_DQUOTE] = ACTIONS(2495),
    [anon_sym_u_DQUOTE] = ACTIONS(2495),
    [anon_sym_U_DQUOTE] = ACTIONS(2495),
    [anon_sym_u8_DQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2495),
    [sym_true] = ACTIONS(2493),
    [sym_false] = ACTIONS(2493),
    [anon_sym_NULL] = ACTIONS(2493),
    [anon_sym_nullptr] = ACTIONS(2493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2493),
    [anon_sym_decltype] = ACTIONS(2493),
    [anon_sym_explicit] = ACTIONS(2493),
    [anon_sym_typename] = ACTIONS(2493),
    [anon_sym_template] = ACTIONS(2493),
    [anon_sym_operator] = ACTIONS(2493),
    [anon_sym_try] = ACTIONS(2493),
    [anon_sym_delete] = ACTIONS(2493),
    [anon_sym_throw] = ACTIONS(2493),
    [anon_sym_namespace] = ACTIONS(2493),
    [anon_sym_using] = ACTIONS(2493),
    [anon_sym_static_assert] = ACTIONS(2493),
    [anon_sym_concept] = ACTIONS(2493),
    [anon_sym_co_return] = ACTIONS(2493),
    [anon_sym_co_yield] = ACTIONS(2493),
    [anon_sym_R_DQUOTE] = ACTIONS(2495),
    [anon_sym_LR_DQUOTE] = ACTIONS(2495),
    [anon_sym_uR_DQUOTE] = ACTIONS(2495),
    [anon_sym_UR_DQUOTE] = ACTIONS(2495),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2495),
    [anon_sym_co_await] = ACTIONS(2493),
    [anon_sym_new] = ACTIONS(2493),
    [anon_sym_requires] = ACTIONS(2493),
    [sym_this] = ACTIONS(2493),
    [anon_sym___launch_bounds__] = ACTIONS(2493),
  },
  [STATE(286)] = {
    [sym_identifier] = ACTIONS(2497),
    [aux_sym_preproc_include_token1] = ACTIONS(2497),
    [aux_sym_preproc_def_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token2] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2497),
    [aux_sym_preproc_else_token1] = ACTIONS(2497),
    [aux_sym_preproc_elif_token1] = ACTIONS(2497),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2497),
    [sym_preproc_directive] = ACTIONS(2497),
    [anon_sym_LPAREN2] = ACTIONS(2499),
    [anon_sym_BANG] = ACTIONS(2499),
    [anon_sym_TILDE] = ACTIONS(2499),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_STAR] = ACTIONS(2499),
    [anon_sym_AMP_AMP] = ACTIONS(2499),
    [anon_sym_AMP] = ACTIONS(2497),
    [anon_sym_SEMI] = ACTIONS(2499),
    [anon_sym___extension__] = ACTIONS(2497),
    [anon_sym_typedef] = ACTIONS(2497),
    [anon_sym___device__] = ACTIONS(2497),
    [anon_sym___host__] = ACTIONS(2497),
    [anon_sym___global__] = ACTIONS(2497),
    [anon_sym___forceinline__] = ACTIONS(2497),
    [anon_sym___noinline__] = ACTIONS(2497),
    [anon_sym_virtual] = ACTIONS(2497),
    [anon_sym_extern] = ACTIONS(2497),
    [anon_sym___attribute__] = ACTIONS(2497),
    [anon_sym___attribute] = ACTIONS(2497),
    [anon_sym_COLON_COLON] = ACTIONS(2499),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2499),
    [anon_sym___declspec] = ACTIONS(2497),
    [anon_sym___based] = ACTIONS(2497),
    [anon_sym___cdecl] = ACTIONS(2497),
    [anon_sym___clrcall] = ACTIONS(2497),
    [anon_sym___stdcall] = ACTIONS(2497),
    [anon_sym___fastcall] = ACTIONS(2497),
    [anon_sym___thiscall] = ACTIONS(2497),
    [anon_sym___vectorcall] = ACTIONS(2497),
    [anon_sym_LBRACE] = ACTIONS(2499),
    [anon_sym_signed] = ACTIONS(2497),
    [anon_sym_unsigned] = ACTIONS(2497),
    [anon_sym_long] = ACTIONS(2497),
    [anon_sym_short] = ACTIONS(2497),
    [anon_sym_LBRACK] = ACTIONS(2497),
    [anon_sym_static] = ACTIONS(2497),
    [anon_sym_register] = ACTIONS(2497),
    [anon_sym_inline] = ACTIONS(2497),
    [anon_sym___inline] = ACTIONS(2497),
    [anon_sym___inline__] = ACTIONS(2497),
    [anon_sym___forceinline] = ACTIONS(2497),
    [anon_sym_thread_local] = ACTIONS(2497),
    [anon_sym___thread] = ACTIONS(2497),
    [anon_sym_const] = ACTIONS(2497),
    [anon_sym_constexpr] = ACTIONS(2497),
    [anon_sym_volatile] = ACTIONS(2497),
    [anon_sym_restrict] = ACTIONS(2497),
    [anon_sym___restrict__] = ACTIONS(2497),
    [anon_sym__Atomic] = ACTIONS(2497),
    [anon_sym__Noreturn] = ACTIONS(2497),
    [anon_sym_noreturn] = ACTIONS(2497),
    [anon_sym__Nonnull] = ACTIONS(2497),
    [anon_sym_mutable] = ACTIONS(2497),
    [anon_sym_constinit] = ACTIONS(2497),
    [anon_sym_consteval] = ACTIONS(2497),
    [anon_sym___shared__] = ACTIONS(2497),
    [anon_sym___local__] = ACTIONS(2497),
    [anon_sym___constant__] = ACTIONS(2497),
    [anon_sym___managed__] = ACTIONS(2497),
    [anon_sym___grid_constant__] = ACTIONS(2497),
    [anon_sym_alignas] = ACTIONS(2497),
    [anon_sym__Alignas] = ACTIONS(2497),
    [sym_primitive_type] = ACTIONS(2497),
    [anon_sym_enum] = ACTIONS(2497),
    [anon_sym_class] = ACTIONS(2497),
    [anon_sym_struct] = ACTIONS(2497),
    [anon_sym_union] = ACTIONS(2497),
    [anon_sym_if] = ACTIONS(2497),
    [anon_sym_switch] = ACTIONS(2497),
    [anon_sym_case] = ACTIONS(2497),
    [anon_sym_default] = ACTIONS(2497),
    [anon_sym_while] = ACTIONS(2497),
    [anon_sym_do] = ACTIONS(2497),
    [anon_sym_for] = ACTIONS(2497),
    [anon_sym_return] = ACTIONS(2497),
    [anon_sym_break] = ACTIONS(2497),
    [anon_sym_continue] = ACTIONS(2497),
    [anon_sym_goto] = ACTIONS(2497),
    [anon_sym___try] = ACTIONS(2497),
    [anon_sym___leave] = ACTIONS(2497),
    [anon_sym_not] = ACTIONS(2497),
    [anon_sym_compl] = ACTIONS(2497),
    [anon_sym_DASH_DASH] = ACTIONS(2499),
    [anon_sym_PLUS_PLUS] = ACTIONS(2499),
    [anon_sym_sizeof] = ACTIONS(2497),
    [anon_sym___alignof__] = ACTIONS(2497),
    [anon_sym___alignof] = ACTIONS(2497),
    [anon_sym__alignof] = ACTIONS(2497),
    [anon_sym_alignof] = ACTIONS(2497),
    [anon_sym__Alignof] = ACTIONS(2497),
    [anon_sym_offsetof] = ACTIONS(2497),
    [anon_sym__Generic] = ACTIONS(2497),
    [anon_sym_asm] = ACTIONS(2497),
    [anon_sym___asm__] = ACTIONS(2497),
    [anon_sym___asm] = ACTIONS(2497),
    [sym_number_literal] = ACTIONS(2499),
    [anon_sym_L_SQUOTE] = ACTIONS(2499),
    [anon_sym_u_SQUOTE] = ACTIONS(2499),
    [anon_sym_U_SQUOTE] = ACTIONS(2499),
    [anon_sym_u8_SQUOTE] = ACTIONS(2499),
    [anon_sym_SQUOTE] = ACTIONS(2499),
    [anon_sym_L_DQUOTE] = ACTIONS(2499),
    [anon_sym_u_DQUOTE] = ACTIONS(2499),
    [anon_sym_U_DQUOTE] = ACTIONS(2499),
    [anon_sym_u8_DQUOTE] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(2499),
    [sym_true] = ACTIONS(2497),
    [sym_false] = ACTIONS(2497),
    [anon_sym_NULL] = ACTIONS(2497),
    [anon_sym_nullptr] = ACTIONS(2497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2497),
    [anon_sym_decltype] = ACTIONS(2497),
    [anon_sym_explicit] = ACTIONS(2497),
    [anon_sym_typename] = ACTIONS(2497),
    [anon_sym_template] = ACTIONS(2497),
    [anon_sym_operator] = ACTIONS(2497),
    [anon_sym_try] = ACTIONS(2497),
    [anon_sym_delete] = ACTIONS(2497),
    [anon_sym_throw] = ACTIONS(2497),
    [anon_sym_namespace] = ACTIONS(2497),
    [anon_sym_using] = ACTIONS(2497),
    [anon_sym_static_assert] = ACTIONS(2497),
    [anon_sym_concept] = ACTIONS(2497),
    [anon_sym_co_return] = ACTIONS(2497),
    [anon_sym_co_yield] = ACTIONS(2497),
    [anon_sym_R_DQUOTE] = ACTIONS(2499),
    [anon_sym_LR_DQUOTE] = ACTIONS(2499),
    [anon_sym_uR_DQUOTE] = ACTIONS(2499),
    [anon_sym_UR_DQUOTE] = ACTIONS(2499),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2499),
    [anon_sym_co_await] = ACTIONS(2497),
    [anon_sym_new] = ACTIONS(2497),
    [anon_sym_requires] = ACTIONS(2497),
    [sym_this] = ACTIONS(2497),
    [anon_sym___launch_bounds__] = ACTIONS(2497),
  },
  [STATE(287)] = {
    [sym_identifier] = ACTIONS(2501),
    [aux_sym_preproc_include_token1] = ACTIONS(2501),
    [aux_sym_preproc_def_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token2] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2501),
    [aux_sym_preproc_else_token1] = ACTIONS(2501),
    [aux_sym_preproc_elif_token1] = ACTIONS(2501),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2501),
    [sym_preproc_directive] = ACTIONS(2501),
    [anon_sym_LPAREN2] = ACTIONS(2503),
    [anon_sym_BANG] = ACTIONS(2503),
    [anon_sym_TILDE] = ACTIONS(2503),
    [anon_sym_DASH] = ACTIONS(2501),
    [anon_sym_PLUS] = ACTIONS(2501),
    [anon_sym_STAR] = ACTIONS(2503),
    [anon_sym_AMP_AMP] = ACTIONS(2503),
    [anon_sym_AMP] = ACTIONS(2501),
    [anon_sym_SEMI] = ACTIONS(2503),
    [anon_sym___extension__] = ACTIONS(2501),
    [anon_sym_typedef] = ACTIONS(2501),
    [anon_sym___device__] = ACTIONS(2501),
    [anon_sym___host__] = ACTIONS(2501),
    [anon_sym___global__] = ACTIONS(2501),
    [anon_sym___forceinline__] = ACTIONS(2501),
    [anon_sym___noinline__] = ACTIONS(2501),
    [anon_sym_virtual] = ACTIONS(2501),
    [anon_sym_extern] = ACTIONS(2501),
    [anon_sym___attribute__] = ACTIONS(2501),
    [anon_sym___attribute] = ACTIONS(2501),
    [anon_sym_COLON_COLON] = ACTIONS(2503),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2503),
    [anon_sym___declspec] = ACTIONS(2501),
    [anon_sym___based] = ACTIONS(2501),
    [anon_sym___cdecl] = ACTIONS(2501),
    [anon_sym___clrcall] = ACTIONS(2501),
    [anon_sym___stdcall] = ACTIONS(2501),
    [anon_sym___fastcall] = ACTIONS(2501),
    [anon_sym___thiscall] = ACTIONS(2501),
    [anon_sym___vectorcall] = ACTIONS(2501),
    [anon_sym_LBRACE] = ACTIONS(2503),
    [anon_sym_signed] = ACTIONS(2501),
    [anon_sym_unsigned] = ACTIONS(2501),
    [anon_sym_long] = ACTIONS(2501),
    [anon_sym_short] = ACTIONS(2501),
    [anon_sym_LBRACK] = ACTIONS(2501),
    [anon_sym_static] = ACTIONS(2501),
    [anon_sym_register] = ACTIONS(2501),
    [anon_sym_inline] = ACTIONS(2501),
    [anon_sym___inline] = ACTIONS(2501),
    [anon_sym___inline__] = ACTIONS(2501),
    [anon_sym___forceinline] = ACTIONS(2501),
    [anon_sym_thread_local] = ACTIONS(2501),
    [anon_sym___thread] = ACTIONS(2501),
    [anon_sym_const] = ACTIONS(2501),
    [anon_sym_constexpr] = ACTIONS(2501),
    [anon_sym_volatile] = ACTIONS(2501),
    [anon_sym_restrict] = ACTIONS(2501),
    [anon_sym___restrict__] = ACTIONS(2501),
    [anon_sym__Atomic] = ACTIONS(2501),
    [anon_sym__Noreturn] = ACTIONS(2501),
    [anon_sym_noreturn] = ACTIONS(2501),
    [anon_sym__Nonnull] = ACTIONS(2501),
    [anon_sym_mutable] = ACTIONS(2501),
    [anon_sym_constinit] = ACTIONS(2501),
    [anon_sym_consteval] = ACTIONS(2501),
    [anon_sym___shared__] = ACTIONS(2501),
    [anon_sym___local__] = ACTIONS(2501),
    [anon_sym___constant__] = ACTIONS(2501),
    [anon_sym___managed__] = ACTIONS(2501),
    [anon_sym___grid_constant__] = ACTIONS(2501),
    [anon_sym_alignas] = ACTIONS(2501),
    [anon_sym__Alignas] = ACTIONS(2501),
    [sym_primitive_type] = ACTIONS(2501),
    [anon_sym_enum] = ACTIONS(2501),
    [anon_sym_class] = ACTIONS(2501),
    [anon_sym_struct] = ACTIONS(2501),
    [anon_sym_union] = ACTIONS(2501),
    [anon_sym_if] = ACTIONS(2501),
    [anon_sym_switch] = ACTIONS(2501),
    [anon_sym_case] = ACTIONS(2501),
    [anon_sym_default] = ACTIONS(2501),
    [anon_sym_while] = ACTIONS(2501),
    [anon_sym_do] = ACTIONS(2501),
    [anon_sym_for] = ACTIONS(2501),
    [anon_sym_return] = ACTIONS(2501),
    [anon_sym_break] = ACTIONS(2501),
    [anon_sym_continue] = ACTIONS(2501),
    [anon_sym_goto] = ACTIONS(2501),
    [anon_sym___try] = ACTIONS(2501),
    [anon_sym___leave] = ACTIONS(2501),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_compl] = ACTIONS(2501),
    [anon_sym_DASH_DASH] = ACTIONS(2503),
    [anon_sym_PLUS_PLUS] = ACTIONS(2503),
    [anon_sym_sizeof] = ACTIONS(2501),
    [anon_sym___alignof__] = ACTIONS(2501),
    [anon_sym___alignof] = ACTIONS(2501),
    [anon_sym__alignof] = ACTIONS(2501),
    [anon_sym_alignof] = ACTIONS(2501),
    [anon_sym__Alignof] = ACTIONS(2501),
    [anon_sym_offsetof] = ACTIONS(2501),
    [anon_sym__Generic] = ACTIONS(2501),
    [anon_sym_asm] = ACTIONS(2501),
    [anon_sym___asm__] = ACTIONS(2501),
    [anon_sym___asm] = ACTIONS(2501),
    [sym_number_literal] = ACTIONS(2503),
    [anon_sym_L_SQUOTE] = ACTIONS(2503),
    [anon_sym_u_SQUOTE] = ACTIONS(2503),
    [anon_sym_U_SQUOTE] = ACTIONS(2503),
    [anon_sym_u8_SQUOTE] = ACTIONS(2503),
    [anon_sym_SQUOTE] = ACTIONS(2503),
    [anon_sym_L_DQUOTE] = ACTIONS(2503),
    [anon_sym_u_DQUOTE] = ACTIONS(2503),
    [anon_sym_U_DQUOTE] = ACTIONS(2503),
    [anon_sym_u8_DQUOTE] = ACTIONS(2503),
    [anon_sym_DQUOTE] = ACTIONS(2503),
    [sym_true] = ACTIONS(2501),
    [sym_false] = ACTIONS(2501),
    [anon_sym_NULL] = ACTIONS(2501),
    [anon_sym_nullptr] = ACTIONS(2501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2501),
    [anon_sym_decltype] = ACTIONS(2501),
    [anon_sym_explicit] = ACTIONS(2501),
    [anon_sym_typename] = ACTIONS(2501),
    [anon_sym_template] = ACTIONS(2501),
    [anon_sym_operator] = ACTIONS(2501),
    [anon_sym_try] = ACTIONS(2501),
    [anon_sym_delete] = ACTIONS(2501),
    [anon_sym_throw] = ACTIONS(2501),
    [anon_sym_namespace] = ACTIONS(2501),
    [anon_sym_using] = ACTIONS(2501),
    [anon_sym_static_assert] = ACTIONS(2501),
    [anon_sym_concept] = ACTIONS(2501),
    [anon_sym_co_return] = ACTIONS(2501),
    [anon_sym_co_yield] = ACTIONS(2501),
    [anon_sym_R_DQUOTE] = ACTIONS(2503),
    [anon_sym_LR_DQUOTE] = ACTIONS(2503),
    [anon_sym_uR_DQUOTE] = ACTIONS(2503),
    [anon_sym_UR_DQUOTE] = ACTIONS(2503),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2503),
    [anon_sym_co_await] = ACTIONS(2501),
    [anon_sym_new] = ACTIONS(2501),
    [anon_sym_requires] = ACTIONS(2501),
    [sym_this] = ACTIONS(2501),
    [anon_sym___launch_bounds__] = ACTIONS(2501),
  },
  [STATE(288)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(289)] = {
    [sym_identifier] = ACTIONS(2505),
    [aux_sym_preproc_include_token1] = ACTIONS(2505),
    [aux_sym_preproc_def_token1] = ACTIONS(2505),
    [aux_sym_preproc_if_token1] = ACTIONS(2505),
    [aux_sym_preproc_if_token2] = ACTIONS(2505),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2505),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2505),
    [aux_sym_preproc_else_token1] = ACTIONS(2505),
    [aux_sym_preproc_elif_token1] = ACTIONS(2505),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2505),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2505),
    [sym_preproc_directive] = ACTIONS(2505),
    [anon_sym_LPAREN2] = ACTIONS(2507),
    [anon_sym_BANG] = ACTIONS(2507),
    [anon_sym_TILDE] = ACTIONS(2507),
    [anon_sym_DASH] = ACTIONS(2505),
    [anon_sym_PLUS] = ACTIONS(2505),
    [anon_sym_STAR] = ACTIONS(2507),
    [anon_sym_AMP_AMP] = ACTIONS(2507),
    [anon_sym_AMP] = ACTIONS(2505),
    [anon_sym_SEMI] = ACTIONS(2507),
    [anon_sym___extension__] = ACTIONS(2505),
    [anon_sym_typedef] = ACTIONS(2505),
    [anon_sym___device__] = ACTIONS(2505),
    [anon_sym___host__] = ACTIONS(2505),
    [anon_sym___global__] = ACTIONS(2505),
    [anon_sym___forceinline__] = ACTIONS(2505),
    [anon_sym___noinline__] = ACTIONS(2505),
    [anon_sym_virtual] = ACTIONS(2505),
    [anon_sym_extern] = ACTIONS(2505),
    [anon_sym___attribute__] = ACTIONS(2505),
    [anon_sym___attribute] = ACTIONS(2505),
    [anon_sym_COLON_COLON] = ACTIONS(2507),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2507),
    [anon_sym___declspec] = ACTIONS(2505),
    [anon_sym___based] = ACTIONS(2505),
    [anon_sym___cdecl] = ACTIONS(2505),
    [anon_sym___clrcall] = ACTIONS(2505),
    [anon_sym___stdcall] = ACTIONS(2505),
    [anon_sym___fastcall] = ACTIONS(2505),
    [anon_sym___thiscall] = ACTIONS(2505),
    [anon_sym___vectorcall] = ACTIONS(2505),
    [anon_sym_LBRACE] = ACTIONS(2507),
    [anon_sym_signed] = ACTIONS(2505),
    [anon_sym_unsigned] = ACTIONS(2505),
    [anon_sym_long] = ACTIONS(2505),
    [anon_sym_short] = ACTIONS(2505),
    [anon_sym_LBRACK] = ACTIONS(2505),
    [anon_sym_static] = ACTIONS(2505),
    [anon_sym_register] = ACTIONS(2505),
    [anon_sym_inline] = ACTIONS(2505),
    [anon_sym___inline] = ACTIONS(2505),
    [anon_sym___inline__] = ACTIONS(2505),
    [anon_sym___forceinline] = ACTIONS(2505),
    [anon_sym_thread_local] = ACTIONS(2505),
    [anon_sym___thread] = ACTIONS(2505),
    [anon_sym_const] = ACTIONS(2505),
    [anon_sym_constexpr] = ACTIONS(2505),
    [anon_sym_volatile] = ACTIONS(2505),
    [anon_sym_restrict] = ACTIONS(2505),
    [anon_sym___restrict__] = ACTIONS(2505),
    [anon_sym__Atomic] = ACTIONS(2505),
    [anon_sym__Noreturn] = ACTIONS(2505),
    [anon_sym_noreturn] = ACTIONS(2505),
    [anon_sym__Nonnull] = ACTIONS(2505),
    [anon_sym_mutable] = ACTIONS(2505),
    [anon_sym_constinit] = ACTIONS(2505),
    [anon_sym_consteval] = ACTIONS(2505),
    [anon_sym___shared__] = ACTIONS(2505),
    [anon_sym___local__] = ACTIONS(2505),
    [anon_sym___constant__] = ACTIONS(2505),
    [anon_sym___managed__] = ACTIONS(2505),
    [anon_sym___grid_constant__] = ACTIONS(2505),
    [anon_sym_alignas] = ACTIONS(2505),
    [anon_sym__Alignas] = ACTIONS(2505),
    [sym_primitive_type] = ACTIONS(2505),
    [anon_sym_enum] = ACTIONS(2505),
    [anon_sym_class] = ACTIONS(2505),
    [anon_sym_struct] = ACTIONS(2505),
    [anon_sym_union] = ACTIONS(2505),
    [anon_sym_if] = ACTIONS(2505),
    [anon_sym_switch] = ACTIONS(2505),
    [anon_sym_case] = ACTIONS(2505),
    [anon_sym_default] = ACTIONS(2505),
    [anon_sym_while] = ACTIONS(2505),
    [anon_sym_do] = ACTIONS(2505),
    [anon_sym_for] = ACTIONS(2505),
    [anon_sym_return] = ACTIONS(2505),
    [anon_sym_break] = ACTIONS(2505),
    [anon_sym_continue] = ACTIONS(2505),
    [anon_sym_goto] = ACTIONS(2505),
    [anon_sym___try] = ACTIONS(2505),
    [anon_sym___leave] = ACTIONS(2505),
    [anon_sym_not] = ACTIONS(2505),
    [anon_sym_compl] = ACTIONS(2505),
    [anon_sym_DASH_DASH] = ACTIONS(2507),
    [anon_sym_PLUS_PLUS] = ACTIONS(2507),
    [anon_sym_sizeof] = ACTIONS(2505),
    [anon_sym___alignof__] = ACTIONS(2505),
    [anon_sym___alignof] = ACTIONS(2505),
    [anon_sym__alignof] = ACTIONS(2505),
    [anon_sym_alignof] = ACTIONS(2505),
    [anon_sym__Alignof] = ACTIONS(2505),
    [anon_sym_offsetof] = ACTIONS(2505),
    [anon_sym__Generic] = ACTIONS(2505),
    [anon_sym_asm] = ACTIONS(2505),
    [anon_sym___asm__] = ACTIONS(2505),
    [anon_sym___asm] = ACTIONS(2505),
    [sym_number_literal] = ACTIONS(2507),
    [anon_sym_L_SQUOTE] = ACTIONS(2507),
    [anon_sym_u_SQUOTE] = ACTIONS(2507),
    [anon_sym_U_SQUOTE] = ACTIONS(2507),
    [anon_sym_u8_SQUOTE] = ACTIONS(2507),
    [anon_sym_SQUOTE] = ACTIONS(2507),
    [anon_sym_L_DQUOTE] = ACTIONS(2507),
    [anon_sym_u_DQUOTE] = ACTIONS(2507),
    [anon_sym_U_DQUOTE] = ACTIONS(2507),
    [anon_sym_u8_DQUOTE] = ACTIONS(2507),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_true] = ACTIONS(2505),
    [sym_false] = ACTIONS(2505),
    [anon_sym_NULL] = ACTIONS(2505),
    [anon_sym_nullptr] = ACTIONS(2505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2505),
    [anon_sym_decltype] = ACTIONS(2505),
    [anon_sym_explicit] = ACTIONS(2505),
    [anon_sym_typename] = ACTIONS(2505),
    [anon_sym_template] = ACTIONS(2505),
    [anon_sym_operator] = ACTIONS(2505),
    [anon_sym_try] = ACTIONS(2505),
    [anon_sym_delete] = ACTIONS(2505),
    [anon_sym_throw] = ACTIONS(2505),
    [anon_sym_namespace] = ACTIONS(2505),
    [anon_sym_using] = ACTIONS(2505),
    [anon_sym_static_assert] = ACTIONS(2505),
    [anon_sym_concept] = ACTIONS(2505),
    [anon_sym_co_return] = ACTIONS(2505),
    [anon_sym_co_yield] = ACTIONS(2505),
    [anon_sym_R_DQUOTE] = ACTIONS(2507),
    [anon_sym_LR_DQUOTE] = ACTIONS(2507),
    [anon_sym_uR_DQUOTE] = ACTIONS(2507),
    [anon_sym_UR_DQUOTE] = ACTIONS(2507),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2507),
    [anon_sym_co_await] = ACTIONS(2505),
    [anon_sym_new] = ACTIONS(2505),
    [anon_sym_requires] = ACTIONS(2505),
    [sym_this] = ACTIONS(2505),
    [anon_sym___launch_bounds__] = ACTIONS(2505),
  },
  [STATE(290)] = {
    [sym_identifier] = ACTIONS(2509),
    [aux_sym_preproc_include_token1] = ACTIONS(2509),
    [aux_sym_preproc_def_token1] = ACTIONS(2509),
    [aux_sym_preproc_if_token1] = ACTIONS(2509),
    [aux_sym_preproc_if_token2] = ACTIONS(2509),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2509),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2509),
    [aux_sym_preproc_else_token1] = ACTIONS(2509),
    [aux_sym_preproc_elif_token1] = ACTIONS(2509),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2509),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2509),
    [sym_preproc_directive] = ACTIONS(2509),
    [anon_sym_LPAREN2] = ACTIONS(2511),
    [anon_sym_BANG] = ACTIONS(2511),
    [anon_sym_TILDE] = ACTIONS(2511),
    [anon_sym_DASH] = ACTIONS(2509),
    [anon_sym_PLUS] = ACTIONS(2509),
    [anon_sym_STAR] = ACTIONS(2511),
    [anon_sym_AMP_AMP] = ACTIONS(2511),
    [anon_sym_AMP] = ACTIONS(2509),
    [anon_sym_SEMI] = ACTIONS(2511),
    [anon_sym___extension__] = ACTIONS(2509),
    [anon_sym_typedef] = ACTIONS(2509),
    [anon_sym___device__] = ACTIONS(2509),
    [anon_sym___host__] = ACTIONS(2509),
    [anon_sym___global__] = ACTIONS(2509),
    [anon_sym___forceinline__] = ACTIONS(2509),
    [anon_sym___noinline__] = ACTIONS(2509),
    [anon_sym_virtual] = ACTIONS(2509),
    [anon_sym_extern] = ACTIONS(2509),
    [anon_sym___attribute__] = ACTIONS(2509),
    [anon_sym___attribute] = ACTIONS(2509),
    [anon_sym_COLON_COLON] = ACTIONS(2511),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2511),
    [anon_sym___declspec] = ACTIONS(2509),
    [anon_sym___based] = ACTIONS(2509),
    [anon_sym___cdecl] = ACTIONS(2509),
    [anon_sym___clrcall] = ACTIONS(2509),
    [anon_sym___stdcall] = ACTIONS(2509),
    [anon_sym___fastcall] = ACTIONS(2509),
    [anon_sym___thiscall] = ACTIONS(2509),
    [anon_sym___vectorcall] = ACTIONS(2509),
    [anon_sym_LBRACE] = ACTIONS(2511),
    [anon_sym_signed] = ACTIONS(2509),
    [anon_sym_unsigned] = ACTIONS(2509),
    [anon_sym_long] = ACTIONS(2509),
    [anon_sym_short] = ACTIONS(2509),
    [anon_sym_LBRACK] = ACTIONS(2509),
    [anon_sym_static] = ACTIONS(2509),
    [anon_sym_register] = ACTIONS(2509),
    [anon_sym_inline] = ACTIONS(2509),
    [anon_sym___inline] = ACTIONS(2509),
    [anon_sym___inline__] = ACTIONS(2509),
    [anon_sym___forceinline] = ACTIONS(2509),
    [anon_sym_thread_local] = ACTIONS(2509),
    [anon_sym___thread] = ACTIONS(2509),
    [anon_sym_const] = ACTIONS(2509),
    [anon_sym_constexpr] = ACTIONS(2509),
    [anon_sym_volatile] = ACTIONS(2509),
    [anon_sym_restrict] = ACTIONS(2509),
    [anon_sym___restrict__] = ACTIONS(2509),
    [anon_sym__Atomic] = ACTIONS(2509),
    [anon_sym__Noreturn] = ACTIONS(2509),
    [anon_sym_noreturn] = ACTIONS(2509),
    [anon_sym__Nonnull] = ACTIONS(2509),
    [anon_sym_mutable] = ACTIONS(2509),
    [anon_sym_constinit] = ACTIONS(2509),
    [anon_sym_consteval] = ACTIONS(2509),
    [anon_sym___shared__] = ACTIONS(2509),
    [anon_sym___local__] = ACTIONS(2509),
    [anon_sym___constant__] = ACTIONS(2509),
    [anon_sym___managed__] = ACTIONS(2509),
    [anon_sym___grid_constant__] = ACTIONS(2509),
    [anon_sym_alignas] = ACTIONS(2509),
    [anon_sym__Alignas] = ACTIONS(2509),
    [sym_primitive_type] = ACTIONS(2509),
    [anon_sym_enum] = ACTIONS(2509),
    [anon_sym_class] = ACTIONS(2509),
    [anon_sym_struct] = ACTIONS(2509),
    [anon_sym_union] = ACTIONS(2509),
    [anon_sym_if] = ACTIONS(2509),
    [anon_sym_switch] = ACTIONS(2509),
    [anon_sym_case] = ACTIONS(2509),
    [anon_sym_default] = ACTIONS(2509),
    [anon_sym_while] = ACTIONS(2509),
    [anon_sym_do] = ACTIONS(2509),
    [anon_sym_for] = ACTIONS(2509),
    [anon_sym_return] = ACTIONS(2509),
    [anon_sym_break] = ACTIONS(2509),
    [anon_sym_continue] = ACTIONS(2509),
    [anon_sym_goto] = ACTIONS(2509),
    [anon_sym___try] = ACTIONS(2509),
    [anon_sym___leave] = ACTIONS(2509),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_compl] = ACTIONS(2509),
    [anon_sym_DASH_DASH] = ACTIONS(2511),
    [anon_sym_PLUS_PLUS] = ACTIONS(2511),
    [anon_sym_sizeof] = ACTIONS(2509),
    [anon_sym___alignof__] = ACTIONS(2509),
    [anon_sym___alignof] = ACTIONS(2509),
    [anon_sym__alignof] = ACTIONS(2509),
    [anon_sym_alignof] = ACTIONS(2509),
    [anon_sym__Alignof] = ACTIONS(2509),
    [anon_sym_offsetof] = ACTIONS(2509),
    [anon_sym__Generic] = ACTIONS(2509),
    [anon_sym_asm] = ACTIONS(2509),
    [anon_sym___asm__] = ACTIONS(2509),
    [anon_sym___asm] = ACTIONS(2509),
    [sym_number_literal] = ACTIONS(2511),
    [anon_sym_L_SQUOTE] = ACTIONS(2511),
    [anon_sym_u_SQUOTE] = ACTIONS(2511),
    [anon_sym_U_SQUOTE] = ACTIONS(2511),
    [anon_sym_u8_SQUOTE] = ACTIONS(2511),
    [anon_sym_SQUOTE] = ACTIONS(2511),
    [anon_sym_L_DQUOTE] = ACTIONS(2511),
    [anon_sym_u_DQUOTE] = ACTIONS(2511),
    [anon_sym_U_DQUOTE] = ACTIONS(2511),
    [anon_sym_u8_DQUOTE] = ACTIONS(2511),
    [anon_sym_DQUOTE] = ACTIONS(2511),
    [sym_true] = ACTIONS(2509),
    [sym_false] = ACTIONS(2509),
    [anon_sym_NULL] = ACTIONS(2509),
    [anon_sym_nullptr] = ACTIONS(2509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2509),
    [anon_sym_decltype] = ACTIONS(2509),
    [anon_sym_explicit] = ACTIONS(2509),
    [anon_sym_typename] = ACTIONS(2509),
    [anon_sym_template] = ACTIONS(2509),
    [anon_sym_operator] = ACTIONS(2509),
    [anon_sym_try] = ACTIONS(2509),
    [anon_sym_delete] = ACTIONS(2509),
    [anon_sym_throw] = ACTIONS(2509),
    [anon_sym_namespace] = ACTIONS(2509),
    [anon_sym_using] = ACTIONS(2509),
    [anon_sym_static_assert] = ACTIONS(2509),
    [anon_sym_concept] = ACTIONS(2509),
    [anon_sym_co_return] = ACTIONS(2509),
    [anon_sym_co_yield] = ACTIONS(2509),
    [anon_sym_R_DQUOTE] = ACTIONS(2511),
    [anon_sym_LR_DQUOTE] = ACTIONS(2511),
    [anon_sym_uR_DQUOTE] = ACTIONS(2511),
    [anon_sym_UR_DQUOTE] = ACTIONS(2511),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2511),
    [anon_sym_co_await] = ACTIONS(2509),
    [anon_sym_new] = ACTIONS(2509),
    [anon_sym_requires] = ACTIONS(2509),
    [sym_this] = ACTIONS(2509),
    [anon_sym___launch_bounds__] = ACTIONS(2509),
  },
  [STATE(291)] = {
    [sym_identifier] = ACTIONS(2513),
    [aux_sym_preproc_include_token1] = ACTIONS(2513),
    [aux_sym_preproc_def_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token2] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2513),
    [aux_sym_preproc_else_token1] = ACTIONS(2513),
    [aux_sym_preproc_elif_token1] = ACTIONS(2513),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2513),
    [sym_preproc_directive] = ACTIONS(2513),
    [anon_sym_LPAREN2] = ACTIONS(2515),
    [anon_sym_BANG] = ACTIONS(2515),
    [anon_sym_TILDE] = ACTIONS(2515),
    [anon_sym_DASH] = ACTIONS(2513),
    [anon_sym_PLUS] = ACTIONS(2513),
    [anon_sym_STAR] = ACTIONS(2515),
    [anon_sym_AMP_AMP] = ACTIONS(2515),
    [anon_sym_AMP] = ACTIONS(2513),
    [anon_sym_SEMI] = ACTIONS(2515),
    [anon_sym___extension__] = ACTIONS(2513),
    [anon_sym_typedef] = ACTIONS(2513),
    [anon_sym___device__] = ACTIONS(2513),
    [anon_sym___host__] = ACTIONS(2513),
    [anon_sym___global__] = ACTIONS(2513),
    [anon_sym___forceinline__] = ACTIONS(2513),
    [anon_sym___noinline__] = ACTIONS(2513),
    [anon_sym_virtual] = ACTIONS(2513),
    [anon_sym_extern] = ACTIONS(2513),
    [anon_sym___attribute__] = ACTIONS(2513),
    [anon_sym___attribute] = ACTIONS(2513),
    [anon_sym_COLON_COLON] = ACTIONS(2515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2515),
    [anon_sym___declspec] = ACTIONS(2513),
    [anon_sym___based] = ACTIONS(2513),
    [anon_sym___cdecl] = ACTIONS(2513),
    [anon_sym___clrcall] = ACTIONS(2513),
    [anon_sym___stdcall] = ACTIONS(2513),
    [anon_sym___fastcall] = ACTIONS(2513),
    [anon_sym___thiscall] = ACTIONS(2513),
    [anon_sym___vectorcall] = ACTIONS(2513),
    [anon_sym_LBRACE] = ACTIONS(2515),
    [anon_sym_signed] = ACTIONS(2513),
    [anon_sym_unsigned] = ACTIONS(2513),
    [anon_sym_long] = ACTIONS(2513),
    [anon_sym_short] = ACTIONS(2513),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_static] = ACTIONS(2513),
    [anon_sym_register] = ACTIONS(2513),
    [anon_sym_inline] = ACTIONS(2513),
    [anon_sym___inline] = ACTIONS(2513),
    [anon_sym___inline__] = ACTIONS(2513),
    [anon_sym___forceinline] = ACTIONS(2513),
    [anon_sym_thread_local] = ACTIONS(2513),
    [anon_sym___thread] = ACTIONS(2513),
    [anon_sym_const] = ACTIONS(2513),
    [anon_sym_constexpr] = ACTIONS(2513),
    [anon_sym_volatile] = ACTIONS(2513),
    [anon_sym_restrict] = ACTIONS(2513),
    [anon_sym___restrict__] = ACTIONS(2513),
    [anon_sym__Atomic] = ACTIONS(2513),
    [anon_sym__Noreturn] = ACTIONS(2513),
    [anon_sym_noreturn] = ACTIONS(2513),
    [anon_sym__Nonnull] = ACTIONS(2513),
    [anon_sym_mutable] = ACTIONS(2513),
    [anon_sym_constinit] = ACTIONS(2513),
    [anon_sym_consteval] = ACTIONS(2513),
    [anon_sym___shared__] = ACTIONS(2513),
    [anon_sym___local__] = ACTIONS(2513),
    [anon_sym___constant__] = ACTIONS(2513),
    [anon_sym___managed__] = ACTIONS(2513),
    [anon_sym___grid_constant__] = ACTIONS(2513),
    [anon_sym_alignas] = ACTIONS(2513),
    [anon_sym__Alignas] = ACTIONS(2513),
    [sym_primitive_type] = ACTIONS(2513),
    [anon_sym_enum] = ACTIONS(2513),
    [anon_sym_class] = ACTIONS(2513),
    [anon_sym_struct] = ACTIONS(2513),
    [anon_sym_union] = ACTIONS(2513),
    [anon_sym_if] = ACTIONS(2513),
    [anon_sym_switch] = ACTIONS(2513),
    [anon_sym_case] = ACTIONS(2513),
    [anon_sym_default] = ACTIONS(2513),
    [anon_sym_while] = ACTIONS(2513),
    [anon_sym_do] = ACTIONS(2513),
    [anon_sym_for] = ACTIONS(2513),
    [anon_sym_return] = ACTIONS(2513),
    [anon_sym_break] = ACTIONS(2513),
    [anon_sym_continue] = ACTIONS(2513),
    [anon_sym_goto] = ACTIONS(2513),
    [anon_sym___try] = ACTIONS(2513),
    [anon_sym___leave] = ACTIONS(2513),
    [anon_sym_not] = ACTIONS(2513),
    [anon_sym_compl] = ACTIONS(2513),
    [anon_sym_DASH_DASH] = ACTIONS(2515),
    [anon_sym_PLUS_PLUS] = ACTIONS(2515),
    [anon_sym_sizeof] = ACTIONS(2513),
    [anon_sym___alignof__] = ACTIONS(2513),
    [anon_sym___alignof] = ACTIONS(2513),
    [anon_sym__alignof] = ACTIONS(2513),
    [anon_sym_alignof] = ACTIONS(2513),
    [anon_sym__Alignof] = ACTIONS(2513),
    [anon_sym_offsetof] = ACTIONS(2513),
    [anon_sym__Generic] = ACTIONS(2513),
    [anon_sym_asm] = ACTIONS(2513),
    [anon_sym___asm__] = ACTIONS(2513),
    [anon_sym___asm] = ACTIONS(2513),
    [sym_number_literal] = ACTIONS(2515),
    [anon_sym_L_SQUOTE] = ACTIONS(2515),
    [anon_sym_u_SQUOTE] = ACTIONS(2515),
    [anon_sym_U_SQUOTE] = ACTIONS(2515),
    [anon_sym_u8_SQUOTE] = ACTIONS(2515),
    [anon_sym_SQUOTE] = ACTIONS(2515),
    [anon_sym_L_DQUOTE] = ACTIONS(2515),
    [anon_sym_u_DQUOTE] = ACTIONS(2515),
    [anon_sym_U_DQUOTE] = ACTIONS(2515),
    [anon_sym_u8_DQUOTE] = ACTIONS(2515),
    [anon_sym_DQUOTE] = ACTIONS(2515),
    [sym_true] = ACTIONS(2513),
    [sym_false] = ACTIONS(2513),
    [anon_sym_NULL] = ACTIONS(2513),
    [anon_sym_nullptr] = ACTIONS(2513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2513),
    [anon_sym_decltype] = ACTIONS(2513),
    [anon_sym_explicit] = ACTIONS(2513),
    [anon_sym_typename] = ACTIONS(2513),
    [anon_sym_template] = ACTIONS(2513),
    [anon_sym_operator] = ACTIONS(2513),
    [anon_sym_try] = ACTIONS(2513),
    [anon_sym_delete] = ACTIONS(2513),
    [anon_sym_throw] = ACTIONS(2513),
    [anon_sym_namespace] = ACTIONS(2513),
    [anon_sym_using] = ACTIONS(2513),
    [anon_sym_static_assert] = ACTIONS(2513),
    [anon_sym_concept] = ACTIONS(2513),
    [anon_sym_co_return] = ACTIONS(2513),
    [anon_sym_co_yield] = ACTIONS(2513),
    [anon_sym_R_DQUOTE] = ACTIONS(2515),
    [anon_sym_LR_DQUOTE] = ACTIONS(2515),
    [anon_sym_uR_DQUOTE] = ACTIONS(2515),
    [anon_sym_UR_DQUOTE] = ACTIONS(2515),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2515),
    [anon_sym_co_await] = ACTIONS(2513),
    [anon_sym_new] = ACTIONS(2513),
    [anon_sym_requires] = ACTIONS(2513),
    [sym_this] = ACTIONS(2513),
    [anon_sym___launch_bounds__] = ACTIONS(2513),
  },
  [STATE(292)] = {
    [sym_identifier] = ACTIONS(2517),
    [aux_sym_preproc_include_token1] = ACTIONS(2517),
    [aux_sym_preproc_def_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token2] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2517),
    [aux_sym_preproc_else_token1] = ACTIONS(2517),
    [aux_sym_preproc_elif_token1] = ACTIONS(2517),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2517),
    [sym_preproc_directive] = ACTIONS(2517),
    [anon_sym_LPAREN2] = ACTIONS(2519),
    [anon_sym_BANG] = ACTIONS(2519),
    [anon_sym_TILDE] = ACTIONS(2519),
    [anon_sym_DASH] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2519),
    [anon_sym_AMP_AMP] = ACTIONS(2519),
    [anon_sym_AMP] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym___extension__] = ACTIONS(2517),
    [anon_sym_typedef] = ACTIONS(2517),
    [anon_sym___device__] = ACTIONS(2517),
    [anon_sym___host__] = ACTIONS(2517),
    [anon_sym___global__] = ACTIONS(2517),
    [anon_sym___forceinline__] = ACTIONS(2517),
    [anon_sym___noinline__] = ACTIONS(2517),
    [anon_sym_virtual] = ACTIONS(2517),
    [anon_sym_extern] = ACTIONS(2517),
    [anon_sym___attribute__] = ACTIONS(2517),
    [anon_sym___attribute] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2519),
    [anon_sym___declspec] = ACTIONS(2517),
    [anon_sym___based] = ACTIONS(2517),
    [anon_sym___cdecl] = ACTIONS(2517),
    [anon_sym___clrcall] = ACTIONS(2517),
    [anon_sym___stdcall] = ACTIONS(2517),
    [anon_sym___fastcall] = ACTIONS(2517),
    [anon_sym___thiscall] = ACTIONS(2517),
    [anon_sym___vectorcall] = ACTIONS(2517),
    [anon_sym_LBRACE] = ACTIONS(2519),
    [anon_sym_signed] = ACTIONS(2517),
    [anon_sym_unsigned] = ACTIONS(2517),
    [anon_sym_long] = ACTIONS(2517),
    [anon_sym_short] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2517),
    [anon_sym_static] = ACTIONS(2517),
    [anon_sym_register] = ACTIONS(2517),
    [anon_sym_inline] = ACTIONS(2517),
    [anon_sym___inline] = ACTIONS(2517),
    [anon_sym___inline__] = ACTIONS(2517),
    [anon_sym___forceinline] = ACTIONS(2517),
    [anon_sym_thread_local] = ACTIONS(2517),
    [anon_sym___thread] = ACTIONS(2517),
    [anon_sym_const] = ACTIONS(2517),
    [anon_sym_constexpr] = ACTIONS(2517),
    [anon_sym_volatile] = ACTIONS(2517),
    [anon_sym_restrict] = ACTIONS(2517),
    [anon_sym___restrict__] = ACTIONS(2517),
    [anon_sym__Atomic] = ACTIONS(2517),
    [anon_sym__Noreturn] = ACTIONS(2517),
    [anon_sym_noreturn] = ACTIONS(2517),
    [anon_sym__Nonnull] = ACTIONS(2517),
    [anon_sym_mutable] = ACTIONS(2517),
    [anon_sym_constinit] = ACTIONS(2517),
    [anon_sym_consteval] = ACTIONS(2517),
    [anon_sym___shared__] = ACTIONS(2517),
    [anon_sym___local__] = ACTIONS(2517),
    [anon_sym___constant__] = ACTIONS(2517),
    [anon_sym___managed__] = ACTIONS(2517),
    [anon_sym___grid_constant__] = ACTIONS(2517),
    [anon_sym_alignas] = ACTIONS(2517),
    [anon_sym__Alignas] = ACTIONS(2517),
    [sym_primitive_type] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_class] = ACTIONS(2517),
    [anon_sym_struct] = ACTIONS(2517),
    [anon_sym_union] = ACTIONS(2517),
    [anon_sym_if] = ACTIONS(2517),
    [anon_sym_switch] = ACTIONS(2517),
    [anon_sym_case] = ACTIONS(2517),
    [anon_sym_default] = ACTIONS(2517),
    [anon_sym_while] = ACTIONS(2517),
    [anon_sym_do] = ACTIONS(2517),
    [anon_sym_for] = ACTIONS(2517),
    [anon_sym_return] = ACTIONS(2517),
    [anon_sym_break] = ACTIONS(2517),
    [anon_sym_continue] = ACTIONS(2517),
    [anon_sym_goto] = ACTIONS(2517),
    [anon_sym___try] = ACTIONS(2517),
    [anon_sym___leave] = ACTIONS(2517),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_compl] = ACTIONS(2517),
    [anon_sym_DASH_DASH] = ACTIONS(2519),
    [anon_sym_PLUS_PLUS] = ACTIONS(2519),
    [anon_sym_sizeof] = ACTIONS(2517),
    [anon_sym___alignof__] = ACTIONS(2517),
    [anon_sym___alignof] = ACTIONS(2517),
    [anon_sym__alignof] = ACTIONS(2517),
    [anon_sym_alignof] = ACTIONS(2517),
    [anon_sym__Alignof] = ACTIONS(2517),
    [anon_sym_offsetof] = ACTIONS(2517),
    [anon_sym__Generic] = ACTIONS(2517),
    [anon_sym_asm] = ACTIONS(2517),
    [anon_sym___asm__] = ACTIONS(2517),
    [anon_sym___asm] = ACTIONS(2517),
    [sym_number_literal] = ACTIONS(2519),
    [anon_sym_L_SQUOTE] = ACTIONS(2519),
    [anon_sym_u_SQUOTE] = ACTIONS(2519),
    [anon_sym_U_SQUOTE] = ACTIONS(2519),
    [anon_sym_u8_SQUOTE] = ACTIONS(2519),
    [anon_sym_SQUOTE] = ACTIONS(2519),
    [anon_sym_L_DQUOTE] = ACTIONS(2519),
    [anon_sym_u_DQUOTE] = ACTIONS(2519),
    [anon_sym_U_DQUOTE] = ACTIONS(2519),
    [anon_sym_u8_DQUOTE] = ACTIONS(2519),
    [anon_sym_DQUOTE] = ACTIONS(2519),
    [sym_true] = ACTIONS(2517),
    [sym_false] = ACTIONS(2517),
    [anon_sym_NULL] = ACTIONS(2517),
    [anon_sym_nullptr] = ACTIONS(2517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2517),
    [anon_sym_decltype] = ACTIONS(2517),
    [anon_sym_explicit] = ACTIONS(2517),
    [anon_sym_typename] = ACTIONS(2517),
    [anon_sym_template] = ACTIONS(2517),
    [anon_sym_operator] = ACTIONS(2517),
    [anon_sym_try] = ACTIONS(2517),
    [anon_sym_delete] = ACTIONS(2517),
    [anon_sym_throw] = ACTIONS(2517),
    [anon_sym_namespace] = ACTIONS(2517),
    [anon_sym_using] = ACTIONS(2517),
    [anon_sym_static_assert] = ACTIONS(2517),
    [anon_sym_concept] = ACTIONS(2517),
    [anon_sym_co_return] = ACTIONS(2517),
    [anon_sym_co_yield] = ACTIONS(2517),
    [anon_sym_R_DQUOTE] = ACTIONS(2519),
    [anon_sym_LR_DQUOTE] = ACTIONS(2519),
    [anon_sym_uR_DQUOTE] = ACTIONS(2519),
    [anon_sym_UR_DQUOTE] = ACTIONS(2519),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2519),
    [anon_sym_co_await] = ACTIONS(2517),
    [anon_sym_new] = ACTIONS(2517),
    [anon_sym_requires] = ACTIONS(2517),
    [sym_this] = ACTIONS(2517),
    [anon_sym___launch_bounds__] = ACTIONS(2517),
  },
  [STATE(293)] = {
    [sym_identifier] = ACTIONS(2521),
    [aux_sym_preproc_include_token1] = ACTIONS(2521),
    [aux_sym_preproc_def_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token2] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2521),
    [aux_sym_preproc_else_token1] = ACTIONS(2521),
    [aux_sym_preproc_elif_token1] = ACTIONS(2521),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2521),
    [sym_preproc_directive] = ACTIONS(2521),
    [anon_sym_LPAREN2] = ACTIONS(2523),
    [anon_sym_BANG] = ACTIONS(2523),
    [anon_sym_TILDE] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2523),
    [anon_sym_AMP_AMP] = ACTIONS(2523),
    [anon_sym_AMP] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym___extension__] = ACTIONS(2521),
    [anon_sym_typedef] = ACTIONS(2521),
    [anon_sym___device__] = ACTIONS(2521),
    [anon_sym___host__] = ACTIONS(2521),
    [anon_sym___global__] = ACTIONS(2521),
    [anon_sym___forceinline__] = ACTIONS(2521),
    [anon_sym___noinline__] = ACTIONS(2521),
    [anon_sym_virtual] = ACTIONS(2521),
    [anon_sym_extern] = ACTIONS(2521),
    [anon_sym___attribute__] = ACTIONS(2521),
    [anon_sym___attribute] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2523),
    [anon_sym___declspec] = ACTIONS(2521),
    [anon_sym___based] = ACTIONS(2521),
    [anon_sym___cdecl] = ACTIONS(2521),
    [anon_sym___clrcall] = ACTIONS(2521),
    [anon_sym___stdcall] = ACTIONS(2521),
    [anon_sym___fastcall] = ACTIONS(2521),
    [anon_sym___thiscall] = ACTIONS(2521),
    [anon_sym___vectorcall] = ACTIONS(2521),
    [anon_sym_LBRACE] = ACTIONS(2523),
    [anon_sym_signed] = ACTIONS(2521),
    [anon_sym_unsigned] = ACTIONS(2521),
    [anon_sym_long] = ACTIONS(2521),
    [anon_sym_short] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2521),
    [anon_sym_static] = ACTIONS(2521),
    [anon_sym_register] = ACTIONS(2521),
    [anon_sym_inline] = ACTIONS(2521),
    [anon_sym___inline] = ACTIONS(2521),
    [anon_sym___inline__] = ACTIONS(2521),
    [anon_sym___forceinline] = ACTIONS(2521),
    [anon_sym_thread_local] = ACTIONS(2521),
    [anon_sym___thread] = ACTIONS(2521),
    [anon_sym_const] = ACTIONS(2521),
    [anon_sym_constexpr] = ACTIONS(2521),
    [anon_sym_volatile] = ACTIONS(2521),
    [anon_sym_restrict] = ACTIONS(2521),
    [anon_sym___restrict__] = ACTIONS(2521),
    [anon_sym__Atomic] = ACTIONS(2521),
    [anon_sym__Noreturn] = ACTIONS(2521),
    [anon_sym_noreturn] = ACTIONS(2521),
    [anon_sym__Nonnull] = ACTIONS(2521),
    [anon_sym_mutable] = ACTIONS(2521),
    [anon_sym_constinit] = ACTIONS(2521),
    [anon_sym_consteval] = ACTIONS(2521),
    [anon_sym___shared__] = ACTIONS(2521),
    [anon_sym___local__] = ACTIONS(2521),
    [anon_sym___constant__] = ACTIONS(2521),
    [anon_sym___managed__] = ACTIONS(2521),
    [anon_sym___grid_constant__] = ACTIONS(2521),
    [anon_sym_alignas] = ACTIONS(2521),
    [anon_sym__Alignas] = ACTIONS(2521),
    [sym_primitive_type] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_class] = ACTIONS(2521),
    [anon_sym_struct] = ACTIONS(2521),
    [anon_sym_union] = ACTIONS(2521),
    [anon_sym_if] = ACTIONS(2521),
    [anon_sym_switch] = ACTIONS(2521),
    [anon_sym_case] = ACTIONS(2521),
    [anon_sym_default] = ACTIONS(2521),
    [anon_sym_while] = ACTIONS(2521),
    [anon_sym_do] = ACTIONS(2521),
    [anon_sym_for] = ACTIONS(2521),
    [anon_sym_return] = ACTIONS(2521),
    [anon_sym_break] = ACTIONS(2521),
    [anon_sym_continue] = ACTIONS(2521),
    [anon_sym_goto] = ACTIONS(2521),
    [anon_sym___try] = ACTIONS(2521),
    [anon_sym___leave] = ACTIONS(2521),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_compl] = ACTIONS(2521),
    [anon_sym_DASH_DASH] = ACTIONS(2523),
    [anon_sym_PLUS_PLUS] = ACTIONS(2523),
    [anon_sym_sizeof] = ACTIONS(2521),
    [anon_sym___alignof__] = ACTIONS(2521),
    [anon_sym___alignof] = ACTIONS(2521),
    [anon_sym__alignof] = ACTIONS(2521),
    [anon_sym_alignof] = ACTIONS(2521),
    [anon_sym__Alignof] = ACTIONS(2521),
    [anon_sym_offsetof] = ACTIONS(2521),
    [anon_sym__Generic] = ACTIONS(2521),
    [anon_sym_asm] = ACTIONS(2521),
    [anon_sym___asm__] = ACTIONS(2521),
    [anon_sym___asm] = ACTIONS(2521),
    [sym_number_literal] = ACTIONS(2523),
    [anon_sym_L_SQUOTE] = ACTIONS(2523),
    [anon_sym_u_SQUOTE] = ACTIONS(2523),
    [anon_sym_U_SQUOTE] = ACTIONS(2523),
    [anon_sym_u8_SQUOTE] = ACTIONS(2523),
    [anon_sym_SQUOTE] = ACTIONS(2523),
    [anon_sym_L_DQUOTE] = ACTIONS(2523),
    [anon_sym_u_DQUOTE] = ACTIONS(2523),
    [anon_sym_U_DQUOTE] = ACTIONS(2523),
    [anon_sym_u8_DQUOTE] = ACTIONS(2523),
    [anon_sym_DQUOTE] = ACTIONS(2523),
    [sym_true] = ACTIONS(2521),
    [sym_false] = ACTIONS(2521),
    [anon_sym_NULL] = ACTIONS(2521),
    [anon_sym_nullptr] = ACTIONS(2521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2521),
    [anon_sym_decltype] = ACTIONS(2521),
    [anon_sym_explicit] = ACTIONS(2521),
    [anon_sym_typename] = ACTIONS(2521),
    [anon_sym_template] = ACTIONS(2521),
    [anon_sym_operator] = ACTIONS(2521),
    [anon_sym_try] = ACTIONS(2521),
    [anon_sym_delete] = ACTIONS(2521),
    [anon_sym_throw] = ACTIONS(2521),
    [anon_sym_namespace] = ACTIONS(2521),
    [anon_sym_using] = ACTIONS(2521),
    [anon_sym_static_assert] = ACTIONS(2521),
    [anon_sym_concept] = ACTIONS(2521),
    [anon_sym_co_return] = ACTIONS(2521),
    [anon_sym_co_yield] = ACTIONS(2521),
    [anon_sym_R_DQUOTE] = ACTIONS(2523),
    [anon_sym_LR_DQUOTE] = ACTIONS(2523),
    [anon_sym_uR_DQUOTE] = ACTIONS(2523),
    [anon_sym_UR_DQUOTE] = ACTIONS(2523),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2523),
    [anon_sym_co_await] = ACTIONS(2521),
    [anon_sym_new] = ACTIONS(2521),
    [anon_sym_requires] = ACTIONS(2521),
    [sym_this] = ACTIONS(2521),
    [anon_sym___launch_bounds__] = ACTIONS(2521),
  },
  [STATE(294)] = {
    [sym_identifier] = ACTIONS(2525),
    [aux_sym_preproc_include_token1] = ACTIONS(2525),
    [aux_sym_preproc_def_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token2] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2525),
    [aux_sym_preproc_else_token1] = ACTIONS(2525),
    [aux_sym_preproc_elif_token1] = ACTIONS(2525),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2525),
    [sym_preproc_directive] = ACTIONS(2525),
    [anon_sym_LPAREN2] = ACTIONS(2527),
    [anon_sym_BANG] = ACTIONS(2527),
    [anon_sym_TILDE] = ACTIONS(2527),
    [anon_sym_DASH] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2527),
    [anon_sym_AMP_AMP] = ACTIONS(2527),
    [anon_sym_AMP] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym___extension__] = ACTIONS(2525),
    [anon_sym_typedef] = ACTIONS(2525),
    [anon_sym___device__] = ACTIONS(2525),
    [anon_sym___host__] = ACTIONS(2525),
    [anon_sym___global__] = ACTIONS(2525),
    [anon_sym___forceinline__] = ACTIONS(2525),
    [anon_sym___noinline__] = ACTIONS(2525),
    [anon_sym_virtual] = ACTIONS(2525),
    [anon_sym_extern] = ACTIONS(2525),
    [anon_sym___attribute__] = ACTIONS(2525),
    [anon_sym___attribute] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2527),
    [anon_sym___declspec] = ACTIONS(2525),
    [anon_sym___based] = ACTIONS(2525),
    [anon_sym___cdecl] = ACTIONS(2525),
    [anon_sym___clrcall] = ACTIONS(2525),
    [anon_sym___stdcall] = ACTIONS(2525),
    [anon_sym___fastcall] = ACTIONS(2525),
    [anon_sym___thiscall] = ACTIONS(2525),
    [anon_sym___vectorcall] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_signed] = ACTIONS(2525),
    [anon_sym_unsigned] = ACTIONS(2525),
    [anon_sym_long] = ACTIONS(2525),
    [anon_sym_short] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2525),
    [anon_sym_static] = ACTIONS(2525),
    [anon_sym_register] = ACTIONS(2525),
    [anon_sym_inline] = ACTIONS(2525),
    [anon_sym___inline] = ACTIONS(2525),
    [anon_sym___inline__] = ACTIONS(2525),
    [anon_sym___forceinline] = ACTIONS(2525),
    [anon_sym_thread_local] = ACTIONS(2525),
    [anon_sym___thread] = ACTIONS(2525),
    [anon_sym_const] = ACTIONS(2525),
    [anon_sym_constexpr] = ACTIONS(2525),
    [anon_sym_volatile] = ACTIONS(2525),
    [anon_sym_restrict] = ACTIONS(2525),
    [anon_sym___restrict__] = ACTIONS(2525),
    [anon_sym__Atomic] = ACTIONS(2525),
    [anon_sym__Noreturn] = ACTIONS(2525),
    [anon_sym_noreturn] = ACTIONS(2525),
    [anon_sym__Nonnull] = ACTIONS(2525),
    [anon_sym_mutable] = ACTIONS(2525),
    [anon_sym_constinit] = ACTIONS(2525),
    [anon_sym_consteval] = ACTIONS(2525),
    [anon_sym___shared__] = ACTIONS(2525),
    [anon_sym___local__] = ACTIONS(2525),
    [anon_sym___constant__] = ACTIONS(2525),
    [anon_sym___managed__] = ACTIONS(2525),
    [anon_sym___grid_constant__] = ACTIONS(2525),
    [anon_sym_alignas] = ACTIONS(2525),
    [anon_sym__Alignas] = ACTIONS(2525),
    [sym_primitive_type] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_class] = ACTIONS(2525),
    [anon_sym_struct] = ACTIONS(2525),
    [anon_sym_union] = ACTIONS(2525),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_switch] = ACTIONS(2525),
    [anon_sym_case] = ACTIONS(2525),
    [anon_sym_default] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(2525),
    [anon_sym_do] = ACTIONS(2525),
    [anon_sym_for] = ACTIONS(2525),
    [anon_sym_return] = ACTIONS(2525),
    [anon_sym_break] = ACTIONS(2525),
    [anon_sym_continue] = ACTIONS(2525),
    [anon_sym_goto] = ACTIONS(2525),
    [anon_sym___try] = ACTIONS(2525),
    [anon_sym___leave] = ACTIONS(2525),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_compl] = ACTIONS(2525),
    [anon_sym_DASH_DASH] = ACTIONS(2527),
    [anon_sym_PLUS_PLUS] = ACTIONS(2527),
    [anon_sym_sizeof] = ACTIONS(2525),
    [anon_sym___alignof__] = ACTIONS(2525),
    [anon_sym___alignof] = ACTIONS(2525),
    [anon_sym__alignof] = ACTIONS(2525),
    [anon_sym_alignof] = ACTIONS(2525),
    [anon_sym__Alignof] = ACTIONS(2525),
    [anon_sym_offsetof] = ACTIONS(2525),
    [anon_sym__Generic] = ACTIONS(2525),
    [anon_sym_asm] = ACTIONS(2525),
    [anon_sym___asm__] = ACTIONS(2525),
    [anon_sym___asm] = ACTIONS(2525),
    [sym_number_literal] = ACTIONS(2527),
    [anon_sym_L_SQUOTE] = ACTIONS(2527),
    [anon_sym_u_SQUOTE] = ACTIONS(2527),
    [anon_sym_U_SQUOTE] = ACTIONS(2527),
    [anon_sym_u8_SQUOTE] = ACTIONS(2527),
    [anon_sym_SQUOTE] = ACTIONS(2527),
    [anon_sym_L_DQUOTE] = ACTIONS(2527),
    [anon_sym_u_DQUOTE] = ACTIONS(2527),
    [anon_sym_U_DQUOTE] = ACTIONS(2527),
    [anon_sym_u8_DQUOTE] = ACTIONS(2527),
    [anon_sym_DQUOTE] = ACTIONS(2527),
    [sym_true] = ACTIONS(2525),
    [sym_false] = ACTIONS(2525),
    [anon_sym_NULL] = ACTIONS(2525),
    [anon_sym_nullptr] = ACTIONS(2525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2525),
    [anon_sym_decltype] = ACTIONS(2525),
    [anon_sym_explicit] = ACTIONS(2525),
    [anon_sym_typename] = ACTIONS(2525),
    [anon_sym_template] = ACTIONS(2525),
    [anon_sym_operator] = ACTIONS(2525),
    [anon_sym_try] = ACTIONS(2525),
    [anon_sym_delete] = ACTIONS(2525),
    [anon_sym_throw] = ACTIONS(2525),
    [anon_sym_namespace] = ACTIONS(2525),
    [anon_sym_using] = ACTIONS(2525),
    [anon_sym_static_assert] = ACTIONS(2525),
    [anon_sym_concept] = ACTIONS(2525),
    [anon_sym_co_return] = ACTIONS(2525),
    [anon_sym_co_yield] = ACTIONS(2525),
    [anon_sym_R_DQUOTE] = ACTIONS(2527),
    [anon_sym_LR_DQUOTE] = ACTIONS(2527),
    [anon_sym_uR_DQUOTE] = ACTIONS(2527),
    [anon_sym_UR_DQUOTE] = ACTIONS(2527),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2527),
    [anon_sym_co_await] = ACTIONS(2525),
    [anon_sym_new] = ACTIONS(2525),
    [anon_sym_requires] = ACTIONS(2525),
    [sym_this] = ACTIONS(2525),
    [anon_sym___launch_bounds__] = ACTIONS(2525),
  },
  [STATE(295)] = {
    [sym_identifier] = ACTIONS(2529),
    [aux_sym_preproc_include_token1] = ACTIONS(2529),
    [aux_sym_preproc_def_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token2] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2529),
    [aux_sym_preproc_else_token1] = ACTIONS(2529),
    [aux_sym_preproc_elif_token1] = ACTIONS(2529),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2529),
    [sym_preproc_directive] = ACTIONS(2529),
    [anon_sym_LPAREN2] = ACTIONS(2531),
    [anon_sym_BANG] = ACTIONS(2531),
    [anon_sym_TILDE] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2531),
    [anon_sym_AMP_AMP] = ACTIONS(2531),
    [anon_sym_AMP] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym___extension__] = ACTIONS(2529),
    [anon_sym_typedef] = ACTIONS(2529),
    [anon_sym___device__] = ACTIONS(2529),
    [anon_sym___host__] = ACTIONS(2529),
    [anon_sym___global__] = ACTIONS(2529),
    [anon_sym___forceinline__] = ACTIONS(2529),
    [anon_sym___noinline__] = ACTIONS(2529),
    [anon_sym_virtual] = ACTIONS(2529),
    [anon_sym_extern] = ACTIONS(2529),
    [anon_sym___attribute__] = ACTIONS(2529),
    [anon_sym___attribute] = ACTIONS(2529),
    [anon_sym_COLON_COLON] = ACTIONS(2531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2531),
    [anon_sym___declspec] = ACTIONS(2529),
    [anon_sym___based] = ACTIONS(2529),
    [anon_sym___cdecl] = ACTIONS(2529),
    [anon_sym___clrcall] = ACTIONS(2529),
    [anon_sym___stdcall] = ACTIONS(2529),
    [anon_sym___fastcall] = ACTIONS(2529),
    [anon_sym___thiscall] = ACTIONS(2529),
    [anon_sym___vectorcall] = ACTIONS(2529),
    [anon_sym_LBRACE] = ACTIONS(2531),
    [anon_sym_signed] = ACTIONS(2529),
    [anon_sym_unsigned] = ACTIONS(2529),
    [anon_sym_long] = ACTIONS(2529),
    [anon_sym_short] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2529),
    [anon_sym_register] = ACTIONS(2529),
    [anon_sym_inline] = ACTIONS(2529),
    [anon_sym___inline] = ACTIONS(2529),
    [anon_sym___inline__] = ACTIONS(2529),
    [anon_sym___forceinline] = ACTIONS(2529),
    [anon_sym_thread_local] = ACTIONS(2529),
    [anon_sym___thread] = ACTIONS(2529),
    [anon_sym_const] = ACTIONS(2529),
    [anon_sym_constexpr] = ACTIONS(2529),
    [anon_sym_volatile] = ACTIONS(2529),
    [anon_sym_restrict] = ACTIONS(2529),
    [anon_sym___restrict__] = ACTIONS(2529),
    [anon_sym__Atomic] = ACTIONS(2529),
    [anon_sym__Noreturn] = ACTIONS(2529),
    [anon_sym_noreturn] = ACTIONS(2529),
    [anon_sym__Nonnull] = ACTIONS(2529),
    [anon_sym_mutable] = ACTIONS(2529),
    [anon_sym_constinit] = ACTIONS(2529),
    [anon_sym_consteval] = ACTIONS(2529),
    [anon_sym___shared__] = ACTIONS(2529),
    [anon_sym___local__] = ACTIONS(2529),
    [anon_sym___constant__] = ACTIONS(2529),
    [anon_sym___managed__] = ACTIONS(2529),
    [anon_sym___grid_constant__] = ACTIONS(2529),
    [anon_sym_alignas] = ACTIONS(2529),
    [anon_sym__Alignas] = ACTIONS(2529),
    [sym_primitive_type] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2529),
    [anon_sym_struct] = ACTIONS(2529),
    [anon_sym_union] = ACTIONS(2529),
    [anon_sym_if] = ACTIONS(2529),
    [anon_sym_switch] = ACTIONS(2529),
    [anon_sym_case] = ACTIONS(2529),
    [anon_sym_default] = ACTIONS(2529),
    [anon_sym_while] = ACTIONS(2529),
    [anon_sym_do] = ACTIONS(2529),
    [anon_sym_for] = ACTIONS(2529),
    [anon_sym_return] = ACTIONS(2529),
    [anon_sym_break] = ACTIONS(2529),
    [anon_sym_continue] = ACTIONS(2529),
    [anon_sym_goto] = ACTIONS(2529),
    [anon_sym___try] = ACTIONS(2529),
    [anon_sym___leave] = ACTIONS(2529),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_compl] = ACTIONS(2529),
    [anon_sym_DASH_DASH] = ACTIONS(2531),
    [anon_sym_PLUS_PLUS] = ACTIONS(2531),
    [anon_sym_sizeof] = ACTIONS(2529),
    [anon_sym___alignof__] = ACTIONS(2529),
    [anon_sym___alignof] = ACTIONS(2529),
    [anon_sym__alignof] = ACTIONS(2529),
    [anon_sym_alignof] = ACTIONS(2529),
    [anon_sym__Alignof] = ACTIONS(2529),
    [anon_sym_offsetof] = ACTIONS(2529),
    [anon_sym__Generic] = ACTIONS(2529),
    [anon_sym_asm] = ACTIONS(2529),
    [anon_sym___asm__] = ACTIONS(2529),
    [anon_sym___asm] = ACTIONS(2529),
    [sym_number_literal] = ACTIONS(2531),
    [anon_sym_L_SQUOTE] = ACTIONS(2531),
    [anon_sym_u_SQUOTE] = ACTIONS(2531),
    [anon_sym_U_SQUOTE] = ACTIONS(2531),
    [anon_sym_u8_SQUOTE] = ACTIONS(2531),
    [anon_sym_SQUOTE] = ACTIONS(2531),
    [anon_sym_L_DQUOTE] = ACTIONS(2531),
    [anon_sym_u_DQUOTE] = ACTIONS(2531),
    [anon_sym_U_DQUOTE] = ACTIONS(2531),
    [anon_sym_u8_DQUOTE] = ACTIONS(2531),
    [anon_sym_DQUOTE] = ACTIONS(2531),
    [sym_true] = ACTIONS(2529),
    [sym_false] = ACTIONS(2529),
    [anon_sym_NULL] = ACTIONS(2529),
    [anon_sym_nullptr] = ACTIONS(2529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2529),
    [anon_sym_decltype] = ACTIONS(2529),
    [anon_sym_explicit] = ACTIONS(2529),
    [anon_sym_typename] = ACTIONS(2529),
    [anon_sym_template] = ACTIONS(2529),
    [anon_sym_operator] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2529),
    [anon_sym_delete] = ACTIONS(2529),
    [anon_sym_throw] = ACTIONS(2529),
    [anon_sym_namespace] = ACTIONS(2529),
    [anon_sym_using] = ACTIONS(2529),
    [anon_sym_static_assert] = ACTIONS(2529),
    [anon_sym_concept] = ACTIONS(2529),
    [anon_sym_co_return] = ACTIONS(2529),
    [anon_sym_co_yield] = ACTIONS(2529),
    [anon_sym_R_DQUOTE] = ACTIONS(2531),
    [anon_sym_LR_DQUOTE] = ACTIONS(2531),
    [anon_sym_uR_DQUOTE] = ACTIONS(2531),
    [anon_sym_UR_DQUOTE] = ACTIONS(2531),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2531),
    [anon_sym_co_await] = ACTIONS(2529),
    [anon_sym_new] = ACTIONS(2529),
    [anon_sym_requires] = ACTIONS(2529),
    [sym_this] = ACTIONS(2529),
    [anon_sym___launch_bounds__] = ACTIONS(2529),
  },
  [STATE(296)] = {
    [sym_identifier] = ACTIONS(2533),
    [aux_sym_preproc_include_token1] = ACTIONS(2533),
    [aux_sym_preproc_def_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token2] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2533),
    [aux_sym_preproc_else_token1] = ACTIONS(2533),
    [aux_sym_preproc_elif_token1] = ACTIONS(2533),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2533),
    [sym_preproc_directive] = ACTIONS(2533),
    [anon_sym_LPAREN2] = ACTIONS(2535),
    [anon_sym_BANG] = ACTIONS(2535),
    [anon_sym_TILDE] = ACTIONS(2535),
    [anon_sym_DASH] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2535),
    [anon_sym_AMP_AMP] = ACTIONS(2535),
    [anon_sym_AMP] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym___extension__] = ACTIONS(2533),
    [anon_sym_typedef] = ACTIONS(2533),
    [anon_sym___device__] = ACTIONS(2533),
    [anon_sym___host__] = ACTIONS(2533),
    [anon_sym___global__] = ACTIONS(2533),
    [anon_sym___forceinline__] = ACTIONS(2533),
    [anon_sym___noinline__] = ACTIONS(2533),
    [anon_sym_virtual] = ACTIONS(2533),
    [anon_sym_extern] = ACTIONS(2533),
    [anon_sym___attribute__] = ACTIONS(2533),
    [anon_sym___attribute] = ACTIONS(2533),
    [anon_sym_COLON_COLON] = ACTIONS(2535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2535),
    [anon_sym___declspec] = ACTIONS(2533),
    [anon_sym___based] = ACTIONS(2533),
    [anon_sym___cdecl] = ACTIONS(2533),
    [anon_sym___clrcall] = ACTIONS(2533),
    [anon_sym___stdcall] = ACTIONS(2533),
    [anon_sym___fastcall] = ACTIONS(2533),
    [anon_sym___thiscall] = ACTIONS(2533),
    [anon_sym___vectorcall] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2535),
    [anon_sym_signed] = ACTIONS(2533),
    [anon_sym_unsigned] = ACTIONS(2533),
    [anon_sym_long] = ACTIONS(2533),
    [anon_sym_short] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2533),
    [anon_sym_static] = ACTIONS(2533),
    [anon_sym_register] = ACTIONS(2533),
    [anon_sym_inline] = ACTIONS(2533),
    [anon_sym___inline] = ACTIONS(2533),
    [anon_sym___inline__] = ACTIONS(2533),
    [anon_sym___forceinline] = ACTIONS(2533),
    [anon_sym_thread_local] = ACTIONS(2533),
    [anon_sym___thread] = ACTIONS(2533),
    [anon_sym_const] = ACTIONS(2533),
    [anon_sym_constexpr] = ACTIONS(2533),
    [anon_sym_volatile] = ACTIONS(2533),
    [anon_sym_restrict] = ACTIONS(2533),
    [anon_sym___restrict__] = ACTIONS(2533),
    [anon_sym__Atomic] = ACTIONS(2533),
    [anon_sym__Noreturn] = ACTIONS(2533),
    [anon_sym_noreturn] = ACTIONS(2533),
    [anon_sym__Nonnull] = ACTIONS(2533),
    [anon_sym_mutable] = ACTIONS(2533),
    [anon_sym_constinit] = ACTIONS(2533),
    [anon_sym_consteval] = ACTIONS(2533),
    [anon_sym___shared__] = ACTIONS(2533),
    [anon_sym___local__] = ACTIONS(2533),
    [anon_sym___constant__] = ACTIONS(2533),
    [anon_sym___managed__] = ACTIONS(2533),
    [anon_sym___grid_constant__] = ACTIONS(2533),
    [anon_sym_alignas] = ACTIONS(2533),
    [anon_sym__Alignas] = ACTIONS(2533),
    [sym_primitive_type] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_class] = ACTIONS(2533),
    [anon_sym_struct] = ACTIONS(2533),
    [anon_sym_union] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2533),
    [anon_sym_switch] = ACTIONS(2533),
    [anon_sym_case] = ACTIONS(2533),
    [anon_sym_default] = ACTIONS(2533),
    [anon_sym_while] = ACTIONS(2533),
    [anon_sym_do] = ACTIONS(2533),
    [anon_sym_for] = ACTIONS(2533),
    [anon_sym_return] = ACTIONS(2533),
    [anon_sym_break] = ACTIONS(2533),
    [anon_sym_continue] = ACTIONS(2533),
    [anon_sym_goto] = ACTIONS(2533),
    [anon_sym___try] = ACTIONS(2533),
    [anon_sym___leave] = ACTIONS(2533),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_compl] = ACTIONS(2533),
    [anon_sym_DASH_DASH] = ACTIONS(2535),
    [anon_sym_PLUS_PLUS] = ACTIONS(2535),
    [anon_sym_sizeof] = ACTIONS(2533),
    [anon_sym___alignof__] = ACTIONS(2533),
    [anon_sym___alignof] = ACTIONS(2533),
    [anon_sym__alignof] = ACTIONS(2533),
    [anon_sym_alignof] = ACTIONS(2533),
    [anon_sym__Alignof] = ACTIONS(2533),
    [anon_sym_offsetof] = ACTIONS(2533),
    [anon_sym__Generic] = ACTIONS(2533),
    [anon_sym_asm] = ACTIONS(2533),
    [anon_sym___asm__] = ACTIONS(2533),
    [anon_sym___asm] = ACTIONS(2533),
    [sym_number_literal] = ACTIONS(2535),
    [anon_sym_L_SQUOTE] = ACTIONS(2535),
    [anon_sym_u_SQUOTE] = ACTIONS(2535),
    [anon_sym_U_SQUOTE] = ACTIONS(2535),
    [anon_sym_u8_SQUOTE] = ACTIONS(2535),
    [anon_sym_SQUOTE] = ACTIONS(2535),
    [anon_sym_L_DQUOTE] = ACTIONS(2535),
    [anon_sym_u_DQUOTE] = ACTIONS(2535),
    [anon_sym_U_DQUOTE] = ACTIONS(2535),
    [anon_sym_u8_DQUOTE] = ACTIONS(2535),
    [anon_sym_DQUOTE] = ACTIONS(2535),
    [sym_true] = ACTIONS(2533),
    [sym_false] = ACTIONS(2533),
    [anon_sym_NULL] = ACTIONS(2533),
    [anon_sym_nullptr] = ACTIONS(2533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2533),
    [anon_sym_decltype] = ACTIONS(2533),
    [anon_sym_explicit] = ACTIONS(2533),
    [anon_sym_typename] = ACTIONS(2533),
    [anon_sym_template] = ACTIONS(2533),
    [anon_sym_operator] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2533),
    [anon_sym_delete] = ACTIONS(2533),
    [anon_sym_throw] = ACTIONS(2533),
    [anon_sym_namespace] = ACTIONS(2533),
    [anon_sym_using] = ACTIONS(2533),
    [anon_sym_static_assert] = ACTIONS(2533),
    [anon_sym_concept] = ACTIONS(2533),
    [anon_sym_co_return] = ACTIONS(2533),
    [anon_sym_co_yield] = ACTIONS(2533),
    [anon_sym_R_DQUOTE] = ACTIONS(2535),
    [anon_sym_LR_DQUOTE] = ACTIONS(2535),
    [anon_sym_uR_DQUOTE] = ACTIONS(2535),
    [anon_sym_UR_DQUOTE] = ACTIONS(2535),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2535),
    [anon_sym_co_await] = ACTIONS(2533),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_requires] = ACTIONS(2533),
    [sym_this] = ACTIONS(2533),
    [anon_sym___launch_bounds__] = ACTIONS(2533),
  },
  [STATE(297)] = {
    [sym_identifier] = ACTIONS(2537),
    [aux_sym_preproc_include_token1] = ACTIONS(2537),
    [aux_sym_preproc_def_token1] = ACTIONS(2537),
    [aux_sym_preproc_if_token1] = ACTIONS(2537),
    [aux_sym_preproc_if_token2] = ACTIONS(2537),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2537),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2537),
    [aux_sym_preproc_else_token1] = ACTIONS(2537),
    [aux_sym_preproc_elif_token1] = ACTIONS(2537),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2537),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2537),
    [sym_preproc_directive] = ACTIONS(2537),
    [anon_sym_LPAREN2] = ACTIONS(2539),
    [anon_sym_BANG] = ACTIONS(2539),
    [anon_sym_TILDE] = ACTIONS(2539),
    [anon_sym_DASH] = ACTIONS(2537),
    [anon_sym_PLUS] = ACTIONS(2537),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_AMP_AMP] = ACTIONS(2539),
    [anon_sym_AMP] = ACTIONS(2537),
    [anon_sym_SEMI] = ACTIONS(2539),
    [anon_sym___extension__] = ACTIONS(2537),
    [anon_sym_typedef] = ACTIONS(2537),
    [anon_sym___device__] = ACTIONS(2537),
    [anon_sym___host__] = ACTIONS(2537),
    [anon_sym___global__] = ACTIONS(2537),
    [anon_sym___forceinline__] = ACTIONS(2537),
    [anon_sym___noinline__] = ACTIONS(2537),
    [anon_sym_virtual] = ACTIONS(2537),
    [anon_sym_extern] = ACTIONS(2537),
    [anon_sym___attribute__] = ACTIONS(2537),
    [anon_sym___attribute] = ACTIONS(2537),
    [anon_sym_COLON_COLON] = ACTIONS(2539),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2539),
    [anon_sym___declspec] = ACTIONS(2537),
    [anon_sym___based] = ACTIONS(2537),
    [anon_sym___cdecl] = ACTIONS(2537),
    [anon_sym___clrcall] = ACTIONS(2537),
    [anon_sym___stdcall] = ACTIONS(2537),
    [anon_sym___fastcall] = ACTIONS(2537),
    [anon_sym___thiscall] = ACTIONS(2537),
    [anon_sym___vectorcall] = ACTIONS(2537),
    [anon_sym_LBRACE] = ACTIONS(2539),
    [anon_sym_signed] = ACTIONS(2537),
    [anon_sym_unsigned] = ACTIONS(2537),
    [anon_sym_long] = ACTIONS(2537),
    [anon_sym_short] = ACTIONS(2537),
    [anon_sym_LBRACK] = ACTIONS(2537),
    [anon_sym_static] = ACTIONS(2537),
    [anon_sym_register] = ACTIONS(2537),
    [anon_sym_inline] = ACTIONS(2537),
    [anon_sym___inline] = ACTIONS(2537),
    [anon_sym___inline__] = ACTIONS(2537),
    [anon_sym___forceinline] = ACTIONS(2537),
    [anon_sym_thread_local] = ACTIONS(2537),
    [anon_sym___thread] = ACTIONS(2537),
    [anon_sym_const] = ACTIONS(2537),
    [anon_sym_constexpr] = ACTIONS(2537),
    [anon_sym_volatile] = ACTIONS(2537),
    [anon_sym_restrict] = ACTIONS(2537),
    [anon_sym___restrict__] = ACTIONS(2537),
    [anon_sym__Atomic] = ACTIONS(2537),
    [anon_sym__Noreturn] = ACTIONS(2537),
    [anon_sym_noreturn] = ACTIONS(2537),
    [anon_sym__Nonnull] = ACTIONS(2537),
    [anon_sym_mutable] = ACTIONS(2537),
    [anon_sym_constinit] = ACTIONS(2537),
    [anon_sym_consteval] = ACTIONS(2537),
    [anon_sym___shared__] = ACTIONS(2537),
    [anon_sym___local__] = ACTIONS(2537),
    [anon_sym___constant__] = ACTIONS(2537),
    [anon_sym___managed__] = ACTIONS(2537),
    [anon_sym___grid_constant__] = ACTIONS(2537),
    [anon_sym_alignas] = ACTIONS(2537),
    [anon_sym__Alignas] = ACTIONS(2537),
    [sym_primitive_type] = ACTIONS(2537),
    [anon_sym_enum] = ACTIONS(2537),
    [anon_sym_class] = ACTIONS(2537),
    [anon_sym_struct] = ACTIONS(2537),
    [anon_sym_union] = ACTIONS(2537),
    [anon_sym_if] = ACTIONS(2537),
    [anon_sym_switch] = ACTIONS(2537),
    [anon_sym_case] = ACTIONS(2537),
    [anon_sym_default] = ACTIONS(2537),
    [anon_sym_while] = ACTIONS(2537),
    [anon_sym_do] = ACTIONS(2537),
    [anon_sym_for] = ACTIONS(2537),
    [anon_sym_return] = ACTIONS(2537),
    [anon_sym_break] = ACTIONS(2537),
    [anon_sym_continue] = ACTIONS(2537),
    [anon_sym_goto] = ACTIONS(2537),
    [anon_sym___try] = ACTIONS(2537),
    [anon_sym___leave] = ACTIONS(2537),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_compl] = ACTIONS(2537),
    [anon_sym_DASH_DASH] = ACTIONS(2539),
    [anon_sym_PLUS_PLUS] = ACTIONS(2539),
    [anon_sym_sizeof] = ACTIONS(2537),
    [anon_sym___alignof__] = ACTIONS(2537),
    [anon_sym___alignof] = ACTIONS(2537),
    [anon_sym__alignof] = ACTIONS(2537),
    [anon_sym_alignof] = ACTIONS(2537),
    [anon_sym__Alignof] = ACTIONS(2537),
    [anon_sym_offsetof] = ACTIONS(2537),
    [anon_sym__Generic] = ACTIONS(2537),
    [anon_sym_asm] = ACTIONS(2537),
    [anon_sym___asm__] = ACTIONS(2537),
    [anon_sym___asm] = ACTIONS(2537),
    [sym_number_literal] = ACTIONS(2539),
    [anon_sym_L_SQUOTE] = ACTIONS(2539),
    [anon_sym_u_SQUOTE] = ACTIONS(2539),
    [anon_sym_U_SQUOTE] = ACTIONS(2539),
    [anon_sym_u8_SQUOTE] = ACTIONS(2539),
    [anon_sym_SQUOTE] = ACTIONS(2539),
    [anon_sym_L_DQUOTE] = ACTIONS(2539),
    [anon_sym_u_DQUOTE] = ACTIONS(2539),
    [anon_sym_U_DQUOTE] = ACTIONS(2539),
    [anon_sym_u8_DQUOTE] = ACTIONS(2539),
    [anon_sym_DQUOTE] = ACTIONS(2539),
    [sym_true] = ACTIONS(2537),
    [sym_false] = ACTIONS(2537),
    [anon_sym_NULL] = ACTIONS(2537),
    [anon_sym_nullptr] = ACTIONS(2537),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2537),
    [anon_sym_decltype] = ACTIONS(2537),
    [anon_sym_explicit] = ACTIONS(2537),
    [anon_sym_typename] = ACTIONS(2537),
    [anon_sym_template] = ACTIONS(2537),
    [anon_sym_operator] = ACTIONS(2537),
    [anon_sym_try] = ACTIONS(2537),
    [anon_sym_delete] = ACTIONS(2537),
    [anon_sym_throw] = ACTIONS(2537),
    [anon_sym_namespace] = ACTIONS(2537),
    [anon_sym_using] = ACTIONS(2537),
    [anon_sym_static_assert] = ACTIONS(2537),
    [anon_sym_concept] = ACTIONS(2537),
    [anon_sym_co_return] = ACTIONS(2537),
    [anon_sym_co_yield] = ACTIONS(2537),
    [anon_sym_R_DQUOTE] = ACTIONS(2539),
    [anon_sym_LR_DQUOTE] = ACTIONS(2539),
    [anon_sym_uR_DQUOTE] = ACTIONS(2539),
    [anon_sym_UR_DQUOTE] = ACTIONS(2539),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2539),
    [anon_sym_co_await] = ACTIONS(2537),
    [anon_sym_new] = ACTIONS(2537),
    [anon_sym_requires] = ACTIONS(2537),
    [sym_this] = ACTIONS(2537),
    [anon_sym___launch_bounds__] = ACTIONS(2537),
  },
  [STATE(298)] = {
    [sym_identifier] = ACTIONS(2541),
    [aux_sym_preproc_include_token1] = ACTIONS(2541),
    [aux_sym_preproc_def_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token2] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2541),
    [aux_sym_preproc_else_token1] = ACTIONS(2541),
    [aux_sym_preproc_elif_token1] = ACTIONS(2541),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2541),
    [sym_preproc_directive] = ACTIONS(2541),
    [anon_sym_LPAREN2] = ACTIONS(2543),
    [anon_sym_BANG] = ACTIONS(2543),
    [anon_sym_TILDE] = ACTIONS(2543),
    [anon_sym_DASH] = ACTIONS(2541),
    [anon_sym_PLUS] = ACTIONS(2541),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_AMP_AMP] = ACTIONS(2543),
    [anon_sym_AMP] = ACTIONS(2541),
    [anon_sym_SEMI] = ACTIONS(2543),
    [anon_sym___extension__] = ACTIONS(2541),
    [anon_sym_typedef] = ACTIONS(2541),
    [anon_sym___device__] = ACTIONS(2541),
    [anon_sym___host__] = ACTIONS(2541),
    [anon_sym___global__] = ACTIONS(2541),
    [anon_sym___forceinline__] = ACTIONS(2541),
    [anon_sym___noinline__] = ACTIONS(2541),
    [anon_sym_virtual] = ACTIONS(2541),
    [anon_sym_extern] = ACTIONS(2541),
    [anon_sym___attribute__] = ACTIONS(2541),
    [anon_sym___attribute] = ACTIONS(2541),
    [anon_sym_COLON_COLON] = ACTIONS(2543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2543),
    [anon_sym___declspec] = ACTIONS(2541),
    [anon_sym___based] = ACTIONS(2541),
    [anon_sym___cdecl] = ACTIONS(2541),
    [anon_sym___clrcall] = ACTIONS(2541),
    [anon_sym___stdcall] = ACTIONS(2541),
    [anon_sym___fastcall] = ACTIONS(2541),
    [anon_sym___thiscall] = ACTIONS(2541),
    [anon_sym___vectorcall] = ACTIONS(2541),
    [anon_sym_LBRACE] = ACTIONS(2543),
    [anon_sym_signed] = ACTIONS(2541),
    [anon_sym_unsigned] = ACTIONS(2541),
    [anon_sym_long] = ACTIONS(2541),
    [anon_sym_short] = ACTIONS(2541),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [anon_sym_static] = ACTIONS(2541),
    [anon_sym_register] = ACTIONS(2541),
    [anon_sym_inline] = ACTIONS(2541),
    [anon_sym___inline] = ACTIONS(2541),
    [anon_sym___inline__] = ACTIONS(2541),
    [anon_sym___forceinline] = ACTIONS(2541),
    [anon_sym_thread_local] = ACTIONS(2541),
    [anon_sym___thread] = ACTIONS(2541),
    [anon_sym_const] = ACTIONS(2541),
    [anon_sym_constexpr] = ACTIONS(2541),
    [anon_sym_volatile] = ACTIONS(2541),
    [anon_sym_restrict] = ACTIONS(2541),
    [anon_sym___restrict__] = ACTIONS(2541),
    [anon_sym__Atomic] = ACTIONS(2541),
    [anon_sym__Noreturn] = ACTIONS(2541),
    [anon_sym_noreturn] = ACTIONS(2541),
    [anon_sym__Nonnull] = ACTIONS(2541),
    [anon_sym_mutable] = ACTIONS(2541),
    [anon_sym_constinit] = ACTIONS(2541),
    [anon_sym_consteval] = ACTIONS(2541),
    [anon_sym___shared__] = ACTIONS(2541),
    [anon_sym___local__] = ACTIONS(2541),
    [anon_sym___constant__] = ACTIONS(2541),
    [anon_sym___managed__] = ACTIONS(2541),
    [anon_sym___grid_constant__] = ACTIONS(2541),
    [anon_sym_alignas] = ACTIONS(2541),
    [anon_sym__Alignas] = ACTIONS(2541),
    [sym_primitive_type] = ACTIONS(2541),
    [anon_sym_enum] = ACTIONS(2541),
    [anon_sym_class] = ACTIONS(2541),
    [anon_sym_struct] = ACTIONS(2541),
    [anon_sym_union] = ACTIONS(2541),
    [anon_sym_if] = ACTIONS(2541),
    [anon_sym_switch] = ACTIONS(2541),
    [anon_sym_case] = ACTIONS(2541),
    [anon_sym_default] = ACTIONS(2541),
    [anon_sym_while] = ACTIONS(2541),
    [anon_sym_do] = ACTIONS(2541),
    [anon_sym_for] = ACTIONS(2541),
    [anon_sym_return] = ACTIONS(2541),
    [anon_sym_break] = ACTIONS(2541),
    [anon_sym_continue] = ACTIONS(2541),
    [anon_sym_goto] = ACTIONS(2541),
    [anon_sym___try] = ACTIONS(2541),
    [anon_sym___leave] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2541),
    [anon_sym_compl] = ACTIONS(2541),
    [anon_sym_DASH_DASH] = ACTIONS(2543),
    [anon_sym_PLUS_PLUS] = ACTIONS(2543),
    [anon_sym_sizeof] = ACTIONS(2541),
    [anon_sym___alignof__] = ACTIONS(2541),
    [anon_sym___alignof] = ACTIONS(2541),
    [anon_sym__alignof] = ACTIONS(2541),
    [anon_sym_alignof] = ACTIONS(2541),
    [anon_sym__Alignof] = ACTIONS(2541),
    [anon_sym_offsetof] = ACTIONS(2541),
    [anon_sym__Generic] = ACTIONS(2541),
    [anon_sym_asm] = ACTIONS(2541),
    [anon_sym___asm__] = ACTIONS(2541),
    [anon_sym___asm] = ACTIONS(2541),
    [sym_number_literal] = ACTIONS(2543),
    [anon_sym_L_SQUOTE] = ACTIONS(2543),
    [anon_sym_u_SQUOTE] = ACTIONS(2543),
    [anon_sym_U_SQUOTE] = ACTIONS(2543),
    [anon_sym_u8_SQUOTE] = ACTIONS(2543),
    [anon_sym_SQUOTE] = ACTIONS(2543),
    [anon_sym_L_DQUOTE] = ACTIONS(2543),
    [anon_sym_u_DQUOTE] = ACTIONS(2543),
    [anon_sym_U_DQUOTE] = ACTIONS(2543),
    [anon_sym_u8_DQUOTE] = ACTIONS(2543),
    [anon_sym_DQUOTE] = ACTIONS(2543),
    [sym_true] = ACTIONS(2541),
    [sym_false] = ACTIONS(2541),
    [anon_sym_NULL] = ACTIONS(2541),
    [anon_sym_nullptr] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2541),
    [anon_sym_decltype] = ACTIONS(2541),
    [anon_sym_explicit] = ACTIONS(2541),
    [anon_sym_typename] = ACTIONS(2541),
    [anon_sym_template] = ACTIONS(2541),
    [anon_sym_operator] = ACTIONS(2541),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_delete] = ACTIONS(2541),
    [anon_sym_throw] = ACTIONS(2541),
    [anon_sym_namespace] = ACTIONS(2541),
    [anon_sym_using] = ACTIONS(2541),
    [anon_sym_static_assert] = ACTIONS(2541),
    [anon_sym_concept] = ACTIONS(2541),
    [anon_sym_co_return] = ACTIONS(2541),
    [anon_sym_co_yield] = ACTIONS(2541),
    [anon_sym_R_DQUOTE] = ACTIONS(2543),
    [anon_sym_LR_DQUOTE] = ACTIONS(2543),
    [anon_sym_uR_DQUOTE] = ACTIONS(2543),
    [anon_sym_UR_DQUOTE] = ACTIONS(2543),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2543),
    [anon_sym_co_await] = ACTIONS(2541),
    [anon_sym_new] = ACTIONS(2541),
    [anon_sym_requires] = ACTIONS(2541),
    [sym_this] = ACTIONS(2541),
    [anon_sym___launch_bounds__] = ACTIONS(2541),
  },
  [STATE(299)] = {
    [sym_identifier] = ACTIONS(2545),
    [aux_sym_preproc_include_token1] = ACTIONS(2545),
    [aux_sym_preproc_def_token1] = ACTIONS(2545),
    [aux_sym_preproc_if_token1] = ACTIONS(2545),
    [aux_sym_preproc_if_token2] = ACTIONS(2545),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2545),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2545),
    [aux_sym_preproc_else_token1] = ACTIONS(2545),
    [aux_sym_preproc_elif_token1] = ACTIONS(2545),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2545),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2545),
    [sym_preproc_directive] = ACTIONS(2545),
    [anon_sym_LPAREN2] = ACTIONS(2547),
    [anon_sym_BANG] = ACTIONS(2547),
    [anon_sym_TILDE] = ACTIONS(2547),
    [anon_sym_DASH] = ACTIONS(2545),
    [anon_sym_PLUS] = ACTIONS(2545),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_AMP_AMP] = ACTIONS(2547),
    [anon_sym_AMP] = ACTIONS(2545),
    [anon_sym_SEMI] = ACTIONS(2547),
    [anon_sym___extension__] = ACTIONS(2545),
    [anon_sym_typedef] = ACTIONS(2545),
    [anon_sym___device__] = ACTIONS(2545),
    [anon_sym___host__] = ACTIONS(2545),
    [anon_sym___global__] = ACTIONS(2545),
    [anon_sym___forceinline__] = ACTIONS(2545),
    [anon_sym___noinline__] = ACTIONS(2545),
    [anon_sym_virtual] = ACTIONS(2545),
    [anon_sym_extern] = ACTIONS(2545),
    [anon_sym___attribute__] = ACTIONS(2545),
    [anon_sym___attribute] = ACTIONS(2545),
    [anon_sym_COLON_COLON] = ACTIONS(2547),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2547),
    [anon_sym___declspec] = ACTIONS(2545),
    [anon_sym___based] = ACTIONS(2545),
    [anon_sym___cdecl] = ACTIONS(2545),
    [anon_sym___clrcall] = ACTIONS(2545),
    [anon_sym___stdcall] = ACTIONS(2545),
    [anon_sym___fastcall] = ACTIONS(2545),
    [anon_sym___thiscall] = ACTIONS(2545),
    [anon_sym___vectorcall] = ACTIONS(2545),
    [anon_sym_LBRACE] = ACTIONS(2547),
    [anon_sym_signed] = ACTIONS(2545),
    [anon_sym_unsigned] = ACTIONS(2545),
    [anon_sym_long] = ACTIONS(2545),
    [anon_sym_short] = ACTIONS(2545),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [anon_sym_static] = ACTIONS(2545),
    [anon_sym_register] = ACTIONS(2545),
    [anon_sym_inline] = ACTIONS(2545),
    [anon_sym___inline] = ACTIONS(2545),
    [anon_sym___inline__] = ACTIONS(2545),
    [anon_sym___forceinline] = ACTIONS(2545),
    [anon_sym_thread_local] = ACTIONS(2545),
    [anon_sym___thread] = ACTIONS(2545),
    [anon_sym_const] = ACTIONS(2545),
    [anon_sym_constexpr] = ACTIONS(2545),
    [anon_sym_volatile] = ACTIONS(2545),
    [anon_sym_restrict] = ACTIONS(2545),
    [anon_sym___restrict__] = ACTIONS(2545),
    [anon_sym__Atomic] = ACTIONS(2545),
    [anon_sym__Noreturn] = ACTIONS(2545),
    [anon_sym_noreturn] = ACTIONS(2545),
    [anon_sym__Nonnull] = ACTIONS(2545),
    [anon_sym_mutable] = ACTIONS(2545),
    [anon_sym_constinit] = ACTIONS(2545),
    [anon_sym_consteval] = ACTIONS(2545),
    [anon_sym___shared__] = ACTIONS(2545),
    [anon_sym___local__] = ACTIONS(2545),
    [anon_sym___constant__] = ACTIONS(2545),
    [anon_sym___managed__] = ACTIONS(2545),
    [anon_sym___grid_constant__] = ACTIONS(2545),
    [anon_sym_alignas] = ACTIONS(2545),
    [anon_sym__Alignas] = ACTIONS(2545),
    [sym_primitive_type] = ACTIONS(2545),
    [anon_sym_enum] = ACTIONS(2545),
    [anon_sym_class] = ACTIONS(2545),
    [anon_sym_struct] = ACTIONS(2545),
    [anon_sym_union] = ACTIONS(2545),
    [anon_sym_if] = ACTIONS(2545),
    [anon_sym_switch] = ACTIONS(2545),
    [anon_sym_case] = ACTIONS(2545),
    [anon_sym_default] = ACTIONS(2545),
    [anon_sym_while] = ACTIONS(2545),
    [anon_sym_do] = ACTIONS(2545),
    [anon_sym_for] = ACTIONS(2545),
    [anon_sym_return] = ACTIONS(2545),
    [anon_sym_break] = ACTIONS(2545),
    [anon_sym_continue] = ACTIONS(2545),
    [anon_sym_goto] = ACTIONS(2545),
    [anon_sym___try] = ACTIONS(2545),
    [anon_sym___leave] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2545),
    [anon_sym_compl] = ACTIONS(2545),
    [anon_sym_DASH_DASH] = ACTIONS(2547),
    [anon_sym_PLUS_PLUS] = ACTIONS(2547),
    [anon_sym_sizeof] = ACTIONS(2545),
    [anon_sym___alignof__] = ACTIONS(2545),
    [anon_sym___alignof] = ACTIONS(2545),
    [anon_sym__alignof] = ACTIONS(2545),
    [anon_sym_alignof] = ACTIONS(2545),
    [anon_sym__Alignof] = ACTIONS(2545),
    [anon_sym_offsetof] = ACTIONS(2545),
    [anon_sym__Generic] = ACTIONS(2545),
    [anon_sym_asm] = ACTIONS(2545),
    [anon_sym___asm__] = ACTIONS(2545),
    [anon_sym___asm] = ACTIONS(2545),
    [sym_number_literal] = ACTIONS(2547),
    [anon_sym_L_SQUOTE] = ACTIONS(2547),
    [anon_sym_u_SQUOTE] = ACTIONS(2547),
    [anon_sym_U_SQUOTE] = ACTIONS(2547),
    [anon_sym_u8_SQUOTE] = ACTIONS(2547),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_L_DQUOTE] = ACTIONS(2547),
    [anon_sym_u_DQUOTE] = ACTIONS(2547),
    [anon_sym_U_DQUOTE] = ACTIONS(2547),
    [anon_sym_u8_DQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2547),
    [sym_true] = ACTIONS(2545),
    [sym_false] = ACTIONS(2545),
    [anon_sym_NULL] = ACTIONS(2545),
    [anon_sym_nullptr] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2545),
    [anon_sym_decltype] = ACTIONS(2545),
    [anon_sym_explicit] = ACTIONS(2545),
    [anon_sym_typename] = ACTIONS(2545),
    [anon_sym_template] = ACTIONS(2545),
    [anon_sym_operator] = ACTIONS(2545),
    [anon_sym_try] = ACTIONS(2545),
    [anon_sym_delete] = ACTIONS(2545),
    [anon_sym_throw] = ACTIONS(2545),
    [anon_sym_namespace] = ACTIONS(2545),
    [anon_sym_using] = ACTIONS(2545),
    [anon_sym_static_assert] = ACTIONS(2545),
    [anon_sym_concept] = ACTIONS(2545),
    [anon_sym_co_return] = ACTIONS(2545),
    [anon_sym_co_yield] = ACTIONS(2545),
    [anon_sym_R_DQUOTE] = ACTIONS(2547),
    [anon_sym_LR_DQUOTE] = ACTIONS(2547),
    [anon_sym_uR_DQUOTE] = ACTIONS(2547),
    [anon_sym_UR_DQUOTE] = ACTIONS(2547),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2547),
    [anon_sym_co_await] = ACTIONS(2545),
    [anon_sym_new] = ACTIONS(2545),
    [anon_sym_requires] = ACTIONS(2545),
    [sym_this] = ACTIONS(2545),
    [anon_sym___launch_bounds__] = ACTIONS(2545),
  },
  [STATE(300)] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_include_token1] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token2] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [aux_sym_preproc_else_token1] = ACTIONS(2549),
    [aux_sym_preproc_elif_token1] = ACTIONS(2549),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2549),
    [anon_sym_PLUS] = ACTIONS(2549),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym___device__] = ACTIONS(2549),
    [anon_sym___host__] = ACTIONS(2549),
    [anon_sym___global__] = ACTIONS(2549),
    [anon_sym___forceinline__] = ACTIONS(2549),
    [anon_sym___noinline__] = ACTIONS(2549),
    [anon_sym_virtual] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym___attribute] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym___cdecl] = ACTIONS(2549),
    [anon_sym___clrcall] = ACTIONS(2549),
    [anon_sym___stdcall] = ACTIONS(2549),
    [anon_sym___fastcall] = ACTIONS(2549),
    [anon_sym___thiscall] = ACTIONS(2549),
    [anon_sym___vectorcall] = ACTIONS(2549),
    [anon_sym_LBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym__Nonnull] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym___shared__] = ACTIONS(2549),
    [anon_sym___local__] = ACTIONS(2549),
    [anon_sym___constant__] = ACTIONS(2549),
    [anon_sym___managed__] = ACTIONS(2549),
    [anon_sym___grid_constant__] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2549),
    [anon_sym_switch] = ACTIONS(2549),
    [anon_sym_case] = ACTIONS(2549),
    [anon_sym_default] = ACTIONS(2549),
    [anon_sym_while] = ACTIONS(2549),
    [anon_sym_do] = ACTIONS(2549),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_return] = ACTIONS(2549),
    [anon_sym_break] = ACTIONS(2549),
    [anon_sym_continue] = ACTIONS(2549),
    [anon_sym_goto] = ACTIONS(2549),
    [anon_sym___try] = ACTIONS(2549),
    [anon_sym___leave] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2549),
    [anon_sym_compl] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2551),
    [anon_sym_sizeof] = ACTIONS(2549),
    [anon_sym___alignof__] = ACTIONS(2549),
    [anon_sym___alignof] = ACTIONS(2549),
    [anon_sym__alignof] = ACTIONS(2549),
    [anon_sym_alignof] = ACTIONS(2549),
    [anon_sym__Alignof] = ACTIONS(2549),
    [anon_sym_offsetof] = ACTIONS(2549),
    [anon_sym__Generic] = ACTIONS(2549),
    [anon_sym_asm] = ACTIONS(2549),
    [anon_sym___asm__] = ACTIONS(2549),
    [anon_sym___asm] = ACTIONS(2549),
    [sym_number_literal] = ACTIONS(2551),
    [anon_sym_L_SQUOTE] = ACTIONS(2551),
    [anon_sym_u_SQUOTE] = ACTIONS(2551),
    [anon_sym_U_SQUOTE] = ACTIONS(2551),
    [anon_sym_u8_SQUOTE] = ACTIONS(2551),
    [anon_sym_SQUOTE] = ACTIONS(2551),
    [anon_sym_L_DQUOTE] = ACTIONS(2551),
    [anon_sym_u_DQUOTE] = ACTIONS(2551),
    [anon_sym_U_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8_DQUOTE] = ACTIONS(2551),
    [anon_sym_DQUOTE] = ACTIONS(2551),
    [sym_true] = ACTIONS(2549),
    [sym_false] = ACTIONS(2549),
    [anon_sym_NULL] = ACTIONS(2549),
    [anon_sym_nullptr] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_try] = ACTIONS(2549),
    [anon_sym_delete] = ACTIONS(2549),
    [anon_sym_throw] = ACTIONS(2549),
    [anon_sym_namespace] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_concept] = ACTIONS(2549),
    [anon_sym_co_return] = ACTIONS(2549),
    [anon_sym_co_yield] = ACTIONS(2549),
    [anon_sym_R_DQUOTE] = ACTIONS(2551),
    [anon_sym_LR_DQUOTE] = ACTIONS(2551),
    [anon_sym_uR_DQUOTE] = ACTIONS(2551),
    [anon_sym_UR_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2551),
    [anon_sym_co_await] = ACTIONS(2549),
    [anon_sym_new] = ACTIONS(2549),
    [anon_sym_requires] = ACTIONS(2549),
    [sym_this] = ACTIONS(2549),
    [anon_sym___launch_bounds__] = ACTIONS(2549),
  },
  [STATE(301)] = {
    [sym_identifier] = ACTIONS(2553),
    [aux_sym_preproc_include_token1] = ACTIONS(2553),
    [aux_sym_preproc_def_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token2] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2553),
    [aux_sym_preproc_else_token1] = ACTIONS(2553),
    [aux_sym_preproc_elif_token1] = ACTIONS(2553),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2553),
    [sym_preproc_directive] = ACTIONS(2553),
    [anon_sym_LPAREN2] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2555),
    [anon_sym_TILDE] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2553),
    [anon_sym_PLUS] = ACTIONS(2553),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_AMP_AMP] = ACTIONS(2555),
    [anon_sym_AMP] = ACTIONS(2553),
    [anon_sym_SEMI] = ACTIONS(2555),
    [anon_sym___extension__] = ACTIONS(2553),
    [anon_sym_typedef] = ACTIONS(2553),
    [anon_sym___device__] = ACTIONS(2553),
    [anon_sym___host__] = ACTIONS(2553),
    [anon_sym___global__] = ACTIONS(2553),
    [anon_sym___forceinline__] = ACTIONS(2553),
    [anon_sym___noinline__] = ACTIONS(2553),
    [anon_sym_virtual] = ACTIONS(2553),
    [anon_sym_extern] = ACTIONS(2553),
    [anon_sym___attribute__] = ACTIONS(2553),
    [anon_sym___attribute] = ACTIONS(2553),
    [anon_sym_COLON_COLON] = ACTIONS(2555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2555),
    [anon_sym___declspec] = ACTIONS(2553),
    [anon_sym___based] = ACTIONS(2553),
    [anon_sym___cdecl] = ACTIONS(2553),
    [anon_sym___clrcall] = ACTIONS(2553),
    [anon_sym___stdcall] = ACTIONS(2553),
    [anon_sym___fastcall] = ACTIONS(2553),
    [anon_sym___thiscall] = ACTIONS(2553),
    [anon_sym___vectorcall] = ACTIONS(2553),
    [anon_sym_LBRACE] = ACTIONS(2555),
    [anon_sym_signed] = ACTIONS(2553),
    [anon_sym_unsigned] = ACTIONS(2553),
    [anon_sym_long] = ACTIONS(2553),
    [anon_sym_short] = ACTIONS(2553),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2553),
    [anon_sym_register] = ACTIONS(2553),
    [anon_sym_inline] = ACTIONS(2553),
    [anon_sym___inline] = ACTIONS(2553),
    [anon_sym___inline__] = ACTIONS(2553),
    [anon_sym___forceinline] = ACTIONS(2553),
    [anon_sym_thread_local] = ACTIONS(2553),
    [anon_sym___thread] = ACTIONS(2553),
    [anon_sym_const] = ACTIONS(2553),
    [anon_sym_constexpr] = ACTIONS(2553),
    [anon_sym_volatile] = ACTIONS(2553),
    [anon_sym_restrict] = ACTIONS(2553),
    [anon_sym___restrict__] = ACTIONS(2553),
    [anon_sym__Atomic] = ACTIONS(2553),
    [anon_sym__Noreturn] = ACTIONS(2553),
    [anon_sym_noreturn] = ACTIONS(2553),
    [anon_sym__Nonnull] = ACTIONS(2553),
    [anon_sym_mutable] = ACTIONS(2553),
    [anon_sym_constinit] = ACTIONS(2553),
    [anon_sym_consteval] = ACTIONS(2553),
    [anon_sym___shared__] = ACTIONS(2553),
    [anon_sym___local__] = ACTIONS(2553),
    [anon_sym___constant__] = ACTIONS(2553),
    [anon_sym___managed__] = ACTIONS(2553),
    [anon_sym___grid_constant__] = ACTIONS(2553),
    [anon_sym_alignas] = ACTIONS(2553),
    [anon_sym__Alignas] = ACTIONS(2553),
    [sym_primitive_type] = ACTIONS(2553),
    [anon_sym_enum] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2553),
    [anon_sym_struct] = ACTIONS(2553),
    [anon_sym_union] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2553),
    [anon_sym_switch] = ACTIONS(2553),
    [anon_sym_case] = ACTIONS(2553),
    [anon_sym_default] = ACTIONS(2553),
    [anon_sym_while] = ACTIONS(2553),
    [anon_sym_do] = ACTIONS(2553),
    [anon_sym_for] = ACTIONS(2553),
    [anon_sym_return] = ACTIONS(2553),
    [anon_sym_break] = ACTIONS(2553),
    [anon_sym_continue] = ACTIONS(2553),
    [anon_sym_goto] = ACTIONS(2553),
    [anon_sym___try] = ACTIONS(2553),
    [anon_sym___leave] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2553),
    [anon_sym_compl] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2555),
    [anon_sym_sizeof] = ACTIONS(2553),
    [anon_sym___alignof__] = ACTIONS(2553),
    [anon_sym___alignof] = ACTIONS(2553),
    [anon_sym__alignof] = ACTIONS(2553),
    [anon_sym_alignof] = ACTIONS(2553),
    [anon_sym__Alignof] = ACTIONS(2553),
    [anon_sym_offsetof] = ACTIONS(2553),
    [anon_sym__Generic] = ACTIONS(2553),
    [anon_sym_asm] = ACTIONS(2553),
    [anon_sym___asm__] = ACTIONS(2553),
    [anon_sym___asm] = ACTIONS(2553),
    [sym_number_literal] = ACTIONS(2555),
    [anon_sym_L_SQUOTE] = ACTIONS(2555),
    [anon_sym_u_SQUOTE] = ACTIONS(2555),
    [anon_sym_U_SQUOTE] = ACTIONS(2555),
    [anon_sym_u8_SQUOTE] = ACTIONS(2555),
    [anon_sym_SQUOTE] = ACTIONS(2555),
    [anon_sym_L_DQUOTE] = ACTIONS(2555),
    [anon_sym_u_DQUOTE] = ACTIONS(2555),
    [anon_sym_U_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8_DQUOTE] = ACTIONS(2555),
    [anon_sym_DQUOTE] = ACTIONS(2555),
    [sym_true] = ACTIONS(2553),
    [sym_false] = ACTIONS(2553),
    [anon_sym_NULL] = ACTIONS(2553),
    [anon_sym_nullptr] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2553),
    [anon_sym_decltype] = ACTIONS(2553),
    [anon_sym_explicit] = ACTIONS(2553),
    [anon_sym_typename] = ACTIONS(2553),
    [anon_sym_template] = ACTIONS(2553),
    [anon_sym_operator] = ACTIONS(2553),
    [anon_sym_try] = ACTIONS(2553),
    [anon_sym_delete] = ACTIONS(2553),
    [anon_sym_throw] = ACTIONS(2553),
    [anon_sym_namespace] = ACTIONS(2553),
    [anon_sym_using] = ACTIONS(2553),
    [anon_sym_static_assert] = ACTIONS(2553),
    [anon_sym_concept] = ACTIONS(2553),
    [anon_sym_co_return] = ACTIONS(2553),
    [anon_sym_co_yield] = ACTIONS(2553),
    [anon_sym_R_DQUOTE] = ACTIONS(2555),
    [anon_sym_LR_DQUOTE] = ACTIONS(2555),
    [anon_sym_uR_DQUOTE] = ACTIONS(2555),
    [anon_sym_UR_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2555),
    [anon_sym_co_await] = ACTIONS(2553),
    [anon_sym_new] = ACTIONS(2553),
    [anon_sym_requires] = ACTIONS(2553),
    [sym_this] = ACTIONS(2553),
    [anon_sym___launch_bounds__] = ACTIONS(2553),
  },
  [STATE(302)] = {
    [sym_identifier] = ACTIONS(2557),
    [aux_sym_preproc_include_token1] = ACTIONS(2557),
    [aux_sym_preproc_def_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token2] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2557),
    [aux_sym_preproc_else_token1] = ACTIONS(2557),
    [aux_sym_preproc_elif_token1] = ACTIONS(2557),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2557),
    [sym_preproc_directive] = ACTIONS(2557),
    [anon_sym_LPAREN2] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2557),
    [anon_sym_PLUS] = ACTIONS(2557),
    [anon_sym_STAR] = ACTIONS(2559),
    [anon_sym_AMP_AMP] = ACTIONS(2559),
    [anon_sym_AMP] = ACTIONS(2557),
    [anon_sym_SEMI] = ACTIONS(2559),
    [anon_sym___extension__] = ACTIONS(2557),
    [anon_sym_typedef] = ACTIONS(2557),
    [anon_sym___device__] = ACTIONS(2557),
    [anon_sym___host__] = ACTIONS(2557),
    [anon_sym___global__] = ACTIONS(2557),
    [anon_sym___forceinline__] = ACTIONS(2557),
    [anon_sym___noinline__] = ACTIONS(2557),
    [anon_sym_virtual] = ACTIONS(2557),
    [anon_sym_extern] = ACTIONS(2557),
    [anon_sym___attribute__] = ACTIONS(2557),
    [anon_sym___attribute] = ACTIONS(2557),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2559),
    [anon_sym___declspec] = ACTIONS(2557),
    [anon_sym___based] = ACTIONS(2557),
    [anon_sym___cdecl] = ACTIONS(2557),
    [anon_sym___clrcall] = ACTIONS(2557),
    [anon_sym___stdcall] = ACTIONS(2557),
    [anon_sym___fastcall] = ACTIONS(2557),
    [anon_sym___thiscall] = ACTIONS(2557),
    [anon_sym___vectorcall] = ACTIONS(2557),
    [anon_sym_LBRACE] = ACTIONS(2559),
    [anon_sym_signed] = ACTIONS(2557),
    [anon_sym_unsigned] = ACTIONS(2557),
    [anon_sym_long] = ACTIONS(2557),
    [anon_sym_short] = ACTIONS(2557),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2557),
    [anon_sym_register] = ACTIONS(2557),
    [anon_sym_inline] = ACTIONS(2557),
    [anon_sym___inline] = ACTIONS(2557),
    [anon_sym___inline__] = ACTIONS(2557),
    [anon_sym___forceinline] = ACTIONS(2557),
    [anon_sym_thread_local] = ACTIONS(2557),
    [anon_sym___thread] = ACTIONS(2557),
    [anon_sym_const] = ACTIONS(2557),
    [anon_sym_constexpr] = ACTIONS(2557),
    [anon_sym_volatile] = ACTIONS(2557),
    [anon_sym_restrict] = ACTIONS(2557),
    [anon_sym___restrict__] = ACTIONS(2557),
    [anon_sym__Atomic] = ACTIONS(2557),
    [anon_sym__Noreturn] = ACTIONS(2557),
    [anon_sym_noreturn] = ACTIONS(2557),
    [anon_sym__Nonnull] = ACTIONS(2557),
    [anon_sym_mutable] = ACTIONS(2557),
    [anon_sym_constinit] = ACTIONS(2557),
    [anon_sym_consteval] = ACTIONS(2557),
    [anon_sym___shared__] = ACTIONS(2557),
    [anon_sym___local__] = ACTIONS(2557),
    [anon_sym___constant__] = ACTIONS(2557),
    [anon_sym___managed__] = ACTIONS(2557),
    [anon_sym___grid_constant__] = ACTIONS(2557),
    [anon_sym_alignas] = ACTIONS(2557),
    [anon_sym__Alignas] = ACTIONS(2557),
    [sym_primitive_type] = ACTIONS(2557),
    [anon_sym_enum] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2557),
    [anon_sym_struct] = ACTIONS(2557),
    [anon_sym_union] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2557),
    [anon_sym_switch] = ACTIONS(2557),
    [anon_sym_case] = ACTIONS(2557),
    [anon_sym_default] = ACTIONS(2557),
    [anon_sym_while] = ACTIONS(2557),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_for] = ACTIONS(2557),
    [anon_sym_return] = ACTIONS(2557),
    [anon_sym_break] = ACTIONS(2557),
    [anon_sym_continue] = ACTIONS(2557),
    [anon_sym_goto] = ACTIONS(2557),
    [anon_sym___try] = ACTIONS(2557),
    [anon_sym___leave] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2557),
    [anon_sym_compl] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2559),
    [anon_sym_sizeof] = ACTIONS(2557),
    [anon_sym___alignof__] = ACTIONS(2557),
    [anon_sym___alignof] = ACTIONS(2557),
    [anon_sym__alignof] = ACTIONS(2557),
    [anon_sym_alignof] = ACTIONS(2557),
    [anon_sym__Alignof] = ACTIONS(2557),
    [anon_sym_offsetof] = ACTIONS(2557),
    [anon_sym__Generic] = ACTIONS(2557),
    [anon_sym_asm] = ACTIONS(2557),
    [anon_sym___asm__] = ACTIONS(2557),
    [anon_sym___asm] = ACTIONS(2557),
    [sym_number_literal] = ACTIONS(2559),
    [anon_sym_L_SQUOTE] = ACTIONS(2559),
    [anon_sym_u_SQUOTE] = ACTIONS(2559),
    [anon_sym_U_SQUOTE] = ACTIONS(2559),
    [anon_sym_u8_SQUOTE] = ACTIONS(2559),
    [anon_sym_SQUOTE] = ACTIONS(2559),
    [anon_sym_L_DQUOTE] = ACTIONS(2559),
    [anon_sym_u_DQUOTE] = ACTIONS(2559),
    [anon_sym_U_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8_DQUOTE] = ACTIONS(2559),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_true] = ACTIONS(2557),
    [sym_false] = ACTIONS(2557),
    [anon_sym_NULL] = ACTIONS(2557),
    [anon_sym_nullptr] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2557),
    [anon_sym_decltype] = ACTIONS(2557),
    [anon_sym_explicit] = ACTIONS(2557),
    [anon_sym_typename] = ACTIONS(2557),
    [anon_sym_template] = ACTIONS(2557),
    [anon_sym_operator] = ACTIONS(2557),
    [anon_sym_try] = ACTIONS(2557),
    [anon_sym_delete] = ACTIONS(2557),
    [anon_sym_throw] = ACTIONS(2557),
    [anon_sym_namespace] = ACTIONS(2557),
    [anon_sym_using] = ACTIONS(2557),
    [anon_sym_static_assert] = ACTIONS(2557),
    [anon_sym_concept] = ACTIONS(2557),
    [anon_sym_co_return] = ACTIONS(2557),
    [anon_sym_co_yield] = ACTIONS(2557),
    [anon_sym_R_DQUOTE] = ACTIONS(2559),
    [anon_sym_LR_DQUOTE] = ACTIONS(2559),
    [anon_sym_uR_DQUOTE] = ACTIONS(2559),
    [anon_sym_UR_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2559),
    [anon_sym_co_await] = ACTIONS(2557),
    [anon_sym_new] = ACTIONS(2557),
    [anon_sym_requires] = ACTIONS(2557),
    [sym_this] = ACTIONS(2557),
    [anon_sym___launch_bounds__] = ACTIONS(2557),
  },
  [STATE(303)] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_include_token1] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token2] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [aux_sym_preproc_else_token1] = ACTIONS(2561),
    [aux_sym_preproc_elif_token1] = ACTIONS(2561),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym___device__] = ACTIONS(2561),
    [anon_sym___host__] = ACTIONS(2561),
    [anon_sym___global__] = ACTIONS(2561),
    [anon_sym___forceinline__] = ACTIONS(2561),
    [anon_sym___noinline__] = ACTIONS(2561),
    [anon_sym_virtual] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym___attribute] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym___cdecl] = ACTIONS(2561),
    [anon_sym___clrcall] = ACTIONS(2561),
    [anon_sym___stdcall] = ACTIONS(2561),
    [anon_sym___fastcall] = ACTIONS(2561),
    [anon_sym___thiscall] = ACTIONS(2561),
    [anon_sym___vectorcall] = ACTIONS(2561),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym__Nonnull] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym___shared__] = ACTIONS(2561),
    [anon_sym___local__] = ACTIONS(2561),
    [anon_sym___constant__] = ACTIONS(2561),
    [anon_sym___managed__] = ACTIONS(2561),
    [anon_sym___grid_constant__] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_switch] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_default] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_do] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_return] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_goto] = ACTIONS(2561),
    [anon_sym___try] = ACTIONS(2561),
    [anon_sym___leave] = ACTIONS(2561),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_compl] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2563),
    [anon_sym_sizeof] = ACTIONS(2561),
    [anon_sym___alignof__] = ACTIONS(2561),
    [anon_sym___alignof] = ACTIONS(2561),
    [anon_sym__alignof] = ACTIONS(2561),
    [anon_sym_alignof] = ACTIONS(2561),
    [anon_sym__Alignof] = ACTIONS(2561),
    [anon_sym_offsetof] = ACTIONS(2561),
    [anon_sym__Generic] = ACTIONS(2561),
    [anon_sym_asm] = ACTIONS(2561),
    [anon_sym___asm__] = ACTIONS(2561),
    [anon_sym___asm] = ACTIONS(2561),
    [sym_number_literal] = ACTIONS(2563),
    [anon_sym_L_SQUOTE] = ACTIONS(2563),
    [anon_sym_u_SQUOTE] = ACTIONS(2563),
    [anon_sym_U_SQUOTE] = ACTIONS(2563),
    [anon_sym_u8_SQUOTE] = ACTIONS(2563),
    [anon_sym_SQUOTE] = ACTIONS(2563),
    [anon_sym_L_DQUOTE] = ACTIONS(2563),
    [anon_sym_u_DQUOTE] = ACTIONS(2563),
    [anon_sym_U_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8_DQUOTE] = ACTIONS(2563),
    [anon_sym_DQUOTE] = ACTIONS(2563),
    [sym_true] = ACTIONS(2561),
    [sym_false] = ACTIONS(2561),
    [anon_sym_NULL] = ACTIONS(2561),
    [anon_sym_nullptr] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_try] = ACTIONS(2561),
    [anon_sym_delete] = ACTIONS(2561),
    [anon_sym_throw] = ACTIONS(2561),
    [anon_sym_namespace] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_concept] = ACTIONS(2561),
    [anon_sym_co_return] = ACTIONS(2561),
    [anon_sym_co_yield] = ACTIONS(2561),
    [anon_sym_R_DQUOTE] = ACTIONS(2563),
    [anon_sym_LR_DQUOTE] = ACTIONS(2563),
    [anon_sym_uR_DQUOTE] = ACTIONS(2563),
    [anon_sym_UR_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2563),
    [anon_sym_co_await] = ACTIONS(2561),
    [anon_sym_new] = ACTIONS(2561),
    [anon_sym_requires] = ACTIONS(2561),
    [sym_this] = ACTIONS(2561),
    [anon_sym___launch_bounds__] = ACTIONS(2561),
  },
  [STATE(304)] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_include_token1] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token2] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [aux_sym_preproc_else_token1] = ACTIONS(2565),
    [aux_sym_preproc_elif_token1] = ACTIONS(2565),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym___device__] = ACTIONS(2565),
    [anon_sym___host__] = ACTIONS(2565),
    [anon_sym___global__] = ACTIONS(2565),
    [anon_sym___forceinline__] = ACTIONS(2565),
    [anon_sym___noinline__] = ACTIONS(2565),
    [anon_sym_virtual] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym___attribute] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym___cdecl] = ACTIONS(2565),
    [anon_sym___clrcall] = ACTIONS(2565),
    [anon_sym___stdcall] = ACTIONS(2565),
    [anon_sym___fastcall] = ACTIONS(2565),
    [anon_sym___thiscall] = ACTIONS(2565),
    [anon_sym___vectorcall] = ACTIONS(2565),
    [anon_sym_LBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym__Nonnull] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym___shared__] = ACTIONS(2565),
    [anon_sym___local__] = ACTIONS(2565),
    [anon_sym___constant__] = ACTIONS(2565),
    [anon_sym___managed__] = ACTIONS(2565),
    [anon_sym___grid_constant__] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_switch] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_default] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_do] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_return] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_goto] = ACTIONS(2565),
    [anon_sym___try] = ACTIONS(2565),
    [anon_sym___leave] = ACTIONS(2565),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_compl] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2567),
    [anon_sym_sizeof] = ACTIONS(2565),
    [anon_sym___alignof__] = ACTIONS(2565),
    [anon_sym___alignof] = ACTIONS(2565),
    [anon_sym__alignof] = ACTIONS(2565),
    [anon_sym_alignof] = ACTIONS(2565),
    [anon_sym__Alignof] = ACTIONS(2565),
    [anon_sym_offsetof] = ACTIONS(2565),
    [anon_sym__Generic] = ACTIONS(2565),
    [anon_sym_asm] = ACTIONS(2565),
    [anon_sym___asm__] = ACTIONS(2565),
    [anon_sym___asm] = ACTIONS(2565),
    [sym_number_literal] = ACTIONS(2567),
    [anon_sym_L_SQUOTE] = ACTIONS(2567),
    [anon_sym_u_SQUOTE] = ACTIONS(2567),
    [anon_sym_U_SQUOTE] = ACTIONS(2567),
    [anon_sym_u8_SQUOTE] = ACTIONS(2567),
    [anon_sym_SQUOTE] = ACTIONS(2567),
    [anon_sym_L_DQUOTE] = ACTIONS(2567),
    [anon_sym_u_DQUOTE] = ACTIONS(2567),
    [anon_sym_U_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8_DQUOTE] = ACTIONS(2567),
    [anon_sym_DQUOTE] = ACTIONS(2567),
    [sym_true] = ACTIONS(2565),
    [sym_false] = ACTIONS(2565),
    [anon_sym_NULL] = ACTIONS(2565),
    [anon_sym_nullptr] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_try] = ACTIONS(2565),
    [anon_sym_delete] = ACTIONS(2565),
    [anon_sym_throw] = ACTIONS(2565),
    [anon_sym_namespace] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_concept] = ACTIONS(2565),
    [anon_sym_co_return] = ACTIONS(2565),
    [anon_sym_co_yield] = ACTIONS(2565),
    [anon_sym_R_DQUOTE] = ACTIONS(2567),
    [anon_sym_LR_DQUOTE] = ACTIONS(2567),
    [anon_sym_uR_DQUOTE] = ACTIONS(2567),
    [anon_sym_UR_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2567),
    [anon_sym_co_await] = ACTIONS(2565),
    [anon_sym_new] = ACTIONS(2565),
    [anon_sym_requires] = ACTIONS(2565),
    [sym_this] = ACTIONS(2565),
    [anon_sym___launch_bounds__] = ACTIONS(2565),
  },
  [STATE(305)] = {
    [sym_identifier] = ACTIONS(2569),
    [aux_sym_preproc_include_token1] = ACTIONS(2569),
    [aux_sym_preproc_def_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token2] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2569),
    [aux_sym_preproc_else_token1] = ACTIONS(2569),
    [aux_sym_preproc_elif_token1] = ACTIONS(2569),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2569),
    [sym_preproc_directive] = ACTIONS(2569),
    [anon_sym_LPAREN2] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2571),
    [anon_sym_TILDE] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2571),
    [anon_sym_AMP_AMP] = ACTIONS(2571),
    [anon_sym_AMP] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym___extension__] = ACTIONS(2569),
    [anon_sym_typedef] = ACTIONS(2569),
    [anon_sym___device__] = ACTIONS(2569),
    [anon_sym___host__] = ACTIONS(2569),
    [anon_sym___global__] = ACTIONS(2569),
    [anon_sym___forceinline__] = ACTIONS(2569),
    [anon_sym___noinline__] = ACTIONS(2569),
    [anon_sym_virtual] = ACTIONS(2569),
    [anon_sym_extern] = ACTIONS(2569),
    [anon_sym___attribute__] = ACTIONS(2569),
    [anon_sym___attribute] = ACTIONS(2569),
    [anon_sym_COLON_COLON] = ACTIONS(2571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2571),
    [anon_sym___declspec] = ACTIONS(2569),
    [anon_sym___based] = ACTIONS(2569),
    [anon_sym___cdecl] = ACTIONS(2569),
    [anon_sym___clrcall] = ACTIONS(2569),
    [anon_sym___stdcall] = ACTIONS(2569),
    [anon_sym___fastcall] = ACTIONS(2569),
    [anon_sym___thiscall] = ACTIONS(2569),
    [anon_sym___vectorcall] = ACTIONS(2569),
    [anon_sym_LBRACE] = ACTIONS(2571),
    [anon_sym_signed] = ACTIONS(2569),
    [anon_sym_unsigned] = ACTIONS(2569),
    [anon_sym_long] = ACTIONS(2569),
    [anon_sym_short] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2569),
    [anon_sym_register] = ACTIONS(2569),
    [anon_sym_inline] = ACTIONS(2569),
    [anon_sym___inline] = ACTIONS(2569),
    [anon_sym___inline__] = ACTIONS(2569),
    [anon_sym___forceinline] = ACTIONS(2569),
    [anon_sym_thread_local] = ACTIONS(2569),
    [anon_sym___thread] = ACTIONS(2569),
    [anon_sym_const] = ACTIONS(2569),
    [anon_sym_constexpr] = ACTIONS(2569),
    [anon_sym_volatile] = ACTIONS(2569),
    [anon_sym_restrict] = ACTIONS(2569),
    [anon_sym___restrict__] = ACTIONS(2569),
    [anon_sym__Atomic] = ACTIONS(2569),
    [anon_sym__Noreturn] = ACTIONS(2569),
    [anon_sym_noreturn] = ACTIONS(2569),
    [anon_sym__Nonnull] = ACTIONS(2569),
    [anon_sym_mutable] = ACTIONS(2569),
    [anon_sym_constinit] = ACTIONS(2569),
    [anon_sym_consteval] = ACTIONS(2569),
    [anon_sym___shared__] = ACTIONS(2569),
    [anon_sym___local__] = ACTIONS(2569),
    [anon_sym___constant__] = ACTIONS(2569),
    [anon_sym___managed__] = ACTIONS(2569),
    [anon_sym___grid_constant__] = ACTIONS(2569),
    [anon_sym_alignas] = ACTIONS(2569),
    [anon_sym__Alignas] = ACTIONS(2569),
    [sym_primitive_type] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2569),
    [anon_sym_struct] = ACTIONS(2569),
    [anon_sym_union] = ACTIONS(2569),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_switch] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_default] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_do] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_return] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_goto] = ACTIONS(2569),
    [anon_sym___try] = ACTIONS(2569),
    [anon_sym___leave] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_compl] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2571),
    [anon_sym_sizeof] = ACTIONS(2569),
    [anon_sym___alignof__] = ACTIONS(2569),
    [anon_sym___alignof] = ACTIONS(2569),
    [anon_sym__alignof] = ACTIONS(2569),
    [anon_sym_alignof] = ACTIONS(2569),
    [anon_sym__Alignof] = ACTIONS(2569),
    [anon_sym_offsetof] = ACTIONS(2569),
    [anon_sym__Generic] = ACTIONS(2569),
    [anon_sym_asm] = ACTIONS(2569),
    [anon_sym___asm__] = ACTIONS(2569),
    [anon_sym___asm] = ACTIONS(2569),
    [sym_number_literal] = ACTIONS(2571),
    [anon_sym_L_SQUOTE] = ACTIONS(2571),
    [anon_sym_u_SQUOTE] = ACTIONS(2571),
    [anon_sym_U_SQUOTE] = ACTIONS(2571),
    [anon_sym_u8_SQUOTE] = ACTIONS(2571),
    [anon_sym_SQUOTE] = ACTIONS(2571),
    [anon_sym_L_DQUOTE] = ACTIONS(2571),
    [anon_sym_u_DQUOTE] = ACTIONS(2571),
    [anon_sym_U_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8_DQUOTE] = ACTIONS(2571),
    [anon_sym_DQUOTE] = ACTIONS(2571),
    [sym_true] = ACTIONS(2569),
    [sym_false] = ACTIONS(2569),
    [anon_sym_NULL] = ACTIONS(2569),
    [anon_sym_nullptr] = ACTIONS(2569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2569),
    [anon_sym_decltype] = ACTIONS(2569),
    [anon_sym_explicit] = ACTIONS(2569),
    [anon_sym_typename] = ACTIONS(2569),
    [anon_sym_template] = ACTIONS(2569),
    [anon_sym_operator] = ACTIONS(2569),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_delete] = ACTIONS(2569),
    [anon_sym_throw] = ACTIONS(2569),
    [anon_sym_namespace] = ACTIONS(2569),
    [anon_sym_using] = ACTIONS(2569),
    [anon_sym_static_assert] = ACTIONS(2569),
    [anon_sym_concept] = ACTIONS(2569),
    [anon_sym_co_return] = ACTIONS(2569),
    [anon_sym_co_yield] = ACTIONS(2569),
    [anon_sym_R_DQUOTE] = ACTIONS(2571),
    [anon_sym_LR_DQUOTE] = ACTIONS(2571),
    [anon_sym_uR_DQUOTE] = ACTIONS(2571),
    [anon_sym_UR_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2571),
    [anon_sym_co_await] = ACTIONS(2569),
    [anon_sym_new] = ACTIONS(2569),
    [anon_sym_requires] = ACTIONS(2569),
    [sym_this] = ACTIONS(2569),
    [anon_sym___launch_bounds__] = ACTIONS(2569),
  },
  [STATE(306)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [aux_sym_preproc_else_token1] = ACTIONS(2573),
    [aux_sym_preproc_elif_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [anon_sym___asm] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(307)] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_include_token1] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token2] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [aux_sym_preproc_else_token1] = ACTIONS(2577),
    [aux_sym_preproc_elif_token1] = ACTIONS(2577),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_BANG] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym___device__] = ACTIONS(2577),
    [anon_sym___host__] = ACTIONS(2577),
    [anon_sym___global__] = ACTIONS(2577),
    [anon_sym___forceinline__] = ACTIONS(2577),
    [anon_sym___noinline__] = ACTIONS(2577),
    [anon_sym_virtual] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym___attribute] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym___cdecl] = ACTIONS(2577),
    [anon_sym___clrcall] = ACTIONS(2577),
    [anon_sym___stdcall] = ACTIONS(2577),
    [anon_sym___fastcall] = ACTIONS(2577),
    [anon_sym___thiscall] = ACTIONS(2577),
    [anon_sym___vectorcall] = ACTIONS(2577),
    [anon_sym_LBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym__Nonnull] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym___shared__] = ACTIONS(2577),
    [anon_sym___local__] = ACTIONS(2577),
    [anon_sym___constant__] = ACTIONS(2577),
    [anon_sym___managed__] = ACTIONS(2577),
    [anon_sym___grid_constant__] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_switch] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_default] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_do] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_return] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_goto] = ACTIONS(2577),
    [anon_sym___try] = ACTIONS(2577),
    [anon_sym___leave] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_compl] = ACTIONS(2577),
    [anon_sym_DASH_DASH] = ACTIONS(2579),
    [anon_sym_PLUS_PLUS] = ACTIONS(2579),
    [anon_sym_sizeof] = ACTIONS(2577),
    [anon_sym___alignof__] = ACTIONS(2577),
    [anon_sym___alignof] = ACTIONS(2577),
    [anon_sym__alignof] = ACTIONS(2577),
    [anon_sym_alignof] = ACTIONS(2577),
    [anon_sym__Alignof] = ACTIONS(2577),
    [anon_sym_offsetof] = ACTIONS(2577),
    [anon_sym__Generic] = ACTIONS(2577),
    [anon_sym_asm] = ACTIONS(2577),
    [anon_sym___asm__] = ACTIONS(2577),
    [anon_sym___asm] = ACTIONS(2577),
    [sym_number_literal] = ACTIONS(2579),
    [anon_sym_L_SQUOTE] = ACTIONS(2579),
    [anon_sym_u_SQUOTE] = ACTIONS(2579),
    [anon_sym_U_SQUOTE] = ACTIONS(2579),
    [anon_sym_u8_SQUOTE] = ACTIONS(2579),
    [anon_sym_SQUOTE] = ACTIONS(2579),
    [anon_sym_L_DQUOTE] = ACTIONS(2579),
    [anon_sym_u_DQUOTE] = ACTIONS(2579),
    [anon_sym_U_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8_DQUOTE] = ACTIONS(2579),
    [anon_sym_DQUOTE] = ACTIONS(2579),
    [sym_true] = ACTIONS(2577),
    [sym_false] = ACTIONS(2577),
    [anon_sym_NULL] = ACTIONS(2577),
    [anon_sym_nullptr] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_try] = ACTIONS(2577),
    [anon_sym_delete] = ACTIONS(2577),
    [anon_sym_throw] = ACTIONS(2577),
    [anon_sym_namespace] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_concept] = ACTIONS(2577),
    [anon_sym_co_return] = ACTIONS(2577),
    [anon_sym_co_yield] = ACTIONS(2577),
    [anon_sym_R_DQUOTE] = ACTIONS(2579),
    [anon_sym_LR_DQUOTE] = ACTIONS(2579),
    [anon_sym_uR_DQUOTE] = ACTIONS(2579),
    [anon_sym_UR_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2579),
    [anon_sym_co_await] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(2577),
    [anon_sym_requires] = ACTIONS(2577),
    [sym_this] = ACTIONS(2577),
    [anon_sym___launch_bounds__] = ACTIONS(2577),
  },
  [STATE(308)] = {
    [sym_identifier] = ACTIONS(2581),
    [aux_sym_preproc_include_token1] = ACTIONS(2581),
    [aux_sym_preproc_def_token1] = ACTIONS(2581),
    [aux_sym_preproc_if_token1] = ACTIONS(2581),
    [aux_sym_preproc_if_token2] = ACTIONS(2581),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2581),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2581),
    [aux_sym_preproc_else_token1] = ACTIONS(2581),
    [aux_sym_preproc_elif_token1] = ACTIONS(2581),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2581),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2581),
    [sym_preproc_directive] = ACTIONS(2581),
    [anon_sym_LPAREN2] = ACTIONS(2583),
    [anon_sym_BANG] = ACTIONS(2583),
    [anon_sym_TILDE] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2583),
    [anon_sym_AMP_AMP] = ACTIONS(2583),
    [anon_sym_AMP] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym___extension__] = ACTIONS(2581),
    [anon_sym_typedef] = ACTIONS(2581),
    [anon_sym___device__] = ACTIONS(2581),
    [anon_sym___host__] = ACTIONS(2581),
    [anon_sym___global__] = ACTIONS(2581),
    [anon_sym___forceinline__] = ACTIONS(2581),
    [anon_sym___noinline__] = ACTIONS(2581),
    [anon_sym_virtual] = ACTIONS(2581),
    [anon_sym_extern] = ACTIONS(2581),
    [anon_sym___attribute__] = ACTIONS(2581),
    [anon_sym___attribute] = ACTIONS(2581),
    [anon_sym_COLON_COLON] = ACTIONS(2583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2583),
    [anon_sym___declspec] = ACTIONS(2581),
    [anon_sym___based] = ACTIONS(2581),
    [anon_sym___cdecl] = ACTIONS(2581),
    [anon_sym___clrcall] = ACTIONS(2581),
    [anon_sym___stdcall] = ACTIONS(2581),
    [anon_sym___fastcall] = ACTIONS(2581),
    [anon_sym___thiscall] = ACTIONS(2581),
    [anon_sym___vectorcall] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_signed] = ACTIONS(2581),
    [anon_sym_unsigned] = ACTIONS(2581),
    [anon_sym_long] = ACTIONS(2581),
    [anon_sym_short] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2581),
    [anon_sym_static] = ACTIONS(2581),
    [anon_sym_register] = ACTIONS(2581),
    [anon_sym_inline] = ACTIONS(2581),
    [anon_sym___inline] = ACTIONS(2581),
    [anon_sym___inline__] = ACTIONS(2581),
    [anon_sym___forceinline] = ACTIONS(2581),
    [anon_sym_thread_local] = ACTIONS(2581),
    [anon_sym___thread] = ACTIONS(2581),
    [anon_sym_const] = ACTIONS(2581),
    [anon_sym_constexpr] = ACTIONS(2581),
    [anon_sym_volatile] = ACTIONS(2581),
    [anon_sym_restrict] = ACTIONS(2581),
    [anon_sym___restrict__] = ACTIONS(2581),
    [anon_sym__Atomic] = ACTIONS(2581),
    [anon_sym__Noreturn] = ACTIONS(2581),
    [anon_sym_noreturn] = ACTIONS(2581),
    [anon_sym__Nonnull] = ACTIONS(2581),
    [anon_sym_mutable] = ACTIONS(2581),
    [anon_sym_constinit] = ACTIONS(2581),
    [anon_sym_consteval] = ACTIONS(2581),
    [anon_sym___shared__] = ACTIONS(2581),
    [anon_sym___local__] = ACTIONS(2581),
    [anon_sym___constant__] = ACTIONS(2581),
    [anon_sym___managed__] = ACTIONS(2581),
    [anon_sym___grid_constant__] = ACTIONS(2581),
    [anon_sym_alignas] = ACTIONS(2581),
    [anon_sym__Alignas] = ACTIONS(2581),
    [sym_primitive_type] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_class] = ACTIONS(2581),
    [anon_sym_struct] = ACTIONS(2581),
    [anon_sym_union] = ACTIONS(2581),
    [anon_sym_if] = ACTIONS(2581),
    [anon_sym_switch] = ACTIONS(2581),
    [anon_sym_case] = ACTIONS(2581),
    [anon_sym_default] = ACTIONS(2581),
    [anon_sym_while] = ACTIONS(2581),
    [anon_sym_do] = ACTIONS(2581),
    [anon_sym_for] = ACTIONS(2581),
    [anon_sym_return] = ACTIONS(2581),
    [anon_sym_break] = ACTIONS(2581),
    [anon_sym_continue] = ACTIONS(2581),
    [anon_sym_goto] = ACTIONS(2581),
    [anon_sym___try] = ACTIONS(2581),
    [anon_sym___leave] = ACTIONS(2581),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_compl] = ACTIONS(2581),
    [anon_sym_DASH_DASH] = ACTIONS(2583),
    [anon_sym_PLUS_PLUS] = ACTIONS(2583),
    [anon_sym_sizeof] = ACTIONS(2581),
    [anon_sym___alignof__] = ACTIONS(2581),
    [anon_sym___alignof] = ACTIONS(2581),
    [anon_sym__alignof] = ACTIONS(2581),
    [anon_sym_alignof] = ACTIONS(2581),
    [anon_sym__Alignof] = ACTIONS(2581),
    [anon_sym_offsetof] = ACTIONS(2581),
    [anon_sym__Generic] = ACTIONS(2581),
    [anon_sym_asm] = ACTIONS(2581),
    [anon_sym___asm__] = ACTIONS(2581),
    [anon_sym___asm] = ACTIONS(2581),
    [sym_number_literal] = ACTIONS(2583),
    [anon_sym_L_SQUOTE] = ACTIONS(2583),
    [anon_sym_u_SQUOTE] = ACTIONS(2583),
    [anon_sym_U_SQUOTE] = ACTIONS(2583),
    [anon_sym_u8_SQUOTE] = ACTIONS(2583),
    [anon_sym_SQUOTE] = ACTIONS(2583),
    [anon_sym_L_DQUOTE] = ACTIONS(2583),
    [anon_sym_u_DQUOTE] = ACTIONS(2583),
    [anon_sym_U_DQUOTE] = ACTIONS(2583),
    [anon_sym_u8_DQUOTE] = ACTIONS(2583),
    [anon_sym_DQUOTE] = ACTIONS(2583),
    [sym_true] = ACTIONS(2581),
    [sym_false] = ACTIONS(2581),
    [anon_sym_NULL] = ACTIONS(2581),
    [anon_sym_nullptr] = ACTIONS(2581),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2581),
    [anon_sym_decltype] = ACTIONS(2581),
    [anon_sym_explicit] = ACTIONS(2581),
    [anon_sym_typename] = ACTIONS(2581),
    [anon_sym_template] = ACTIONS(2581),
    [anon_sym_operator] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2581),
    [anon_sym_delete] = ACTIONS(2581),
    [anon_sym_throw] = ACTIONS(2581),
    [anon_sym_namespace] = ACTIONS(2581),
    [anon_sym_using] = ACTIONS(2581),
    [anon_sym_static_assert] = ACTIONS(2581),
    [anon_sym_concept] = ACTIONS(2581),
    [anon_sym_co_return] = ACTIONS(2581),
    [anon_sym_co_yield] = ACTIONS(2581),
    [anon_sym_R_DQUOTE] = ACTIONS(2583),
    [anon_sym_LR_DQUOTE] = ACTIONS(2583),
    [anon_sym_uR_DQUOTE] = ACTIONS(2583),
    [anon_sym_UR_DQUOTE] = ACTIONS(2583),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2583),
    [anon_sym_co_await] = ACTIONS(2581),
    [anon_sym_new] = ACTIONS(2581),
    [anon_sym_requires] = ACTIONS(2581),
    [sym_this] = ACTIONS(2581),
    [anon_sym___launch_bounds__] = ACTIONS(2581),
  },
  [STATE(309)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_include_token1] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token2] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [aux_sym_preproc_else_token1] = ACTIONS(2585),
    [aux_sym_preproc_elif_token1] = ACTIONS(2585),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym___cdecl] = ACTIONS(2585),
    [anon_sym___clrcall] = ACTIONS(2585),
    [anon_sym___stdcall] = ACTIONS(2585),
    [anon_sym___fastcall] = ACTIONS(2585),
    [anon_sym___thiscall] = ACTIONS(2585),
    [anon_sym___vectorcall] = ACTIONS(2585),
    [anon_sym_LBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_switch] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_default] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_do] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_return] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_goto] = ACTIONS(2585),
    [anon_sym___try] = ACTIONS(2585),
    [anon_sym___leave] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_compl] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2587),
    [anon_sym_sizeof] = ACTIONS(2585),
    [anon_sym___alignof__] = ACTIONS(2585),
    [anon_sym___alignof] = ACTIONS(2585),
    [anon_sym__alignof] = ACTIONS(2585),
    [anon_sym_alignof] = ACTIONS(2585),
    [anon_sym__Alignof] = ACTIONS(2585),
    [anon_sym_offsetof] = ACTIONS(2585),
    [anon_sym__Generic] = ACTIONS(2585),
    [anon_sym_asm] = ACTIONS(2585),
    [anon_sym___asm__] = ACTIONS(2585),
    [anon_sym___asm] = ACTIONS(2585),
    [sym_number_literal] = ACTIONS(2587),
    [anon_sym_L_SQUOTE] = ACTIONS(2587),
    [anon_sym_u_SQUOTE] = ACTIONS(2587),
    [anon_sym_U_SQUOTE] = ACTIONS(2587),
    [anon_sym_u8_SQUOTE] = ACTIONS(2587),
    [anon_sym_SQUOTE] = ACTIONS(2587),
    [anon_sym_L_DQUOTE] = ACTIONS(2587),
    [anon_sym_u_DQUOTE] = ACTIONS(2587),
    [anon_sym_U_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8_DQUOTE] = ACTIONS(2587),
    [anon_sym_DQUOTE] = ACTIONS(2587),
    [sym_true] = ACTIONS(2585),
    [sym_false] = ACTIONS(2585),
    [anon_sym_NULL] = ACTIONS(2585),
    [anon_sym_nullptr] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_try] = ACTIONS(2585),
    [anon_sym_delete] = ACTIONS(2585),
    [anon_sym_throw] = ACTIONS(2585),
    [anon_sym_namespace] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym_concept] = ACTIONS(2585),
    [anon_sym_co_return] = ACTIONS(2585),
    [anon_sym_co_yield] = ACTIONS(2585),
    [anon_sym_R_DQUOTE] = ACTIONS(2587),
    [anon_sym_LR_DQUOTE] = ACTIONS(2587),
    [anon_sym_uR_DQUOTE] = ACTIONS(2587),
    [anon_sym_UR_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2587),
    [anon_sym_co_await] = ACTIONS(2585),
    [anon_sym_new] = ACTIONS(2585),
    [anon_sym_requires] = ACTIONS(2585),
    [sym_this] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(310)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(1986),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(311)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_include_token1] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token2] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [aux_sym_preproc_else_token1] = ACTIONS(2585),
    [aux_sym_preproc_elif_token1] = ACTIONS(2585),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym___cdecl] = ACTIONS(2585),
    [anon_sym___clrcall] = ACTIONS(2585),
    [anon_sym___stdcall] = ACTIONS(2585),
    [anon_sym___fastcall] = ACTIONS(2585),
    [anon_sym___thiscall] = ACTIONS(2585),
    [anon_sym___vectorcall] = ACTIONS(2585),
    [anon_sym_LBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_switch] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_default] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_do] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_return] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_goto] = ACTIONS(2585),
    [anon_sym___try] = ACTIONS(2585),
    [anon_sym___leave] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_compl] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2587),
    [anon_sym_sizeof] = ACTIONS(2585),
    [anon_sym___alignof__] = ACTIONS(2585),
    [anon_sym___alignof] = ACTIONS(2585),
    [anon_sym__alignof] = ACTIONS(2585),
    [anon_sym_alignof] = ACTIONS(2585),
    [anon_sym__Alignof] = ACTIONS(2585),
    [anon_sym_offsetof] = ACTIONS(2585),
    [anon_sym__Generic] = ACTIONS(2585),
    [anon_sym_asm] = ACTIONS(2585),
    [anon_sym___asm__] = ACTIONS(2585),
    [anon_sym___asm] = ACTIONS(2585),
    [sym_number_literal] = ACTIONS(2587),
    [anon_sym_L_SQUOTE] = ACTIONS(2587),
    [anon_sym_u_SQUOTE] = ACTIONS(2587),
    [anon_sym_U_SQUOTE] = ACTIONS(2587),
    [anon_sym_u8_SQUOTE] = ACTIONS(2587),
    [anon_sym_SQUOTE] = ACTIONS(2587),
    [anon_sym_L_DQUOTE] = ACTIONS(2587),
    [anon_sym_u_DQUOTE] = ACTIONS(2587),
    [anon_sym_U_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8_DQUOTE] = ACTIONS(2587),
    [anon_sym_DQUOTE] = ACTIONS(2587),
    [sym_true] = ACTIONS(2585),
    [sym_false] = ACTIONS(2585),
    [anon_sym_NULL] = ACTIONS(2585),
    [anon_sym_nullptr] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_try] = ACTIONS(2585),
    [anon_sym_delete] = ACTIONS(2585),
    [anon_sym_throw] = ACTIONS(2585),
    [anon_sym_namespace] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym_concept] = ACTIONS(2585),
    [anon_sym_co_return] = ACTIONS(2585),
    [anon_sym_co_yield] = ACTIONS(2585),
    [anon_sym_R_DQUOTE] = ACTIONS(2587),
    [anon_sym_LR_DQUOTE] = ACTIONS(2587),
    [anon_sym_uR_DQUOTE] = ACTIONS(2587),
    [anon_sym_UR_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2587),
    [anon_sym_co_await] = ACTIONS(2585),
    [anon_sym_new] = ACTIONS(2585),
    [anon_sym_requires] = ACTIONS(2585),
    [sym_this] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(312)] = {
    [sym_catch_clause] = STATE(240),
    [aux_sym_constructor_try_statement_repeat1] = STATE(240),
    [ts_builtin_sym_end] = ACTIONS(1936),
    [sym_identifier] = ACTIONS(1934),
    [aux_sym_preproc_include_token1] = ACTIONS(1934),
    [aux_sym_preproc_def_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1934),
    [sym_preproc_directive] = ACTIONS(1934),
    [anon_sym_LPAREN2] = ACTIONS(1936),
    [anon_sym_BANG] = ACTIONS(1936),
    [anon_sym_TILDE] = ACTIONS(1936),
    [anon_sym_DASH] = ACTIONS(1934),
    [anon_sym_PLUS] = ACTIONS(1934),
    [anon_sym_STAR] = ACTIONS(1936),
    [anon_sym_AMP_AMP] = ACTIONS(1936),
    [anon_sym_AMP] = ACTIONS(1934),
    [anon_sym_SEMI] = ACTIONS(1936),
    [anon_sym___extension__] = ACTIONS(1934),
    [anon_sym_typedef] = ACTIONS(1934),
    [anon_sym___device__] = ACTIONS(1934),
    [anon_sym___host__] = ACTIONS(1934),
    [anon_sym___global__] = ACTIONS(1934),
    [anon_sym___forceinline__] = ACTIONS(1934),
    [anon_sym___noinline__] = ACTIONS(1934),
    [anon_sym_virtual] = ACTIONS(1934),
    [anon_sym_extern] = ACTIONS(1934),
    [anon_sym___attribute__] = ACTIONS(1934),
    [anon_sym___attribute] = ACTIONS(1934),
    [anon_sym_COLON_COLON] = ACTIONS(1936),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1936),
    [anon_sym___declspec] = ACTIONS(1934),
    [anon_sym___based] = ACTIONS(1934),
    [anon_sym___cdecl] = ACTIONS(1934),
    [anon_sym___clrcall] = ACTIONS(1934),
    [anon_sym___stdcall] = ACTIONS(1934),
    [anon_sym___fastcall] = ACTIONS(1934),
    [anon_sym___thiscall] = ACTIONS(1934),
    [anon_sym___vectorcall] = ACTIONS(1934),
    [anon_sym_LBRACE] = ACTIONS(1936),
    [anon_sym_signed] = ACTIONS(1934),
    [anon_sym_unsigned] = ACTIONS(1934),
    [anon_sym_long] = ACTIONS(1934),
    [anon_sym_short] = ACTIONS(1934),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [anon_sym_static] = ACTIONS(1934),
    [anon_sym_register] = ACTIONS(1934),
    [anon_sym_inline] = ACTIONS(1934),
    [anon_sym___inline] = ACTIONS(1934),
    [anon_sym___inline__] = ACTIONS(1934),
    [anon_sym___forceinline] = ACTIONS(1934),
    [anon_sym_thread_local] = ACTIONS(1934),
    [anon_sym___thread] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1934),
    [anon_sym_constexpr] = ACTIONS(1934),
    [anon_sym_volatile] = ACTIONS(1934),
    [anon_sym_restrict] = ACTIONS(1934),
    [anon_sym___restrict__] = ACTIONS(1934),
    [anon_sym__Atomic] = ACTIONS(1934),
    [anon_sym__Noreturn] = ACTIONS(1934),
    [anon_sym_noreturn] = ACTIONS(1934),
    [anon_sym__Nonnull] = ACTIONS(1934),
    [anon_sym_mutable] = ACTIONS(1934),
    [anon_sym_constinit] = ACTIONS(1934),
    [anon_sym_consteval] = ACTIONS(1934),
    [anon_sym___shared__] = ACTIONS(1934),
    [anon_sym___local__] = ACTIONS(1934),
    [anon_sym___constant__] = ACTIONS(1934),
    [anon_sym___managed__] = ACTIONS(1934),
    [anon_sym___grid_constant__] = ACTIONS(1934),
    [anon_sym_alignas] = ACTIONS(1934),
    [anon_sym__Alignas] = ACTIONS(1934),
    [sym_primitive_type] = ACTIONS(1934),
    [anon_sym_enum] = ACTIONS(1934),
    [anon_sym_class] = ACTIONS(1934),
    [anon_sym_struct] = ACTIONS(1934),
    [anon_sym_union] = ACTIONS(1934),
    [anon_sym_if] = ACTIONS(1934),
    [anon_sym_else] = ACTIONS(1934),
    [anon_sym_switch] = ACTIONS(1934),
    [anon_sym_case] = ACTIONS(1934),
    [anon_sym_default] = ACTIONS(1934),
    [anon_sym_while] = ACTIONS(1934),
    [anon_sym_do] = ACTIONS(1934),
    [anon_sym_for] = ACTIONS(1934),
    [anon_sym_return] = ACTIONS(1934),
    [anon_sym_break] = ACTIONS(1934),
    [anon_sym_continue] = ACTIONS(1934),
    [anon_sym_goto] = ACTIONS(1934),
    [anon_sym___try] = ACTIONS(1934),
    [anon_sym___leave] = ACTIONS(1934),
    [anon_sym_not] = ACTIONS(1934),
    [anon_sym_compl] = ACTIONS(1934),
    [anon_sym_DASH_DASH] = ACTIONS(1936),
    [anon_sym_PLUS_PLUS] = ACTIONS(1936),
    [anon_sym_sizeof] = ACTIONS(1934),
    [anon_sym___alignof__] = ACTIONS(1934),
    [anon_sym___alignof] = ACTIONS(1934),
    [anon_sym__alignof] = ACTIONS(1934),
    [anon_sym_alignof] = ACTIONS(1934),
    [anon_sym__Alignof] = ACTIONS(1934),
    [anon_sym_offsetof] = ACTIONS(1934),
    [anon_sym__Generic] = ACTIONS(1934),
    [anon_sym_asm] = ACTIONS(1934),
    [anon_sym___asm__] = ACTIONS(1934),
    [anon_sym___asm] = ACTIONS(1934),
    [sym_number_literal] = ACTIONS(1936),
    [anon_sym_L_SQUOTE] = ACTIONS(1936),
    [anon_sym_u_SQUOTE] = ACTIONS(1936),
    [anon_sym_U_SQUOTE] = ACTIONS(1936),
    [anon_sym_u8_SQUOTE] = ACTIONS(1936),
    [anon_sym_SQUOTE] = ACTIONS(1936),
    [anon_sym_L_DQUOTE] = ACTIONS(1936),
    [anon_sym_u_DQUOTE] = ACTIONS(1936),
    [anon_sym_U_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8_DQUOTE] = ACTIONS(1936),
    [anon_sym_DQUOTE] = ACTIONS(1936),
    [sym_true] = ACTIONS(1934),
    [sym_false] = ACTIONS(1934),
    [anon_sym_NULL] = ACTIONS(1934),
    [anon_sym_nullptr] = ACTIONS(1934),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1934),
    [anon_sym_decltype] = ACTIONS(1934),
    [anon_sym_explicit] = ACTIONS(1934),
    [anon_sym_typename] = ACTIONS(1934),
    [anon_sym_template] = ACTIONS(1934),
    [anon_sym_operator] = ACTIONS(1934),
    [anon_sym_try] = ACTIONS(1934),
    [anon_sym_delete] = ACTIONS(1934),
    [anon_sym_throw] = ACTIONS(1934),
    [anon_sym_namespace] = ACTIONS(1934),
    [anon_sym_using] = ACTIONS(1934),
    [anon_sym_static_assert] = ACTIONS(1934),
    [anon_sym_concept] = ACTIONS(1934),
    [anon_sym_co_return] = ACTIONS(1934),
    [anon_sym_co_yield] = ACTIONS(1934),
    [anon_sym_catch] = ACTIONS(2589),
    [anon_sym_R_DQUOTE] = ACTIONS(1936),
    [anon_sym_LR_DQUOTE] = ACTIONS(1936),
    [anon_sym_uR_DQUOTE] = ACTIONS(1936),
    [anon_sym_UR_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1936),
    [anon_sym_co_await] = ACTIONS(1934),
    [anon_sym_new] = ACTIONS(1934),
    [anon_sym_requires] = ACTIONS(1934),
    [sym_this] = ACTIONS(1934),
    [anon_sym___launch_bounds__] = ACTIONS(1934),
  },
  [STATE(313)] = {
    [sym_identifier] = ACTIONS(2591),
    [aux_sym_preproc_include_token1] = ACTIONS(2591),
    [aux_sym_preproc_def_token1] = ACTIONS(2591),
    [aux_sym_preproc_if_token1] = ACTIONS(2591),
    [aux_sym_preproc_if_token2] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2591),
    [aux_sym_preproc_elif_token1] = ACTIONS(2591),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2591),
    [sym_preproc_directive] = ACTIONS(2591),
    [anon_sym_LPAREN2] = ACTIONS(2593),
    [anon_sym_BANG] = ACTIONS(2593),
    [anon_sym_TILDE] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2591),
    [anon_sym_PLUS] = ACTIONS(2591),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_AMP_AMP] = ACTIONS(2593),
    [anon_sym_AMP] = ACTIONS(2591),
    [anon_sym_SEMI] = ACTIONS(2593),
    [anon_sym___extension__] = ACTIONS(2591),
    [anon_sym_typedef] = ACTIONS(2591),
    [anon_sym___device__] = ACTIONS(2591),
    [anon_sym___host__] = ACTIONS(2591),
    [anon_sym___global__] = ACTIONS(2591),
    [anon_sym___forceinline__] = ACTIONS(2591),
    [anon_sym___noinline__] = ACTIONS(2591),
    [anon_sym_virtual] = ACTIONS(2591),
    [anon_sym_extern] = ACTIONS(2591),
    [anon_sym___attribute__] = ACTIONS(2591),
    [anon_sym___attribute] = ACTIONS(2591),
    [anon_sym_COLON_COLON] = ACTIONS(2593),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2593),
    [anon_sym___declspec] = ACTIONS(2591),
    [anon_sym___based] = ACTIONS(2591),
    [anon_sym___cdecl] = ACTIONS(2591),
    [anon_sym___clrcall] = ACTIONS(2591),
    [anon_sym___stdcall] = ACTIONS(2591),
    [anon_sym___fastcall] = ACTIONS(2591),
    [anon_sym___thiscall] = ACTIONS(2591),
    [anon_sym___vectorcall] = ACTIONS(2591),
    [anon_sym_LBRACE] = ACTIONS(2593),
    [anon_sym_signed] = ACTIONS(2591),
    [anon_sym_unsigned] = ACTIONS(2591),
    [anon_sym_long] = ACTIONS(2591),
    [anon_sym_short] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [anon_sym_static] = ACTIONS(2591),
    [anon_sym_register] = ACTIONS(2591),
    [anon_sym_inline] = ACTIONS(2591),
    [anon_sym___inline] = ACTIONS(2591),
    [anon_sym___inline__] = ACTIONS(2591),
    [anon_sym___forceinline] = ACTIONS(2591),
    [anon_sym_thread_local] = ACTIONS(2591),
    [anon_sym___thread] = ACTIONS(2591),
    [anon_sym_const] = ACTIONS(2591),
    [anon_sym_constexpr] = ACTIONS(2591),
    [anon_sym_volatile] = ACTIONS(2591),
    [anon_sym_restrict] = ACTIONS(2591),
    [anon_sym___restrict__] = ACTIONS(2591),
    [anon_sym__Atomic] = ACTIONS(2591),
    [anon_sym__Noreturn] = ACTIONS(2591),
    [anon_sym_noreturn] = ACTIONS(2591),
    [anon_sym__Nonnull] = ACTIONS(2591),
    [anon_sym_mutable] = ACTIONS(2591),
    [anon_sym_constinit] = ACTIONS(2591),
    [anon_sym_consteval] = ACTIONS(2591),
    [anon_sym___shared__] = ACTIONS(2591),
    [anon_sym___local__] = ACTIONS(2591),
    [anon_sym___constant__] = ACTIONS(2591),
    [anon_sym___managed__] = ACTIONS(2591),
    [anon_sym___grid_constant__] = ACTIONS(2591),
    [anon_sym_alignas] = ACTIONS(2591),
    [anon_sym__Alignas] = ACTIONS(2591),
    [sym_primitive_type] = ACTIONS(2591),
    [anon_sym_enum] = ACTIONS(2591),
    [anon_sym_class] = ACTIONS(2591),
    [anon_sym_struct] = ACTIONS(2591),
    [anon_sym_union] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_switch] = ACTIONS(2591),
    [anon_sym_case] = ACTIONS(2591),
    [anon_sym_default] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(2591),
    [anon_sym_do] = ACTIONS(2591),
    [anon_sym_for] = ACTIONS(2591),
    [anon_sym_return] = ACTIONS(2591),
    [anon_sym_break] = ACTIONS(2591),
    [anon_sym_continue] = ACTIONS(2591),
    [anon_sym_goto] = ACTIONS(2591),
    [anon_sym___try] = ACTIONS(2591),
    [anon_sym___leave] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_compl] = ACTIONS(2591),
    [anon_sym_DASH_DASH] = ACTIONS(2593),
    [anon_sym_PLUS_PLUS] = ACTIONS(2593),
    [anon_sym_sizeof] = ACTIONS(2591),
    [anon_sym___alignof__] = ACTIONS(2591),
    [anon_sym___alignof] = ACTIONS(2591),
    [anon_sym__alignof] = ACTIONS(2591),
    [anon_sym_alignof] = ACTIONS(2591),
    [anon_sym__Alignof] = ACTIONS(2591),
    [anon_sym_offsetof] = ACTIONS(2591),
    [anon_sym__Generic] = ACTIONS(2591),
    [anon_sym_asm] = ACTIONS(2591),
    [anon_sym___asm__] = ACTIONS(2591),
    [anon_sym___asm] = ACTIONS(2591),
    [sym_number_literal] = ACTIONS(2593),
    [anon_sym_L_SQUOTE] = ACTIONS(2593),
    [anon_sym_u_SQUOTE] = ACTIONS(2593),
    [anon_sym_U_SQUOTE] = ACTIONS(2593),
    [anon_sym_u8_SQUOTE] = ACTIONS(2593),
    [anon_sym_SQUOTE] = ACTIONS(2593),
    [anon_sym_L_DQUOTE] = ACTIONS(2593),
    [anon_sym_u_DQUOTE] = ACTIONS(2593),
    [anon_sym_U_DQUOTE] = ACTIONS(2593),
    [anon_sym_u8_DQUOTE] = ACTIONS(2593),
    [anon_sym_DQUOTE] = ACTIONS(2593),
    [sym_true] = ACTIONS(2591),
    [sym_false] = ACTIONS(2591),
    [anon_sym_NULL] = ACTIONS(2591),
    [anon_sym_nullptr] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2591),
    [anon_sym_decltype] = ACTIONS(2591),
    [anon_sym_explicit] = ACTIONS(2591),
    [anon_sym_typename] = ACTIONS(2591),
    [anon_sym_template] = ACTIONS(2591),
    [anon_sym_operator] = ACTIONS(2591),
    [anon_sym_try] = ACTIONS(2591),
    [anon_sym_delete] = ACTIONS(2591),
    [anon_sym_throw] = ACTIONS(2591),
    [anon_sym_namespace] = ACTIONS(2591),
    [anon_sym_using] = ACTIONS(2591),
    [anon_sym_static_assert] = ACTIONS(2591),
    [anon_sym_concept] = ACTIONS(2591),
    [anon_sym_co_return] = ACTIONS(2591),
    [anon_sym_co_yield] = ACTIONS(2591),
    [anon_sym_R_DQUOTE] = ACTIONS(2593),
    [anon_sym_LR_DQUOTE] = ACTIONS(2593),
    [anon_sym_uR_DQUOTE] = ACTIONS(2593),
    [anon_sym_UR_DQUOTE] = ACTIONS(2593),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2593),
    [anon_sym_co_await] = ACTIONS(2591),
    [anon_sym_new] = ACTIONS(2591),
    [anon_sym_requires] = ACTIONS(2591),
    [sym_this] = ACTIONS(2591),
    [anon_sym___launch_bounds__] = ACTIONS(2591),
  },
  [STATE(314)] = {
    [sym_identifier] = ACTIONS(2595),
    [aux_sym_preproc_include_token1] = ACTIONS(2595),
    [aux_sym_preproc_def_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token2] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2595),
    [aux_sym_preproc_else_token1] = ACTIONS(2595),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2595),
    [sym_preproc_directive] = ACTIONS(2595),
    [anon_sym_LPAREN2] = ACTIONS(2597),
    [anon_sym_BANG] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_DASH] = ACTIONS(2595),
    [anon_sym_PLUS] = ACTIONS(2595),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_AMP_AMP] = ACTIONS(2597),
    [anon_sym_AMP] = ACTIONS(2595),
    [anon_sym_SEMI] = ACTIONS(2597),
    [anon_sym___extension__] = ACTIONS(2595),
    [anon_sym_typedef] = ACTIONS(2595),
    [anon_sym___device__] = ACTIONS(2595),
    [anon_sym___host__] = ACTIONS(2595),
    [anon_sym___global__] = ACTIONS(2595),
    [anon_sym___forceinline__] = ACTIONS(2595),
    [anon_sym___noinline__] = ACTIONS(2595),
    [anon_sym_virtual] = ACTIONS(2595),
    [anon_sym_extern] = ACTIONS(2595),
    [anon_sym___attribute__] = ACTIONS(2595),
    [anon_sym___attribute] = ACTIONS(2595),
    [anon_sym_COLON_COLON] = ACTIONS(2597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2597),
    [anon_sym___declspec] = ACTIONS(2595),
    [anon_sym___based] = ACTIONS(2595),
    [anon_sym___cdecl] = ACTIONS(2595),
    [anon_sym___clrcall] = ACTIONS(2595),
    [anon_sym___stdcall] = ACTIONS(2595),
    [anon_sym___fastcall] = ACTIONS(2595),
    [anon_sym___thiscall] = ACTIONS(2595),
    [anon_sym___vectorcall] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_signed] = ACTIONS(2595),
    [anon_sym_unsigned] = ACTIONS(2595),
    [anon_sym_long] = ACTIONS(2595),
    [anon_sym_short] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_register] = ACTIONS(2595),
    [anon_sym_inline] = ACTIONS(2595),
    [anon_sym___inline] = ACTIONS(2595),
    [anon_sym___inline__] = ACTIONS(2595),
    [anon_sym___forceinline] = ACTIONS(2595),
    [anon_sym_thread_local] = ACTIONS(2595),
    [anon_sym___thread] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_constexpr] = ACTIONS(2595),
    [anon_sym_volatile] = ACTIONS(2595),
    [anon_sym_restrict] = ACTIONS(2595),
    [anon_sym___restrict__] = ACTIONS(2595),
    [anon_sym__Atomic] = ACTIONS(2595),
    [anon_sym__Noreturn] = ACTIONS(2595),
    [anon_sym_noreturn] = ACTIONS(2595),
    [anon_sym__Nonnull] = ACTIONS(2595),
    [anon_sym_mutable] = ACTIONS(2595),
    [anon_sym_constinit] = ACTIONS(2595),
    [anon_sym_consteval] = ACTIONS(2595),
    [anon_sym___shared__] = ACTIONS(2595),
    [anon_sym___local__] = ACTIONS(2595),
    [anon_sym___constant__] = ACTIONS(2595),
    [anon_sym___managed__] = ACTIONS(2595),
    [anon_sym___grid_constant__] = ACTIONS(2595),
    [anon_sym_alignas] = ACTIONS(2595),
    [anon_sym__Alignas] = ACTIONS(2595),
    [sym_primitive_type] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_struct] = ACTIONS(2595),
    [anon_sym_union] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2595),
    [anon_sym_switch] = ACTIONS(2595),
    [anon_sym_case] = ACTIONS(2595),
    [anon_sym_default] = ACTIONS(2595),
    [anon_sym_while] = ACTIONS(2595),
    [anon_sym_do] = ACTIONS(2595),
    [anon_sym_for] = ACTIONS(2595),
    [anon_sym_return] = ACTIONS(2595),
    [anon_sym_break] = ACTIONS(2595),
    [anon_sym_continue] = ACTIONS(2595),
    [anon_sym_goto] = ACTIONS(2595),
    [anon_sym___try] = ACTIONS(2595),
    [anon_sym___leave] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2595),
    [anon_sym_compl] = ACTIONS(2595),
    [anon_sym_DASH_DASH] = ACTIONS(2597),
    [anon_sym_PLUS_PLUS] = ACTIONS(2597),
    [anon_sym_sizeof] = ACTIONS(2595),
    [anon_sym___alignof__] = ACTIONS(2595),
    [anon_sym___alignof] = ACTIONS(2595),
    [anon_sym__alignof] = ACTIONS(2595),
    [anon_sym_alignof] = ACTIONS(2595),
    [anon_sym__Alignof] = ACTIONS(2595),
    [anon_sym_offsetof] = ACTIONS(2595),
    [anon_sym__Generic] = ACTIONS(2595),
    [anon_sym_asm] = ACTIONS(2595),
    [anon_sym___asm__] = ACTIONS(2595),
    [anon_sym___asm] = ACTIONS(2595),
    [sym_number_literal] = ACTIONS(2597),
    [anon_sym_L_SQUOTE] = ACTIONS(2597),
    [anon_sym_u_SQUOTE] = ACTIONS(2597),
    [anon_sym_U_SQUOTE] = ACTIONS(2597),
    [anon_sym_u8_SQUOTE] = ACTIONS(2597),
    [anon_sym_SQUOTE] = ACTIONS(2597),
    [anon_sym_L_DQUOTE] = ACTIONS(2597),
    [anon_sym_u_DQUOTE] = ACTIONS(2597),
    [anon_sym_U_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8_DQUOTE] = ACTIONS(2597),
    [anon_sym_DQUOTE] = ACTIONS(2597),
    [sym_true] = ACTIONS(2595),
    [sym_false] = ACTIONS(2595),
    [anon_sym_NULL] = ACTIONS(2595),
    [anon_sym_nullptr] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2595),
    [anon_sym_decltype] = ACTIONS(2595),
    [anon_sym_explicit] = ACTIONS(2595),
    [anon_sym_typename] = ACTIONS(2595),
    [anon_sym_template] = ACTIONS(2595),
    [anon_sym_operator] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2595),
    [anon_sym_delete] = ACTIONS(2595),
    [anon_sym_throw] = ACTIONS(2595),
    [anon_sym_namespace] = ACTIONS(2595),
    [anon_sym_using] = ACTIONS(2595),
    [anon_sym_static_assert] = ACTIONS(2595),
    [anon_sym_concept] = ACTIONS(2595),
    [anon_sym_co_return] = ACTIONS(2595),
    [anon_sym_co_yield] = ACTIONS(2595),
    [anon_sym_R_DQUOTE] = ACTIONS(2597),
    [anon_sym_LR_DQUOTE] = ACTIONS(2597),
    [anon_sym_uR_DQUOTE] = ACTIONS(2597),
    [anon_sym_UR_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2597),
    [anon_sym_co_await] = ACTIONS(2595),
    [anon_sym_new] = ACTIONS(2595),
    [anon_sym_requires] = ACTIONS(2595),
    [sym_this] = ACTIONS(2595),
    [anon_sym___launch_bounds__] = ACTIONS(2595),
  },
  [STATE(315)] = {
    [sym_identifier] = ACTIONS(2599),
    [aux_sym_preproc_include_token1] = ACTIONS(2599),
    [aux_sym_preproc_def_token1] = ACTIONS(2599),
    [aux_sym_preproc_if_token1] = ACTIONS(2599),
    [aux_sym_preproc_if_token2] = ACTIONS(2599),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2599),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2599),
    [aux_sym_preproc_else_token1] = ACTIONS(2599),
    [aux_sym_preproc_elif_token1] = ACTIONS(2599),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2599),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2599),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_BANG] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2601),
    [anon_sym_DASH] = ACTIONS(2599),
    [anon_sym_PLUS] = ACTIONS(2599),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_AMP_AMP] = ACTIONS(2601),
    [anon_sym_AMP] = ACTIONS(2599),
    [anon_sym_SEMI] = ACTIONS(2601),
    [anon_sym___extension__] = ACTIONS(2599),
    [anon_sym_typedef] = ACTIONS(2599),
    [anon_sym___device__] = ACTIONS(2599),
    [anon_sym___host__] = ACTIONS(2599),
    [anon_sym___global__] = ACTIONS(2599),
    [anon_sym___forceinline__] = ACTIONS(2599),
    [anon_sym___noinline__] = ACTIONS(2599),
    [anon_sym_virtual] = ACTIONS(2599),
    [anon_sym_extern] = ACTIONS(2599),
    [anon_sym___attribute__] = ACTIONS(2599),
    [anon_sym___attribute] = ACTIONS(2599),
    [anon_sym_COLON_COLON] = ACTIONS(2601),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2601),
    [anon_sym___declspec] = ACTIONS(2599),
    [anon_sym___based] = ACTIONS(2599),
    [anon_sym___cdecl] = ACTIONS(2599),
    [anon_sym___clrcall] = ACTIONS(2599),
    [anon_sym___stdcall] = ACTIONS(2599),
    [anon_sym___fastcall] = ACTIONS(2599),
    [anon_sym___thiscall] = ACTIONS(2599),
    [anon_sym___vectorcall] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(2601),
    [anon_sym_signed] = ACTIONS(2599),
    [anon_sym_unsigned] = ACTIONS(2599),
    [anon_sym_long] = ACTIONS(2599),
    [anon_sym_short] = ACTIONS(2599),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [anon_sym_static] = ACTIONS(2599),
    [anon_sym_register] = ACTIONS(2599),
    [anon_sym_inline] = ACTIONS(2599),
    [anon_sym___inline] = ACTIONS(2599),
    [anon_sym___inline__] = ACTIONS(2599),
    [anon_sym___forceinline] = ACTIONS(2599),
    [anon_sym_thread_local] = ACTIONS(2599),
    [anon_sym___thread] = ACTIONS(2599),
    [anon_sym_const] = ACTIONS(2599),
    [anon_sym_constexpr] = ACTIONS(2599),
    [anon_sym_volatile] = ACTIONS(2599),
    [anon_sym_restrict] = ACTIONS(2599),
    [anon_sym___restrict__] = ACTIONS(2599),
    [anon_sym__Atomic] = ACTIONS(2599),
    [anon_sym__Noreturn] = ACTIONS(2599),
    [anon_sym_noreturn] = ACTIONS(2599),
    [anon_sym__Nonnull] = ACTIONS(2599),
    [anon_sym_mutable] = ACTIONS(2599),
    [anon_sym_constinit] = ACTIONS(2599),
    [anon_sym_consteval] = ACTIONS(2599),
    [anon_sym___shared__] = ACTIONS(2599),
    [anon_sym___local__] = ACTIONS(2599),
    [anon_sym___constant__] = ACTIONS(2599),
    [anon_sym___managed__] = ACTIONS(2599),
    [anon_sym___grid_constant__] = ACTIONS(2599),
    [anon_sym_alignas] = ACTIONS(2599),
    [anon_sym__Alignas] = ACTIONS(2599),
    [sym_primitive_type] = ACTIONS(2599),
    [anon_sym_enum] = ACTIONS(2599),
    [anon_sym_class] = ACTIONS(2599),
    [anon_sym_struct] = ACTIONS(2599),
    [anon_sym_union] = ACTIONS(2599),
    [anon_sym_if] = ACTIONS(2599),
    [anon_sym_switch] = ACTIONS(2599),
    [anon_sym_case] = ACTIONS(2599),
    [anon_sym_default] = ACTIONS(2599),
    [anon_sym_while] = ACTIONS(2599),
    [anon_sym_do] = ACTIONS(2599),
    [anon_sym_for] = ACTIONS(2599),
    [anon_sym_return] = ACTIONS(2599),
    [anon_sym_break] = ACTIONS(2599),
    [anon_sym_continue] = ACTIONS(2599),
    [anon_sym_goto] = ACTIONS(2599),
    [anon_sym___try] = ACTIONS(2599),
    [anon_sym___leave] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2599),
    [anon_sym_compl] = ACTIONS(2599),
    [anon_sym_DASH_DASH] = ACTIONS(2601),
    [anon_sym_PLUS_PLUS] = ACTIONS(2601),
    [anon_sym_sizeof] = ACTIONS(2599),
    [anon_sym___alignof__] = ACTIONS(2599),
    [anon_sym___alignof] = ACTIONS(2599),
    [anon_sym__alignof] = ACTIONS(2599),
    [anon_sym_alignof] = ACTIONS(2599),
    [anon_sym__Alignof] = ACTIONS(2599),
    [anon_sym_offsetof] = ACTIONS(2599),
    [anon_sym__Generic] = ACTIONS(2599),
    [anon_sym_asm] = ACTIONS(2599),
    [anon_sym___asm__] = ACTIONS(2599),
    [anon_sym___asm] = ACTIONS(2599),
    [sym_number_literal] = ACTIONS(2601),
    [anon_sym_L_SQUOTE] = ACTIONS(2601),
    [anon_sym_u_SQUOTE] = ACTIONS(2601),
    [anon_sym_U_SQUOTE] = ACTIONS(2601),
    [anon_sym_u8_SQUOTE] = ACTIONS(2601),
    [anon_sym_SQUOTE] = ACTIONS(2601),
    [anon_sym_L_DQUOTE] = ACTIONS(2601),
    [anon_sym_u_DQUOTE] = ACTIONS(2601),
    [anon_sym_U_DQUOTE] = ACTIONS(2601),
    [anon_sym_u8_DQUOTE] = ACTIONS(2601),
    [anon_sym_DQUOTE] = ACTIONS(2601),
    [sym_true] = ACTIONS(2599),
    [sym_false] = ACTIONS(2599),
    [anon_sym_NULL] = ACTIONS(2599),
    [anon_sym_nullptr] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2599),
    [anon_sym_decltype] = ACTIONS(2599),
    [anon_sym_explicit] = ACTIONS(2599),
    [anon_sym_typename] = ACTIONS(2599),
    [anon_sym_template] = ACTIONS(2599),
    [anon_sym_operator] = ACTIONS(2599),
    [anon_sym_try] = ACTIONS(2599),
    [anon_sym_delete] = ACTIONS(2599),
    [anon_sym_throw] = ACTIONS(2599),
    [anon_sym_namespace] = ACTIONS(2599),
    [anon_sym_using] = ACTIONS(2599),
    [anon_sym_static_assert] = ACTIONS(2599),
    [anon_sym_concept] = ACTIONS(2599),
    [anon_sym_co_return] = ACTIONS(2599),
    [anon_sym_co_yield] = ACTIONS(2599),
    [anon_sym_R_DQUOTE] = ACTIONS(2601),
    [anon_sym_LR_DQUOTE] = ACTIONS(2601),
    [anon_sym_uR_DQUOTE] = ACTIONS(2601),
    [anon_sym_UR_DQUOTE] = ACTIONS(2601),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2601),
    [anon_sym_co_await] = ACTIONS(2599),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_requires] = ACTIONS(2599),
    [sym_this] = ACTIONS(2599),
    [anon_sym___launch_bounds__] = ACTIONS(2599),
  },
  [STATE(316)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(2603),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(317)] = {
    [sym_identifier] = ACTIONS(2605),
    [aux_sym_preproc_include_token1] = ACTIONS(2605),
    [aux_sym_preproc_def_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token2] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2605),
    [aux_sym_preproc_else_token1] = ACTIONS(2605),
    [aux_sym_preproc_elif_token1] = ACTIONS(2605),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2605),
    [sym_preproc_directive] = ACTIONS(2605),
    [anon_sym_LPAREN2] = ACTIONS(2607),
    [anon_sym_BANG] = ACTIONS(2607),
    [anon_sym_TILDE] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2607),
    [anon_sym_AMP_AMP] = ACTIONS(2607),
    [anon_sym_AMP] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2605),
    [anon_sym_typedef] = ACTIONS(2605),
    [anon_sym___device__] = ACTIONS(2605),
    [anon_sym___host__] = ACTIONS(2605),
    [anon_sym___global__] = ACTIONS(2605),
    [anon_sym___forceinline__] = ACTIONS(2605),
    [anon_sym___noinline__] = ACTIONS(2605),
    [anon_sym_virtual] = ACTIONS(2605),
    [anon_sym_extern] = ACTIONS(2605),
    [anon_sym___attribute__] = ACTIONS(2605),
    [anon_sym___attribute] = ACTIONS(2605),
    [anon_sym_COLON_COLON] = ACTIONS(2607),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2607),
    [anon_sym___declspec] = ACTIONS(2605),
    [anon_sym___based] = ACTIONS(2605),
    [anon_sym___cdecl] = ACTIONS(2605),
    [anon_sym___clrcall] = ACTIONS(2605),
    [anon_sym___stdcall] = ACTIONS(2605),
    [anon_sym___fastcall] = ACTIONS(2605),
    [anon_sym___thiscall] = ACTIONS(2605),
    [anon_sym___vectorcall] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(2607),
    [anon_sym_signed] = ACTIONS(2605),
    [anon_sym_unsigned] = ACTIONS(2605),
    [anon_sym_long] = ACTIONS(2605),
    [anon_sym_short] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2605),
    [anon_sym_static] = ACTIONS(2605),
    [anon_sym_register] = ACTIONS(2605),
    [anon_sym_inline] = ACTIONS(2605),
    [anon_sym___inline] = ACTIONS(2605),
    [anon_sym___inline__] = ACTIONS(2605),
    [anon_sym___forceinline] = ACTIONS(2605),
    [anon_sym_thread_local] = ACTIONS(2605),
    [anon_sym___thread] = ACTIONS(2605),
    [anon_sym_const] = ACTIONS(2605),
    [anon_sym_constexpr] = ACTIONS(2605),
    [anon_sym_volatile] = ACTIONS(2605),
    [anon_sym_restrict] = ACTIONS(2605),
    [anon_sym___restrict__] = ACTIONS(2605),
    [anon_sym__Atomic] = ACTIONS(2605),
    [anon_sym__Noreturn] = ACTIONS(2605),
    [anon_sym_noreturn] = ACTIONS(2605),
    [anon_sym__Nonnull] = ACTIONS(2605),
    [anon_sym_mutable] = ACTIONS(2605),
    [anon_sym_constinit] = ACTIONS(2605),
    [anon_sym_consteval] = ACTIONS(2605),
    [anon_sym___shared__] = ACTIONS(2605),
    [anon_sym___local__] = ACTIONS(2605),
    [anon_sym___constant__] = ACTIONS(2605),
    [anon_sym___managed__] = ACTIONS(2605),
    [anon_sym___grid_constant__] = ACTIONS(2605),
    [anon_sym_alignas] = ACTIONS(2605),
    [anon_sym__Alignas] = ACTIONS(2605),
    [sym_primitive_type] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_class] = ACTIONS(2605),
    [anon_sym_struct] = ACTIONS(2605),
    [anon_sym_union] = ACTIONS(2605),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_switch] = ACTIONS(2605),
    [anon_sym_case] = ACTIONS(2605),
    [anon_sym_default] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(2605),
    [anon_sym_do] = ACTIONS(2605),
    [anon_sym_for] = ACTIONS(2605),
    [anon_sym_return] = ACTIONS(2605),
    [anon_sym_break] = ACTIONS(2605),
    [anon_sym_continue] = ACTIONS(2605),
    [anon_sym_goto] = ACTIONS(2605),
    [anon_sym___try] = ACTIONS(2605),
    [anon_sym___leave] = ACTIONS(2605),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_compl] = ACTIONS(2605),
    [anon_sym_DASH_DASH] = ACTIONS(2607),
    [anon_sym_PLUS_PLUS] = ACTIONS(2607),
    [anon_sym_sizeof] = ACTIONS(2605),
    [anon_sym___alignof__] = ACTIONS(2605),
    [anon_sym___alignof] = ACTIONS(2605),
    [anon_sym__alignof] = ACTIONS(2605),
    [anon_sym_alignof] = ACTIONS(2605),
    [anon_sym__Alignof] = ACTIONS(2605),
    [anon_sym_offsetof] = ACTIONS(2605),
    [anon_sym__Generic] = ACTIONS(2605),
    [anon_sym_asm] = ACTIONS(2605),
    [anon_sym___asm__] = ACTIONS(2605),
    [anon_sym___asm] = ACTIONS(2605),
    [sym_number_literal] = ACTIONS(2607),
    [anon_sym_L_SQUOTE] = ACTIONS(2607),
    [anon_sym_u_SQUOTE] = ACTIONS(2607),
    [anon_sym_U_SQUOTE] = ACTIONS(2607),
    [anon_sym_u8_SQUOTE] = ACTIONS(2607),
    [anon_sym_SQUOTE] = ACTIONS(2607),
    [anon_sym_L_DQUOTE] = ACTIONS(2607),
    [anon_sym_u_DQUOTE] = ACTIONS(2607),
    [anon_sym_U_DQUOTE] = ACTIONS(2607),
    [anon_sym_u8_DQUOTE] = ACTIONS(2607),
    [anon_sym_DQUOTE] = ACTIONS(2607),
    [sym_true] = ACTIONS(2605),
    [sym_false] = ACTIONS(2605),
    [anon_sym_NULL] = ACTIONS(2605),
    [anon_sym_nullptr] = ACTIONS(2605),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2605),
    [anon_sym_decltype] = ACTIONS(2605),
    [anon_sym_explicit] = ACTIONS(2605),
    [anon_sym_typename] = ACTIONS(2605),
    [anon_sym_template] = ACTIONS(2605),
    [anon_sym_operator] = ACTIONS(2605),
    [anon_sym_try] = ACTIONS(2605),
    [anon_sym_delete] = ACTIONS(2605),
    [anon_sym_throw] = ACTIONS(2605),
    [anon_sym_namespace] = ACTIONS(2605),
    [anon_sym_using] = ACTIONS(2605),
    [anon_sym_static_assert] = ACTIONS(2605),
    [anon_sym_concept] = ACTIONS(2605),
    [anon_sym_co_return] = ACTIONS(2605),
    [anon_sym_co_yield] = ACTIONS(2605),
    [anon_sym_R_DQUOTE] = ACTIONS(2607),
    [anon_sym_LR_DQUOTE] = ACTIONS(2607),
    [anon_sym_uR_DQUOTE] = ACTIONS(2607),
    [anon_sym_UR_DQUOTE] = ACTIONS(2607),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2607),
    [anon_sym_co_await] = ACTIONS(2605),
    [anon_sym_new] = ACTIONS(2605),
    [anon_sym_requires] = ACTIONS(2605),
    [sym_this] = ACTIONS(2605),
    [anon_sym___launch_bounds__] = ACTIONS(2605),
  },
  [STATE(318)] = {
    [sym_identifier] = ACTIONS(2609),
    [aux_sym_preproc_include_token1] = ACTIONS(2609),
    [aux_sym_preproc_def_token1] = ACTIONS(2609),
    [aux_sym_preproc_if_token1] = ACTIONS(2609),
    [aux_sym_preproc_if_token2] = ACTIONS(2609),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2609),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2609),
    [aux_sym_preproc_else_token1] = ACTIONS(2609),
    [aux_sym_preproc_elif_token1] = ACTIONS(2609),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2609),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2609),
    [sym_preproc_directive] = ACTIONS(2609),
    [anon_sym_LPAREN2] = ACTIONS(2611),
    [anon_sym_BANG] = ACTIONS(2611),
    [anon_sym_TILDE] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2611),
    [anon_sym_AMP_AMP] = ACTIONS(2611),
    [anon_sym_AMP] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2609),
    [anon_sym___device__] = ACTIONS(2609),
    [anon_sym___host__] = ACTIONS(2609),
    [anon_sym___global__] = ACTIONS(2609),
    [anon_sym___forceinline__] = ACTIONS(2609),
    [anon_sym___noinline__] = ACTIONS(2609),
    [anon_sym_virtual] = ACTIONS(2609),
    [anon_sym_extern] = ACTIONS(2609),
    [anon_sym___attribute__] = ACTIONS(2609),
    [anon_sym___attribute] = ACTIONS(2609),
    [anon_sym_COLON_COLON] = ACTIONS(2611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2611),
    [anon_sym___declspec] = ACTIONS(2609),
    [anon_sym___based] = ACTIONS(2609),
    [anon_sym___cdecl] = ACTIONS(2609),
    [anon_sym___clrcall] = ACTIONS(2609),
    [anon_sym___stdcall] = ACTIONS(2609),
    [anon_sym___fastcall] = ACTIONS(2609),
    [anon_sym___thiscall] = ACTIONS(2609),
    [anon_sym___vectorcall] = ACTIONS(2609),
    [anon_sym_LBRACE] = ACTIONS(2611),
    [anon_sym_signed] = ACTIONS(2609),
    [anon_sym_unsigned] = ACTIONS(2609),
    [anon_sym_long] = ACTIONS(2609),
    [anon_sym_short] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2609),
    [anon_sym_static] = ACTIONS(2609),
    [anon_sym_register] = ACTIONS(2609),
    [anon_sym_inline] = ACTIONS(2609),
    [anon_sym___inline] = ACTIONS(2609),
    [anon_sym___inline__] = ACTIONS(2609),
    [anon_sym___forceinline] = ACTIONS(2609),
    [anon_sym_thread_local] = ACTIONS(2609),
    [anon_sym___thread] = ACTIONS(2609),
    [anon_sym_const] = ACTIONS(2609),
    [anon_sym_constexpr] = ACTIONS(2609),
    [anon_sym_volatile] = ACTIONS(2609),
    [anon_sym_restrict] = ACTIONS(2609),
    [anon_sym___restrict__] = ACTIONS(2609),
    [anon_sym__Atomic] = ACTIONS(2609),
    [anon_sym__Noreturn] = ACTIONS(2609),
    [anon_sym_noreturn] = ACTIONS(2609),
    [anon_sym__Nonnull] = ACTIONS(2609),
    [anon_sym_mutable] = ACTIONS(2609),
    [anon_sym_constinit] = ACTIONS(2609),
    [anon_sym_consteval] = ACTIONS(2609),
    [anon_sym___shared__] = ACTIONS(2609),
    [anon_sym___local__] = ACTIONS(2609),
    [anon_sym___constant__] = ACTIONS(2609),
    [anon_sym___managed__] = ACTIONS(2609),
    [anon_sym___grid_constant__] = ACTIONS(2609),
    [anon_sym_alignas] = ACTIONS(2609),
    [anon_sym__Alignas] = ACTIONS(2609),
    [sym_primitive_type] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_class] = ACTIONS(2609),
    [anon_sym_struct] = ACTIONS(2609),
    [anon_sym_union] = ACTIONS(2609),
    [anon_sym_if] = ACTIONS(2609),
    [anon_sym_switch] = ACTIONS(2609),
    [anon_sym_case] = ACTIONS(2609),
    [anon_sym_default] = ACTIONS(2609),
    [anon_sym_while] = ACTIONS(2609),
    [anon_sym_do] = ACTIONS(2609),
    [anon_sym_for] = ACTIONS(2609),
    [anon_sym_return] = ACTIONS(2609),
    [anon_sym_break] = ACTIONS(2609),
    [anon_sym_continue] = ACTIONS(2609),
    [anon_sym_goto] = ACTIONS(2609),
    [anon_sym___try] = ACTIONS(2609),
    [anon_sym___leave] = ACTIONS(2609),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_compl] = ACTIONS(2609),
    [anon_sym_DASH_DASH] = ACTIONS(2611),
    [anon_sym_PLUS_PLUS] = ACTIONS(2611),
    [anon_sym_sizeof] = ACTIONS(2609),
    [anon_sym___alignof__] = ACTIONS(2609),
    [anon_sym___alignof] = ACTIONS(2609),
    [anon_sym__alignof] = ACTIONS(2609),
    [anon_sym_alignof] = ACTIONS(2609),
    [anon_sym__Alignof] = ACTIONS(2609),
    [anon_sym_offsetof] = ACTIONS(2609),
    [anon_sym__Generic] = ACTIONS(2609),
    [anon_sym_asm] = ACTIONS(2609),
    [anon_sym___asm__] = ACTIONS(2609),
    [anon_sym___asm] = ACTIONS(2609),
    [sym_number_literal] = ACTIONS(2611),
    [anon_sym_L_SQUOTE] = ACTIONS(2611),
    [anon_sym_u_SQUOTE] = ACTIONS(2611),
    [anon_sym_U_SQUOTE] = ACTIONS(2611),
    [anon_sym_u8_SQUOTE] = ACTIONS(2611),
    [anon_sym_SQUOTE] = ACTIONS(2611),
    [anon_sym_L_DQUOTE] = ACTIONS(2611),
    [anon_sym_u_DQUOTE] = ACTIONS(2611),
    [anon_sym_U_DQUOTE] = ACTIONS(2611),
    [anon_sym_u8_DQUOTE] = ACTIONS(2611),
    [anon_sym_DQUOTE] = ACTIONS(2611),
    [sym_true] = ACTIONS(2609),
    [sym_false] = ACTIONS(2609),
    [anon_sym_NULL] = ACTIONS(2609),
    [anon_sym_nullptr] = ACTIONS(2609),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2609),
    [anon_sym_decltype] = ACTIONS(2609),
    [anon_sym_explicit] = ACTIONS(2609),
    [anon_sym_typename] = ACTIONS(2609),
    [anon_sym_template] = ACTIONS(2609),
    [anon_sym_operator] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2609),
    [anon_sym_delete] = ACTIONS(2609),
    [anon_sym_throw] = ACTIONS(2609),
    [anon_sym_namespace] = ACTIONS(2609),
    [anon_sym_using] = ACTIONS(2609),
    [anon_sym_static_assert] = ACTIONS(2609),
    [anon_sym_concept] = ACTIONS(2609),
    [anon_sym_co_return] = ACTIONS(2609),
    [anon_sym_co_yield] = ACTIONS(2609),
    [anon_sym_R_DQUOTE] = ACTIONS(2611),
    [anon_sym_LR_DQUOTE] = ACTIONS(2611),
    [anon_sym_uR_DQUOTE] = ACTIONS(2611),
    [anon_sym_UR_DQUOTE] = ACTIONS(2611),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2611),
    [anon_sym_co_await] = ACTIONS(2609),
    [anon_sym_new] = ACTIONS(2609),
    [anon_sym_requires] = ACTIONS(2609),
    [sym_this] = ACTIONS(2609),
    [anon_sym___launch_bounds__] = ACTIONS(2609),
  },
  [STATE(319)] = {
    [sym_identifier] = ACTIONS(2613),
    [aux_sym_preproc_include_token1] = ACTIONS(2613),
    [aux_sym_preproc_def_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token2] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2613),
    [aux_sym_preproc_else_token1] = ACTIONS(2613),
    [aux_sym_preproc_elif_token1] = ACTIONS(2613),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2613),
    [sym_preproc_directive] = ACTIONS(2613),
    [anon_sym_LPAREN2] = ACTIONS(2615),
    [anon_sym_BANG] = ACTIONS(2615),
    [anon_sym_TILDE] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2615),
    [anon_sym_AMP_AMP] = ACTIONS(2615),
    [anon_sym_AMP] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym___extension__] = ACTIONS(2613),
    [anon_sym_typedef] = ACTIONS(2613),
    [anon_sym___device__] = ACTIONS(2613),
    [anon_sym___host__] = ACTIONS(2613),
    [anon_sym___global__] = ACTIONS(2613),
    [anon_sym___forceinline__] = ACTIONS(2613),
    [anon_sym___noinline__] = ACTIONS(2613),
    [anon_sym_virtual] = ACTIONS(2613),
    [anon_sym_extern] = ACTIONS(2613),
    [anon_sym___attribute__] = ACTIONS(2613),
    [anon_sym___attribute] = ACTIONS(2613),
    [anon_sym_COLON_COLON] = ACTIONS(2615),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2615),
    [anon_sym___declspec] = ACTIONS(2613),
    [anon_sym___based] = ACTIONS(2613),
    [anon_sym___cdecl] = ACTIONS(2613),
    [anon_sym___clrcall] = ACTIONS(2613),
    [anon_sym___stdcall] = ACTIONS(2613),
    [anon_sym___fastcall] = ACTIONS(2613),
    [anon_sym___thiscall] = ACTIONS(2613),
    [anon_sym___vectorcall] = ACTIONS(2613),
    [anon_sym_LBRACE] = ACTIONS(2615),
    [anon_sym_signed] = ACTIONS(2613),
    [anon_sym_unsigned] = ACTIONS(2613),
    [anon_sym_long] = ACTIONS(2613),
    [anon_sym_short] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2613),
    [anon_sym_static] = ACTIONS(2613),
    [anon_sym_register] = ACTIONS(2613),
    [anon_sym_inline] = ACTIONS(2613),
    [anon_sym___inline] = ACTIONS(2613),
    [anon_sym___inline__] = ACTIONS(2613),
    [anon_sym___forceinline] = ACTIONS(2613),
    [anon_sym_thread_local] = ACTIONS(2613),
    [anon_sym___thread] = ACTIONS(2613),
    [anon_sym_const] = ACTIONS(2613),
    [anon_sym_constexpr] = ACTIONS(2613),
    [anon_sym_volatile] = ACTIONS(2613),
    [anon_sym_restrict] = ACTIONS(2613),
    [anon_sym___restrict__] = ACTIONS(2613),
    [anon_sym__Atomic] = ACTIONS(2613),
    [anon_sym__Noreturn] = ACTIONS(2613),
    [anon_sym_noreturn] = ACTIONS(2613),
    [anon_sym__Nonnull] = ACTIONS(2613),
    [anon_sym_mutable] = ACTIONS(2613),
    [anon_sym_constinit] = ACTIONS(2613),
    [anon_sym_consteval] = ACTIONS(2613),
    [anon_sym___shared__] = ACTIONS(2613),
    [anon_sym___local__] = ACTIONS(2613),
    [anon_sym___constant__] = ACTIONS(2613),
    [anon_sym___managed__] = ACTIONS(2613),
    [anon_sym___grid_constant__] = ACTIONS(2613),
    [anon_sym_alignas] = ACTIONS(2613),
    [anon_sym__Alignas] = ACTIONS(2613),
    [sym_primitive_type] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_class] = ACTIONS(2613),
    [anon_sym_struct] = ACTIONS(2613),
    [anon_sym_union] = ACTIONS(2613),
    [anon_sym_if] = ACTIONS(2613),
    [anon_sym_switch] = ACTIONS(2613),
    [anon_sym_case] = ACTIONS(2613),
    [anon_sym_default] = ACTIONS(2613),
    [anon_sym_while] = ACTIONS(2613),
    [anon_sym_do] = ACTIONS(2613),
    [anon_sym_for] = ACTIONS(2613),
    [anon_sym_return] = ACTIONS(2613),
    [anon_sym_break] = ACTIONS(2613),
    [anon_sym_continue] = ACTIONS(2613),
    [anon_sym_goto] = ACTIONS(2613),
    [anon_sym___try] = ACTIONS(2613),
    [anon_sym___leave] = ACTIONS(2613),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_compl] = ACTIONS(2613),
    [anon_sym_DASH_DASH] = ACTIONS(2615),
    [anon_sym_PLUS_PLUS] = ACTIONS(2615),
    [anon_sym_sizeof] = ACTIONS(2613),
    [anon_sym___alignof__] = ACTIONS(2613),
    [anon_sym___alignof] = ACTIONS(2613),
    [anon_sym__alignof] = ACTIONS(2613),
    [anon_sym_alignof] = ACTIONS(2613),
    [anon_sym__Alignof] = ACTIONS(2613),
    [anon_sym_offsetof] = ACTIONS(2613),
    [anon_sym__Generic] = ACTIONS(2613),
    [anon_sym_asm] = ACTIONS(2613),
    [anon_sym___asm__] = ACTIONS(2613),
    [anon_sym___asm] = ACTIONS(2613),
    [sym_number_literal] = ACTIONS(2615),
    [anon_sym_L_SQUOTE] = ACTIONS(2615),
    [anon_sym_u_SQUOTE] = ACTIONS(2615),
    [anon_sym_U_SQUOTE] = ACTIONS(2615),
    [anon_sym_u8_SQUOTE] = ACTIONS(2615),
    [anon_sym_SQUOTE] = ACTIONS(2615),
    [anon_sym_L_DQUOTE] = ACTIONS(2615),
    [anon_sym_u_DQUOTE] = ACTIONS(2615),
    [anon_sym_U_DQUOTE] = ACTIONS(2615),
    [anon_sym_u8_DQUOTE] = ACTIONS(2615),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_true] = ACTIONS(2613),
    [sym_false] = ACTIONS(2613),
    [anon_sym_NULL] = ACTIONS(2613),
    [anon_sym_nullptr] = ACTIONS(2613),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2613),
    [anon_sym_decltype] = ACTIONS(2613),
    [anon_sym_explicit] = ACTIONS(2613),
    [anon_sym_typename] = ACTIONS(2613),
    [anon_sym_template] = ACTIONS(2613),
    [anon_sym_operator] = ACTIONS(2613),
    [anon_sym_try] = ACTIONS(2613),
    [anon_sym_delete] = ACTIONS(2613),
    [anon_sym_throw] = ACTIONS(2613),
    [anon_sym_namespace] = ACTIONS(2613),
    [anon_sym_using] = ACTIONS(2613),
    [anon_sym_static_assert] = ACTIONS(2613),
    [anon_sym_concept] = ACTIONS(2613),
    [anon_sym_co_return] = ACTIONS(2613),
    [anon_sym_co_yield] = ACTIONS(2613),
    [anon_sym_R_DQUOTE] = ACTIONS(2615),
    [anon_sym_LR_DQUOTE] = ACTIONS(2615),
    [anon_sym_uR_DQUOTE] = ACTIONS(2615),
    [anon_sym_UR_DQUOTE] = ACTIONS(2615),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2615),
    [anon_sym_co_await] = ACTIONS(2613),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_requires] = ACTIONS(2613),
    [sym_this] = ACTIONS(2613),
    [anon_sym___launch_bounds__] = ACTIONS(2613),
  },
  [STATE(320)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym_typedef] = ACTIONS(1988),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(321)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [aux_sym_preproc_else_token1] = ACTIONS(2573),
    [aux_sym_preproc_elif_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [anon_sym___asm] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(322)] = {
    [sym_identifier] = ACTIONS(2617),
    [aux_sym_preproc_include_token1] = ACTIONS(2617),
    [aux_sym_preproc_def_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token2] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2617),
    [aux_sym_preproc_else_token1] = ACTIONS(2617),
    [aux_sym_preproc_elif_token1] = ACTIONS(2617),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2617),
    [sym_preproc_directive] = ACTIONS(2617),
    [anon_sym_LPAREN2] = ACTIONS(2619),
    [anon_sym_BANG] = ACTIONS(2619),
    [anon_sym_TILDE] = ACTIONS(2619),
    [anon_sym_DASH] = ACTIONS(2617),
    [anon_sym_PLUS] = ACTIONS(2617),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_AMP_AMP] = ACTIONS(2619),
    [anon_sym_AMP] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2619),
    [anon_sym___extension__] = ACTIONS(2617),
    [anon_sym_typedef] = ACTIONS(2617),
    [anon_sym___device__] = ACTIONS(2617),
    [anon_sym___host__] = ACTIONS(2617),
    [anon_sym___global__] = ACTIONS(2617),
    [anon_sym___forceinline__] = ACTIONS(2617),
    [anon_sym___noinline__] = ACTIONS(2617),
    [anon_sym_virtual] = ACTIONS(2617),
    [anon_sym_extern] = ACTIONS(2617),
    [anon_sym___attribute__] = ACTIONS(2617),
    [anon_sym___attribute] = ACTIONS(2617),
    [anon_sym_COLON_COLON] = ACTIONS(2619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2619),
    [anon_sym___declspec] = ACTIONS(2617),
    [anon_sym___based] = ACTIONS(2617),
    [anon_sym___cdecl] = ACTIONS(2617),
    [anon_sym___clrcall] = ACTIONS(2617),
    [anon_sym___stdcall] = ACTIONS(2617),
    [anon_sym___fastcall] = ACTIONS(2617),
    [anon_sym___thiscall] = ACTIONS(2617),
    [anon_sym___vectorcall] = ACTIONS(2617),
    [anon_sym_LBRACE] = ACTIONS(2619),
    [anon_sym_signed] = ACTIONS(2617),
    [anon_sym_unsigned] = ACTIONS(2617),
    [anon_sym_long] = ACTIONS(2617),
    [anon_sym_short] = ACTIONS(2617),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2617),
    [anon_sym_register] = ACTIONS(2617),
    [anon_sym_inline] = ACTIONS(2617),
    [anon_sym___inline] = ACTIONS(2617),
    [anon_sym___inline__] = ACTIONS(2617),
    [anon_sym___forceinline] = ACTIONS(2617),
    [anon_sym_thread_local] = ACTIONS(2617),
    [anon_sym___thread] = ACTIONS(2617),
    [anon_sym_const] = ACTIONS(2617),
    [anon_sym_constexpr] = ACTIONS(2617),
    [anon_sym_volatile] = ACTIONS(2617),
    [anon_sym_restrict] = ACTIONS(2617),
    [anon_sym___restrict__] = ACTIONS(2617),
    [anon_sym__Atomic] = ACTIONS(2617),
    [anon_sym__Noreturn] = ACTIONS(2617),
    [anon_sym_noreturn] = ACTIONS(2617),
    [anon_sym__Nonnull] = ACTIONS(2617),
    [anon_sym_mutable] = ACTIONS(2617),
    [anon_sym_constinit] = ACTIONS(2617),
    [anon_sym_consteval] = ACTIONS(2617),
    [anon_sym___shared__] = ACTIONS(2617),
    [anon_sym___local__] = ACTIONS(2617),
    [anon_sym___constant__] = ACTIONS(2617),
    [anon_sym___managed__] = ACTIONS(2617),
    [anon_sym___grid_constant__] = ACTIONS(2617),
    [anon_sym_alignas] = ACTIONS(2617),
    [anon_sym__Alignas] = ACTIONS(2617),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2617),
    [anon_sym_struct] = ACTIONS(2617),
    [anon_sym_union] = ACTIONS(2617),
    [anon_sym_if] = ACTIONS(2617),
    [anon_sym_switch] = ACTIONS(2617),
    [anon_sym_case] = ACTIONS(2617),
    [anon_sym_default] = ACTIONS(2617),
    [anon_sym_while] = ACTIONS(2617),
    [anon_sym_do] = ACTIONS(2617),
    [anon_sym_for] = ACTIONS(2617),
    [anon_sym_return] = ACTIONS(2617),
    [anon_sym_break] = ACTIONS(2617),
    [anon_sym_continue] = ACTIONS(2617),
    [anon_sym_goto] = ACTIONS(2617),
    [anon_sym___try] = ACTIONS(2617),
    [anon_sym___leave] = ACTIONS(2617),
    [anon_sym_not] = ACTIONS(2617),
    [anon_sym_compl] = ACTIONS(2617),
    [anon_sym_DASH_DASH] = ACTIONS(2619),
    [anon_sym_PLUS_PLUS] = ACTIONS(2619),
    [anon_sym_sizeof] = ACTIONS(2617),
    [anon_sym___alignof__] = ACTIONS(2617),
    [anon_sym___alignof] = ACTIONS(2617),
    [anon_sym__alignof] = ACTIONS(2617),
    [anon_sym_alignof] = ACTIONS(2617),
    [anon_sym__Alignof] = ACTIONS(2617),
    [anon_sym_offsetof] = ACTIONS(2617),
    [anon_sym__Generic] = ACTIONS(2617),
    [anon_sym_asm] = ACTIONS(2617),
    [anon_sym___asm__] = ACTIONS(2617),
    [anon_sym___asm] = ACTIONS(2617),
    [sym_number_literal] = ACTIONS(2619),
    [anon_sym_L_SQUOTE] = ACTIONS(2619),
    [anon_sym_u_SQUOTE] = ACTIONS(2619),
    [anon_sym_U_SQUOTE] = ACTIONS(2619),
    [anon_sym_u8_SQUOTE] = ACTIONS(2619),
    [anon_sym_SQUOTE] = ACTIONS(2619),
    [anon_sym_L_DQUOTE] = ACTIONS(2619),
    [anon_sym_u_DQUOTE] = ACTIONS(2619),
    [anon_sym_U_DQUOTE] = ACTIONS(2619),
    [anon_sym_u8_DQUOTE] = ACTIONS(2619),
    [anon_sym_DQUOTE] = ACTIONS(2619),
    [sym_true] = ACTIONS(2617),
    [sym_false] = ACTIONS(2617),
    [anon_sym_NULL] = ACTIONS(2617),
    [anon_sym_nullptr] = ACTIONS(2617),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2617),
    [anon_sym_decltype] = ACTIONS(2617),
    [anon_sym_explicit] = ACTIONS(2617),
    [anon_sym_typename] = ACTIONS(2617),
    [anon_sym_template] = ACTIONS(2617),
    [anon_sym_operator] = ACTIONS(2617),
    [anon_sym_try] = ACTIONS(2617),
    [anon_sym_delete] = ACTIONS(2617),
    [anon_sym_throw] = ACTIONS(2617),
    [anon_sym_namespace] = ACTIONS(2617),
    [anon_sym_using] = ACTIONS(2617),
    [anon_sym_static_assert] = ACTIONS(2617),
    [anon_sym_concept] = ACTIONS(2617),
    [anon_sym_co_return] = ACTIONS(2617),
    [anon_sym_co_yield] = ACTIONS(2617),
    [anon_sym_R_DQUOTE] = ACTIONS(2619),
    [anon_sym_LR_DQUOTE] = ACTIONS(2619),
    [anon_sym_uR_DQUOTE] = ACTIONS(2619),
    [anon_sym_UR_DQUOTE] = ACTIONS(2619),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2619),
    [anon_sym_co_await] = ACTIONS(2617),
    [anon_sym_new] = ACTIONS(2617),
    [anon_sym_requires] = ACTIONS(2617),
    [sym_this] = ACTIONS(2617),
    [anon_sym___launch_bounds__] = ACTIONS(2617),
  },
  [STATE(323)] = {
    [sym_catch_clause] = STATE(281),
    [aux_sym_constructor_try_statement_repeat1] = STATE(281),
    [sym_identifier] = ACTIONS(1996),
    [aux_sym_preproc_include_token1] = ACTIONS(1996),
    [aux_sym_preproc_def_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token2] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1996),
    [sym_preproc_directive] = ACTIONS(1996),
    [anon_sym_LPAREN2] = ACTIONS(1998),
    [anon_sym_BANG] = ACTIONS(1998),
    [anon_sym_TILDE] = ACTIONS(1998),
    [anon_sym_DASH] = ACTIONS(1996),
    [anon_sym_PLUS] = ACTIONS(1996),
    [anon_sym_STAR] = ACTIONS(1998),
    [anon_sym_AMP_AMP] = ACTIONS(1998),
    [anon_sym_AMP] = ACTIONS(1996),
    [anon_sym_SEMI] = ACTIONS(1998),
    [anon_sym___extension__] = ACTIONS(1996),
    [anon_sym_typedef] = ACTIONS(1996),
    [anon_sym___device__] = ACTIONS(1996),
    [anon_sym___host__] = ACTIONS(1996),
    [anon_sym___global__] = ACTIONS(1996),
    [anon_sym___forceinline__] = ACTIONS(1996),
    [anon_sym___noinline__] = ACTIONS(1996),
    [anon_sym_virtual] = ACTIONS(1996),
    [anon_sym_extern] = ACTIONS(1996),
    [anon_sym___attribute__] = ACTIONS(1996),
    [anon_sym___attribute] = ACTIONS(1996),
    [anon_sym_COLON_COLON] = ACTIONS(1998),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1998),
    [anon_sym___declspec] = ACTIONS(1996),
    [anon_sym___based] = ACTIONS(1996),
    [anon_sym___cdecl] = ACTIONS(1996),
    [anon_sym___clrcall] = ACTIONS(1996),
    [anon_sym___stdcall] = ACTIONS(1996),
    [anon_sym___fastcall] = ACTIONS(1996),
    [anon_sym___thiscall] = ACTIONS(1996),
    [anon_sym___vectorcall] = ACTIONS(1996),
    [anon_sym_LBRACE] = ACTIONS(1998),
    [anon_sym_signed] = ACTIONS(1996),
    [anon_sym_unsigned] = ACTIONS(1996),
    [anon_sym_long] = ACTIONS(1996),
    [anon_sym_short] = ACTIONS(1996),
    [anon_sym_LBRACK] = ACTIONS(1996),
    [anon_sym_static] = ACTIONS(1996),
    [anon_sym_register] = ACTIONS(1996),
    [anon_sym_inline] = ACTIONS(1996),
    [anon_sym___inline] = ACTIONS(1996),
    [anon_sym___inline__] = ACTIONS(1996),
    [anon_sym___forceinline] = ACTIONS(1996),
    [anon_sym_thread_local] = ACTIONS(1996),
    [anon_sym___thread] = ACTIONS(1996),
    [anon_sym_const] = ACTIONS(1996),
    [anon_sym_constexpr] = ACTIONS(1996),
    [anon_sym_volatile] = ACTIONS(1996),
    [anon_sym_restrict] = ACTIONS(1996),
    [anon_sym___restrict__] = ACTIONS(1996),
    [anon_sym__Atomic] = ACTIONS(1996),
    [anon_sym__Noreturn] = ACTIONS(1996),
    [anon_sym_noreturn] = ACTIONS(1996),
    [anon_sym__Nonnull] = ACTIONS(1996),
    [anon_sym_mutable] = ACTIONS(1996),
    [anon_sym_constinit] = ACTIONS(1996),
    [anon_sym_consteval] = ACTIONS(1996),
    [anon_sym___shared__] = ACTIONS(1996),
    [anon_sym___local__] = ACTIONS(1996),
    [anon_sym___constant__] = ACTIONS(1996),
    [anon_sym___managed__] = ACTIONS(1996),
    [anon_sym___grid_constant__] = ACTIONS(1996),
    [anon_sym_alignas] = ACTIONS(1996),
    [anon_sym__Alignas] = ACTIONS(1996),
    [sym_primitive_type] = ACTIONS(1996),
    [anon_sym_enum] = ACTIONS(1996),
    [anon_sym_class] = ACTIONS(1996),
    [anon_sym_struct] = ACTIONS(1996),
    [anon_sym_union] = ACTIONS(1996),
    [anon_sym_if] = ACTIONS(1996),
    [anon_sym_switch] = ACTIONS(1996),
    [anon_sym_case] = ACTIONS(1996),
    [anon_sym_default] = ACTIONS(1996),
    [anon_sym_while] = ACTIONS(1996),
    [anon_sym_do] = ACTIONS(1996),
    [anon_sym_for] = ACTIONS(1996),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_break] = ACTIONS(1996),
    [anon_sym_continue] = ACTIONS(1996),
    [anon_sym_goto] = ACTIONS(1996),
    [anon_sym___try] = ACTIONS(1996),
    [anon_sym___leave] = ACTIONS(1996),
    [anon_sym_not] = ACTIONS(1996),
    [anon_sym_compl] = ACTIONS(1996),
    [anon_sym_DASH_DASH] = ACTIONS(1998),
    [anon_sym_PLUS_PLUS] = ACTIONS(1998),
    [anon_sym_sizeof] = ACTIONS(1996),
    [anon_sym___alignof__] = ACTIONS(1996),
    [anon_sym___alignof] = ACTIONS(1996),
    [anon_sym__alignof] = ACTIONS(1996),
    [anon_sym_alignof] = ACTIONS(1996),
    [anon_sym__Alignof] = ACTIONS(1996),
    [anon_sym_offsetof] = ACTIONS(1996),
    [anon_sym__Generic] = ACTIONS(1996),
    [anon_sym_asm] = ACTIONS(1996),
    [anon_sym___asm__] = ACTIONS(1996),
    [anon_sym___asm] = ACTIONS(1996),
    [sym_number_literal] = ACTIONS(1998),
    [anon_sym_L_SQUOTE] = ACTIONS(1998),
    [anon_sym_u_SQUOTE] = ACTIONS(1998),
    [anon_sym_U_SQUOTE] = ACTIONS(1998),
    [anon_sym_u8_SQUOTE] = ACTIONS(1998),
    [anon_sym_SQUOTE] = ACTIONS(1998),
    [anon_sym_L_DQUOTE] = ACTIONS(1998),
    [anon_sym_u_DQUOTE] = ACTIONS(1998),
    [anon_sym_U_DQUOTE] = ACTIONS(1998),
    [anon_sym_u8_DQUOTE] = ACTIONS(1998),
    [anon_sym_DQUOTE] = ACTIONS(1998),
    [sym_true] = ACTIONS(1996),
    [sym_false] = ACTIONS(1996),
    [anon_sym_NULL] = ACTIONS(1996),
    [anon_sym_nullptr] = ACTIONS(1996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1996),
    [anon_sym_decltype] = ACTIONS(1996),
    [anon_sym_explicit] = ACTIONS(1996),
    [anon_sym_typename] = ACTIONS(1996),
    [anon_sym_template] = ACTIONS(1996),
    [anon_sym_operator] = ACTIONS(1996),
    [anon_sym_try] = ACTIONS(1996),
    [anon_sym_delete] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1996),
    [anon_sym_namespace] = ACTIONS(1996),
    [anon_sym_using] = ACTIONS(1996),
    [anon_sym_static_assert] = ACTIONS(1996),
    [anon_sym_concept] = ACTIONS(1996),
    [anon_sym_co_return] = ACTIONS(1996),
    [anon_sym_co_yield] = ACTIONS(1996),
    [anon_sym_catch] = ACTIONS(2455),
    [anon_sym_R_DQUOTE] = ACTIONS(1998),
    [anon_sym_LR_DQUOTE] = ACTIONS(1998),
    [anon_sym_uR_DQUOTE] = ACTIONS(1998),
    [anon_sym_UR_DQUOTE] = ACTIONS(1998),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1998),
    [anon_sym_co_await] = ACTIONS(1996),
    [anon_sym_new] = ACTIONS(1996),
    [anon_sym_requires] = ACTIONS(1996),
    [sym_this] = ACTIONS(1996),
    [anon_sym___launch_bounds__] = ACTIONS(1996),
  },
  [STATE(324)] = {
    [sym_catch_clause] = STATE(281),
    [aux_sym_constructor_try_statement_repeat1] = STATE(281),
    [sym_identifier] = ACTIONS(1992),
    [aux_sym_preproc_include_token1] = ACTIONS(1992),
    [aux_sym_preproc_def_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token2] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1992),
    [sym_preproc_directive] = ACTIONS(1992),
    [anon_sym_LPAREN2] = ACTIONS(1994),
    [anon_sym_BANG] = ACTIONS(1994),
    [anon_sym_TILDE] = ACTIONS(1994),
    [anon_sym_DASH] = ACTIONS(1992),
    [anon_sym_PLUS] = ACTIONS(1992),
    [anon_sym_STAR] = ACTIONS(1994),
    [anon_sym_AMP_AMP] = ACTIONS(1994),
    [anon_sym_AMP] = ACTIONS(1992),
    [anon_sym_SEMI] = ACTIONS(1994),
    [anon_sym___extension__] = ACTIONS(1992),
    [anon_sym_typedef] = ACTIONS(1992),
    [anon_sym___device__] = ACTIONS(1992),
    [anon_sym___host__] = ACTIONS(1992),
    [anon_sym___global__] = ACTIONS(1992),
    [anon_sym___forceinline__] = ACTIONS(1992),
    [anon_sym___noinline__] = ACTIONS(1992),
    [anon_sym_virtual] = ACTIONS(1992),
    [anon_sym_extern] = ACTIONS(1992),
    [anon_sym___attribute__] = ACTIONS(1992),
    [anon_sym___attribute] = ACTIONS(1992),
    [anon_sym_COLON_COLON] = ACTIONS(1994),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1994),
    [anon_sym___declspec] = ACTIONS(1992),
    [anon_sym___based] = ACTIONS(1992),
    [anon_sym___cdecl] = ACTIONS(1992),
    [anon_sym___clrcall] = ACTIONS(1992),
    [anon_sym___stdcall] = ACTIONS(1992),
    [anon_sym___fastcall] = ACTIONS(1992),
    [anon_sym___thiscall] = ACTIONS(1992),
    [anon_sym___vectorcall] = ACTIONS(1992),
    [anon_sym_LBRACE] = ACTIONS(1994),
    [anon_sym_signed] = ACTIONS(1992),
    [anon_sym_unsigned] = ACTIONS(1992),
    [anon_sym_long] = ACTIONS(1992),
    [anon_sym_short] = ACTIONS(1992),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_static] = ACTIONS(1992),
    [anon_sym_register] = ACTIONS(1992),
    [anon_sym_inline] = ACTIONS(1992),
    [anon_sym___inline] = ACTIONS(1992),
    [anon_sym___inline__] = ACTIONS(1992),
    [anon_sym___forceinline] = ACTIONS(1992),
    [anon_sym_thread_local] = ACTIONS(1992),
    [anon_sym___thread] = ACTIONS(1992),
    [anon_sym_const] = ACTIONS(1992),
    [anon_sym_constexpr] = ACTIONS(1992),
    [anon_sym_volatile] = ACTIONS(1992),
    [anon_sym_restrict] = ACTIONS(1992),
    [anon_sym___restrict__] = ACTIONS(1992),
    [anon_sym__Atomic] = ACTIONS(1992),
    [anon_sym__Noreturn] = ACTIONS(1992),
    [anon_sym_noreturn] = ACTIONS(1992),
    [anon_sym__Nonnull] = ACTIONS(1992),
    [anon_sym_mutable] = ACTIONS(1992),
    [anon_sym_constinit] = ACTIONS(1992),
    [anon_sym_consteval] = ACTIONS(1992),
    [anon_sym___shared__] = ACTIONS(1992),
    [anon_sym___local__] = ACTIONS(1992),
    [anon_sym___constant__] = ACTIONS(1992),
    [anon_sym___managed__] = ACTIONS(1992),
    [anon_sym___grid_constant__] = ACTIONS(1992),
    [anon_sym_alignas] = ACTIONS(1992),
    [anon_sym__Alignas] = ACTIONS(1992),
    [sym_primitive_type] = ACTIONS(1992),
    [anon_sym_enum] = ACTIONS(1992),
    [anon_sym_class] = ACTIONS(1992),
    [anon_sym_struct] = ACTIONS(1992),
    [anon_sym_union] = ACTIONS(1992),
    [anon_sym_if] = ACTIONS(1992),
    [anon_sym_switch] = ACTIONS(1992),
    [anon_sym_case] = ACTIONS(1992),
    [anon_sym_default] = ACTIONS(1992),
    [anon_sym_while] = ACTIONS(1992),
    [anon_sym_do] = ACTIONS(1992),
    [anon_sym_for] = ACTIONS(1992),
    [anon_sym_return] = ACTIONS(1992),
    [anon_sym_break] = ACTIONS(1992),
    [anon_sym_continue] = ACTIONS(1992),
    [anon_sym_goto] = ACTIONS(1992),
    [anon_sym___try] = ACTIONS(1992),
    [anon_sym___leave] = ACTIONS(1992),
    [anon_sym_not] = ACTIONS(1992),
    [anon_sym_compl] = ACTIONS(1992),
    [anon_sym_DASH_DASH] = ACTIONS(1994),
    [anon_sym_PLUS_PLUS] = ACTIONS(1994),
    [anon_sym_sizeof] = ACTIONS(1992),
    [anon_sym___alignof__] = ACTIONS(1992),
    [anon_sym___alignof] = ACTIONS(1992),
    [anon_sym__alignof] = ACTIONS(1992),
    [anon_sym_alignof] = ACTIONS(1992),
    [anon_sym__Alignof] = ACTIONS(1992),
    [anon_sym_offsetof] = ACTIONS(1992),
    [anon_sym__Generic] = ACTIONS(1992),
    [anon_sym_asm] = ACTIONS(1992),
    [anon_sym___asm__] = ACTIONS(1992),
    [anon_sym___asm] = ACTIONS(1992),
    [sym_number_literal] = ACTIONS(1994),
    [anon_sym_L_SQUOTE] = ACTIONS(1994),
    [anon_sym_u_SQUOTE] = ACTIONS(1994),
    [anon_sym_U_SQUOTE] = ACTIONS(1994),
    [anon_sym_u8_SQUOTE] = ACTIONS(1994),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [anon_sym_L_DQUOTE] = ACTIONS(1994),
    [anon_sym_u_DQUOTE] = ACTIONS(1994),
    [anon_sym_U_DQUOTE] = ACTIONS(1994),
    [anon_sym_u8_DQUOTE] = ACTIONS(1994),
    [anon_sym_DQUOTE] = ACTIONS(1994),
    [sym_true] = ACTIONS(1992),
    [sym_false] = ACTIONS(1992),
    [anon_sym_NULL] = ACTIONS(1992),
    [anon_sym_nullptr] = ACTIONS(1992),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1992),
    [anon_sym_decltype] = ACTIONS(1992),
    [anon_sym_explicit] = ACTIONS(1992),
    [anon_sym_typename] = ACTIONS(1992),
    [anon_sym_template] = ACTIONS(1992),
    [anon_sym_operator] = ACTIONS(1992),
    [anon_sym_try] = ACTIONS(1992),
    [anon_sym_delete] = ACTIONS(1992),
    [anon_sym_throw] = ACTIONS(1992),
    [anon_sym_namespace] = ACTIONS(1992),
    [anon_sym_using] = ACTIONS(1992),
    [anon_sym_static_assert] = ACTIONS(1992),
    [anon_sym_concept] = ACTIONS(1992),
    [anon_sym_co_return] = ACTIONS(1992),
    [anon_sym_co_yield] = ACTIONS(1992),
    [anon_sym_catch] = ACTIONS(2455),
    [anon_sym_R_DQUOTE] = ACTIONS(1994),
    [anon_sym_LR_DQUOTE] = ACTIONS(1994),
    [anon_sym_uR_DQUOTE] = ACTIONS(1994),
    [anon_sym_UR_DQUOTE] = ACTIONS(1994),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1994),
    [anon_sym_co_await] = ACTIONS(1992),
    [anon_sym_new] = ACTIONS(1992),
    [anon_sym_requires] = ACTIONS(1992),
    [sym_this] = ACTIONS(1992),
    [anon_sym___launch_bounds__] = ACTIONS(1992),
  },
  [STATE(325)] = {
    [sym_expression] = STATE(3910),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(2621),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2624),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(2627),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(2630),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(326)] = {
    [sym_expression] = STATE(2632),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_initializer_list] = STATE(2799),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2633),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [aux_sym_preproc_if_token2] = ACTIONS(2635),
    [aux_sym_preproc_else_token1] = ACTIONS(2635),
    [aux_sym_preproc_elif_token1] = ACTIONS(2633),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2635),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(2637),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2633),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2633),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_EQ] = ACTIONS(2633),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_STAR_EQ] = ACTIONS(2635),
    [anon_sym_SLASH_EQ] = ACTIONS(2635),
    [anon_sym_PERCENT_EQ] = ACTIONS(2635),
    [anon_sym_PLUS_EQ] = ACTIONS(2635),
    [anon_sym_DASH_EQ] = ACTIONS(2635),
    [anon_sym_LT_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT_GT_EQ] = ACTIONS(2635),
    [anon_sym_AMP_EQ] = ACTIONS(2635),
    [anon_sym_CARET_EQ] = ACTIONS(2635),
    [anon_sym_PIPE_EQ] = ACTIONS(2635),
    [anon_sym_and_eq] = ACTIONS(2633),
    [anon_sym_or_eq] = ACTIONS(2633),
    [anon_sym_xor_eq] = ACTIONS(2633),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(327)] = {
    [sym_catch_clause] = STATE(280),
    [aux_sym_constructor_try_statement_repeat1] = STATE(280),
    [sym_identifier] = ACTIONS(1992),
    [aux_sym_preproc_include_token1] = ACTIONS(1992),
    [aux_sym_preproc_def_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1992),
    [sym_preproc_directive] = ACTIONS(1992),
    [anon_sym_LPAREN2] = ACTIONS(1994),
    [anon_sym_BANG] = ACTIONS(1994),
    [anon_sym_TILDE] = ACTIONS(1994),
    [anon_sym_DASH] = ACTIONS(1992),
    [anon_sym_PLUS] = ACTIONS(1992),
    [anon_sym_STAR] = ACTIONS(1994),
    [anon_sym_AMP_AMP] = ACTIONS(1994),
    [anon_sym_AMP] = ACTIONS(1992),
    [anon_sym_SEMI] = ACTIONS(1994),
    [anon_sym___extension__] = ACTIONS(1992),
    [anon_sym_typedef] = ACTIONS(1992),
    [anon_sym___device__] = ACTIONS(1992),
    [anon_sym___host__] = ACTIONS(1992),
    [anon_sym___global__] = ACTIONS(1992),
    [anon_sym___forceinline__] = ACTIONS(1992),
    [anon_sym___noinline__] = ACTIONS(1992),
    [anon_sym_virtual] = ACTIONS(1992),
    [anon_sym_extern] = ACTIONS(1992),
    [anon_sym___attribute__] = ACTIONS(1992),
    [anon_sym___attribute] = ACTIONS(1992),
    [anon_sym_COLON_COLON] = ACTIONS(1994),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1994),
    [anon_sym___declspec] = ACTIONS(1992),
    [anon_sym___based] = ACTIONS(1992),
    [anon_sym___cdecl] = ACTIONS(1992),
    [anon_sym___clrcall] = ACTIONS(1992),
    [anon_sym___stdcall] = ACTIONS(1992),
    [anon_sym___fastcall] = ACTIONS(1992),
    [anon_sym___thiscall] = ACTIONS(1992),
    [anon_sym___vectorcall] = ACTIONS(1992),
    [anon_sym_LBRACE] = ACTIONS(1994),
    [anon_sym_RBRACE] = ACTIONS(1994),
    [anon_sym_signed] = ACTIONS(1992),
    [anon_sym_unsigned] = ACTIONS(1992),
    [anon_sym_long] = ACTIONS(1992),
    [anon_sym_short] = ACTIONS(1992),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_static] = ACTIONS(1992),
    [anon_sym_register] = ACTIONS(1992),
    [anon_sym_inline] = ACTIONS(1992),
    [anon_sym___inline] = ACTIONS(1992),
    [anon_sym___inline__] = ACTIONS(1992),
    [anon_sym___forceinline] = ACTIONS(1992),
    [anon_sym_thread_local] = ACTIONS(1992),
    [anon_sym___thread] = ACTIONS(1992),
    [anon_sym_const] = ACTIONS(1992),
    [anon_sym_constexpr] = ACTIONS(1992),
    [anon_sym_volatile] = ACTIONS(1992),
    [anon_sym_restrict] = ACTIONS(1992),
    [anon_sym___restrict__] = ACTIONS(1992),
    [anon_sym__Atomic] = ACTIONS(1992),
    [anon_sym__Noreturn] = ACTIONS(1992),
    [anon_sym_noreturn] = ACTIONS(1992),
    [anon_sym__Nonnull] = ACTIONS(1992),
    [anon_sym_mutable] = ACTIONS(1992),
    [anon_sym_constinit] = ACTIONS(1992),
    [anon_sym_consteval] = ACTIONS(1992),
    [anon_sym___shared__] = ACTIONS(1992),
    [anon_sym___local__] = ACTIONS(1992),
    [anon_sym___constant__] = ACTIONS(1992),
    [anon_sym___managed__] = ACTIONS(1992),
    [anon_sym___grid_constant__] = ACTIONS(1992),
    [anon_sym_alignas] = ACTIONS(1992),
    [anon_sym__Alignas] = ACTIONS(1992),
    [sym_primitive_type] = ACTIONS(1992),
    [anon_sym_enum] = ACTIONS(1992),
    [anon_sym_class] = ACTIONS(1992),
    [anon_sym_struct] = ACTIONS(1992),
    [anon_sym_union] = ACTIONS(1992),
    [anon_sym_if] = ACTIONS(1992),
    [anon_sym_switch] = ACTIONS(1992),
    [anon_sym_case] = ACTIONS(1992),
    [anon_sym_default] = ACTIONS(1992),
    [anon_sym_while] = ACTIONS(1992),
    [anon_sym_do] = ACTIONS(1992),
    [anon_sym_for] = ACTIONS(1992),
    [anon_sym_return] = ACTIONS(1992),
    [anon_sym_break] = ACTIONS(1992),
    [anon_sym_continue] = ACTIONS(1992),
    [anon_sym_goto] = ACTIONS(1992),
    [anon_sym___try] = ACTIONS(1992),
    [anon_sym___leave] = ACTIONS(1992),
    [anon_sym_not] = ACTIONS(1992),
    [anon_sym_compl] = ACTIONS(1992),
    [anon_sym_DASH_DASH] = ACTIONS(1994),
    [anon_sym_PLUS_PLUS] = ACTIONS(1994),
    [anon_sym_sizeof] = ACTIONS(1992),
    [anon_sym___alignof__] = ACTIONS(1992),
    [anon_sym___alignof] = ACTIONS(1992),
    [anon_sym__alignof] = ACTIONS(1992),
    [anon_sym_alignof] = ACTIONS(1992),
    [anon_sym__Alignof] = ACTIONS(1992),
    [anon_sym_offsetof] = ACTIONS(1992),
    [anon_sym__Generic] = ACTIONS(1992),
    [anon_sym_asm] = ACTIONS(1992),
    [anon_sym___asm__] = ACTIONS(1992),
    [anon_sym___asm] = ACTIONS(1992),
    [sym_number_literal] = ACTIONS(1994),
    [anon_sym_L_SQUOTE] = ACTIONS(1994),
    [anon_sym_u_SQUOTE] = ACTIONS(1994),
    [anon_sym_U_SQUOTE] = ACTIONS(1994),
    [anon_sym_u8_SQUOTE] = ACTIONS(1994),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [anon_sym_L_DQUOTE] = ACTIONS(1994),
    [anon_sym_u_DQUOTE] = ACTIONS(1994),
    [anon_sym_U_DQUOTE] = ACTIONS(1994),
    [anon_sym_u8_DQUOTE] = ACTIONS(1994),
    [anon_sym_DQUOTE] = ACTIONS(1994),
    [sym_true] = ACTIONS(1992),
    [sym_false] = ACTIONS(1992),
    [anon_sym_NULL] = ACTIONS(1992),
    [anon_sym_nullptr] = ACTIONS(1992),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1992),
    [anon_sym_decltype] = ACTIONS(1992),
    [anon_sym_explicit] = ACTIONS(1992),
    [anon_sym_typename] = ACTIONS(1992),
    [anon_sym_template] = ACTIONS(1992),
    [anon_sym_operator] = ACTIONS(1992),
    [anon_sym_try] = ACTIONS(1992),
    [anon_sym_delete] = ACTIONS(1992),
    [anon_sym_throw] = ACTIONS(1992),
    [anon_sym_namespace] = ACTIONS(1992),
    [anon_sym_using] = ACTIONS(1992),
    [anon_sym_static_assert] = ACTIONS(1992),
    [anon_sym_concept] = ACTIONS(1992),
    [anon_sym_co_return] = ACTIONS(1992),
    [anon_sym_co_yield] = ACTIONS(1992),
    [anon_sym_catch] = ACTIONS(2461),
    [anon_sym_R_DQUOTE] = ACTIONS(1994),
    [anon_sym_LR_DQUOTE] = ACTIONS(1994),
    [anon_sym_uR_DQUOTE] = ACTIONS(1994),
    [anon_sym_UR_DQUOTE] = ACTIONS(1994),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1994),
    [anon_sym_co_await] = ACTIONS(1992),
    [anon_sym_new] = ACTIONS(1992),
    [anon_sym_requires] = ACTIONS(1992),
    [sym_this] = ACTIONS(1992),
    [anon_sym___launch_bounds__] = ACTIONS(1992),
  },
  [STATE(328)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(329)] = {
    [sym_catch_clause] = STATE(280),
    [aux_sym_constructor_try_statement_repeat1] = STATE(280),
    [sym_identifier] = ACTIONS(1996),
    [aux_sym_preproc_include_token1] = ACTIONS(1996),
    [aux_sym_preproc_def_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1996),
    [sym_preproc_directive] = ACTIONS(1996),
    [anon_sym_LPAREN2] = ACTIONS(1998),
    [anon_sym_BANG] = ACTIONS(1998),
    [anon_sym_TILDE] = ACTIONS(1998),
    [anon_sym_DASH] = ACTIONS(1996),
    [anon_sym_PLUS] = ACTIONS(1996),
    [anon_sym_STAR] = ACTIONS(1998),
    [anon_sym_AMP_AMP] = ACTIONS(1998),
    [anon_sym_AMP] = ACTIONS(1996),
    [anon_sym_SEMI] = ACTIONS(1998),
    [anon_sym___extension__] = ACTIONS(1996),
    [anon_sym_typedef] = ACTIONS(1996),
    [anon_sym___device__] = ACTIONS(1996),
    [anon_sym___host__] = ACTIONS(1996),
    [anon_sym___global__] = ACTIONS(1996),
    [anon_sym___forceinline__] = ACTIONS(1996),
    [anon_sym___noinline__] = ACTIONS(1996),
    [anon_sym_virtual] = ACTIONS(1996),
    [anon_sym_extern] = ACTIONS(1996),
    [anon_sym___attribute__] = ACTIONS(1996),
    [anon_sym___attribute] = ACTIONS(1996),
    [anon_sym_COLON_COLON] = ACTIONS(1998),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1998),
    [anon_sym___declspec] = ACTIONS(1996),
    [anon_sym___based] = ACTIONS(1996),
    [anon_sym___cdecl] = ACTIONS(1996),
    [anon_sym___clrcall] = ACTIONS(1996),
    [anon_sym___stdcall] = ACTIONS(1996),
    [anon_sym___fastcall] = ACTIONS(1996),
    [anon_sym___thiscall] = ACTIONS(1996),
    [anon_sym___vectorcall] = ACTIONS(1996),
    [anon_sym_LBRACE] = ACTIONS(1998),
    [anon_sym_RBRACE] = ACTIONS(1998),
    [anon_sym_signed] = ACTIONS(1996),
    [anon_sym_unsigned] = ACTIONS(1996),
    [anon_sym_long] = ACTIONS(1996),
    [anon_sym_short] = ACTIONS(1996),
    [anon_sym_LBRACK] = ACTIONS(1996),
    [anon_sym_static] = ACTIONS(1996),
    [anon_sym_register] = ACTIONS(1996),
    [anon_sym_inline] = ACTIONS(1996),
    [anon_sym___inline] = ACTIONS(1996),
    [anon_sym___inline__] = ACTIONS(1996),
    [anon_sym___forceinline] = ACTIONS(1996),
    [anon_sym_thread_local] = ACTIONS(1996),
    [anon_sym___thread] = ACTIONS(1996),
    [anon_sym_const] = ACTIONS(1996),
    [anon_sym_constexpr] = ACTIONS(1996),
    [anon_sym_volatile] = ACTIONS(1996),
    [anon_sym_restrict] = ACTIONS(1996),
    [anon_sym___restrict__] = ACTIONS(1996),
    [anon_sym__Atomic] = ACTIONS(1996),
    [anon_sym__Noreturn] = ACTIONS(1996),
    [anon_sym_noreturn] = ACTIONS(1996),
    [anon_sym__Nonnull] = ACTIONS(1996),
    [anon_sym_mutable] = ACTIONS(1996),
    [anon_sym_constinit] = ACTIONS(1996),
    [anon_sym_consteval] = ACTIONS(1996),
    [anon_sym___shared__] = ACTIONS(1996),
    [anon_sym___local__] = ACTIONS(1996),
    [anon_sym___constant__] = ACTIONS(1996),
    [anon_sym___managed__] = ACTIONS(1996),
    [anon_sym___grid_constant__] = ACTIONS(1996),
    [anon_sym_alignas] = ACTIONS(1996),
    [anon_sym__Alignas] = ACTIONS(1996),
    [sym_primitive_type] = ACTIONS(1996),
    [anon_sym_enum] = ACTIONS(1996),
    [anon_sym_class] = ACTIONS(1996),
    [anon_sym_struct] = ACTIONS(1996),
    [anon_sym_union] = ACTIONS(1996),
    [anon_sym_if] = ACTIONS(1996),
    [anon_sym_switch] = ACTIONS(1996),
    [anon_sym_case] = ACTIONS(1996),
    [anon_sym_default] = ACTIONS(1996),
    [anon_sym_while] = ACTIONS(1996),
    [anon_sym_do] = ACTIONS(1996),
    [anon_sym_for] = ACTIONS(1996),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_break] = ACTIONS(1996),
    [anon_sym_continue] = ACTIONS(1996),
    [anon_sym_goto] = ACTIONS(1996),
    [anon_sym___try] = ACTIONS(1996),
    [anon_sym___leave] = ACTIONS(1996),
    [anon_sym_not] = ACTIONS(1996),
    [anon_sym_compl] = ACTIONS(1996),
    [anon_sym_DASH_DASH] = ACTIONS(1998),
    [anon_sym_PLUS_PLUS] = ACTIONS(1998),
    [anon_sym_sizeof] = ACTIONS(1996),
    [anon_sym___alignof__] = ACTIONS(1996),
    [anon_sym___alignof] = ACTIONS(1996),
    [anon_sym__alignof] = ACTIONS(1996),
    [anon_sym_alignof] = ACTIONS(1996),
    [anon_sym__Alignof] = ACTIONS(1996),
    [anon_sym_offsetof] = ACTIONS(1996),
    [anon_sym__Generic] = ACTIONS(1996),
    [anon_sym_asm] = ACTIONS(1996),
    [anon_sym___asm__] = ACTIONS(1996),
    [anon_sym___asm] = ACTIONS(1996),
    [sym_number_literal] = ACTIONS(1998),
    [anon_sym_L_SQUOTE] = ACTIONS(1998),
    [anon_sym_u_SQUOTE] = ACTIONS(1998),
    [anon_sym_U_SQUOTE] = ACTIONS(1998),
    [anon_sym_u8_SQUOTE] = ACTIONS(1998),
    [anon_sym_SQUOTE] = ACTIONS(1998),
    [anon_sym_L_DQUOTE] = ACTIONS(1998),
    [anon_sym_u_DQUOTE] = ACTIONS(1998),
    [anon_sym_U_DQUOTE] = ACTIONS(1998),
    [anon_sym_u8_DQUOTE] = ACTIONS(1998),
    [anon_sym_DQUOTE] = ACTIONS(1998),
    [sym_true] = ACTIONS(1996),
    [sym_false] = ACTIONS(1996),
    [anon_sym_NULL] = ACTIONS(1996),
    [anon_sym_nullptr] = ACTIONS(1996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1996),
    [anon_sym_decltype] = ACTIONS(1996),
    [anon_sym_explicit] = ACTIONS(1996),
    [anon_sym_typename] = ACTIONS(1996),
    [anon_sym_template] = ACTIONS(1996),
    [anon_sym_operator] = ACTIONS(1996),
    [anon_sym_try] = ACTIONS(1996),
    [anon_sym_delete] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1996),
    [anon_sym_namespace] = ACTIONS(1996),
    [anon_sym_using] = ACTIONS(1996),
    [anon_sym_static_assert] = ACTIONS(1996),
    [anon_sym_concept] = ACTIONS(1996),
    [anon_sym_co_return] = ACTIONS(1996),
    [anon_sym_co_yield] = ACTIONS(1996),
    [anon_sym_catch] = ACTIONS(2461),
    [anon_sym_R_DQUOTE] = ACTIONS(1998),
    [anon_sym_LR_DQUOTE] = ACTIONS(1998),
    [anon_sym_uR_DQUOTE] = ACTIONS(1998),
    [anon_sym_UR_DQUOTE] = ACTIONS(1998),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1998),
    [anon_sym_co_await] = ACTIONS(1996),
    [anon_sym_new] = ACTIONS(1996),
    [anon_sym_requires] = ACTIONS(1996),
    [sym_this] = ACTIONS(1996),
    [anon_sym___launch_bounds__] = ACTIONS(1996),
  },
  [STATE(330)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_else] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_catch] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(331)] = {
    [sym_else_clause] = STATE(355),
    [ts_builtin_sym_end] = ACTIONS(2012),
    [sym_identifier] = ACTIONS(2010),
    [aux_sym_preproc_include_token1] = ACTIONS(2010),
    [aux_sym_preproc_def_token1] = ACTIONS(2010),
    [aux_sym_preproc_if_token1] = ACTIONS(2010),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2010),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2010),
    [sym_preproc_directive] = ACTIONS(2010),
    [anon_sym_LPAREN2] = ACTIONS(2012),
    [anon_sym_BANG] = ACTIONS(2012),
    [anon_sym_TILDE] = ACTIONS(2012),
    [anon_sym_DASH] = ACTIONS(2010),
    [anon_sym_PLUS] = ACTIONS(2010),
    [anon_sym_STAR] = ACTIONS(2012),
    [anon_sym_AMP_AMP] = ACTIONS(2012),
    [anon_sym_AMP] = ACTIONS(2010),
    [anon_sym_SEMI] = ACTIONS(2012),
    [anon_sym___extension__] = ACTIONS(2010),
    [anon_sym_typedef] = ACTIONS(2010),
    [anon_sym___device__] = ACTIONS(2010),
    [anon_sym___host__] = ACTIONS(2010),
    [anon_sym___global__] = ACTIONS(2010),
    [anon_sym___forceinline__] = ACTIONS(2010),
    [anon_sym___noinline__] = ACTIONS(2010),
    [anon_sym_virtual] = ACTIONS(2010),
    [anon_sym_extern] = ACTIONS(2010),
    [anon_sym___attribute__] = ACTIONS(2010),
    [anon_sym___attribute] = ACTIONS(2010),
    [anon_sym_COLON_COLON] = ACTIONS(2012),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2012),
    [anon_sym___declspec] = ACTIONS(2010),
    [anon_sym___based] = ACTIONS(2010),
    [anon_sym___cdecl] = ACTIONS(2010),
    [anon_sym___clrcall] = ACTIONS(2010),
    [anon_sym___stdcall] = ACTIONS(2010),
    [anon_sym___fastcall] = ACTIONS(2010),
    [anon_sym___thiscall] = ACTIONS(2010),
    [anon_sym___vectorcall] = ACTIONS(2010),
    [anon_sym_LBRACE] = ACTIONS(2012),
    [anon_sym_signed] = ACTIONS(2010),
    [anon_sym_unsigned] = ACTIONS(2010),
    [anon_sym_long] = ACTIONS(2010),
    [anon_sym_short] = ACTIONS(2010),
    [anon_sym_LBRACK] = ACTIONS(2010),
    [anon_sym_static] = ACTIONS(2010),
    [anon_sym_register] = ACTIONS(2010),
    [anon_sym_inline] = ACTIONS(2010),
    [anon_sym___inline] = ACTIONS(2010),
    [anon_sym___inline__] = ACTIONS(2010),
    [anon_sym___forceinline] = ACTIONS(2010),
    [anon_sym_thread_local] = ACTIONS(2010),
    [anon_sym___thread] = ACTIONS(2010),
    [anon_sym_const] = ACTIONS(2010),
    [anon_sym_constexpr] = ACTIONS(2010),
    [anon_sym_volatile] = ACTIONS(2010),
    [anon_sym_restrict] = ACTIONS(2010),
    [anon_sym___restrict__] = ACTIONS(2010),
    [anon_sym__Atomic] = ACTIONS(2010),
    [anon_sym__Noreturn] = ACTIONS(2010),
    [anon_sym_noreturn] = ACTIONS(2010),
    [anon_sym__Nonnull] = ACTIONS(2010),
    [anon_sym_mutable] = ACTIONS(2010),
    [anon_sym_constinit] = ACTIONS(2010),
    [anon_sym_consteval] = ACTIONS(2010),
    [anon_sym___shared__] = ACTIONS(2010),
    [anon_sym___local__] = ACTIONS(2010),
    [anon_sym___constant__] = ACTIONS(2010),
    [anon_sym___managed__] = ACTIONS(2010),
    [anon_sym___grid_constant__] = ACTIONS(2010),
    [anon_sym_alignas] = ACTIONS(2010),
    [anon_sym__Alignas] = ACTIONS(2010),
    [sym_primitive_type] = ACTIONS(2010),
    [anon_sym_enum] = ACTIONS(2010),
    [anon_sym_class] = ACTIONS(2010),
    [anon_sym_struct] = ACTIONS(2010),
    [anon_sym_union] = ACTIONS(2010),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_else] = ACTIONS(2681),
    [anon_sym_switch] = ACTIONS(2010),
    [anon_sym_case] = ACTIONS(2010),
    [anon_sym_default] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2010),
    [anon_sym_do] = ACTIONS(2010),
    [anon_sym_for] = ACTIONS(2010),
    [anon_sym_return] = ACTIONS(2010),
    [anon_sym_break] = ACTIONS(2010),
    [anon_sym_continue] = ACTIONS(2010),
    [anon_sym_goto] = ACTIONS(2010),
    [anon_sym___try] = ACTIONS(2010),
    [anon_sym___leave] = ACTIONS(2010),
    [anon_sym_not] = ACTIONS(2010),
    [anon_sym_compl] = ACTIONS(2010),
    [anon_sym_DASH_DASH] = ACTIONS(2012),
    [anon_sym_PLUS_PLUS] = ACTIONS(2012),
    [anon_sym_sizeof] = ACTIONS(2010),
    [anon_sym___alignof__] = ACTIONS(2010),
    [anon_sym___alignof] = ACTIONS(2010),
    [anon_sym__alignof] = ACTIONS(2010),
    [anon_sym_alignof] = ACTIONS(2010),
    [anon_sym__Alignof] = ACTIONS(2010),
    [anon_sym_offsetof] = ACTIONS(2010),
    [anon_sym__Generic] = ACTIONS(2010),
    [anon_sym_asm] = ACTIONS(2010),
    [anon_sym___asm__] = ACTIONS(2010),
    [anon_sym___asm] = ACTIONS(2010),
    [sym_number_literal] = ACTIONS(2012),
    [anon_sym_L_SQUOTE] = ACTIONS(2012),
    [anon_sym_u_SQUOTE] = ACTIONS(2012),
    [anon_sym_U_SQUOTE] = ACTIONS(2012),
    [anon_sym_u8_SQUOTE] = ACTIONS(2012),
    [anon_sym_SQUOTE] = ACTIONS(2012),
    [anon_sym_L_DQUOTE] = ACTIONS(2012),
    [anon_sym_u_DQUOTE] = ACTIONS(2012),
    [anon_sym_U_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8_DQUOTE] = ACTIONS(2012),
    [anon_sym_DQUOTE] = ACTIONS(2012),
    [sym_true] = ACTIONS(2010),
    [sym_false] = ACTIONS(2010),
    [anon_sym_NULL] = ACTIONS(2010),
    [anon_sym_nullptr] = ACTIONS(2010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2010),
    [anon_sym_decltype] = ACTIONS(2010),
    [anon_sym_explicit] = ACTIONS(2010),
    [anon_sym_typename] = ACTIONS(2010),
    [anon_sym_template] = ACTIONS(2010),
    [anon_sym_operator] = ACTIONS(2010),
    [anon_sym_try] = ACTIONS(2010),
    [anon_sym_delete] = ACTIONS(2010),
    [anon_sym_throw] = ACTIONS(2010),
    [anon_sym_namespace] = ACTIONS(2010),
    [anon_sym_using] = ACTIONS(2010),
    [anon_sym_static_assert] = ACTIONS(2010),
    [anon_sym_concept] = ACTIONS(2010),
    [anon_sym_co_return] = ACTIONS(2010),
    [anon_sym_co_yield] = ACTIONS(2010),
    [anon_sym_R_DQUOTE] = ACTIONS(2012),
    [anon_sym_LR_DQUOTE] = ACTIONS(2012),
    [anon_sym_uR_DQUOTE] = ACTIONS(2012),
    [anon_sym_UR_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2012),
    [anon_sym_co_await] = ACTIONS(2010),
    [anon_sym_new] = ACTIONS(2010),
    [anon_sym_requires] = ACTIONS(2010),
    [sym_this] = ACTIONS(2010),
    [anon_sym___launch_bounds__] = ACTIONS(2010),
  },
  [STATE(332)] = {
    [sym_identifier] = ACTIONS(2006),
    [aux_sym_preproc_include_token1] = ACTIONS(2006),
    [aux_sym_preproc_def_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2006),
    [sym_preproc_directive] = ACTIONS(2006),
    [anon_sym_LPAREN2] = ACTIONS(2008),
    [anon_sym_BANG] = ACTIONS(2008),
    [anon_sym_TILDE] = ACTIONS(2008),
    [anon_sym_DASH] = ACTIONS(2006),
    [anon_sym_PLUS] = ACTIONS(2006),
    [anon_sym_STAR] = ACTIONS(2008),
    [anon_sym_AMP_AMP] = ACTIONS(2008),
    [anon_sym_AMP] = ACTIONS(2006),
    [anon_sym_SEMI] = ACTIONS(2008),
    [anon_sym___extension__] = ACTIONS(2006),
    [anon_sym_typedef] = ACTIONS(2006),
    [anon_sym___device__] = ACTIONS(2006),
    [anon_sym___host__] = ACTIONS(2006),
    [anon_sym___global__] = ACTIONS(2006),
    [anon_sym___forceinline__] = ACTIONS(2006),
    [anon_sym___noinline__] = ACTIONS(2006),
    [anon_sym_virtual] = ACTIONS(2006),
    [anon_sym_extern] = ACTIONS(2006),
    [anon_sym___attribute__] = ACTIONS(2006),
    [anon_sym___attribute] = ACTIONS(2006),
    [anon_sym_COLON_COLON] = ACTIONS(2008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2008),
    [anon_sym___declspec] = ACTIONS(2006),
    [anon_sym___based] = ACTIONS(2006),
    [anon_sym___cdecl] = ACTIONS(2006),
    [anon_sym___clrcall] = ACTIONS(2006),
    [anon_sym___stdcall] = ACTIONS(2006),
    [anon_sym___fastcall] = ACTIONS(2006),
    [anon_sym___thiscall] = ACTIONS(2006),
    [anon_sym___vectorcall] = ACTIONS(2006),
    [anon_sym_LBRACE] = ACTIONS(2008),
    [anon_sym_RBRACE] = ACTIONS(2008),
    [anon_sym_signed] = ACTIONS(2006),
    [anon_sym_unsigned] = ACTIONS(2006),
    [anon_sym_long] = ACTIONS(2006),
    [anon_sym_short] = ACTIONS(2006),
    [anon_sym_LBRACK] = ACTIONS(2006),
    [anon_sym_static] = ACTIONS(2006),
    [anon_sym_register] = ACTIONS(2006),
    [anon_sym_inline] = ACTIONS(2006),
    [anon_sym___inline] = ACTIONS(2006),
    [anon_sym___inline__] = ACTIONS(2006),
    [anon_sym___forceinline] = ACTIONS(2006),
    [anon_sym_thread_local] = ACTIONS(2006),
    [anon_sym___thread] = ACTIONS(2006),
    [anon_sym_const] = ACTIONS(2006),
    [anon_sym_constexpr] = ACTIONS(2006),
    [anon_sym_volatile] = ACTIONS(2006),
    [anon_sym_restrict] = ACTIONS(2006),
    [anon_sym___restrict__] = ACTIONS(2006),
    [anon_sym__Atomic] = ACTIONS(2006),
    [anon_sym__Noreturn] = ACTIONS(2006),
    [anon_sym_noreturn] = ACTIONS(2006),
    [anon_sym__Nonnull] = ACTIONS(2006),
    [anon_sym_mutable] = ACTIONS(2006),
    [anon_sym_constinit] = ACTIONS(2006),
    [anon_sym_consteval] = ACTIONS(2006),
    [anon_sym___shared__] = ACTIONS(2006),
    [anon_sym___local__] = ACTIONS(2006),
    [anon_sym___constant__] = ACTIONS(2006),
    [anon_sym___managed__] = ACTIONS(2006),
    [anon_sym___grid_constant__] = ACTIONS(2006),
    [anon_sym_alignas] = ACTIONS(2006),
    [anon_sym__Alignas] = ACTIONS(2006),
    [sym_primitive_type] = ACTIONS(2006),
    [anon_sym_enum] = ACTIONS(2006),
    [anon_sym_class] = ACTIONS(2006),
    [anon_sym_struct] = ACTIONS(2006),
    [anon_sym_union] = ACTIONS(2006),
    [anon_sym_if] = ACTIONS(2006),
    [anon_sym_else] = ACTIONS(2006),
    [anon_sym_switch] = ACTIONS(2006),
    [anon_sym_case] = ACTIONS(2006),
    [anon_sym_default] = ACTIONS(2006),
    [anon_sym_while] = ACTIONS(2006),
    [anon_sym_do] = ACTIONS(2006),
    [anon_sym_for] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2006),
    [anon_sym_break] = ACTIONS(2006),
    [anon_sym_continue] = ACTIONS(2006),
    [anon_sym_goto] = ACTIONS(2006),
    [anon_sym___try] = ACTIONS(2006),
    [anon_sym___leave] = ACTIONS(2006),
    [anon_sym_not] = ACTIONS(2006),
    [anon_sym_compl] = ACTIONS(2006),
    [anon_sym_DASH_DASH] = ACTIONS(2008),
    [anon_sym_PLUS_PLUS] = ACTIONS(2008),
    [anon_sym_sizeof] = ACTIONS(2006),
    [anon_sym___alignof__] = ACTIONS(2006),
    [anon_sym___alignof] = ACTIONS(2006),
    [anon_sym__alignof] = ACTIONS(2006),
    [anon_sym_alignof] = ACTIONS(2006),
    [anon_sym__Alignof] = ACTIONS(2006),
    [anon_sym_offsetof] = ACTIONS(2006),
    [anon_sym__Generic] = ACTIONS(2006),
    [anon_sym_asm] = ACTIONS(2006),
    [anon_sym___asm__] = ACTIONS(2006),
    [anon_sym___asm] = ACTIONS(2006),
    [sym_number_literal] = ACTIONS(2008),
    [anon_sym_L_SQUOTE] = ACTIONS(2008),
    [anon_sym_u_SQUOTE] = ACTIONS(2008),
    [anon_sym_U_SQUOTE] = ACTIONS(2008),
    [anon_sym_u8_SQUOTE] = ACTIONS(2008),
    [anon_sym_SQUOTE] = ACTIONS(2008),
    [anon_sym_L_DQUOTE] = ACTIONS(2008),
    [anon_sym_u_DQUOTE] = ACTIONS(2008),
    [anon_sym_U_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8_DQUOTE] = ACTIONS(2008),
    [anon_sym_DQUOTE] = ACTIONS(2008),
    [sym_true] = ACTIONS(2006),
    [sym_false] = ACTIONS(2006),
    [anon_sym_NULL] = ACTIONS(2006),
    [anon_sym_nullptr] = ACTIONS(2006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2006),
    [anon_sym_decltype] = ACTIONS(2006),
    [anon_sym_explicit] = ACTIONS(2006),
    [anon_sym_typename] = ACTIONS(2006),
    [anon_sym_template] = ACTIONS(2006),
    [anon_sym_operator] = ACTIONS(2006),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_delete] = ACTIONS(2006),
    [anon_sym_throw] = ACTIONS(2006),
    [anon_sym_namespace] = ACTIONS(2006),
    [anon_sym_using] = ACTIONS(2006),
    [anon_sym_static_assert] = ACTIONS(2006),
    [anon_sym_concept] = ACTIONS(2006),
    [anon_sym_co_return] = ACTIONS(2006),
    [anon_sym_co_yield] = ACTIONS(2006),
    [anon_sym_catch] = ACTIONS(2006),
    [anon_sym_R_DQUOTE] = ACTIONS(2008),
    [anon_sym_LR_DQUOTE] = ACTIONS(2008),
    [anon_sym_uR_DQUOTE] = ACTIONS(2008),
    [anon_sym_UR_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2008),
    [anon_sym_co_await] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(2006),
    [anon_sym_requires] = ACTIONS(2006),
    [sym_this] = ACTIONS(2006),
    [anon_sym___launch_bounds__] = ACTIONS(2006),
  },
  [STATE(333)] = {
    [sym_else_clause] = STATE(444),
    [sym_identifier] = ACTIONS(2010),
    [aux_sym_preproc_include_token1] = ACTIONS(2010),
    [aux_sym_preproc_def_token1] = ACTIONS(2010),
    [aux_sym_preproc_if_token1] = ACTIONS(2010),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2010),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2010),
    [sym_preproc_directive] = ACTIONS(2010),
    [anon_sym_LPAREN2] = ACTIONS(2012),
    [anon_sym_BANG] = ACTIONS(2012),
    [anon_sym_TILDE] = ACTIONS(2012),
    [anon_sym_DASH] = ACTIONS(2010),
    [anon_sym_PLUS] = ACTIONS(2010),
    [anon_sym_STAR] = ACTIONS(2012),
    [anon_sym_AMP_AMP] = ACTIONS(2012),
    [anon_sym_AMP] = ACTIONS(2010),
    [anon_sym_SEMI] = ACTIONS(2012),
    [anon_sym___extension__] = ACTIONS(2010),
    [anon_sym_typedef] = ACTIONS(2010),
    [anon_sym___device__] = ACTIONS(2010),
    [anon_sym___host__] = ACTIONS(2010),
    [anon_sym___global__] = ACTIONS(2010),
    [anon_sym___forceinline__] = ACTIONS(2010),
    [anon_sym___noinline__] = ACTIONS(2010),
    [anon_sym_virtual] = ACTIONS(2010),
    [anon_sym_extern] = ACTIONS(2010),
    [anon_sym___attribute__] = ACTIONS(2010),
    [anon_sym___attribute] = ACTIONS(2010),
    [anon_sym_COLON_COLON] = ACTIONS(2012),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2012),
    [anon_sym___declspec] = ACTIONS(2010),
    [anon_sym___based] = ACTIONS(2010),
    [anon_sym___cdecl] = ACTIONS(2010),
    [anon_sym___clrcall] = ACTIONS(2010),
    [anon_sym___stdcall] = ACTIONS(2010),
    [anon_sym___fastcall] = ACTIONS(2010),
    [anon_sym___thiscall] = ACTIONS(2010),
    [anon_sym___vectorcall] = ACTIONS(2010),
    [anon_sym_LBRACE] = ACTIONS(2012),
    [anon_sym_RBRACE] = ACTIONS(2012),
    [anon_sym_signed] = ACTIONS(2010),
    [anon_sym_unsigned] = ACTIONS(2010),
    [anon_sym_long] = ACTIONS(2010),
    [anon_sym_short] = ACTIONS(2010),
    [anon_sym_LBRACK] = ACTIONS(2010),
    [anon_sym_static] = ACTIONS(2010),
    [anon_sym_register] = ACTIONS(2010),
    [anon_sym_inline] = ACTIONS(2010),
    [anon_sym___inline] = ACTIONS(2010),
    [anon_sym___inline__] = ACTIONS(2010),
    [anon_sym___forceinline] = ACTIONS(2010),
    [anon_sym_thread_local] = ACTIONS(2010),
    [anon_sym___thread] = ACTIONS(2010),
    [anon_sym_const] = ACTIONS(2010),
    [anon_sym_constexpr] = ACTIONS(2010),
    [anon_sym_volatile] = ACTIONS(2010),
    [anon_sym_restrict] = ACTIONS(2010),
    [anon_sym___restrict__] = ACTIONS(2010),
    [anon_sym__Atomic] = ACTIONS(2010),
    [anon_sym__Noreturn] = ACTIONS(2010),
    [anon_sym_noreturn] = ACTIONS(2010),
    [anon_sym__Nonnull] = ACTIONS(2010),
    [anon_sym_mutable] = ACTIONS(2010),
    [anon_sym_constinit] = ACTIONS(2010),
    [anon_sym_consteval] = ACTIONS(2010),
    [anon_sym___shared__] = ACTIONS(2010),
    [anon_sym___local__] = ACTIONS(2010),
    [anon_sym___constant__] = ACTIONS(2010),
    [anon_sym___managed__] = ACTIONS(2010),
    [anon_sym___grid_constant__] = ACTIONS(2010),
    [anon_sym_alignas] = ACTIONS(2010),
    [anon_sym__Alignas] = ACTIONS(2010),
    [sym_primitive_type] = ACTIONS(2010),
    [anon_sym_enum] = ACTIONS(2010),
    [anon_sym_class] = ACTIONS(2010),
    [anon_sym_struct] = ACTIONS(2010),
    [anon_sym_union] = ACTIONS(2010),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_else] = ACTIONS(2683),
    [anon_sym_switch] = ACTIONS(2010),
    [anon_sym_case] = ACTIONS(2010),
    [anon_sym_default] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2010),
    [anon_sym_do] = ACTIONS(2010),
    [anon_sym_for] = ACTIONS(2010),
    [anon_sym_return] = ACTIONS(2010),
    [anon_sym_break] = ACTIONS(2010),
    [anon_sym_continue] = ACTIONS(2010),
    [anon_sym_goto] = ACTIONS(2010),
    [anon_sym___try] = ACTIONS(2010),
    [anon_sym___leave] = ACTIONS(2010),
    [anon_sym_not] = ACTIONS(2010),
    [anon_sym_compl] = ACTIONS(2010),
    [anon_sym_DASH_DASH] = ACTIONS(2012),
    [anon_sym_PLUS_PLUS] = ACTIONS(2012),
    [anon_sym_sizeof] = ACTIONS(2010),
    [anon_sym___alignof__] = ACTIONS(2010),
    [anon_sym___alignof] = ACTIONS(2010),
    [anon_sym__alignof] = ACTIONS(2010),
    [anon_sym_alignof] = ACTIONS(2010),
    [anon_sym__Alignof] = ACTIONS(2010),
    [anon_sym_offsetof] = ACTIONS(2010),
    [anon_sym__Generic] = ACTIONS(2010),
    [anon_sym_asm] = ACTIONS(2010),
    [anon_sym___asm__] = ACTIONS(2010),
    [anon_sym___asm] = ACTIONS(2010),
    [sym_number_literal] = ACTIONS(2012),
    [anon_sym_L_SQUOTE] = ACTIONS(2012),
    [anon_sym_u_SQUOTE] = ACTIONS(2012),
    [anon_sym_U_SQUOTE] = ACTIONS(2012),
    [anon_sym_u8_SQUOTE] = ACTIONS(2012),
    [anon_sym_SQUOTE] = ACTIONS(2012),
    [anon_sym_L_DQUOTE] = ACTIONS(2012),
    [anon_sym_u_DQUOTE] = ACTIONS(2012),
    [anon_sym_U_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8_DQUOTE] = ACTIONS(2012),
    [anon_sym_DQUOTE] = ACTIONS(2012),
    [sym_true] = ACTIONS(2010),
    [sym_false] = ACTIONS(2010),
    [anon_sym_NULL] = ACTIONS(2010),
    [anon_sym_nullptr] = ACTIONS(2010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2010),
    [anon_sym_decltype] = ACTIONS(2010),
    [anon_sym_explicit] = ACTIONS(2010),
    [anon_sym_typename] = ACTIONS(2010),
    [anon_sym_template] = ACTIONS(2010),
    [anon_sym_operator] = ACTIONS(2010),
    [anon_sym_try] = ACTIONS(2010),
    [anon_sym_delete] = ACTIONS(2010),
    [anon_sym_throw] = ACTIONS(2010),
    [anon_sym_namespace] = ACTIONS(2010),
    [anon_sym_using] = ACTIONS(2010),
    [anon_sym_static_assert] = ACTIONS(2010),
    [anon_sym_concept] = ACTIONS(2010),
    [anon_sym_co_return] = ACTIONS(2010),
    [anon_sym_co_yield] = ACTIONS(2010),
    [anon_sym_R_DQUOTE] = ACTIONS(2012),
    [anon_sym_LR_DQUOTE] = ACTIONS(2012),
    [anon_sym_uR_DQUOTE] = ACTIONS(2012),
    [anon_sym_UR_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2012),
    [anon_sym_co_await] = ACTIONS(2010),
    [anon_sym_new] = ACTIONS(2010),
    [anon_sym_requires] = ACTIONS(2010),
    [sym_this] = ACTIONS(2010),
    [anon_sym___launch_bounds__] = ACTIONS(2010),
  },
  [STATE(334)] = {
    [sym_identifier] = ACTIONS(1928),
    [aux_sym_preproc_include_token1] = ACTIONS(1928),
    [aux_sym_preproc_def_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token2] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1928),
    [sym_preproc_directive] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_BANG] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_DASH] = ACTIONS(1928),
    [anon_sym_PLUS] = ACTIONS(1928),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_AMP_AMP] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1928),
    [anon_sym_SEMI] = ACTIONS(1926),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym_typedef] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym___based] = ACTIONS(1928),
    [anon_sym___cdecl] = ACTIONS(1928),
    [anon_sym___clrcall] = ACTIONS(1928),
    [anon_sym___stdcall] = ACTIONS(1928),
    [anon_sym___fastcall] = ACTIONS(1928),
    [anon_sym___thiscall] = ACTIONS(1928),
    [anon_sym___vectorcall] = ACTIONS(1928),
    [anon_sym_LBRACE] = ACTIONS(1926),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [anon_sym_if] = ACTIONS(1928),
    [anon_sym_else] = ACTIONS(1928),
    [anon_sym_switch] = ACTIONS(1928),
    [anon_sym_case] = ACTIONS(1928),
    [anon_sym_default] = ACTIONS(1928),
    [anon_sym_while] = ACTIONS(1928),
    [anon_sym_do] = ACTIONS(1928),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_return] = ACTIONS(1928),
    [anon_sym_break] = ACTIONS(1928),
    [anon_sym_continue] = ACTIONS(1928),
    [anon_sym_goto] = ACTIONS(1928),
    [anon_sym___try] = ACTIONS(1928),
    [anon_sym___leave] = ACTIONS(1928),
    [anon_sym_not] = ACTIONS(1928),
    [anon_sym_compl] = ACTIONS(1928),
    [anon_sym_DASH_DASH] = ACTIONS(1926),
    [anon_sym_PLUS_PLUS] = ACTIONS(1926),
    [anon_sym_sizeof] = ACTIONS(1928),
    [anon_sym___alignof__] = ACTIONS(1928),
    [anon_sym___alignof] = ACTIONS(1928),
    [anon_sym__alignof] = ACTIONS(1928),
    [anon_sym_alignof] = ACTIONS(1928),
    [anon_sym__Alignof] = ACTIONS(1928),
    [anon_sym_offsetof] = ACTIONS(1928),
    [anon_sym__Generic] = ACTIONS(1928),
    [anon_sym_asm] = ACTIONS(1928),
    [anon_sym___asm__] = ACTIONS(1928),
    [anon_sym___asm] = ACTIONS(1928),
    [sym_number_literal] = ACTIONS(1926),
    [anon_sym_L_SQUOTE] = ACTIONS(1926),
    [anon_sym_u_SQUOTE] = ACTIONS(1926),
    [anon_sym_U_SQUOTE] = ACTIONS(1926),
    [anon_sym_u8_SQUOTE] = ACTIONS(1926),
    [anon_sym_SQUOTE] = ACTIONS(1926),
    [anon_sym_L_DQUOTE] = ACTIONS(1926),
    [anon_sym_u_DQUOTE] = ACTIONS(1926),
    [anon_sym_U_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8_DQUOTE] = ACTIONS(1926),
    [anon_sym_DQUOTE] = ACTIONS(1926),
    [sym_true] = ACTIONS(1928),
    [sym_false] = ACTIONS(1928),
    [anon_sym_NULL] = ACTIONS(1928),
    [anon_sym_nullptr] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_explicit] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_operator] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_delete] = ACTIONS(1928),
    [anon_sym_throw] = ACTIONS(1928),
    [anon_sym_namespace] = ACTIONS(1928),
    [anon_sym_using] = ACTIONS(1928),
    [anon_sym_static_assert] = ACTIONS(1928),
    [anon_sym_concept] = ACTIONS(1928),
    [anon_sym_co_return] = ACTIONS(1928),
    [anon_sym_co_yield] = ACTIONS(1928),
    [anon_sym_catch] = ACTIONS(1928),
    [anon_sym_R_DQUOTE] = ACTIONS(1926),
    [anon_sym_LR_DQUOTE] = ACTIONS(1926),
    [anon_sym_uR_DQUOTE] = ACTIONS(1926),
    [anon_sym_UR_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1926),
    [anon_sym_co_await] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1928),
    [anon_sym_requires] = ACTIONS(1928),
    [sym_this] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(335)] = {
    [sym_else_clause] = STATE(435),
    [sym_identifier] = ACTIONS(2016),
    [aux_sym_preproc_include_token1] = ACTIONS(2016),
    [aux_sym_preproc_def_token1] = ACTIONS(2016),
    [aux_sym_preproc_if_token1] = ACTIONS(2016),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2016),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2016),
    [sym_preproc_directive] = ACTIONS(2016),
    [anon_sym_LPAREN2] = ACTIONS(2018),
    [anon_sym_BANG] = ACTIONS(2018),
    [anon_sym_TILDE] = ACTIONS(2018),
    [anon_sym_DASH] = ACTIONS(2016),
    [anon_sym_PLUS] = ACTIONS(2016),
    [anon_sym_STAR] = ACTIONS(2018),
    [anon_sym_AMP_AMP] = ACTIONS(2018),
    [anon_sym_AMP] = ACTIONS(2016),
    [anon_sym_SEMI] = ACTIONS(2018),
    [anon_sym___extension__] = ACTIONS(2016),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym___device__] = ACTIONS(2016),
    [anon_sym___host__] = ACTIONS(2016),
    [anon_sym___global__] = ACTIONS(2016),
    [anon_sym___forceinline__] = ACTIONS(2016),
    [anon_sym___noinline__] = ACTIONS(2016),
    [anon_sym_virtual] = ACTIONS(2016),
    [anon_sym_extern] = ACTIONS(2016),
    [anon_sym___attribute__] = ACTIONS(2016),
    [anon_sym___attribute] = ACTIONS(2016),
    [anon_sym_COLON_COLON] = ACTIONS(2018),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2018),
    [anon_sym___declspec] = ACTIONS(2016),
    [anon_sym___based] = ACTIONS(2016),
    [anon_sym___cdecl] = ACTIONS(2016),
    [anon_sym___clrcall] = ACTIONS(2016),
    [anon_sym___stdcall] = ACTIONS(2016),
    [anon_sym___fastcall] = ACTIONS(2016),
    [anon_sym___thiscall] = ACTIONS(2016),
    [anon_sym___vectorcall] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2018),
    [anon_sym_RBRACE] = ACTIONS(2018),
    [anon_sym_signed] = ACTIONS(2016),
    [anon_sym_unsigned] = ACTIONS(2016),
    [anon_sym_long] = ACTIONS(2016),
    [anon_sym_short] = ACTIONS(2016),
    [anon_sym_LBRACK] = ACTIONS(2016),
    [anon_sym_static] = ACTIONS(2016),
    [anon_sym_register] = ACTIONS(2016),
    [anon_sym_inline] = ACTIONS(2016),
    [anon_sym___inline] = ACTIONS(2016),
    [anon_sym___inline__] = ACTIONS(2016),
    [anon_sym___forceinline] = ACTIONS(2016),
    [anon_sym_thread_local] = ACTIONS(2016),
    [anon_sym___thread] = ACTIONS(2016),
    [anon_sym_const] = ACTIONS(2016),
    [anon_sym_constexpr] = ACTIONS(2016),
    [anon_sym_volatile] = ACTIONS(2016),
    [anon_sym_restrict] = ACTIONS(2016),
    [anon_sym___restrict__] = ACTIONS(2016),
    [anon_sym__Atomic] = ACTIONS(2016),
    [anon_sym__Noreturn] = ACTIONS(2016),
    [anon_sym_noreturn] = ACTIONS(2016),
    [anon_sym__Nonnull] = ACTIONS(2016),
    [anon_sym_mutable] = ACTIONS(2016),
    [anon_sym_constinit] = ACTIONS(2016),
    [anon_sym_consteval] = ACTIONS(2016),
    [anon_sym___shared__] = ACTIONS(2016),
    [anon_sym___local__] = ACTIONS(2016),
    [anon_sym___constant__] = ACTIONS(2016),
    [anon_sym___managed__] = ACTIONS(2016),
    [anon_sym___grid_constant__] = ACTIONS(2016),
    [anon_sym_alignas] = ACTIONS(2016),
    [anon_sym__Alignas] = ACTIONS(2016),
    [sym_primitive_type] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2016),
    [anon_sym_class] = ACTIONS(2016),
    [anon_sym_struct] = ACTIONS(2016),
    [anon_sym_union] = ACTIONS(2016),
    [anon_sym_if] = ACTIONS(2016),
    [anon_sym_else] = ACTIONS(2683),
    [anon_sym_switch] = ACTIONS(2016),
    [anon_sym_case] = ACTIONS(2016),
    [anon_sym_default] = ACTIONS(2016),
    [anon_sym_while] = ACTIONS(2016),
    [anon_sym_do] = ACTIONS(2016),
    [anon_sym_for] = ACTIONS(2016),
    [anon_sym_return] = ACTIONS(2016),
    [anon_sym_break] = ACTIONS(2016),
    [anon_sym_continue] = ACTIONS(2016),
    [anon_sym_goto] = ACTIONS(2016),
    [anon_sym___try] = ACTIONS(2016),
    [anon_sym___leave] = ACTIONS(2016),
    [anon_sym_not] = ACTIONS(2016),
    [anon_sym_compl] = ACTIONS(2016),
    [anon_sym_DASH_DASH] = ACTIONS(2018),
    [anon_sym_PLUS_PLUS] = ACTIONS(2018),
    [anon_sym_sizeof] = ACTIONS(2016),
    [anon_sym___alignof__] = ACTIONS(2016),
    [anon_sym___alignof] = ACTIONS(2016),
    [anon_sym__alignof] = ACTIONS(2016),
    [anon_sym_alignof] = ACTIONS(2016),
    [anon_sym__Alignof] = ACTIONS(2016),
    [anon_sym_offsetof] = ACTIONS(2016),
    [anon_sym__Generic] = ACTIONS(2016),
    [anon_sym_asm] = ACTIONS(2016),
    [anon_sym___asm__] = ACTIONS(2016),
    [anon_sym___asm] = ACTIONS(2016),
    [sym_number_literal] = ACTIONS(2018),
    [anon_sym_L_SQUOTE] = ACTIONS(2018),
    [anon_sym_u_SQUOTE] = ACTIONS(2018),
    [anon_sym_U_SQUOTE] = ACTIONS(2018),
    [anon_sym_u8_SQUOTE] = ACTIONS(2018),
    [anon_sym_SQUOTE] = ACTIONS(2018),
    [anon_sym_L_DQUOTE] = ACTIONS(2018),
    [anon_sym_u_DQUOTE] = ACTIONS(2018),
    [anon_sym_U_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8_DQUOTE] = ACTIONS(2018),
    [anon_sym_DQUOTE] = ACTIONS(2018),
    [sym_true] = ACTIONS(2016),
    [sym_false] = ACTIONS(2016),
    [anon_sym_NULL] = ACTIONS(2016),
    [anon_sym_nullptr] = ACTIONS(2016),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2016),
    [anon_sym_decltype] = ACTIONS(2016),
    [anon_sym_explicit] = ACTIONS(2016),
    [anon_sym_typename] = ACTIONS(2016),
    [anon_sym_template] = ACTIONS(2016),
    [anon_sym_operator] = ACTIONS(2016),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_delete] = ACTIONS(2016),
    [anon_sym_throw] = ACTIONS(2016),
    [anon_sym_namespace] = ACTIONS(2016),
    [anon_sym_using] = ACTIONS(2016),
    [anon_sym_static_assert] = ACTIONS(2016),
    [anon_sym_concept] = ACTIONS(2016),
    [anon_sym_co_return] = ACTIONS(2016),
    [anon_sym_co_yield] = ACTIONS(2016),
    [anon_sym_R_DQUOTE] = ACTIONS(2018),
    [anon_sym_LR_DQUOTE] = ACTIONS(2018),
    [anon_sym_uR_DQUOTE] = ACTIONS(2018),
    [anon_sym_UR_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2018),
    [anon_sym_co_await] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(2016),
    [anon_sym_requires] = ACTIONS(2016),
    [sym_this] = ACTIONS(2016),
    [anon_sym___launch_bounds__] = ACTIONS(2016),
  },
  [STATE(336)] = {
    [sym_identifier] = ACTIONS(2006),
    [aux_sym_preproc_include_token1] = ACTIONS(2006),
    [aux_sym_preproc_def_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token2] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2006),
    [sym_preproc_directive] = ACTIONS(2006),
    [anon_sym_LPAREN2] = ACTIONS(2008),
    [anon_sym_BANG] = ACTIONS(2008),
    [anon_sym_TILDE] = ACTIONS(2008),
    [anon_sym_DASH] = ACTIONS(2006),
    [anon_sym_PLUS] = ACTIONS(2006),
    [anon_sym_STAR] = ACTIONS(2008),
    [anon_sym_AMP_AMP] = ACTIONS(2008),
    [anon_sym_AMP] = ACTIONS(2006),
    [anon_sym_SEMI] = ACTIONS(2008),
    [anon_sym___extension__] = ACTIONS(2006),
    [anon_sym_typedef] = ACTIONS(2006),
    [anon_sym___device__] = ACTIONS(2006),
    [anon_sym___host__] = ACTIONS(2006),
    [anon_sym___global__] = ACTIONS(2006),
    [anon_sym___forceinline__] = ACTIONS(2006),
    [anon_sym___noinline__] = ACTIONS(2006),
    [anon_sym_virtual] = ACTIONS(2006),
    [anon_sym_extern] = ACTIONS(2006),
    [anon_sym___attribute__] = ACTIONS(2006),
    [anon_sym___attribute] = ACTIONS(2006),
    [anon_sym_COLON_COLON] = ACTIONS(2008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2008),
    [anon_sym___declspec] = ACTIONS(2006),
    [anon_sym___based] = ACTIONS(2006),
    [anon_sym___cdecl] = ACTIONS(2006),
    [anon_sym___clrcall] = ACTIONS(2006),
    [anon_sym___stdcall] = ACTIONS(2006),
    [anon_sym___fastcall] = ACTIONS(2006),
    [anon_sym___thiscall] = ACTIONS(2006),
    [anon_sym___vectorcall] = ACTIONS(2006),
    [anon_sym_LBRACE] = ACTIONS(2008),
    [anon_sym_signed] = ACTIONS(2006),
    [anon_sym_unsigned] = ACTIONS(2006),
    [anon_sym_long] = ACTIONS(2006),
    [anon_sym_short] = ACTIONS(2006),
    [anon_sym_LBRACK] = ACTIONS(2006),
    [anon_sym_static] = ACTIONS(2006),
    [anon_sym_register] = ACTIONS(2006),
    [anon_sym_inline] = ACTIONS(2006),
    [anon_sym___inline] = ACTIONS(2006),
    [anon_sym___inline__] = ACTIONS(2006),
    [anon_sym___forceinline] = ACTIONS(2006),
    [anon_sym_thread_local] = ACTIONS(2006),
    [anon_sym___thread] = ACTIONS(2006),
    [anon_sym_const] = ACTIONS(2006),
    [anon_sym_constexpr] = ACTIONS(2006),
    [anon_sym_volatile] = ACTIONS(2006),
    [anon_sym_restrict] = ACTIONS(2006),
    [anon_sym___restrict__] = ACTIONS(2006),
    [anon_sym__Atomic] = ACTIONS(2006),
    [anon_sym__Noreturn] = ACTIONS(2006),
    [anon_sym_noreturn] = ACTIONS(2006),
    [anon_sym__Nonnull] = ACTIONS(2006),
    [anon_sym_mutable] = ACTIONS(2006),
    [anon_sym_constinit] = ACTIONS(2006),
    [anon_sym_consteval] = ACTIONS(2006),
    [anon_sym___shared__] = ACTIONS(2006),
    [anon_sym___local__] = ACTIONS(2006),
    [anon_sym___constant__] = ACTIONS(2006),
    [anon_sym___managed__] = ACTIONS(2006),
    [anon_sym___grid_constant__] = ACTIONS(2006),
    [anon_sym_alignas] = ACTIONS(2006),
    [anon_sym__Alignas] = ACTIONS(2006),
    [sym_primitive_type] = ACTIONS(2006),
    [anon_sym_enum] = ACTIONS(2006),
    [anon_sym_class] = ACTIONS(2006),
    [anon_sym_struct] = ACTIONS(2006),
    [anon_sym_union] = ACTIONS(2006),
    [anon_sym_if] = ACTIONS(2006),
    [anon_sym_else] = ACTIONS(2006),
    [anon_sym_switch] = ACTIONS(2006),
    [anon_sym_case] = ACTIONS(2006),
    [anon_sym_default] = ACTIONS(2006),
    [anon_sym_while] = ACTIONS(2006),
    [anon_sym_do] = ACTIONS(2006),
    [anon_sym_for] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2006),
    [anon_sym_break] = ACTIONS(2006),
    [anon_sym_continue] = ACTIONS(2006),
    [anon_sym_goto] = ACTIONS(2006),
    [anon_sym___try] = ACTIONS(2006),
    [anon_sym___leave] = ACTIONS(2006),
    [anon_sym_not] = ACTIONS(2006),
    [anon_sym_compl] = ACTIONS(2006),
    [anon_sym_DASH_DASH] = ACTIONS(2008),
    [anon_sym_PLUS_PLUS] = ACTIONS(2008),
    [anon_sym_sizeof] = ACTIONS(2006),
    [anon_sym___alignof__] = ACTIONS(2006),
    [anon_sym___alignof] = ACTIONS(2006),
    [anon_sym__alignof] = ACTIONS(2006),
    [anon_sym_alignof] = ACTIONS(2006),
    [anon_sym__Alignof] = ACTIONS(2006),
    [anon_sym_offsetof] = ACTIONS(2006),
    [anon_sym__Generic] = ACTIONS(2006),
    [anon_sym_asm] = ACTIONS(2006),
    [anon_sym___asm__] = ACTIONS(2006),
    [anon_sym___asm] = ACTIONS(2006),
    [sym_number_literal] = ACTIONS(2008),
    [anon_sym_L_SQUOTE] = ACTIONS(2008),
    [anon_sym_u_SQUOTE] = ACTIONS(2008),
    [anon_sym_U_SQUOTE] = ACTIONS(2008),
    [anon_sym_u8_SQUOTE] = ACTIONS(2008),
    [anon_sym_SQUOTE] = ACTIONS(2008),
    [anon_sym_L_DQUOTE] = ACTIONS(2008),
    [anon_sym_u_DQUOTE] = ACTIONS(2008),
    [anon_sym_U_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8_DQUOTE] = ACTIONS(2008),
    [anon_sym_DQUOTE] = ACTIONS(2008),
    [sym_true] = ACTIONS(2006),
    [sym_false] = ACTIONS(2006),
    [anon_sym_NULL] = ACTIONS(2006),
    [anon_sym_nullptr] = ACTIONS(2006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2006),
    [anon_sym_decltype] = ACTIONS(2006),
    [anon_sym_explicit] = ACTIONS(2006),
    [anon_sym_typename] = ACTIONS(2006),
    [anon_sym_template] = ACTIONS(2006),
    [anon_sym_operator] = ACTIONS(2006),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_delete] = ACTIONS(2006),
    [anon_sym_throw] = ACTIONS(2006),
    [anon_sym_namespace] = ACTIONS(2006),
    [anon_sym_using] = ACTIONS(2006),
    [anon_sym_static_assert] = ACTIONS(2006),
    [anon_sym_concept] = ACTIONS(2006),
    [anon_sym_co_return] = ACTIONS(2006),
    [anon_sym_co_yield] = ACTIONS(2006),
    [anon_sym_catch] = ACTIONS(2006),
    [anon_sym_R_DQUOTE] = ACTIONS(2008),
    [anon_sym_LR_DQUOTE] = ACTIONS(2008),
    [anon_sym_uR_DQUOTE] = ACTIONS(2008),
    [anon_sym_UR_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2008),
    [anon_sym_co_await] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(2006),
    [anon_sym_requires] = ACTIONS(2006),
    [sym_this] = ACTIONS(2006),
    [anon_sym___launch_bounds__] = ACTIONS(2006),
  },
  [STATE(337)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_RBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_else] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_catch] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(338)] = {
    [sym_else_clause] = STATE(397),
    [sym_identifier] = ACTIONS(2010),
    [aux_sym_preproc_include_token1] = ACTIONS(2010),
    [aux_sym_preproc_def_token1] = ACTIONS(2010),
    [aux_sym_preproc_if_token1] = ACTIONS(2010),
    [aux_sym_preproc_if_token2] = ACTIONS(2010),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2010),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2010),
    [sym_preproc_directive] = ACTIONS(2010),
    [anon_sym_LPAREN2] = ACTIONS(2012),
    [anon_sym_BANG] = ACTIONS(2012),
    [anon_sym_TILDE] = ACTIONS(2012),
    [anon_sym_DASH] = ACTIONS(2010),
    [anon_sym_PLUS] = ACTIONS(2010),
    [anon_sym_STAR] = ACTIONS(2012),
    [anon_sym_AMP_AMP] = ACTIONS(2012),
    [anon_sym_AMP] = ACTIONS(2010),
    [anon_sym_SEMI] = ACTIONS(2012),
    [anon_sym___extension__] = ACTIONS(2010),
    [anon_sym_typedef] = ACTIONS(2010),
    [anon_sym___device__] = ACTIONS(2010),
    [anon_sym___host__] = ACTIONS(2010),
    [anon_sym___global__] = ACTIONS(2010),
    [anon_sym___forceinline__] = ACTIONS(2010),
    [anon_sym___noinline__] = ACTIONS(2010),
    [anon_sym_virtual] = ACTIONS(2010),
    [anon_sym_extern] = ACTIONS(2010),
    [anon_sym___attribute__] = ACTIONS(2010),
    [anon_sym___attribute] = ACTIONS(2010),
    [anon_sym_COLON_COLON] = ACTIONS(2012),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2012),
    [anon_sym___declspec] = ACTIONS(2010),
    [anon_sym___based] = ACTIONS(2010),
    [anon_sym___cdecl] = ACTIONS(2010),
    [anon_sym___clrcall] = ACTIONS(2010),
    [anon_sym___stdcall] = ACTIONS(2010),
    [anon_sym___fastcall] = ACTIONS(2010),
    [anon_sym___thiscall] = ACTIONS(2010),
    [anon_sym___vectorcall] = ACTIONS(2010),
    [anon_sym_LBRACE] = ACTIONS(2012),
    [anon_sym_signed] = ACTIONS(2010),
    [anon_sym_unsigned] = ACTIONS(2010),
    [anon_sym_long] = ACTIONS(2010),
    [anon_sym_short] = ACTIONS(2010),
    [anon_sym_LBRACK] = ACTIONS(2010),
    [anon_sym_static] = ACTIONS(2010),
    [anon_sym_register] = ACTIONS(2010),
    [anon_sym_inline] = ACTIONS(2010),
    [anon_sym___inline] = ACTIONS(2010),
    [anon_sym___inline__] = ACTIONS(2010),
    [anon_sym___forceinline] = ACTIONS(2010),
    [anon_sym_thread_local] = ACTIONS(2010),
    [anon_sym___thread] = ACTIONS(2010),
    [anon_sym_const] = ACTIONS(2010),
    [anon_sym_constexpr] = ACTIONS(2010),
    [anon_sym_volatile] = ACTIONS(2010),
    [anon_sym_restrict] = ACTIONS(2010),
    [anon_sym___restrict__] = ACTIONS(2010),
    [anon_sym__Atomic] = ACTIONS(2010),
    [anon_sym__Noreturn] = ACTIONS(2010),
    [anon_sym_noreturn] = ACTIONS(2010),
    [anon_sym__Nonnull] = ACTIONS(2010),
    [anon_sym_mutable] = ACTIONS(2010),
    [anon_sym_constinit] = ACTIONS(2010),
    [anon_sym_consteval] = ACTIONS(2010),
    [anon_sym___shared__] = ACTIONS(2010),
    [anon_sym___local__] = ACTIONS(2010),
    [anon_sym___constant__] = ACTIONS(2010),
    [anon_sym___managed__] = ACTIONS(2010),
    [anon_sym___grid_constant__] = ACTIONS(2010),
    [anon_sym_alignas] = ACTIONS(2010),
    [anon_sym__Alignas] = ACTIONS(2010),
    [sym_primitive_type] = ACTIONS(2010),
    [anon_sym_enum] = ACTIONS(2010),
    [anon_sym_class] = ACTIONS(2010),
    [anon_sym_struct] = ACTIONS(2010),
    [anon_sym_union] = ACTIONS(2010),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_else] = ACTIONS(2685),
    [anon_sym_switch] = ACTIONS(2010),
    [anon_sym_case] = ACTIONS(2010),
    [anon_sym_default] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2010),
    [anon_sym_do] = ACTIONS(2010),
    [anon_sym_for] = ACTIONS(2010),
    [anon_sym_return] = ACTIONS(2010),
    [anon_sym_break] = ACTIONS(2010),
    [anon_sym_continue] = ACTIONS(2010),
    [anon_sym_goto] = ACTIONS(2010),
    [anon_sym___try] = ACTIONS(2010),
    [anon_sym___leave] = ACTIONS(2010),
    [anon_sym_not] = ACTIONS(2010),
    [anon_sym_compl] = ACTIONS(2010),
    [anon_sym_DASH_DASH] = ACTIONS(2012),
    [anon_sym_PLUS_PLUS] = ACTIONS(2012),
    [anon_sym_sizeof] = ACTIONS(2010),
    [anon_sym___alignof__] = ACTIONS(2010),
    [anon_sym___alignof] = ACTIONS(2010),
    [anon_sym__alignof] = ACTIONS(2010),
    [anon_sym_alignof] = ACTIONS(2010),
    [anon_sym__Alignof] = ACTIONS(2010),
    [anon_sym_offsetof] = ACTIONS(2010),
    [anon_sym__Generic] = ACTIONS(2010),
    [anon_sym_asm] = ACTIONS(2010),
    [anon_sym___asm__] = ACTIONS(2010),
    [anon_sym___asm] = ACTIONS(2010),
    [sym_number_literal] = ACTIONS(2012),
    [anon_sym_L_SQUOTE] = ACTIONS(2012),
    [anon_sym_u_SQUOTE] = ACTIONS(2012),
    [anon_sym_U_SQUOTE] = ACTIONS(2012),
    [anon_sym_u8_SQUOTE] = ACTIONS(2012),
    [anon_sym_SQUOTE] = ACTIONS(2012),
    [anon_sym_L_DQUOTE] = ACTIONS(2012),
    [anon_sym_u_DQUOTE] = ACTIONS(2012),
    [anon_sym_U_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8_DQUOTE] = ACTIONS(2012),
    [anon_sym_DQUOTE] = ACTIONS(2012),
    [sym_true] = ACTIONS(2010),
    [sym_false] = ACTIONS(2010),
    [anon_sym_NULL] = ACTIONS(2010),
    [anon_sym_nullptr] = ACTIONS(2010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2010),
    [anon_sym_decltype] = ACTIONS(2010),
    [anon_sym_explicit] = ACTIONS(2010),
    [anon_sym_typename] = ACTIONS(2010),
    [anon_sym_template] = ACTIONS(2010),
    [anon_sym_operator] = ACTIONS(2010),
    [anon_sym_try] = ACTIONS(2010),
    [anon_sym_delete] = ACTIONS(2010),
    [anon_sym_throw] = ACTIONS(2010),
    [anon_sym_namespace] = ACTIONS(2010),
    [anon_sym_using] = ACTIONS(2010),
    [anon_sym_static_assert] = ACTIONS(2010),
    [anon_sym_concept] = ACTIONS(2010),
    [anon_sym_co_return] = ACTIONS(2010),
    [anon_sym_co_yield] = ACTIONS(2010),
    [anon_sym_R_DQUOTE] = ACTIONS(2012),
    [anon_sym_LR_DQUOTE] = ACTIONS(2012),
    [anon_sym_uR_DQUOTE] = ACTIONS(2012),
    [anon_sym_UR_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2012),
    [anon_sym_co_await] = ACTIONS(2010),
    [anon_sym_new] = ACTIONS(2010),
    [anon_sym_requires] = ACTIONS(2010),
    [sym_this] = ACTIONS(2010),
    [anon_sym___launch_bounds__] = ACTIONS(2010),
  },
  [STATE(339)] = {
    [sym_identifier] = ACTIONS(1928),
    [aux_sym_preproc_include_token1] = ACTIONS(1928),
    [aux_sym_preproc_def_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1928),
    [sym_preproc_directive] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_BANG] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_DASH] = ACTIONS(1928),
    [anon_sym_PLUS] = ACTIONS(1928),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_AMP_AMP] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1928),
    [anon_sym_SEMI] = ACTIONS(1926),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym_typedef] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym___based] = ACTIONS(1928),
    [anon_sym___cdecl] = ACTIONS(1928),
    [anon_sym___clrcall] = ACTIONS(1928),
    [anon_sym___stdcall] = ACTIONS(1928),
    [anon_sym___fastcall] = ACTIONS(1928),
    [anon_sym___thiscall] = ACTIONS(1928),
    [anon_sym___vectorcall] = ACTIONS(1928),
    [anon_sym_LBRACE] = ACTIONS(1926),
    [anon_sym_RBRACE] = ACTIONS(1926),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [anon_sym_if] = ACTIONS(1928),
    [anon_sym_else] = ACTIONS(1928),
    [anon_sym_switch] = ACTIONS(1928),
    [anon_sym_case] = ACTIONS(1928),
    [anon_sym_default] = ACTIONS(1928),
    [anon_sym_while] = ACTIONS(1928),
    [anon_sym_do] = ACTIONS(1928),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_return] = ACTIONS(1928),
    [anon_sym_break] = ACTIONS(1928),
    [anon_sym_continue] = ACTIONS(1928),
    [anon_sym_goto] = ACTIONS(1928),
    [anon_sym___try] = ACTIONS(1928),
    [anon_sym___leave] = ACTIONS(1928),
    [anon_sym_not] = ACTIONS(1928),
    [anon_sym_compl] = ACTIONS(1928),
    [anon_sym_DASH_DASH] = ACTIONS(1926),
    [anon_sym_PLUS_PLUS] = ACTIONS(1926),
    [anon_sym_sizeof] = ACTIONS(1928),
    [anon_sym___alignof__] = ACTIONS(1928),
    [anon_sym___alignof] = ACTIONS(1928),
    [anon_sym__alignof] = ACTIONS(1928),
    [anon_sym_alignof] = ACTIONS(1928),
    [anon_sym__Alignof] = ACTIONS(1928),
    [anon_sym_offsetof] = ACTIONS(1928),
    [anon_sym__Generic] = ACTIONS(1928),
    [anon_sym_asm] = ACTIONS(1928),
    [anon_sym___asm__] = ACTIONS(1928),
    [anon_sym___asm] = ACTIONS(1928),
    [sym_number_literal] = ACTIONS(1926),
    [anon_sym_L_SQUOTE] = ACTIONS(1926),
    [anon_sym_u_SQUOTE] = ACTIONS(1926),
    [anon_sym_U_SQUOTE] = ACTIONS(1926),
    [anon_sym_u8_SQUOTE] = ACTIONS(1926),
    [anon_sym_SQUOTE] = ACTIONS(1926),
    [anon_sym_L_DQUOTE] = ACTIONS(1926),
    [anon_sym_u_DQUOTE] = ACTIONS(1926),
    [anon_sym_U_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8_DQUOTE] = ACTIONS(1926),
    [anon_sym_DQUOTE] = ACTIONS(1926),
    [sym_true] = ACTIONS(1928),
    [sym_false] = ACTIONS(1928),
    [anon_sym_NULL] = ACTIONS(1928),
    [anon_sym_nullptr] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_explicit] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_operator] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_delete] = ACTIONS(1928),
    [anon_sym_throw] = ACTIONS(1928),
    [anon_sym_namespace] = ACTIONS(1928),
    [anon_sym_using] = ACTIONS(1928),
    [anon_sym_static_assert] = ACTIONS(1928),
    [anon_sym_concept] = ACTIONS(1928),
    [anon_sym_co_return] = ACTIONS(1928),
    [anon_sym_co_yield] = ACTIONS(1928),
    [anon_sym_catch] = ACTIONS(1928),
    [anon_sym_R_DQUOTE] = ACTIONS(1926),
    [anon_sym_LR_DQUOTE] = ACTIONS(1926),
    [anon_sym_uR_DQUOTE] = ACTIONS(1926),
    [anon_sym_UR_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1926),
    [anon_sym_co_await] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1928),
    [anon_sym_requires] = ACTIONS(1928),
    [sym_this] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(340)] = {
    [sym_expression] = STATE(2632),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_initializer_list] = STATE(2799),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_RPAREN] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(2689),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2633),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2633),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(2635),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_RBRACK] = ACTIONS(2635),
    [anon_sym_EQ] = ACTIONS(2633),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_STAR_EQ] = ACTIONS(2635),
    [anon_sym_SLASH_EQ] = ACTIONS(2635),
    [anon_sym_PERCENT_EQ] = ACTIONS(2635),
    [anon_sym_PLUS_EQ] = ACTIONS(2635),
    [anon_sym_DASH_EQ] = ACTIONS(2635),
    [anon_sym_LT_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT_GT_EQ] = ACTIONS(2635),
    [anon_sym_AMP_EQ] = ACTIONS(2635),
    [anon_sym_CARET_EQ] = ACTIONS(2635),
    [anon_sym_PIPE_EQ] = ACTIONS(2635),
    [anon_sym_and_eq] = ACTIONS(2633),
    [anon_sym_or_eq] = ACTIONS(2633),
    [anon_sym_xor_eq] = ACTIONS(2633),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(341)] = {
    [ts_builtin_sym_end] = ACTIONS(2008),
    [sym_identifier] = ACTIONS(2006),
    [aux_sym_preproc_include_token1] = ACTIONS(2006),
    [aux_sym_preproc_def_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2006),
    [sym_preproc_directive] = ACTIONS(2006),
    [anon_sym_LPAREN2] = ACTIONS(2008),
    [anon_sym_BANG] = ACTIONS(2008),
    [anon_sym_TILDE] = ACTIONS(2008),
    [anon_sym_DASH] = ACTIONS(2006),
    [anon_sym_PLUS] = ACTIONS(2006),
    [anon_sym_STAR] = ACTIONS(2008),
    [anon_sym_AMP_AMP] = ACTIONS(2008),
    [anon_sym_AMP] = ACTIONS(2006),
    [anon_sym_SEMI] = ACTIONS(2008),
    [anon_sym___extension__] = ACTIONS(2006),
    [anon_sym_typedef] = ACTIONS(2006),
    [anon_sym___device__] = ACTIONS(2006),
    [anon_sym___host__] = ACTIONS(2006),
    [anon_sym___global__] = ACTIONS(2006),
    [anon_sym___forceinline__] = ACTIONS(2006),
    [anon_sym___noinline__] = ACTIONS(2006),
    [anon_sym_virtual] = ACTIONS(2006),
    [anon_sym_extern] = ACTIONS(2006),
    [anon_sym___attribute__] = ACTIONS(2006),
    [anon_sym___attribute] = ACTIONS(2006),
    [anon_sym_COLON_COLON] = ACTIONS(2008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2008),
    [anon_sym___declspec] = ACTIONS(2006),
    [anon_sym___based] = ACTIONS(2006),
    [anon_sym___cdecl] = ACTIONS(2006),
    [anon_sym___clrcall] = ACTIONS(2006),
    [anon_sym___stdcall] = ACTIONS(2006),
    [anon_sym___fastcall] = ACTIONS(2006),
    [anon_sym___thiscall] = ACTIONS(2006),
    [anon_sym___vectorcall] = ACTIONS(2006),
    [anon_sym_LBRACE] = ACTIONS(2008),
    [anon_sym_signed] = ACTIONS(2006),
    [anon_sym_unsigned] = ACTIONS(2006),
    [anon_sym_long] = ACTIONS(2006),
    [anon_sym_short] = ACTIONS(2006),
    [anon_sym_LBRACK] = ACTIONS(2006),
    [anon_sym_static] = ACTIONS(2006),
    [anon_sym_register] = ACTIONS(2006),
    [anon_sym_inline] = ACTIONS(2006),
    [anon_sym___inline] = ACTIONS(2006),
    [anon_sym___inline__] = ACTIONS(2006),
    [anon_sym___forceinline] = ACTIONS(2006),
    [anon_sym_thread_local] = ACTIONS(2006),
    [anon_sym___thread] = ACTIONS(2006),
    [anon_sym_const] = ACTIONS(2006),
    [anon_sym_constexpr] = ACTIONS(2006),
    [anon_sym_volatile] = ACTIONS(2006),
    [anon_sym_restrict] = ACTIONS(2006),
    [anon_sym___restrict__] = ACTIONS(2006),
    [anon_sym__Atomic] = ACTIONS(2006),
    [anon_sym__Noreturn] = ACTIONS(2006),
    [anon_sym_noreturn] = ACTIONS(2006),
    [anon_sym__Nonnull] = ACTIONS(2006),
    [anon_sym_mutable] = ACTIONS(2006),
    [anon_sym_constinit] = ACTIONS(2006),
    [anon_sym_consteval] = ACTIONS(2006),
    [anon_sym___shared__] = ACTIONS(2006),
    [anon_sym___local__] = ACTIONS(2006),
    [anon_sym___constant__] = ACTIONS(2006),
    [anon_sym___managed__] = ACTIONS(2006),
    [anon_sym___grid_constant__] = ACTIONS(2006),
    [anon_sym_alignas] = ACTIONS(2006),
    [anon_sym__Alignas] = ACTIONS(2006),
    [sym_primitive_type] = ACTIONS(2006),
    [anon_sym_enum] = ACTIONS(2006),
    [anon_sym_class] = ACTIONS(2006),
    [anon_sym_struct] = ACTIONS(2006),
    [anon_sym_union] = ACTIONS(2006),
    [anon_sym_if] = ACTIONS(2006),
    [anon_sym_else] = ACTIONS(2006),
    [anon_sym_switch] = ACTIONS(2006),
    [anon_sym_case] = ACTIONS(2006),
    [anon_sym_default] = ACTIONS(2006),
    [anon_sym_while] = ACTIONS(2006),
    [anon_sym_do] = ACTIONS(2006),
    [anon_sym_for] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2006),
    [anon_sym_break] = ACTIONS(2006),
    [anon_sym_continue] = ACTIONS(2006),
    [anon_sym_goto] = ACTIONS(2006),
    [anon_sym___try] = ACTIONS(2006),
    [anon_sym___leave] = ACTIONS(2006),
    [anon_sym_not] = ACTIONS(2006),
    [anon_sym_compl] = ACTIONS(2006),
    [anon_sym_DASH_DASH] = ACTIONS(2008),
    [anon_sym_PLUS_PLUS] = ACTIONS(2008),
    [anon_sym_sizeof] = ACTIONS(2006),
    [anon_sym___alignof__] = ACTIONS(2006),
    [anon_sym___alignof] = ACTIONS(2006),
    [anon_sym__alignof] = ACTIONS(2006),
    [anon_sym_alignof] = ACTIONS(2006),
    [anon_sym__Alignof] = ACTIONS(2006),
    [anon_sym_offsetof] = ACTIONS(2006),
    [anon_sym__Generic] = ACTIONS(2006),
    [anon_sym_asm] = ACTIONS(2006),
    [anon_sym___asm__] = ACTIONS(2006),
    [anon_sym___asm] = ACTIONS(2006),
    [sym_number_literal] = ACTIONS(2008),
    [anon_sym_L_SQUOTE] = ACTIONS(2008),
    [anon_sym_u_SQUOTE] = ACTIONS(2008),
    [anon_sym_U_SQUOTE] = ACTIONS(2008),
    [anon_sym_u8_SQUOTE] = ACTIONS(2008),
    [anon_sym_SQUOTE] = ACTIONS(2008),
    [anon_sym_L_DQUOTE] = ACTIONS(2008),
    [anon_sym_u_DQUOTE] = ACTIONS(2008),
    [anon_sym_U_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8_DQUOTE] = ACTIONS(2008),
    [anon_sym_DQUOTE] = ACTIONS(2008),
    [sym_true] = ACTIONS(2006),
    [sym_false] = ACTIONS(2006),
    [anon_sym_NULL] = ACTIONS(2006),
    [anon_sym_nullptr] = ACTIONS(2006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2006),
    [anon_sym_decltype] = ACTIONS(2006),
    [anon_sym_explicit] = ACTIONS(2006),
    [anon_sym_typename] = ACTIONS(2006),
    [anon_sym_template] = ACTIONS(2006),
    [anon_sym_operator] = ACTIONS(2006),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_delete] = ACTIONS(2006),
    [anon_sym_throw] = ACTIONS(2006),
    [anon_sym_namespace] = ACTIONS(2006),
    [anon_sym_using] = ACTIONS(2006),
    [anon_sym_static_assert] = ACTIONS(2006),
    [anon_sym_concept] = ACTIONS(2006),
    [anon_sym_co_return] = ACTIONS(2006),
    [anon_sym_co_yield] = ACTIONS(2006),
    [anon_sym_catch] = ACTIONS(2006),
    [anon_sym_R_DQUOTE] = ACTIONS(2008),
    [anon_sym_LR_DQUOTE] = ACTIONS(2008),
    [anon_sym_uR_DQUOTE] = ACTIONS(2008),
    [anon_sym_UR_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2008),
    [anon_sym_co_await] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(2006),
    [anon_sym_requires] = ACTIONS(2006),
    [sym_this] = ACTIONS(2006),
    [anon_sym___launch_bounds__] = ACTIONS(2006),
  },
  [STATE(342)] = {
    [sym_else_clause] = STATE(393),
    [sym_identifier] = ACTIONS(2016),
    [aux_sym_preproc_include_token1] = ACTIONS(2016),
    [aux_sym_preproc_def_token1] = ACTIONS(2016),
    [aux_sym_preproc_if_token1] = ACTIONS(2016),
    [aux_sym_preproc_if_token2] = ACTIONS(2016),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2016),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2016),
    [sym_preproc_directive] = ACTIONS(2016),
    [anon_sym_LPAREN2] = ACTIONS(2018),
    [anon_sym_BANG] = ACTIONS(2018),
    [anon_sym_TILDE] = ACTIONS(2018),
    [anon_sym_DASH] = ACTIONS(2016),
    [anon_sym_PLUS] = ACTIONS(2016),
    [anon_sym_STAR] = ACTIONS(2018),
    [anon_sym_AMP_AMP] = ACTIONS(2018),
    [anon_sym_AMP] = ACTIONS(2016),
    [anon_sym_SEMI] = ACTIONS(2018),
    [anon_sym___extension__] = ACTIONS(2016),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym___device__] = ACTIONS(2016),
    [anon_sym___host__] = ACTIONS(2016),
    [anon_sym___global__] = ACTIONS(2016),
    [anon_sym___forceinline__] = ACTIONS(2016),
    [anon_sym___noinline__] = ACTIONS(2016),
    [anon_sym_virtual] = ACTIONS(2016),
    [anon_sym_extern] = ACTIONS(2016),
    [anon_sym___attribute__] = ACTIONS(2016),
    [anon_sym___attribute] = ACTIONS(2016),
    [anon_sym_COLON_COLON] = ACTIONS(2018),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2018),
    [anon_sym___declspec] = ACTIONS(2016),
    [anon_sym___based] = ACTIONS(2016),
    [anon_sym___cdecl] = ACTIONS(2016),
    [anon_sym___clrcall] = ACTIONS(2016),
    [anon_sym___stdcall] = ACTIONS(2016),
    [anon_sym___fastcall] = ACTIONS(2016),
    [anon_sym___thiscall] = ACTIONS(2016),
    [anon_sym___vectorcall] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2018),
    [anon_sym_signed] = ACTIONS(2016),
    [anon_sym_unsigned] = ACTIONS(2016),
    [anon_sym_long] = ACTIONS(2016),
    [anon_sym_short] = ACTIONS(2016),
    [anon_sym_LBRACK] = ACTIONS(2016),
    [anon_sym_static] = ACTIONS(2016),
    [anon_sym_register] = ACTIONS(2016),
    [anon_sym_inline] = ACTIONS(2016),
    [anon_sym___inline] = ACTIONS(2016),
    [anon_sym___inline__] = ACTIONS(2016),
    [anon_sym___forceinline] = ACTIONS(2016),
    [anon_sym_thread_local] = ACTIONS(2016),
    [anon_sym___thread] = ACTIONS(2016),
    [anon_sym_const] = ACTIONS(2016),
    [anon_sym_constexpr] = ACTIONS(2016),
    [anon_sym_volatile] = ACTIONS(2016),
    [anon_sym_restrict] = ACTIONS(2016),
    [anon_sym___restrict__] = ACTIONS(2016),
    [anon_sym__Atomic] = ACTIONS(2016),
    [anon_sym__Noreturn] = ACTIONS(2016),
    [anon_sym_noreturn] = ACTIONS(2016),
    [anon_sym__Nonnull] = ACTIONS(2016),
    [anon_sym_mutable] = ACTIONS(2016),
    [anon_sym_constinit] = ACTIONS(2016),
    [anon_sym_consteval] = ACTIONS(2016),
    [anon_sym___shared__] = ACTIONS(2016),
    [anon_sym___local__] = ACTIONS(2016),
    [anon_sym___constant__] = ACTIONS(2016),
    [anon_sym___managed__] = ACTIONS(2016),
    [anon_sym___grid_constant__] = ACTIONS(2016),
    [anon_sym_alignas] = ACTIONS(2016),
    [anon_sym__Alignas] = ACTIONS(2016),
    [sym_primitive_type] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2016),
    [anon_sym_class] = ACTIONS(2016),
    [anon_sym_struct] = ACTIONS(2016),
    [anon_sym_union] = ACTIONS(2016),
    [anon_sym_if] = ACTIONS(2016),
    [anon_sym_else] = ACTIONS(2685),
    [anon_sym_switch] = ACTIONS(2016),
    [anon_sym_case] = ACTIONS(2016),
    [anon_sym_default] = ACTIONS(2016),
    [anon_sym_while] = ACTIONS(2016),
    [anon_sym_do] = ACTIONS(2016),
    [anon_sym_for] = ACTIONS(2016),
    [anon_sym_return] = ACTIONS(2016),
    [anon_sym_break] = ACTIONS(2016),
    [anon_sym_continue] = ACTIONS(2016),
    [anon_sym_goto] = ACTIONS(2016),
    [anon_sym___try] = ACTIONS(2016),
    [anon_sym___leave] = ACTIONS(2016),
    [anon_sym_not] = ACTIONS(2016),
    [anon_sym_compl] = ACTIONS(2016),
    [anon_sym_DASH_DASH] = ACTIONS(2018),
    [anon_sym_PLUS_PLUS] = ACTIONS(2018),
    [anon_sym_sizeof] = ACTIONS(2016),
    [anon_sym___alignof__] = ACTIONS(2016),
    [anon_sym___alignof] = ACTIONS(2016),
    [anon_sym__alignof] = ACTIONS(2016),
    [anon_sym_alignof] = ACTIONS(2016),
    [anon_sym__Alignof] = ACTIONS(2016),
    [anon_sym_offsetof] = ACTIONS(2016),
    [anon_sym__Generic] = ACTIONS(2016),
    [anon_sym_asm] = ACTIONS(2016),
    [anon_sym___asm__] = ACTIONS(2016),
    [anon_sym___asm] = ACTIONS(2016),
    [sym_number_literal] = ACTIONS(2018),
    [anon_sym_L_SQUOTE] = ACTIONS(2018),
    [anon_sym_u_SQUOTE] = ACTIONS(2018),
    [anon_sym_U_SQUOTE] = ACTIONS(2018),
    [anon_sym_u8_SQUOTE] = ACTIONS(2018),
    [anon_sym_SQUOTE] = ACTIONS(2018),
    [anon_sym_L_DQUOTE] = ACTIONS(2018),
    [anon_sym_u_DQUOTE] = ACTIONS(2018),
    [anon_sym_U_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8_DQUOTE] = ACTIONS(2018),
    [anon_sym_DQUOTE] = ACTIONS(2018),
    [sym_true] = ACTIONS(2016),
    [sym_false] = ACTIONS(2016),
    [anon_sym_NULL] = ACTIONS(2016),
    [anon_sym_nullptr] = ACTIONS(2016),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2016),
    [anon_sym_decltype] = ACTIONS(2016),
    [anon_sym_explicit] = ACTIONS(2016),
    [anon_sym_typename] = ACTIONS(2016),
    [anon_sym_template] = ACTIONS(2016),
    [anon_sym_operator] = ACTIONS(2016),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_delete] = ACTIONS(2016),
    [anon_sym_throw] = ACTIONS(2016),
    [anon_sym_namespace] = ACTIONS(2016),
    [anon_sym_using] = ACTIONS(2016),
    [anon_sym_static_assert] = ACTIONS(2016),
    [anon_sym_concept] = ACTIONS(2016),
    [anon_sym_co_return] = ACTIONS(2016),
    [anon_sym_co_yield] = ACTIONS(2016),
    [anon_sym_R_DQUOTE] = ACTIONS(2018),
    [anon_sym_LR_DQUOTE] = ACTIONS(2018),
    [anon_sym_uR_DQUOTE] = ACTIONS(2018),
    [anon_sym_UR_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2018),
    [anon_sym_co_await] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(2016),
    [anon_sym_requires] = ACTIONS(2016),
    [sym_this] = ACTIONS(2016),
    [anon_sym___launch_bounds__] = ACTIONS(2016),
  },
  [STATE(343)] = {
    [sym_else_clause] = STATE(345),
    [ts_builtin_sym_end] = ACTIONS(2018),
    [sym_identifier] = ACTIONS(2016),
    [aux_sym_preproc_include_token1] = ACTIONS(2016),
    [aux_sym_preproc_def_token1] = ACTIONS(2016),
    [aux_sym_preproc_if_token1] = ACTIONS(2016),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2016),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2016),
    [sym_preproc_directive] = ACTIONS(2016),
    [anon_sym_LPAREN2] = ACTIONS(2018),
    [anon_sym_BANG] = ACTIONS(2018),
    [anon_sym_TILDE] = ACTIONS(2018),
    [anon_sym_DASH] = ACTIONS(2016),
    [anon_sym_PLUS] = ACTIONS(2016),
    [anon_sym_STAR] = ACTIONS(2018),
    [anon_sym_AMP_AMP] = ACTIONS(2018),
    [anon_sym_AMP] = ACTIONS(2016),
    [anon_sym_SEMI] = ACTIONS(2018),
    [anon_sym___extension__] = ACTIONS(2016),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym___device__] = ACTIONS(2016),
    [anon_sym___host__] = ACTIONS(2016),
    [anon_sym___global__] = ACTIONS(2016),
    [anon_sym___forceinline__] = ACTIONS(2016),
    [anon_sym___noinline__] = ACTIONS(2016),
    [anon_sym_virtual] = ACTIONS(2016),
    [anon_sym_extern] = ACTIONS(2016),
    [anon_sym___attribute__] = ACTIONS(2016),
    [anon_sym___attribute] = ACTIONS(2016),
    [anon_sym_COLON_COLON] = ACTIONS(2018),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2018),
    [anon_sym___declspec] = ACTIONS(2016),
    [anon_sym___based] = ACTIONS(2016),
    [anon_sym___cdecl] = ACTIONS(2016),
    [anon_sym___clrcall] = ACTIONS(2016),
    [anon_sym___stdcall] = ACTIONS(2016),
    [anon_sym___fastcall] = ACTIONS(2016),
    [anon_sym___thiscall] = ACTIONS(2016),
    [anon_sym___vectorcall] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2018),
    [anon_sym_signed] = ACTIONS(2016),
    [anon_sym_unsigned] = ACTIONS(2016),
    [anon_sym_long] = ACTIONS(2016),
    [anon_sym_short] = ACTIONS(2016),
    [anon_sym_LBRACK] = ACTIONS(2016),
    [anon_sym_static] = ACTIONS(2016),
    [anon_sym_register] = ACTIONS(2016),
    [anon_sym_inline] = ACTIONS(2016),
    [anon_sym___inline] = ACTIONS(2016),
    [anon_sym___inline__] = ACTIONS(2016),
    [anon_sym___forceinline] = ACTIONS(2016),
    [anon_sym_thread_local] = ACTIONS(2016),
    [anon_sym___thread] = ACTIONS(2016),
    [anon_sym_const] = ACTIONS(2016),
    [anon_sym_constexpr] = ACTIONS(2016),
    [anon_sym_volatile] = ACTIONS(2016),
    [anon_sym_restrict] = ACTIONS(2016),
    [anon_sym___restrict__] = ACTIONS(2016),
    [anon_sym__Atomic] = ACTIONS(2016),
    [anon_sym__Noreturn] = ACTIONS(2016),
    [anon_sym_noreturn] = ACTIONS(2016),
    [anon_sym__Nonnull] = ACTIONS(2016),
    [anon_sym_mutable] = ACTIONS(2016),
    [anon_sym_constinit] = ACTIONS(2016),
    [anon_sym_consteval] = ACTIONS(2016),
    [anon_sym___shared__] = ACTIONS(2016),
    [anon_sym___local__] = ACTIONS(2016),
    [anon_sym___constant__] = ACTIONS(2016),
    [anon_sym___managed__] = ACTIONS(2016),
    [anon_sym___grid_constant__] = ACTIONS(2016),
    [anon_sym_alignas] = ACTIONS(2016),
    [anon_sym__Alignas] = ACTIONS(2016),
    [sym_primitive_type] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2016),
    [anon_sym_class] = ACTIONS(2016),
    [anon_sym_struct] = ACTIONS(2016),
    [anon_sym_union] = ACTIONS(2016),
    [anon_sym_if] = ACTIONS(2016),
    [anon_sym_else] = ACTIONS(2681),
    [anon_sym_switch] = ACTIONS(2016),
    [anon_sym_case] = ACTIONS(2016),
    [anon_sym_default] = ACTIONS(2016),
    [anon_sym_while] = ACTIONS(2016),
    [anon_sym_do] = ACTIONS(2016),
    [anon_sym_for] = ACTIONS(2016),
    [anon_sym_return] = ACTIONS(2016),
    [anon_sym_break] = ACTIONS(2016),
    [anon_sym_continue] = ACTIONS(2016),
    [anon_sym_goto] = ACTIONS(2016),
    [anon_sym___try] = ACTIONS(2016),
    [anon_sym___leave] = ACTIONS(2016),
    [anon_sym_not] = ACTIONS(2016),
    [anon_sym_compl] = ACTIONS(2016),
    [anon_sym_DASH_DASH] = ACTIONS(2018),
    [anon_sym_PLUS_PLUS] = ACTIONS(2018),
    [anon_sym_sizeof] = ACTIONS(2016),
    [anon_sym___alignof__] = ACTIONS(2016),
    [anon_sym___alignof] = ACTIONS(2016),
    [anon_sym__alignof] = ACTIONS(2016),
    [anon_sym_alignof] = ACTIONS(2016),
    [anon_sym__Alignof] = ACTIONS(2016),
    [anon_sym_offsetof] = ACTIONS(2016),
    [anon_sym__Generic] = ACTIONS(2016),
    [anon_sym_asm] = ACTIONS(2016),
    [anon_sym___asm__] = ACTIONS(2016),
    [anon_sym___asm] = ACTIONS(2016),
    [sym_number_literal] = ACTIONS(2018),
    [anon_sym_L_SQUOTE] = ACTIONS(2018),
    [anon_sym_u_SQUOTE] = ACTIONS(2018),
    [anon_sym_U_SQUOTE] = ACTIONS(2018),
    [anon_sym_u8_SQUOTE] = ACTIONS(2018),
    [anon_sym_SQUOTE] = ACTIONS(2018),
    [anon_sym_L_DQUOTE] = ACTIONS(2018),
    [anon_sym_u_DQUOTE] = ACTIONS(2018),
    [anon_sym_U_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8_DQUOTE] = ACTIONS(2018),
    [anon_sym_DQUOTE] = ACTIONS(2018),
    [sym_true] = ACTIONS(2016),
    [sym_false] = ACTIONS(2016),
    [anon_sym_NULL] = ACTIONS(2016),
    [anon_sym_nullptr] = ACTIONS(2016),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2016),
    [anon_sym_decltype] = ACTIONS(2016),
    [anon_sym_explicit] = ACTIONS(2016),
    [anon_sym_typename] = ACTIONS(2016),
    [anon_sym_template] = ACTIONS(2016),
    [anon_sym_operator] = ACTIONS(2016),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_delete] = ACTIONS(2016),
    [anon_sym_throw] = ACTIONS(2016),
    [anon_sym_namespace] = ACTIONS(2016),
    [anon_sym_using] = ACTIONS(2016),
    [anon_sym_static_assert] = ACTIONS(2016),
    [anon_sym_concept] = ACTIONS(2016),
    [anon_sym_co_return] = ACTIONS(2016),
    [anon_sym_co_yield] = ACTIONS(2016),
    [anon_sym_R_DQUOTE] = ACTIONS(2018),
    [anon_sym_LR_DQUOTE] = ACTIONS(2018),
    [anon_sym_uR_DQUOTE] = ACTIONS(2018),
    [anon_sym_UR_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2018),
    [anon_sym_co_await] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(2016),
    [anon_sym_requires] = ACTIONS(2016),
    [sym_this] = ACTIONS(2016),
    [anon_sym___launch_bounds__] = ACTIONS(2016),
  },
  [STATE(344)] = {
    [sym_identifier] = ACTIONS(2222),
    [aux_sym_preproc_include_token1] = ACTIONS(2222),
    [aux_sym_preproc_def_token1] = ACTIONS(2222),
    [aux_sym_preproc_if_token1] = ACTIONS(2222),
    [aux_sym_preproc_if_token2] = ACTIONS(2222),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2222),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2222),
    [sym_preproc_directive] = ACTIONS(2222),
    [anon_sym_LPAREN2] = ACTIONS(2224),
    [anon_sym_BANG] = ACTIONS(2224),
    [anon_sym_TILDE] = ACTIONS(2224),
    [anon_sym_DASH] = ACTIONS(2222),
    [anon_sym_PLUS] = ACTIONS(2222),
    [anon_sym_STAR] = ACTIONS(2224),
    [anon_sym_AMP_AMP] = ACTIONS(2224),
    [anon_sym_AMP] = ACTIONS(2222),
    [anon_sym_SEMI] = ACTIONS(2224),
    [anon_sym___extension__] = ACTIONS(2222),
    [anon_sym_typedef] = ACTIONS(2222),
    [anon_sym___device__] = ACTIONS(2222),
    [anon_sym___host__] = ACTIONS(2222),
    [anon_sym___global__] = ACTIONS(2222),
    [anon_sym___forceinline__] = ACTIONS(2222),
    [anon_sym___noinline__] = ACTIONS(2222),
    [anon_sym_virtual] = ACTIONS(2222),
    [anon_sym_extern] = ACTIONS(2222),
    [anon_sym___attribute__] = ACTIONS(2222),
    [anon_sym___attribute] = ACTIONS(2222),
    [anon_sym_COLON_COLON] = ACTIONS(2224),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2224),
    [anon_sym___declspec] = ACTIONS(2222),
    [anon_sym___based] = ACTIONS(2222),
    [anon_sym___cdecl] = ACTIONS(2222),
    [anon_sym___clrcall] = ACTIONS(2222),
    [anon_sym___stdcall] = ACTIONS(2222),
    [anon_sym___fastcall] = ACTIONS(2222),
    [anon_sym___thiscall] = ACTIONS(2222),
    [anon_sym___vectorcall] = ACTIONS(2222),
    [anon_sym_LBRACE] = ACTIONS(2224),
    [anon_sym_signed] = ACTIONS(2222),
    [anon_sym_unsigned] = ACTIONS(2222),
    [anon_sym_long] = ACTIONS(2222),
    [anon_sym_short] = ACTIONS(2222),
    [anon_sym_LBRACK] = ACTIONS(2222),
    [anon_sym_static] = ACTIONS(2222),
    [anon_sym_register] = ACTIONS(2222),
    [anon_sym_inline] = ACTIONS(2222),
    [anon_sym___inline] = ACTIONS(2222),
    [anon_sym___inline__] = ACTIONS(2222),
    [anon_sym___forceinline] = ACTIONS(2222),
    [anon_sym_thread_local] = ACTIONS(2222),
    [anon_sym___thread] = ACTIONS(2222),
    [anon_sym_const] = ACTIONS(2222),
    [anon_sym_constexpr] = ACTIONS(2222),
    [anon_sym_volatile] = ACTIONS(2222),
    [anon_sym_restrict] = ACTIONS(2222),
    [anon_sym___restrict__] = ACTIONS(2222),
    [anon_sym__Atomic] = ACTIONS(2222),
    [anon_sym__Noreturn] = ACTIONS(2222),
    [anon_sym_noreturn] = ACTIONS(2222),
    [anon_sym__Nonnull] = ACTIONS(2222),
    [anon_sym_mutable] = ACTIONS(2222),
    [anon_sym_constinit] = ACTIONS(2222),
    [anon_sym_consteval] = ACTIONS(2222),
    [anon_sym___shared__] = ACTIONS(2222),
    [anon_sym___local__] = ACTIONS(2222),
    [anon_sym___constant__] = ACTIONS(2222),
    [anon_sym___managed__] = ACTIONS(2222),
    [anon_sym___grid_constant__] = ACTIONS(2222),
    [anon_sym_alignas] = ACTIONS(2222),
    [anon_sym__Alignas] = ACTIONS(2222),
    [sym_primitive_type] = ACTIONS(2222),
    [anon_sym_enum] = ACTIONS(2222),
    [anon_sym_class] = ACTIONS(2222),
    [anon_sym_struct] = ACTIONS(2222),
    [anon_sym_union] = ACTIONS(2222),
    [anon_sym_if] = ACTIONS(2222),
    [anon_sym_else] = ACTIONS(2222),
    [anon_sym_switch] = ACTIONS(2222),
    [anon_sym_case] = ACTIONS(2222),
    [anon_sym_default] = ACTIONS(2222),
    [anon_sym_while] = ACTIONS(2222),
    [anon_sym_do] = ACTIONS(2222),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_return] = ACTIONS(2222),
    [anon_sym_break] = ACTIONS(2222),
    [anon_sym_continue] = ACTIONS(2222),
    [anon_sym_goto] = ACTIONS(2222),
    [anon_sym___try] = ACTIONS(2222),
    [anon_sym___leave] = ACTIONS(2222),
    [anon_sym_not] = ACTIONS(2222),
    [anon_sym_compl] = ACTIONS(2222),
    [anon_sym_DASH_DASH] = ACTIONS(2224),
    [anon_sym_PLUS_PLUS] = ACTIONS(2224),
    [anon_sym_sizeof] = ACTIONS(2222),
    [anon_sym___alignof__] = ACTIONS(2222),
    [anon_sym___alignof] = ACTIONS(2222),
    [anon_sym__alignof] = ACTIONS(2222),
    [anon_sym_alignof] = ACTIONS(2222),
    [anon_sym__Alignof] = ACTIONS(2222),
    [anon_sym_offsetof] = ACTIONS(2222),
    [anon_sym__Generic] = ACTIONS(2222),
    [anon_sym_asm] = ACTIONS(2222),
    [anon_sym___asm__] = ACTIONS(2222),
    [anon_sym___asm] = ACTIONS(2222),
    [sym_number_literal] = ACTIONS(2224),
    [anon_sym_L_SQUOTE] = ACTIONS(2224),
    [anon_sym_u_SQUOTE] = ACTIONS(2224),
    [anon_sym_U_SQUOTE] = ACTIONS(2224),
    [anon_sym_u8_SQUOTE] = ACTIONS(2224),
    [anon_sym_SQUOTE] = ACTIONS(2224),
    [anon_sym_L_DQUOTE] = ACTIONS(2224),
    [anon_sym_u_DQUOTE] = ACTIONS(2224),
    [anon_sym_U_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8_DQUOTE] = ACTIONS(2224),
    [anon_sym_DQUOTE] = ACTIONS(2224),
    [sym_true] = ACTIONS(2222),
    [sym_false] = ACTIONS(2222),
    [anon_sym_NULL] = ACTIONS(2222),
    [anon_sym_nullptr] = ACTIONS(2222),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2222),
    [anon_sym_decltype] = ACTIONS(2222),
    [anon_sym_explicit] = ACTIONS(2222),
    [anon_sym_typename] = ACTIONS(2222),
    [anon_sym_template] = ACTIONS(2222),
    [anon_sym_operator] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2222),
    [anon_sym_delete] = ACTIONS(2222),
    [anon_sym_throw] = ACTIONS(2222),
    [anon_sym_namespace] = ACTIONS(2222),
    [anon_sym_using] = ACTIONS(2222),
    [anon_sym_static_assert] = ACTIONS(2222),
    [anon_sym_concept] = ACTIONS(2222),
    [anon_sym_co_return] = ACTIONS(2222),
    [anon_sym_co_yield] = ACTIONS(2222),
    [anon_sym_R_DQUOTE] = ACTIONS(2224),
    [anon_sym_LR_DQUOTE] = ACTIONS(2224),
    [anon_sym_uR_DQUOTE] = ACTIONS(2224),
    [anon_sym_UR_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2224),
    [anon_sym_co_await] = ACTIONS(2222),
    [anon_sym_new] = ACTIONS(2222),
    [anon_sym_requires] = ACTIONS(2222),
    [sym_this] = ACTIONS(2222),
    [anon_sym___launch_bounds__] = ACTIONS(2222),
  },
  [STATE(345)] = {
    [ts_builtin_sym_end] = ACTIONS(2064),
    [sym_identifier] = ACTIONS(2062),
    [aux_sym_preproc_include_token1] = ACTIONS(2062),
    [aux_sym_preproc_def_token1] = ACTIONS(2062),
    [aux_sym_preproc_if_token1] = ACTIONS(2062),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2062),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2062),
    [sym_preproc_directive] = ACTIONS(2062),
    [anon_sym_LPAREN2] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(2064),
    [anon_sym_TILDE] = ACTIONS(2064),
    [anon_sym_DASH] = ACTIONS(2062),
    [anon_sym_PLUS] = ACTIONS(2062),
    [anon_sym_STAR] = ACTIONS(2064),
    [anon_sym_AMP_AMP] = ACTIONS(2064),
    [anon_sym_AMP] = ACTIONS(2062),
    [anon_sym_SEMI] = ACTIONS(2064),
    [anon_sym___extension__] = ACTIONS(2062),
    [anon_sym_typedef] = ACTIONS(2062),
    [anon_sym___device__] = ACTIONS(2062),
    [anon_sym___host__] = ACTIONS(2062),
    [anon_sym___global__] = ACTIONS(2062),
    [anon_sym___forceinline__] = ACTIONS(2062),
    [anon_sym___noinline__] = ACTIONS(2062),
    [anon_sym_virtual] = ACTIONS(2062),
    [anon_sym_extern] = ACTIONS(2062),
    [anon_sym___attribute__] = ACTIONS(2062),
    [anon_sym___attribute] = ACTIONS(2062),
    [anon_sym_COLON_COLON] = ACTIONS(2064),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2064),
    [anon_sym___declspec] = ACTIONS(2062),
    [anon_sym___based] = ACTIONS(2062),
    [anon_sym___cdecl] = ACTIONS(2062),
    [anon_sym___clrcall] = ACTIONS(2062),
    [anon_sym___stdcall] = ACTIONS(2062),
    [anon_sym___fastcall] = ACTIONS(2062),
    [anon_sym___thiscall] = ACTIONS(2062),
    [anon_sym___vectorcall] = ACTIONS(2062),
    [anon_sym_LBRACE] = ACTIONS(2064),
    [anon_sym_signed] = ACTIONS(2062),
    [anon_sym_unsigned] = ACTIONS(2062),
    [anon_sym_long] = ACTIONS(2062),
    [anon_sym_short] = ACTIONS(2062),
    [anon_sym_LBRACK] = ACTIONS(2062),
    [anon_sym_static] = ACTIONS(2062),
    [anon_sym_register] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym___inline] = ACTIONS(2062),
    [anon_sym___inline__] = ACTIONS(2062),
    [anon_sym___forceinline] = ACTIONS(2062),
    [anon_sym_thread_local] = ACTIONS(2062),
    [anon_sym___thread] = ACTIONS(2062),
    [anon_sym_const] = ACTIONS(2062),
    [anon_sym_constexpr] = ACTIONS(2062),
    [anon_sym_volatile] = ACTIONS(2062),
    [anon_sym_restrict] = ACTIONS(2062),
    [anon_sym___restrict__] = ACTIONS(2062),
    [anon_sym__Atomic] = ACTIONS(2062),
    [anon_sym__Noreturn] = ACTIONS(2062),
    [anon_sym_noreturn] = ACTIONS(2062),
    [anon_sym__Nonnull] = ACTIONS(2062),
    [anon_sym_mutable] = ACTIONS(2062),
    [anon_sym_constinit] = ACTIONS(2062),
    [anon_sym_consteval] = ACTIONS(2062),
    [anon_sym___shared__] = ACTIONS(2062),
    [anon_sym___local__] = ACTIONS(2062),
    [anon_sym___constant__] = ACTIONS(2062),
    [anon_sym___managed__] = ACTIONS(2062),
    [anon_sym___grid_constant__] = ACTIONS(2062),
    [anon_sym_alignas] = ACTIONS(2062),
    [anon_sym__Alignas] = ACTIONS(2062),
    [sym_primitive_type] = ACTIONS(2062),
    [anon_sym_enum] = ACTIONS(2062),
    [anon_sym_class] = ACTIONS(2062),
    [anon_sym_struct] = ACTIONS(2062),
    [anon_sym_union] = ACTIONS(2062),
    [anon_sym_if] = ACTIONS(2062),
    [anon_sym_else] = ACTIONS(2062),
    [anon_sym_switch] = ACTIONS(2062),
    [anon_sym_case] = ACTIONS(2062),
    [anon_sym_default] = ACTIONS(2062),
    [anon_sym_while] = ACTIONS(2062),
    [anon_sym_do] = ACTIONS(2062),
    [anon_sym_for] = ACTIONS(2062),
    [anon_sym_return] = ACTIONS(2062),
    [anon_sym_break] = ACTIONS(2062),
    [anon_sym_continue] = ACTIONS(2062),
    [anon_sym_goto] = ACTIONS(2062),
    [anon_sym___try] = ACTIONS(2062),
    [anon_sym___leave] = ACTIONS(2062),
    [anon_sym_not] = ACTIONS(2062),
    [anon_sym_compl] = ACTIONS(2062),
    [anon_sym_DASH_DASH] = ACTIONS(2064),
    [anon_sym_PLUS_PLUS] = ACTIONS(2064),
    [anon_sym_sizeof] = ACTIONS(2062),
    [anon_sym___alignof__] = ACTIONS(2062),
    [anon_sym___alignof] = ACTIONS(2062),
    [anon_sym__alignof] = ACTIONS(2062),
    [anon_sym_alignof] = ACTIONS(2062),
    [anon_sym__Alignof] = ACTIONS(2062),
    [anon_sym_offsetof] = ACTIONS(2062),
    [anon_sym__Generic] = ACTIONS(2062),
    [anon_sym_asm] = ACTIONS(2062),
    [anon_sym___asm__] = ACTIONS(2062),
    [anon_sym___asm] = ACTIONS(2062),
    [sym_number_literal] = ACTIONS(2064),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2064),
    [anon_sym_u_DQUOTE] = ACTIONS(2064),
    [anon_sym_U_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8_DQUOTE] = ACTIONS(2064),
    [anon_sym_DQUOTE] = ACTIONS(2064),
    [sym_true] = ACTIONS(2062),
    [sym_false] = ACTIONS(2062),
    [anon_sym_NULL] = ACTIONS(2062),
    [anon_sym_nullptr] = ACTIONS(2062),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2062),
    [anon_sym_decltype] = ACTIONS(2062),
    [anon_sym_explicit] = ACTIONS(2062),
    [anon_sym_typename] = ACTIONS(2062),
    [anon_sym_template] = ACTIONS(2062),
    [anon_sym_operator] = ACTIONS(2062),
    [anon_sym_try] = ACTIONS(2062),
    [anon_sym_delete] = ACTIONS(2062),
    [anon_sym_throw] = ACTIONS(2062),
    [anon_sym_namespace] = ACTIONS(2062),
    [anon_sym_using] = ACTIONS(2062),
    [anon_sym_static_assert] = ACTIONS(2062),
    [anon_sym_concept] = ACTIONS(2062),
    [anon_sym_co_return] = ACTIONS(2062),
    [anon_sym_co_yield] = ACTIONS(2062),
    [anon_sym_R_DQUOTE] = ACTIONS(2064),
    [anon_sym_LR_DQUOTE] = ACTIONS(2064),
    [anon_sym_uR_DQUOTE] = ACTIONS(2064),
    [anon_sym_UR_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2064),
    [anon_sym_co_await] = ACTIONS(2062),
    [anon_sym_new] = ACTIONS(2062),
    [anon_sym_requires] = ACTIONS(2062),
    [sym_this] = ACTIONS(2062),
    [anon_sym___launch_bounds__] = ACTIONS(2062),
  },
  [STATE(346)] = {
    [ts_builtin_sym_end] = ACTIONS(2152),
    [sym_identifier] = ACTIONS(2150),
    [aux_sym_preproc_include_token1] = ACTIONS(2150),
    [aux_sym_preproc_def_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2150),
    [sym_preproc_directive] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP_AMP] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2150),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym___device__] = ACTIONS(2150),
    [anon_sym___host__] = ACTIONS(2150),
    [anon_sym___global__] = ACTIONS(2150),
    [anon_sym___forceinline__] = ACTIONS(2150),
    [anon_sym___noinline__] = ACTIONS(2150),
    [anon_sym_virtual] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym___attribute] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym___based] = ACTIONS(2150),
    [anon_sym___cdecl] = ACTIONS(2150),
    [anon_sym___clrcall] = ACTIONS(2150),
    [anon_sym___stdcall] = ACTIONS(2150),
    [anon_sym___fastcall] = ACTIONS(2150),
    [anon_sym___thiscall] = ACTIONS(2150),
    [anon_sym___vectorcall] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym__Nonnull] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym___shared__] = ACTIONS(2150),
    [anon_sym___local__] = ACTIONS(2150),
    [anon_sym___constant__] = ACTIONS(2150),
    [anon_sym___managed__] = ACTIONS(2150),
    [anon_sym___grid_constant__] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_case] = ACTIONS(2150),
    [anon_sym_default] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [anon_sym___asm] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [anon_sym_explicit] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_operator] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_namespace] = ACTIONS(2150),
    [anon_sym_using] = ACTIONS(2150),
    [anon_sym_static_assert] = ACTIONS(2150),
    [anon_sym_concept] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym___launch_bounds__] = ACTIONS(2150),
  },
  [STATE(347)] = {
    [ts_builtin_sym_end] = ACTIONS(2192),
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_include_token1] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym___device__] = ACTIONS(2190),
    [anon_sym___host__] = ACTIONS(2190),
    [anon_sym___global__] = ACTIONS(2190),
    [anon_sym___forceinline__] = ACTIONS(2190),
    [anon_sym___noinline__] = ACTIONS(2190),
    [anon_sym_virtual] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym___attribute] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym___cdecl] = ACTIONS(2190),
    [anon_sym___clrcall] = ACTIONS(2190),
    [anon_sym___stdcall] = ACTIONS(2190),
    [anon_sym___fastcall] = ACTIONS(2190),
    [anon_sym___thiscall] = ACTIONS(2190),
    [anon_sym___vectorcall] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym__Nonnull] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym___shared__] = ACTIONS(2190),
    [anon_sym___local__] = ACTIONS(2190),
    [anon_sym___constant__] = ACTIONS(2190),
    [anon_sym___managed__] = ACTIONS(2190),
    [anon_sym___grid_constant__] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym_default] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [anon_sym___asm] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_namespace] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym_concept] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym___launch_bounds__] = ACTIONS(2190),
  },
  [STATE(348)] = {
    [ts_builtin_sym_end] = ACTIONS(2184),
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(349)] = {
    [ts_builtin_sym_end] = ACTIONS(2184),
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(350)] = {
    [sym_catch_clause] = STATE(240),
    [aux_sym_constructor_try_statement_repeat1] = STATE(240),
    [ts_builtin_sym_end] = ACTIONS(1998),
    [sym_identifier] = ACTIONS(1996),
    [aux_sym_preproc_include_token1] = ACTIONS(1996),
    [aux_sym_preproc_def_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1996),
    [sym_preproc_directive] = ACTIONS(1996),
    [anon_sym_LPAREN2] = ACTIONS(1998),
    [anon_sym_BANG] = ACTIONS(1998),
    [anon_sym_TILDE] = ACTIONS(1998),
    [anon_sym_DASH] = ACTIONS(1996),
    [anon_sym_PLUS] = ACTIONS(1996),
    [anon_sym_STAR] = ACTIONS(1998),
    [anon_sym_AMP_AMP] = ACTIONS(1998),
    [anon_sym_AMP] = ACTIONS(1996),
    [anon_sym_SEMI] = ACTIONS(1998),
    [anon_sym___extension__] = ACTIONS(1996),
    [anon_sym_typedef] = ACTIONS(1996),
    [anon_sym___device__] = ACTIONS(1996),
    [anon_sym___host__] = ACTIONS(1996),
    [anon_sym___global__] = ACTIONS(1996),
    [anon_sym___forceinline__] = ACTIONS(1996),
    [anon_sym___noinline__] = ACTIONS(1996),
    [anon_sym_virtual] = ACTIONS(1996),
    [anon_sym_extern] = ACTIONS(1996),
    [anon_sym___attribute__] = ACTIONS(1996),
    [anon_sym___attribute] = ACTIONS(1996),
    [anon_sym_COLON_COLON] = ACTIONS(1998),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1998),
    [anon_sym___declspec] = ACTIONS(1996),
    [anon_sym___based] = ACTIONS(1996),
    [anon_sym___cdecl] = ACTIONS(1996),
    [anon_sym___clrcall] = ACTIONS(1996),
    [anon_sym___stdcall] = ACTIONS(1996),
    [anon_sym___fastcall] = ACTIONS(1996),
    [anon_sym___thiscall] = ACTIONS(1996),
    [anon_sym___vectorcall] = ACTIONS(1996),
    [anon_sym_LBRACE] = ACTIONS(1998),
    [anon_sym_signed] = ACTIONS(1996),
    [anon_sym_unsigned] = ACTIONS(1996),
    [anon_sym_long] = ACTIONS(1996),
    [anon_sym_short] = ACTIONS(1996),
    [anon_sym_LBRACK] = ACTIONS(1996),
    [anon_sym_static] = ACTIONS(1996),
    [anon_sym_register] = ACTIONS(1996),
    [anon_sym_inline] = ACTIONS(1996),
    [anon_sym___inline] = ACTIONS(1996),
    [anon_sym___inline__] = ACTIONS(1996),
    [anon_sym___forceinline] = ACTIONS(1996),
    [anon_sym_thread_local] = ACTIONS(1996),
    [anon_sym___thread] = ACTIONS(1996),
    [anon_sym_const] = ACTIONS(1996),
    [anon_sym_constexpr] = ACTIONS(1996),
    [anon_sym_volatile] = ACTIONS(1996),
    [anon_sym_restrict] = ACTIONS(1996),
    [anon_sym___restrict__] = ACTIONS(1996),
    [anon_sym__Atomic] = ACTIONS(1996),
    [anon_sym__Noreturn] = ACTIONS(1996),
    [anon_sym_noreturn] = ACTIONS(1996),
    [anon_sym__Nonnull] = ACTIONS(1996),
    [anon_sym_mutable] = ACTIONS(1996),
    [anon_sym_constinit] = ACTIONS(1996),
    [anon_sym_consteval] = ACTIONS(1996),
    [anon_sym___shared__] = ACTIONS(1996),
    [anon_sym___local__] = ACTIONS(1996),
    [anon_sym___constant__] = ACTIONS(1996),
    [anon_sym___managed__] = ACTIONS(1996),
    [anon_sym___grid_constant__] = ACTIONS(1996),
    [anon_sym_alignas] = ACTIONS(1996),
    [anon_sym__Alignas] = ACTIONS(1996),
    [sym_primitive_type] = ACTIONS(1996),
    [anon_sym_enum] = ACTIONS(1996),
    [anon_sym_class] = ACTIONS(1996),
    [anon_sym_struct] = ACTIONS(1996),
    [anon_sym_union] = ACTIONS(1996),
    [anon_sym_if] = ACTIONS(1996),
    [anon_sym_switch] = ACTIONS(1996),
    [anon_sym_case] = ACTIONS(1996),
    [anon_sym_default] = ACTIONS(1996),
    [anon_sym_while] = ACTIONS(1996),
    [anon_sym_do] = ACTIONS(1996),
    [anon_sym_for] = ACTIONS(1996),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_break] = ACTIONS(1996),
    [anon_sym_continue] = ACTIONS(1996),
    [anon_sym_goto] = ACTIONS(1996),
    [anon_sym_not] = ACTIONS(1996),
    [anon_sym_compl] = ACTIONS(1996),
    [anon_sym_DASH_DASH] = ACTIONS(1998),
    [anon_sym_PLUS_PLUS] = ACTIONS(1998),
    [anon_sym_sizeof] = ACTIONS(1996),
    [anon_sym___alignof__] = ACTIONS(1996),
    [anon_sym___alignof] = ACTIONS(1996),
    [anon_sym__alignof] = ACTIONS(1996),
    [anon_sym_alignof] = ACTIONS(1996),
    [anon_sym__Alignof] = ACTIONS(1996),
    [anon_sym_offsetof] = ACTIONS(1996),
    [anon_sym__Generic] = ACTIONS(1996),
    [anon_sym_asm] = ACTIONS(1996),
    [anon_sym___asm__] = ACTIONS(1996),
    [anon_sym___asm] = ACTIONS(1996),
    [sym_number_literal] = ACTIONS(1998),
    [anon_sym_L_SQUOTE] = ACTIONS(1998),
    [anon_sym_u_SQUOTE] = ACTIONS(1998),
    [anon_sym_U_SQUOTE] = ACTIONS(1998),
    [anon_sym_u8_SQUOTE] = ACTIONS(1998),
    [anon_sym_SQUOTE] = ACTIONS(1998),
    [anon_sym_L_DQUOTE] = ACTIONS(1998),
    [anon_sym_u_DQUOTE] = ACTIONS(1998),
    [anon_sym_U_DQUOTE] = ACTIONS(1998),
    [anon_sym_u8_DQUOTE] = ACTIONS(1998),
    [anon_sym_DQUOTE] = ACTIONS(1998),
    [sym_true] = ACTIONS(1996),
    [sym_false] = ACTIONS(1996),
    [anon_sym_NULL] = ACTIONS(1996),
    [anon_sym_nullptr] = ACTIONS(1996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1996),
    [anon_sym_decltype] = ACTIONS(1996),
    [anon_sym_explicit] = ACTIONS(1996),
    [anon_sym_typename] = ACTIONS(1996),
    [anon_sym_template] = ACTIONS(1996),
    [anon_sym_operator] = ACTIONS(1996),
    [anon_sym_try] = ACTIONS(1996),
    [anon_sym_delete] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1996),
    [anon_sym_namespace] = ACTIONS(1996),
    [anon_sym_using] = ACTIONS(1996),
    [anon_sym_static_assert] = ACTIONS(1996),
    [anon_sym_concept] = ACTIONS(1996),
    [anon_sym_co_return] = ACTIONS(1996),
    [anon_sym_co_yield] = ACTIONS(1996),
    [anon_sym_catch] = ACTIONS(2589),
    [anon_sym_R_DQUOTE] = ACTIONS(1998),
    [anon_sym_LR_DQUOTE] = ACTIONS(1998),
    [anon_sym_uR_DQUOTE] = ACTIONS(1998),
    [anon_sym_UR_DQUOTE] = ACTIONS(1998),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1998),
    [anon_sym_co_await] = ACTIONS(1996),
    [anon_sym_new] = ACTIONS(1996),
    [anon_sym_requires] = ACTIONS(1996),
    [sym_this] = ACTIONS(1996),
    [anon_sym___launch_bounds__] = ACTIONS(1996),
  },
  [STATE(351)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_RBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(352)] = {
    [ts_builtin_sym_end] = ACTIONS(2220),
    [sym_identifier] = ACTIONS(2218),
    [aux_sym_preproc_include_token1] = ACTIONS(2218),
    [aux_sym_preproc_def_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2218),
    [sym_preproc_directive] = ACTIONS(2218),
    [anon_sym_LPAREN2] = ACTIONS(2220),
    [anon_sym_BANG] = ACTIONS(2220),
    [anon_sym_TILDE] = ACTIONS(2220),
    [anon_sym_DASH] = ACTIONS(2218),
    [anon_sym_PLUS] = ACTIONS(2218),
    [anon_sym_STAR] = ACTIONS(2220),
    [anon_sym_AMP_AMP] = ACTIONS(2220),
    [anon_sym_AMP] = ACTIONS(2218),
    [anon_sym_SEMI] = ACTIONS(2220),
    [anon_sym___extension__] = ACTIONS(2218),
    [anon_sym_typedef] = ACTIONS(2218),
    [anon_sym___device__] = ACTIONS(2218),
    [anon_sym___host__] = ACTIONS(2218),
    [anon_sym___global__] = ACTIONS(2218),
    [anon_sym___forceinline__] = ACTIONS(2218),
    [anon_sym___noinline__] = ACTIONS(2218),
    [anon_sym_virtual] = ACTIONS(2218),
    [anon_sym_extern] = ACTIONS(2218),
    [anon_sym___attribute__] = ACTIONS(2218),
    [anon_sym___attribute] = ACTIONS(2218),
    [anon_sym_COLON_COLON] = ACTIONS(2220),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2220),
    [anon_sym___declspec] = ACTIONS(2218),
    [anon_sym___based] = ACTIONS(2218),
    [anon_sym___cdecl] = ACTIONS(2218),
    [anon_sym___clrcall] = ACTIONS(2218),
    [anon_sym___stdcall] = ACTIONS(2218),
    [anon_sym___fastcall] = ACTIONS(2218),
    [anon_sym___thiscall] = ACTIONS(2218),
    [anon_sym___vectorcall] = ACTIONS(2218),
    [anon_sym_LBRACE] = ACTIONS(2220),
    [anon_sym_signed] = ACTIONS(2218),
    [anon_sym_unsigned] = ACTIONS(2218),
    [anon_sym_long] = ACTIONS(2218),
    [anon_sym_short] = ACTIONS(2218),
    [anon_sym_LBRACK] = ACTIONS(2218),
    [anon_sym_static] = ACTIONS(2218),
    [anon_sym_register] = ACTIONS(2218),
    [anon_sym_inline] = ACTIONS(2218),
    [anon_sym___inline] = ACTIONS(2218),
    [anon_sym___inline__] = ACTIONS(2218),
    [anon_sym___forceinline] = ACTIONS(2218),
    [anon_sym_thread_local] = ACTIONS(2218),
    [anon_sym___thread] = ACTIONS(2218),
    [anon_sym_const] = ACTIONS(2218),
    [anon_sym_constexpr] = ACTIONS(2218),
    [anon_sym_volatile] = ACTIONS(2218),
    [anon_sym_restrict] = ACTIONS(2218),
    [anon_sym___restrict__] = ACTIONS(2218),
    [anon_sym__Atomic] = ACTIONS(2218),
    [anon_sym__Noreturn] = ACTIONS(2218),
    [anon_sym_noreturn] = ACTIONS(2218),
    [anon_sym__Nonnull] = ACTIONS(2218),
    [anon_sym_mutable] = ACTIONS(2218),
    [anon_sym_constinit] = ACTIONS(2218),
    [anon_sym_consteval] = ACTIONS(2218),
    [anon_sym___shared__] = ACTIONS(2218),
    [anon_sym___local__] = ACTIONS(2218),
    [anon_sym___constant__] = ACTIONS(2218),
    [anon_sym___managed__] = ACTIONS(2218),
    [anon_sym___grid_constant__] = ACTIONS(2218),
    [anon_sym_alignas] = ACTIONS(2218),
    [anon_sym__Alignas] = ACTIONS(2218),
    [sym_primitive_type] = ACTIONS(2218),
    [anon_sym_enum] = ACTIONS(2218),
    [anon_sym_class] = ACTIONS(2218),
    [anon_sym_struct] = ACTIONS(2218),
    [anon_sym_union] = ACTIONS(2218),
    [anon_sym_if] = ACTIONS(2218),
    [anon_sym_else] = ACTIONS(2218),
    [anon_sym_switch] = ACTIONS(2218),
    [anon_sym_case] = ACTIONS(2218),
    [anon_sym_default] = ACTIONS(2218),
    [anon_sym_while] = ACTIONS(2218),
    [anon_sym_do] = ACTIONS(2218),
    [anon_sym_for] = ACTIONS(2218),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_break] = ACTIONS(2218),
    [anon_sym_continue] = ACTIONS(2218),
    [anon_sym_goto] = ACTIONS(2218),
    [anon_sym___try] = ACTIONS(2218),
    [anon_sym___leave] = ACTIONS(2218),
    [anon_sym_not] = ACTIONS(2218),
    [anon_sym_compl] = ACTIONS(2218),
    [anon_sym_DASH_DASH] = ACTIONS(2220),
    [anon_sym_PLUS_PLUS] = ACTIONS(2220),
    [anon_sym_sizeof] = ACTIONS(2218),
    [anon_sym___alignof__] = ACTIONS(2218),
    [anon_sym___alignof] = ACTIONS(2218),
    [anon_sym__alignof] = ACTIONS(2218),
    [anon_sym_alignof] = ACTIONS(2218),
    [anon_sym__Alignof] = ACTIONS(2218),
    [anon_sym_offsetof] = ACTIONS(2218),
    [anon_sym__Generic] = ACTIONS(2218),
    [anon_sym_asm] = ACTIONS(2218),
    [anon_sym___asm__] = ACTIONS(2218),
    [anon_sym___asm] = ACTIONS(2218),
    [sym_number_literal] = ACTIONS(2220),
    [anon_sym_L_SQUOTE] = ACTIONS(2220),
    [anon_sym_u_SQUOTE] = ACTIONS(2220),
    [anon_sym_U_SQUOTE] = ACTIONS(2220),
    [anon_sym_u8_SQUOTE] = ACTIONS(2220),
    [anon_sym_SQUOTE] = ACTIONS(2220),
    [anon_sym_L_DQUOTE] = ACTIONS(2220),
    [anon_sym_u_DQUOTE] = ACTIONS(2220),
    [anon_sym_U_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8_DQUOTE] = ACTIONS(2220),
    [anon_sym_DQUOTE] = ACTIONS(2220),
    [sym_true] = ACTIONS(2218),
    [sym_false] = ACTIONS(2218),
    [anon_sym_NULL] = ACTIONS(2218),
    [anon_sym_nullptr] = ACTIONS(2218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2218),
    [anon_sym_decltype] = ACTIONS(2218),
    [anon_sym_explicit] = ACTIONS(2218),
    [anon_sym_typename] = ACTIONS(2218),
    [anon_sym_template] = ACTIONS(2218),
    [anon_sym_operator] = ACTIONS(2218),
    [anon_sym_try] = ACTIONS(2218),
    [anon_sym_delete] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2218),
    [anon_sym_namespace] = ACTIONS(2218),
    [anon_sym_using] = ACTIONS(2218),
    [anon_sym_static_assert] = ACTIONS(2218),
    [anon_sym_concept] = ACTIONS(2218),
    [anon_sym_co_return] = ACTIONS(2218),
    [anon_sym_co_yield] = ACTIONS(2218),
    [anon_sym_R_DQUOTE] = ACTIONS(2220),
    [anon_sym_LR_DQUOTE] = ACTIONS(2220),
    [anon_sym_uR_DQUOTE] = ACTIONS(2220),
    [anon_sym_UR_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2220),
    [anon_sym_co_await] = ACTIONS(2218),
    [anon_sym_new] = ACTIONS(2218),
    [anon_sym_requires] = ACTIONS(2218),
    [sym_this] = ACTIONS(2218),
    [anon_sym___launch_bounds__] = ACTIONS(2218),
  },
  [STATE(353)] = {
    [ts_builtin_sym_end] = ACTIONS(2046),
    [sym_identifier] = ACTIONS(2044),
    [aux_sym_preproc_include_token1] = ACTIONS(2044),
    [aux_sym_preproc_def_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2044),
    [sym_preproc_directive] = ACTIONS(2044),
    [anon_sym_LPAREN2] = ACTIONS(2046),
    [anon_sym_BANG] = ACTIONS(2046),
    [anon_sym_TILDE] = ACTIONS(2046),
    [anon_sym_DASH] = ACTIONS(2044),
    [anon_sym_PLUS] = ACTIONS(2044),
    [anon_sym_STAR] = ACTIONS(2046),
    [anon_sym_AMP_AMP] = ACTIONS(2046),
    [anon_sym_AMP] = ACTIONS(2044),
    [anon_sym_SEMI] = ACTIONS(2046),
    [anon_sym___extension__] = ACTIONS(2044),
    [anon_sym_typedef] = ACTIONS(2044),
    [anon_sym___device__] = ACTIONS(2044),
    [anon_sym___host__] = ACTIONS(2044),
    [anon_sym___global__] = ACTIONS(2044),
    [anon_sym___forceinline__] = ACTIONS(2044),
    [anon_sym___noinline__] = ACTIONS(2044),
    [anon_sym_virtual] = ACTIONS(2044),
    [anon_sym_extern] = ACTIONS(2044),
    [anon_sym___attribute__] = ACTIONS(2044),
    [anon_sym___attribute] = ACTIONS(2044),
    [anon_sym_COLON_COLON] = ACTIONS(2046),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2046),
    [anon_sym___declspec] = ACTIONS(2044),
    [anon_sym___based] = ACTIONS(2044),
    [anon_sym___cdecl] = ACTIONS(2044),
    [anon_sym___clrcall] = ACTIONS(2044),
    [anon_sym___stdcall] = ACTIONS(2044),
    [anon_sym___fastcall] = ACTIONS(2044),
    [anon_sym___thiscall] = ACTIONS(2044),
    [anon_sym___vectorcall] = ACTIONS(2044),
    [anon_sym_LBRACE] = ACTIONS(2046),
    [anon_sym_signed] = ACTIONS(2044),
    [anon_sym_unsigned] = ACTIONS(2044),
    [anon_sym_long] = ACTIONS(2044),
    [anon_sym_short] = ACTIONS(2044),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_static] = ACTIONS(2044),
    [anon_sym_register] = ACTIONS(2044),
    [anon_sym_inline] = ACTIONS(2044),
    [anon_sym___inline] = ACTIONS(2044),
    [anon_sym___inline__] = ACTIONS(2044),
    [anon_sym___forceinline] = ACTIONS(2044),
    [anon_sym_thread_local] = ACTIONS(2044),
    [anon_sym___thread] = ACTIONS(2044),
    [anon_sym_const] = ACTIONS(2044),
    [anon_sym_constexpr] = ACTIONS(2044),
    [anon_sym_volatile] = ACTIONS(2044),
    [anon_sym_restrict] = ACTIONS(2044),
    [anon_sym___restrict__] = ACTIONS(2044),
    [anon_sym__Atomic] = ACTIONS(2044),
    [anon_sym__Noreturn] = ACTIONS(2044),
    [anon_sym_noreturn] = ACTIONS(2044),
    [anon_sym__Nonnull] = ACTIONS(2044),
    [anon_sym_mutable] = ACTIONS(2044),
    [anon_sym_constinit] = ACTIONS(2044),
    [anon_sym_consteval] = ACTIONS(2044),
    [anon_sym___shared__] = ACTIONS(2044),
    [anon_sym___local__] = ACTIONS(2044),
    [anon_sym___constant__] = ACTIONS(2044),
    [anon_sym___managed__] = ACTIONS(2044),
    [anon_sym___grid_constant__] = ACTIONS(2044),
    [anon_sym_alignas] = ACTIONS(2044),
    [anon_sym__Alignas] = ACTIONS(2044),
    [sym_primitive_type] = ACTIONS(2044),
    [anon_sym_enum] = ACTIONS(2044),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2044),
    [anon_sym_union] = ACTIONS(2044),
    [anon_sym_if] = ACTIONS(2044),
    [anon_sym_else] = ACTIONS(2044),
    [anon_sym_switch] = ACTIONS(2044),
    [anon_sym_case] = ACTIONS(2044),
    [anon_sym_default] = ACTIONS(2044),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_do] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2044),
    [anon_sym_return] = ACTIONS(2044),
    [anon_sym_break] = ACTIONS(2044),
    [anon_sym_continue] = ACTIONS(2044),
    [anon_sym_goto] = ACTIONS(2044),
    [anon_sym___try] = ACTIONS(2044),
    [anon_sym___leave] = ACTIONS(2044),
    [anon_sym_not] = ACTIONS(2044),
    [anon_sym_compl] = ACTIONS(2044),
    [anon_sym_DASH_DASH] = ACTIONS(2046),
    [anon_sym_PLUS_PLUS] = ACTIONS(2046),
    [anon_sym_sizeof] = ACTIONS(2044),
    [anon_sym___alignof__] = ACTIONS(2044),
    [anon_sym___alignof] = ACTIONS(2044),
    [anon_sym__alignof] = ACTIONS(2044),
    [anon_sym_alignof] = ACTIONS(2044),
    [anon_sym__Alignof] = ACTIONS(2044),
    [anon_sym_offsetof] = ACTIONS(2044),
    [anon_sym__Generic] = ACTIONS(2044),
    [anon_sym_asm] = ACTIONS(2044),
    [anon_sym___asm__] = ACTIONS(2044),
    [anon_sym___asm] = ACTIONS(2044),
    [sym_number_literal] = ACTIONS(2046),
    [anon_sym_L_SQUOTE] = ACTIONS(2046),
    [anon_sym_u_SQUOTE] = ACTIONS(2046),
    [anon_sym_U_SQUOTE] = ACTIONS(2046),
    [anon_sym_u8_SQUOTE] = ACTIONS(2046),
    [anon_sym_SQUOTE] = ACTIONS(2046),
    [anon_sym_L_DQUOTE] = ACTIONS(2046),
    [anon_sym_u_DQUOTE] = ACTIONS(2046),
    [anon_sym_U_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8_DQUOTE] = ACTIONS(2046),
    [anon_sym_DQUOTE] = ACTIONS(2046),
    [sym_true] = ACTIONS(2044),
    [sym_false] = ACTIONS(2044),
    [anon_sym_NULL] = ACTIONS(2044),
    [anon_sym_nullptr] = ACTIONS(2044),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2044),
    [anon_sym_decltype] = ACTIONS(2044),
    [anon_sym_explicit] = ACTIONS(2044),
    [anon_sym_typename] = ACTIONS(2044),
    [anon_sym_template] = ACTIONS(2044),
    [anon_sym_operator] = ACTIONS(2044),
    [anon_sym_try] = ACTIONS(2044),
    [anon_sym_delete] = ACTIONS(2044),
    [anon_sym_throw] = ACTIONS(2044),
    [anon_sym_namespace] = ACTIONS(2044),
    [anon_sym_using] = ACTIONS(2044),
    [anon_sym_static_assert] = ACTIONS(2044),
    [anon_sym_concept] = ACTIONS(2044),
    [anon_sym_co_return] = ACTIONS(2044),
    [anon_sym_co_yield] = ACTIONS(2044),
    [anon_sym_R_DQUOTE] = ACTIONS(2046),
    [anon_sym_LR_DQUOTE] = ACTIONS(2046),
    [anon_sym_uR_DQUOTE] = ACTIONS(2046),
    [anon_sym_UR_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2046),
    [anon_sym_co_await] = ACTIONS(2044),
    [anon_sym_new] = ACTIONS(2044),
    [anon_sym_requires] = ACTIONS(2044),
    [sym_this] = ACTIONS(2044),
    [anon_sym___launch_bounds__] = ACTIONS(2044),
  },
  [STATE(354)] = {
    [sym_identifier] = ACTIONS(2052),
    [aux_sym_preproc_include_token1] = ACTIONS(2052),
    [aux_sym_preproc_def_token1] = ACTIONS(2052),
    [aux_sym_preproc_if_token1] = ACTIONS(2052),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2052),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2052),
    [sym_preproc_directive] = ACTIONS(2052),
    [anon_sym_LPAREN2] = ACTIONS(2054),
    [anon_sym_BANG] = ACTIONS(2054),
    [anon_sym_TILDE] = ACTIONS(2054),
    [anon_sym_DASH] = ACTIONS(2052),
    [anon_sym_PLUS] = ACTIONS(2052),
    [anon_sym_STAR] = ACTIONS(2054),
    [anon_sym_AMP_AMP] = ACTIONS(2054),
    [anon_sym_AMP] = ACTIONS(2052),
    [anon_sym_SEMI] = ACTIONS(2054),
    [anon_sym___extension__] = ACTIONS(2052),
    [anon_sym_typedef] = ACTIONS(2052),
    [anon_sym___device__] = ACTIONS(2052),
    [anon_sym___host__] = ACTIONS(2052),
    [anon_sym___global__] = ACTIONS(2052),
    [anon_sym___forceinline__] = ACTIONS(2052),
    [anon_sym___noinline__] = ACTIONS(2052),
    [anon_sym_virtual] = ACTIONS(2052),
    [anon_sym_extern] = ACTIONS(2052),
    [anon_sym___attribute__] = ACTIONS(2052),
    [anon_sym___attribute] = ACTIONS(2052),
    [anon_sym_COLON_COLON] = ACTIONS(2054),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2054),
    [anon_sym___declspec] = ACTIONS(2052),
    [anon_sym___based] = ACTIONS(2052),
    [anon_sym___cdecl] = ACTIONS(2052),
    [anon_sym___clrcall] = ACTIONS(2052),
    [anon_sym___stdcall] = ACTIONS(2052),
    [anon_sym___fastcall] = ACTIONS(2052),
    [anon_sym___thiscall] = ACTIONS(2052),
    [anon_sym___vectorcall] = ACTIONS(2052),
    [anon_sym_LBRACE] = ACTIONS(2054),
    [anon_sym_RBRACE] = ACTIONS(2054),
    [anon_sym_signed] = ACTIONS(2052),
    [anon_sym_unsigned] = ACTIONS(2052),
    [anon_sym_long] = ACTIONS(2052),
    [anon_sym_short] = ACTIONS(2052),
    [anon_sym_LBRACK] = ACTIONS(2052),
    [anon_sym_static] = ACTIONS(2052),
    [anon_sym_register] = ACTIONS(2052),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym___inline] = ACTIONS(2052),
    [anon_sym___inline__] = ACTIONS(2052),
    [anon_sym___forceinline] = ACTIONS(2052),
    [anon_sym_thread_local] = ACTIONS(2052),
    [anon_sym___thread] = ACTIONS(2052),
    [anon_sym_const] = ACTIONS(2052),
    [anon_sym_constexpr] = ACTIONS(2052),
    [anon_sym_volatile] = ACTIONS(2052),
    [anon_sym_restrict] = ACTIONS(2052),
    [anon_sym___restrict__] = ACTIONS(2052),
    [anon_sym__Atomic] = ACTIONS(2052),
    [anon_sym__Noreturn] = ACTIONS(2052),
    [anon_sym_noreturn] = ACTIONS(2052),
    [anon_sym__Nonnull] = ACTIONS(2052),
    [anon_sym_mutable] = ACTIONS(2052),
    [anon_sym_constinit] = ACTIONS(2052),
    [anon_sym_consteval] = ACTIONS(2052),
    [anon_sym___shared__] = ACTIONS(2052),
    [anon_sym___local__] = ACTIONS(2052),
    [anon_sym___constant__] = ACTIONS(2052),
    [anon_sym___managed__] = ACTIONS(2052),
    [anon_sym___grid_constant__] = ACTIONS(2052),
    [anon_sym_alignas] = ACTIONS(2052),
    [anon_sym__Alignas] = ACTIONS(2052),
    [sym_primitive_type] = ACTIONS(2052),
    [anon_sym_enum] = ACTIONS(2052),
    [anon_sym_class] = ACTIONS(2052),
    [anon_sym_struct] = ACTIONS(2052),
    [anon_sym_union] = ACTIONS(2052),
    [anon_sym_if] = ACTIONS(2052),
    [anon_sym_else] = ACTIONS(2052),
    [anon_sym_switch] = ACTIONS(2052),
    [anon_sym_case] = ACTIONS(2052),
    [anon_sym_default] = ACTIONS(2052),
    [anon_sym_while] = ACTIONS(2052),
    [anon_sym_do] = ACTIONS(2052),
    [anon_sym_for] = ACTIONS(2052),
    [anon_sym_return] = ACTIONS(2052),
    [anon_sym_break] = ACTIONS(2052),
    [anon_sym_continue] = ACTIONS(2052),
    [anon_sym_goto] = ACTIONS(2052),
    [anon_sym___try] = ACTIONS(2052),
    [anon_sym___leave] = ACTIONS(2052),
    [anon_sym_not] = ACTIONS(2052),
    [anon_sym_compl] = ACTIONS(2052),
    [anon_sym_DASH_DASH] = ACTIONS(2054),
    [anon_sym_PLUS_PLUS] = ACTIONS(2054),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2052),
    [anon_sym___alignof] = ACTIONS(2052),
    [anon_sym__alignof] = ACTIONS(2052),
    [anon_sym_alignof] = ACTIONS(2052),
    [anon_sym__Alignof] = ACTIONS(2052),
    [anon_sym_offsetof] = ACTIONS(2052),
    [anon_sym__Generic] = ACTIONS(2052),
    [anon_sym_asm] = ACTIONS(2052),
    [anon_sym___asm__] = ACTIONS(2052),
    [anon_sym___asm] = ACTIONS(2052),
    [sym_number_literal] = ACTIONS(2054),
    [anon_sym_L_SQUOTE] = ACTIONS(2054),
    [anon_sym_u_SQUOTE] = ACTIONS(2054),
    [anon_sym_U_SQUOTE] = ACTIONS(2054),
    [anon_sym_u8_SQUOTE] = ACTIONS(2054),
    [anon_sym_SQUOTE] = ACTIONS(2054),
    [anon_sym_L_DQUOTE] = ACTIONS(2054),
    [anon_sym_u_DQUOTE] = ACTIONS(2054),
    [anon_sym_U_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8_DQUOTE] = ACTIONS(2054),
    [anon_sym_DQUOTE] = ACTIONS(2054),
    [sym_true] = ACTIONS(2052),
    [sym_false] = ACTIONS(2052),
    [anon_sym_NULL] = ACTIONS(2052),
    [anon_sym_nullptr] = ACTIONS(2052),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2052),
    [anon_sym_decltype] = ACTIONS(2052),
    [anon_sym_explicit] = ACTIONS(2052),
    [anon_sym_typename] = ACTIONS(2052),
    [anon_sym_template] = ACTIONS(2052),
    [anon_sym_operator] = ACTIONS(2052),
    [anon_sym_try] = ACTIONS(2052),
    [anon_sym_delete] = ACTIONS(2052),
    [anon_sym_throw] = ACTIONS(2052),
    [anon_sym_namespace] = ACTIONS(2052),
    [anon_sym_using] = ACTIONS(2052),
    [anon_sym_static_assert] = ACTIONS(2052),
    [anon_sym_concept] = ACTIONS(2052),
    [anon_sym_co_return] = ACTIONS(2052),
    [anon_sym_co_yield] = ACTIONS(2052),
    [anon_sym_R_DQUOTE] = ACTIONS(2054),
    [anon_sym_LR_DQUOTE] = ACTIONS(2054),
    [anon_sym_uR_DQUOTE] = ACTIONS(2054),
    [anon_sym_UR_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2054),
    [anon_sym_co_await] = ACTIONS(2052),
    [anon_sym_new] = ACTIONS(2052),
    [anon_sym_requires] = ACTIONS(2052),
    [sym_this] = ACTIONS(2052),
    [anon_sym___launch_bounds__] = ACTIONS(2052),
  },
  [STATE(355)] = {
    [ts_builtin_sym_end] = ACTIONS(2156),
    [sym_identifier] = ACTIONS(2154),
    [aux_sym_preproc_include_token1] = ACTIONS(2154),
    [aux_sym_preproc_def_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2154),
    [sym_preproc_directive] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP_AMP] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2154),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym___device__] = ACTIONS(2154),
    [anon_sym___host__] = ACTIONS(2154),
    [anon_sym___global__] = ACTIONS(2154),
    [anon_sym___forceinline__] = ACTIONS(2154),
    [anon_sym___noinline__] = ACTIONS(2154),
    [anon_sym_virtual] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym___attribute] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym___based] = ACTIONS(2154),
    [anon_sym___cdecl] = ACTIONS(2154),
    [anon_sym___clrcall] = ACTIONS(2154),
    [anon_sym___stdcall] = ACTIONS(2154),
    [anon_sym___fastcall] = ACTIONS(2154),
    [anon_sym___thiscall] = ACTIONS(2154),
    [anon_sym___vectorcall] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym__Nonnull] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym___shared__] = ACTIONS(2154),
    [anon_sym___local__] = ACTIONS(2154),
    [anon_sym___constant__] = ACTIONS(2154),
    [anon_sym___managed__] = ACTIONS(2154),
    [anon_sym___grid_constant__] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_case] = ACTIONS(2154),
    [anon_sym_default] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [anon_sym___asm] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [anon_sym_explicit] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_operator] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_namespace] = ACTIONS(2154),
    [anon_sym_using] = ACTIONS(2154),
    [anon_sym_static_assert] = ACTIONS(2154),
    [anon_sym_concept] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym___launch_bounds__] = ACTIONS(2154),
  },
  [STATE(356)] = {
    [ts_builtin_sym_end] = ACTIONS(2160),
    [sym_identifier] = ACTIONS(2158),
    [aux_sym_preproc_include_token1] = ACTIONS(2158),
    [aux_sym_preproc_def_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2158),
    [sym_preproc_directive] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP_AMP] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2158),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym___device__] = ACTIONS(2158),
    [anon_sym___host__] = ACTIONS(2158),
    [anon_sym___global__] = ACTIONS(2158),
    [anon_sym___forceinline__] = ACTIONS(2158),
    [anon_sym___noinline__] = ACTIONS(2158),
    [anon_sym_virtual] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym___attribute] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym___based] = ACTIONS(2158),
    [anon_sym___cdecl] = ACTIONS(2158),
    [anon_sym___clrcall] = ACTIONS(2158),
    [anon_sym___stdcall] = ACTIONS(2158),
    [anon_sym___fastcall] = ACTIONS(2158),
    [anon_sym___thiscall] = ACTIONS(2158),
    [anon_sym___vectorcall] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym__Nonnull] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym___shared__] = ACTIONS(2158),
    [anon_sym___local__] = ACTIONS(2158),
    [anon_sym___constant__] = ACTIONS(2158),
    [anon_sym___managed__] = ACTIONS(2158),
    [anon_sym___grid_constant__] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_case] = ACTIONS(2158),
    [anon_sym_default] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [anon_sym___asm] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [anon_sym_explicit] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_operator] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_namespace] = ACTIONS(2158),
    [anon_sym_using] = ACTIONS(2158),
    [anon_sym_static_assert] = ACTIONS(2158),
    [anon_sym_concept] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym___launch_bounds__] = ACTIONS(2158),
  },
  [STATE(357)] = {
    [ts_builtin_sym_end] = ACTIONS(2188),
    [sym_identifier] = ACTIONS(2186),
    [aux_sym_preproc_include_token1] = ACTIONS(2186),
    [aux_sym_preproc_def_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2186),
    [sym_preproc_directive] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP_AMP] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2186),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym___device__] = ACTIONS(2186),
    [anon_sym___host__] = ACTIONS(2186),
    [anon_sym___global__] = ACTIONS(2186),
    [anon_sym___forceinline__] = ACTIONS(2186),
    [anon_sym___noinline__] = ACTIONS(2186),
    [anon_sym_virtual] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym___attribute] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym___based] = ACTIONS(2186),
    [anon_sym___cdecl] = ACTIONS(2186),
    [anon_sym___clrcall] = ACTIONS(2186),
    [anon_sym___stdcall] = ACTIONS(2186),
    [anon_sym___fastcall] = ACTIONS(2186),
    [anon_sym___thiscall] = ACTIONS(2186),
    [anon_sym___vectorcall] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym__Nonnull] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym___shared__] = ACTIONS(2186),
    [anon_sym___local__] = ACTIONS(2186),
    [anon_sym___constant__] = ACTIONS(2186),
    [anon_sym___managed__] = ACTIONS(2186),
    [anon_sym___grid_constant__] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_case] = ACTIONS(2186),
    [anon_sym_default] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [anon_sym___asm] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [anon_sym_explicit] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_operator] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_namespace] = ACTIONS(2186),
    [anon_sym_using] = ACTIONS(2186),
    [anon_sym_static_assert] = ACTIONS(2186),
    [anon_sym_concept] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym___launch_bounds__] = ACTIONS(2186),
  },
  [STATE(358)] = {
    [ts_builtin_sym_end] = ACTIONS(2216),
    [sym_identifier] = ACTIONS(2214),
    [aux_sym_preproc_include_token1] = ACTIONS(2214),
    [aux_sym_preproc_def_token1] = ACTIONS(2214),
    [aux_sym_preproc_if_token1] = ACTIONS(2214),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2214),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2214),
    [sym_preproc_directive] = ACTIONS(2214),
    [anon_sym_LPAREN2] = ACTIONS(2216),
    [anon_sym_BANG] = ACTIONS(2216),
    [anon_sym_TILDE] = ACTIONS(2216),
    [anon_sym_DASH] = ACTIONS(2214),
    [anon_sym_PLUS] = ACTIONS(2214),
    [anon_sym_STAR] = ACTIONS(2216),
    [anon_sym_AMP_AMP] = ACTIONS(2216),
    [anon_sym_AMP] = ACTIONS(2214),
    [anon_sym_SEMI] = ACTIONS(2216),
    [anon_sym___extension__] = ACTIONS(2214),
    [anon_sym_typedef] = ACTIONS(2214),
    [anon_sym___device__] = ACTIONS(2214),
    [anon_sym___host__] = ACTIONS(2214),
    [anon_sym___global__] = ACTIONS(2214),
    [anon_sym___forceinline__] = ACTIONS(2214),
    [anon_sym___noinline__] = ACTIONS(2214),
    [anon_sym_virtual] = ACTIONS(2214),
    [anon_sym_extern] = ACTIONS(2214),
    [anon_sym___attribute__] = ACTIONS(2214),
    [anon_sym___attribute] = ACTIONS(2214),
    [anon_sym_COLON_COLON] = ACTIONS(2216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2216),
    [anon_sym___declspec] = ACTIONS(2214),
    [anon_sym___based] = ACTIONS(2214),
    [anon_sym___cdecl] = ACTIONS(2214),
    [anon_sym___clrcall] = ACTIONS(2214),
    [anon_sym___stdcall] = ACTIONS(2214),
    [anon_sym___fastcall] = ACTIONS(2214),
    [anon_sym___thiscall] = ACTIONS(2214),
    [anon_sym___vectorcall] = ACTIONS(2214),
    [anon_sym_LBRACE] = ACTIONS(2216),
    [anon_sym_signed] = ACTIONS(2214),
    [anon_sym_unsigned] = ACTIONS(2214),
    [anon_sym_long] = ACTIONS(2214),
    [anon_sym_short] = ACTIONS(2214),
    [anon_sym_LBRACK] = ACTIONS(2214),
    [anon_sym_static] = ACTIONS(2214),
    [anon_sym_register] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(2214),
    [anon_sym___inline] = ACTIONS(2214),
    [anon_sym___inline__] = ACTIONS(2214),
    [anon_sym___forceinline] = ACTIONS(2214),
    [anon_sym_thread_local] = ACTIONS(2214),
    [anon_sym___thread] = ACTIONS(2214),
    [anon_sym_const] = ACTIONS(2214),
    [anon_sym_constexpr] = ACTIONS(2214),
    [anon_sym_volatile] = ACTIONS(2214),
    [anon_sym_restrict] = ACTIONS(2214),
    [anon_sym___restrict__] = ACTIONS(2214),
    [anon_sym__Atomic] = ACTIONS(2214),
    [anon_sym__Noreturn] = ACTIONS(2214),
    [anon_sym_noreturn] = ACTIONS(2214),
    [anon_sym__Nonnull] = ACTIONS(2214),
    [anon_sym_mutable] = ACTIONS(2214),
    [anon_sym_constinit] = ACTIONS(2214),
    [anon_sym_consteval] = ACTIONS(2214),
    [anon_sym___shared__] = ACTIONS(2214),
    [anon_sym___local__] = ACTIONS(2214),
    [anon_sym___constant__] = ACTIONS(2214),
    [anon_sym___managed__] = ACTIONS(2214),
    [anon_sym___grid_constant__] = ACTIONS(2214),
    [anon_sym_alignas] = ACTIONS(2214),
    [anon_sym__Alignas] = ACTIONS(2214),
    [sym_primitive_type] = ACTIONS(2214),
    [anon_sym_enum] = ACTIONS(2214),
    [anon_sym_class] = ACTIONS(2214),
    [anon_sym_struct] = ACTIONS(2214),
    [anon_sym_union] = ACTIONS(2214),
    [anon_sym_if] = ACTIONS(2214),
    [anon_sym_else] = ACTIONS(2214),
    [anon_sym_switch] = ACTIONS(2214),
    [anon_sym_case] = ACTIONS(2214),
    [anon_sym_default] = ACTIONS(2214),
    [anon_sym_while] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2214),
    [anon_sym_for] = ACTIONS(2214),
    [anon_sym_return] = ACTIONS(2214),
    [anon_sym_break] = ACTIONS(2214),
    [anon_sym_continue] = ACTIONS(2214),
    [anon_sym_goto] = ACTIONS(2214),
    [anon_sym___try] = ACTIONS(2214),
    [anon_sym___leave] = ACTIONS(2214),
    [anon_sym_not] = ACTIONS(2214),
    [anon_sym_compl] = ACTIONS(2214),
    [anon_sym_DASH_DASH] = ACTIONS(2216),
    [anon_sym_PLUS_PLUS] = ACTIONS(2216),
    [anon_sym_sizeof] = ACTIONS(2214),
    [anon_sym___alignof__] = ACTIONS(2214),
    [anon_sym___alignof] = ACTIONS(2214),
    [anon_sym__alignof] = ACTIONS(2214),
    [anon_sym_alignof] = ACTIONS(2214),
    [anon_sym__Alignof] = ACTIONS(2214),
    [anon_sym_offsetof] = ACTIONS(2214),
    [anon_sym__Generic] = ACTIONS(2214),
    [anon_sym_asm] = ACTIONS(2214),
    [anon_sym___asm__] = ACTIONS(2214),
    [anon_sym___asm] = ACTIONS(2214),
    [sym_number_literal] = ACTIONS(2216),
    [anon_sym_L_SQUOTE] = ACTIONS(2216),
    [anon_sym_u_SQUOTE] = ACTIONS(2216),
    [anon_sym_U_SQUOTE] = ACTIONS(2216),
    [anon_sym_u8_SQUOTE] = ACTIONS(2216),
    [anon_sym_SQUOTE] = ACTIONS(2216),
    [anon_sym_L_DQUOTE] = ACTIONS(2216),
    [anon_sym_u_DQUOTE] = ACTIONS(2216),
    [anon_sym_U_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8_DQUOTE] = ACTIONS(2216),
    [anon_sym_DQUOTE] = ACTIONS(2216),
    [sym_true] = ACTIONS(2214),
    [sym_false] = ACTIONS(2214),
    [anon_sym_NULL] = ACTIONS(2214),
    [anon_sym_nullptr] = ACTIONS(2214),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2214),
    [anon_sym_decltype] = ACTIONS(2214),
    [anon_sym_explicit] = ACTIONS(2214),
    [anon_sym_typename] = ACTIONS(2214),
    [anon_sym_template] = ACTIONS(2214),
    [anon_sym_operator] = ACTIONS(2214),
    [anon_sym_try] = ACTIONS(2214),
    [anon_sym_delete] = ACTIONS(2214),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_namespace] = ACTIONS(2214),
    [anon_sym_using] = ACTIONS(2214),
    [anon_sym_static_assert] = ACTIONS(2214),
    [anon_sym_concept] = ACTIONS(2214),
    [anon_sym_co_return] = ACTIONS(2214),
    [anon_sym_co_yield] = ACTIONS(2214),
    [anon_sym_R_DQUOTE] = ACTIONS(2216),
    [anon_sym_LR_DQUOTE] = ACTIONS(2216),
    [anon_sym_uR_DQUOTE] = ACTIONS(2216),
    [anon_sym_UR_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2216),
    [anon_sym_co_await] = ACTIONS(2214),
    [anon_sym_new] = ACTIONS(2214),
    [anon_sym_requires] = ACTIONS(2214),
    [sym_this] = ACTIONS(2214),
    [anon_sym___launch_bounds__] = ACTIONS(2214),
  },
  [STATE(359)] = {
    [ts_builtin_sym_end] = ACTIONS(2136),
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_include_token1] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym___device__] = ACTIONS(2134),
    [anon_sym___host__] = ACTIONS(2134),
    [anon_sym___global__] = ACTIONS(2134),
    [anon_sym___forceinline__] = ACTIONS(2134),
    [anon_sym___noinline__] = ACTIONS(2134),
    [anon_sym_virtual] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym___attribute] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym___cdecl] = ACTIONS(2134),
    [anon_sym___clrcall] = ACTIONS(2134),
    [anon_sym___stdcall] = ACTIONS(2134),
    [anon_sym___fastcall] = ACTIONS(2134),
    [anon_sym___thiscall] = ACTIONS(2134),
    [anon_sym___vectorcall] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym__Nonnull] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym___shared__] = ACTIONS(2134),
    [anon_sym___local__] = ACTIONS(2134),
    [anon_sym___constant__] = ACTIONS(2134),
    [anon_sym___managed__] = ACTIONS(2134),
    [anon_sym___grid_constant__] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_case] = ACTIONS(2134),
    [anon_sym_default] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [anon_sym___asm] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_namespace] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_concept] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym___launch_bounds__] = ACTIONS(2134),
  },
  [STATE(360)] = {
    [sym_catch_clause] = STATE(240),
    [aux_sym_constructor_try_statement_repeat1] = STATE(240),
    [ts_builtin_sym_end] = ACTIONS(1994),
    [sym_identifier] = ACTIONS(1992),
    [aux_sym_preproc_include_token1] = ACTIONS(1992),
    [aux_sym_preproc_def_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1992),
    [sym_preproc_directive] = ACTIONS(1992),
    [anon_sym_LPAREN2] = ACTIONS(1994),
    [anon_sym_BANG] = ACTIONS(1994),
    [anon_sym_TILDE] = ACTIONS(1994),
    [anon_sym_DASH] = ACTIONS(1992),
    [anon_sym_PLUS] = ACTIONS(1992),
    [anon_sym_STAR] = ACTIONS(1994),
    [anon_sym_AMP_AMP] = ACTIONS(1994),
    [anon_sym_AMP] = ACTIONS(1992),
    [anon_sym_SEMI] = ACTIONS(1994),
    [anon_sym___extension__] = ACTIONS(1992),
    [anon_sym_typedef] = ACTIONS(1992),
    [anon_sym___device__] = ACTIONS(1992),
    [anon_sym___host__] = ACTIONS(1992),
    [anon_sym___global__] = ACTIONS(1992),
    [anon_sym___forceinline__] = ACTIONS(1992),
    [anon_sym___noinline__] = ACTIONS(1992),
    [anon_sym_virtual] = ACTIONS(1992),
    [anon_sym_extern] = ACTIONS(1992),
    [anon_sym___attribute__] = ACTIONS(1992),
    [anon_sym___attribute] = ACTIONS(1992),
    [anon_sym_COLON_COLON] = ACTIONS(1994),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1994),
    [anon_sym___declspec] = ACTIONS(1992),
    [anon_sym___based] = ACTIONS(1992),
    [anon_sym___cdecl] = ACTIONS(1992),
    [anon_sym___clrcall] = ACTIONS(1992),
    [anon_sym___stdcall] = ACTIONS(1992),
    [anon_sym___fastcall] = ACTIONS(1992),
    [anon_sym___thiscall] = ACTIONS(1992),
    [anon_sym___vectorcall] = ACTIONS(1992),
    [anon_sym_LBRACE] = ACTIONS(1994),
    [anon_sym_signed] = ACTIONS(1992),
    [anon_sym_unsigned] = ACTIONS(1992),
    [anon_sym_long] = ACTIONS(1992),
    [anon_sym_short] = ACTIONS(1992),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_static] = ACTIONS(1992),
    [anon_sym_register] = ACTIONS(1992),
    [anon_sym_inline] = ACTIONS(1992),
    [anon_sym___inline] = ACTIONS(1992),
    [anon_sym___inline__] = ACTIONS(1992),
    [anon_sym___forceinline] = ACTIONS(1992),
    [anon_sym_thread_local] = ACTIONS(1992),
    [anon_sym___thread] = ACTIONS(1992),
    [anon_sym_const] = ACTIONS(1992),
    [anon_sym_constexpr] = ACTIONS(1992),
    [anon_sym_volatile] = ACTIONS(1992),
    [anon_sym_restrict] = ACTIONS(1992),
    [anon_sym___restrict__] = ACTIONS(1992),
    [anon_sym__Atomic] = ACTIONS(1992),
    [anon_sym__Noreturn] = ACTIONS(1992),
    [anon_sym_noreturn] = ACTIONS(1992),
    [anon_sym__Nonnull] = ACTIONS(1992),
    [anon_sym_mutable] = ACTIONS(1992),
    [anon_sym_constinit] = ACTIONS(1992),
    [anon_sym_consteval] = ACTIONS(1992),
    [anon_sym___shared__] = ACTIONS(1992),
    [anon_sym___local__] = ACTIONS(1992),
    [anon_sym___constant__] = ACTIONS(1992),
    [anon_sym___managed__] = ACTIONS(1992),
    [anon_sym___grid_constant__] = ACTIONS(1992),
    [anon_sym_alignas] = ACTIONS(1992),
    [anon_sym__Alignas] = ACTIONS(1992),
    [sym_primitive_type] = ACTIONS(1992),
    [anon_sym_enum] = ACTIONS(1992),
    [anon_sym_class] = ACTIONS(1992),
    [anon_sym_struct] = ACTIONS(1992),
    [anon_sym_union] = ACTIONS(1992),
    [anon_sym_if] = ACTIONS(1992),
    [anon_sym_switch] = ACTIONS(1992),
    [anon_sym_case] = ACTIONS(1992),
    [anon_sym_default] = ACTIONS(1992),
    [anon_sym_while] = ACTIONS(1992),
    [anon_sym_do] = ACTIONS(1992),
    [anon_sym_for] = ACTIONS(1992),
    [anon_sym_return] = ACTIONS(1992),
    [anon_sym_break] = ACTIONS(1992),
    [anon_sym_continue] = ACTIONS(1992),
    [anon_sym_goto] = ACTIONS(1992),
    [anon_sym_not] = ACTIONS(1992),
    [anon_sym_compl] = ACTIONS(1992),
    [anon_sym_DASH_DASH] = ACTIONS(1994),
    [anon_sym_PLUS_PLUS] = ACTIONS(1994),
    [anon_sym_sizeof] = ACTIONS(1992),
    [anon_sym___alignof__] = ACTIONS(1992),
    [anon_sym___alignof] = ACTIONS(1992),
    [anon_sym__alignof] = ACTIONS(1992),
    [anon_sym_alignof] = ACTIONS(1992),
    [anon_sym__Alignof] = ACTIONS(1992),
    [anon_sym_offsetof] = ACTIONS(1992),
    [anon_sym__Generic] = ACTIONS(1992),
    [anon_sym_asm] = ACTIONS(1992),
    [anon_sym___asm__] = ACTIONS(1992),
    [anon_sym___asm] = ACTIONS(1992),
    [sym_number_literal] = ACTIONS(1994),
    [anon_sym_L_SQUOTE] = ACTIONS(1994),
    [anon_sym_u_SQUOTE] = ACTIONS(1994),
    [anon_sym_U_SQUOTE] = ACTIONS(1994),
    [anon_sym_u8_SQUOTE] = ACTIONS(1994),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [anon_sym_L_DQUOTE] = ACTIONS(1994),
    [anon_sym_u_DQUOTE] = ACTIONS(1994),
    [anon_sym_U_DQUOTE] = ACTIONS(1994),
    [anon_sym_u8_DQUOTE] = ACTIONS(1994),
    [anon_sym_DQUOTE] = ACTIONS(1994),
    [sym_true] = ACTIONS(1992),
    [sym_false] = ACTIONS(1992),
    [anon_sym_NULL] = ACTIONS(1992),
    [anon_sym_nullptr] = ACTIONS(1992),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1992),
    [anon_sym_decltype] = ACTIONS(1992),
    [anon_sym_explicit] = ACTIONS(1992),
    [anon_sym_typename] = ACTIONS(1992),
    [anon_sym_template] = ACTIONS(1992),
    [anon_sym_operator] = ACTIONS(1992),
    [anon_sym_try] = ACTIONS(1992),
    [anon_sym_delete] = ACTIONS(1992),
    [anon_sym_throw] = ACTIONS(1992),
    [anon_sym_namespace] = ACTIONS(1992),
    [anon_sym_using] = ACTIONS(1992),
    [anon_sym_static_assert] = ACTIONS(1992),
    [anon_sym_concept] = ACTIONS(1992),
    [anon_sym_co_return] = ACTIONS(1992),
    [anon_sym_co_yield] = ACTIONS(1992),
    [anon_sym_catch] = ACTIONS(2589),
    [anon_sym_R_DQUOTE] = ACTIONS(1994),
    [anon_sym_LR_DQUOTE] = ACTIONS(1994),
    [anon_sym_uR_DQUOTE] = ACTIONS(1994),
    [anon_sym_UR_DQUOTE] = ACTIONS(1994),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1994),
    [anon_sym_co_await] = ACTIONS(1992),
    [anon_sym_new] = ACTIONS(1992),
    [anon_sym_requires] = ACTIONS(1992),
    [sym_this] = ACTIONS(1992),
    [anon_sym___launch_bounds__] = ACTIONS(1992),
  },
  [STATE(361)] = {
    [ts_builtin_sym_end] = ACTIONS(2030),
    [sym_identifier] = ACTIONS(2028),
    [aux_sym_preproc_include_token1] = ACTIONS(2028),
    [aux_sym_preproc_def_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2028),
    [sym_preproc_directive] = ACTIONS(2028),
    [anon_sym_LPAREN2] = ACTIONS(2030),
    [anon_sym_BANG] = ACTIONS(2030),
    [anon_sym_TILDE] = ACTIONS(2030),
    [anon_sym_DASH] = ACTIONS(2028),
    [anon_sym_PLUS] = ACTIONS(2028),
    [anon_sym_STAR] = ACTIONS(2030),
    [anon_sym_AMP_AMP] = ACTIONS(2030),
    [anon_sym_AMP] = ACTIONS(2028),
    [anon_sym_SEMI] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(2028),
    [anon_sym_typedef] = ACTIONS(2028),
    [anon_sym___device__] = ACTIONS(2028),
    [anon_sym___host__] = ACTIONS(2028),
    [anon_sym___global__] = ACTIONS(2028),
    [anon_sym___forceinline__] = ACTIONS(2028),
    [anon_sym___noinline__] = ACTIONS(2028),
    [anon_sym_virtual] = ACTIONS(2028),
    [anon_sym_extern] = ACTIONS(2028),
    [anon_sym___attribute__] = ACTIONS(2028),
    [anon_sym___attribute] = ACTIONS(2028),
    [anon_sym_COLON_COLON] = ACTIONS(2030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2030),
    [anon_sym___declspec] = ACTIONS(2028),
    [anon_sym___based] = ACTIONS(2028),
    [anon_sym___cdecl] = ACTIONS(2028),
    [anon_sym___clrcall] = ACTIONS(2028),
    [anon_sym___stdcall] = ACTIONS(2028),
    [anon_sym___fastcall] = ACTIONS(2028),
    [anon_sym___thiscall] = ACTIONS(2028),
    [anon_sym___vectorcall] = ACTIONS(2028),
    [anon_sym_LBRACE] = ACTIONS(2030),
    [anon_sym_signed] = ACTIONS(2028),
    [anon_sym_unsigned] = ACTIONS(2028),
    [anon_sym_long] = ACTIONS(2028),
    [anon_sym_short] = ACTIONS(2028),
    [anon_sym_LBRACK] = ACTIONS(2028),
    [anon_sym_static] = ACTIONS(2028),
    [anon_sym_register] = ACTIONS(2028),
    [anon_sym_inline] = ACTIONS(2028),
    [anon_sym___inline] = ACTIONS(2028),
    [anon_sym___inline__] = ACTIONS(2028),
    [anon_sym___forceinline] = ACTIONS(2028),
    [anon_sym_thread_local] = ACTIONS(2028),
    [anon_sym___thread] = ACTIONS(2028),
    [anon_sym_const] = ACTIONS(2028),
    [anon_sym_constexpr] = ACTIONS(2028),
    [anon_sym_volatile] = ACTIONS(2028),
    [anon_sym_restrict] = ACTIONS(2028),
    [anon_sym___restrict__] = ACTIONS(2028),
    [anon_sym__Atomic] = ACTIONS(2028),
    [anon_sym__Noreturn] = ACTIONS(2028),
    [anon_sym_noreturn] = ACTIONS(2028),
    [anon_sym__Nonnull] = ACTIONS(2028),
    [anon_sym_mutable] = ACTIONS(2028),
    [anon_sym_constinit] = ACTIONS(2028),
    [anon_sym_consteval] = ACTIONS(2028),
    [anon_sym___shared__] = ACTIONS(2028),
    [anon_sym___local__] = ACTIONS(2028),
    [anon_sym___constant__] = ACTIONS(2028),
    [anon_sym___managed__] = ACTIONS(2028),
    [anon_sym___grid_constant__] = ACTIONS(2028),
    [anon_sym_alignas] = ACTIONS(2028),
    [anon_sym__Alignas] = ACTIONS(2028),
    [sym_primitive_type] = ACTIONS(2028),
    [anon_sym_enum] = ACTIONS(2028),
    [anon_sym_class] = ACTIONS(2028),
    [anon_sym_struct] = ACTIONS(2028),
    [anon_sym_union] = ACTIONS(2028),
    [anon_sym_if] = ACTIONS(2028),
    [anon_sym_else] = ACTIONS(2028),
    [anon_sym_switch] = ACTIONS(2028),
    [anon_sym_case] = ACTIONS(2028),
    [anon_sym_default] = ACTIONS(2028),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_do] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2028),
    [anon_sym_return] = ACTIONS(2028),
    [anon_sym_break] = ACTIONS(2028),
    [anon_sym_continue] = ACTIONS(2028),
    [anon_sym_goto] = ACTIONS(2028),
    [anon_sym___try] = ACTIONS(2028),
    [anon_sym___leave] = ACTIONS(2028),
    [anon_sym_not] = ACTIONS(2028),
    [anon_sym_compl] = ACTIONS(2028),
    [anon_sym_DASH_DASH] = ACTIONS(2030),
    [anon_sym_PLUS_PLUS] = ACTIONS(2030),
    [anon_sym_sizeof] = ACTIONS(2028),
    [anon_sym___alignof__] = ACTIONS(2028),
    [anon_sym___alignof] = ACTIONS(2028),
    [anon_sym__alignof] = ACTIONS(2028),
    [anon_sym_alignof] = ACTIONS(2028),
    [anon_sym__Alignof] = ACTIONS(2028),
    [anon_sym_offsetof] = ACTIONS(2028),
    [anon_sym__Generic] = ACTIONS(2028),
    [anon_sym_asm] = ACTIONS(2028),
    [anon_sym___asm__] = ACTIONS(2028),
    [anon_sym___asm] = ACTIONS(2028),
    [sym_number_literal] = ACTIONS(2030),
    [anon_sym_L_SQUOTE] = ACTIONS(2030),
    [anon_sym_u_SQUOTE] = ACTIONS(2030),
    [anon_sym_U_SQUOTE] = ACTIONS(2030),
    [anon_sym_u8_SQUOTE] = ACTIONS(2030),
    [anon_sym_SQUOTE] = ACTIONS(2030),
    [anon_sym_L_DQUOTE] = ACTIONS(2030),
    [anon_sym_u_DQUOTE] = ACTIONS(2030),
    [anon_sym_U_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8_DQUOTE] = ACTIONS(2030),
    [anon_sym_DQUOTE] = ACTIONS(2030),
    [sym_true] = ACTIONS(2028),
    [sym_false] = ACTIONS(2028),
    [anon_sym_NULL] = ACTIONS(2028),
    [anon_sym_nullptr] = ACTIONS(2028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2028),
    [anon_sym_decltype] = ACTIONS(2028),
    [anon_sym_explicit] = ACTIONS(2028),
    [anon_sym_typename] = ACTIONS(2028),
    [anon_sym_template] = ACTIONS(2028),
    [anon_sym_operator] = ACTIONS(2028),
    [anon_sym_try] = ACTIONS(2028),
    [anon_sym_delete] = ACTIONS(2028),
    [anon_sym_throw] = ACTIONS(2028),
    [anon_sym_namespace] = ACTIONS(2028),
    [anon_sym_using] = ACTIONS(2028),
    [anon_sym_static_assert] = ACTIONS(2028),
    [anon_sym_concept] = ACTIONS(2028),
    [anon_sym_co_return] = ACTIONS(2028),
    [anon_sym_co_yield] = ACTIONS(2028),
    [anon_sym_R_DQUOTE] = ACTIONS(2030),
    [anon_sym_LR_DQUOTE] = ACTIONS(2030),
    [anon_sym_uR_DQUOTE] = ACTIONS(2030),
    [anon_sym_UR_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2030),
    [anon_sym_co_await] = ACTIONS(2028),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_requires] = ACTIONS(2028),
    [sym_this] = ACTIONS(2028),
    [anon_sym___launch_bounds__] = ACTIONS(2028),
  },
  [STATE(362)] = {
    [sym_identifier] = ACTIONS(2036),
    [aux_sym_preproc_include_token1] = ACTIONS(2036),
    [aux_sym_preproc_def_token1] = ACTIONS(2036),
    [aux_sym_preproc_if_token1] = ACTIONS(2036),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2036),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2036),
    [sym_preproc_directive] = ACTIONS(2036),
    [anon_sym_LPAREN2] = ACTIONS(2038),
    [anon_sym_BANG] = ACTIONS(2038),
    [anon_sym_TILDE] = ACTIONS(2038),
    [anon_sym_DASH] = ACTIONS(2036),
    [anon_sym_PLUS] = ACTIONS(2036),
    [anon_sym_STAR] = ACTIONS(2038),
    [anon_sym_AMP_AMP] = ACTIONS(2038),
    [anon_sym_AMP] = ACTIONS(2036),
    [anon_sym_SEMI] = ACTIONS(2038),
    [anon_sym___extension__] = ACTIONS(2036),
    [anon_sym_typedef] = ACTIONS(2036),
    [anon_sym___device__] = ACTIONS(2036),
    [anon_sym___host__] = ACTIONS(2036),
    [anon_sym___global__] = ACTIONS(2036),
    [anon_sym___forceinline__] = ACTIONS(2036),
    [anon_sym___noinline__] = ACTIONS(2036),
    [anon_sym_virtual] = ACTIONS(2036),
    [anon_sym_extern] = ACTIONS(2036),
    [anon_sym___attribute__] = ACTIONS(2036),
    [anon_sym___attribute] = ACTIONS(2036),
    [anon_sym_COLON_COLON] = ACTIONS(2038),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2038),
    [anon_sym___declspec] = ACTIONS(2036),
    [anon_sym___based] = ACTIONS(2036),
    [anon_sym___cdecl] = ACTIONS(2036),
    [anon_sym___clrcall] = ACTIONS(2036),
    [anon_sym___stdcall] = ACTIONS(2036),
    [anon_sym___fastcall] = ACTIONS(2036),
    [anon_sym___thiscall] = ACTIONS(2036),
    [anon_sym___vectorcall] = ACTIONS(2036),
    [anon_sym_LBRACE] = ACTIONS(2038),
    [anon_sym_RBRACE] = ACTIONS(2038),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(2036),
    [anon_sym_static] = ACTIONS(2036),
    [anon_sym_register] = ACTIONS(2036),
    [anon_sym_inline] = ACTIONS(2036),
    [anon_sym___inline] = ACTIONS(2036),
    [anon_sym___inline__] = ACTIONS(2036),
    [anon_sym___forceinline] = ACTIONS(2036),
    [anon_sym_thread_local] = ACTIONS(2036),
    [anon_sym___thread] = ACTIONS(2036),
    [anon_sym_const] = ACTIONS(2036),
    [anon_sym_constexpr] = ACTIONS(2036),
    [anon_sym_volatile] = ACTIONS(2036),
    [anon_sym_restrict] = ACTIONS(2036),
    [anon_sym___restrict__] = ACTIONS(2036),
    [anon_sym__Atomic] = ACTIONS(2036),
    [anon_sym__Noreturn] = ACTIONS(2036),
    [anon_sym_noreturn] = ACTIONS(2036),
    [anon_sym__Nonnull] = ACTIONS(2036),
    [anon_sym_mutable] = ACTIONS(2036),
    [anon_sym_constinit] = ACTIONS(2036),
    [anon_sym_consteval] = ACTIONS(2036),
    [anon_sym___shared__] = ACTIONS(2036),
    [anon_sym___local__] = ACTIONS(2036),
    [anon_sym___constant__] = ACTIONS(2036),
    [anon_sym___managed__] = ACTIONS(2036),
    [anon_sym___grid_constant__] = ACTIONS(2036),
    [anon_sym_alignas] = ACTIONS(2036),
    [anon_sym__Alignas] = ACTIONS(2036),
    [sym_primitive_type] = ACTIONS(2036),
    [anon_sym_enum] = ACTIONS(2036),
    [anon_sym_class] = ACTIONS(2036),
    [anon_sym_struct] = ACTIONS(2036),
    [anon_sym_union] = ACTIONS(2036),
    [anon_sym_if] = ACTIONS(2036),
    [anon_sym_else] = ACTIONS(2036),
    [anon_sym_switch] = ACTIONS(2036),
    [anon_sym_case] = ACTIONS(2036),
    [anon_sym_default] = ACTIONS(2036),
    [anon_sym_while] = ACTIONS(2036),
    [anon_sym_do] = ACTIONS(2036),
    [anon_sym_for] = ACTIONS(2036),
    [anon_sym_return] = ACTIONS(2036),
    [anon_sym_break] = ACTIONS(2036),
    [anon_sym_continue] = ACTIONS(2036),
    [anon_sym_goto] = ACTIONS(2036),
    [anon_sym___try] = ACTIONS(2036),
    [anon_sym___leave] = ACTIONS(2036),
    [anon_sym_not] = ACTIONS(2036),
    [anon_sym_compl] = ACTIONS(2036),
    [anon_sym_DASH_DASH] = ACTIONS(2038),
    [anon_sym_PLUS_PLUS] = ACTIONS(2038),
    [anon_sym_sizeof] = ACTIONS(2036),
    [anon_sym___alignof__] = ACTIONS(2036),
    [anon_sym___alignof] = ACTIONS(2036),
    [anon_sym__alignof] = ACTIONS(2036),
    [anon_sym_alignof] = ACTIONS(2036),
    [anon_sym__Alignof] = ACTIONS(2036),
    [anon_sym_offsetof] = ACTIONS(2036),
    [anon_sym__Generic] = ACTIONS(2036),
    [anon_sym_asm] = ACTIONS(2036),
    [anon_sym___asm__] = ACTIONS(2036),
    [anon_sym___asm] = ACTIONS(2036),
    [sym_number_literal] = ACTIONS(2038),
    [anon_sym_L_SQUOTE] = ACTIONS(2038),
    [anon_sym_u_SQUOTE] = ACTIONS(2038),
    [anon_sym_U_SQUOTE] = ACTIONS(2038),
    [anon_sym_u8_SQUOTE] = ACTIONS(2038),
    [anon_sym_SQUOTE] = ACTIONS(2038),
    [anon_sym_L_DQUOTE] = ACTIONS(2038),
    [anon_sym_u_DQUOTE] = ACTIONS(2038),
    [anon_sym_U_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8_DQUOTE] = ACTIONS(2038),
    [anon_sym_DQUOTE] = ACTIONS(2038),
    [sym_true] = ACTIONS(2036),
    [sym_false] = ACTIONS(2036),
    [anon_sym_NULL] = ACTIONS(2036),
    [anon_sym_nullptr] = ACTIONS(2036),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2036),
    [anon_sym_decltype] = ACTIONS(2036),
    [anon_sym_explicit] = ACTIONS(2036),
    [anon_sym_typename] = ACTIONS(2036),
    [anon_sym_template] = ACTIONS(2036),
    [anon_sym_operator] = ACTIONS(2036),
    [anon_sym_try] = ACTIONS(2036),
    [anon_sym_delete] = ACTIONS(2036),
    [anon_sym_throw] = ACTIONS(2036),
    [anon_sym_namespace] = ACTIONS(2036),
    [anon_sym_using] = ACTIONS(2036),
    [anon_sym_static_assert] = ACTIONS(2036),
    [anon_sym_concept] = ACTIONS(2036),
    [anon_sym_co_return] = ACTIONS(2036),
    [anon_sym_co_yield] = ACTIONS(2036),
    [anon_sym_R_DQUOTE] = ACTIONS(2038),
    [anon_sym_LR_DQUOTE] = ACTIONS(2038),
    [anon_sym_uR_DQUOTE] = ACTIONS(2038),
    [anon_sym_UR_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2038),
    [anon_sym_co_await] = ACTIONS(2036),
    [anon_sym_new] = ACTIONS(2036),
    [anon_sym_requires] = ACTIONS(2036),
    [sym_this] = ACTIONS(2036),
    [anon_sym___launch_bounds__] = ACTIONS(2036),
  },
  [STATE(363)] = {
    [sym_identifier] = ACTIONS(2020),
    [aux_sym_preproc_include_token1] = ACTIONS(2020),
    [aux_sym_preproc_def_token1] = ACTIONS(2020),
    [aux_sym_preproc_if_token1] = ACTIONS(2020),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2020),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2020),
    [sym_preproc_directive] = ACTIONS(2020),
    [anon_sym_LPAREN2] = ACTIONS(2022),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2020),
    [anon_sym_PLUS] = ACTIONS(2020),
    [anon_sym_STAR] = ACTIONS(2022),
    [anon_sym_AMP_AMP] = ACTIONS(2022),
    [anon_sym_AMP] = ACTIONS(2020),
    [anon_sym_SEMI] = ACTIONS(2022),
    [anon_sym___extension__] = ACTIONS(2020),
    [anon_sym_typedef] = ACTIONS(2020),
    [anon_sym___device__] = ACTIONS(2020),
    [anon_sym___host__] = ACTIONS(2020),
    [anon_sym___global__] = ACTIONS(2020),
    [anon_sym___forceinline__] = ACTIONS(2020),
    [anon_sym___noinline__] = ACTIONS(2020),
    [anon_sym_virtual] = ACTIONS(2020),
    [anon_sym_extern] = ACTIONS(2020),
    [anon_sym___attribute__] = ACTIONS(2020),
    [anon_sym___attribute] = ACTIONS(2020),
    [anon_sym_COLON_COLON] = ACTIONS(2022),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2022),
    [anon_sym___declspec] = ACTIONS(2020),
    [anon_sym___based] = ACTIONS(2020),
    [anon_sym___cdecl] = ACTIONS(2020),
    [anon_sym___clrcall] = ACTIONS(2020),
    [anon_sym___stdcall] = ACTIONS(2020),
    [anon_sym___fastcall] = ACTIONS(2020),
    [anon_sym___thiscall] = ACTIONS(2020),
    [anon_sym___vectorcall] = ACTIONS(2020),
    [anon_sym_LBRACE] = ACTIONS(2022),
    [anon_sym_RBRACE] = ACTIONS(2022),
    [anon_sym_signed] = ACTIONS(2020),
    [anon_sym_unsigned] = ACTIONS(2020),
    [anon_sym_long] = ACTIONS(2020),
    [anon_sym_short] = ACTIONS(2020),
    [anon_sym_LBRACK] = ACTIONS(2020),
    [anon_sym_static] = ACTIONS(2020),
    [anon_sym_register] = ACTIONS(2020),
    [anon_sym_inline] = ACTIONS(2020),
    [anon_sym___inline] = ACTIONS(2020),
    [anon_sym___inline__] = ACTIONS(2020),
    [anon_sym___forceinline] = ACTIONS(2020),
    [anon_sym_thread_local] = ACTIONS(2020),
    [anon_sym___thread] = ACTIONS(2020),
    [anon_sym_const] = ACTIONS(2020),
    [anon_sym_constexpr] = ACTIONS(2020),
    [anon_sym_volatile] = ACTIONS(2020),
    [anon_sym_restrict] = ACTIONS(2020),
    [anon_sym___restrict__] = ACTIONS(2020),
    [anon_sym__Atomic] = ACTIONS(2020),
    [anon_sym__Noreturn] = ACTIONS(2020),
    [anon_sym_noreturn] = ACTIONS(2020),
    [anon_sym__Nonnull] = ACTIONS(2020),
    [anon_sym_mutable] = ACTIONS(2020),
    [anon_sym_constinit] = ACTIONS(2020),
    [anon_sym_consteval] = ACTIONS(2020),
    [anon_sym___shared__] = ACTIONS(2020),
    [anon_sym___local__] = ACTIONS(2020),
    [anon_sym___constant__] = ACTIONS(2020),
    [anon_sym___managed__] = ACTIONS(2020),
    [anon_sym___grid_constant__] = ACTIONS(2020),
    [anon_sym_alignas] = ACTIONS(2020),
    [anon_sym__Alignas] = ACTIONS(2020),
    [sym_primitive_type] = ACTIONS(2020),
    [anon_sym_enum] = ACTIONS(2020),
    [anon_sym_class] = ACTIONS(2020),
    [anon_sym_struct] = ACTIONS(2020),
    [anon_sym_union] = ACTIONS(2020),
    [anon_sym_if] = ACTIONS(2020),
    [anon_sym_else] = ACTIONS(2020),
    [anon_sym_switch] = ACTIONS(2020),
    [anon_sym_case] = ACTIONS(2020),
    [anon_sym_default] = ACTIONS(2020),
    [anon_sym_while] = ACTIONS(2020),
    [anon_sym_do] = ACTIONS(2020),
    [anon_sym_for] = ACTIONS(2020),
    [anon_sym_return] = ACTIONS(2020),
    [anon_sym_break] = ACTIONS(2020),
    [anon_sym_continue] = ACTIONS(2020),
    [anon_sym_goto] = ACTIONS(2020),
    [anon_sym___try] = ACTIONS(2020),
    [anon_sym___leave] = ACTIONS(2020),
    [anon_sym_not] = ACTIONS(2020),
    [anon_sym_compl] = ACTIONS(2020),
    [anon_sym_DASH_DASH] = ACTIONS(2022),
    [anon_sym_PLUS_PLUS] = ACTIONS(2022),
    [anon_sym_sizeof] = ACTIONS(2020),
    [anon_sym___alignof__] = ACTIONS(2020),
    [anon_sym___alignof] = ACTIONS(2020),
    [anon_sym__alignof] = ACTIONS(2020),
    [anon_sym_alignof] = ACTIONS(2020),
    [anon_sym__Alignof] = ACTIONS(2020),
    [anon_sym_offsetof] = ACTIONS(2020),
    [anon_sym__Generic] = ACTIONS(2020),
    [anon_sym_asm] = ACTIONS(2020),
    [anon_sym___asm__] = ACTIONS(2020),
    [anon_sym___asm] = ACTIONS(2020),
    [sym_number_literal] = ACTIONS(2022),
    [anon_sym_L_SQUOTE] = ACTIONS(2022),
    [anon_sym_u_SQUOTE] = ACTIONS(2022),
    [anon_sym_U_SQUOTE] = ACTIONS(2022),
    [anon_sym_u8_SQUOTE] = ACTIONS(2022),
    [anon_sym_SQUOTE] = ACTIONS(2022),
    [anon_sym_L_DQUOTE] = ACTIONS(2022),
    [anon_sym_u_DQUOTE] = ACTIONS(2022),
    [anon_sym_U_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8_DQUOTE] = ACTIONS(2022),
    [anon_sym_DQUOTE] = ACTIONS(2022),
    [sym_true] = ACTIONS(2020),
    [sym_false] = ACTIONS(2020),
    [anon_sym_NULL] = ACTIONS(2020),
    [anon_sym_nullptr] = ACTIONS(2020),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2020),
    [anon_sym_decltype] = ACTIONS(2020),
    [anon_sym_explicit] = ACTIONS(2020),
    [anon_sym_typename] = ACTIONS(2020),
    [anon_sym_template] = ACTIONS(2020),
    [anon_sym_operator] = ACTIONS(2020),
    [anon_sym_try] = ACTIONS(2020),
    [anon_sym_delete] = ACTIONS(2020),
    [anon_sym_throw] = ACTIONS(2020),
    [anon_sym_namespace] = ACTIONS(2020),
    [anon_sym_using] = ACTIONS(2020),
    [anon_sym_static_assert] = ACTIONS(2020),
    [anon_sym_concept] = ACTIONS(2020),
    [anon_sym_co_return] = ACTIONS(2020),
    [anon_sym_co_yield] = ACTIONS(2020),
    [anon_sym_R_DQUOTE] = ACTIONS(2022),
    [anon_sym_LR_DQUOTE] = ACTIONS(2022),
    [anon_sym_uR_DQUOTE] = ACTIONS(2022),
    [anon_sym_UR_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2022),
    [anon_sym_co_await] = ACTIONS(2020),
    [anon_sym_new] = ACTIONS(2020),
    [anon_sym_requires] = ACTIONS(2020),
    [sym_this] = ACTIONS(2020),
    [anon_sym___launch_bounds__] = ACTIONS(2020),
  },
  [STATE(364)] = {
    [sym_identifier] = ACTIONS(2166),
    [aux_sym_preproc_include_token1] = ACTIONS(2166),
    [aux_sym_preproc_def_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2166),
    [sym_preproc_directive] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP_AMP] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2166),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym___device__] = ACTIONS(2166),
    [anon_sym___host__] = ACTIONS(2166),
    [anon_sym___global__] = ACTIONS(2166),
    [anon_sym___forceinline__] = ACTIONS(2166),
    [anon_sym___noinline__] = ACTIONS(2166),
    [anon_sym_virtual] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym___attribute] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym___based] = ACTIONS(2166),
    [anon_sym___cdecl] = ACTIONS(2166),
    [anon_sym___clrcall] = ACTIONS(2166),
    [anon_sym___stdcall] = ACTIONS(2166),
    [anon_sym___fastcall] = ACTIONS(2166),
    [anon_sym___thiscall] = ACTIONS(2166),
    [anon_sym___vectorcall] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_RBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym__Nonnull] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym___shared__] = ACTIONS(2166),
    [anon_sym___local__] = ACTIONS(2166),
    [anon_sym___constant__] = ACTIONS(2166),
    [anon_sym___managed__] = ACTIONS(2166),
    [anon_sym___grid_constant__] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym_default] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [anon_sym___asm] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [anon_sym_explicit] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_operator] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_namespace] = ACTIONS(2166),
    [anon_sym_using] = ACTIONS(2166),
    [anon_sym_static_assert] = ACTIONS(2166),
    [anon_sym_concept] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym___launch_bounds__] = ACTIONS(2166),
  },
  [STATE(365)] = {
    [sym_identifier] = ACTIONS(2078),
    [aux_sym_preproc_include_token1] = ACTIONS(2078),
    [aux_sym_preproc_def_token1] = ACTIONS(2078),
    [aux_sym_preproc_if_token1] = ACTIONS(2078),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2078),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2078),
    [sym_preproc_directive] = ACTIONS(2078),
    [anon_sym_LPAREN2] = ACTIONS(2083),
    [anon_sym_BANG] = ACTIONS(2083),
    [anon_sym_TILDE] = ACTIONS(2083),
    [anon_sym_DASH] = ACTIONS(2078),
    [anon_sym_PLUS] = ACTIONS(2078),
    [anon_sym_STAR] = ACTIONS(2083),
    [anon_sym_AMP_AMP] = ACTIONS(2083),
    [anon_sym_AMP] = ACTIONS(2078),
    [anon_sym_SEMI] = ACTIONS(2083),
    [anon_sym___extension__] = ACTIONS(2078),
    [anon_sym_typedef] = ACTIONS(2078),
    [anon_sym___device__] = ACTIONS(2078),
    [anon_sym___host__] = ACTIONS(2078),
    [anon_sym___global__] = ACTIONS(2078),
    [anon_sym___forceinline__] = ACTIONS(2078),
    [anon_sym___noinline__] = ACTIONS(2078),
    [anon_sym_virtual] = ACTIONS(2078),
    [anon_sym_extern] = ACTIONS(2078),
    [anon_sym___attribute__] = ACTIONS(2078),
    [anon_sym___attribute] = ACTIONS(2078),
    [anon_sym_COLON_COLON] = ACTIONS(2083),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2083),
    [anon_sym___declspec] = ACTIONS(2078),
    [anon_sym___based] = ACTIONS(2078),
    [anon_sym___cdecl] = ACTIONS(2078),
    [anon_sym___clrcall] = ACTIONS(2078),
    [anon_sym___stdcall] = ACTIONS(2078),
    [anon_sym___fastcall] = ACTIONS(2078),
    [anon_sym___thiscall] = ACTIONS(2078),
    [anon_sym___vectorcall] = ACTIONS(2078),
    [anon_sym_LBRACE] = ACTIONS(2083),
    [anon_sym_RBRACE] = ACTIONS(2083),
    [anon_sym_signed] = ACTIONS(2078),
    [anon_sym_unsigned] = ACTIONS(2078),
    [anon_sym_long] = ACTIONS(2078),
    [anon_sym_short] = ACTIONS(2078),
    [anon_sym_LBRACK] = ACTIONS(2078),
    [anon_sym_static] = ACTIONS(2078),
    [anon_sym_register] = ACTIONS(2078),
    [anon_sym_inline] = ACTIONS(2078),
    [anon_sym___inline] = ACTIONS(2078),
    [anon_sym___inline__] = ACTIONS(2078),
    [anon_sym___forceinline] = ACTIONS(2078),
    [anon_sym_thread_local] = ACTIONS(2078),
    [anon_sym___thread] = ACTIONS(2078),
    [anon_sym_const] = ACTIONS(2078),
    [anon_sym_constexpr] = ACTIONS(2078),
    [anon_sym_volatile] = ACTIONS(2078),
    [anon_sym_restrict] = ACTIONS(2078),
    [anon_sym___restrict__] = ACTIONS(2078),
    [anon_sym__Atomic] = ACTIONS(2078),
    [anon_sym__Noreturn] = ACTIONS(2078),
    [anon_sym_noreturn] = ACTIONS(2078),
    [anon_sym__Nonnull] = ACTIONS(2078),
    [anon_sym_mutable] = ACTIONS(2078),
    [anon_sym_constinit] = ACTIONS(2078),
    [anon_sym_consteval] = ACTIONS(2078),
    [anon_sym___shared__] = ACTIONS(2078),
    [anon_sym___local__] = ACTIONS(2078),
    [anon_sym___constant__] = ACTIONS(2078),
    [anon_sym___managed__] = ACTIONS(2078),
    [anon_sym___grid_constant__] = ACTIONS(2078),
    [anon_sym_alignas] = ACTIONS(2078),
    [anon_sym__Alignas] = ACTIONS(2078),
    [sym_primitive_type] = ACTIONS(2078),
    [anon_sym_enum] = ACTIONS(2078),
    [anon_sym_class] = ACTIONS(2078),
    [anon_sym_struct] = ACTIONS(2078),
    [anon_sym_union] = ACTIONS(2078),
    [anon_sym_if] = ACTIONS(2078),
    [anon_sym_else] = ACTIONS(2078),
    [anon_sym_switch] = ACTIONS(2078),
    [anon_sym_case] = ACTIONS(2078),
    [anon_sym_default] = ACTIONS(2078),
    [anon_sym_while] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(2078),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_return] = ACTIONS(2078),
    [anon_sym_break] = ACTIONS(2078),
    [anon_sym_continue] = ACTIONS(2078),
    [anon_sym_goto] = ACTIONS(2078),
    [anon_sym___try] = ACTIONS(2078),
    [anon_sym___leave] = ACTIONS(2078),
    [anon_sym_not] = ACTIONS(2078),
    [anon_sym_compl] = ACTIONS(2078),
    [anon_sym_DASH_DASH] = ACTIONS(2083),
    [anon_sym_PLUS_PLUS] = ACTIONS(2083),
    [anon_sym_sizeof] = ACTIONS(2078),
    [anon_sym___alignof__] = ACTIONS(2078),
    [anon_sym___alignof] = ACTIONS(2078),
    [anon_sym__alignof] = ACTIONS(2078),
    [anon_sym_alignof] = ACTIONS(2078),
    [anon_sym__Alignof] = ACTIONS(2078),
    [anon_sym_offsetof] = ACTIONS(2078),
    [anon_sym__Generic] = ACTIONS(2078),
    [anon_sym_asm] = ACTIONS(2078),
    [anon_sym___asm__] = ACTIONS(2078),
    [anon_sym___asm] = ACTIONS(2078),
    [sym_number_literal] = ACTIONS(2083),
    [anon_sym_L_SQUOTE] = ACTIONS(2083),
    [anon_sym_u_SQUOTE] = ACTIONS(2083),
    [anon_sym_U_SQUOTE] = ACTIONS(2083),
    [anon_sym_u8_SQUOTE] = ACTIONS(2083),
    [anon_sym_SQUOTE] = ACTIONS(2083),
    [anon_sym_L_DQUOTE] = ACTIONS(2083),
    [anon_sym_u_DQUOTE] = ACTIONS(2083),
    [anon_sym_U_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8_DQUOTE] = ACTIONS(2083),
    [anon_sym_DQUOTE] = ACTIONS(2083),
    [sym_true] = ACTIONS(2078),
    [sym_false] = ACTIONS(2078),
    [anon_sym_NULL] = ACTIONS(2078),
    [anon_sym_nullptr] = ACTIONS(2078),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2078),
    [anon_sym_decltype] = ACTIONS(2078),
    [anon_sym_explicit] = ACTIONS(2078),
    [anon_sym_typename] = ACTIONS(2078),
    [anon_sym_template] = ACTIONS(2078),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2078),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_namespace] = ACTIONS(2078),
    [anon_sym_using] = ACTIONS(2078),
    [anon_sym_static_assert] = ACTIONS(2078),
    [anon_sym_concept] = ACTIONS(2078),
    [anon_sym_co_return] = ACTIONS(2078),
    [anon_sym_co_yield] = ACTIONS(2078),
    [anon_sym_R_DQUOTE] = ACTIONS(2083),
    [anon_sym_LR_DQUOTE] = ACTIONS(2083),
    [anon_sym_uR_DQUOTE] = ACTIONS(2083),
    [anon_sym_UR_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2083),
    [anon_sym_co_await] = ACTIONS(2078),
    [anon_sym_new] = ACTIONS(2078),
    [anon_sym_requires] = ACTIONS(2078),
    [sym_this] = ACTIONS(2078),
    [anon_sym___launch_bounds__] = ACTIONS(2078),
  },
  [STATE(366)] = {
    [ts_builtin_sym_end] = ACTIONS(2132),
    [sym_identifier] = ACTIONS(2130),
    [aux_sym_preproc_include_token1] = ACTIONS(2130),
    [aux_sym_preproc_def_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2130),
    [sym_preproc_directive] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP_AMP] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2130),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym___device__] = ACTIONS(2130),
    [anon_sym___host__] = ACTIONS(2130),
    [anon_sym___global__] = ACTIONS(2130),
    [anon_sym___forceinline__] = ACTIONS(2130),
    [anon_sym___noinline__] = ACTIONS(2130),
    [anon_sym_virtual] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym___attribute] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym___based] = ACTIONS(2130),
    [anon_sym___cdecl] = ACTIONS(2130),
    [anon_sym___clrcall] = ACTIONS(2130),
    [anon_sym___stdcall] = ACTIONS(2130),
    [anon_sym___fastcall] = ACTIONS(2130),
    [anon_sym___thiscall] = ACTIONS(2130),
    [anon_sym___vectorcall] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym__Nonnull] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym___shared__] = ACTIONS(2130),
    [anon_sym___local__] = ACTIONS(2130),
    [anon_sym___constant__] = ACTIONS(2130),
    [anon_sym___managed__] = ACTIONS(2130),
    [anon_sym___grid_constant__] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_case] = ACTIONS(2130),
    [anon_sym_default] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [anon_sym___asm] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [anon_sym_explicit] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_operator] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_namespace] = ACTIONS(2130),
    [anon_sym_using] = ACTIONS(2130),
    [anon_sym_static_assert] = ACTIONS(2130),
    [anon_sym_concept] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym___launch_bounds__] = ACTIONS(2130),
  },
  [STATE(367)] = {
    [ts_builtin_sym_end] = ACTIONS(2083),
    [sym_identifier] = ACTIONS(2078),
    [aux_sym_preproc_include_token1] = ACTIONS(2078),
    [aux_sym_preproc_def_token1] = ACTIONS(2078),
    [aux_sym_preproc_if_token1] = ACTIONS(2078),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2078),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2078),
    [sym_preproc_directive] = ACTIONS(2078),
    [anon_sym_LPAREN2] = ACTIONS(2083),
    [anon_sym_BANG] = ACTIONS(2083),
    [anon_sym_TILDE] = ACTIONS(2083),
    [anon_sym_DASH] = ACTIONS(2078),
    [anon_sym_PLUS] = ACTIONS(2078),
    [anon_sym_STAR] = ACTIONS(2083),
    [anon_sym_AMP_AMP] = ACTIONS(2083),
    [anon_sym_AMP] = ACTIONS(2078),
    [anon_sym_SEMI] = ACTIONS(2083),
    [anon_sym___extension__] = ACTIONS(2078),
    [anon_sym_typedef] = ACTIONS(2078),
    [anon_sym___device__] = ACTIONS(2078),
    [anon_sym___host__] = ACTIONS(2078),
    [anon_sym___global__] = ACTIONS(2078),
    [anon_sym___forceinline__] = ACTIONS(2078),
    [anon_sym___noinline__] = ACTIONS(2078),
    [anon_sym_virtual] = ACTIONS(2078),
    [anon_sym_extern] = ACTIONS(2078),
    [anon_sym___attribute__] = ACTIONS(2078),
    [anon_sym___attribute] = ACTIONS(2078),
    [anon_sym_COLON_COLON] = ACTIONS(2083),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2083),
    [anon_sym___declspec] = ACTIONS(2078),
    [anon_sym___based] = ACTIONS(2078),
    [anon_sym___cdecl] = ACTIONS(2078),
    [anon_sym___clrcall] = ACTIONS(2078),
    [anon_sym___stdcall] = ACTIONS(2078),
    [anon_sym___fastcall] = ACTIONS(2078),
    [anon_sym___thiscall] = ACTIONS(2078),
    [anon_sym___vectorcall] = ACTIONS(2078),
    [anon_sym_LBRACE] = ACTIONS(2083),
    [anon_sym_signed] = ACTIONS(2078),
    [anon_sym_unsigned] = ACTIONS(2078),
    [anon_sym_long] = ACTIONS(2078),
    [anon_sym_short] = ACTIONS(2078),
    [anon_sym_LBRACK] = ACTIONS(2078),
    [anon_sym_static] = ACTIONS(2078),
    [anon_sym_register] = ACTIONS(2078),
    [anon_sym_inline] = ACTIONS(2078),
    [anon_sym___inline] = ACTIONS(2078),
    [anon_sym___inline__] = ACTIONS(2078),
    [anon_sym___forceinline] = ACTIONS(2078),
    [anon_sym_thread_local] = ACTIONS(2078),
    [anon_sym___thread] = ACTIONS(2078),
    [anon_sym_const] = ACTIONS(2078),
    [anon_sym_constexpr] = ACTIONS(2078),
    [anon_sym_volatile] = ACTIONS(2078),
    [anon_sym_restrict] = ACTIONS(2078),
    [anon_sym___restrict__] = ACTIONS(2078),
    [anon_sym__Atomic] = ACTIONS(2078),
    [anon_sym__Noreturn] = ACTIONS(2078),
    [anon_sym_noreturn] = ACTIONS(2078),
    [anon_sym__Nonnull] = ACTIONS(2078),
    [anon_sym_mutable] = ACTIONS(2078),
    [anon_sym_constinit] = ACTIONS(2078),
    [anon_sym_consteval] = ACTIONS(2078),
    [anon_sym___shared__] = ACTIONS(2078),
    [anon_sym___local__] = ACTIONS(2078),
    [anon_sym___constant__] = ACTIONS(2078),
    [anon_sym___managed__] = ACTIONS(2078),
    [anon_sym___grid_constant__] = ACTIONS(2078),
    [anon_sym_alignas] = ACTIONS(2078),
    [anon_sym__Alignas] = ACTIONS(2078),
    [sym_primitive_type] = ACTIONS(2078),
    [anon_sym_enum] = ACTIONS(2078),
    [anon_sym_class] = ACTIONS(2078),
    [anon_sym_struct] = ACTIONS(2078),
    [anon_sym_union] = ACTIONS(2078),
    [anon_sym_if] = ACTIONS(2078),
    [anon_sym_else] = ACTIONS(2078),
    [anon_sym_switch] = ACTIONS(2078),
    [anon_sym_case] = ACTIONS(2078),
    [anon_sym_default] = ACTIONS(2078),
    [anon_sym_while] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(2078),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_return] = ACTIONS(2078),
    [anon_sym_break] = ACTIONS(2078),
    [anon_sym_continue] = ACTIONS(2078),
    [anon_sym_goto] = ACTIONS(2078),
    [anon_sym___try] = ACTIONS(2078),
    [anon_sym___leave] = ACTIONS(2078),
    [anon_sym_not] = ACTIONS(2078),
    [anon_sym_compl] = ACTIONS(2078),
    [anon_sym_DASH_DASH] = ACTIONS(2083),
    [anon_sym_PLUS_PLUS] = ACTIONS(2083),
    [anon_sym_sizeof] = ACTIONS(2078),
    [anon_sym___alignof__] = ACTIONS(2078),
    [anon_sym___alignof] = ACTIONS(2078),
    [anon_sym__alignof] = ACTIONS(2078),
    [anon_sym_alignof] = ACTIONS(2078),
    [anon_sym__Alignof] = ACTIONS(2078),
    [anon_sym_offsetof] = ACTIONS(2078),
    [anon_sym__Generic] = ACTIONS(2078),
    [anon_sym_asm] = ACTIONS(2078),
    [anon_sym___asm__] = ACTIONS(2078),
    [anon_sym___asm] = ACTIONS(2078),
    [sym_number_literal] = ACTIONS(2083),
    [anon_sym_L_SQUOTE] = ACTIONS(2083),
    [anon_sym_u_SQUOTE] = ACTIONS(2083),
    [anon_sym_U_SQUOTE] = ACTIONS(2083),
    [anon_sym_u8_SQUOTE] = ACTIONS(2083),
    [anon_sym_SQUOTE] = ACTIONS(2083),
    [anon_sym_L_DQUOTE] = ACTIONS(2083),
    [anon_sym_u_DQUOTE] = ACTIONS(2083),
    [anon_sym_U_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8_DQUOTE] = ACTIONS(2083),
    [anon_sym_DQUOTE] = ACTIONS(2083),
    [sym_true] = ACTIONS(2078),
    [sym_false] = ACTIONS(2078),
    [anon_sym_NULL] = ACTIONS(2078),
    [anon_sym_nullptr] = ACTIONS(2078),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2078),
    [anon_sym_decltype] = ACTIONS(2078),
    [anon_sym_explicit] = ACTIONS(2078),
    [anon_sym_typename] = ACTIONS(2078),
    [anon_sym_template] = ACTIONS(2078),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2078),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_namespace] = ACTIONS(2078),
    [anon_sym_using] = ACTIONS(2078),
    [anon_sym_static_assert] = ACTIONS(2078),
    [anon_sym_concept] = ACTIONS(2078),
    [anon_sym_co_return] = ACTIONS(2078),
    [anon_sym_co_yield] = ACTIONS(2078),
    [anon_sym_R_DQUOTE] = ACTIONS(2083),
    [anon_sym_LR_DQUOTE] = ACTIONS(2083),
    [anon_sym_uR_DQUOTE] = ACTIONS(2083),
    [anon_sym_UR_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2083),
    [anon_sym_co_await] = ACTIONS(2078),
    [anon_sym_new] = ACTIONS(2078),
    [anon_sym_requires] = ACTIONS(2078),
    [sym_this] = ACTIONS(2078),
    [anon_sym___launch_bounds__] = ACTIONS(2078),
  },
  [STATE(368)] = {
    [ts_builtin_sym_end] = ACTIONS(2128),
    [sym_identifier] = ACTIONS(2126),
    [aux_sym_preproc_include_token1] = ACTIONS(2126),
    [aux_sym_preproc_def_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2126),
    [sym_preproc_directive] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP_AMP] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2126),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym___device__] = ACTIONS(2126),
    [anon_sym___host__] = ACTIONS(2126),
    [anon_sym___global__] = ACTIONS(2126),
    [anon_sym___forceinline__] = ACTIONS(2126),
    [anon_sym___noinline__] = ACTIONS(2126),
    [anon_sym_virtual] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym___attribute] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym___based] = ACTIONS(2126),
    [anon_sym___cdecl] = ACTIONS(2126),
    [anon_sym___clrcall] = ACTIONS(2126),
    [anon_sym___stdcall] = ACTIONS(2126),
    [anon_sym___fastcall] = ACTIONS(2126),
    [anon_sym___thiscall] = ACTIONS(2126),
    [anon_sym___vectorcall] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym__Nonnull] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym___shared__] = ACTIONS(2126),
    [anon_sym___local__] = ACTIONS(2126),
    [anon_sym___constant__] = ACTIONS(2126),
    [anon_sym___managed__] = ACTIONS(2126),
    [anon_sym___grid_constant__] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_case] = ACTIONS(2126),
    [anon_sym_default] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [anon_sym___asm] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [anon_sym_explicit] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_operator] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_namespace] = ACTIONS(2126),
    [anon_sym_using] = ACTIONS(2126),
    [anon_sym_static_assert] = ACTIONS(2126),
    [anon_sym_concept] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym___launch_bounds__] = ACTIONS(2126),
  },
  [STATE(369)] = {
    [ts_builtin_sym_end] = ACTIONS(2224),
    [sym_identifier] = ACTIONS(2222),
    [aux_sym_preproc_include_token1] = ACTIONS(2222),
    [aux_sym_preproc_def_token1] = ACTIONS(2222),
    [aux_sym_preproc_if_token1] = ACTIONS(2222),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2222),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2222),
    [sym_preproc_directive] = ACTIONS(2222),
    [anon_sym_LPAREN2] = ACTIONS(2224),
    [anon_sym_BANG] = ACTIONS(2224),
    [anon_sym_TILDE] = ACTIONS(2224),
    [anon_sym_DASH] = ACTIONS(2222),
    [anon_sym_PLUS] = ACTIONS(2222),
    [anon_sym_STAR] = ACTIONS(2224),
    [anon_sym_AMP_AMP] = ACTIONS(2224),
    [anon_sym_AMP] = ACTIONS(2222),
    [anon_sym_SEMI] = ACTIONS(2224),
    [anon_sym___extension__] = ACTIONS(2222),
    [anon_sym_typedef] = ACTIONS(2222),
    [anon_sym___device__] = ACTIONS(2222),
    [anon_sym___host__] = ACTIONS(2222),
    [anon_sym___global__] = ACTIONS(2222),
    [anon_sym___forceinline__] = ACTIONS(2222),
    [anon_sym___noinline__] = ACTIONS(2222),
    [anon_sym_virtual] = ACTIONS(2222),
    [anon_sym_extern] = ACTIONS(2222),
    [anon_sym___attribute__] = ACTIONS(2222),
    [anon_sym___attribute] = ACTIONS(2222),
    [anon_sym_COLON_COLON] = ACTIONS(2224),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2224),
    [anon_sym___declspec] = ACTIONS(2222),
    [anon_sym___based] = ACTIONS(2222),
    [anon_sym___cdecl] = ACTIONS(2222),
    [anon_sym___clrcall] = ACTIONS(2222),
    [anon_sym___stdcall] = ACTIONS(2222),
    [anon_sym___fastcall] = ACTIONS(2222),
    [anon_sym___thiscall] = ACTIONS(2222),
    [anon_sym___vectorcall] = ACTIONS(2222),
    [anon_sym_LBRACE] = ACTIONS(2224),
    [anon_sym_signed] = ACTIONS(2222),
    [anon_sym_unsigned] = ACTIONS(2222),
    [anon_sym_long] = ACTIONS(2222),
    [anon_sym_short] = ACTIONS(2222),
    [anon_sym_LBRACK] = ACTIONS(2222),
    [anon_sym_static] = ACTIONS(2222),
    [anon_sym_register] = ACTIONS(2222),
    [anon_sym_inline] = ACTIONS(2222),
    [anon_sym___inline] = ACTIONS(2222),
    [anon_sym___inline__] = ACTIONS(2222),
    [anon_sym___forceinline] = ACTIONS(2222),
    [anon_sym_thread_local] = ACTIONS(2222),
    [anon_sym___thread] = ACTIONS(2222),
    [anon_sym_const] = ACTIONS(2222),
    [anon_sym_constexpr] = ACTIONS(2222),
    [anon_sym_volatile] = ACTIONS(2222),
    [anon_sym_restrict] = ACTIONS(2222),
    [anon_sym___restrict__] = ACTIONS(2222),
    [anon_sym__Atomic] = ACTIONS(2222),
    [anon_sym__Noreturn] = ACTIONS(2222),
    [anon_sym_noreturn] = ACTIONS(2222),
    [anon_sym__Nonnull] = ACTIONS(2222),
    [anon_sym_mutable] = ACTIONS(2222),
    [anon_sym_constinit] = ACTIONS(2222),
    [anon_sym_consteval] = ACTIONS(2222),
    [anon_sym___shared__] = ACTIONS(2222),
    [anon_sym___local__] = ACTIONS(2222),
    [anon_sym___constant__] = ACTIONS(2222),
    [anon_sym___managed__] = ACTIONS(2222),
    [anon_sym___grid_constant__] = ACTIONS(2222),
    [anon_sym_alignas] = ACTIONS(2222),
    [anon_sym__Alignas] = ACTIONS(2222),
    [sym_primitive_type] = ACTIONS(2222),
    [anon_sym_enum] = ACTIONS(2222),
    [anon_sym_class] = ACTIONS(2222),
    [anon_sym_struct] = ACTIONS(2222),
    [anon_sym_union] = ACTIONS(2222),
    [anon_sym_if] = ACTIONS(2222),
    [anon_sym_else] = ACTIONS(2222),
    [anon_sym_switch] = ACTIONS(2222),
    [anon_sym_case] = ACTIONS(2222),
    [anon_sym_default] = ACTIONS(2222),
    [anon_sym_while] = ACTIONS(2222),
    [anon_sym_do] = ACTIONS(2222),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_return] = ACTIONS(2222),
    [anon_sym_break] = ACTIONS(2222),
    [anon_sym_continue] = ACTIONS(2222),
    [anon_sym_goto] = ACTIONS(2222),
    [anon_sym___try] = ACTIONS(2222),
    [anon_sym___leave] = ACTIONS(2222),
    [anon_sym_not] = ACTIONS(2222),
    [anon_sym_compl] = ACTIONS(2222),
    [anon_sym_DASH_DASH] = ACTIONS(2224),
    [anon_sym_PLUS_PLUS] = ACTIONS(2224),
    [anon_sym_sizeof] = ACTIONS(2222),
    [anon_sym___alignof__] = ACTIONS(2222),
    [anon_sym___alignof] = ACTIONS(2222),
    [anon_sym__alignof] = ACTIONS(2222),
    [anon_sym_alignof] = ACTIONS(2222),
    [anon_sym__Alignof] = ACTIONS(2222),
    [anon_sym_offsetof] = ACTIONS(2222),
    [anon_sym__Generic] = ACTIONS(2222),
    [anon_sym_asm] = ACTIONS(2222),
    [anon_sym___asm__] = ACTIONS(2222),
    [anon_sym___asm] = ACTIONS(2222),
    [sym_number_literal] = ACTIONS(2224),
    [anon_sym_L_SQUOTE] = ACTIONS(2224),
    [anon_sym_u_SQUOTE] = ACTIONS(2224),
    [anon_sym_U_SQUOTE] = ACTIONS(2224),
    [anon_sym_u8_SQUOTE] = ACTIONS(2224),
    [anon_sym_SQUOTE] = ACTIONS(2224),
    [anon_sym_L_DQUOTE] = ACTIONS(2224),
    [anon_sym_u_DQUOTE] = ACTIONS(2224),
    [anon_sym_U_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8_DQUOTE] = ACTIONS(2224),
    [anon_sym_DQUOTE] = ACTIONS(2224),
    [sym_true] = ACTIONS(2222),
    [sym_false] = ACTIONS(2222),
    [anon_sym_NULL] = ACTIONS(2222),
    [anon_sym_nullptr] = ACTIONS(2222),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2222),
    [anon_sym_decltype] = ACTIONS(2222),
    [anon_sym_explicit] = ACTIONS(2222),
    [anon_sym_typename] = ACTIONS(2222),
    [anon_sym_template] = ACTIONS(2222),
    [anon_sym_operator] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2222),
    [anon_sym_delete] = ACTIONS(2222),
    [anon_sym_throw] = ACTIONS(2222),
    [anon_sym_namespace] = ACTIONS(2222),
    [anon_sym_using] = ACTIONS(2222),
    [anon_sym_static_assert] = ACTIONS(2222),
    [anon_sym_concept] = ACTIONS(2222),
    [anon_sym_co_return] = ACTIONS(2222),
    [anon_sym_co_yield] = ACTIONS(2222),
    [anon_sym_R_DQUOTE] = ACTIONS(2224),
    [anon_sym_LR_DQUOTE] = ACTIONS(2224),
    [anon_sym_uR_DQUOTE] = ACTIONS(2224),
    [anon_sym_UR_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2224),
    [anon_sym_co_await] = ACTIONS(2222),
    [anon_sym_new] = ACTIONS(2222),
    [anon_sym_requires] = ACTIONS(2222),
    [sym_this] = ACTIONS(2222),
    [anon_sym___launch_bounds__] = ACTIONS(2222),
  },
  [STATE(370)] = {
    [sym_identifier] = ACTIONS(2130),
    [aux_sym_preproc_include_token1] = ACTIONS(2130),
    [aux_sym_preproc_def_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2130),
    [sym_preproc_directive] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP_AMP] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2130),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym___device__] = ACTIONS(2130),
    [anon_sym___host__] = ACTIONS(2130),
    [anon_sym___global__] = ACTIONS(2130),
    [anon_sym___forceinline__] = ACTIONS(2130),
    [anon_sym___noinline__] = ACTIONS(2130),
    [anon_sym_virtual] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym___attribute] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym___based] = ACTIONS(2130),
    [anon_sym___cdecl] = ACTIONS(2130),
    [anon_sym___clrcall] = ACTIONS(2130),
    [anon_sym___stdcall] = ACTIONS(2130),
    [anon_sym___fastcall] = ACTIONS(2130),
    [anon_sym___thiscall] = ACTIONS(2130),
    [anon_sym___vectorcall] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_RBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym__Nonnull] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym___shared__] = ACTIONS(2130),
    [anon_sym___local__] = ACTIONS(2130),
    [anon_sym___constant__] = ACTIONS(2130),
    [anon_sym___managed__] = ACTIONS(2130),
    [anon_sym___grid_constant__] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_case] = ACTIONS(2130),
    [anon_sym_default] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [anon_sym___asm] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [anon_sym_explicit] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_operator] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_namespace] = ACTIONS(2130),
    [anon_sym_using] = ACTIONS(2130),
    [anon_sym_static_assert] = ACTIONS(2130),
    [anon_sym_concept] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym___launch_bounds__] = ACTIONS(2130),
  },
  [STATE(371)] = {
    [sym_identifier] = ACTIONS(2222),
    [aux_sym_preproc_include_token1] = ACTIONS(2222),
    [aux_sym_preproc_def_token1] = ACTIONS(2222),
    [aux_sym_preproc_if_token1] = ACTIONS(2222),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2222),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2222),
    [sym_preproc_directive] = ACTIONS(2222),
    [anon_sym_LPAREN2] = ACTIONS(2224),
    [anon_sym_BANG] = ACTIONS(2224),
    [anon_sym_TILDE] = ACTIONS(2224),
    [anon_sym_DASH] = ACTIONS(2222),
    [anon_sym_PLUS] = ACTIONS(2222),
    [anon_sym_STAR] = ACTIONS(2224),
    [anon_sym_AMP_AMP] = ACTIONS(2224),
    [anon_sym_AMP] = ACTIONS(2222),
    [anon_sym_SEMI] = ACTIONS(2224),
    [anon_sym___extension__] = ACTIONS(2222),
    [anon_sym_typedef] = ACTIONS(2222),
    [anon_sym___device__] = ACTIONS(2222),
    [anon_sym___host__] = ACTIONS(2222),
    [anon_sym___global__] = ACTIONS(2222),
    [anon_sym___forceinline__] = ACTIONS(2222),
    [anon_sym___noinline__] = ACTIONS(2222),
    [anon_sym_virtual] = ACTIONS(2222),
    [anon_sym_extern] = ACTIONS(2222),
    [anon_sym___attribute__] = ACTIONS(2222),
    [anon_sym___attribute] = ACTIONS(2222),
    [anon_sym_COLON_COLON] = ACTIONS(2224),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2224),
    [anon_sym___declspec] = ACTIONS(2222),
    [anon_sym___based] = ACTIONS(2222),
    [anon_sym___cdecl] = ACTIONS(2222),
    [anon_sym___clrcall] = ACTIONS(2222),
    [anon_sym___stdcall] = ACTIONS(2222),
    [anon_sym___fastcall] = ACTIONS(2222),
    [anon_sym___thiscall] = ACTIONS(2222),
    [anon_sym___vectorcall] = ACTIONS(2222),
    [anon_sym_LBRACE] = ACTIONS(2224),
    [anon_sym_RBRACE] = ACTIONS(2224),
    [anon_sym_signed] = ACTIONS(2222),
    [anon_sym_unsigned] = ACTIONS(2222),
    [anon_sym_long] = ACTIONS(2222),
    [anon_sym_short] = ACTIONS(2222),
    [anon_sym_LBRACK] = ACTIONS(2222),
    [anon_sym_static] = ACTIONS(2222),
    [anon_sym_register] = ACTIONS(2222),
    [anon_sym_inline] = ACTIONS(2222),
    [anon_sym___inline] = ACTIONS(2222),
    [anon_sym___inline__] = ACTIONS(2222),
    [anon_sym___forceinline] = ACTIONS(2222),
    [anon_sym_thread_local] = ACTIONS(2222),
    [anon_sym___thread] = ACTIONS(2222),
    [anon_sym_const] = ACTIONS(2222),
    [anon_sym_constexpr] = ACTIONS(2222),
    [anon_sym_volatile] = ACTIONS(2222),
    [anon_sym_restrict] = ACTIONS(2222),
    [anon_sym___restrict__] = ACTIONS(2222),
    [anon_sym__Atomic] = ACTIONS(2222),
    [anon_sym__Noreturn] = ACTIONS(2222),
    [anon_sym_noreturn] = ACTIONS(2222),
    [anon_sym__Nonnull] = ACTIONS(2222),
    [anon_sym_mutable] = ACTIONS(2222),
    [anon_sym_constinit] = ACTIONS(2222),
    [anon_sym_consteval] = ACTIONS(2222),
    [anon_sym___shared__] = ACTIONS(2222),
    [anon_sym___local__] = ACTIONS(2222),
    [anon_sym___constant__] = ACTIONS(2222),
    [anon_sym___managed__] = ACTIONS(2222),
    [anon_sym___grid_constant__] = ACTIONS(2222),
    [anon_sym_alignas] = ACTIONS(2222),
    [anon_sym__Alignas] = ACTIONS(2222),
    [sym_primitive_type] = ACTIONS(2222),
    [anon_sym_enum] = ACTIONS(2222),
    [anon_sym_class] = ACTIONS(2222),
    [anon_sym_struct] = ACTIONS(2222),
    [anon_sym_union] = ACTIONS(2222),
    [anon_sym_if] = ACTIONS(2222),
    [anon_sym_else] = ACTIONS(2222),
    [anon_sym_switch] = ACTIONS(2222),
    [anon_sym_case] = ACTIONS(2222),
    [anon_sym_default] = ACTIONS(2222),
    [anon_sym_while] = ACTIONS(2222),
    [anon_sym_do] = ACTIONS(2222),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_return] = ACTIONS(2222),
    [anon_sym_break] = ACTIONS(2222),
    [anon_sym_continue] = ACTIONS(2222),
    [anon_sym_goto] = ACTIONS(2222),
    [anon_sym___try] = ACTIONS(2222),
    [anon_sym___leave] = ACTIONS(2222),
    [anon_sym_not] = ACTIONS(2222),
    [anon_sym_compl] = ACTIONS(2222),
    [anon_sym_DASH_DASH] = ACTIONS(2224),
    [anon_sym_PLUS_PLUS] = ACTIONS(2224),
    [anon_sym_sizeof] = ACTIONS(2222),
    [anon_sym___alignof__] = ACTIONS(2222),
    [anon_sym___alignof] = ACTIONS(2222),
    [anon_sym__alignof] = ACTIONS(2222),
    [anon_sym_alignof] = ACTIONS(2222),
    [anon_sym__Alignof] = ACTIONS(2222),
    [anon_sym_offsetof] = ACTIONS(2222),
    [anon_sym__Generic] = ACTIONS(2222),
    [anon_sym_asm] = ACTIONS(2222),
    [anon_sym___asm__] = ACTIONS(2222),
    [anon_sym___asm] = ACTIONS(2222),
    [sym_number_literal] = ACTIONS(2224),
    [anon_sym_L_SQUOTE] = ACTIONS(2224),
    [anon_sym_u_SQUOTE] = ACTIONS(2224),
    [anon_sym_U_SQUOTE] = ACTIONS(2224),
    [anon_sym_u8_SQUOTE] = ACTIONS(2224),
    [anon_sym_SQUOTE] = ACTIONS(2224),
    [anon_sym_L_DQUOTE] = ACTIONS(2224),
    [anon_sym_u_DQUOTE] = ACTIONS(2224),
    [anon_sym_U_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8_DQUOTE] = ACTIONS(2224),
    [anon_sym_DQUOTE] = ACTIONS(2224),
    [sym_true] = ACTIONS(2222),
    [sym_false] = ACTIONS(2222),
    [anon_sym_NULL] = ACTIONS(2222),
    [anon_sym_nullptr] = ACTIONS(2222),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2222),
    [anon_sym_decltype] = ACTIONS(2222),
    [anon_sym_explicit] = ACTIONS(2222),
    [anon_sym_typename] = ACTIONS(2222),
    [anon_sym_template] = ACTIONS(2222),
    [anon_sym_operator] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2222),
    [anon_sym_delete] = ACTIONS(2222),
    [anon_sym_throw] = ACTIONS(2222),
    [anon_sym_namespace] = ACTIONS(2222),
    [anon_sym_using] = ACTIONS(2222),
    [anon_sym_static_assert] = ACTIONS(2222),
    [anon_sym_concept] = ACTIONS(2222),
    [anon_sym_co_return] = ACTIONS(2222),
    [anon_sym_co_yield] = ACTIONS(2222),
    [anon_sym_R_DQUOTE] = ACTIONS(2224),
    [anon_sym_LR_DQUOTE] = ACTIONS(2224),
    [anon_sym_uR_DQUOTE] = ACTIONS(2224),
    [anon_sym_UR_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2224),
    [anon_sym_co_await] = ACTIONS(2222),
    [anon_sym_new] = ACTIONS(2222),
    [anon_sym_requires] = ACTIONS(2222),
    [sym_this] = ACTIONS(2222),
    [anon_sym___launch_bounds__] = ACTIONS(2222),
  },
  [STATE(372)] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_include_token1] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym___device__] = ACTIONS(2138),
    [anon_sym___host__] = ACTIONS(2138),
    [anon_sym___global__] = ACTIONS(2138),
    [anon_sym___forceinline__] = ACTIONS(2138),
    [anon_sym___noinline__] = ACTIONS(2138),
    [anon_sym_virtual] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym___attribute] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym___cdecl] = ACTIONS(2138),
    [anon_sym___clrcall] = ACTIONS(2138),
    [anon_sym___stdcall] = ACTIONS(2138),
    [anon_sym___fastcall] = ACTIONS(2138),
    [anon_sym___thiscall] = ACTIONS(2138),
    [anon_sym___vectorcall] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_RBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym__Nonnull] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym___shared__] = ACTIONS(2138),
    [anon_sym___local__] = ACTIONS(2138),
    [anon_sym___constant__] = ACTIONS(2138),
    [anon_sym___managed__] = ACTIONS(2138),
    [anon_sym___grid_constant__] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_case] = ACTIONS(2138),
    [anon_sym_default] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [anon_sym___asm] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_namespace] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_concept] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym___launch_bounds__] = ACTIONS(2138),
  },
  [STATE(373)] = {
    [ts_builtin_sym_end] = ACTIONS(2140),
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_include_token1] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym___device__] = ACTIONS(2138),
    [anon_sym___host__] = ACTIONS(2138),
    [anon_sym___global__] = ACTIONS(2138),
    [anon_sym___forceinline__] = ACTIONS(2138),
    [anon_sym___noinline__] = ACTIONS(2138),
    [anon_sym_virtual] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym___attribute] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym___cdecl] = ACTIONS(2138),
    [anon_sym___clrcall] = ACTIONS(2138),
    [anon_sym___stdcall] = ACTIONS(2138),
    [anon_sym___fastcall] = ACTIONS(2138),
    [anon_sym___thiscall] = ACTIONS(2138),
    [anon_sym___vectorcall] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym__Nonnull] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym___shared__] = ACTIONS(2138),
    [anon_sym___local__] = ACTIONS(2138),
    [anon_sym___constant__] = ACTIONS(2138),
    [anon_sym___managed__] = ACTIONS(2138),
    [anon_sym___grid_constant__] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_case] = ACTIONS(2138),
    [anon_sym_default] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [anon_sym___asm] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_namespace] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_concept] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym___launch_bounds__] = ACTIONS(2138),
  },
  [STATE(374)] = {
    [sym_identifier] = ACTIONS(2142),
    [aux_sym_preproc_include_token1] = ACTIONS(2142),
    [aux_sym_preproc_def_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2142),
    [sym_preproc_directive] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym___device__] = ACTIONS(2142),
    [anon_sym___host__] = ACTIONS(2142),
    [anon_sym___global__] = ACTIONS(2142),
    [anon_sym___forceinline__] = ACTIONS(2142),
    [anon_sym___noinline__] = ACTIONS(2142),
    [anon_sym_virtual] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym___attribute] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_RBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym__Nonnull] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym___shared__] = ACTIONS(2142),
    [anon_sym___local__] = ACTIONS(2142),
    [anon_sym___constant__] = ACTIONS(2142),
    [anon_sym___managed__] = ACTIONS(2142),
    [anon_sym___grid_constant__] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_case] = ACTIONS(2142),
    [anon_sym_default] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [anon_sym___asm] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [anon_sym_explicit] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_namespace] = ACTIONS(2142),
    [anon_sym_using] = ACTIONS(2142),
    [anon_sym_static_assert] = ACTIONS(2142),
    [anon_sym_concept] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym___launch_bounds__] = ACTIONS(2142),
  },
  [STATE(375)] = {
    [sym_identifier] = ACTIONS(2126),
    [aux_sym_preproc_include_token1] = ACTIONS(2126),
    [aux_sym_preproc_def_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token2] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2126),
    [sym_preproc_directive] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP_AMP] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2126),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym___device__] = ACTIONS(2126),
    [anon_sym___host__] = ACTIONS(2126),
    [anon_sym___global__] = ACTIONS(2126),
    [anon_sym___forceinline__] = ACTIONS(2126),
    [anon_sym___noinline__] = ACTIONS(2126),
    [anon_sym_virtual] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym___attribute] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym___based] = ACTIONS(2126),
    [anon_sym___cdecl] = ACTIONS(2126),
    [anon_sym___clrcall] = ACTIONS(2126),
    [anon_sym___stdcall] = ACTIONS(2126),
    [anon_sym___fastcall] = ACTIONS(2126),
    [anon_sym___thiscall] = ACTIONS(2126),
    [anon_sym___vectorcall] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym__Nonnull] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym___shared__] = ACTIONS(2126),
    [anon_sym___local__] = ACTIONS(2126),
    [anon_sym___constant__] = ACTIONS(2126),
    [anon_sym___managed__] = ACTIONS(2126),
    [anon_sym___grid_constant__] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_case] = ACTIONS(2126),
    [anon_sym_default] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [anon_sym___asm] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [anon_sym_explicit] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_operator] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_namespace] = ACTIONS(2126),
    [anon_sym_using] = ACTIONS(2126),
    [anon_sym_static_assert] = ACTIONS(2126),
    [anon_sym_concept] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym___launch_bounds__] = ACTIONS(2126),
  },
  [STATE(376)] = {
    [sym_identifier] = ACTIONS(2146),
    [aux_sym_preproc_include_token1] = ACTIONS(2146),
    [aux_sym_preproc_def_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2146),
    [sym_preproc_directive] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP_AMP] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2146),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym___device__] = ACTIONS(2146),
    [anon_sym___host__] = ACTIONS(2146),
    [anon_sym___global__] = ACTIONS(2146),
    [anon_sym___forceinline__] = ACTIONS(2146),
    [anon_sym___noinline__] = ACTIONS(2146),
    [anon_sym_virtual] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym___attribute] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym___based] = ACTIONS(2146),
    [anon_sym___cdecl] = ACTIONS(2146),
    [anon_sym___clrcall] = ACTIONS(2146),
    [anon_sym___stdcall] = ACTIONS(2146),
    [anon_sym___fastcall] = ACTIONS(2146),
    [anon_sym___thiscall] = ACTIONS(2146),
    [anon_sym___vectorcall] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_RBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym__Nonnull] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym___shared__] = ACTIONS(2146),
    [anon_sym___local__] = ACTIONS(2146),
    [anon_sym___constant__] = ACTIONS(2146),
    [anon_sym___managed__] = ACTIONS(2146),
    [anon_sym___grid_constant__] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_case] = ACTIONS(2146),
    [anon_sym_default] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [anon_sym___asm] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [anon_sym_explicit] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_operator] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_namespace] = ACTIONS(2146),
    [anon_sym_using] = ACTIONS(2146),
    [anon_sym_static_assert] = ACTIONS(2146),
    [anon_sym_concept] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym___launch_bounds__] = ACTIONS(2146),
  },
  [STATE(377)] = {
    [sym_identifier] = ACTIONS(2130),
    [aux_sym_preproc_include_token1] = ACTIONS(2130),
    [aux_sym_preproc_def_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token2] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2130),
    [sym_preproc_directive] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP_AMP] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2130),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym___device__] = ACTIONS(2130),
    [anon_sym___host__] = ACTIONS(2130),
    [anon_sym___global__] = ACTIONS(2130),
    [anon_sym___forceinline__] = ACTIONS(2130),
    [anon_sym___noinline__] = ACTIONS(2130),
    [anon_sym_virtual] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym___attribute] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym___based] = ACTIONS(2130),
    [anon_sym___cdecl] = ACTIONS(2130),
    [anon_sym___clrcall] = ACTIONS(2130),
    [anon_sym___stdcall] = ACTIONS(2130),
    [anon_sym___fastcall] = ACTIONS(2130),
    [anon_sym___thiscall] = ACTIONS(2130),
    [anon_sym___vectorcall] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym__Nonnull] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym___shared__] = ACTIONS(2130),
    [anon_sym___local__] = ACTIONS(2130),
    [anon_sym___constant__] = ACTIONS(2130),
    [anon_sym___managed__] = ACTIONS(2130),
    [anon_sym___grid_constant__] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_case] = ACTIONS(2130),
    [anon_sym_default] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [anon_sym___asm] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [anon_sym_explicit] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_operator] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_namespace] = ACTIONS(2130),
    [anon_sym_using] = ACTIONS(2130),
    [anon_sym_static_assert] = ACTIONS(2130),
    [anon_sym_concept] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym___launch_bounds__] = ACTIONS(2130),
  },
  [STATE(378)] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_include_token1] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token2] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym___device__] = ACTIONS(2138),
    [anon_sym___host__] = ACTIONS(2138),
    [anon_sym___global__] = ACTIONS(2138),
    [anon_sym___forceinline__] = ACTIONS(2138),
    [anon_sym___noinline__] = ACTIONS(2138),
    [anon_sym_virtual] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym___attribute] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym___cdecl] = ACTIONS(2138),
    [anon_sym___clrcall] = ACTIONS(2138),
    [anon_sym___stdcall] = ACTIONS(2138),
    [anon_sym___fastcall] = ACTIONS(2138),
    [anon_sym___thiscall] = ACTIONS(2138),
    [anon_sym___vectorcall] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym__Nonnull] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym___shared__] = ACTIONS(2138),
    [anon_sym___local__] = ACTIONS(2138),
    [anon_sym___constant__] = ACTIONS(2138),
    [anon_sym___managed__] = ACTIONS(2138),
    [anon_sym___grid_constant__] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_case] = ACTIONS(2138),
    [anon_sym_default] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [anon_sym___asm] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_namespace] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_concept] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym___launch_bounds__] = ACTIONS(2138),
  },
  [STATE(379)] = {
    [sym_identifier] = ACTIONS(2142),
    [aux_sym_preproc_include_token1] = ACTIONS(2142),
    [aux_sym_preproc_def_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token2] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2142),
    [sym_preproc_directive] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym___device__] = ACTIONS(2142),
    [anon_sym___host__] = ACTIONS(2142),
    [anon_sym___global__] = ACTIONS(2142),
    [anon_sym___forceinline__] = ACTIONS(2142),
    [anon_sym___noinline__] = ACTIONS(2142),
    [anon_sym_virtual] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym___attribute] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym__Nonnull] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym___shared__] = ACTIONS(2142),
    [anon_sym___local__] = ACTIONS(2142),
    [anon_sym___constant__] = ACTIONS(2142),
    [anon_sym___managed__] = ACTIONS(2142),
    [anon_sym___grid_constant__] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_case] = ACTIONS(2142),
    [anon_sym_default] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [anon_sym___asm] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [anon_sym_explicit] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_namespace] = ACTIONS(2142),
    [anon_sym_using] = ACTIONS(2142),
    [anon_sym_static_assert] = ACTIONS(2142),
    [anon_sym_concept] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym___launch_bounds__] = ACTIONS(2142),
  },
  [STATE(380)] = {
    [sym_identifier] = ACTIONS(2146),
    [aux_sym_preproc_include_token1] = ACTIONS(2146),
    [aux_sym_preproc_def_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token2] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2146),
    [sym_preproc_directive] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP_AMP] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2146),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym___device__] = ACTIONS(2146),
    [anon_sym___host__] = ACTIONS(2146),
    [anon_sym___global__] = ACTIONS(2146),
    [anon_sym___forceinline__] = ACTIONS(2146),
    [anon_sym___noinline__] = ACTIONS(2146),
    [anon_sym_virtual] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym___attribute] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym___based] = ACTIONS(2146),
    [anon_sym___cdecl] = ACTIONS(2146),
    [anon_sym___clrcall] = ACTIONS(2146),
    [anon_sym___stdcall] = ACTIONS(2146),
    [anon_sym___fastcall] = ACTIONS(2146),
    [anon_sym___thiscall] = ACTIONS(2146),
    [anon_sym___vectorcall] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym__Nonnull] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym___shared__] = ACTIONS(2146),
    [anon_sym___local__] = ACTIONS(2146),
    [anon_sym___constant__] = ACTIONS(2146),
    [anon_sym___managed__] = ACTIONS(2146),
    [anon_sym___grid_constant__] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_case] = ACTIONS(2146),
    [anon_sym_default] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [anon_sym___asm] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [anon_sym_explicit] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_operator] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_namespace] = ACTIONS(2146),
    [anon_sym_using] = ACTIONS(2146),
    [anon_sym_static_assert] = ACTIONS(2146),
    [anon_sym_concept] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym___launch_bounds__] = ACTIONS(2146),
  },
  [STATE(381)] = {
    [sym_identifier] = ACTIONS(2150),
    [aux_sym_preproc_include_token1] = ACTIONS(2150),
    [aux_sym_preproc_def_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token2] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2150),
    [sym_preproc_directive] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP_AMP] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2150),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym___device__] = ACTIONS(2150),
    [anon_sym___host__] = ACTIONS(2150),
    [anon_sym___global__] = ACTIONS(2150),
    [anon_sym___forceinline__] = ACTIONS(2150),
    [anon_sym___noinline__] = ACTIONS(2150),
    [anon_sym_virtual] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym___attribute] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym___based] = ACTIONS(2150),
    [anon_sym___cdecl] = ACTIONS(2150),
    [anon_sym___clrcall] = ACTIONS(2150),
    [anon_sym___stdcall] = ACTIONS(2150),
    [anon_sym___fastcall] = ACTIONS(2150),
    [anon_sym___thiscall] = ACTIONS(2150),
    [anon_sym___vectorcall] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym__Nonnull] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym___shared__] = ACTIONS(2150),
    [anon_sym___local__] = ACTIONS(2150),
    [anon_sym___constant__] = ACTIONS(2150),
    [anon_sym___managed__] = ACTIONS(2150),
    [anon_sym___grid_constant__] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_case] = ACTIONS(2150),
    [anon_sym_default] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [anon_sym___asm] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [anon_sym_explicit] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_operator] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_namespace] = ACTIONS(2150),
    [anon_sym_using] = ACTIONS(2150),
    [anon_sym_static_assert] = ACTIONS(2150),
    [anon_sym_concept] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym___launch_bounds__] = ACTIONS(2150),
  },
  [STATE(382)] = {
    [sym_identifier] = ACTIONS(2020),
    [aux_sym_preproc_include_token1] = ACTIONS(2020),
    [aux_sym_preproc_def_token1] = ACTIONS(2020),
    [aux_sym_preproc_if_token1] = ACTIONS(2020),
    [aux_sym_preproc_if_token2] = ACTIONS(2020),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2020),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2020),
    [sym_preproc_directive] = ACTIONS(2020),
    [anon_sym_LPAREN2] = ACTIONS(2022),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2020),
    [anon_sym_PLUS] = ACTIONS(2020),
    [anon_sym_STAR] = ACTIONS(2022),
    [anon_sym_AMP_AMP] = ACTIONS(2022),
    [anon_sym_AMP] = ACTIONS(2020),
    [anon_sym_SEMI] = ACTIONS(2022),
    [anon_sym___extension__] = ACTIONS(2020),
    [anon_sym_typedef] = ACTIONS(2020),
    [anon_sym___device__] = ACTIONS(2020),
    [anon_sym___host__] = ACTIONS(2020),
    [anon_sym___global__] = ACTIONS(2020),
    [anon_sym___forceinline__] = ACTIONS(2020),
    [anon_sym___noinline__] = ACTIONS(2020),
    [anon_sym_virtual] = ACTIONS(2020),
    [anon_sym_extern] = ACTIONS(2020),
    [anon_sym___attribute__] = ACTIONS(2020),
    [anon_sym___attribute] = ACTIONS(2020),
    [anon_sym_COLON_COLON] = ACTIONS(2022),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2022),
    [anon_sym___declspec] = ACTIONS(2020),
    [anon_sym___based] = ACTIONS(2020),
    [anon_sym___cdecl] = ACTIONS(2020),
    [anon_sym___clrcall] = ACTIONS(2020),
    [anon_sym___stdcall] = ACTIONS(2020),
    [anon_sym___fastcall] = ACTIONS(2020),
    [anon_sym___thiscall] = ACTIONS(2020),
    [anon_sym___vectorcall] = ACTIONS(2020),
    [anon_sym_LBRACE] = ACTIONS(2022),
    [anon_sym_signed] = ACTIONS(2020),
    [anon_sym_unsigned] = ACTIONS(2020),
    [anon_sym_long] = ACTIONS(2020),
    [anon_sym_short] = ACTIONS(2020),
    [anon_sym_LBRACK] = ACTIONS(2020),
    [anon_sym_static] = ACTIONS(2020),
    [anon_sym_register] = ACTIONS(2020),
    [anon_sym_inline] = ACTIONS(2020),
    [anon_sym___inline] = ACTIONS(2020),
    [anon_sym___inline__] = ACTIONS(2020),
    [anon_sym___forceinline] = ACTIONS(2020),
    [anon_sym_thread_local] = ACTIONS(2020),
    [anon_sym___thread] = ACTIONS(2020),
    [anon_sym_const] = ACTIONS(2020),
    [anon_sym_constexpr] = ACTIONS(2020),
    [anon_sym_volatile] = ACTIONS(2020),
    [anon_sym_restrict] = ACTIONS(2020),
    [anon_sym___restrict__] = ACTIONS(2020),
    [anon_sym__Atomic] = ACTIONS(2020),
    [anon_sym__Noreturn] = ACTIONS(2020),
    [anon_sym_noreturn] = ACTIONS(2020),
    [anon_sym__Nonnull] = ACTIONS(2020),
    [anon_sym_mutable] = ACTIONS(2020),
    [anon_sym_constinit] = ACTIONS(2020),
    [anon_sym_consteval] = ACTIONS(2020),
    [anon_sym___shared__] = ACTIONS(2020),
    [anon_sym___local__] = ACTIONS(2020),
    [anon_sym___constant__] = ACTIONS(2020),
    [anon_sym___managed__] = ACTIONS(2020),
    [anon_sym___grid_constant__] = ACTIONS(2020),
    [anon_sym_alignas] = ACTIONS(2020),
    [anon_sym__Alignas] = ACTIONS(2020),
    [sym_primitive_type] = ACTIONS(2020),
    [anon_sym_enum] = ACTIONS(2020),
    [anon_sym_class] = ACTIONS(2020),
    [anon_sym_struct] = ACTIONS(2020),
    [anon_sym_union] = ACTIONS(2020),
    [anon_sym_if] = ACTIONS(2020),
    [anon_sym_else] = ACTIONS(2020),
    [anon_sym_switch] = ACTIONS(2020),
    [anon_sym_case] = ACTIONS(2020),
    [anon_sym_default] = ACTIONS(2020),
    [anon_sym_while] = ACTIONS(2020),
    [anon_sym_do] = ACTIONS(2020),
    [anon_sym_for] = ACTIONS(2020),
    [anon_sym_return] = ACTIONS(2020),
    [anon_sym_break] = ACTIONS(2020),
    [anon_sym_continue] = ACTIONS(2020),
    [anon_sym_goto] = ACTIONS(2020),
    [anon_sym___try] = ACTIONS(2020),
    [anon_sym___leave] = ACTIONS(2020),
    [anon_sym_not] = ACTIONS(2020),
    [anon_sym_compl] = ACTIONS(2020),
    [anon_sym_DASH_DASH] = ACTIONS(2022),
    [anon_sym_PLUS_PLUS] = ACTIONS(2022),
    [anon_sym_sizeof] = ACTIONS(2020),
    [anon_sym___alignof__] = ACTIONS(2020),
    [anon_sym___alignof] = ACTIONS(2020),
    [anon_sym__alignof] = ACTIONS(2020),
    [anon_sym_alignof] = ACTIONS(2020),
    [anon_sym__Alignof] = ACTIONS(2020),
    [anon_sym_offsetof] = ACTIONS(2020),
    [anon_sym__Generic] = ACTIONS(2020),
    [anon_sym_asm] = ACTIONS(2020),
    [anon_sym___asm__] = ACTIONS(2020),
    [anon_sym___asm] = ACTIONS(2020),
    [sym_number_literal] = ACTIONS(2022),
    [anon_sym_L_SQUOTE] = ACTIONS(2022),
    [anon_sym_u_SQUOTE] = ACTIONS(2022),
    [anon_sym_U_SQUOTE] = ACTIONS(2022),
    [anon_sym_u8_SQUOTE] = ACTIONS(2022),
    [anon_sym_SQUOTE] = ACTIONS(2022),
    [anon_sym_L_DQUOTE] = ACTIONS(2022),
    [anon_sym_u_DQUOTE] = ACTIONS(2022),
    [anon_sym_U_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8_DQUOTE] = ACTIONS(2022),
    [anon_sym_DQUOTE] = ACTIONS(2022),
    [sym_true] = ACTIONS(2020),
    [sym_false] = ACTIONS(2020),
    [anon_sym_NULL] = ACTIONS(2020),
    [anon_sym_nullptr] = ACTIONS(2020),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2020),
    [anon_sym_decltype] = ACTIONS(2020),
    [anon_sym_explicit] = ACTIONS(2020),
    [anon_sym_typename] = ACTIONS(2020),
    [anon_sym_template] = ACTIONS(2020),
    [anon_sym_operator] = ACTIONS(2020),
    [anon_sym_try] = ACTIONS(2020),
    [anon_sym_delete] = ACTIONS(2020),
    [anon_sym_throw] = ACTIONS(2020),
    [anon_sym_namespace] = ACTIONS(2020),
    [anon_sym_using] = ACTIONS(2020),
    [anon_sym_static_assert] = ACTIONS(2020),
    [anon_sym_concept] = ACTIONS(2020),
    [anon_sym_co_return] = ACTIONS(2020),
    [anon_sym_co_yield] = ACTIONS(2020),
    [anon_sym_R_DQUOTE] = ACTIONS(2022),
    [anon_sym_LR_DQUOTE] = ACTIONS(2022),
    [anon_sym_uR_DQUOTE] = ACTIONS(2022),
    [anon_sym_UR_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2022),
    [anon_sym_co_await] = ACTIONS(2020),
    [anon_sym_new] = ACTIONS(2020),
    [anon_sym_requires] = ACTIONS(2020),
    [sym_this] = ACTIONS(2020),
    [anon_sym___launch_bounds__] = ACTIONS(2020),
  },
  [STATE(383)] = {
    [sym_identifier] = ACTIONS(2094),
    [aux_sym_preproc_include_token1] = ACTIONS(2094),
    [aux_sym_preproc_def_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token2] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2094),
    [sym_preproc_directive] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP_AMP] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2094),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym___device__] = ACTIONS(2094),
    [anon_sym___host__] = ACTIONS(2094),
    [anon_sym___global__] = ACTIONS(2094),
    [anon_sym___forceinline__] = ACTIONS(2094),
    [anon_sym___noinline__] = ACTIONS(2094),
    [anon_sym_virtual] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym___attribute] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym___based] = ACTIONS(2094),
    [anon_sym___cdecl] = ACTIONS(2094),
    [anon_sym___clrcall] = ACTIONS(2094),
    [anon_sym___stdcall] = ACTIONS(2094),
    [anon_sym___fastcall] = ACTIONS(2094),
    [anon_sym___thiscall] = ACTIONS(2094),
    [anon_sym___vectorcall] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym__Nonnull] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym___shared__] = ACTIONS(2094),
    [anon_sym___local__] = ACTIONS(2094),
    [anon_sym___constant__] = ACTIONS(2094),
    [anon_sym___managed__] = ACTIONS(2094),
    [anon_sym___grid_constant__] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_case] = ACTIONS(2094),
    [anon_sym_default] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [anon_sym___asm] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [anon_sym_explicit] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_operator] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_namespace] = ACTIONS(2094),
    [anon_sym_using] = ACTIONS(2094),
    [anon_sym_static_assert] = ACTIONS(2094),
    [anon_sym_concept] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym___launch_bounds__] = ACTIONS(2094),
  },
  [STATE(384)] = {
    [sym_identifier] = ACTIONS(2024),
    [aux_sym_preproc_include_token1] = ACTIONS(2024),
    [aux_sym_preproc_def_token1] = ACTIONS(2024),
    [aux_sym_preproc_if_token1] = ACTIONS(2024),
    [aux_sym_preproc_if_token2] = ACTIONS(2024),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2024),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2024),
    [sym_preproc_directive] = ACTIONS(2024),
    [anon_sym_LPAREN2] = ACTIONS(2026),
    [anon_sym_BANG] = ACTIONS(2026),
    [anon_sym_TILDE] = ACTIONS(2026),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_STAR] = ACTIONS(2026),
    [anon_sym_AMP_AMP] = ACTIONS(2026),
    [anon_sym_AMP] = ACTIONS(2024),
    [anon_sym_SEMI] = ACTIONS(2026),
    [anon_sym___extension__] = ACTIONS(2024),
    [anon_sym_typedef] = ACTIONS(2024),
    [anon_sym___device__] = ACTIONS(2024),
    [anon_sym___host__] = ACTIONS(2024),
    [anon_sym___global__] = ACTIONS(2024),
    [anon_sym___forceinline__] = ACTIONS(2024),
    [anon_sym___noinline__] = ACTIONS(2024),
    [anon_sym_virtual] = ACTIONS(2024),
    [anon_sym_extern] = ACTIONS(2024),
    [anon_sym___attribute__] = ACTIONS(2024),
    [anon_sym___attribute] = ACTIONS(2024),
    [anon_sym_COLON_COLON] = ACTIONS(2026),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2026),
    [anon_sym___declspec] = ACTIONS(2024),
    [anon_sym___based] = ACTIONS(2024),
    [anon_sym___cdecl] = ACTIONS(2024),
    [anon_sym___clrcall] = ACTIONS(2024),
    [anon_sym___stdcall] = ACTIONS(2024),
    [anon_sym___fastcall] = ACTIONS(2024),
    [anon_sym___thiscall] = ACTIONS(2024),
    [anon_sym___vectorcall] = ACTIONS(2024),
    [anon_sym_LBRACE] = ACTIONS(2026),
    [anon_sym_signed] = ACTIONS(2024),
    [anon_sym_unsigned] = ACTIONS(2024),
    [anon_sym_long] = ACTIONS(2024),
    [anon_sym_short] = ACTIONS(2024),
    [anon_sym_LBRACK] = ACTIONS(2024),
    [anon_sym_static] = ACTIONS(2024),
    [anon_sym_register] = ACTIONS(2024),
    [anon_sym_inline] = ACTIONS(2024),
    [anon_sym___inline] = ACTIONS(2024),
    [anon_sym___inline__] = ACTIONS(2024),
    [anon_sym___forceinline] = ACTIONS(2024),
    [anon_sym_thread_local] = ACTIONS(2024),
    [anon_sym___thread] = ACTIONS(2024),
    [anon_sym_const] = ACTIONS(2024),
    [anon_sym_constexpr] = ACTIONS(2024),
    [anon_sym_volatile] = ACTIONS(2024),
    [anon_sym_restrict] = ACTIONS(2024),
    [anon_sym___restrict__] = ACTIONS(2024),
    [anon_sym__Atomic] = ACTIONS(2024),
    [anon_sym__Noreturn] = ACTIONS(2024),
    [anon_sym_noreturn] = ACTIONS(2024),
    [anon_sym__Nonnull] = ACTIONS(2024),
    [anon_sym_mutable] = ACTIONS(2024),
    [anon_sym_constinit] = ACTIONS(2024),
    [anon_sym_consteval] = ACTIONS(2024),
    [anon_sym___shared__] = ACTIONS(2024),
    [anon_sym___local__] = ACTIONS(2024),
    [anon_sym___constant__] = ACTIONS(2024),
    [anon_sym___managed__] = ACTIONS(2024),
    [anon_sym___grid_constant__] = ACTIONS(2024),
    [anon_sym_alignas] = ACTIONS(2024),
    [anon_sym__Alignas] = ACTIONS(2024),
    [sym_primitive_type] = ACTIONS(2024),
    [anon_sym_enum] = ACTIONS(2024),
    [anon_sym_class] = ACTIONS(2024),
    [anon_sym_struct] = ACTIONS(2024),
    [anon_sym_union] = ACTIONS(2024),
    [anon_sym_if] = ACTIONS(2024),
    [anon_sym_else] = ACTIONS(2024),
    [anon_sym_switch] = ACTIONS(2024),
    [anon_sym_case] = ACTIONS(2024),
    [anon_sym_default] = ACTIONS(2024),
    [anon_sym_while] = ACTIONS(2024),
    [anon_sym_do] = ACTIONS(2024),
    [anon_sym_for] = ACTIONS(2024),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_break] = ACTIONS(2024),
    [anon_sym_continue] = ACTIONS(2024),
    [anon_sym_goto] = ACTIONS(2024),
    [anon_sym___try] = ACTIONS(2024),
    [anon_sym___leave] = ACTIONS(2024),
    [anon_sym_not] = ACTIONS(2024),
    [anon_sym_compl] = ACTIONS(2024),
    [anon_sym_DASH_DASH] = ACTIONS(2026),
    [anon_sym_PLUS_PLUS] = ACTIONS(2026),
    [anon_sym_sizeof] = ACTIONS(2024),
    [anon_sym___alignof__] = ACTIONS(2024),
    [anon_sym___alignof] = ACTIONS(2024),
    [anon_sym__alignof] = ACTIONS(2024),
    [anon_sym_alignof] = ACTIONS(2024),
    [anon_sym__Alignof] = ACTIONS(2024),
    [anon_sym_offsetof] = ACTIONS(2024),
    [anon_sym__Generic] = ACTIONS(2024),
    [anon_sym_asm] = ACTIONS(2024),
    [anon_sym___asm__] = ACTIONS(2024),
    [anon_sym___asm] = ACTIONS(2024),
    [sym_number_literal] = ACTIONS(2026),
    [anon_sym_L_SQUOTE] = ACTIONS(2026),
    [anon_sym_u_SQUOTE] = ACTIONS(2026),
    [anon_sym_U_SQUOTE] = ACTIONS(2026),
    [anon_sym_u8_SQUOTE] = ACTIONS(2026),
    [anon_sym_SQUOTE] = ACTIONS(2026),
    [anon_sym_L_DQUOTE] = ACTIONS(2026),
    [anon_sym_u_DQUOTE] = ACTIONS(2026),
    [anon_sym_U_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8_DQUOTE] = ACTIONS(2026),
    [anon_sym_DQUOTE] = ACTIONS(2026),
    [sym_true] = ACTIONS(2024),
    [sym_false] = ACTIONS(2024),
    [anon_sym_NULL] = ACTIONS(2024),
    [anon_sym_nullptr] = ACTIONS(2024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2024),
    [anon_sym_decltype] = ACTIONS(2024),
    [anon_sym_explicit] = ACTIONS(2024),
    [anon_sym_typename] = ACTIONS(2024),
    [anon_sym_template] = ACTIONS(2024),
    [anon_sym_operator] = ACTIONS(2024),
    [anon_sym_try] = ACTIONS(2024),
    [anon_sym_delete] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2024),
    [anon_sym_namespace] = ACTIONS(2024),
    [anon_sym_using] = ACTIONS(2024),
    [anon_sym_static_assert] = ACTIONS(2024),
    [anon_sym_concept] = ACTIONS(2024),
    [anon_sym_co_return] = ACTIONS(2024),
    [anon_sym_co_yield] = ACTIONS(2024),
    [anon_sym_R_DQUOTE] = ACTIONS(2026),
    [anon_sym_LR_DQUOTE] = ACTIONS(2026),
    [anon_sym_uR_DQUOTE] = ACTIONS(2026),
    [anon_sym_UR_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2026),
    [anon_sym_co_await] = ACTIONS(2024),
    [anon_sym_new] = ACTIONS(2024),
    [anon_sym_requires] = ACTIONS(2024),
    [sym_this] = ACTIONS(2024),
    [anon_sym___launch_bounds__] = ACTIONS(2024),
  },
  [STATE(385)] = {
    [sym_identifier] = ACTIONS(2048),
    [aux_sym_preproc_include_token1] = ACTIONS(2048),
    [aux_sym_preproc_def_token1] = ACTIONS(2048),
    [aux_sym_preproc_if_token1] = ACTIONS(2048),
    [aux_sym_preproc_if_token2] = ACTIONS(2048),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2048),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2048),
    [sym_preproc_directive] = ACTIONS(2048),
    [anon_sym_LPAREN2] = ACTIONS(2050),
    [anon_sym_BANG] = ACTIONS(2050),
    [anon_sym_TILDE] = ACTIONS(2050),
    [anon_sym_DASH] = ACTIONS(2048),
    [anon_sym_PLUS] = ACTIONS(2048),
    [anon_sym_STAR] = ACTIONS(2050),
    [anon_sym_AMP_AMP] = ACTIONS(2050),
    [anon_sym_AMP] = ACTIONS(2048),
    [anon_sym_SEMI] = ACTIONS(2050),
    [anon_sym___extension__] = ACTIONS(2048),
    [anon_sym_typedef] = ACTIONS(2048),
    [anon_sym___device__] = ACTIONS(2048),
    [anon_sym___host__] = ACTIONS(2048),
    [anon_sym___global__] = ACTIONS(2048),
    [anon_sym___forceinline__] = ACTIONS(2048),
    [anon_sym___noinline__] = ACTIONS(2048),
    [anon_sym_virtual] = ACTIONS(2048),
    [anon_sym_extern] = ACTIONS(2048),
    [anon_sym___attribute__] = ACTIONS(2048),
    [anon_sym___attribute] = ACTIONS(2048),
    [anon_sym_COLON_COLON] = ACTIONS(2050),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2050),
    [anon_sym___declspec] = ACTIONS(2048),
    [anon_sym___based] = ACTIONS(2048),
    [anon_sym___cdecl] = ACTIONS(2048),
    [anon_sym___clrcall] = ACTIONS(2048),
    [anon_sym___stdcall] = ACTIONS(2048),
    [anon_sym___fastcall] = ACTIONS(2048),
    [anon_sym___thiscall] = ACTIONS(2048),
    [anon_sym___vectorcall] = ACTIONS(2048),
    [anon_sym_LBRACE] = ACTIONS(2050),
    [anon_sym_signed] = ACTIONS(2048),
    [anon_sym_unsigned] = ACTIONS(2048),
    [anon_sym_long] = ACTIONS(2048),
    [anon_sym_short] = ACTIONS(2048),
    [anon_sym_LBRACK] = ACTIONS(2048),
    [anon_sym_static] = ACTIONS(2048),
    [anon_sym_register] = ACTIONS(2048),
    [anon_sym_inline] = ACTIONS(2048),
    [anon_sym___inline] = ACTIONS(2048),
    [anon_sym___inline__] = ACTIONS(2048),
    [anon_sym___forceinline] = ACTIONS(2048),
    [anon_sym_thread_local] = ACTIONS(2048),
    [anon_sym___thread] = ACTIONS(2048),
    [anon_sym_const] = ACTIONS(2048),
    [anon_sym_constexpr] = ACTIONS(2048),
    [anon_sym_volatile] = ACTIONS(2048),
    [anon_sym_restrict] = ACTIONS(2048),
    [anon_sym___restrict__] = ACTIONS(2048),
    [anon_sym__Atomic] = ACTIONS(2048),
    [anon_sym__Noreturn] = ACTIONS(2048),
    [anon_sym_noreturn] = ACTIONS(2048),
    [anon_sym__Nonnull] = ACTIONS(2048),
    [anon_sym_mutable] = ACTIONS(2048),
    [anon_sym_constinit] = ACTIONS(2048),
    [anon_sym_consteval] = ACTIONS(2048),
    [anon_sym___shared__] = ACTIONS(2048),
    [anon_sym___local__] = ACTIONS(2048),
    [anon_sym___constant__] = ACTIONS(2048),
    [anon_sym___managed__] = ACTIONS(2048),
    [anon_sym___grid_constant__] = ACTIONS(2048),
    [anon_sym_alignas] = ACTIONS(2048),
    [anon_sym__Alignas] = ACTIONS(2048),
    [sym_primitive_type] = ACTIONS(2048),
    [anon_sym_enum] = ACTIONS(2048),
    [anon_sym_class] = ACTIONS(2048),
    [anon_sym_struct] = ACTIONS(2048),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_if] = ACTIONS(2048),
    [anon_sym_else] = ACTIONS(2048),
    [anon_sym_switch] = ACTIONS(2048),
    [anon_sym_case] = ACTIONS(2048),
    [anon_sym_default] = ACTIONS(2048),
    [anon_sym_while] = ACTIONS(2048),
    [anon_sym_do] = ACTIONS(2048),
    [anon_sym_for] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2048),
    [anon_sym_break] = ACTIONS(2048),
    [anon_sym_continue] = ACTIONS(2048),
    [anon_sym_goto] = ACTIONS(2048),
    [anon_sym___try] = ACTIONS(2048),
    [anon_sym___leave] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2048),
    [anon_sym_compl] = ACTIONS(2048),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2048),
    [anon_sym___alignof__] = ACTIONS(2048),
    [anon_sym___alignof] = ACTIONS(2048),
    [anon_sym__alignof] = ACTIONS(2048),
    [anon_sym_alignof] = ACTIONS(2048),
    [anon_sym__Alignof] = ACTIONS(2048),
    [anon_sym_offsetof] = ACTIONS(2048),
    [anon_sym__Generic] = ACTIONS(2048),
    [anon_sym_asm] = ACTIONS(2048),
    [anon_sym___asm__] = ACTIONS(2048),
    [anon_sym___asm] = ACTIONS(2048),
    [sym_number_literal] = ACTIONS(2050),
    [anon_sym_L_SQUOTE] = ACTIONS(2050),
    [anon_sym_u_SQUOTE] = ACTIONS(2050),
    [anon_sym_U_SQUOTE] = ACTIONS(2050),
    [anon_sym_u8_SQUOTE] = ACTIONS(2050),
    [anon_sym_SQUOTE] = ACTIONS(2050),
    [anon_sym_L_DQUOTE] = ACTIONS(2050),
    [anon_sym_u_DQUOTE] = ACTIONS(2050),
    [anon_sym_U_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8_DQUOTE] = ACTIONS(2050),
    [anon_sym_DQUOTE] = ACTIONS(2050),
    [sym_true] = ACTIONS(2048),
    [sym_false] = ACTIONS(2048),
    [anon_sym_NULL] = ACTIONS(2048),
    [anon_sym_nullptr] = ACTIONS(2048),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2048),
    [anon_sym_decltype] = ACTIONS(2048),
    [anon_sym_explicit] = ACTIONS(2048),
    [anon_sym_typename] = ACTIONS(2048),
    [anon_sym_template] = ACTIONS(2048),
    [anon_sym_operator] = ACTIONS(2048),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_delete] = ACTIONS(2048),
    [anon_sym_throw] = ACTIONS(2048),
    [anon_sym_namespace] = ACTIONS(2048),
    [anon_sym_using] = ACTIONS(2048),
    [anon_sym_static_assert] = ACTIONS(2048),
    [anon_sym_concept] = ACTIONS(2048),
    [anon_sym_co_return] = ACTIONS(2048),
    [anon_sym_co_yield] = ACTIONS(2048),
    [anon_sym_R_DQUOTE] = ACTIONS(2050),
    [anon_sym_LR_DQUOTE] = ACTIONS(2050),
    [anon_sym_uR_DQUOTE] = ACTIONS(2050),
    [anon_sym_UR_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2050),
    [anon_sym_co_await] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(2048),
    [anon_sym_requires] = ACTIONS(2048),
    [sym_this] = ACTIONS(2048),
    [anon_sym___launch_bounds__] = ACTIONS(2048),
  },
  [STATE(386)] = {
    [sym_identifier] = ACTIONS(2056),
    [aux_sym_preproc_include_token1] = ACTIONS(2056),
    [aux_sym_preproc_def_token1] = ACTIONS(2056),
    [aux_sym_preproc_if_token1] = ACTIONS(2056),
    [aux_sym_preproc_if_token2] = ACTIONS(2056),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2056),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2056),
    [sym_preproc_directive] = ACTIONS(2056),
    [anon_sym_LPAREN2] = ACTIONS(2058),
    [anon_sym_BANG] = ACTIONS(2058),
    [anon_sym_TILDE] = ACTIONS(2058),
    [anon_sym_DASH] = ACTIONS(2056),
    [anon_sym_PLUS] = ACTIONS(2056),
    [anon_sym_STAR] = ACTIONS(2058),
    [anon_sym_AMP_AMP] = ACTIONS(2058),
    [anon_sym_AMP] = ACTIONS(2056),
    [anon_sym_SEMI] = ACTIONS(2058),
    [anon_sym___extension__] = ACTIONS(2056),
    [anon_sym_typedef] = ACTIONS(2056),
    [anon_sym___device__] = ACTIONS(2056),
    [anon_sym___host__] = ACTIONS(2056),
    [anon_sym___global__] = ACTIONS(2056),
    [anon_sym___forceinline__] = ACTIONS(2056),
    [anon_sym___noinline__] = ACTIONS(2056),
    [anon_sym_virtual] = ACTIONS(2056),
    [anon_sym_extern] = ACTIONS(2056),
    [anon_sym___attribute__] = ACTIONS(2056),
    [anon_sym___attribute] = ACTIONS(2056),
    [anon_sym_COLON_COLON] = ACTIONS(2058),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2058),
    [anon_sym___declspec] = ACTIONS(2056),
    [anon_sym___based] = ACTIONS(2056),
    [anon_sym___cdecl] = ACTIONS(2056),
    [anon_sym___clrcall] = ACTIONS(2056),
    [anon_sym___stdcall] = ACTIONS(2056),
    [anon_sym___fastcall] = ACTIONS(2056),
    [anon_sym___thiscall] = ACTIONS(2056),
    [anon_sym___vectorcall] = ACTIONS(2056),
    [anon_sym_LBRACE] = ACTIONS(2058),
    [anon_sym_signed] = ACTIONS(2056),
    [anon_sym_unsigned] = ACTIONS(2056),
    [anon_sym_long] = ACTIONS(2056),
    [anon_sym_short] = ACTIONS(2056),
    [anon_sym_LBRACK] = ACTIONS(2056),
    [anon_sym_static] = ACTIONS(2056),
    [anon_sym_register] = ACTIONS(2056),
    [anon_sym_inline] = ACTIONS(2056),
    [anon_sym___inline] = ACTIONS(2056),
    [anon_sym___inline__] = ACTIONS(2056),
    [anon_sym___forceinline] = ACTIONS(2056),
    [anon_sym_thread_local] = ACTIONS(2056),
    [anon_sym___thread] = ACTIONS(2056),
    [anon_sym_const] = ACTIONS(2056),
    [anon_sym_constexpr] = ACTIONS(2056),
    [anon_sym_volatile] = ACTIONS(2056),
    [anon_sym_restrict] = ACTIONS(2056),
    [anon_sym___restrict__] = ACTIONS(2056),
    [anon_sym__Atomic] = ACTIONS(2056),
    [anon_sym__Noreturn] = ACTIONS(2056),
    [anon_sym_noreturn] = ACTIONS(2056),
    [anon_sym__Nonnull] = ACTIONS(2056),
    [anon_sym_mutable] = ACTIONS(2056),
    [anon_sym_constinit] = ACTIONS(2056),
    [anon_sym_consteval] = ACTIONS(2056),
    [anon_sym___shared__] = ACTIONS(2056),
    [anon_sym___local__] = ACTIONS(2056),
    [anon_sym___constant__] = ACTIONS(2056),
    [anon_sym___managed__] = ACTIONS(2056),
    [anon_sym___grid_constant__] = ACTIONS(2056),
    [anon_sym_alignas] = ACTIONS(2056),
    [anon_sym__Alignas] = ACTIONS(2056),
    [sym_primitive_type] = ACTIONS(2056),
    [anon_sym_enum] = ACTIONS(2056),
    [anon_sym_class] = ACTIONS(2056),
    [anon_sym_struct] = ACTIONS(2056),
    [anon_sym_union] = ACTIONS(2056),
    [anon_sym_if] = ACTIONS(2056),
    [anon_sym_else] = ACTIONS(2056),
    [anon_sym_switch] = ACTIONS(2056),
    [anon_sym_case] = ACTIONS(2056),
    [anon_sym_default] = ACTIONS(2056),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_do] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2056),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_break] = ACTIONS(2056),
    [anon_sym_continue] = ACTIONS(2056),
    [anon_sym_goto] = ACTIONS(2056),
    [anon_sym___try] = ACTIONS(2056),
    [anon_sym___leave] = ACTIONS(2056),
    [anon_sym_not] = ACTIONS(2056),
    [anon_sym_compl] = ACTIONS(2056),
    [anon_sym_DASH_DASH] = ACTIONS(2058),
    [anon_sym_PLUS_PLUS] = ACTIONS(2058),
    [anon_sym_sizeof] = ACTIONS(2056),
    [anon_sym___alignof__] = ACTIONS(2056),
    [anon_sym___alignof] = ACTIONS(2056),
    [anon_sym__alignof] = ACTIONS(2056),
    [anon_sym_alignof] = ACTIONS(2056),
    [anon_sym__Alignof] = ACTIONS(2056),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2056),
    [anon_sym_asm] = ACTIONS(2056),
    [anon_sym___asm__] = ACTIONS(2056),
    [anon_sym___asm] = ACTIONS(2056),
    [sym_number_literal] = ACTIONS(2058),
    [anon_sym_L_SQUOTE] = ACTIONS(2058),
    [anon_sym_u_SQUOTE] = ACTIONS(2058),
    [anon_sym_U_SQUOTE] = ACTIONS(2058),
    [anon_sym_u8_SQUOTE] = ACTIONS(2058),
    [anon_sym_SQUOTE] = ACTIONS(2058),
    [anon_sym_L_DQUOTE] = ACTIONS(2058),
    [anon_sym_u_DQUOTE] = ACTIONS(2058),
    [anon_sym_U_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8_DQUOTE] = ACTIONS(2058),
    [anon_sym_DQUOTE] = ACTIONS(2058),
    [sym_true] = ACTIONS(2056),
    [sym_false] = ACTIONS(2056),
    [anon_sym_NULL] = ACTIONS(2056),
    [anon_sym_nullptr] = ACTIONS(2056),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2056),
    [anon_sym_decltype] = ACTIONS(2056),
    [anon_sym_explicit] = ACTIONS(2056),
    [anon_sym_typename] = ACTIONS(2056),
    [anon_sym_template] = ACTIONS(2056),
    [anon_sym_operator] = ACTIONS(2056),
    [anon_sym_try] = ACTIONS(2056),
    [anon_sym_delete] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2056),
    [anon_sym_namespace] = ACTIONS(2056),
    [anon_sym_using] = ACTIONS(2056),
    [anon_sym_static_assert] = ACTIONS(2056),
    [anon_sym_concept] = ACTIONS(2056),
    [anon_sym_co_return] = ACTIONS(2056),
    [anon_sym_co_yield] = ACTIONS(2056),
    [anon_sym_R_DQUOTE] = ACTIONS(2058),
    [anon_sym_LR_DQUOTE] = ACTIONS(2058),
    [anon_sym_uR_DQUOTE] = ACTIONS(2058),
    [anon_sym_UR_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2058),
    [anon_sym_co_await] = ACTIONS(2056),
    [anon_sym_new] = ACTIONS(2056),
    [anon_sym_requires] = ACTIONS(2056),
    [sym_this] = ACTIONS(2056),
    [anon_sym___launch_bounds__] = ACTIONS(2056),
  },
  [STATE(387)] = {
    [sym_identifier] = ACTIONS(2066),
    [aux_sym_preproc_include_token1] = ACTIONS(2066),
    [aux_sym_preproc_def_token1] = ACTIONS(2066),
    [aux_sym_preproc_if_token1] = ACTIONS(2066),
    [aux_sym_preproc_if_token2] = ACTIONS(2066),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2066),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2066),
    [sym_preproc_directive] = ACTIONS(2066),
    [anon_sym_LPAREN2] = ACTIONS(2068),
    [anon_sym_BANG] = ACTIONS(2068),
    [anon_sym_TILDE] = ACTIONS(2068),
    [anon_sym_DASH] = ACTIONS(2066),
    [anon_sym_PLUS] = ACTIONS(2066),
    [anon_sym_STAR] = ACTIONS(2068),
    [anon_sym_AMP_AMP] = ACTIONS(2068),
    [anon_sym_AMP] = ACTIONS(2066),
    [anon_sym_SEMI] = ACTIONS(2068),
    [anon_sym___extension__] = ACTIONS(2066),
    [anon_sym_typedef] = ACTIONS(2066),
    [anon_sym___device__] = ACTIONS(2066),
    [anon_sym___host__] = ACTIONS(2066),
    [anon_sym___global__] = ACTIONS(2066),
    [anon_sym___forceinline__] = ACTIONS(2066),
    [anon_sym___noinline__] = ACTIONS(2066),
    [anon_sym_virtual] = ACTIONS(2066),
    [anon_sym_extern] = ACTIONS(2066),
    [anon_sym___attribute__] = ACTIONS(2066),
    [anon_sym___attribute] = ACTIONS(2066),
    [anon_sym_COLON_COLON] = ACTIONS(2068),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2068),
    [anon_sym___declspec] = ACTIONS(2066),
    [anon_sym___based] = ACTIONS(2066),
    [anon_sym___cdecl] = ACTIONS(2066),
    [anon_sym___clrcall] = ACTIONS(2066),
    [anon_sym___stdcall] = ACTIONS(2066),
    [anon_sym___fastcall] = ACTIONS(2066),
    [anon_sym___thiscall] = ACTIONS(2066),
    [anon_sym___vectorcall] = ACTIONS(2066),
    [anon_sym_LBRACE] = ACTIONS(2068),
    [anon_sym_signed] = ACTIONS(2066),
    [anon_sym_unsigned] = ACTIONS(2066),
    [anon_sym_long] = ACTIONS(2066),
    [anon_sym_short] = ACTIONS(2066),
    [anon_sym_LBRACK] = ACTIONS(2066),
    [anon_sym_static] = ACTIONS(2066),
    [anon_sym_register] = ACTIONS(2066),
    [anon_sym_inline] = ACTIONS(2066),
    [anon_sym___inline] = ACTIONS(2066),
    [anon_sym___inline__] = ACTIONS(2066),
    [anon_sym___forceinline] = ACTIONS(2066),
    [anon_sym_thread_local] = ACTIONS(2066),
    [anon_sym___thread] = ACTIONS(2066),
    [anon_sym_const] = ACTIONS(2066),
    [anon_sym_constexpr] = ACTIONS(2066),
    [anon_sym_volatile] = ACTIONS(2066),
    [anon_sym_restrict] = ACTIONS(2066),
    [anon_sym___restrict__] = ACTIONS(2066),
    [anon_sym__Atomic] = ACTIONS(2066),
    [anon_sym__Noreturn] = ACTIONS(2066),
    [anon_sym_noreturn] = ACTIONS(2066),
    [anon_sym__Nonnull] = ACTIONS(2066),
    [anon_sym_mutable] = ACTIONS(2066),
    [anon_sym_constinit] = ACTIONS(2066),
    [anon_sym_consteval] = ACTIONS(2066),
    [anon_sym___shared__] = ACTIONS(2066),
    [anon_sym___local__] = ACTIONS(2066),
    [anon_sym___constant__] = ACTIONS(2066),
    [anon_sym___managed__] = ACTIONS(2066),
    [anon_sym___grid_constant__] = ACTIONS(2066),
    [anon_sym_alignas] = ACTIONS(2066),
    [anon_sym__Alignas] = ACTIONS(2066),
    [sym_primitive_type] = ACTIONS(2066),
    [anon_sym_enum] = ACTIONS(2066),
    [anon_sym_class] = ACTIONS(2066),
    [anon_sym_struct] = ACTIONS(2066),
    [anon_sym_union] = ACTIONS(2066),
    [anon_sym_if] = ACTIONS(2066),
    [anon_sym_else] = ACTIONS(2066),
    [anon_sym_switch] = ACTIONS(2066),
    [anon_sym_case] = ACTIONS(2066),
    [anon_sym_default] = ACTIONS(2066),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_do] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2066),
    [anon_sym_return] = ACTIONS(2066),
    [anon_sym_break] = ACTIONS(2066),
    [anon_sym_continue] = ACTIONS(2066),
    [anon_sym_goto] = ACTIONS(2066),
    [anon_sym___try] = ACTIONS(2066),
    [anon_sym___leave] = ACTIONS(2066),
    [anon_sym_not] = ACTIONS(2066),
    [anon_sym_compl] = ACTIONS(2066),
    [anon_sym_DASH_DASH] = ACTIONS(2068),
    [anon_sym_PLUS_PLUS] = ACTIONS(2068),
    [anon_sym_sizeof] = ACTIONS(2066),
    [anon_sym___alignof__] = ACTIONS(2066),
    [anon_sym___alignof] = ACTIONS(2066),
    [anon_sym__alignof] = ACTIONS(2066),
    [anon_sym_alignof] = ACTIONS(2066),
    [anon_sym__Alignof] = ACTIONS(2066),
    [anon_sym_offsetof] = ACTIONS(2066),
    [anon_sym__Generic] = ACTIONS(2066),
    [anon_sym_asm] = ACTIONS(2066),
    [anon_sym___asm__] = ACTIONS(2066),
    [anon_sym___asm] = ACTIONS(2066),
    [sym_number_literal] = ACTIONS(2068),
    [anon_sym_L_SQUOTE] = ACTIONS(2068),
    [anon_sym_u_SQUOTE] = ACTIONS(2068),
    [anon_sym_U_SQUOTE] = ACTIONS(2068),
    [anon_sym_u8_SQUOTE] = ACTIONS(2068),
    [anon_sym_SQUOTE] = ACTIONS(2068),
    [anon_sym_L_DQUOTE] = ACTIONS(2068),
    [anon_sym_u_DQUOTE] = ACTIONS(2068),
    [anon_sym_U_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8_DQUOTE] = ACTIONS(2068),
    [anon_sym_DQUOTE] = ACTIONS(2068),
    [sym_true] = ACTIONS(2066),
    [sym_false] = ACTIONS(2066),
    [anon_sym_NULL] = ACTIONS(2066),
    [anon_sym_nullptr] = ACTIONS(2066),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2066),
    [anon_sym_decltype] = ACTIONS(2066),
    [anon_sym_explicit] = ACTIONS(2066),
    [anon_sym_typename] = ACTIONS(2066),
    [anon_sym_template] = ACTIONS(2066),
    [anon_sym_operator] = ACTIONS(2066),
    [anon_sym_try] = ACTIONS(2066),
    [anon_sym_delete] = ACTIONS(2066),
    [anon_sym_throw] = ACTIONS(2066),
    [anon_sym_namespace] = ACTIONS(2066),
    [anon_sym_using] = ACTIONS(2066),
    [anon_sym_static_assert] = ACTIONS(2066),
    [anon_sym_concept] = ACTIONS(2066),
    [anon_sym_co_return] = ACTIONS(2066),
    [anon_sym_co_yield] = ACTIONS(2066),
    [anon_sym_R_DQUOTE] = ACTIONS(2068),
    [anon_sym_LR_DQUOTE] = ACTIONS(2068),
    [anon_sym_uR_DQUOTE] = ACTIONS(2068),
    [anon_sym_UR_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2068),
    [anon_sym_co_await] = ACTIONS(2066),
    [anon_sym_new] = ACTIONS(2066),
    [anon_sym_requires] = ACTIONS(2066),
    [sym_this] = ACTIONS(2066),
    [anon_sym___launch_bounds__] = ACTIONS(2066),
  },
  [STATE(388)] = {
    [sym_identifier] = ACTIONS(2098),
    [aux_sym_preproc_include_token1] = ACTIONS(2098),
    [aux_sym_preproc_def_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token2] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2098),
    [sym_preproc_directive] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP_AMP] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2098),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym___device__] = ACTIONS(2098),
    [anon_sym___host__] = ACTIONS(2098),
    [anon_sym___global__] = ACTIONS(2098),
    [anon_sym___forceinline__] = ACTIONS(2098),
    [anon_sym___noinline__] = ACTIONS(2098),
    [anon_sym_virtual] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym___attribute] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym___based] = ACTIONS(2098),
    [anon_sym___cdecl] = ACTIONS(2098),
    [anon_sym___clrcall] = ACTIONS(2098),
    [anon_sym___stdcall] = ACTIONS(2098),
    [anon_sym___fastcall] = ACTIONS(2098),
    [anon_sym___thiscall] = ACTIONS(2098),
    [anon_sym___vectorcall] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym__Nonnull] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym___shared__] = ACTIONS(2098),
    [anon_sym___local__] = ACTIONS(2098),
    [anon_sym___constant__] = ACTIONS(2098),
    [anon_sym___managed__] = ACTIONS(2098),
    [anon_sym___grid_constant__] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_case] = ACTIONS(2098),
    [anon_sym_default] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [anon_sym___asm] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [anon_sym_explicit] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_operator] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_namespace] = ACTIONS(2098),
    [anon_sym_using] = ACTIONS(2098),
    [anon_sym_static_assert] = ACTIONS(2098),
    [anon_sym_concept] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym___launch_bounds__] = ACTIONS(2098),
  },
  [STATE(389)] = {
    [sym_identifier] = ACTIONS(2170),
    [aux_sym_preproc_include_token1] = ACTIONS(2170),
    [aux_sym_preproc_def_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token2] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2170),
    [sym_preproc_directive] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP_AMP] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2170),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym___device__] = ACTIONS(2170),
    [anon_sym___host__] = ACTIONS(2170),
    [anon_sym___global__] = ACTIONS(2170),
    [anon_sym___forceinline__] = ACTIONS(2170),
    [anon_sym___noinline__] = ACTIONS(2170),
    [anon_sym_virtual] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym___attribute] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym___based] = ACTIONS(2170),
    [anon_sym___cdecl] = ACTIONS(2170),
    [anon_sym___clrcall] = ACTIONS(2170),
    [anon_sym___stdcall] = ACTIONS(2170),
    [anon_sym___fastcall] = ACTIONS(2170),
    [anon_sym___thiscall] = ACTIONS(2170),
    [anon_sym___vectorcall] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym__Nonnull] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym___shared__] = ACTIONS(2170),
    [anon_sym___local__] = ACTIONS(2170),
    [anon_sym___constant__] = ACTIONS(2170),
    [anon_sym___managed__] = ACTIONS(2170),
    [anon_sym___grid_constant__] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_case] = ACTIONS(2170),
    [anon_sym_default] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [anon_sym___asm] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [anon_sym_explicit] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_operator] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_namespace] = ACTIONS(2170),
    [anon_sym_using] = ACTIONS(2170),
    [anon_sym_static_assert] = ACTIONS(2170),
    [anon_sym_concept] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym___launch_bounds__] = ACTIONS(2170),
  },
  [STATE(390)] = {
    [sym_identifier] = ACTIONS(2174),
    [aux_sym_preproc_include_token1] = ACTIONS(2174),
    [aux_sym_preproc_def_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token2] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2174),
    [sym_preproc_directive] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP_AMP] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2174),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym___device__] = ACTIONS(2174),
    [anon_sym___host__] = ACTIONS(2174),
    [anon_sym___global__] = ACTIONS(2174),
    [anon_sym___forceinline__] = ACTIONS(2174),
    [anon_sym___noinline__] = ACTIONS(2174),
    [anon_sym_virtual] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym___attribute] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym___based] = ACTIONS(2174),
    [anon_sym___cdecl] = ACTIONS(2174),
    [anon_sym___clrcall] = ACTIONS(2174),
    [anon_sym___stdcall] = ACTIONS(2174),
    [anon_sym___fastcall] = ACTIONS(2174),
    [anon_sym___thiscall] = ACTIONS(2174),
    [anon_sym___vectorcall] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym__Nonnull] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym___shared__] = ACTIONS(2174),
    [anon_sym___local__] = ACTIONS(2174),
    [anon_sym___constant__] = ACTIONS(2174),
    [anon_sym___managed__] = ACTIONS(2174),
    [anon_sym___grid_constant__] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_case] = ACTIONS(2174),
    [anon_sym_default] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [anon_sym___asm] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [anon_sym_explicit] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_operator] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_namespace] = ACTIONS(2174),
    [anon_sym_using] = ACTIONS(2174),
    [anon_sym_static_assert] = ACTIONS(2174),
    [anon_sym_concept] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym___launch_bounds__] = ACTIONS(2174),
  },
  [STATE(391)] = {
    [sym_identifier] = ACTIONS(2150),
    [aux_sym_preproc_include_token1] = ACTIONS(2150),
    [aux_sym_preproc_def_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2150),
    [sym_preproc_directive] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP_AMP] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2150),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym___device__] = ACTIONS(2150),
    [anon_sym___host__] = ACTIONS(2150),
    [anon_sym___global__] = ACTIONS(2150),
    [anon_sym___forceinline__] = ACTIONS(2150),
    [anon_sym___noinline__] = ACTIONS(2150),
    [anon_sym_virtual] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym___attribute] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym___based] = ACTIONS(2150),
    [anon_sym___cdecl] = ACTIONS(2150),
    [anon_sym___clrcall] = ACTIONS(2150),
    [anon_sym___stdcall] = ACTIONS(2150),
    [anon_sym___fastcall] = ACTIONS(2150),
    [anon_sym___thiscall] = ACTIONS(2150),
    [anon_sym___vectorcall] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_RBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym__Nonnull] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym___shared__] = ACTIONS(2150),
    [anon_sym___local__] = ACTIONS(2150),
    [anon_sym___constant__] = ACTIONS(2150),
    [anon_sym___managed__] = ACTIONS(2150),
    [anon_sym___grid_constant__] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_case] = ACTIONS(2150),
    [anon_sym_default] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [anon_sym___asm] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [anon_sym_explicit] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_operator] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_namespace] = ACTIONS(2150),
    [anon_sym_using] = ACTIONS(2150),
    [anon_sym_static_assert] = ACTIONS(2150),
    [anon_sym_concept] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym___launch_bounds__] = ACTIONS(2150),
  },
  [STATE(392)] = {
    [sym_identifier] = ACTIONS(2040),
    [aux_sym_preproc_include_token1] = ACTIONS(2040),
    [aux_sym_preproc_def_token1] = ACTIONS(2040),
    [aux_sym_preproc_if_token1] = ACTIONS(2040),
    [aux_sym_preproc_if_token2] = ACTIONS(2040),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2040),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2040),
    [sym_preproc_directive] = ACTIONS(2040),
    [anon_sym_LPAREN2] = ACTIONS(2042),
    [anon_sym_BANG] = ACTIONS(2042),
    [anon_sym_TILDE] = ACTIONS(2042),
    [anon_sym_DASH] = ACTIONS(2040),
    [anon_sym_PLUS] = ACTIONS(2040),
    [anon_sym_STAR] = ACTIONS(2042),
    [anon_sym_AMP_AMP] = ACTIONS(2042),
    [anon_sym_AMP] = ACTIONS(2040),
    [anon_sym_SEMI] = ACTIONS(2042),
    [anon_sym___extension__] = ACTIONS(2040),
    [anon_sym_typedef] = ACTIONS(2040),
    [anon_sym___device__] = ACTIONS(2040),
    [anon_sym___host__] = ACTIONS(2040),
    [anon_sym___global__] = ACTIONS(2040),
    [anon_sym___forceinline__] = ACTIONS(2040),
    [anon_sym___noinline__] = ACTIONS(2040),
    [anon_sym_virtual] = ACTIONS(2040),
    [anon_sym_extern] = ACTIONS(2040),
    [anon_sym___attribute__] = ACTIONS(2040),
    [anon_sym___attribute] = ACTIONS(2040),
    [anon_sym_COLON_COLON] = ACTIONS(2042),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2042),
    [anon_sym___declspec] = ACTIONS(2040),
    [anon_sym___based] = ACTIONS(2040),
    [anon_sym___cdecl] = ACTIONS(2040),
    [anon_sym___clrcall] = ACTIONS(2040),
    [anon_sym___stdcall] = ACTIONS(2040),
    [anon_sym___fastcall] = ACTIONS(2040),
    [anon_sym___thiscall] = ACTIONS(2040),
    [anon_sym___vectorcall] = ACTIONS(2040),
    [anon_sym_LBRACE] = ACTIONS(2042),
    [anon_sym_signed] = ACTIONS(2040),
    [anon_sym_unsigned] = ACTIONS(2040),
    [anon_sym_long] = ACTIONS(2040),
    [anon_sym_short] = ACTIONS(2040),
    [anon_sym_LBRACK] = ACTIONS(2040),
    [anon_sym_static] = ACTIONS(2040),
    [anon_sym_register] = ACTIONS(2040),
    [anon_sym_inline] = ACTIONS(2040),
    [anon_sym___inline] = ACTIONS(2040),
    [anon_sym___inline__] = ACTIONS(2040),
    [anon_sym___forceinline] = ACTIONS(2040),
    [anon_sym_thread_local] = ACTIONS(2040),
    [anon_sym___thread] = ACTIONS(2040),
    [anon_sym_const] = ACTIONS(2040),
    [anon_sym_constexpr] = ACTIONS(2040),
    [anon_sym_volatile] = ACTIONS(2040),
    [anon_sym_restrict] = ACTIONS(2040),
    [anon_sym___restrict__] = ACTIONS(2040),
    [anon_sym__Atomic] = ACTIONS(2040),
    [anon_sym__Noreturn] = ACTIONS(2040),
    [anon_sym_noreturn] = ACTIONS(2040),
    [anon_sym__Nonnull] = ACTIONS(2040),
    [anon_sym_mutable] = ACTIONS(2040),
    [anon_sym_constinit] = ACTIONS(2040),
    [anon_sym_consteval] = ACTIONS(2040),
    [anon_sym___shared__] = ACTIONS(2040),
    [anon_sym___local__] = ACTIONS(2040),
    [anon_sym___constant__] = ACTIONS(2040),
    [anon_sym___managed__] = ACTIONS(2040),
    [anon_sym___grid_constant__] = ACTIONS(2040),
    [anon_sym_alignas] = ACTIONS(2040),
    [anon_sym__Alignas] = ACTIONS(2040),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2040),
    [anon_sym_class] = ACTIONS(2040),
    [anon_sym_struct] = ACTIONS(2040),
    [anon_sym_union] = ACTIONS(2040),
    [anon_sym_if] = ACTIONS(2040),
    [anon_sym_else] = ACTIONS(2040),
    [anon_sym_switch] = ACTIONS(2040),
    [anon_sym_case] = ACTIONS(2040),
    [anon_sym_default] = ACTIONS(2040),
    [anon_sym_while] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(2040),
    [anon_sym_for] = ACTIONS(2040),
    [anon_sym_return] = ACTIONS(2040),
    [anon_sym_break] = ACTIONS(2040),
    [anon_sym_continue] = ACTIONS(2040),
    [anon_sym_goto] = ACTIONS(2040),
    [anon_sym___try] = ACTIONS(2040),
    [anon_sym___leave] = ACTIONS(2040),
    [anon_sym_not] = ACTIONS(2040),
    [anon_sym_compl] = ACTIONS(2040),
    [anon_sym_DASH_DASH] = ACTIONS(2042),
    [anon_sym_PLUS_PLUS] = ACTIONS(2042),
    [anon_sym_sizeof] = ACTIONS(2040),
    [anon_sym___alignof__] = ACTIONS(2040),
    [anon_sym___alignof] = ACTIONS(2040),
    [anon_sym__alignof] = ACTIONS(2040),
    [anon_sym_alignof] = ACTIONS(2040),
    [anon_sym__Alignof] = ACTIONS(2040),
    [anon_sym_offsetof] = ACTIONS(2040),
    [anon_sym__Generic] = ACTIONS(2040),
    [anon_sym_asm] = ACTIONS(2040),
    [anon_sym___asm__] = ACTIONS(2040),
    [anon_sym___asm] = ACTIONS(2040),
    [sym_number_literal] = ACTIONS(2042),
    [anon_sym_L_SQUOTE] = ACTIONS(2042),
    [anon_sym_u_SQUOTE] = ACTIONS(2042),
    [anon_sym_U_SQUOTE] = ACTIONS(2042),
    [anon_sym_u8_SQUOTE] = ACTIONS(2042),
    [anon_sym_SQUOTE] = ACTIONS(2042),
    [anon_sym_L_DQUOTE] = ACTIONS(2042),
    [anon_sym_u_DQUOTE] = ACTIONS(2042),
    [anon_sym_U_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8_DQUOTE] = ACTIONS(2042),
    [anon_sym_DQUOTE] = ACTIONS(2042),
    [sym_true] = ACTIONS(2040),
    [sym_false] = ACTIONS(2040),
    [anon_sym_NULL] = ACTIONS(2040),
    [anon_sym_nullptr] = ACTIONS(2040),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2040),
    [anon_sym_decltype] = ACTIONS(2040),
    [anon_sym_explicit] = ACTIONS(2040),
    [anon_sym_typename] = ACTIONS(2040),
    [anon_sym_template] = ACTIONS(2040),
    [anon_sym_operator] = ACTIONS(2040),
    [anon_sym_try] = ACTIONS(2040),
    [anon_sym_delete] = ACTIONS(2040),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_namespace] = ACTIONS(2040),
    [anon_sym_using] = ACTIONS(2040),
    [anon_sym_static_assert] = ACTIONS(2040),
    [anon_sym_concept] = ACTIONS(2040),
    [anon_sym_co_return] = ACTIONS(2040),
    [anon_sym_co_yield] = ACTIONS(2040),
    [anon_sym_R_DQUOTE] = ACTIONS(2042),
    [anon_sym_LR_DQUOTE] = ACTIONS(2042),
    [anon_sym_uR_DQUOTE] = ACTIONS(2042),
    [anon_sym_UR_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2042),
    [anon_sym_co_await] = ACTIONS(2040),
    [anon_sym_new] = ACTIONS(2040),
    [anon_sym_requires] = ACTIONS(2040),
    [sym_this] = ACTIONS(2040),
    [anon_sym___launch_bounds__] = ACTIONS(2040),
  },
  [STATE(393)] = {
    [sym_identifier] = ACTIONS(2062),
    [aux_sym_preproc_include_token1] = ACTIONS(2062),
    [aux_sym_preproc_def_token1] = ACTIONS(2062),
    [aux_sym_preproc_if_token1] = ACTIONS(2062),
    [aux_sym_preproc_if_token2] = ACTIONS(2062),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2062),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2062),
    [sym_preproc_directive] = ACTIONS(2062),
    [anon_sym_LPAREN2] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(2064),
    [anon_sym_TILDE] = ACTIONS(2064),
    [anon_sym_DASH] = ACTIONS(2062),
    [anon_sym_PLUS] = ACTIONS(2062),
    [anon_sym_STAR] = ACTIONS(2064),
    [anon_sym_AMP_AMP] = ACTIONS(2064),
    [anon_sym_AMP] = ACTIONS(2062),
    [anon_sym_SEMI] = ACTIONS(2064),
    [anon_sym___extension__] = ACTIONS(2062),
    [anon_sym_typedef] = ACTIONS(2062),
    [anon_sym___device__] = ACTIONS(2062),
    [anon_sym___host__] = ACTIONS(2062),
    [anon_sym___global__] = ACTIONS(2062),
    [anon_sym___forceinline__] = ACTIONS(2062),
    [anon_sym___noinline__] = ACTIONS(2062),
    [anon_sym_virtual] = ACTIONS(2062),
    [anon_sym_extern] = ACTIONS(2062),
    [anon_sym___attribute__] = ACTIONS(2062),
    [anon_sym___attribute] = ACTIONS(2062),
    [anon_sym_COLON_COLON] = ACTIONS(2064),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2064),
    [anon_sym___declspec] = ACTIONS(2062),
    [anon_sym___based] = ACTIONS(2062),
    [anon_sym___cdecl] = ACTIONS(2062),
    [anon_sym___clrcall] = ACTIONS(2062),
    [anon_sym___stdcall] = ACTIONS(2062),
    [anon_sym___fastcall] = ACTIONS(2062),
    [anon_sym___thiscall] = ACTIONS(2062),
    [anon_sym___vectorcall] = ACTIONS(2062),
    [anon_sym_LBRACE] = ACTIONS(2064),
    [anon_sym_signed] = ACTIONS(2062),
    [anon_sym_unsigned] = ACTIONS(2062),
    [anon_sym_long] = ACTIONS(2062),
    [anon_sym_short] = ACTIONS(2062),
    [anon_sym_LBRACK] = ACTIONS(2062),
    [anon_sym_static] = ACTIONS(2062),
    [anon_sym_register] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym___inline] = ACTIONS(2062),
    [anon_sym___inline__] = ACTIONS(2062),
    [anon_sym___forceinline] = ACTIONS(2062),
    [anon_sym_thread_local] = ACTIONS(2062),
    [anon_sym___thread] = ACTIONS(2062),
    [anon_sym_const] = ACTIONS(2062),
    [anon_sym_constexpr] = ACTIONS(2062),
    [anon_sym_volatile] = ACTIONS(2062),
    [anon_sym_restrict] = ACTIONS(2062),
    [anon_sym___restrict__] = ACTIONS(2062),
    [anon_sym__Atomic] = ACTIONS(2062),
    [anon_sym__Noreturn] = ACTIONS(2062),
    [anon_sym_noreturn] = ACTIONS(2062),
    [anon_sym__Nonnull] = ACTIONS(2062),
    [anon_sym_mutable] = ACTIONS(2062),
    [anon_sym_constinit] = ACTIONS(2062),
    [anon_sym_consteval] = ACTIONS(2062),
    [anon_sym___shared__] = ACTIONS(2062),
    [anon_sym___local__] = ACTIONS(2062),
    [anon_sym___constant__] = ACTIONS(2062),
    [anon_sym___managed__] = ACTIONS(2062),
    [anon_sym___grid_constant__] = ACTIONS(2062),
    [anon_sym_alignas] = ACTIONS(2062),
    [anon_sym__Alignas] = ACTIONS(2062),
    [sym_primitive_type] = ACTIONS(2062),
    [anon_sym_enum] = ACTIONS(2062),
    [anon_sym_class] = ACTIONS(2062),
    [anon_sym_struct] = ACTIONS(2062),
    [anon_sym_union] = ACTIONS(2062),
    [anon_sym_if] = ACTIONS(2062),
    [anon_sym_else] = ACTIONS(2062),
    [anon_sym_switch] = ACTIONS(2062),
    [anon_sym_case] = ACTIONS(2062),
    [anon_sym_default] = ACTIONS(2062),
    [anon_sym_while] = ACTIONS(2062),
    [anon_sym_do] = ACTIONS(2062),
    [anon_sym_for] = ACTIONS(2062),
    [anon_sym_return] = ACTIONS(2062),
    [anon_sym_break] = ACTIONS(2062),
    [anon_sym_continue] = ACTIONS(2062),
    [anon_sym_goto] = ACTIONS(2062),
    [anon_sym___try] = ACTIONS(2062),
    [anon_sym___leave] = ACTIONS(2062),
    [anon_sym_not] = ACTIONS(2062),
    [anon_sym_compl] = ACTIONS(2062),
    [anon_sym_DASH_DASH] = ACTIONS(2064),
    [anon_sym_PLUS_PLUS] = ACTIONS(2064),
    [anon_sym_sizeof] = ACTIONS(2062),
    [anon_sym___alignof__] = ACTIONS(2062),
    [anon_sym___alignof] = ACTIONS(2062),
    [anon_sym__alignof] = ACTIONS(2062),
    [anon_sym_alignof] = ACTIONS(2062),
    [anon_sym__Alignof] = ACTIONS(2062),
    [anon_sym_offsetof] = ACTIONS(2062),
    [anon_sym__Generic] = ACTIONS(2062),
    [anon_sym_asm] = ACTIONS(2062),
    [anon_sym___asm__] = ACTIONS(2062),
    [anon_sym___asm] = ACTIONS(2062),
    [sym_number_literal] = ACTIONS(2064),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2064),
    [anon_sym_u_DQUOTE] = ACTIONS(2064),
    [anon_sym_U_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8_DQUOTE] = ACTIONS(2064),
    [anon_sym_DQUOTE] = ACTIONS(2064),
    [sym_true] = ACTIONS(2062),
    [sym_false] = ACTIONS(2062),
    [anon_sym_NULL] = ACTIONS(2062),
    [anon_sym_nullptr] = ACTIONS(2062),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2062),
    [anon_sym_decltype] = ACTIONS(2062),
    [anon_sym_explicit] = ACTIONS(2062),
    [anon_sym_typename] = ACTIONS(2062),
    [anon_sym_template] = ACTIONS(2062),
    [anon_sym_operator] = ACTIONS(2062),
    [anon_sym_try] = ACTIONS(2062),
    [anon_sym_delete] = ACTIONS(2062),
    [anon_sym_throw] = ACTIONS(2062),
    [anon_sym_namespace] = ACTIONS(2062),
    [anon_sym_using] = ACTIONS(2062),
    [anon_sym_static_assert] = ACTIONS(2062),
    [anon_sym_concept] = ACTIONS(2062),
    [anon_sym_co_return] = ACTIONS(2062),
    [anon_sym_co_yield] = ACTIONS(2062),
    [anon_sym_R_DQUOTE] = ACTIONS(2064),
    [anon_sym_LR_DQUOTE] = ACTIONS(2064),
    [anon_sym_uR_DQUOTE] = ACTIONS(2064),
    [anon_sym_UR_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2064),
    [anon_sym_co_await] = ACTIONS(2062),
    [anon_sym_new] = ACTIONS(2062),
    [anon_sym_requires] = ACTIONS(2062),
    [sym_this] = ACTIONS(2062),
    [anon_sym___launch_bounds__] = ACTIONS(2062),
  },
  [STATE(394)] = {
    [sym_identifier] = ACTIONS(2052),
    [aux_sym_preproc_include_token1] = ACTIONS(2052),
    [aux_sym_preproc_def_token1] = ACTIONS(2052),
    [aux_sym_preproc_if_token1] = ACTIONS(2052),
    [aux_sym_preproc_if_token2] = ACTIONS(2052),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2052),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2052),
    [sym_preproc_directive] = ACTIONS(2052),
    [anon_sym_LPAREN2] = ACTIONS(2054),
    [anon_sym_BANG] = ACTIONS(2054),
    [anon_sym_TILDE] = ACTIONS(2054),
    [anon_sym_DASH] = ACTIONS(2052),
    [anon_sym_PLUS] = ACTIONS(2052),
    [anon_sym_STAR] = ACTIONS(2054),
    [anon_sym_AMP_AMP] = ACTIONS(2054),
    [anon_sym_AMP] = ACTIONS(2052),
    [anon_sym_SEMI] = ACTIONS(2054),
    [anon_sym___extension__] = ACTIONS(2052),
    [anon_sym_typedef] = ACTIONS(2052),
    [anon_sym___device__] = ACTIONS(2052),
    [anon_sym___host__] = ACTIONS(2052),
    [anon_sym___global__] = ACTIONS(2052),
    [anon_sym___forceinline__] = ACTIONS(2052),
    [anon_sym___noinline__] = ACTIONS(2052),
    [anon_sym_virtual] = ACTIONS(2052),
    [anon_sym_extern] = ACTIONS(2052),
    [anon_sym___attribute__] = ACTIONS(2052),
    [anon_sym___attribute] = ACTIONS(2052),
    [anon_sym_COLON_COLON] = ACTIONS(2054),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2054),
    [anon_sym___declspec] = ACTIONS(2052),
    [anon_sym___based] = ACTIONS(2052),
    [anon_sym___cdecl] = ACTIONS(2052),
    [anon_sym___clrcall] = ACTIONS(2052),
    [anon_sym___stdcall] = ACTIONS(2052),
    [anon_sym___fastcall] = ACTIONS(2052),
    [anon_sym___thiscall] = ACTIONS(2052),
    [anon_sym___vectorcall] = ACTIONS(2052),
    [anon_sym_LBRACE] = ACTIONS(2054),
    [anon_sym_signed] = ACTIONS(2052),
    [anon_sym_unsigned] = ACTIONS(2052),
    [anon_sym_long] = ACTIONS(2052),
    [anon_sym_short] = ACTIONS(2052),
    [anon_sym_LBRACK] = ACTIONS(2052),
    [anon_sym_static] = ACTIONS(2052),
    [anon_sym_register] = ACTIONS(2052),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym___inline] = ACTIONS(2052),
    [anon_sym___inline__] = ACTIONS(2052),
    [anon_sym___forceinline] = ACTIONS(2052),
    [anon_sym_thread_local] = ACTIONS(2052),
    [anon_sym___thread] = ACTIONS(2052),
    [anon_sym_const] = ACTIONS(2052),
    [anon_sym_constexpr] = ACTIONS(2052),
    [anon_sym_volatile] = ACTIONS(2052),
    [anon_sym_restrict] = ACTIONS(2052),
    [anon_sym___restrict__] = ACTIONS(2052),
    [anon_sym__Atomic] = ACTIONS(2052),
    [anon_sym__Noreturn] = ACTIONS(2052),
    [anon_sym_noreturn] = ACTIONS(2052),
    [anon_sym__Nonnull] = ACTIONS(2052),
    [anon_sym_mutable] = ACTIONS(2052),
    [anon_sym_constinit] = ACTIONS(2052),
    [anon_sym_consteval] = ACTIONS(2052),
    [anon_sym___shared__] = ACTIONS(2052),
    [anon_sym___local__] = ACTIONS(2052),
    [anon_sym___constant__] = ACTIONS(2052),
    [anon_sym___managed__] = ACTIONS(2052),
    [anon_sym___grid_constant__] = ACTIONS(2052),
    [anon_sym_alignas] = ACTIONS(2052),
    [anon_sym__Alignas] = ACTIONS(2052),
    [sym_primitive_type] = ACTIONS(2052),
    [anon_sym_enum] = ACTIONS(2052),
    [anon_sym_class] = ACTIONS(2052),
    [anon_sym_struct] = ACTIONS(2052),
    [anon_sym_union] = ACTIONS(2052),
    [anon_sym_if] = ACTIONS(2052),
    [anon_sym_else] = ACTIONS(2052),
    [anon_sym_switch] = ACTIONS(2052),
    [anon_sym_case] = ACTIONS(2052),
    [anon_sym_default] = ACTIONS(2052),
    [anon_sym_while] = ACTIONS(2052),
    [anon_sym_do] = ACTIONS(2052),
    [anon_sym_for] = ACTIONS(2052),
    [anon_sym_return] = ACTIONS(2052),
    [anon_sym_break] = ACTIONS(2052),
    [anon_sym_continue] = ACTIONS(2052),
    [anon_sym_goto] = ACTIONS(2052),
    [anon_sym___try] = ACTIONS(2052),
    [anon_sym___leave] = ACTIONS(2052),
    [anon_sym_not] = ACTIONS(2052),
    [anon_sym_compl] = ACTIONS(2052),
    [anon_sym_DASH_DASH] = ACTIONS(2054),
    [anon_sym_PLUS_PLUS] = ACTIONS(2054),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2052),
    [anon_sym___alignof] = ACTIONS(2052),
    [anon_sym__alignof] = ACTIONS(2052),
    [anon_sym_alignof] = ACTIONS(2052),
    [anon_sym__Alignof] = ACTIONS(2052),
    [anon_sym_offsetof] = ACTIONS(2052),
    [anon_sym__Generic] = ACTIONS(2052),
    [anon_sym_asm] = ACTIONS(2052),
    [anon_sym___asm__] = ACTIONS(2052),
    [anon_sym___asm] = ACTIONS(2052),
    [sym_number_literal] = ACTIONS(2054),
    [anon_sym_L_SQUOTE] = ACTIONS(2054),
    [anon_sym_u_SQUOTE] = ACTIONS(2054),
    [anon_sym_U_SQUOTE] = ACTIONS(2054),
    [anon_sym_u8_SQUOTE] = ACTIONS(2054),
    [anon_sym_SQUOTE] = ACTIONS(2054),
    [anon_sym_L_DQUOTE] = ACTIONS(2054),
    [anon_sym_u_DQUOTE] = ACTIONS(2054),
    [anon_sym_U_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8_DQUOTE] = ACTIONS(2054),
    [anon_sym_DQUOTE] = ACTIONS(2054),
    [sym_true] = ACTIONS(2052),
    [sym_false] = ACTIONS(2052),
    [anon_sym_NULL] = ACTIONS(2052),
    [anon_sym_nullptr] = ACTIONS(2052),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2052),
    [anon_sym_decltype] = ACTIONS(2052),
    [anon_sym_explicit] = ACTIONS(2052),
    [anon_sym_typename] = ACTIONS(2052),
    [anon_sym_template] = ACTIONS(2052),
    [anon_sym_operator] = ACTIONS(2052),
    [anon_sym_try] = ACTIONS(2052),
    [anon_sym_delete] = ACTIONS(2052),
    [anon_sym_throw] = ACTIONS(2052),
    [anon_sym_namespace] = ACTIONS(2052),
    [anon_sym_using] = ACTIONS(2052),
    [anon_sym_static_assert] = ACTIONS(2052),
    [anon_sym_concept] = ACTIONS(2052),
    [anon_sym_co_return] = ACTIONS(2052),
    [anon_sym_co_yield] = ACTIONS(2052),
    [anon_sym_R_DQUOTE] = ACTIONS(2054),
    [anon_sym_LR_DQUOTE] = ACTIONS(2054),
    [anon_sym_uR_DQUOTE] = ACTIONS(2054),
    [anon_sym_UR_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2054),
    [anon_sym_co_await] = ACTIONS(2052),
    [anon_sym_new] = ACTIONS(2052),
    [anon_sym_requires] = ACTIONS(2052),
    [sym_this] = ACTIONS(2052),
    [anon_sym___launch_bounds__] = ACTIONS(2052),
  },
  [STATE(395)] = {
    [ts_builtin_sym_end] = ACTIONS(2022),
    [sym_identifier] = ACTIONS(2020),
    [aux_sym_preproc_include_token1] = ACTIONS(2020),
    [aux_sym_preproc_def_token1] = ACTIONS(2020),
    [aux_sym_preproc_if_token1] = ACTIONS(2020),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2020),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2020),
    [sym_preproc_directive] = ACTIONS(2020),
    [anon_sym_LPAREN2] = ACTIONS(2022),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2020),
    [anon_sym_PLUS] = ACTIONS(2020),
    [anon_sym_STAR] = ACTIONS(2022),
    [anon_sym_AMP_AMP] = ACTIONS(2022),
    [anon_sym_AMP] = ACTIONS(2020),
    [anon_sym_SEMI] = ACTIONS(2022),
    [anon_sym___extension__] = ACTIONS(2020),
    [anon_sym_typedef] = ACTIONS(2020),
    [anon_sym___device__] = ACTIONS(2020),
    [anon_sym___host__] = ACTIONS(2020),
    [anon_sym___global__] = ACTIONS(2020),
    [anon_sym___forceinline__] = ACTIONS(2020),
    [anon_sym___noinline__] = ACTIONS(2020),
    [anon_sym_virtual] = ACTIONS(2020),
    [anon_sym_extern] = ACTIONS(2020),
    [anon_sym___attribute__] = ACTIONS(2020),
    [anon_sym___attribute] = ACTIONS(2020),
    [anon_sym_COLON_COLON] = ACTIONS(2022),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2022),
    [anon_sym___declspec] = ACTIONS(2020),
    [anon_sym___based] = ACTIONS(2020),
    [anon_sym___cdecl] = ACTIONS(2020),
    [anon_sym___clrcall] = ACTIONS(2020),
    [anon_sym___stdcall] = ACTIONS(2020),
    [anon_sym___fastcall] = ACTIONS(2020),
    [anon_sym___thiscall] = ACTIONS(2020),
    [anon_sym___vectorcall] = ACTIONS(2020),
    [anon_sym_LBRACE] = ACTIONS(2022),
    [anon_sym_signed] = ACTIONS(2020),
    [anon_sym_unsigned] = ACTIONS(2020),
    [anon_sym_long] = ACTIONS(2020),
    [anon_sym_short] = ACTIONS(2020),
    [anon_sym_LBRACK] = ACTIONS(2020),
    [anon_sym_static] = ACTIONS(2020),
    [anon_sym_register] = ACTIONS(2020),
    [anon_sym_inline] = ACTIONS(2020),
    [anon_sym___inline] = ACTIONS(2020),
    [anon_sym___inline__] = ACTIONS(2020),
    [anon_sym___forceinline] = ACTIONS(2020),
    [anon_sym_thread_local] = ACTIONS(2020),
    [anon_sym___thread] = ACTIONS(2020),
    [anon_sym_const] = ACTIONS(2020),
    [anon_sym_constexpr] = ACTIONS(2020),
    [anon_sym_volatile] = ACTIONS(2020),
    [anon_sym_restrict] = ACTIONS(2020),
    [anon_sym___restrict__] = ACTIONS(2020),
    [anon_sym__Atomic] = ACTIONS(2020),
    [anon_sym__Noreturn] = ACTIONS(2020),
    [anon_sym_noreturn] = ACTIONS(2020),
    [anon_sym__Nonnull] = ACTIONS(2020),
    [anon_sym_mutable] = ACTIONS(2020),
    [anon_sym_constinit] = ACTIONS(2020),
    [anon_sym_consteval] = ACTIONS(2020),
    [anon_sym___shared__] = ACTIONS(2020),
    [anon_sym___local__] = ACTIONS(2020),
    [anon_sym___constant__] = ACTIONS(2020),
    [anon_sym___managed__] = ACTIONS(2020),
    [anon_sym___grid_constant__] = ACTIONS(2020),
    [anon_sym_alignas] = ACTIONS(2020),
    [anon_sym__Alignas] = ACTIONS(2020),
    [sym_primitive_type] = ACTIONS(2020),
    [anon_sym_enum] = ACTIONS(2020),
    [anon_sym_class] = ACTIONS(2020),
    [anon_sym_struct] = ACTIONS(2020),
    [anon_sym_union] = ACTIONS(2020),
    [anon_sym_if] = ACTIONS(2020),
    [anon_sym_else] = ACTIONS(2020),
    [anon_sym_switch] = ACTIONS(2020),
    [anon_sym_case] = ACTIONS(2020),
    [anon_sym_default] = ACTIONS(2020),
    [anon_sym_while] = ACTIONS(2020),
    [anon_sym_do] = ACTIONS(2020),
    [anon_sym_for] = ACTIONS(2020),
    [anon_sym_return] = ACTIONS(2020),
    [anon_sym_break] = ACTIONS(2020),
    [anon_sym_continue] = ACTIONS(2020),
    [anon_sym_goto] = ACTIONS(2020),
    [anon_sym___try] = ACTIONS(2020),
    [anon_sym___leave] = ACTIONS(2020),
    [anon_sym_not] = ACTIONS(2020),
    [anon_sym_compl] = ACTIONS(2020),
    [anon_sym_DASH_DASH] = ACTIONS(2022),
    [anon_sym_PLUS_PLUS] = ACTIONS(2022),
    [anon_sym_sizeof] = ACTIONS(2020),
    [anon_sym___alignof__] = ACTIONS(2020),
    [anon_sym___alignof] = ACTIONS(2020),
    [anon_sym__alignof] = ACTIONS(2020),
    [anon_sym_alignof] = ACTIONS(2020),
    [anon_sym__Alignof] = ACTIONS(2020),
    [anon_sym_offsetof] = ACTIONS(2020),
    [anon_sym__Generic] = ACTIONS(2020),
    [anon_sym_asm] = ACTIONS(2020),
    [anon_sym___asm__] = ACTIONS(2020),
    [anon_sym___asm] = ACTIONS(2020),
    [sym_number_literal] = ACTIONS(2022),
    [anon_sym_L_SQUOTE] = ACTIONS(2022),
    [anon_sym_u_SQUOTE] = ACTIONS(2022),
    [anon_sym_U_SQUOTE] = ACTIONS(2022),
    [anon_sym_u8_SQUOTE] = ACTIONS(2022),
    [anon_sym_SQUOTE] = ACTIONS(2022),
    [anon_sym_L_DQUOTE] = ACTIONS(2022),
    [anon_sym_u_DQUOTE] = ACTIONS(2022),
    [anon_sym_U_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8_DQUOTE] = ACTIONS(2022),
    [anon_sym_DQUOTE] = ACTIONS(2022),
    [sym_true] = ACTIONS(2020),
    [sym_false] = ACTIONS(2020),
    [anon_sym_NULL] = ACTIONS(2020),
    [anon_sym_nullptr] = ACTIONS(2020),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2020),
    [anon_sym_decltype] = ACTIONS(2020),
    [anon_sym_explicit] = ACTIONS(2020),
    [anon_sym_typename] = ACTIONS(2020),
    [anon_sym_template] = ACTIONS(2020),
    [anon_sym_operator] = ACTIONS(2020),
    [anon_sym_try] = ACTIONS(2020),
    [anon_sym_delete] = ACTIONS(2020),
    [anon_sym_throw] = ACTIONS(2020),
    [anon_sym_namespace] = ACTIONS(2020),
    [anon_sym_using] = ACTIONS(2020),
    [anon_sym_static_assert] = ACTIONS(2020),
    [anon_sym_concept] = ACTIONS(2020),
    [anon_sym_co_return] = ACTIONS(2020),
    [anon_sym_co_yield] = ACTIONS(2020),
    [anon_sym_R_DQUOTE] = ACTIONS(2022),
    [anon_sym_LR_DQUOTE] = ACTIONS(2022),
    [anon_sym_uR_DQUOTE] = ACTIONS(2022),
    [anon_sym_UR_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2022),
    [anon_sym_co_await] = ACTIONS(2020),
    [anon_sym_new] = ACTIONS(2020),
    [anon_sym_requires] = ACTIONS(2020),
    [sym_this] = ACTIONS(2020),
    [anon_sym___launch_bounds__] = ACTIONS(2020),
  },
  [STATE(396)] = {
    [ts_builtin_sym_end] = ACTIONS(2168),
    [sym_identifier] = ACTIONS(2166),
    [aux_sym_preproc_include_token1] = ACTIONS(2166),
    [aux_sym_preproc_def_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2166),
    [sym_preproc_directive] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP_AMP] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2166),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym___device__] = ACTIONS(2166),
    [anon_sym___host__] = ACTIONS(2166),
    [anon_sym___global__] = ACTIONS(2166),
    [anon_sym___forceinline__] = ACTIONS(2166),
    [anon_sym___noinline__] = ACTIONS(2166),
    [anon_sym_virtual] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym___attribute] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym___based] = ACTIONS(2166),
    [anon_sym___cdecl] = ACTIONS(2166),
    [anon_sym___clrcall] = ACTIONS(2166),
    [anon_sym___stdcall] = ACTIONS(2166),
    [anon_sym___fastcall] = ACTIONS(2166),
    [anon_sym___thiscall] = ACTIONS(2166),
    [anon_sym___vectorcall] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym__Nonnull] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym___shared__] = ACTIONS(2166),
    [anon_sym___local__] = ACTIONS(2166),
    [anon_sym___constant__] = ACTIONS(2166),
    [anon_sym___managed__] = ACTIONS(2166),
    [anon_sym___grid_constant__] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym_default] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [anon_sym___asm] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [anon_sym_explicit] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_operator] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_namespace] = ACTIONS(2166),
    [anon_sym_using] = ACTIONS(2166),
    [anon_sym_static_assert] = ACTIONS(2166),
    [anon_sym_concept] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym___launch_bounds__] = ACTIONS(2166),
  },
  [STATE(397)] = {
    [sym_identifier] = ACTIONS(2154),
    [aux_sym_preproc_include_token1] = ACTIONS(2154),
    [aux_sym_preproc_def_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token2] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2154),
    [sym_preproc_directive] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP_AMP] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2154),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym___device__] = ACTIONS(2154),
    [anon_sym___host__] = ACTIONS(2154),
    [anon_sym___global__] = ACTIONS(2154),
    [anon_sym___forceinline__] = ACTIONS(2154),
    [anon_sym___noinline__] = ACTIONS(2154),
    [anon_sym_virtual] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym___attribute] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym___based] = ACTIONS(2154),
    [anon_sym___cdecl] = ACTIONS(2154),
    [anon_sym___clrcall] = ACTIONS(2154),
    [anon_sym___stdcall] = ACTIONS(2154),
    [anon_sym___fastcall] = ACTIONS(2154),
    [anon_sym___thiscall] = ACTIONS(2154),
    [anon_sym___vectorcall] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym__Nonnull] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym___shared__] = ACTIONS(2154),
    [anon_sym___local__] = ACTIONS(2154),
    [anon_sym___constant__] = ACTIONS(2154),
    [anon_sym___managed__] = ACTIONS(2154),
    [anon_sym___grid_constant__] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_case] = ACTIONS(2154),
    [anon_sym_default] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [anon_sym___asm] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [anon_sym_explicit] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_operator] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_namespace] = ACTIONS(2154),
    [anon_sym_using] = ACTIONS(2154),
    [anon_sym_static_assert] = ACTIONS(2154),
    [anon_sym_concept] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym___launch_bounds__] = ACTIONS(2154),
  },
  [STATE(398)] = {
    [sym_identifier] = ACTIONS(2158),
    [aux_sym_preproc_include_token1] = ACTIONS(2158),
    [aux_sym_preproc_def_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token2] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2158),
    [sym_preproc_directive] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP_AMP] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2158),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym___device__] = ACTIONS(2158),
    [anon_sym___host__] = ACTIONS(2158),
    [anon_sym___global__] = ACTIONS(2158),
    [anon_sym___forceinline__] = ACTIONS(2158),
    [anon_sym___noinline__] = ACTIONS(2158),
    [anon_sym_virtual] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym___attribute] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym___based] = ACTIONS(2158),
    [anon_sym___cdecl] = ACTIONS(2158),
    [anon_sym___clrcall] = ACTIONS(2158),
    [anon_sym___stdcall] = ACTIONS(2158),
    [anon_sym___fastcall] = ACTIONS(2158),
    [anon_sym___thiscall] = ACTIONS(2158),
    [anon_sym___vectorcall] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym__Nonnull] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym___shared__] = ACTIONS(2158),
    [anon_sym___local__] = ACTIONS(2158),
    [anon_sym___constant__] = ACTIONS(2158),
    [anon_sym___managed__] = ACTIONS(2158),
    [anon_sym___grid_constant__] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_case] = ACTIONS(2158),
    [anon_sym_default] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [anon_sym___asm] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [anon_sym_explicit] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_operator] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_namespace] = ACTIONS(2158),
    [anon_sym_using] = ACTIONS(2158),
    [anon_sym_static_assert] = ACTIONS(2158),
    [anon_sym_concept] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym___launch_bounds__] = ACTIONS(2158),
  },
  [STATE(399)] = {
    [sym_identifier] = ACTIONS(2162),
    [aux_sym_preproc_include_token1] = ACTIONS(2162),
    [aux_sym_preproc_def_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token2] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2162),
    [sym_preproc_directive] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP_AMP] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2162),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym___device__] = ACTIONS(2162),
    [anon_sym___host__] = ACTIONS(2162),
    [anon_sym___global__] = ACTIONS(2162),
    [anon_sym___forceinline__] = ACTIONS(2162),
    [anon_sym___noinline__] = ACTIONS(2162),
    [anon_sym_virtual] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym___attribute] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym___based] = ACTIONS(2162),
    [anon_sym___cdecl] = ACTIONS(2162),
    [anon_sym___clrcall] = ACTIONS(2162),
    [anon_sym___stdcall] = ACTIONS(2162),
    [anon_sym___fastcall] = ACTIONS(2162),
    [anon_sym___thiscall] = ACTIONS(2162),
    [anon_sym___vectorcall] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym__Nonnull] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym___shared__] = ACTIONS(2162),
    [anon_sym___local__] = ACTIONS(2162),
    [anon_sym___constant__] = ACTIONS(2162),
    [anon_sym___managed__] = ACTIONS(2162),
    [anon_sym___grid_constant__] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_case] = ACTIONS(2162),
    [anon_sym_default] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [anon_sym___asm] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [anon_sym_explicit] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_operator] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_namespace] = ACTIONS(2162),
    [anon_sym_using] = ACTIONS(2162),
    [anon_sym_static_assert] = ACTIONS(2162),
    [anon_sym_concept] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym___launch_bounds__] = ACTIONS(2162),
  },
  [STATE(400)] = {
    [sym_identifier] = ACTIONS(2186),
    [aux_sym_preproc_include_token1] = ACTIONS(2186),
    [aux_sym_preproc_def_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token2] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2186),
    [sym_preproc_directive] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP_AMP] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2186),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym___device__] = ACTIONS(2186),
    [anon_sym___host__] = ACTIONS(2186),
    [anon_sym___global__] = ACTIONS(2186),
    [anon_sym___forceinline__] = ACTIONS(2186),
    [anon_sym___noinline__] = ACTIONS(2186),
    [anon_sym_virtual] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym___attribute] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym___based] = ACTIONS(2186),
    [anon_sym___cdecl] = ACTIONS(2186),
    [anon_sym___clrcall] = ACTIONS(2186),
    [anon_sym___stdcall] = ACTIONS(2186),
    [anon_sym___fastcall] = ACTIONS(2186),
    [anon_sym___thiscall] = ACTIONS(2186),
    [anon_sym___vectorcall] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym__Nonnull] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym___shared__] = ACTIONS(2186),
    [anon_sym___local__] = ACTIONS(2186),
    [anon_sym___constant__] = ACTIONS(2186),
    [anon_sym___managed__] = ACTIONS(2186),
    [anon_sym___grid_constant__] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_case] = ACTIONS(2186),
    [anon_sym_default] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [anon_sym___asm] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [anon_sym_explicit] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_operator] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_namespace] = ACTIONS(2186),
    [anon_sym_using] = ACTIONS(2186),
    [anon_sym_static_assert] = ACTIONS(2186),
    [anon_sym_concept] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym___launch_bounds__] = ACTIONS(2186),
  },
  [STATE(401)] = {
    [sym_identifier] = ACTIONS(2214),
    [aux_sym_preproc_include_token1] = ACTIONS(2214),
    [aux_sym_preproc_def_token1] = ACTIONS(2214),
    [aux_sym_preproc_if_token1] = ACTIONS(2214),
    [aux_sym_preproc_if_token2] = ACTIONS(2214),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2214),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2214),
    [sym_preproc_directive] = ACTIONS(2214),
    [anon_sym_LPAREN2] = ACTIONS(2216),
    [anon_sym_BANG] = ACTIONS(2216),
    [anon_sym_TILDE] = ACTIONS(2216),
    [anon_sym_DASH] = ACTIONS(2214),
    [anon_sym_PLUS] = ACTIONS(2214),
    [anon_sym_STAR] = ACTIONS(2216),
    [anon_sym_AMP_AMP] = ACTIONS(2216),
    [anon_sym_AMP] = ACTIONS(2214),
    [anon_sym_SEMI] = ACTIONS(2216),
    [anon_sym___extension__] = ACTIONS(2214),
    [anon_sym_typedef] = ACTIONS(2214),
    [anon_sym___device__] = ACTIONS(2214),
    [anon_sym___host__] = ACTIONS(2214),
    [anon_sym___global__] = ACTIONS(2214),
    [anon_sym___forceinline__] = ACTIONS(2214),
    [anon_sym___noinline__] = ACTIONS(2214),
    [anon_sym_virtual] = ACTIONS(2214),
    [anon_sym_extern] = ACTIONS(2214),
    [anon_sym___attribute__] = ACTIONS(2214),
    [anon_sym___attribute] = ACTIONS(2214),
    [anon_sym_COLON_COLON] = ACTIONS(2216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2216),
    [anon_sym___declspec] = ACTIONS(2214),
    [anon_sym___based] = ACTIONS(2214),
    [anon_sym___cdecl] = ACTIONS(2214),
    [anon_sym___clrcall] = ACTIONS(2214),
    [anon_sym___stdcall] = ACTIONS(2214),
    [anon_sym___fastcall] = ACTIONS(2214),
    [anon_sym___thiscall] = ACTIONS(2214),
    [anon_sym___vectorcall] = ACTIONS(2214),
    [anon_sym_LBRACE] = ACTIONS(2216),
    [anon_sym_signed] = ACTIONS(2214),
    [anon_sym_unsigned] = ACTIONS(2214),
    [anon_sym_long] = ACTIONS(2214),
    [anon_sym_short] = ACTIONS(2214),
    [anon_sym_LBRACK] = ACTIONS(2214),
    [anon_sym_static] = ACTIONS(2214),
    [anon_sym_register] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(2214),
    [anon_sym___inline] = ACTIONS(2214),
    [anon_sym___inline__] = ACTIONS(2214),
    [anon_sym___forceinline] = ACTIONS(2214),
    [anon_sym_thread_local] = ACTIONS(2214),
    [anon_sym___thread] = ACTIONS(2214),
    [anon_sym_const] = ACTIONS(2214),
    [anon_sym_constexpr] = ACTIONS(2214),
    [anon_sym_volatile] = ACTIONS(2214),
    [anon_sym_restrict] = ACTIONS(2214),
    [anon_sym___restrict__] = ACTIONS(2214),
    [anon_sym__Atomic] = ACTIONS(2214),
    [anon_sym__Noreturn] = ACTIONS(2214),
    [anon_sym_noreturn] = ACTIONS(2214),
    [anon_sym__Nonnull] = ACTIONS(2214),
    [anon_sym_mutable] = ACTIONS(2214),
    [anon_sym_constinit] = ACTIONS(2214),
    [anon_sym_consteval] = ACTIONS(2214),
    [anon_sym___shared__] = ACTIONS(2214),
    [anon_sym___local__] = ACTIONS(2214),
    [anon_sym___constant__] = ACTIONS(2214),
    [anon_sym___managed__] = ACTIONS(2214),
    [anon_sym___grid_constant__] = ACTIONS(2214),
    [anon_sym_alignas] = ACTIONS(2214),
    [anon_sym__Alignas] = ACTIONS(2214),
    [sym_primitive_type] = ACTIONS(2214),
    [anon_sym_enum] = ACTIONS(2214),
    [anon_sym_class] = ACTIONS(2214),
    [anon_sym_struct] = ACTIONS(2214),
    [anon_sym_union] = ACTIONS(2214),
    [anon_sym_if] = ACTIONS(2214),
    [anon_sym_else] = ACTIONS(2214),
    [anon_sym_switch] = ACTIONS(2214),
    [anon_sym_case] = ACTIONS(2214),
    [anon_sym_default] = ACTIONS(2214),
    [anon_sym_while] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2214),
    [anon_sym_for] = ACTIONS(2214),
    [anon_sym_return] = ACTIONS(2214),
    [anon_sym_break] = ACTIONS(2214),
    [anon_sym_continue] = ACTIONS(2214),
    [anon_sym_goto] = ACTIONS(2214),
    [anon_sym___try] = ACTIONS(2214),
    [anon_sym___leave] = ACTIONS(2214),
    [anon_sym_not] = ACTIONS(2214),
    [anon_sym_compl] = ACTIONS(2214),
    [anon_sym_DASH_DASH] = ACTIONS(2216),
    [anon_sym_PLUS_PLUS] = ACTIONS(2216),
    [anon_sym_sizeof] = ACTIONS(2214),
    [anon_sym___alignof__] = ACTIONS(2214),
    [anon_sym___alignof] = ACTIONS(2214),
    [anon_sym__alignof] = ACTIONS(2214),
    [anon_sym_alignof] = ACTIONS(2214),
    [anon_sym__Alignof] = ACTIONS(2214),
    [anon_sym_offsetof] = ACTIONS(2214),
    [anon_sym__Generic] = ACTIONS(2214),
    [anon_sym_asm] = ACTIONS(2214),
    [anon_sym___asm__] = ACTIONS(2214),
    [anon_sym___asm] = ACTIONS(2214),
    [sym_number_literal] = ACTIONS(2216),
    [anon_sym_L_SQUOTE] = ACTIONS(2216),
    [anon_sym_u_SQUOTE] = ACTIONS(2216),
    [anon_sym_U_SQUOTE] = ACTIONS(2216),
    [anon_sym_u8_SQUOTE] = ACTIONS(2216),
    [anon_sym_SQUOTE] = ACTIONS(2216),
    [anon_sym_L_DQUOTE] = ACTIONS(2216),
    [anon_sym_u_DQUOTE] = ACTIONS(2216),
    [anon_sym_U_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8_DQUOTE] = ACTIONS(2216),
    [anon_sym_DQUOTE] = ACTIONS(2216),
    [sym_true] = ACTIONS(2214),
    [sym_false] = ACTIONS(2214),
    [anon_sym_NULL] = ACTIONS(2214),
    [anon_sym_nullptr] = ACTIONS(2214),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2214),
    [anon_sym_decltype] = ACTIONS(2214),
    [anon_sym_explicit] = ACTIONS(2214),
    [anon_sym_typename] = ACTIONS(2214),
    [anon_sym_template] = ACTIONS(2214),
    [anon_sym_operator] = ACTIONS(2214),
    [anon_sym_try] = ACTIONS(2214),
    [anon_sym_delete] = ACTIONS(2214),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_namespace] = ACTIONS(2214),
    [anon_sym_using] = ACTIONS(2214),
    [anon_sym_static_assert] = ACTIONS(2214),
    [anon_sym_concept] = ACTIONS(2214),
    [anon_sym_co_return] = ACTIONS(2214),
    [anon_sym_co_yield] = ACTIONS(2214),
    [anon_sym_R_DQUOTE] = ACTIONS(2216),
    [anon_sym_LR_DQUOTE] = ACTIONS(2216),
    [anon_sym_uR_DQUOTE] = ACTIONS(2216),
    [anon_sym_UR_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2216),
    [anon_sym_co_await] = ACTIONS(2214),
    [anon_sym_new] = ACTIONS(2214),
    [anon_sym_requires] = ACTIONS(2214),
    [sym_this] = ACTIONS(2214),
    [anon_sym___launch_bounds__] = ACTIONS(2214),
  },
  [STATE(402)] = {
    [ts_builtin_sym_end] = ACTIONS(2096),
    [sym_identifier] = ACTIONS(2094),
    [aux_sym_preproc_include_token1] = ACTIONS(2094),
    [aux_sym_preproc_def_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2094),
    [sym_preproc_directive] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP_AMP] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2094),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym___device__] = ACTIONS(2094),
    [anon_sym___host__] = ACTIONS(2094),
    [anon_sym___global__] = ACTIONS(2094),
    [anon_sym___forceinline__] = ACTIONS(2094),
    [anon_sym___noinline__] = ACTIONS(2094),
    [anon_sym_virtual] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym___attribute] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym___based] = ACTIONS(2094),
    [anon_sym___cdecl] = ACTIONS(2094),
    [anon_sym___clrcall] = ACTIONS(2094),
    [anon_sym___stdcall] = ACTIONS(2094),
    [anon_sym___fastcall] = ACTIONS(2094),
    [anon_sym___thiscall] = ACTIONS(2094),
    [anon_sym___vectorcall] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym__Nonnull] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym___shared__] = ACTIONS(2094),
    [anon_sym___local__] = ACTIONS(2094),
    [anon_sym___constant__] = ACTIONS(2094),
    [anon_sym___managed__] = ACTIONS(2094),
    [anon_sym___grid_constant__] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_case] = ACTIONS(2094),
    [anon_sym_default] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [anon_sym___asm] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [anon_sym_explicit] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_operator] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_namespace] = ACTIONS(2094),
    [anon_sym_using] = ACTIONS(2094),
    [anon_sym_static_assert] = ACTIONS(2094),
    [anon_sym_concept] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym___launch_bounds__] = ACTIONS(2094),
  },
  [STATE(403)] = {
    [sym_identifier] = ACTIONS(2036),
    [aux_sym_preproc_include_token1] = ACTIONS(2036),
    [aux_sym_preproc_def_token1] = ACTIONS(2036),
    [aux_sym_preproc_if_token1] = ACTIONS(2036),
    [aux_sym_preproc_if_token2] = ACTIONS(2036),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2036),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2036),
    [sym_preproc_directive] = ACTIONS(2036),
    [anon_sym_LPAREN2] = ACTIONS(2038),
    [anon_sym_BANG] = ACTIONS(2038),
    [anon_sym_TILDE] = ACTIONS(2038),
    [anon_sym_DASH] = ACTIONS(2036),
    [anon_sym_PLUS] = ACTIONS(2036),
    [anon_sym_STAR] = ACTIONS(2038),
    [anon_sym_AMP_AMP] = ACTIONS(2038),
    [anon_sym_AMP] = ACTIONS(2036),
    [anon_sym_SEMI] = ACTIONS(2038),
    [anon_sym___extension__] = ACTIONS(2036),
    [anon_sym_typedef] = ACTIONS(2036),
    [anon_sym___device__] = ACTIONS(2036),
    [anon_sym___host__] = ACTIONS(2036),
    [anon_sym___global__] = ACTIONS(2036),
    [anon_sym___forceinline__] = ACTIONS(2036),
    [anon_sym___noinline__] = ACTIONS(2036),
    [anon_sym_virtual] = ACTIONS(2036),
    [anon_sym_extern] = ACTIONS(2036),
    [anon_sym___attribute__] = ACTIONS(2036),
    [anon_sym___attribute] = ACTIONS(2036),
    [anon_sym_COLON_COLON] = ACTIONS(2038),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2038),
    [anon_sym___declspec] = ACTIONS(2036),
    [anon_sym___based] = ACTIONS(2036),
    [anon_sym___cdecl] = ACTIONS(2036),
    [anon_sym___clrcall] = ACTIONS(2036),
    [anon_sym___stdcall] = ACTIONS(2036),
    [anon_sym___fastcall] = ACTIONS(2036),
    [anon_sym___thiscall] = ACTIONS(2036),
    [anon_sym___vectorcall] = ACTIONS(2036),
    [anon_sym_LBRACE] = ACTIONS(2038),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(2036),
    [anon_sym_static] = ACTIONS(2036),
    [anon_sym_register] = ACTIONS(2036),
    [anon_sym_inline] = ACTIONS(2036),
    [anon_sym___inline] = ACTIONS(2036),
    [anon_sym___inline__] = ACTIONS(2036),
    [anon_sym___forceinline] = ACTIONS(2036),
    [anon_sym_thread_local] = ACTIONS(2036),
    [anon_sym___thread] = ACTIONS(2036),
    [anon_sym_const] = ACTIONS(2036),
    [anon_sym_constexpr] = ACTIONS(2036),
    [anon_sym_volatile] = ACTIONS(2036),
    [anon_sym_restrict] = ACTIONS(2036),
    [anon_sym___restrict__] = ACTIONS(2036),
    [anon_sym__Atomic] = ACTIONS(2036),
    [anon_sym__Noreturn] = ACTIONS(2036),
    [anon_sym_noreturn] = ACTIONS(2036),
    [anon_sym__Nonnull] = ACTIONS(2036),
    [anon_sym_mutable] = ACTIONS(2036),
    [anon_sym_constinit] = ACTIONS(2036),
    [anon_sym_consteval] = ACTIONS(2036),
    [anon_sym___shared__] = ACTIONS(2036),
    [anon_sym___local__] = ACTIONS(2036),
    [anon_sym___constant__] = ACTIONS(2036),
    [anon_sym___managed__] = ACTIONS(2036),
    [anon_sym___grid_constant__] = ACTIONS(2036),
    [anon_sym_alignas] = ACTIONS(2036),
    [anon_sym__Alignas] = ACTIONS(2036),
    [sym_primitive_type] = ACTIONS(2036),
    [anon_sym_enum] = ACTIONS(2036),
    [anon_sym_class] = ACTIONS(2036),
    [anon_sym_struct] = ACTIONS(2036),
    [anon_sym_union] = ACTIONS(2036),
    [anon_sym_if] = ACTIONS(2036),
    [anon_sym_else] = ACTIONS(2036),
    [anon_sym_switch] = ACTIONS(2036),
    [anon_sym_case] = ACTIONS(2036),
    [anon_sym_default] = ACTIONS(2036),
    [anon_sym_while] = ACTIONS(2036),
    [anon_sym_do] = ACTIONS(2036),
    [anon_sym_for] = ACTIONS(2036),
    [anon_sym_return] = ACTIONS(2036),
    [anon_sym_break] = ACTIONS(2036),
    [anon_sym_continue] = ACTIONS(2036),
    [anon_sym_goto] = ACTIONS(2036),
    [anon_sym___try] = ACTIONS(2036),
    [anon_sym___leave] = ACTIONS(2036),
    [anon_sym_not] = ACTIONS(2036),
    [anon_sym_compl] = ACTIONS(2036),
    [anon_sym_DASH_DASH] = ACTIONS(2038),
    [anon_sym_PLUS_PLUS] = ACTIONS(2038),
    [anon_sym_sizeof] = ACTIONS(2036),
    [anon_sym___alignof__] = ACTIONS(2036),
    [anon_sym___alignof] = ACTIONS(2036),
    [anon_sym__alignof] = ACTIONS(2036),
    [anon_sym_alignof] = ACTIONS(2036),
    [anon_sym__Alignof] = ACTIONS(2036),
    [anon_sym_offsetof] = ACTIONS(2036),
    [anon_sym__Generic] = ACTIONS(2036),
    [anon_sym_asm] = ACTIONS(2036),
    [anon_sym___asm__] = ACTIONS(2036),
    [anon_sym___asm] = ACTIONS(2036),
    [sym_number_literal] = ACTIONS(2038),
    [anon_sym_L_SQUOTE] = ACTIONS(2038),
    [anon_sym_u_SQUOTE] = ACTIONS(2038),
    [anon_sym_U_SQUOTE] = ACTIONS(2038),
    [anon_sym_u8_SQUOTE] = ACTIONS(2038),
    [anon_sym_SQUOTE] = ACTIONS(2038),
    [anon_sym_L_DQUOTE] = ACTIONS(2038),
    [anon_sym_u_DQUOTE] = ACTIONS(2038),
    [anon_sym_U_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8_DQUOTE] = ACTIONS(2038),
    [anon_sym_DQUOTE] = ACTIONS(2038),
    [sym_true] = ACTIONS(2036),
    [sym_false] = ACTIONS(2036),
    [anon_sym_NULL] = ACTIONS(2036),
    [anon_sym_nullptr] = ACTIONS(2036),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2036),
    [anon_sym_decltype] = ACTIONS(2036),
    [anon_sym_explicit] = ACTIONS(2036),
    [anon_sym_typename] = ACTIONS(2036),
    [anon_sym_template] = ACTIONS(2036),
    [anon_sym_operator] = ACTIONS(2036),
    [anon_sym_try] = ACTIONS(2036),
    [anon_sym_delete] = ACTIONS(2036),
    [anon_sym_throw] = ACTIONS(2036),
    [anon_sym_namespace] = ACTIONS(2036),
    [anon_sym_using] = ACTIONS(2036),
    [anon_sym_static_assert] = ACTIONS(2036),
    [anon_sym_concept] = ACTIONS(2036),
    [anon_sym_co_return] = ACTIONS(2036),
    [anon_sym_co_yield] = ACTIONS(2036),
    [anon_sym_R_DQUOTE] = ACTIONS(2038),
    [anon_sym_LR_DQUOTE] = ACTIONS(2038),
    [anon_sym_uR_DQUOTE] = ACTIONS(2038),
    [anon_sym_UR_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2038),
    [anon_sym_co_await] = ACTIONS(2036),
    [anon_sym_new] = ACTIONS(2036),
    [anon_sym_requires] = ACTIONS(2036),
    [sym_this] = ACTIONS(2036),
    [anon_sym___launch_bounds__] = ACTIONS(2036),
  },
  [STATE(404)] = {
    [sym_identifier] = ACTIONS(2094),
    [aux_sym_preproc_include_token1] = ACTIONS(2094),
    [aux_sym_preproc_def_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2094),
    [sym_preproc_directive] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP_AMP] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2094),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym___device__] = ACTIONS(2094),
    [anon_sym___host__] = ACTIONS(2094),
    [anon_sym___global__] = ACTIONS(2094),
    [anon_sym___forceinline__] = ACTIONS(2094),
    [anon_sym___noinline__] = ACTIONS(2094),
    [anon_sym_virtual] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym___attribute] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym___based] = ACTIONS(2094),
    [anon_sym___cdecl] = ACTIONS(2094),
    [anon_sym___clrcall] = ACTIONS(2094),
    [anon_sym___stdcall] = ACTIONS(2094),
    [anon_sym___fastcall] = ACTIONS(2094),
    [anon_sym___thiscall] = ACTIONS(2094),
    [anon_sym___vectorcall] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_RBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym__Nonnull] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym___shared__] = ACTIONS(2094),
    [anon_sym___local__] = ACTIONS(2094),
    [anon_sym___constant__] = ACTIONS(2094),
    [anon_sym___managed__] = ACTIONS(2094),
    [anon_sym___grid_constant__] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_case] = ACTIONS(2094),
    [anon_sym_default] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [anon_sym___asm] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [anon_sym_explicit] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_operator] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_namespace] = ACTIONS(2094),
    [anon_sym_using] = ACTIONS(2094),
    [anon_sym_static_assert] = ACTIONS(2094),
    [anon_sym_concept] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym___launch_bounds__] = ACTIONS(2094),
  },
  [STATE(405)] = {
    [ts_builtin_sym_end] = ACTIONS(2026),
    [sym_identifier] = ACTIONS(2024),
    [aux_sym_preproc_include_token1] = ACTIONS(2024),
    [aux_sym_preproc_def_token1] = ACTIONS(2024),
    [aux_sym_preproc_if_token1] = ACTIONS(2024),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2024),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2024),
    [sym_preproc_directive] = ACTIONS(2024),
    [anon_sym_LPAREN2] = ACTIONS(2026),
    [anon_sym_BANG] = ACTIONS(2026),
    [anon_sym_TILDE] = ACTIONS(2026),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_STAR] = ACTIONS(2026),
    [anon_sym_AMP_AMP] = ACTIONS(2026),
    [anon_sym_AMP] = ACTIONS(2024),
    [anon_sym_SEMI] = ACTIONS(2026),
    [anon_sym___extension__] = ACTIONS(2024),
    [anon_sym_typedef] = ACTIONS(2024),
    [anon_sym___device__] = ACTIONS(2024),
    [anon_sym___host__] = ACTIONS(2024),
    [anon_sym___global__] = ACTIONS(2024),
    [anon_sym___forceinline__] = ACTIONS(2024),
    [anon_sym___noinline__] = ACTIONS(2024),
    [anon_sym_virtual] = ACTIONS(2024),
    [anon_sym_extern] = ACTIONS(2024),
    [anon_sym___attribute__] = ACTIONS(2024),
    [anon_sym___attribute] = ACTIONS(2024),
    [anon_sym_COLON_COLON] = ACTIONS(2026),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2026),
    [anon_sym___declspec] = ACTIONS(2024),
    [anon_sym___based] = ACTIONS(2024),
    [anon_sym___cdecl] = ACTIONS(2024),
    [anon_sym___clrcall] = ACTIONS(2024),
    [anon_sym___stdcall] = ACTIONS(2024),
    [anon_sym___fastcall] = ACTIONS(2024),
    [anon_sym___thiscall] = ACTIONS(2024),
    [anon_sym___vectorcall] = ACTIONS(2024),
    [anon_sym_LBRACE] = ACTIONS(2026),
    [anon_sym_signed] = ACTIONS(2024),
    [anon_sym_unsigned] = ACTIONS(2024),
    [anon_sym_long] = ACTIONS(2024),
    [anon_sym_short] = ACTIONS(2024),
    [anon_sym_LBRACK] = ACTIONS(2024),
    [anon_sym_static] = ACTIONS(2024),
    [anon_sym_register] = ACTIONS(2024),
    [anon_sym_inline] = ACTIONS(2024),
    [anon_sym___inline] = ACTIONS(2024),
    [anon_sym___inline__] = ACTIONS(2024),
    [anon_sym___forceinline] = ACTIONS(2024),
    [anon_sym_thread_local] = ACTIONS(2024),
    [anon_sym___thread] = ACTIONS(2024),
    [anon_sym_const] = ACTIONS(2024),
    [anon_sym_constexpr] = ACTIONS(2024),
    [anon_sym_volatile] = ACTIONS(2024),
    [anon_sym_restrict] = ACTIONS(2024),
    [anon_sym___restrict__] = ACTIONS(2024),
    [anon_sym__Atomic] = ACTIONS(2024),
    [anon_sym__Noreturn] = ACTIONS(2024),
    [anon_sym_noreturn] = ACTIONS(2024),
    [anon_sym__Nonnull] = ACTIONS(2024),
    [anon_sym_mutable] = ACTIONS(2024),
    [anon_sym_constinit] = ACTIONS(2024),
    [anon_sym_consteval] = ACTIONS(2024),
    [anon_sym___shared__] = ACTIONS(2024),
    [anon_sym___local__] = ACTIONS(2024),
    [anon_sym___constant__] = ACTIONS(2024),
    [anon_sym___managed__] = ACTIONS(2024),
    [anon_sym___grid_constant__] = ACTIONS(2024),
    [anon_sym_alignas] = ACTIONS(2024),
    [anon_sym__Alignas] = ACTIONS(2024),
    [sym_primitive_type] = ACTIONS(2024),
    [anon_sym_enum] = ACTIONS(2024),
    [anon_sym_class] = ACTIONS(2024),
    [anon_sym_struct] = ACTIONS(2024),
    [anon_sym_union] = ACTIONS(2024),
    [anon_sym_if] = ACTIONS(2024),
    [anon_sym_else] = ACTIONS(2024),
    [anon_sym_switch] = ACTIONS(2024),
    [anon_sym_case] = ACTIONS(2024),
    [anon_sym_default] = ACTIONS(2024),
    [anon_sym_while] = ACTIONS(2024),
    [anon_sym_do] = ACTIONS(2024),
    [anon_sym_for] = ACTIONS(2024),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_break] = ACTIONS(2024),
    [anon_sym_continue] = ACTIONS(2024),
    [anon_sym_goto] = ACTIONS(2024),
    [anon_sym___try] = ACTIONS(2024),
    [anon_sym___leave] = ACTIONS(2024),
    [anon_sym_not] = ACTIONS(2024),
    [anon_sym_compl] = ACTIONS(2024),
    [anon_sym_DASH_DASH] = ACTIONS(2026),
    [anon_sym_PLUS_PLUS] = ACTIONS(2026),
    [anon_sym_sizeof] = ACTIONS(2024),
    [anon_sym___alignof__] = ACTIONS(2024),
    [anon_sym___alignof] = ACTIONS(2024),
    [anon_sym__alignof] = ACTIONS(2024),
    [anon_sym_alignof] = ACTIONS(2024),
    [anon_sym__Alignof] = ACTIONS(2024),
    [anon_sym_offsetof] = ACTIONS(2024),
    [anon_sym__Generic] = ACTIONS(2024),
    [anon_sym_asm] = ACTIONS(2024),
    [anon_sym___asm__] = ACTIONS(2024),
    [anon_sym___asm] = ACTIONS(2024),
    [sym_number_literal] = ACTIONS(2026),
    [anon_sym_L_SQUOTE] = ACTIONS(2026),
    [anon_sym_u_SQUOTE] = ACTIONS(2026),
    [anon_sym_U_SQUOTE] = ACTIONS(2026),
    [anon_sym_u8_SQUOTE] = ACTIONS(2026),
    [anon_sym_SQUOTE] = ACTIONS(2026),
    [anon_sym_L_DQUOTE] = ACTIONS(2026),
    [anon_sym_u_DQUOTE] = ACTIONS(2026),
    [anon_sym_U_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8_DQUOTE] = ACTIONS(2026),
    [anon_sym_DQUOTE] = ACTIONS(2026),
    [sym_true] = ACTIONS(2024),
    [sym_false] = ACTIONS(2024),
    [anon_sym_NULL] = ACTIONS(2024),
    [anon_sym_nullptr] = ACTIONS(2024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2024),
    [anon_sym_decltype] = ACTIONS(2024),
    [anon_sym_explicit] = ACTIONS(2024),
    [anon_sym_typename] = ACTIONS(2024),
    [anon_sym_template] = ACTIONS(2024),
    [anon_sym_operator] = ACTIONS(2024),
    [anon_sym_try] = ACTIONS(2024),
    [anon_sym_delete] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2024),
    [anon_sym_namespace] = ACTIONS(2024),
    [anon_sym_using] = ACTIONS(2024),
    [anon_sym_static_assert] = ACTIONS(2024),
    [anon_sym_concept] = ACTIONS(2024),
    [anon_sym_co_return] = ACTIONS(2024),
    [anon_sym_co_yield] = ACTIONS(2024),
    [anon_sym_R_DQUOTE] = ACTIONS(2026),
    [anon_sym_LR_DQUOTE] = ACTIONS(2026),
    [anon_sym_uR_DQUOTE] = ACTIONS(2026),
    [anon_sym_UR_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2026),
    [anon_sym_co_await] = ACTIONS(2024),
    [anon_sym_new] = ACTIONS(2024),
    [anon_sym_requires] = ACTIONS(2024),
    [sym_this] = ACTIONS(2024),
    [anon_sym___launch_bounds__] = ACTIONS(2024),
  },
  [STATE(406)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(407)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(408)] = {
    [sym_identifier] = ACTIONS(2024),
    [aux_sym_preproc_include_token1] = ACTIONS(2024),
    [aux_sym_preproc_def_token1] = ACTIONS(2024),
    [aux_sym_preproc_if_token1] = ACTIONS(2024),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2024),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2024),
    [sym_preproc_directive] = ACTIONS(2024),
    [anon_sym_LPAREN2] = ACTIONS(2026),
    [anon_sym_BANG] = ACTIONS(2026),
    [anon_sym_TILDE] = ACTIONS(2026),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_STAR] = ACTIONS(2026),
    [anon_sym_AMP_AMP] = ACTIONS(2026),
    [anon_sym_AMP] = ACTIONS(2024),
    [anon_sym_SEMI] = ACTIONS(2026),
    [anon_sym___extension__] = ACTIONS(2024),
    [anon_sym_typedef] = ACTIONS(2024),
    [anon_sym___device__] = ACTIONS(2024),
    [anon_sym___host__] = ACTIONS(2024),
    [anon_sym___global__] = ACTIONS(2024),
    [anon_sym___forceinline__] = ACTIONS(2024),
    [anon_sym___noinline__] = ACTIONS(2024),
    [anon_sym_virtual] = ACTIONS(2024),
    [anon_sym_extern] = ACTIONS(2024),
    [anon_sym___attribute__] = ACTIONS(2024),
    [anon_sym___attribute] = ACTIONS(2024),
    [anon_sym_COLON_COLON] = ACTIONS(2026),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2026),
    [anon_sym___declspec] = ACTIONS(2024),
    [anon_sym___based] = ACTIONS(2024),
    [anon_sym___cdecl] = ACTIONS(2024),
    [anon_sym___clrcall] = ACTIONS(2024),
    [anon_sym___stdcall] = ACTIONS(2024),
    [anon_sym___fastcall] = ACTIONS(2024),
    [anon_sym___thiscall] = ACTIONS(2024),
    [anon_sym___vectorcall] = ACTIONS(2024),
    [anon_sym_LBRACE] = ACTIONS(2026),
    [anon_sym_RBRACE] = ACTIONS(2026),
    [anon_sym_signed] = ACTIONS(2024),
    [anon_sym_unsigned] = ACTIONS(2024),
    [anon_sym_long] = ACTIONS(2024),
    [anon_sym_short] = ACTIONS(2024),
    [anon_sym_LBRACK] = ACTIONS(2024),
    [anon_sym_static] = ACTIONS(2024),
    [anon_sym_register] = ACTIONS(2024),
    [anon_sym_inline] = ACTIONS(2024),
    [anon_sym___inline] = ACTIONS(2024),
    [anon_sym___inline__] = ACTIONS(2024),
    [anon_sym___forceinline] = ACTIONS(2024),
    [anon_sym_thread_local] = ACTIONS(2024),
    [anon_sym___thread] = ACTIONS(2024),
    [anon_sym_const] = ACTIONS(2024),
    [anon_sym_constexpr] = ACTIONS(2024),
    [anon_sym_volatile] = ACTIONS(2024),
    [anon_sym_restrict] = ACTIONS(2024),
    [anon_sym___restrict__] = ACTIONS(2024),
    [anon_sym__Atomic] = ACTIONS(2024),
    [anon_sym__Noreturn] = ACTIONS(2024),
    [anon_sym_noreturn] = ACTIONS(2024),
    [anon_sym__Nonnull] = ACTIONS(2024),
    [anon_sym_mutable] = ACTIONS(2024),
    [anon_sym_constinit] = ACTIONS(2024),
    [anon_sym_consteval] = ACTIONS(2024),
    [anon_sym___shared__] = ACTIONS(2024),
    [anon_sym___local__] = ACTIONS(2024),
    [anon_sym___constant__] = ACTIONS(2024),
    [anon_sym___managed__] = ACTIONS(2024),
    [anon_sym___grid_constant__] = ACTIONS(2024),
    [anon_sym_alignas] = ACTIONS(2024),
    [anon_sym__Alignas] = ACTIONS(2024),
    [sym_primitive_type] = ACTIONS(2024),
    [anon_sym_enum] = ACTIONS(2024),
    [anon_sym_class] = ACTIONS(2024),
    [anon_sym_struct] = ACTIONS(2024),
    [anon_sym_union] = ACTIONS(2024),
    [anon_sym_if] = ACTIONS(2024),
    [anon_sym_else] = ACTIONS(2024),
    [anon_sym_switch] = ACTIONS(2024),
    [anon_sym_case] = ACTIONS(2024),
    [anon_sym_default] = ACTIONS(2024),
    [anon_sym_while] = ACTIONS(2024),
    [anon_sym_do] = ACTIONS(2024),
    [anon_sym_for] = ACTIONS(2024),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_break] = ACTIONS(2024),
    [anon_sym_continue] = ACTIONS(2024),
    [anon_sym_goto] = ACTIONS(2024),
    [anon_sym___try] = ACTIONS(2024),
    [anon_sym___leave] = ACTIONS(2024),
    [anon_sym_not] = ACTIONS(2024),
    [anon_sym_compl] = ACTIONS(2024),
    [anon_sym_DASH_DASH] = ACTIONS(2026),
    [anon_sym_PLUS_PLUS] = ACTIONS(2026),
    [anon_sym_sizeof] = ACTIONS(2024),
    [anon_sym___alignof__] = ACTIONS(2024),
    [anon_sym___alignof] = ACTIONS(2024),
    [anon_sym__alignof] = ACTIONS(2024),
    [anon_sym_alignof] = ACTIONS(2024),
    [anon_sym__Alignof] = ACTIONS(2024),
    [anon_sym_offsetof] = ACTIONS(2024),
    [anon_sym__Generic] = ACTIONS(2024),
    [anon_sym_asm] = ACTIONS(2024),
    [anon_sym___asm__] = ACTIONS(2024),
    [anon_sym___asm] = ACTIONS(2024),
    [sym_number_literal] = ACTIONS(2026),
    [anon_sym_L_SQUOTE] = ACTIONS(2026),
    [anon_sym_u_SQUOTE] = ACTIONS(2026),
    [anon_sym_U_SQUOTE] = ACTIONS(2026),
    [anon_sym_u8_SQUOTE] = ACTIONS(2026),
    [anon_sym_SQUOTE] = ACTIONS(2026),
    [anon_sym_L_DQUOTE] = ACTIONS(2026),
    [anon_sym_u_DQUOTE] = ACTIONS(2026),
    [anon_sym_U_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8_DQUOTE] = ACTIONS(2026),
    [anon_sym_DQUOTE] = ACTIONS(2026),
    [sym_true] = ACTIONS(2024),
    [sym_false] = ACTIONS(2024),
    [anon_sym_NULL] = ACTIONS(2024),
    [anon_sym_nullptr] = ACTIONS(2024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2024),
    [anon_sym_decltype] = ACTIONS(2024),
    [anon_sym_explicit] = ACTIONS(2024),
    [anon_sym_typename] = ACTIONS(2024),
    [anon_sym_template] = ACTIONS(2024),
    [anon_sym_operator] = ACTIONS(2024),
    [anon_sym_try] = ACTIONS(2024),
    [anon_sym_delete] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2024),
    [anon_sym_namespace] = ACTIONS(2024),
    [anon_sym_using] = ACTIONS(2024),
    [anon_sym_static_assert] = ACTIONS(2024),
    [anon_sym_concept] = ACTIONS(2024),
    [anon_sym_co_return] = ACTIONS(2024),
    [anon_sym_co_yield] = ACTIONS(2024),
    [anon_sym_R_DQUOTE] = ACTIONS(2026),
    [anon_sym_LR_DQUOTE] = ACTIONS(2026),
    [anon_sym_uR_DQUOTE] = ACTIONS(2026),
    [anon_sym_UR_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2026),
    [anon_sym_co_await] = ACTIONS(2024),
    [anon_sym_new] = ACTIONS(2024),
    [anon_sym_requires] = ACTIONS(2024),
    [sym_this] = ACTIONS(2024),
    [anon_sym___launch_bounds__] = ACTIONS(2024),
  },
  [STATE(409)] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_include_token1] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token2] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym___device__] = ACTIONS(2190),
    [anon_sym___host__] = ACTIONS(2190),
    [anon_sym___global__] = ACTIONS(2190),
    [anon_sym___forceinline__] = ACTIONS(2190),
    [anon_sym___noinline__] = ACTIONS(2190),
    [anon_sym_virtual] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym___attribute] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym___cdecl] = ACTIONS(2190),
    [anon_sym___clrcall] = ACTIONS(2190),
    [anon_sym___stdcall] = ACTIONS(2190),
    [anon_sym___fastcall] = ACTIONS(2190),
    [anon_sym___thiscall] = ACTIONS(2190),
    [anon_sym___vectorcall] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym__Nonnull] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym___shared__] = ACTIONS(2190),
    [anon_sym___local__] = ACTIONS(2190),
    [anon_sym___constant__] = ACTIONS(2190),
    [anon_sym___managed__] = ACTIONS(2190),
    [anon_sym___grid_constant__] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym_default] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [anon_sym___asm] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_namespace] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym_concept] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym___launch_bounds__] = ACTIONS(2190),
  },
  [STATE(410)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(411)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(412)] = {
    [sym_identifier] = ACTIONS(2048),
    [aux_sym_preproc_include_token1] = ACTIONS(2048),
    [aux_sym_preproc_def_token1] = ACTIONS(2048),
    [aux_sym_preproc_if_token1] = ACTIONS(2048),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2048),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2048),
    [sym_preproc_directive] = ACTIONS(2048),
    [anon_sym_LPAREN2] = ACTIONS(2050),
    [anon_sym_BANG] = ACTIONS(2050),
    [anon_sym_TILDE] = ACTIONS(2050),
    [anon_sym_DASH] = ACTIONS(2048),
    [anon_sym_PLUS] = ACTIONS(2048),
    [anon_sym_STAR] = ACTIONS(2050),
    [anon_sym_AMP_AMP] = ACTIONS(2050),
    [anon_sym_AMP] = ACTIONS(2048),
    [anon_sym_SEMI] = ACTIONS(2050),
    [anon_sym___extension__] = ACTIONS(2048),
    [anon_sym_typedef] = ACTIONS(2048),
    [anon_sym___device__] = ACTIONS(2048),
    [anon_sym___host__] = ACTIONS(2048),
    [anon_sym___global__] = ACTIONS(2048),
    [anon_sym___forceinline__] = ACTIONS(2048),
    [anon_sym___noinline__] = ACTIONS(2048),
    [anon_sym_virtual] = ACTIONS(2048),
    [anon_sym_extern] = ACTIONS(2048),
    [anon_sym___attribute__] = ACTIONS(2048),
    [anon_sym___attribute] = ACTIONS(2048),
    [anon_sym_COLON_COLON] = ACTIONS(2050),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2050),
    [anon_sym___declspec] = ACTIONS(2048),
    [anon_sym___based] = ACTIONS(2048),
    [anon_sym___cdecl] = ACTIONS(2048),
    [anon_sym___clrcall] = ACTIONS(2048),
    [anon_sym___stdcall] = ACTIONS(2048),
    [anon_sym___fastcall] = ACTIONS(2048),
    [anon_sym___thiscall] = ACTIONS(2048),
    [anon_sym___vectorcall] = ACTIONS(2048),
    [anon_sym_LBRACE] = ACTIONS(2050),
    [anon_sym_RBRACE] = ACTIONS(2050),
    [anon_sym_signed] = ACTIONS(2048),
    [anon_sym_unsigned] = ACTIONS(2048),
    [anon_sym_long] = ACTIONS(2048),
    [anon_sym_short] = ACTIONS(2048),
    [anon_sym_LBRACK] = ACTIONS(2048),
    [anon_sym_static] = ACTIONS(2048),
    [anon_sym_register] = ACTIONS(2048),
    [anon_sym_inline] = ACTIONS(2048),
    [anon_sym___inline] = ACTIONS(2048),
    [anon_sym___inline__] = ACTIONS(2048),
    [anon_sym___forceinline] = ACTIONS(2048),
    [anon_sym_thread_local] = ACTIONS(2048),
    [anon_sym___thread] = ACTIONS(2048),
    [anon_sym_const] = ACTIONS(2048),
    [anon_sym_constexpr] = ACTIONS(2048),
    [anon_sym_volatile] = ACTIONS(2048),
    [anon_sym_restrict] = ACTIONS(2048),
    [anon_sym___restrict__] = ACTIONS(2048),
    [anon_sym__Atomic] = ACTIONS(2048),
    [anon_sym__Noreturn] = ACTIONS(2048),
    [anon_sym_noreturn] = ACTIONS(2048),
    [anon_sym__Nonnull] = ACTIONS(2048),
    [anon_sym_mutable] = ACTIONS(2048),
    [anon_sym_constinit] = ACTIONS(2048),
    [anon_sym_consteval] = ACTIONS(2048),
    [anon_sym___shared__] = ACTIONS(2048),
    [anon_sym___local__] = ACTIONS(2048),
    [anon_sym___constant__] = ACTIONS(2048),
    [anon_sym___managed__] = ACTIONS(2048),
    [anon_sym___grid_constant__] = ACTIONS(2048),
    [anon_sym_alignas] = ACTIONS(2048),
    [anon_sym__Alignas] = ACTIONS(2048),
    [sym_primitive_type] = ACTIONS(2048),
    [anon_sym_enum] = ACTIONS(2048),
    [anon_sym_class] = ACTIONS(2048),
    [anon_sym_struct] = ACTIONS(2048),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_if] = ACTIONS(2048),
    [anon_sym_else] = ACTIONS(2048),
    [anon_sym_switch] = ACTIONS(2048),
    [anon_sym_case] = ACTIONS(2048),
    [anon_sym_default] = ACTIONS(2048),
    [anon_sym_while] = ACTIONS(2048),
    [anon_sym_do] = ACTIONS(2048),
    [anon_sym_for] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2048),
    [anon_sym_break] = ACTIONS(2048),
    [anon_sym_continue] = ACTIONS(2048),
    [anon_sym_goto] = ACTIONS(2048),
    [anon_sym___try] = ACTIONS(2048),
    [anon_sym___leave] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2048),
    [anon_sym_compl] = ACTIONS(2048),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2048),
    [anon_sym___alignof__] = ACTIONS(2048),
    [anon_sym___alignof] = ACTIONS(2048),
    [anon_sym__alignof] = ACTIONS(2048),
    [anon_sym_alignof] = ACTIONS(2048),
    [anon_sym__Alignof] = ACTIONS(2048),
    [anon_sym_offsetof] = ACTIONS(2048),
    [anon_sym__Generic] = ACTIONS(2048),
    [anon_sym_asm] = ACTIONS(2048),
    [anon_sym___asm__] = ACTIONS(2048),
    [anon_sym___asm] = ACTIONS(2048),
    [sym_number_literal] = ACTIONS(2050),
    [anon_sym_L_SQUOTE] = ACTIONS(2050),
    [anon_sym_u_SQUOTE] = ACTIONS(2050),
    [anon_sym_U_SQUOTE] = ACTIONS(2050),
    [anon_sym_u8_SQUOTE] = ACTIONS(2050),
    [anon_sym_SQUOTE] = ACTIONS(2050),
    [anon_sym_L_DQUOTE] = ACTIONS(2050),
    [anon_sym_u_DQUOTE] = ACTIONS(2050),
    [anon_sym_U_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8_DQUOTE] = ACTIONS(2050),
    [anon_sym_DQUOTE] = ACTIONS(2050),
    [sym_true] = ACTIONS(2048),
    [sym_false] = ACTIONS(2048),
    [anon_sym_NULL] = ACTIONS(2048),
    [anon_sym_nullptr] = ACTIONS(2048),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2048),
    [anon_sym_decltype] = ACTIONS(2048),
    [anon_sym_explicit] = ACTIONS(2048),
    [anon_sym_typename] = ACTIONS(2048),
    [anon_sym_template] = ACTIONS(2048),
    [anon_sym_operator] = ACTIONS(2048),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_delete] = ACTIONS(2048),
    [anon_sym_throw] = ACTIONS(2048),
    [anon_sym_namespace] = ACTIONS(2048),
    [anon_sym_using] = ACTIONS(2048),
    [anon_sym_static_assert] = ACTIONS(2048),
    [anon_sym_concept] = ACTIONS(2048),
    [anon_sym_co_return] = ACTIONS(2048),
    [anon_sym_co_yield] = ACTIONS(2048),
    [anon_sym_R_DQUOTE] = ACTIONS(2050),
    [anon_sym_LR_DQUOTE] = ACTIONS(2050),
    [anon_sym_uR_DQUOTE] = ACTIONS(2050),
    [anon_sym_UR_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2050),
    [anon_sym_co_await] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(2048),
    [anon_sym_requires] = ACTIONS(2048),
    [sym_this] = ACTIONS(2048),
    [anon_sym___launch_bounds__] = ACTIONS(2048),
  },
  [STATE(413)] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_include_token1] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token2] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym___device__] = ACTIONS(2134),
    [anon_sym___host__] = ACTIONS(2134),
    [anon_sym___global__] = ACTIONS(2134),
    [anon_sym___forceinline__] = ACTIONS(2134),
    [anon_sym___noinline__] = ACTIONS(2134),
    [anon_sym_virtual] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym___attribute] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym___cdecl] = ACTIONS(2134),
    [anon_sym___clrcall] = ACTIONS(2134),
    [anon_sym___stdcall] = ACTIONS(2134),
    [anon_sym___fastcall] = ACTIONS(2134),
    [anon_sym___thiscall] = ACTIONS(2134),
    [anon_sym___vectorcall] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym__Nonnull] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym___shared__] = ACTIONS(2134),
    [anon_sym___local__] = ACTIONS(2134),
    [anon_sym___constant__] = ACTIONS(2134),
    [anon_sym___managed__] = ACTIONS(2134),
    [anon_sym___grid_constant__] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_case] = ACTIONS(2134),
    [anon_sym_default] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [anon_sym___asm] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_namespace] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_concept] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym___launch_bounds__] = ACTIONS(2134),
  },
  [STATE(414)] = {
    [sym_identifier] = ACTIONS(2056),
    [aux_sym_preproc_include_token1] = ACTIONS(2056),
    [aux_sym_preproc_def_token1] = ACTIONS(2056),
    [aux_sym_preproc_if_token1] = ACTIONS(2056),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2056),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2056),
    [sym_preproc_directive] = ACTIONS(2056),
    [anon_sym_LPAREN2] = ACTIONS(2058),
    [anon_sym_BANG] = ACTIONS(2058),
    [anon_sym_TILDE] = ACTIONS(2058),
    [anon_sym_DASH] = ACTIONS(2056),
    [anon_sym_PLUS] = ACTIONS(2056),
    [anon_sym_STAR] = ACTIONS(2058),
    [anon_sym_AMP_AMP] = ACTIONS(2058),
    [anon_sym_AMP] = ACTIONS(2056),
    [anon_sym_SEMI] = ACTIONS(2058),
    [anon_sym___extension__] = ACTIONS(2056),
    [anon_sym_typedef] = ACTIONS(2056),
    [anon_sym___device__] = ACTIONS(2056),
    [anon_sym___host__] = ACTIONS(2056),
    [anon_sym___global__] = ACTIONS(2056),
    [anon_sym___forceinline__] = ACTIONS(2056),
    [anon_sym___noinline__] = ACTIONS(2056),
    [anon_sym_virtual] = ACTIONS(2056),
    [anon_sym_extern] = ACTIONS(2056),
    [anon_sym___attribute__] = ACTIONS(2056),
    [anon_sym___attribute] = ACTIONS(2056),
    [anon_sym_COLON_COLON] = ACTIONS(2058),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2058),
    [anon_sym___declspec] = ACTIONS(2056),
    [anon_sym___based] = ACTIONS(2056),
    [anon_sym___cdecl] = ACTIONS(2056),
    [anon_sym___clrcall] = ACTIONS(2056),
    [anon_sym___stdcall] = ACTIONS(2056),
    [anon_sym___fastcall] = ACTIONS(2056),
    [anon_sym___thiscall] = ACTIONS(2056),
    [anon_sym___vectorcall] = ACTIONS(2056),
    [anon_sym_LBRACE] = ACTIONS(2058),
    [anon_sym_RBRACE] = ACTIONS(2058),
    [anon_sym_signed] = ACTIONS(2056),
    [anon_sym_unsigned] = ACTIONS(2056),
    [anon_sym_long] = ACTIONS(2056),
    [anon_sym_short] = ACTIONS(2056),
    [anon_sym_LBRACK] = ACTIONS(2056),
    [anon_sym_static] = ACTIONS(2056),
    [anon_sym_register] = ACTIONS(2056),
    [anon_sym_inline] = ACTIONS(2056),
    [anon_sym___inline] = ACTIONS(2056),
    [anon_sym___inline__] = ACTIONS(2056),
    [anon_sym___forceinline] = ACTIONS(2056),
    [anon_sym_thread_local] = ACTIONS(2056),
    [anon_sym___thread] = ACTIONS(2056),
    [anon_sym_const] = ACTIONS(2056),
    [anon_sym_constexpr] = ACTIONS(2056),
    [anon_sym_volatile] = ACTIONS(2056),
    [anon_sym_restrict] = ACTIONS(2056),
    [anon_sym___restrict__] = ACTIONS(2056),
    [anon_sym__Atomic] = ACTIONS(2056),
    [anon_sym__Noreturn] = ACTIONS(2056),
    [anon_sym_noreturn] = ACTIONS(2056),
    [anon_sym__Nonnull] = ACTIONS(2056),
    [anon_sym_mutable] = ACTIONS(2056),
    [anon_sym_constinit] = ACTIONS(2056),
    [anon_sym_consteval] = ACTIONS(2056),
    [anon_sym___shared__] = ACTIONS(2056),
    [anon_sym___local__] = ACTIONS(2056),
    [anon_sym___constant__] = ACTIONS(2056),
    [anon_sym___managed__] = ACTIONS(2056),
    [anon_sym___grid_constant__] = ACTIONS(2056),
    [anon_sym_alignas] = ACTIONS(2056),
    [anon_sym__Alignas] = ACTIONS(2056),
    [sym_primitive_type] = ACTIONS(2056),
    [anon_sym_enum] = ACTIONS(2056),
    [anon_sym_class] = ACTIONS(2056),
    [anon_sym_struct] = ACTIONS(2056),
    [anon_sym_union] = ACTIONS(2056),
    [anon_sym_if] = ACTIONS(2056),
    [anon_sym_else] = ACTIONS(2056),
    [anon_sym_switch] = ACTIONS(2056),
    [anon_sym_case] = ACTIONS(2056),
    [anon_sym_default] = ACTIONS(2056),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_do] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2056),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_break] = ACTIONS(2056),
    [anon_sym_continue] = ACTIONS(2056),
    [anon_sym_goto] = ACTIONS(2056),
    [anon_sym___try] = ACTIONS(2056),
    [anon_sym___leave] = ACTIONS(2056),
    [anon_sym_not] = ACTIONS(2056),
    [anon_sym_compl] = ACTIONS(2056),
    [anon_sym_DASH_DASH] = ACTIONS(2058),
    [anon_sym_PLUS_PLUS] = ACTIONS(2058),
    [anon_sym_sizeof] = ACTIONS(2056),
    [anon_sym___alignof__] = ACTIONS(2056),
    [anon_sym___alignof] = ACTIONS(2056),
    [anon_sym__alignof] = ACTIONS(2056),
    [anon_sym_alignof] = ACTIONS(2056),
    [anon_sym__Alignof] = ACTIONS(2056),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2056),
    [anon_sym_asm] = ACTIONS(2056),
    [anon_sym___asm__] = ACTIONS(2056),
    [anon_sym___asm] = ACTIONS(2056),
    [sym_number_literal] = ACTIONS(2058),
    [anon_sym_L_SQUOTE] = ACTIONS(2058),
    [anon_sym_u_SQUOTE] = ACTIONS(2058),
    [anon_sym_U_SQUOTE] = ACTIONS(2058),
    [anon_sym_u8_SQUOTE] = ACTIONS(2058),
    [anon_sym_SQUOTE] = ACTIONS(2058),
    [anon_sym_L_DQUOTE] = ACTIONS(2058),
    [anon_sym_u_DQUOTE] = ACTIONS(2058),
    [anon_sym_U_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8_DQUOTE] = ACTIONS(2058),
    [anon_sym_DQUOTE] = ACTIONS(2058),
    [sym_true] = ACTIONS(2056),
    [sym_false] = ACTIONS(2056),
    [anon_sym_NULL] = ACTIONS(2056),
    [anon_sym_nullptr] = ACTIONS(2056),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2056),
    [anon_sym_decltype] = ACTIONS(2056),
    [anon_sym_explicit] = ACTIONS(2056),
    [anon_sym_typename] = ACTIONS(2056),
    [anon_sym_template] = ACTIONS(2056),
    [anon_sym_operator] = ACTIONS(2056),
    [anon_sym_try] = ACTIONS(2056),
    [anon_sym_delete] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2056),
    [anon_sym_namespace] = ACTIONS(2056),
    [anon_sym_using] = ACTIONS(2056),
    [anon_sym_static_assert] = ACTIONS(2056),
    [anon_sym_concept] = ACTIONS(2056),
    [anon_sym_co_return] = ACTIONS(2056),
    [anon_sym_co_yield] = ACTIONS(2056),
    [anon_sym_R_DQUOTE] = ACTIONS(2058),
    [anon_sym_LR_DQUOTE] = ACTIONS(2058),
    [anon_sym_uR_DQUOTE] = ACTIONS(2058),
    [anon_sym_UR_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2058),
    [anon_sym_co_await] = ACTIONS(2056),
    [anon_sym_new] = ACTIONS(2056),
    [anon_sym_requires] = ACTIONS(2056),
    [sym_this] = ACTIONS(2056),
    [anon_sym___launch_bounds__] = ACTIONS(2056),
  },
  [STATE(415)] = {
    [sym_identifier] = ACTIONS(2066),
    [aux_sym_preproc_include_token1] = ACTIONS(2066),
    [aux_sym_preproc_def_token1] = ACTIONS(2066),
    [aux_sym_preproc_if_token1] = ACTIONS(2066),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2066),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2066),
    [sym_preproc_directive] = ACTIONS(2066),
    [anon_sym_LPAREN2] = ACTIONS(2068),
    [anon_sym_BANG] = ACTIONS(2068),
    [anon_sym_TILDE] = ACTIONS(2068),
    [anon_sym_DASH] = ACTIONS(2066),
    [anon_sym_PLUS] = ACTIONS(2066),
    [anon_sym_STAR] = ACTIONS(2068),
    [anon_sym_AMP_AMP] = ACTIONS(2068),
    [anon_sym_AMP] = ACTIONS(2066),
    [anon_sym_SEMI] = ACTIONS(2068),
    [anon_sym___extension__] = ACTIONS(2066),
    [anon_sym_typedef] = ACTIONS(2066),
    [anon_sym___device__] = ACTIONS(2066),
    [anon_sym___host__] = ACTIONS(2066),
    [anon_sym___global__] = ACTIONS(2066),
    [anon_sym___forceinline__] = ACTIONS(2066),
    [anon_sym___noinline__] = ACTIONS(2066),
    [anon_sym_virtual] = ACTIONS(2066),
    [anon_sym_extern] = ACTIONS(2066),
    [anon_sym___attribute__] = ACTIONS(2066),
    [anon_sym___attribute] = ACTIONS(2066),
    [anon_sym_COLON_COLON] = ACTIONS(2068),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2068),
    [anon_sym___declspec] = ACTIONS(2066),
    [anon_sym___based] = ACTIONS(2066),
    [anon_sym___cdecl] = ACTIONS(2066),
    [anon_sym___clrcall] = ACTIONS(2066),
    [anon_sym___stdcall] = ACTIONS(2066),
    [anon_sym___fastcall] = ACTIONS(2066),
    [anon_sym___thiscall] = ACTIONS(2066),
    [anon_sym___vectorcall] = ACTIONS(2066),
    [anon_sym_LBRACE] = ACTIONS(2068),
    [anon_sym_RBRACE] = ACTIONS(2068),
    [anon_sym_signed] = ACTIONS(2066),
    [anon_sym_unsigned] = ACTIONS(2066),
    [anon_sym_long] = ACTIONS(2066),
    [anon_sym_short] = ACTIONS(2066),
    [anon_sym_LBRACK] = ACTIONS(2066),
    [anon_sym_static] = ACTIONS(2066),
    [anon_sym_register] = ACTIONS(2066),
    [anon_sym_inline] = ACTIONS(2066),
    [anon_sym___inline] = ACTIONS(2066),
    [anon_sym___inline__] = ACTIONS(2066),
    [anon_sym___forceinline] = ACTIONS(2066),
    [anon_sym_thread_local] = ACTIONS(2066),
    [anon_sym___thread] = ACTIONS(2066),
    [anon_sym_const] = ACTIONS(2066),
    [anon_sym_constexpr] = ACTIONS(2066),
    [anon_sym_volatile] = ACTIONS(2066),
    [anon_sym_restrict] = ACTIONS(2066),
    [anon_sym___restrict__] = ACTIONS(2066),
    [anon_sym__Atomic] = ACTIONS(2066),
    [anon_sym__Noreturn] = ACTIONS(2066),
    [anon_sym_noreturn] = ACTIONS(2066),
    [anon_sym__Nonnull] = ACTIONS(2066),
    [anon_sym_mutable] = ACTIONS(2066),
    [anon_sym_constinit] = ACTIONS(2066),
    [anon_sym_consteval] = ACTIONS(2066),
    [anon_sym___shared__] = ACTIONS(2066),
    [anon_sym___local__] = ACTIONS(2066),
    [anon_sym___constant__] = ACTIONS(2066),
    [anon_sym___managed__] = ACTIONS(2066),
    [anon_sym___grid_constant__] = ACTIONS(2066),
    [anon_sym_alignas] = ACTIONS(2066),
    [anon_sym__Alignas] = ACTIONS(2066),
    [sym_primitive_type] = ACTIONS(2066),
    [anon_sym_enum] = ACTIONS(2066),
    [anon_sym_class] = ACTIONS(2066),
    [anon_sym_struct] = ACTIONS(2066),
    [anon_sym_union] = ACTIONS(2066),
    [anon_sym_if] = ACTIONS(2066),
    [anon_sym_else] = ACTIONS(2066),
    [anon_sym_switch] = ACTIONS(2066),
    [anon_sym_case] = ACTIONS(2066),
    [anon_sym_default] = ACTIONS(2066),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_do] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2066),
    [anon_sym_return] = ACTIONS(2066),
    [anon_sym_break] = ACTIONS(2066),
    [anon_sym_continue] = ACTIONS(2066),
    [anon_sym_goto] = ACTIONS(2066),
    [anon_sym___try] = ACTIONS(2066),
    [anon_sym___leave] = ACTIONS(2066),
    [anon_sym_not] = ACTIONS(2066),
    [anon_sym_compl] = ACTIONS(2066),
    [anon_sym_DASH_DASH] = ACTIONS(2068),
    [anon_sym_PLUS_PLUS] = ACTIONS(2068),
    [anon_sym_sizeof] = ACTIONS(2066),
    [anon_sym___alignof__] = ACTIONS(2066),
    [anon_sym___alignof] = ACTIONS(2066),
    [anon_sym__alignof] = ACTIONS(2066),
    [anon_sym_alignof] = ACTIONS(2066),
    [anon_sym__Alignof] = ACTIONS(2066),
    [anon_sym_offsetof] = ACTIONS(2066),
    [anon_sym__Generic] = ACTIONS(2066),
    [anon_sym_asm] = ACTIONS(2066),
    [anon_sym___asm__] = ACTIONS(2066),
    [anon_sym___asm] = ACTIONS(2066),
    [sym_number_literal] = ACTIONS(2068),
    [anon_sym_L_SQUOTE] = ACTIONS(2068),
    [anon_sym_u_SQUOTE] = ACTIONS(2068),
    [anon_sym_U_SQUOTE] = ACTIONS(2068),
    [anon_sym_u8_SQUOTE] = ACTIONS(2068),
    [anon_sym_SQUOTE] = ACTIONS(2068),
    [anon_sym_L_DQUOTE] = ACTIONS(2068),
    [anon_sym_u_DQUOTE] = ACTIONS(2068),
    [anon_sym_U_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8_DQUOTE] = ACTIONS(2068),
    [anon_sym_DQUOTE] = ACTIONS(2068),
    [sym_true] = ACTIONS(2066),
    [sym_false] = ACTIONS(2066),
    [anon_sym_NULL] = ACTIONS(2066),
    [anon_sym_nullptr] = ACTIONS(2066),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2066),
    [anon_sym_decltype] = ACTIONS(2066),
    [anon_sym_explicit] = ACTIONS(2066),
    [anon_sym_typename] = ACTIONS(2066),
    [anon_sym_template] = ACTIONS(2066),
    [anon_sym_operator] = ACTIONS(2066),
    [anon_sym_try] = ACTIONS(2066),
    [anon_sym_delete] = ACTIONS(2066),
    [anon_sym_throw] = ACTIONS(2066),
    [anon_sym_namespace] = ACTIONS(2066),
    [anon_sym_using] = ACTIONS(2066),
    [anon_sym_static_assert] = ACTIONS(2066),
    [anon_sym_concept] = ACTIONS(2066),
    [anon_sym_co_return] = ACTIONS(2066),
    [anon_sym_co_yield] = ACTIONS(2066),
    [anon_sym_R_DQUOTE] = ACTIONS(2068),
    [anon_sym_LR_DQUOTE] = ACTIONS(2068),
    [anon_sym_uR_DQUOTE] = ACTIONS(2068),
    [anon_sym_UR_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2068),
    [anon_sym_co_await] = ACTIONS(2066),
    [anon_sym_new] = ACTIONS(2066),
    [anon_sym_requires] = ACTIONS(2066),
    [sym_this] = ACTIONS(2066),
    [anon_sym___launch_bounds__] = ACTIONS(2066),
  },
  [STATE(416)] = {
    [sym_identifier] = ACTIONS(2078),
    [aux_sym_preproc_include_token1] = ACTIONS(2078),
    [aux_sym_preproc_def_token1] = ACTIONS(2078),
    [aux_sym_preproc_if_token1] = ACTIONS(2078),
    [aux_sym_preproc_if_token2] = ACTIONS(2078),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2078),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2078),
    [sym_preproc_directive] = ACTIONS(2078),
    [anon_sym_LPAREN2] = ACTIONS(2083),
    [anon_sym_BANG] = ACTIONS(2083),
    [anon_sym_TILDE] = ACTIONS(2083),
    [anon_sym_DASH] = ACTIONS(2078),
    [anon_sym_PLUS] = ACTIONS(2078),
    [anon_sym_STAR] = ACTIONS(2083),
    [anon_sym_AMP_AMP] = ACTIONS(2083),
    [anon_sym_AMP] = ACTIONS(2078),
    [anon_sym_SEMI] = ACTIONS(2083),
    [anon_sym___extension__] = ACTIONS(2078),
    [anon_sym_typedef] = ACTIONS(2078),
    [anon_sym___device__] = ACTIONS(2078),
    [anon_sym___host__] = ACTIONS(2078),
    [anon_sym___global__] = ACTIONS(2078),
    [anon_sym___forceinline__] = ACTIONS(2078),
    [anon_sym___noinline__] = ACTIONS(2078),
    [anon_sym_virtual] = ACTIONS(2078),
    [anon_sym_extern] = ACTIONS(2078),
    [anon_sym___attribute__] = ACTIONS(2078),
    [anon_sym___attribute] = ACTIONS(2078),
    [anon_sym_COLON_COLON] = ACTIONS(2083),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2083),
    [anon_sym___declspec] = ACTIONS(2078),
    [anon_sym___based] = ACTIONS(2078),
    [anon_sym___cdecl] = ACTIONS(2078),
    [anon_sym___clrcall] = ACTIONS(2078),
    [anon_sym___stdcall] = ACTIONS(2078),
    [anon_sym___fastcall] = ACTIONS(2078),
    [anon_sym___thiscall] = ACTIONS(2078),
    [anon_sym___vectorcall] = ACTIONS(2078),
    [anon_sym_LBRACE] = ACTIONS(2083),
    [anon_sym_signed] = ACTIONS(2078),
    [anon_sym_unsigned] = ACTIONS(2078),
    [anon_sym_long] = ACTIONS(2078),
    [anon_sym_short] = ACTIONS(2078),
    [anon_sym_LBRACK] = ACTIONS(2078),
    [anon_sym_static] = ACTIONS(2078),
    [anon_sym_register] = ACTIONS(2078),
    [anon_sym_inline] = ACTIONS(2078),
    [anon_sym___inline] = ACTIONS(2078),
    [anon_sym___inline__] = ACTIONS(2078),
    [anon_sym___forceinline] = ACTIONS(2078),
    [anon_sym_thread_local] = ACTIONS(2078),
    [anon_sym___thread] = ACTIONS(2078),
    [anon_sym_const] = ACTIONS(2078),
    [anon_sym_constexpr] = ACTIONS(2078),
    [anon_sym_volatile] = ACTIONS(2078),
    [anon_sym_restrict] = ACTIONS(2078),
    [anon_sym___restrict__] = ACTIONS(2078),
    [anon_sym__Atomic] = ACTIONS(2078),
    [anon_sym__Noreturn] = ACTIONS(2078),
    [anon_sym_noreturn] = ACTIONS(2078),
    [anon_sym__Nonnull] = ACTIONS(2078),
    [anon_sym_mutable] = ACTIONS(2078),
    [anon_sym_constinit] = ACTIONS(2078),
    [anon_sym_consteval] = ACTIONS(2078),
    [anon_sym___shared__] = ACTIONS(2078),
    [anon_sym___local__] = ACTIONS(2078),
    [anon_sym___constant__] = ACTIONS(2078),
    [anon_sym___managed__] = ACTIONS(2078),
    [anon_sym___grid_constant__] = ACTIONS(2078),
    [anon_sym_alignas] = ACTIONS(2078),
    [anon_sym__Alignas] = ACTIONS(2078),
    [sym_primitive_type] = ACTIONS(2078),
    [anon_sym_enum] = ACTIONS(2078),
    [anon_sym_class] = ACTIONS(2078),
    [anon_sym_struct] = ACTIONS(2078),
    [anon_sym_union] = ACTIONS(2078),
    [anon_sym_if] = ACTIONS(2078),
    [anon_sym_else] = ACTIONS(2078),
    [anon_sym_switch] = ACTIONS(2078),
    [anon_sym_case] = ACTIONS(2078),
    [anon_sym_default] = ACTIONS(2078),
    [anon_sym_while] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(2078),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_return] = ACTIONS(2078),
    [anon_sym_break] = ACTIONS(2078),
    [anon_sym_continue] = ACTIONS(2078),
    [anon_sym_goto] = ACTIONS(2078),
    [anon_sym___try] = ACTIONS(2078),
    [anon_sym___leave] = ACTIONS(2078),
    [anon_sym_not] = ACTIONS(2078),
    [anon_sym_compl] = ACTIONS(2078),
    [anon_sym_DASH_DASH] = ACTIONS(2083),
    [anon_sym_PLUS_PLUS] = ACTIONS(2083),
    [anon_sym_sizeof] = ACTIONS(2078),
    [anon_sym___alignof__] = ACTIONS(2078),
    [anon_sym___alignof] = ACTIONS(2078),
    [anon_sym__alignof] = ACTIONS(2078),
    [anon_sym_alignof] = ACTIONS(2078),
    [anon_sym__Alignof] = ACTIONS(2078),
    [anon_sym_offsetof] = ACTIONS(2078),
    [anon_sym__Generic] = ACTIONS(2078),
    [anon_sym_asm] = ACTIONS(2078),
    [anon_sym___asm__] = ACTIONS(2078),
    [anon_sym___asm] = ACTIONS(2078),
    [sym_number_literal] = ACTIONS(2083),
    [anon_sym_L_SQUOTE] = ACTIONS(2083),
    [anon_sym_u_SQUOTE] = ACTIONS(2083),
    [anon_sym_U_SQUOTE] = ACTIONS(2083),
    [anon_sym_u8_SQUOTE] = ACTIONS(2083),
    [anon_sym_SQUOTE] = ACTIONS(2083),
    [anon_sym_L_DQUOTE] = ACTIONS(2083),
    [anon_sym_u_DQUOTE] = ACTIONS(2083),
    [anon_sym_U_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8_DQUOTE] = ACTIONS(2083),
    [anon_sym_DQUOTE] = ACTIONS(2083),
    [sym_true] = ACTIONS(2078),
    [sym_false] = ACTIONS(2078),
    [anon_sym_NULL] = ACTIONS(2078),
    [anon_sym_nullptr] = ACTIONS(2078),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2078),
    [anon_sym_decltype] = ACTIONS(2078),
    [anon_sym_explicit] = ACTIONS(2078),
    [anon_sym_typename] = ACTIONS(2078),
    [anon_sym_template] = ACTIONS(2078),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2078),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_namespace] = ACTIONS(2078),
    [anon_sym_using] = ACTIONS(2078),
    [anon_sym_static_assert] = ACTIONS(2078),
    [anon_sym_concept] = ACTIONS(2078),
    [anon_sym_co_return] = ACTIONS(2078),
    [anon_sym_co_yield] = ACTIONS(2078),
    [anon_sym_R_DQUOTE] = ACTIONS(2083),
    [anon_sym_LR_DQUOTE] = ACTIONS(2083),
    [anon_sym_uR_DQUOTE] = ACTIONS(2083),
    [anon_sym_UR_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2083),
    [anon_sym_co_await] = ACTIONS(2078),
    [anon_sym_new] = ACTIONS(2078),
    [anon_sym_requires] = ACTIONS(2078),
    [sym_this] = ACTIONS(2078),
    [anon_sym___launch_bounds__] = ACTIONS(2078),
  },
  [STATE(417)] = {
    [sym_identifier] = ACTIONS(2166),
    [aux_sym_preproc_include_token1] = ACTIONS(2166),
    [aux_sym_preproc_def_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token2] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2166),
    [sym_preproc_directive] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP_AMP] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2166),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym___device__] = ACTIONS(2166),
    [anon_sym___host__] = ACTIONS(2166),
    [anon_sym___global__] = ACTIONS(2166),
    [anon_sym___forceinline__] = ACTIONS(2166),
    [anon_sym___noinline__] = ACTIONS(2166),
    [anon_sym_virtual] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym___attribute] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym___based] = ACTIONS(2166),
    [anon_sym___cdecl] = ACTIONS(2166),
    [anon_sym___clrcall] = ACTIONS(2166),
    [anon_sym___stdcall] = ACTIONS(2166),
    [anon_sym___fastcall] = ACTIONS(2166),
    [anon_sym___thiscall] = ACTIONS(2166),
    [anon_sym___vectorcall] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym__Nonnull] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym___shared__] = ACTIONS(2166),
    [anon_sym___local__] = ACTIONS(2166),
    [anon_sym___constant__] = ACTIONS(2166),
    [anon_sym___managed__] = ACTIONS(2166),
    [anon_sym___grid_constant__] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym_default] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [anon_sym___asm] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [anon_sym_explicit] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_operator] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_namespace] = ACTIONS(2166),
    [anon_sym_using] = ACTIONS(2166),
    [anon_sym_static_assert] = ACTIONS(2166),
    [anon_sym_concept] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym___launch_bounds__] = ACTIONS(2166),
  },
  [STATE(418)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(419)] = {
    [sym_identifier] = ACTIONS(2032),
    [aux_sym_preproc_include_token1] = ACTIONS(2032),
    [aux_sym_preproc_def_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token2] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2032),
    [sym_preproc_directive] = ACTIONS(2032),
    [anon_sym_LPAREN2] = ACTIONS(2034),
    [anon_sym_BANG] = ACTIONS(2034),
    [anon_sym_TILDE] = ACTIONS(2034),
    [anon_sym_DASH] = ACTIONS(2032),
    [anon_sym_PLUS] = ACTIONS(2032),
    [anon_sym_STAR] = ACTIONS(2034),
    [anon_sym_AMP_AMP] = ACTIONS(2034),
    [anon_sym_AMP] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(2034),
    [anon_sym___extension__] = ACTIONS(2032),
    [anon_sym_typedef] = ACTIONS(2032),
    [anon_sym___device__] = ACTIONS(2032),
    [anon_sym___host__] = ACTIONS(2032),
    [anon_sym___global__] = ACTIONS(2032),
    [anon_sym___forceinline__] = ACTIONS(2032),
    [anon_sym___noinline__] = ACTIONS(2032),
    [anon_sym_virtual] = ACTIONS(2032),
    [anon_sym_extern] = ACTIONS(2032),
    [anon_sym___attribute__] = ACTIONS(2032),
    [anon_sym___attribute] = ACTIONS(2032),
    [anon_sym_COLON_COLON] = ACTIONS(2034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2034),
    [anon_sym___declspec] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(2032),
    [anon_sym___cdecl] = ACTIONS(2032),
    [anon_sym___clrcall] = ACTIONS(2032),
    [anon_sym___stdcall] = ACTIONS(2032),
    [anon_sym___fastcall] = ACTIONS(2032),
    [anon_sym___thiscall] = ACTIONS(2032),
    [anon_sym___vectorcall] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2032),
    [anon_sym_unsigned] = ACTIONS(2032),
    [anon_sym_long] = ACTIONS(2032),
    [anon_sym_short] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(2032),
    [anon_sym_static] = ACTIONS(2032),
    [anon_sym_register] = ACTIONS(2032),
    [anon_sym_inline] = ACTIONS(2032),
    [anon_sym___inline] = ACTIONS(2032),
    [anon_sym___inline__] = ACTIONS(2032),
    [anon_sym___forceinline] = ACTIONS(2032),
    [anon_sym_thread_local] = ACTIONS(2032),
    [anon_sym___thread] = ACTIONS(2032),
    [anon_sym_const] = ACTIONS(2032),
    [anon_sym_constexpr] = ACTIONS(2032),
    [anon_sym_volatile] = ACTIONS(2032),
    [anon_sym_restrict] = ACTIONS(2032),
    [anon_sym___restrict__] = ACTIONS(2032),
    [anon_sym__Atomic] = ACTIONS(2032),
    [anon_sym__Noreturn] = ACTIONS(2032),
    [anon_sym_noreturn] = ACTIONS(2032),
    [anon_sym__Nonnull] = ACTIONS(2032),
    [anon_sym_mutable] = ACTIONS(2032),
    [anon_sym_constinit] = ACTIONS(2032),
    [anon_sym_consteval] = ACTIONS(2032),
    [anon_sym___shared__] = ACTIONS(2032),
    [anon_sym___local__] = ACTIONS(2032),
    [anon_sym___constant__] = ACTIONS(2032),
    [anon_sym___managed__] = ACTIONS(2032),
    [anon_sym___grid_constant__] = ACTIONS(2032),
    [anon_sym_alignas] = ACTIONS(2032),
    [anon_sym__Alignas] = ACTIONS(2032),
    [sym_primitive_type] = ACTIONS(2032),
    [anon_sym_enum] = ACTIONS(2032),
    [anon_sym_class] = ACTIONS(2032),
    [anon_sym_struct] = ACTIONS(2032),
    [anon_sym_union] = ACTIONS(2032),
    [anon_sym_if] = ACTIONS(2032),
    [anon_sym_else] = ACTIONS(2032),
    [anon_sym_switch] = ACTIONS(2032),
    [anon_sym_case] = ACTIONS(2032),
    [anon_sym_default] = ACTIONS(2032),
    [anon_sym_while] = ACTIONS(2032),
    [anon_sym_do] = ACTIONS(2032),
    [anon_sym_for] = ACTIONS(2032),
    [anon_sym_return] = ACTIONS(2032),
    [anon_sym_break] = ACTIONS(2032),
    [anon_sym_continue] = ACTIONS(2032),
    [anon_sym_goto] = ACTIONS(2032),
    [anon_sym___try] = ACTIONS(2032),
    [anon_sym___leave] = ACTIONS(2032),
    [anon_sym_not] = ACTIONS(2032),
    [anon_sym_compl] = ACTIONS(2032),
    [anon_sym_DASH_DASH] = ACTIONS(2034),
    [anon_sym_PLUS_PLUS] = ACTIONS(2034),
    [anon_sym_sizeof] = ACTIONS(2032),
    [anon_sym___alignof__] = ACTIONS(2032),
    [anon_sym___alignof] = ACTIONS(2032),
    [anon_sym__alignof] = ACTIONS(2032),
    [anon_sym_alignof] = ACTIONS(2032),
    [anon_sym__Alignof] = ACTIONS(2032),
    [anon_sym_offsetof] = ACTIONS(2032),
    [anon_sym__Generic] = ACTIONS(2032),
    [anon_sym_asm] = ACTIONS(2032),
    [anon_sym___asm__] = ACTIONS(2032),
    [anon_sym___asm] = ACTIONS(2032),
    [sym_number_literal] = ACTIONS(2034),
    [anon_sym_L_SQUOTE] = ACTIONS(2034),
    [anon_sym_u_SQUOTE] = ACTIONS(2034),
    [anon_sym_U_SQUOTE] = ACTIONS(2034),
    [anon_sym_u8_SQUOTE] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2034),
    [anon_sym_L_DQUOTE] = ACTIONS(2034),
    [anon_sym_u_DQUOTE] = ACTIONS(2034),
    [anon_sym_U_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8_DQUOTE] = ACTIONS(2034),
    [anon_sym_DQUOTE] = ACTIONS(2034),
    [sym_true] = ACTIONS(2032),
    [sym_false] = ACTIONS(2032),
    [anon_sym_NULL] = ACTIONS(2032),
    [anon_sym_nullptr] = ACTIONS(2032),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2032),
    [anon_sym_decltype] = ACTIONS(2032),
    [anon_sym_explicit] = ACTIONS(2032),
    [anon_sym_typename] = ACTIONS(2032),
    [anon_sym_template] = ACTIONS(2032),
    [anon_sym_operator] = ACTIONS(2032),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_delete] = ACTIONS(2032),
    [anon_sym_throw] = ACTIONS(2032),
    [anon_sym_namespace] = ACTIONS(2032),
    [anon_sym_using] = ACTIONS(2032),
    [anon_sym_static_assert] = ACTIONS(2032),
    [anon_sym_concept] = ACTIONS(2032),
    [anon_sym_co_return] = ACTIONS(2032),
    [anon_sym_co_yield] = ACTIONS(2032),
    [anon_sym_R_DQUOTE] = ACTIONS(2034),
    [anon_sym_LR_DQUOTE] = ACTIONS(2034),
    [anon_sym_uR_DQUOTE] = ACTIONS(2034),
    [anon_sym_UR_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2034),
    [anon_sym_co_await] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(2032),
    [anon_sym_requires] = ACTIONS(2032),
    [sym_this] = ACTIONS(2032),
    [anon_sym___launch_bounds__] = ACTIONS(2032),
  },
  [STATE(420)] = {
    [sym_identifier] = ACTIONS(2218),
    [aux_sym_preproc_include_token1] = ACTIONS(2218),
    [aux_sym_preproc_def_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token2] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2218),
    [sym_preproc_directive] = ACTIONS(2218),
    [anon_sym_LPAREN2] = ACTIONS(2220),
    [anon_sym_BANG] = ACTIONS(2220),
    [anon_sym_TILDE] = ACTIONS(2220),
    [anon_sym_DASH] = ACTIONS(2218),
    [anon_sym_PLUS] = ACTIONS(2218),
    [anon_sym_STAR] = ACTIONS(2220),
    [anon_sym_AMP_AMP] = ACTIONS(2220),
    [anon_sym_AMP] = ACTIONS(2218),
    [anon_sym_SEMI] = ACTIONS(2220),
    [anon_sym___extension__] = ACTIONS(2218),
    [anon_sym_typedef] = ACTIONS(2218),
    [anon_sym___device__] = ACTIONS(2218),
    [anon_sym___host__] = ACTIONS(2218),
    [anon_sym___global__] = ACTIONS(2218),
    [anon_sym___forceinline__] = ACTIONS(2218),
    [anon_sym___noinline__] = ACTIONS(2218),
    [anon_sym_virtual] = ACTIONS(2218),
    [anon_sym_extern] = ACTIONS(2218),
    [anon_sym___attribute__] = ACTIONS(2218),
    [anon_sym___attribute] = ACTIONS(2218),
    [anon_sym_COLON_COLON] = ACTIONS(2220),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2220),
    [anon_sym___declspec] = ACTIONS(2218),
    [anon_sym___based] = ACTIONS(2218),
    [anon_sym___cdecl] = ACTIONS(2218),
    [anon_sym___clrcall] = ACTIONS(2218),
    [anon_sym___stdcall] = ACTIONS(2218),
    [anon_sym___fastcall] = ACTIONS(2218),
    [anon_sym___thiscall] = ACTIONS(2218),
    [anon_sym___vectorcall] = ACTIONS(2218),
    [anon_sym_LBRACE] = ACTIONS(2220),
    [anon_sym_signed] = ACTIONS(2218),
    [anon_sym_unsigned] = ACTIONS(2218),
    [anon_sym_long] = ACTIONS(2218),
    [anon_sym_short] = ACTIONS(2218),
    [anon_sym_LBRACK] = ACTIONS(2218),
    [anon_sym_static] = ACTIONS(2218),
    [anon_sym_register] = ACTIONS(2218),
    [anon_sym_inline] = ACTIONS(2218),
    [anon_sym___inline] = ACTIONS(2218),
    [anon_sym___inline__] = ACTIONS(2218),
    [anon_sym___forceinline] = ACTIONS(2218),
    [anon_sym_thread_local] = ACTIONS(2218),
    [anon_sym___thread] = ACTIONS(2218),
    [anon_sym_const] = ACTIONS(2218),
    [anon_sym_constexpr] = ACTIONS(2218),
    [anon_sym_volatile] = ACTIONS(2218),
    [anon_sym_restrict] = ACTIONS(2218),
    [anon_sym___restrict__] = ACTIONS(2218),
    [anon_sym__Atomic] = ACTIONS(2218),
    [anon_sym__Noreturn] = ACTIONS(2218),
    [anon_sym_noreturn] = ACTIONS(2218),
    [anon_sym__Nonnull] = ACTIONS(2218),
    [anon_sym_mutable] = ACTIONS(2218),
    [anon_sym_constinit] = ACTIONS(2218),
    [anon_sym_consteval] = ACTIONS(2218),
    [anon_sym___shared__] = ACTIONS(2218),
    [anon_sym___local__] = ACTIONS(2218),
    [anon_sym___constant__] = ACTIONS(2218),
    [anon_sym___managed__] = ACTIONS(2218),
    [anon_sym___grid_constant__] = ACTIONS(2218),
    [anon_sym_alignas] = ACTIONS(2218),
    [anon_sym__Alignas] = ACTIONS(2218),
    [sym_primitive_type] = ACTIONS(2218),
    [anon_sym_enum] = ACTIONS(2218),
    [anon_sym_class] = ACTIONS(2218),
    [anon_sym_struct] = ACTIONS(2218),
    [anon_sym_union] = ACTIONS(2218),
    [anon_sym_if] = ACTIONS(2218),
    [anon_sym_else] = ACTIONS(2218),
    [anon_sym_switch] = ACTIONS(2218),
    [anon_sym_case] = ACTIONS(2218),
    [anon_sym_default] = ACTIONS(2218),
    [anon_sym_while] = ACTIONS(2218),
    [anon_sym_do] = ACTIONS(2218),
    [anon_sym_for] = ACTIONS(2218),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_break] = ACTIONS(2218),
    [anon_sym_continue] = ACTIONS(2218),
    [anon_sym_goto] = ACTIONS(2218),
    [anon_sym___try] = ACTIONS(2218),
    [anon_sym___leave] = ACTIONS(2218),
    [anon_sym_not] = ACTIONS(2218),
    [anon_sym_compl] = ACTIONS(2218),
    [anon_sym_DASH_DASH] = ACTIONS(2220),
    [anon_sym_PLUS_PLUS] = ACTIONS(2220),
    [anon_sym_sizeof] = ACTIONS(2218),
    [anon_sym___alignof__] = ACTIONS(2218),
    [anon_sym___alignof] = ACTIONS(2218),
    [anon_sym__alignof] = ACTIONS(2218),
    [anon_sym_alignof] = ACTIONS(2218),
    [anon_sym__Alignof] = ACTIONS(2218),
    [anon_sym_offsetof] = ACTIONS(2218),
    [anon_sym__Generic] = ACTIONS(2218),
    [anon_sym_asm] = ACTIONS(2218),
    [anon_sym___asm__] = ACTIONS(2218),
    [anon_sym___asm] = ACTIONS(2218),
    [sym_number_literal] = ACTIONS(2220),
    [anon_sym_L_SQUOTE] = ACTIONS(2220),
    [anon_sym_u_SQUOTE] = ACTIONS(2220),
    [anon_sym_U_SQUOTE] = ACTIONS(2220),
    [anon_sym_u8_SQUOTE] = ACTIONS(2220),
    [anon_sym_SQUOTE] = ACTIONS(2220),
    [anon_sym_L_DQUOTE] = ACTIONS(2220),
    [anon_sym_u_DQUOTE] = ACTIONS(2220),
    [anon_sym_U_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8_DQUOTE] = ACTIONS(2220),
    [anon_sym_DQUOTE] = ACTIONS(2220),
    [sym_true] = ACTIONS(2218),
    [sym_false] = ACTIONS(2218),
    [anon_sym_NULL] = ACTIONS(2218),
    [anon_sym_nullptr] = ACTIONS(2218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2218),
    [anon_sym_decltype] = ACTIONS(2218),
    [anon_sym_explicit] = ACTIONS(2218),
    [anon_sym_typename] = ACTIONS(2218),
    [anon_sym_template] = ACTIONS(2218),
    [anon_sym_operator] = ACTIONS(2218),
    [anon_sym_try] = ACTIONS(2218),
    [anon_sym_delete] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2218),
    [anon_sym_namespace] = ACTIONS(2218),
    [anon_sym_using] = ACTIONS(2218),
    [anon_sym_static_assert] = ACTIONS(2218),
    [anon_sym_concept] = ACTIONS(2218),
    [anon_sym_co_return] = ACTIONS(2218),
    [anon_sym_co_yield] = ACTIONS(2218),
    [anon_sym_R_DQUOTE] = ACTIONS(2220),
    [anon_sym_LR_DQUOTE] = ACTIONS(2220),
    [anon_sym_uR_DQUOTE] = ACTIONS(2220),
    [anon_sym_UR_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2220),
    [anon_sym_co_await] = ACTIONS(2218),
    [anon_sym_new] = ACTIONS(2218),
    [anon_sym_requires] = ACTIONS(2218),
    [sym_this] = ACTIONS(2218),
    [anon_sym___launch_bounds__] = ACTIONS(2218),
  },
  [STATE(421)] = {
    [sym_identifier] = ACTIONS(2044),
    [aux_sym_preproc_include_token1] = ACTIONS(2044),
    [aux_sym_preproc_def_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token2] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2044),
    [sym_preproc_directive] = ACTIONS(2044),
    [anon_sym_LPAREN2] = ACTIONS(2046),
    [anon_sym_BANG] = ACTIONS(2046),
    [anon_sym_TILDE] = ACTIONS(2046),
    [anon_sym_DASH] = ACTIONS(2044),
    [anon_sym_PLUS] = ACTIONS(2044),
    [anon_sym_STAR] = ACTIONS(2046),
    [anon_sym_AMP_AMP] = ACTIONS(2046),
    [anon_sym_AMP] = ACTIONS(2044),
    [anon_sym_SEMI] = ACTIONS(2046),
    [anon_sym___extension__] = ACTIONS(2044),
    [anon_sym_typedef] = ACTIONS(2044),
    [anon_sym___device__] = ACTIONS(2044),
    [anon_sym___host__] = ACTIONS(2044),
    [anon_sym___global__] = ACTIONS(2044),
    [anon_sym___forceinline__] = ACTIONS(2044),
    [anon_sym___noinline__] = ACTIONS(2044),
    [anon_sym_virtual] = ACTIONS(2044),
    [anon_sym_extern] = ACTIONS(2044),
    [anon_sym___attribute__] = ACTIONS(2044),
    [anon_sym___attribute] = ACTIONS(2044),
    [anon_sym_COLON_COLON] = ACTIONS(2046),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2046),
    [anon_sym___declspec] = ACTIONS(2044),
    [anon_sym___based] = ACTIONS(2044),
    [anon_sym___cdecl] = ACTIONS(2044),
    [anon_sym___clrcall] = ACTIONS(2044),
    [anon_sym___stdcall] = ACTIONS(2044),
    [anon_sym___fastcall] = ACTIONS(2044),
    [anon_sym___thiscall] = ACTIONS(2044),
    [anon_sym___vectorcall] = ACTIONS(2044),
    [anon_sym_LBRACE] = ACTIONS(2046),
    [anon_sym_signed] = ACTIONS(2044),
    [anon_sym_unsigned] = ACTIONS(2044),
    [anon_sym_long] = ACTIONS(2044),
    [anon_sym_short] = ACTIONS(2044),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_static] = ACTIONS(2044),
    [anon_sym_register] = ACTIONS(2044),
    [anon_sym_inline] = ACTIONS(2044),
    [anon_sym___inline] = ACTIONS(2044),
    [anon_sym___inline__] = ACTIONS(2044),
    [anon_sym___forceinline] = ACTIONS(2044),
    [anon_sym_thread_local] = ACTIONS(2044),
    [anon_sym___thread] = ACTIONS(2044),
    [anon_sym_const] = ACTIONS(2044),
    [anon_sym_constexpr] = ACTIONS(2044),
    [anon_sym_volatile] = ACTIONS(2044),
    [anon_sym_restrict] = ACTIONS(2044),
    [anon_sym___restrict__] = ACTIONS(2044),
    [anon_sym__Atomic] = ACTIONS(2044),
    [anon_sym__Noreturn] = ACTIONS(2044),
    [anon_sym_noreturn] = ACTIONS(2044),
    [anon_sym__Nonnull] = ACTIONS(2044),
    [anon_sym_mutable] = ACTIONS(2044),
    [anon_sym_constinit] = ACTIONS(2044),
    [anon_sym_consteval] = ACTIONS(2044),
    [anon_sym___shared__] = ACTIONS(2044),
    [anon_sym___local__] = ACTIONS(2044),
    [anon_sym___constant__] = ACTIONS(2044),
    [anon_sym___managed__] = ACTIONS(2044),
    [anon_sym___grid_constant__] = ACTIONS(2044),
    [anon_sym_alignas] = ACTIONS(2044),
    [anon_sym__Alignas] = ACTIONS(2044),
    [sym_primitive_type] = ACTIONS(2044),
    [anon_sym_enum] = ACTIONS(2044),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2044),
    [anon_sym_union] = ACTIONS(2044),
    [anon_sym_if] = ACTIONS(2044),
    [anon_sym_else] = ACTIONS(2044),
    [anon_sym_switch] = ACTIONS(2044),
    [anon_sym_case] = ACTIONS(2044),
    [anon_sym_default] = ACTIONS(2044),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_do] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2044),
    [anon_sym_return] = ACTIONS(2044),
    [anon_sym_break] = ACTIONS(2044),
    [anon_sym_continue] = ACTIONS(2044),
    [anon_sym_goto] = ACTIONS(2044),
    [anon_sym___try] = ACTIONS(2044),
    [anon_sym___leave] = ACTIONS(2044),
    [anon_sym_not] = ACTIONS(2044),
    [anon_sym_compl] = ACTIONS(2044),
    [anon_sym_DASH_DASH] = ACTIONS(2046),
    [anon_sym_PLUS_PLUS] = ACTIONS(2046),
    [anon_sym_sizeof] = ACTIONS(2044),
    [anon_sym___alignof__] = ACTIONS(2044),
    [anon_sym___alignof] = ACTIONS(2044),
    [anon_sym__alignof] = ACTIONS(2044),
    [anon_sym_alignof] = ACTIONS(2044),
    [anon_sym__Alignof] = ACTIONS(2044),
    [anon_sym_offsetof] = ACTIONS(2044),
    [anon_sym__Generic] = ACTIONS(2044),
    [anon_sym_asm] = ACTIONS(2044),
    [anon_sym___asm__] = ACTIONS(2044),
    [anon_sym___asm] = ACTIONS(2044),
    [sym_number_literal] = ACTIONS(2046),
    [anon_sym_L_SQUOTE] = ACTIONS(2046),
    [anon_sym_u_SQUOTE] = ACTIONS(2046),
    [anon_sym_U_SQUOTE] = ACTIONS(2046),
    [anon_sym_u8_SQUOTE] = ACTIONS(2046),
    [anon_sym_SQUOTE] = ACTIONS(2046),
    [anon_sym_L_DQUOTE] = ACTIONS(2046),
    [anon_sym_u_DQUOTE] = ACTIONS(2046),
    [anon_sym_U_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8_DQUOTE] = ACTIONS(2046),
    [anon_sym_DQUOTE] = ACTIONS(2046),
    [sym_true] = ACTIONS(2044),
    [sym_false] = ACTIONS(2044),
    [anon_sym_NULL] = ACTIONS(2044),
    [anon_sym_nullptr] = ACTIONS(2044),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2044),
    [anon_sym_decltype] = ACTIONS(2044),
    [anon_sym_explicit] = ACTIONS(2044),
    [anon_sym_typename] = ACTIONS(2044),
    [anon_sym_template] = ACTIONS(2044),
    [anon_sym_operator] = ACTIONS(2044),
    [anon_sym_try] = ACTIONS(2044),
    [anon_sym_delete] = ACTIONS(2044),
    [anon_sym_throw] = ACTIONS(2044),
    [anon_sym_namespace] = ACTIONS(2044),
    [anon_sym_using] = ACTIONS(2044),
    [anon_sym_static_assert] = ACTIONS(2044),
    [anon_sym_concept] = ACTIONS(2044),
    [anon_sym_co_return] = ACTIONS(2044),
    [anon_sym_co_yield] = ACTIONS(2044),
    [anon_sym_R_DQUOTE] = ACTIONS(2046),
    [anon_sym_LR_DQUOTE] = ACTIONS(2046),
    [anon_sym_uR_DQUOTE] = ACTIONS(2046),
    [anon_sym_UR_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2046),
    [anon_sym_co_await] = ACTIONS(2044),
    [anon_sym_new] = ACTIONS(2044),
    [anon_sym_requires] = ACTIONS(2044),
    [sym_this] = ACTIONS(2044),
    [anon_sym___launch_bounds__] = ACTIONS(2044),
  },
  [STATE(422)] = {
    [sym_identifier] = ACTIONS(2028),
    [aux_sym_preproc_include_token1] = ACTIONS(2028),
    [aux_sym_preproc_def_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token2] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2028),
    [sym_preproc_directive] = ACTIONS(2028),
    [anon_sym_LPAREN2] = ACTIONS(2030),
    [anon_sym_BANG] = ACTIONS(2030),
    [anon_sym_TILDE] = ACTIONS(2030),
    [anon_sym_DASH] = ACTIONS(2028),
    [anon_sym_PLUS] = ACTIONS(2028),
    [anon_sym_STAR] = ACTIONS(2030),
    [anon_sym_AMP_AMP] = ACTIONS(2030),
    [anon_sym_AMP] = ACTIONS(2028),
    [anon_sym_SEMI] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(2028),
    [anon_sym_typedef] = ACTIONS(2028),
    [anon_sym___device__] = ACTIONS(2028),
    [anon_sym___host__] = ACTIONS(2028),
    [anon_sym___global__] = ACTIONS(2028),
    [anon_sym___forceinline__] = ACTIONS(2028),
    [anon_sym___noinline__] = ACTIONS(2028),
    [anon_sym_virtual] = ACTIONS(2028),
    [anon_sym_extern] = ACTIONS(2028),
    [anon_sym___attribute__] = ACTIONS(2028),
    [anon_sym___attribute] = ACTIONS(2028),
    [anon_sym_COLON_COLON] = ACTIONS(2030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2030),
    [anon_sym___declspec] = ACTIONS(2028),
    [anon_sym___based] = ACTIONS(2028),
    [anon_sym___cdecl] = ACTIONS(2028),
    [anon_sym___clrcall] = ACTIONS(2028),
    [anon_sym___stdcall] = ACTIONS(2028),
    [anon_sym___fastcall] = ACTIONS(2028),
    [anon_sym___thiscall] = ACTIONS(2028),
    [anon_sym___vectorcall] = ACTIONS(2028),
    [anon_sym_LBRACE] = ACTIONS(2030),
    [anon_sym_signed] = ACTIONS(2028),
    [anon_sym_unsigned] = ACTIONS(2028),
    [anon_sym_long] = ACTIONS(2028),
    [anon_sym_short] = ACTIONS(2028),
    [anon_sym_LBRACK] = ACTIONS(2028),
    [anon_sym_static] = ACTIONS(2028),
    [anon_sym_register] = ACTIONS(2028),
    [anon_sym_inline] = ACTIONS(2028),
    [anon_sym___inline] = ACTIONS(2028),
    [anon_sym___inline__] = ACTIONS(2028),
    [anon_sym___forceinline] = ACTIONS(2028),
    [anon_sym_thread_local] = ACTIONS(2028),
    [anon_sym___thread] = ACTIONS(2028),
    [anon_sym_const] = ACTIONS(2028),
    [anon_sym_constexpr] = ACTIONS(2028),
    [anon_sym_volatile] = ACTIONS(2028),
    [anon_sym_restrict] = ACTIONS(2028),
    [anon_sym___restrict__] = ACTIONS(2028),
    [anon_sym__Atomic] = ACTIONS(2028),
    [anon_sym__Noreturn] = ACTIONS(2028),
    [anon_sym_noreturn] = ACTIONS(2028),
    [anon_sym__Nonnull] = ACTIONS(2028),
    [anon_sym_mutable] = ACTIONS(2028),
    [anon_sym_constinit] = ACTIONS(2028),
    [anon_sym_consteval] = ACTIONS(2028),
    [anon_sym___shared__] = ACTIONS(2028),
    [anon_sym___local__] = ACTIONS(2028),
    [anon_sym___constant__] = ACTIONS(2028),
    [anon_sym___managed__] = ACTIONS(2028),
    [anon_sym___grid_constant__] = ACTIONS(2028),
    [anon_sym_alignas] = ACTIONS(2028),
    [anon_sym__Alignas] = ACTIONS(2028),
    [sym_primitive_type] = ACTIONS(2028),
    [anon_sym_enum] = ACTIONS(2028),
    [anon_sym_class] = ACTIONS(2028),
    [anon_sym_struct] = ACTIONS(2028),
    [anon_sym_union] = ACTIONS(2028),
    [anon_sym_if] = ACTIONS(2028),
    [anon_sym_else] = ACTIONS(2028),
    [anon_sym_switch] = ACTIONS(2028),
    [anon_sym_case] = ACTIONS(2028),
    [anon_sym_default] = ACTIONS(2028),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_do] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2028),
    [anon_sym_return] = ACTIONS(2028),
    [anon_sym_break] = ACTIONS(2028),
    [anon_sym_continue] = ACTIONS(2028),
    [anon_sym_goto] = ACTIONS(2028),
    [anon_sym___try] = ACTIONS(2028),
    [anon_sym___leave] = ACTIONS(2028),
    [anon_sym_not] = ACTIONS(2028),
    [anon_sym_compl] = ACTIONS(2028),
    [anon_sym_DASH_DASH] = ACTIONS(2030),
    [anon_sym_PLUS_PLUS] = ACTIONS(2030),
    [anon_sym_sizeof] = ACTIONS(2028),
    [anon_sym___alignof__] = ACTIONS(2028),
    [anon_sym___alignof] = ACTIONS(2028),
    [anon_sym__alignof] = ACTIONS(2028),
    [anon_sym_alignof] = ACTIONS(2028),
    [anon_sym__Alignof] = ACTIONS(2028),
    [anon_sym_offsetof] = ACTIONS(2028),
    [anon_sym__Generic] = ACTIONS(2028),
    [anon_sym_asm] = ACTIONS(2028),
    [anon_sym___asm__] = ACTIONS(2028),
    [anon_sym___asm] = ACTIONS(2028),
    [sym_number_literal] = ACTIONS(2030),
    [anon_sym_L_SQUOTE] = ACTIONS(2030),
    [anon_sym_u_SQUOTE] = ACTIONS(2030),
    [anon_sym_U_SQUOTE] = ACTIONS(2030),
    [anon_sym_u8_SQUOTE] = ACTIONS(2030),
    [anon_sym_SQUOTE] = ACTIONS(2030),
    [anon_sym_L_DQUOTE] = ACTIONS(2030),
    [anon_sym_u_DQUOTE] = ACTIONS(2030),
    [anon_sym_U_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8_DQUOTE] = ACTIONS(2030),
    [anon_sym_DQUOTE] = ACTIONS(2030),
    [sym_true] = ACTIONS(2028),
    [sym_false] = ACTIONS(2028),
    [anon_sym_NULL] = ACTIONS(2028),
    [anon_sym_nullptr] = ACTIONS(2028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2028),
    [anon_sym_decltype] = ACTIONS(2028),
    [anon_sym_explicit] = ACTIONS(2028),
    [anon_sym_typename] = ACTIONS(2028),
    [anon_sym_template] = ACTIONS(2028),
    [anon_sym_operator] = ACTIONS(2028),
    [anon_sym_try] = ACTIONS(2028),
    [anon_sym_delete] = ACTIONS(2028),
    [anon_sym_throw] = ACTIONS(2028),
    [anon_sym_namespace] = ACTIONS(2028),
    [anon_sym_using] = ACTIONS(2028),
    [anon_sym_static_assert] = ACTIONS(2028),
    [anon_sym_concept] = ACTIONS(2028),
    [anon_sym_co_return] = ACTIONS(2028),
    [anon_sym_co_yield] = ACTIONS(2028),
    [anon_sym_R_DQUOTE] = ACTIONS(2030),
    [anon_sym_LR_DQUOTE] = ACTIONS(2030),
    [anon_sym_uR_DQUOTE] = ACTIONS(2030),
    [anon_sym_UR_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2030),
    [anon_sym_co_await] = ACTIONS(2028),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_requires] = ACTIONS(2028),
    [sym_this] = ACTIONS(2028),
    [anon_sym___launch_bounds__] = ACTIONS(2028),
  },
  [STATE(423)] = {
    [sym_identifier] = ACTIONS(2126),
    [aux_sym_preproc_include_token1] = ACTIONS(2126),
    [aux_sym_preproc_def_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2126),
    [sym_preproc_directive] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP_AMP] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2126),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym___device__] = ACTIONS(2126),
    [anon_sym___host__] = ACTIONS(2126),
    [anon_sym___global__] = ACTIONS(2126),
    [anon_sym___forceinline__] = ACTIONS(2126),
    [anon_sym___noinline__] = ACTIONS(2126),
    [anon_sym_virtual] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym___attribute] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym___based] = ACTIONS(2126),
    [anon_sym___cdecl] = ACTIONS(2126),
    [anon_sym___clrcall] = ACTIONS(2126),
    [anon_sym___stdcall] = ACTIONS(2126),
    [anon_sym___fastcall] = ACTIONS(2126),
    [anon_sym___thiscall] = ACTIONS(2126),
    [anon_sym___vectorcall] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_RBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym__Nonnull] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym___shared__] = ACTIONS(2126),
    [anon_sym___local__] = ACTIONS(2126),
    [anon_sym___constant__] = ACTIONS(2126),
    [anon_sym___managed__] = ACTIONS(2126),
    [anon_sym___grid_constant__] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_case] = ACTIONS(2126),
    [anon_sym_default] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [anon_sym___asm] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [anon_sym_explicit] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_operator] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_namespace] = ACTIONS(2126),
    [anon_sym_using] = ACTIONS(2126),
    [anon_sym_static_assert] = ACTIONS(2126),
    [anon_sym_concept] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym___launch_bounds__] = ACTIONS(2126),
  },
  [STATE(424)] = {
    [sym_expression] = STATE(2632),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_initializer_list] = STATE(2799),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(2715),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2633),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2633),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym___attribute__] = ACTIONS(2633),
    [anon_sym___attribute] = ACTIONS(2633),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_EQ] = ACTIONS(2633),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_STAR_EQ] = ACTIONS(2635),
    [anon_sym_SLASH_EQ] = ACTIONS(2635),
    [anon_sym_PERCENT_EQ] = ACTIONS(2635),
    [anon_sym_PLUS_EQ] = ACTIONS(2635),
    [anon_sym_DASH_EQ] = ACTIONS(2635),
    [anon_sym_LT_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT_GT_EQ] = ACTIONS(2635),
    [anon_sym_AMP_EQ] = ACTIONS(2635),
    [anon_sym_CARET_EQ] = ACTIONS(2635),
    [anon_sym_PIPE_EQ] = ACTIONS(2635),
    [anon_sym_and_eq] = ACTIONS(2633),
    [anon_sym_or_eq] = ACTIONS(2633),
    [anon_sym_xor_eq] = ACTIONS(2633),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(425)] = {
    [sym_identifier] = ACTIONS(2098),
    [aux_sym_preproc_include_token1] = ACTIONS(2098),
    [aux_sym_preproc_def_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2098),
    [sym_preproc_directive] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP_AMP] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2098),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym___device__] = ACTIONS(2098),
    [anon_sym___host__] = ACTIONS(2098),
    [anon_sym___global__] = ACTIONS(2098),
    [anon_sym___forceinline__] = ACTIONS(2098),
    [anon_sym___noinline__] = ACTIONS(2098),
    [anon_sym_virtual] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym___attribute] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym___based] = ACTIONS(2098),
    [anon_sym___cdecl] = ACTIONS(2098),
    [anon_sym___clrcall] = ACTIONS(2098),
    [anon_sym___stdcall] = ACTIONS(2098),
    [anon_sym___fastcall] = ACTIONS(2098),
    [anon_sym___thiscall] = ACTIONS(2098),
    [anon_sym___vectorcall] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_RBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym__Nonnull] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym___shared__] = ACTIONS(2098),
    [anon_sym___local__] = ACTIONS(2098),
    [anon_sym___constant__] = ACTIONS(2098),
    [anon_sym___managed__] = ACTIONS(2098),
    [anon_sym___grid_constant__] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_case] = ACTIONS(2098),
    [anon_sym_default] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [anon_sym___asm] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [anon_sym_explicit] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_operator] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_namespace] = ACTIONS(2098),
    [anon_sym_using] = ACTIONS(2098),
    [anon_sym_static_assert] = ACTIONS(2098),
    [anon_sym_concept] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym___launch_bounds__] = ACTIONS(2098),
  },
  [STATE(426)] = {
    [sym_identifier] = ACTIONS(2170),
    [aux_sym_preproc_include_token1] = ACTIONS(2170),
    [aux_sym_preproc_def_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2170),
    [sym_preproc_directive] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP_AMP] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2170),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym___device__] = ACTIONS(2170),
    [anon_sym___host__] = ACTIONS(2170),
    [anon_sym___global__] = ACTIONS(2170),
    [anon_sym___forceinline__] = ACTIONS(2170),
    [anon_sym___noinline__] = ACTIONS(2170),
    [anon_sym_virtual] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym___attribute] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym___based] = ACTIONS(2170),
    [anon_sym___cdecl] = ACTIONS(2170),
    [anon_sym___clrcall] = ACTIONS(2170),
    [anon_sym___stdcall] = ACTIONS(2170),
    [anon_sym___fastcall] = ACTIONS(2170),
    [anon_sym___thiscall] = ACTIONS(2170),
    [anon_sym___vectorcall] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_RBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym__Nonnull] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym___shared__] = ACTIONS(2170),
    [anon_sym___local__] = ACTIONS(2170),
    [anon_sym___constant__] = ACTIONS(2170),
    [anon_sym___managed__] = ACTIONS(2170),
    [anon_sym___grid_constant__] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_case] = ACTIONS(2170),
    [anon_sym_default] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [anon_sym___asm] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [anon_sym_explicit] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_operator] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_namespace] = ACTIONS(2170),
    [anon_sym_using] = ACTIONS(2170),
    [anon_sym_static_assert] = ACTIONS(2170),
    [anon_sym_concept] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym___launch_bounds__] = ACTIONS(2170),
  },
  [STATE(427)] = {
    [sym_identifier] = ACTIONS(2174),
    [aux_sym_preproc_include_token1] = ACTIONS(2174),
    [aux_sym_preproc_def_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2174),
    [sym_preproc_directive] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP_AMP] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2174),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym___device__] = ACTIONS(2174),
    [anon_sym___host__] = ACTIONS(2174),
    [anon_sym___global__] = ACTIONS(2174),
    [anon_sym___forceinline__] = ACTIONS(2174),
    [anon_sym___noinline__] = ACTIONS(2174),
    [anon_sym_virtual] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym___attribute] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym___based] = ACTIONS(2174),
    [anon_sym___cdecl] = ACTIONS(2174),
    [anon_sym___clrcall] = ACTIONS(2174),
    [anon_sym___stdcall] = ACTIONS(2174),
    [anon_sym___fastcall] = ACTIONS(2174),
    [anon_sym___thiscall] = ACTIONS(2174),
    [anon_sym___vectorcall] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_RBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym__Nonnull] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym___shared__] = ACTIONS(2174),
    [anon_sym___local__] = ACTIONS(2174),
    [anon_sym___constant__] = ACTIONS(2174),
    [anon_sym___managed__] = ACTIONS(2174),
    [anon_sym___grid_constant__] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_case] = ACTIONS(2174),
    [anon_sym_default] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [anon_sym___asm] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [anon_sym_explicit] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_operator] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_namespace] = ACTIONS(2174),
    [anon_sym_using] = ACTIONS(2174),
    [anon_sym_static_assert] = ACTIONS(2174),
    [anon_sym_concept] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym___launch_bounds__] = ACTIONS(2174),
  },
  [STATE(428)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_RBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(429)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_RBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(430)] = {
    [sym_identifier] = ACTIONS(2032),
    [aux_sym_preproc_include_token1] = ACTIONS(2032),
    [aux_sym_preproc_def_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2032),
    [sym_preproc_directive] = ACTIONS(2032),
    [anon_sym_LPAREN2] = ACTIONS(2034),
    [anon_sym_BANG] = ACTIONS(2034),
    [anon_sym_TILDE] = ACTIONS(2034),
    [anon_sym_DASH] = ACTIONS(2032),
    [anon_sym_PLUS] = ACTIONS(2032),
    [anon_sym_STAR] = ACTIONS(2034),
    [anon_sym_AMP_AMP] = ACTIONS(2034),
    [anon_sym_AMP] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(2034),
    [anon_sym___extension__] = ACTIONS(2032),
    [anon_sym_typedef] = ACTIONS(2032),
    [anon_sym___device__] = ACTIONS(2032),
    [anon_sym___host__] = ACTIONS(2032),
    [anon_sym___global__] = ACTIONS(2032),
    [anon_sym___forceinline__] = ACTIONS(2032),
    [anon_sym___noinline__] = ACTIONS(2032),
    [anon_sym_virtual] = ACTIONS(2032),
    [anon_sym_extern] = ACTIONS(2032),
    [anon_sym___attribute__] = ACTIONS(2032),
    [anon_sym___attribute] = ACTIONS(2032),
    [anon_sym_COLON_COLON] = ACTIONS(2034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2034),
    [anon_sym___declspec] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(2032),
    [anon_sym___cdecl] = ACTIONS(2032),
    [anon_sym___clrcall] = ACTIONS(2032),
    [anon_sym___stdcall] = ACTIONS(2032),
    [anon_sym___fastcall] = ACTIONS(2032),
    [anon_sym___thiscall] = ACTIONS(2032),
    [anon_sym___vectorcall] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(2034),
    [anon_sym_RBRACE] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2032),
    [anon_sym_unsigned] = ACTIONS(2032),
    [anon_sym_long] = ACTIONS(2032),
    [anon_sym_short] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(2032),
    [anon_sym_static] = ACTIONS(2032),
    [anon_sym_register] = ACTIONS(2032),
    [anon_sym_inline] = ACTIONS(2032),
    [anon_sym___inline] = ACTIONS(2032),
    [anon_sym___inline__] = ACTIONS(2032),
    [anon_sym___forceinline] = ACTIONS(2032),
    [anon_sym_thread_local] = ACTIONS(2032),
    [anon_sym___thread] = ACTIONS(2032),
    [anon_sym_const] = ACTIONS(2032),
    [anon_sym_constexpr] = ACTIONS(2032),
    [anon_sym_volatile] = ACTIONS(2032),
    [anon_sym_restrict] = ACTIONS(2032),
    [anon_sym___restrict__] = ACTIONS(2032),
    [anon_sym__Atomic] = ACTIONS(2032),
    [anon_sym__Noreturn] = ACTIONS(2032),
    [anon_sym_noreturn] = ACTIONS(2032),
    [anon_sym__Nonnull] = ACTIONS(2032),
    [anon_sym_mutable] = ACTIONS(2032),
    [anon_sym_constinit] = ACTIONS(2032),
    [anon_sym_consteval] = ACTIONS(2032),
    [anon_sym___shared__] = ACTIONS(2032),
    [anon_sym___local__] = ACTIONS(2032),
    [anon_sym___constant__] = ACTIONS(2032),
    [anon_sym___managed__] = ACTIONS(2032),
    [anon_sym___grid_constant__] = ACTIONS(2032),
    [anon_sym_alignas] = ACTIONS(2032),
    [anon_sym__Alignas] = ACTIONS(2032),
    [sym_primitive_type] = ACTIONS(2032),
    [anon_sym_enum] = ACTIONS(2032),
    [anon_sym_class] = ACTIONS(2032),
    [anon_sym_struct] = ACTIONS(2032),
    [anon_sym_union] = ACTIONS(2032),
    [anon_sym_if] = ACTIONS(2032),
    [anon_sym_else] = ACTIONS(2032),
    [anon_sym_switch] = ACTIONS(2032),
    [anon_sym_case] = ACTIONS(2032),
    [anon_sym_default] = ACTIONS(2032),
    [anon_sym_while] = ACTIONS(2032),
    [anon_sym_do] = ACTIONS(2032),
    [anon_sym_for] = ACTIONS(2032),
    [anon_sym_return] = ACTIONS(2032),
    [anon_sym_break] = ACTIONS(2032),
    [anon_sym_continue] = ACTIONS(2032),
    [anon_sym_goto] = ACTIONS(2032),
    [anon_sym___try] = ACTIONS(2032),
    [anon_sym___leave] = ACTIONS(2032),
    [anon_sym_not] = ACTIONS(2032),
    [anon_sym_compl] = ACTIONS(2032),
    [anon_sym_DASH_DASH] = ACTIONS(2034),
    [anon_sym_PLUS_PLUS] = ACTIONS(2034),
    [anon_sym_sizeof] = ACTIONS(2032),
    [anon_sym___alignof__] = ACTIONS(2032),
    [anon_sym___alignof] = ACTIONS(2032),
    [anon_sym__alignof] = ACTIONS(2032),
    [anon_sym_alignof] = ACTIONS(2032),
    [anon_sym__Alignof] = ACTIONS(2032),
    [anon_sym_offsetof] = ACTIONS(2032),
    [anon_sym__Generic] = ACTIONS(2032),
    [anon_sym_asm] = ACTIONS(2032),
    [anon_sym___asm__] = ACTIONS(2032),
    [anon_sym___asm] = ACTIONS(2032),
    [sym_number_literal] = ACTIONS(2034),
    [anon_sym_L_SQUOTE] = ACTIONS(2034),
    [anon_sym_u_SQUOTE] = ACTIONS(2034),
    [anon_sym_U_SQUOTE] = ACTIONS(2034),
    [anon_sym_u8_SQUOTE] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2034),
    [anon_sym_L_DQUOTE] = ACTIONS(2034),
    [anon_sym_u_DQUOTE] = ACTIONS(2034),
    [anon_sym_U_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8_DQUOTE] = ACTIONS(2034),
    [anon_sym_DQUOTE] = ACTIONS(2034),
    [sym_true] = ACTIONS(2032),
    [sym_false] = ACTIONS(2032),
    [anon_sym_NULL] = ACTIONS(2032),
    [anon_sym_nullptr] = ACTIONS(2032),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2032),
    [anon_sym_decltype] = ACTIONS(2032),
    [anon_sym_explicit] = ACTIONS(2032),
    [anon_sym_typename] = ACTIONS(2032),
    [anon_sym_template] = ACTIONS(2032),
    [anon_sym_operator] = ACTIONS(2032),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_delete] = ACTIONS(2032),
    [anon_sym_throw] = ACTIONS(2032),
    [anon_sym_namespace] = ACTIONS(2032),
    [anon_sym_using] = ACTIONS(2032),
    [anon_sym_static_assert] = ACTIONS(2032),
    [anon_sym_concept] = ACTIONS(2032),
    [anon_sym_co_return] = ACTIONS(2032),
    [anon_sym_co_yield] = ACTIONS(2032),
    [anon_sym_R_DQUOTE] = ACTIONS(2034),
    [anon_sym_LR_DQUOTE] = ACTIONS(2034),
    [anon_sym_uR_DQUOTE] = ACTIONS(2034),
    [anon_sym_UR_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2034),
    [anon_sym_co_await] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(2032),
    [anon_sym_requires] = ACTIONS(2032),
    [sym_this] = ACTIONS(2032),
    [anon_sym___launch_bounds__] = ACTIONS(2032),
  },
  [STATE(431)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_RBRACE] = ACTIONS(2060),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(432)] = {
    [ts_builtin_sym_end] = ACTIONS(2042),
    [sym_identifier] = ACTIONS(2040),
    [aux_sym_preproc_include_token1] = ACTIONS(2040),
    [aux_sym_preproc_def_token1] = ACTIONS(2040),
    [aux_sym_preproc_if_token1] = ACTIONS(2040),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2040),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2040),
    [sym_preproc_directive] = ACTIONS(2040),
    [anon_sym_LPAREN2] = ACTIONS(2042),
    [anon_sym_BANG] = ACTIONS(2042),
    [anon_sym_TILDE] = ACTIONS(2042),
    [anon_sym_DASH] = ACTIONS(2040),
    [anon_sym_PLUS] = ACTIONS(2040),
    [anon_sym_STAR] = ACTIONS(2042),
    [anon_sym_AMP_AMP] = ACTIONS(2042),
    [anon_sym_AMP] = ACTIONS(2040),
    [anon_sym_SEMI] = ACTIONS(2042),
    [anon_sym___extension__] = ACTIONS(2040),
    [anon_sym_typedef] = ACTIONS(2040),
    [anon_sym___device__] = ACTIONS(2040),
    [anon_sym___host__] = ACTIONS(2040),
    [anon_sym___global__] = ACTIONS(2040),
    [anon_sym___forceinline__] = ACTIONS(2040),
    [anon_sym___noinline__] = ACTIONS(2040),
    [anon_sym_virtual] = ACTIONS(2040),
    [anon_sym_extern] = ACTIONS(2040),
    [anon_sym___attribute__] = ACTIONS(2040),
    [anon_sym___attribute] = ACTIONS(2040),
    [anon_sym_COLON_COLON] = ACTIONS(2042),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2042),
    [anon_sym___declspec] = ACTIONS(2040),
    [anon_sym___based] = ACTIONS(2040),
    [anon_sym___cdecl] = ACTIONS(2040),
    [anon_sym___clrcall] = ACTIONS(2040),
    [anon_sym___stdcall] = ACTIONS(2040),
    [anon_sym___fastcall] = ACTIONS(2040),
    [anon_sym___thiscall] = ACTIONS(2040),
    [anon_sym___vectorcall] = ACTIONS(2040),
    [anon_sym_LBRACE] = ACTIONS(2042),
    [anon_sym_signed] = ACTIONS(2040),
    [anon_sym_unsigned] = ACTIONS(2040),
    [anon_sym_long] = ACTIONS(2040),
    [anon_sym_short] = ACTIONS(2040),
    [anon_sym_LBRACK] = ACTIONS(2040),
    [anon_sym_static] = ACTIONS(2040),
    [anon_sym_register] = ACTIONS(2040),
    [anon_sym_inline] = ACTIONS(2040),
    [anon_sym___inline] = ACTIONS(2040),
    [anon_sym___inline__] = ACTIONS(2040),
    [anon_sym___forceinline] = ACTIONS(2040),
    [anon_sym_thread_local] = ACTIONS(2040),
    [anon_sym___thread] = ACTIONS(2040),
    [anon_sym_const] = ACTIONS(2040),
    [anon_sym_constexpr] = ACTIONS(2040),
    [anon_sym_volatile] = ACTIONS(2040),
    [anon_sym_restrict] = ACTIONS(2040),
    [anon_sym___restrict__] = ACTIONS(2040),
    [anon_sym__Atomic] = ACTIONS(2040),
    [anon_sym__Noreturn] = ACTIONS(2040),
    [anon_sym_noreturn] = ACTIONS(2040),
    [anon_sym__Nonnull] = ACTIONS(2040),
    [anon_sym_mutable] = ACTIONS(2040),
    [anon_sym_constinit] = ACTIONS(2040),
    [anon_sym_consteval] = ACTIONS(2040),
    [anon_sym___shared__] = ACTIONS(2040),
    [anon_sym___local__] = ACTIONS(2040),
    [anon_sym___constant__] = ACTIONS(2040),
    [anon_sym___managed__] = ACTIONS(2040),
    [anon_sym___grid_constant__] = ACTIONS(2040),
    [anon_sym_alignas] = ACTIONS(2040),
    [anon_sym__Alignas] = ACTIONS(2040),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2040),
    [anon_sym_class] = ACTIONS(2040),
    [anon_sym_struct] = ACTIONS(2040),
    [anon_sym_union] = ACTIONS(2040),
    [anon_sym_if] = ACTIONS(2040),
    [anon_sym_else] = ACTIONS(2040),
    [anon_sym_switch] = ACTIONS(2040),
    [anon_sym_case] = ACTIONS(2040),
    [anon_sym_default] = ACTIONS(2040),
    [anon_sym_while] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(2040),
    [anon_sym_for] = ACTIONS(2040),
    [anon_sym_return] = ACTIONS(2040),
    [anon_sym_break] = ACTIONS(2040),
    [anon_sym_continue] = ACTIONS(2040),
    [anon_sym_goto] = ACTIONS(2040),
    [anon_sym___try] = ACTIONS(2040),
    [anon_sym___leave] = ACTIONS(2040),
    [anon_sym_not] = ACTIONS(2040),
    [anon_sym_compl] = ACTIONS(2040),
    [anon_sym_DASH_DASH] = ACTIONS(2042),
    [anon_sym_PLUS_PLUS] = ACTIONS(2042),
    [anon_sym_sizeof] = ACTIONS(2040),
    [anon_sym___alignof__] = ACTIONS(2040),
    [anon_sym___alignof] = ACTIONS(2040),
    [anon_sym__alignof] = ACTIONS(2040),
    [anon_sym_alignof] = ACTIONS(2040),
    [anon_sym__Alignof] = ACTIONS(2040),
    [anon_sym_offsetof] = ACTIONS(2040),
    [anon_sym__Generic] = ACTIONS(2040),
    [anon_sym_asm] = ACTIONS(2040),
    [anon_sym___asm__] = ACTIONS(2040),
    [anon_sym___asm] = ACTIONS(2040),
    [sym_number_literal] = ACTIONS(2042),
    [anon_sym_L_SQUOTE] = ACTIONS(2042),
    [anon_sym_u_SQUOTE] = ACTIONS(2042),
    [anon_sym_U_SQUOTE] = ACTIONS(2042),
    [anon_sym_u8_SQUOTE] = ACTIONS(2042),
    [anon_sym_SQUOTE] = ACTIONS(2042),
    [anon_sym_L_DQUOTE] = ACTIONS(2042),
    [anon_sym_u_DQUOTE] = ACTIONS(2042),
    [anon_sym_U_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8_DQUOTE] = ACTIONS(2042),
    [anon_sym_DQUOTE] = ACTIONS(2042),
    [sym_true] = ACTIONS(2040),
    [sym_false] = ACTIONS(2040),
    [anon_sym_NULL] = ACTIONS(2040),
    [anon_sym_nullptr] = ACTIONS(2040),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2040),
    [anon_sym_decltype] = ACTIONS(2040),
    [anon_sym_explicit] = ACTIONS(2040),
    [anon_sym_typename] = ACTIONS(2040),
    [anon_sym_template] = ACTIONS(2040),
    [anon_sym_operator] = ACTIONS(2040),
    [anon_sym_try] = ACTIONS(2040),
    [anon_sym_delete] = ACTIONS(2040),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_namespace] = ACTIONS(2040),
    [anon_sym_using] = ACTIONS(2040),
    [anon_sym_static_assert] = ACTIONS(2040),
    [anon_sym_concept] = ACTIONS(2040),
    [anon_sym_co_return] = ACTIONS(2040),
    [anon_sym_co_yield] = ACTIONS(2040),
    [anon_sym_R_DQUOTE] = ACTIONS(2042),
    [anon_sym_LR_DQUOTE] = ACTIONS(2042),
    [anon_sym_uR_DQUOTE] = ACTIONS(2042),
    [anon_sym_UR_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2042),
    [anon_sym_co_await] = ACTIONS(2040),
    [anon_sym_new] = ACTIONS(2040),
    [anon_sym_requires] = ACTIONS(2040),
    [sym_this] = ACTIONS(2040),
    [anon_sym___launch_bounds__] = ACTIONS(2040),
  },
  [STATE(433)] = {
    [sym_preproc_def] = STATE(433),
    [sym_preproc_function_def] = STATE(433),
    [sym_preproc_call] = STATE(433),
    [sym_preproc_if_in_field_declaration_list] = STATE(433),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(433),
    [sym_type_definition] = STATE(433),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6183),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(433),
    [sym_field_declaration] = STATE(433),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(433),
    [sym_operator_cast] = STATE(7392),
    [sym_inline_method_definition] = STATE(433),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(433),
    [sym_operator_cast_declaration] = STATE(433),
    [sym_constructor_or_destructor_definition] = STATE(433),
    [sym_constructor_or_destructor_declaration] = STATE(433),
    [sym_friend_declaration] = STATE(433),
    [sym_access_specifier] = STATE(8872),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(433),
    [sym_alias_declaration] = STATE(433),
    [sym_static_assert_declaration] = STATE(433),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(433),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(2737),
    [aux_sym_preproc_def_token1] = ACTIONS(2740),
    [aux_sym_preproc_if_token1] = ACTIONS(2743),
    [aux_sym_preproc_if_token2] = ACTIONS(2746),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2748),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2748),
    [aux_sym_preproc_else_token1] = ACTIONS(2746),
    [aux_sym_preproc_elif_token1] = ACTIONS(2746),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2746),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2746),
    [sym_preproc_directive] = ACTIONS(2751),
    [anon_sym_LPAREN2] = ACTIONS(2754),
    [anon_sym_TILDE] = ACTIONS(2757),
    [anon_sym_STAR] = ACTIONS(2760),
    [anon_sym_AMP_AMP] = ACTIONS(2763),
    [anon_sym_AMP] = ACTIONS(2766),
    [anon_sym_SEMI] = ACTIONS(2769),
    [anon_sym___extension__] = ACTIONS(2772),
    [anon_sym_typedef] = ACTIONS(2775),
    [anon_sym___device__] = ACTIONS(2778),
    [anon_sym___host__] = ACTIONS(2778),
    [anon_sym___global__] = ACTIONS(2778),
    [anon_sym___forceinline__] = ACTIONS(2778),
    [anon_sym___noinline__] = ACTIONS(2778),
    [anon_sym_virtual] = ACTIONS(2778),
    [anon_sym_extern] = ACTIONS(2781),
    [anon_sym___attribute__] = ACTIONS(2784),
    [anon_sym___attribute] = ACTIONS(2784),
    [anon_sym_COLON_COLON] = ACTIONS(2787),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2790),
    [anon_sym___declspec] = ACTIONS(2793),
    [anon_sym___based] = ACTIONS(2796),
    [anon_sym_signed] = ACTIONS(2799),
    [anon_sym_unsigned] = ACTIONS(2799),
    [anon_sym_long] = ACTIONS(2799),
    [anon_sym_short] = ACTIONS(2799),
    [anon_sym_LBRACK] = ACTIONS(2802),
    [anon_sym_static] = ACTIONS(2781),
    [anon_sym_register] = ACTIONS(2781),
    [anon_sym_inline] = ACTIONS(2781),
    [anon_sym___inline] = ACTIONS(2781),
    [anon_sym___inline__] = ACTIONS(2781),
    [anon_sym___forceinline] = ACTIONS(2781),
    [anon_sym_thread_local] = ACTIONS(2781),
    [anon_sym___thread] = ACTIONS(2781),
    [anon_sym_const] = ACTIONS(2805),
    [anon_sym_constexpr] = ACTIONS(2808),
    [anon_sym_volatile] = ACTIONS(2805),
    [anon_sym_restrict] = ACTIONS(2805),
    [anon_sym___restrict__] = ACTIONS(2805),
    [anon_sym__Atomic] = ACTIONS(2805),
    [anon_sym__Noreturn] = ACTIONS(2805),
    [anon_sym_noreturn] = ACTIONS(2805),
    [anon_sym__Nonnull] = ACTIONS(2805),
    [anon_sym_mutable] = ACTIONS(2805),
    [anon_sym_constinit] = ACTIONS(2805),
    [anon_sym_consteval] = ACTIONS(2805),
    [anon_sym___shared__] = ACTIONS(2805),
    [anon_sym___local__] = ACTIONS(2805),
    [anon_sym___constant__] = ACTIONS(2805),
    [anon_sym___managed__] = ACTIONS(2805),
    [anon_sym___grid_constant__] = ACTIONS(2805),
    [anon_sym_alignas] = ACTIONS(2811),
    [anon_sym__Alignas] = ACTIONS(2811),
    [sym_primitive_type] = ACTIONS(2814),
    [anon_sym_enum] = ACTIONS(2817),
    [anon_sym_class] = ACTIONS(2820),
    [anon_sym_struct] = ACTIONS(2823),
    [anon_sym_union] = ACTIONS(2826),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2829),
    [anon_sym_decltype] = ACTIONS(2832),
    [anon_sym_explicit] = ACTIONS(2835),
    [anon_sym_typename] = ACTIONS(2838),
    [anon_sym_template] = ACTIONS(2841),
    [anon_sym_operator] = ACTIONS(2844),
    [anon_sym_friend] = ACTIONS(2847),
    [anon_sym_public] = ACTIONS(2850),
    [anon_sym_private] = ACTIONS(2850),
    [anon_sym_protected] = ACTIONS(2850),
    [anon_sym_using] = ACTIONS(2853),
    [anon_sym_static_assert] = ACTIONS(2856),
    [anon_sym___launch_bounds__] = ACTIONS(2859),
  },
  [STATE(434)] = {
    [ts_builtin_sym_end] = ACTIONS(2050),
    [sym_identifier] = ACTIONS(2048),
    [aux_sym_preproc_include_token1] = ACTIONS(2048),
    [aux_sym_preproc_def_token1] = ACTIONS(2048),
    [aux_sym_preproc_if_token1] = ACTIONS(2048),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2048),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2048),
    [sym_preproc_directive] = ACTIONS(2048),
    [anon_sym_LPAREN2] = ACTIONS(2050),
    [anon_sym_BANG] = ACTIONS(2050),
    [anon_sym_TILDE] = ACTIONS(2050),
    [anon_sym_DASH] = ACTIONS(2048),
    [anon_sym_PLUS] = ACTIONS(2048),
    [anon_sym_STAR] = ACTIONS(2050),
    [anon_sym_AMP_AMP] = ACTIONS(2050),
    [anon_sym_AMP] = ACTIONS(2048),
    [anon_sym_SEMI] = ACTIONS(2050),
    [anon_sym___extension__] = ACTIONS(2048),
    [anon_sym_typedef] = ACTIONS(2048),
    [anon_sym___device__] = ACTIONS(2048),
    [anon_sym___host__] = ACTIONS(2048),
    [anon_sym___global__] = ACTIONS(2048),
    [anon_sym___forceinline__] = ACTIONS(2048),
    [anon_sym___noinline__] = ACTIONS(2048),
    [anon_sym_virtual] = ACTIONS(2048),
    [anon_sym_extern] = ACTIONS(2048),
    [anon_sym___attribute__] = ACTIONS(2048),
    [anon_sym___attribute] = ACTIONS(2048),
    [anon_sym_COLON_COLON] = ACTIONS(2050),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2050),
    [anon_sym___declspec] = ACTIONS(2048),
    [anon_sym___based] = ACTIONS(2048),
    [anon_sym___cdecl] = ACTIONS(2048),
    [anon_sym___clrcall] = ACTIONS(2048),
    [anon_sym___stdcall] = ACTIONS(2048),
    [anon_sym___fastcall] = ACTIONS(2048),
    [anon_sym___thiscall] = ACTIONS(2048),
    [anon_sym___vectorcall] = ACTIONS(2048),
    [anon_sym_LBRACE] = ACTIONS(2050),
    [anon_sym_signed] = ACTIONS(2048),
    [anon_sym_unsigned] = ACTIONS(2048),
    [anon_sym_long] = ACTIONS(2048),
    [anon_sym_short] = ACTIONS(2048),
    [anon_sym_LBRACK] = ACTIONS(2048),
    [anon_sym_static] = ACTIONS(2048),
    [anon_sym_register] = ACTIONS(2048),
    [anon_sym_inline] = ACTIONS(2048),
    [anon_sym___inline] = ACTIONS(2048),
    [anon_sym___inline__] = ACTIONS(2048),
    [anon_sym___forceinline] = ACTIONS(2048),
    [anon_sym_thread_local] = ACTIONS(2048),
    [anon_sym___thread] = ACTIONS(2048),
    [anon_sym_const] = ACTIONS(2048),
    [anon_sym_constexpr] = ACTIONS(2048),
    [anon_sym_volatile] = ACTIONS(2048),
    [anon_sym_restrict] = ACTIONS(2048),
    [anon_sym___restrict__] = ACTIONS(2048),
    [anon_sym__Atomic] = ACTIONS(2048),
    [anon_sym__Noreturn] = ACTIONS(2048),
    [anon_sym_noreturn] = ACTIONS(2048),
    [anon_sym__Nonnull] = ACTIONS(2048),
    [anon_sym_mutable] = ACTIONS(2048),
    [anon_sym_constinit] = ACTIONS(2048),
    [anon_sym_consteval] = ACTIONS(2048),
    [anon_sym___shared__] = ACTIONS(2048),
    [anon_sym___local__] = ACTIONS(2048),
    [anon_sym___constant__] = ACTIONS(2048),
    [anon_sym___managed__] = ACTIONS(2048),
    [anon_sym___grid_constant__] = ACTIONS(2048),
    [anon_sym_alignas] = ACTIONS(2048),
    [anon_sym__Alignas] = ACTIONS(2048),
    [sym_primitive_type] = ACTIONS(2048),
    [anon_sym_enum] = ACTIONS(2048),
    [anon_sym_class] = ACTIONS(2048),
    [anon_sym_struct] = ACTIONS(2048),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_if] = ACTIONS(2048),
    [anon_sym_else] = ACTIONS(2048),
    [anon_sym_switch] = ACTIONS(2048),
    [anon_sym_case] = ACTIONS(2048),
    [anon_sym_default] = ACTIONS(2048),
    [anon_sym_while] = ACTIONS(2048),
    [anon_sym_do] = ACTIONS(2048),
    [anon_sym_for] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2048),
    [anon_sym_break] = ACTIONS(2048),
    [anon_sym_continue] = ACTIONS(2048),
    [anon_sym_goto] = ACTIONS(2048),
    [anon_sym___try] = ACTIONS(2048),
    [anon_sym___leave] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2048),
    [anon_sym_compl] = ACTIONS(2048),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2048),
    [anon_sym___alignof__] = ACTIONS(2048),
    [anon_sym___alignof] = ACTIONS(2048),
    [anon_sym__alignof] = ACTIONS(2048),
    [anon_sym_alignof] = ACTIONS(2048),
    [anon_sym__Alignof] = ACTIONS(2048),
    [anon_sym_offsetof] = ACTIONS(2048),
    [anon_sym__Generic] = ACTIONS(2048),
    [anon_sym_asm] = ACTIONS(2048),
    [anon_sym___asm__] = ACTIONS(2048),
    [anon_sym___asm] = ACTIONS(2048),
    [sym_number_literal] = ACTIONS(2050),
    [anon_sym_L_SQUOTE] = ACTIONS(2050),
    [anon_sym_u_SQUOTE] = ACTIONS(2050),
    [anon_sym_U_SQUOTE] = ACTIONS(2050),
    [anon_sym_u8_SQUOTE] = ACTIONS(2050),
    [anon_sym_SQUOTE] = ACTIONS(2050),
    [anon_sym_L_DQUOTE] = ACTIONS(2050),
    [anon_sym_u_DQUOTE] = ACTIONS(2050),
    [anon_sym_U_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8_DQUOTE] = ACTIONS(2050),
    [anon_sym_DQUOTE] = ACTIONS(2050),
    [sym_true] = ACTIONS(2048),
    [sym_false] = ACTIONS(2048),
    [anon_sym_NULL] = ACTIONS(2048),
    [anon_sym_nullptr] = ACTIONS(2048),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2048),
    [anon_sym_decltype] = ACTIONS(2048),
    [anon_sym_explicit] = ACTIONS(2048),
    [anon_sym_typename] = ACTIONS(2048),
    [anon_sym_template] = ACTIONS(2048),
    [anon_sym_operator] = ACTIONS(2048),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_delete] = ACTIONS(2048),
    [anon_sym_throw] = ACTIONS(2048),
    [anon_sym_namespace] = ACTIONS(2048),
    [anon_sym_using] = ACTIONS(2048),
    [anon_sym_static_assert] = ACTIONS(2048),
    [anon_sym_concept] = ACTIONS(2048),
    [anon_sym_co_return] = ACTIONS(2048),
    [anon_sym_co_yield] = ACTIONS(2048),
    [anon_sym_R_DQUOTE] = ACTIONS(2050),
    [anon_sym_LR_DQUOTE] = ACTIONS(2050),
    [anon_sym_uR_DQUOTE] = ACTIONS(2050),
    [anon_sym_UR_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2050),
    [anon_sym_co_await] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(2048),
    [anon_sym_requires] = ACTIONS(2048),
    [sym_this] = ACTIONS(2048),
    [anon_sym___launch_bounds__] = ACTIONS(2048),
  },
  [STATE(435)] = {
    [sym_identifier] = ACTIONS(2062),
    [aux_sym_preproc_include_token1] = ACTIONS(2062),
    [aux_sym_preproc_def_token1] = ACTIONS(2062),
    [aux_sym_preproc_if_token1] = ACTIONS(2062),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2062),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2062),
    [sym_preproc_directive] = ACTIONS(2062),
    [anon_sym_LPAREN2] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(2064),
    [anon_sym_TILDE] = ACTIONS(2064),
    [anon_sym_DASH] = ACTIONS(2062),
    [anon_sym_PLUS] = ACTIONS(2062),
    [anon_sym_STAR] = ACTIONS(2064),
    [anon_sym_AMP_AMP] = ACTIONS(2064),
    [anon_sym_AMP] = ACTIONS(2062),
    [anon_sym_SEMI] = ACTIONS(2064),
    [anon_sym___extension__] = ACTIONS(2062),
    [anon_sym_typedef] = ACTIONS(2062),
    [anon_sym___device__] = ACTIONS(2062),
    [anon_sym___host__] = ACTIONS(2062),
    [anon_sym___global__] = ACTIONS(2062),
    [anon_sym___forceinline__] = ACTIONS(2062),
    [anon_sym___noinline__] = ACTIONS(2062),
    [anon_sym_virtual] = ACTIONS(2062),
    [anon_sym_extern] = ACTIONS(2062),
    [anon_sym___attribute__] = ACTIONS(2062),
    [anon_sym___attribute] = ACTIONS(2062),
    [anon_sym_COLON_COLON] = ACTIONS(2064),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2064),
    [anon_sym___declspec] = ACTIONS(2062),
    [anon_sym___based] = ACTIONS(2062),
    [anon_sym___cdecl] = ACTIONS(2062),
    [anon_sym___clrcall] = ACTIONS(2062),
    [anon_sym___stdcall] = ACTIONS(2062),
    [anon_sym___fastcall] = ACTIONS(2062),
    [anon_sym___thiscall] = ACTIONS(2062),
    [anon_sym___vectorcall] = ACTIONS(2062),
    [anon_sym_LBRACE] = ACTIONS(2064),
    [anon_sym_RBRACE] = ACTIONS(2064),
    [anon_sym_signed] = ACTIONS(2062),
    [anon_sym_unsigned] = ACTIONS(2062),
    [anon_sym_long] = ACTIONS(2062),
    [anon_sym_short] = ACTIONS(2062),
    [anon_sym_LBRACK] = ACTIONS(2062),
    [anon_sym_static] = ACTIONS(2062),
    [anon_sym_register] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym___inline] = ACTIONS(2062),
    [anon_sym___inline__] = ACTIONS(2062),
    [anon_sym___forceinline] = ACTIONS(2062),
    [anon_sym_thread_local] = ACTIONS(2062),
    [anon_sym___thread] = ACTIONS(2062),
    [anon_sym_const] = ACTIONS(2062),
    [anon_sym_constexpr] = ACTIONS(2062),
    [anon_sym_volatile] = ACTIONS(2062),
    [anon_sym_restrict] = ACTIONS(2062),
    [anon_sym___restrict__] = ACTIONS(2062),
    [anon_sym__Atomic] = ACTIONS(2062),
    [anon_sym__Noreturn] = ACTIONS(2062),
    [anon_sym_noreturn] = ACTIONS(2062),
    [anon_sym__Nonnull] = ACTIONS(2062),
    [anon_sym_mutable] = ACTIONS(2062),
    [anon_sym_constinit] = ACTIONS(2062),
    [anon_sym_consteval] = ACTIONS(2062),
    [anon_sym___shared__] = ACTIONS(2062),
    [anon_sym___local__] = ACTIONS(2062),
    [anon_sym___constant__] = ACTIONS(2062),
    [anon_sym___managed__] = ACTIONS(2062),
    [anon_sym___grid_constant__] = ACTIONS(2062),
    [anon_sym_alignas] = ACTIONS(2062),
    [anon_sym__Alignas] = ACTIONS(2062),
    [sym_primitive_type] = ACTIONS(2062),
    [anon_sym_enum] = ACTIONS(2062),
    [anon_sym_class] = ACTIONS(2062),
    [anon_sym_struct] = ACTIONS(2062),
    [anon_sym_union] = ACTIONS(2062),
    [anon_sym_if] = ACTIONS(2062),
    [anon_sym_else] = ACTIONS(2062),
    [anon_sym_switch] = ACTIONS(2062),
    [anon_sym_case] = ACTIONS(2062),
    [anon_sym_default] = ACTIONS(2062),
    [anon_sym_while] = ACTIONS(2062),
    [anon_sym_do] = ACTIONS(2062),
    [anon_sym_for] = ACTIONS(2062),
    [anon_sym_return] = ACTIONS(2062),
    [anon_sym_break] = ACTIONS(2062),
    [anon_sym_continue] = ACTIONS(2062),
    [anon_sym_goto] = ACTIONS(2062),
    [anon_sym___try] = ACTIONS(2062),
    [anon_sym___leave] = ACTIONS(2062),
    [anon_sym_not] = ACTIONS(2062),
    [anon_sym_compl] = ACTIONS(2062),
    [anon_sym_DASH_DASH] = ACTIONS(2064),
    [anon_sym_PLUS_PLUS] = ACTIONS(2064),
    [anon_sym_sizeof] = ACTIONS(2062),
    [anon_sym___alignof__] = ACTIONS(2062),
    [anon_sym___alignof] = ACTIONS(2062),
    [anon_sym__alignof] = ACTIONS(2062),
    [anon_sym_alignof] = ACTIONS(2062),
    [anon_sym__Alignof] = ACTIONS(2062),
    [anon_sym_offsetof] = ACTIONS(2062),
    [anon_sym__Generic] = ACTIONS(2062),
    [anon_sym_asm] = ACTIONS(2062),
    [anon_sym___asm__] = ACTIONS(2062),
    [anon_sym___asm] = ACTIONS(2062),
    [sym_number_literal] = ACTIONS(2064),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2064),
    [anon_sym_u_DQUOTE] = ACTIONS(2064),
    [anon_sym_U_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8_DQUOTE] = ACTIONS(2064),
    [anon_sym_DQUOTE] = ACTIONS(2064),
    [sym_true] = ACTIONS(2062),
    [sym_false] = ACTIONS(2062),
    [anon_sym_NULL] = ACTIONS(2062),
    [anon_sym_nullptr] = ACTIONS(2062),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2062),
    [anon_sym_decltype] = ACTIONS(2062),
    [anon_sym_explicit] = ACTIONS(2062),
    [anon_sym_typename] = ACTIONS(2062),
    [anon_sym_template] = ACTIONS(2062),
    [anon_sym_operator] = ACTIONS(2062),
    [anon_sym_try] = ACTIONS(2062),
    [anon_sym_delete] = ACTIONS(2062),
    [anon_sym_throw] = ACTIONS(2062),
    [anon_sym_namespace] = ACTIONS(2062),
    [anon_sym_using] = ACTIONS(2062),
    [anon_sym_static_assert] = ACTIONS(2062),
    [anon_sym_concept] = ACTIONS(2062),
    [anon_sym_co_return] = ACTIONS(2062),
    [anon_sym_co_yield] = ACTIONS(2062),
    [anon_sym_R_DQUOTE] = ACTIONS(2064),
    [anon_sym_LR_DQUOTE] = ACTIONS(2064),
    [anon_sym_uR_DQUOTE] = ACTIONS(2064),
    [anon_sym_UR_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2064),
    [anon_sym_co_await] = ACTIONS(2062),
    [anon_sym_new] = ACTIONS(2062),
    [anon_sym_requires] = ACTIONS(2062),
    [sym_this] = ACTIONS(2062),
    [anon_sym___launch_bounds__] = ACTIONS(2062),
  },
  [STATE(436)] = {
    [ts_builtin_sym_end] = ACTIONS(2058),
    [sym_identifier] = ACTIONS(2056),
    [aux_sym_preproc_include_token1] = ACTIONS(2056),
    [aux_sym_preproc_def_token1] = ACTIONS(2056),
    [aux_sym_preproc_if_token1] = ACTIONS(2056),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2056),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2056),
    [sym_preproc_directive] = ACTIONS(2056),
    [anon_sym_LPAREN2] = ACTIONS(2058),
    [anon_sym_BANG] = ACTIONS(2058),
    [anon_sym_TILDE] = ACTIONS(2058),
    [anon_sym_DASH] = ACTIONS(2056),
    [anon_sym_PLUS] = ACTIONS(2056),
    [anon_sym_STAR] = ACTIONS(2058),
    [anon_sym_AMP_AMP] = ACTIONS(2058),
    [anon_sym_AMP] = ACTIONS(2056),
    [anon_sym_SEMI] = ACTIONS(2058),
    [anon_sym___extension__] = ACTIONS(2056),
    [anon_sym_typedef] = ACTIONS(2056),
    [anon_sym___device__] = ACTIONS(2056),
    [anon_sym___host__] = ACTIONS(2056),
    [anon_sym___global__] = ACTIONS(2056),
    [anon_sym___forceinline__] = ACTIONS(2056),
    [anon_sym___noinline__] = ACTIONS(2056),
    [anon_sym_virtual] = ACTIONS(2056),
    [anon_sym_extern] = ACTIONS(2056),
    [anon_sym___attribute__] = ACTIONS(2056),
    [anon_sym___attribute] = ACTIONS(2056),
    [anon_sym_COLON_COLON] = ACTIONS(2058),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2058),
    [anon_sym___declspec] = ACTIONS(2056),
    [anon_sym___based] = ACTIONS(2056),
    [anon_sym___cdecl] = ACTIONS(2056),
    [anon_sym___clrcall] = ACTIONS(2056),
    [anon_sym___stdcall] = ACTIONS(2056),
    [anon_sym___fastcall] = ACTIONS(2056),
    [anon_sym___thiscall] = ACTIONS(2056),
    [anon_sym___vectorcall] = ACTIONS(2056),
    [anon_sym_LBRACE] = ACTIONS(2058),
    [anon_sym_signed] = ACTIONS(2056),
    [anon_sym_unsigned] = ACTIONS(2056),
    [anon_sym_long] = ACTIONS(2056),
    [anon_sym_short] = ACTIONS(2056),
    [anon_sym_LBRACK] = ACTIONS(2056),
    [anon_sym_static] = ACTIONS(2056),
    [anon_sym_register] = ACTIONS(2056),
    [anon_sym_inline] = ACTIONS(2056),
    [anon_sym___inline] = ACTIONS(2056),
    [anon_sym___inline__] = ACTIONS(2056),
    [anon_sym___forceinline] = ACTIONS(2056),
    [anon_sym_thread_local] = ACTIONS(2056),
    [anon_sym___thread] = ACTIONS(2056),
    [anon_sym_const] = ACTIONS(2056),
    [anon_sym_constexpr] = ACTIONS(2056),
    [anon_sym_volatile] = ACTIONS(2056),
    [anon_sym_restrict] = ACTIONS(2056),
    [anon_sym___restrict__] = ACTIONS(2056),
    [anon_sym__Atomic] = ACTIONS(2056),
    [anon_sym__Noreturn] = ACTIONS(2056),
    [anon_sym_noreturn] = ACTIONS(2056),
    [anon_sym__Nonnull] = ACTIONS(2056),
    [anon_sym_mutable] = ACTIONS(2056),
    [anon_sym_constinit] = ACTIONS(2056),
    [anon_sym_consteval] = ACTIONS(2056),
    [anon_sym___shared__] = ACTIONS(2056),
    [anon_sym___local__] = ACTIONS(2056),
    [anon_sym___constant__] = ACTIONS(2056),
    [anon_sym___managed__] = ACTIONS(2056),
    [anon_sym___grid_constant__] = ACTIONS(2056),
    [anon_sym_alignas] = ACTIONS(2056),
    [anon_sym__Alignas] = ACTIONS(2056),
    [sym_primitive_type] = ACTIONS(2056),
    [anon_sym_enum] = ACTIONS(2056),
    [anon_sym_class] = ACTIONS(2056),
    [anon_sym_struct] = ACTIONS(2056),
    [anon_sym_union] = ACTIONS(2056),
    [anon_sym_if] = ACTIONS(2056),
    [anon_sym_else] = ACTIONS(2056),
    [anon_sym_switch] = ACTIONS(2056),
    [anon_sym_case] = ACTIONS(2056),
    [anon_sym_default] = ACTIONS(2056),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_do] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2056),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_break] = ACTIONS(2056),
    [anon_sym_continue] = ACTIONS(2056),
    [anon_sym_goto] = ACTIONS(2056),
    [anon_sym___try] = ACTIONS(2056),
    [anon_sym___leave] = ACTIONS(2056),
    [anon_sym_not] = ACTIONS(2056),
    [anon_sym_compl] = ACTIONS(2056),
    [anon_sym_DASH_DASH] = ACTIONS(2058),
    [anon_sym_PLUS_PLUS] = ACTIONS(2058),
    [anon_sym_sizeof] = ACTIONS(2056),
    [anon_sym___alignof__] = ACTIONS(2056),
    [anon_sym___alignof] = ACTIONS(2056),
    [anon_sym__alignof] = ACTIONS(2056),
    [anon_sym_alignof] = ACTIONS(2056),
    [anon_sym__Alignof] = ACTIONS(2056),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2056),
    [anon_sym_asm] = ACTIONS(2056),
    [anon_sym___asm__] = ACTIONS(2056),
    [anon_sym___asm] = ACTIONS(2056),
    [sym_number_literal] = ACTIONS(2058),
    [anon_sym_L_SQUOTE] = ACTIONS(2058),
    [anon_sym_u_SQUOTE] = ACTIONS(2058),
    [anon_sym_U_SQUOTE] = ACTIONS(2058),
    [anon_sym_u8_SQUOTE] = ACTIONS(2058),
    [anon_sym_SQUOTE] = ACTIONS(2058),
    [anon_sym_L_DQUOTE] = ACTIONS(2058),
    [anon_sym_u_DQUOTE] = ACTIONS(2058),
    [anon_sym_U_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8_DQUOTE] = ACTIONS(2058),
    [anon_sym_DQUOTE] = ACTIONS(2058),
    [sym_true] = ACTIONS(2056),
    [sym_false] = ACTIONS(2056),
    [anon_sym_NULL] = ACTIONS(2056),
    [anon_sym_nullptr] = ACTIONS(2056),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2056),
    [anon_sym_decltype] = ACTIONS(2056),
    [anon_sym_explicit] = ACTIONS(2056),
    [anon_sym_typename] = ACTIONS(2056),
    [anon_sym_template] = ACTIONS(2056),
    [anon_sym_operator] = ACTIONS(2056),
    [anon_sym_try] = ACTIONS(2056),
    [anon_sym_delete] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2056),
    [anon_sym_namespace] = ACTIONS(2056),
    [anon_sym_using] = ACTIONS(2056),
    [anon_sym_static_assert] = ACTIONS(2056),
    [anon_sym_concept] = ACTIONS(2056),
    [anon_sym_co_return] = ACTIONS(2056),
    [anon_sym_co_yield] = ACTIONS(2056),
    [anon_sym_R_DQUOTE] = ACTIONS(2058),
    [anon_sym_LR_DQUOTE] = ACTIONS(2058),
    [anon_sym_uR_DQUOTE] = ACTIONS(2058),
    [anon_sym_UR_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2058),
    [anon_sym_co_await] = ACTIONS(2056),
    [anon_sym_new] = ACTIONS(2056),
    [anon_sym_requires] = ACTIONS(2056),
    [sym_this] = ACTIONS(2056),
    [anon_sym___launch_bounds__] = ACTIONS(2056),
  },
  [STATE(437)] = {
    [ts_builtin_sym_end] = ACTIONS(2068),
    [sym_identifier] = ACTIONS(2066),
    [aux_sym_preproc_include_token1] = ACTIONS(2066),
    [aux_sym_preproc_def_token1] = ACTIONS(2066),
    [aux_sym_preproc_if_token1] = ACTIONS(2066),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2066),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2066),
    [sym_preproc_directive] = ACTIONS(2066),
    [anon_sym_LPAREN2] = ACTIONS(2068),
    [anon_sym_BANG] = ACTIONS(2068),
    [anon_sym_TILDE] = ACTIONS(2068),
    [anon_sym_DASH] = ACTIONS(2066),
    [anon_sym_PLUS] = ACTIONS(2066),
    [anon_sym_STAR] = ACTIONS(2068),
    [anon_sym_AMP_AMP] = ACTIONS(2068),
    [anon_sym_AMP] = ACTIONS(2066),
    [anon_sym_SEMI] = ACTIONS(2068),
    [anon_sym___extension__] = ACTIONS(2066),
    [anon_sym_typedef] = ACTIONS(2066),
    [anon_sym___device__] = ACTIONS(2066),
    [anon_sym___host__] = ACTIONS(2066),
    [anon_sym___global__] = ACTIONS(2066),
    [anon_sym___forceinline__] = ACTIONS(2066),
    [anon_sym___noinline__] = ACTIONS(2066),
    [anon_sym_virtual] = ACTIONS(2066),
    [anon_sym_extern] = ACTIONS(2066),
    [anon_sym___attribute__] = ACTIONS(2066),
    [anon_sym___attribute] = ACTIONS(2066),
    [anon_sym_COLON_COLON] = ACTIONS(2068),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2068),
    [anon_sym___declspec] = ACTIONS(2066),
    [anon_sym___based] = ACTIONS(2066),
    [anon_sym___cdecl] = ACTIONS(2066),
    [anon_sym___clrcall] = ACTIONS(2066),
    [anon_sym___stdcall] = ACTIONS(2066),
    [anon_sym___fastcall] = ACTIONS(2066),
    [anon_sym___thiscall] = ACTIONS(2066),
    [anon_sym___vectorcall] = ACTIONS(2066),
    [anon_sym_LBRACE] = ACTIONS(2068),
    [anon_sym_signed] = ACTIONS(2066),
    [anon_sym_unsigned] = ACTIONS(2066),
    [anon_sym_long] = ACTIONS(2066),
    [anon_sym_short] = ACTIONS(2066),
    [anon_sym_LBRACK] = ACTIONS(2066),
    [anon_sym_static] = ACTIONS(2066),
    [anon_sym_register] = ACTIONS(2066),
    [anon_sym_inline] = ACTIONS(2066),
    [anon_sym___inline] = ACTIONS(2066),
    [anon_sym___inline__] = ACTIONS(2066),
    [anon_sym___forceinline] = ACTIONS(2066),
    [anon_sym_thread_local] = ACTIONS(2066),
    [anon_sym___thread] = ACTIONS(2066),
    [anon_sym_const] = ACTIONS(2066),
    [anon_sym_constexpr] = ACTIONS(2066),
    [anon_sym_volatile] = ACTIONS(2066),
    [anon_sym_restrict] = ACTIONS(2066),
    [anon_sym___restrict__] = ACTIONS(2066),
    [anon_sym__Atomic] = ACTIONS(2066),
    [anon_sym__Noreturn] = ACTIONS(2066),
    [anon_sym_noreturn] = ACTIONS(2066),
    [anon_sym__Nonnull] = ACTIONS(2066),
    [anon_sym_mutable] = ACTIONS(2066),
    [anon_sym_constinit] = ACTIONS(2066),
    [anon_sym_consteval] = ACTIONS(2066),
    [anon_sym___shared__] = ACTIONS(2066),
    [anon_sym___local__] = ACTIONS(2066),
    [anon_sym___constant__] = ACTIONS(2066),
    [anon_sym___managed__] = ACTIONS(2066),
    [anon_sym___grid_constant__] = ACTIONS(2066),
    [anon_sym_alignas] = ACTIONS(2066),
    [anon_sym__Alignas] = ACTIONS(2066),
    [sym_primitive_type] = ACTIONS(2066),
    [anon_sym_enum] = ACTIONS(2066),
    [anon_sym_class] = ACTIONS(2066),
    [anon_sym_struct] = ACTIONS(2066),
    [anon_sym_union] = ACTIONS(2066),
    [anon_sym_if] = ACTIONS(2066),
    [anon_sym_else] = ACTIONS(2066),
    [anon_sym_switch] = ACTIONS(2066),
    [anon_sym_case] = ACTIONS(2066),
    [anon_sym_default] = ACTIONS(2066),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_do] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2066),
    [anon_sym_return] = ACTIONS(2066),
    [anon_sym_break] = ACTIONS(2066),
    [anon_sym_continue] = ACTIONS(2066),
    [anon_sym_goto] = ACTIONS(2066),
    [anon_sym___try] = ACTIONS(2066),
    [anon_sym___leave] = ACTIONS(2066),
    [anon_sym_not] = ACTIONS(2066),
    [anon_sym_compl] = ACTIONS(2066),
    [anon_sym_DASH_DASH] = ACTIONS(2068),
    [anon_sym_PLUS_PLUS] = ACTIONS(2068),
    [anon_sym_sizeof] = ACTIONS(2066),
    [anon_sym___alignof__] = ACTIONS(2066),
    [anon_sym___alignof] = ACTIONS(2066),
    [anon_sym__alignof] = ACTIONS(2066),
    [anon_sym_alignof] = ACTIONS(2066),
    [anon_sym__Alignof] = ACTIONS(2066),
    [anon_sym_offsetof] = ACTIONS(2066),
    [anon_sym__Generic] = ACTIONS(2066),
    [anon_sym_asm] = ACTIONS(2066),
    [anon_sym___asm__] = ACTIONS(2066),
    [anon_sym___asm] = ACTIONS(2066),
    [sym_number_literal] = ACTIONS(2068),
    [anon_sym_L_SQUOTE] = ACTIONS(2068),
    [anon_sym_u_SQUOTE] = ACTIONS(2068),
    [anon_sym_U_SQUOTE] = ACTIONS(2068),
    [anon_sym_u8_SQUOTE] = ACTIONS(2068),
    [anon_sym_SQUOTE] = ACTIONS(2068),
    [anon_sym_L_DQUOTE] = ACTIONS(2068),
    [anon_sym_u_DQUOTE] = ACTIONS(2068),
    [anon_sym_U_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8_DQUOTE] = ACTIONS(2068),
    [anon_sym_DQUOTE] = ACTIONS(2068),
    [sym_true] = ACTIONS(2066),
    [sym_false] = ACTIONS(2066),
    [anon_sym_NULL] = ACTIONS(2066),
    [anon_sym_nullptr] = ACTIONS(2066),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2066),
    [anon_sym_decltype] = ACTIONS(2066),
    [anon_sym_explicit] = ACTIONS(2066),
    [anon_sym_typename] = ACTIONS(2066),
    [anon_sym_template] = ACTIONS(2066),
    [anon_sym_operator] = ACTIONS(2066),
    [anon_sym_try] = ACTIONS(2066),
    [anon_sym_delete] = ACTIONS(2066),
    [anon_sym_throw] = ACTIONS(2066),
    [anon_sym_namespace] = ACTIONS(2066),
    [anon_sym_using] = ACTIONS(2066),
    [anon_sym_static_assert] = ACTIONS(2066),
    [anon_sym_concept] = ACTIONS(2066),
    [anon_sym_co_return] = ACTIONS(2066),
    [anon_sym_co_yield] = ACTIONS(2066),
    [anon_sym_R_DQUOTE] = ACTIONS(2068),
    [anon_sym_LR_DQUOTE] = ACTIONS(2068),
    [anon_sym_uR_DQUOTE] = ACTIONS(2068),
    [anon_sym_UR_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2068),
    [anon_sym_co_await] = ACTIONS(2066),
    [anon_sym_new] = ACTIONS(2066),
    [anon_sym_requires] = ACTIONS(2066),
    [sym_this] = ACTIONS(2066),
    [anon_sym___launch_bounds__] = ACTIONS(2066),
  },
  [STATE(438)] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_include_token1] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym___device__] = ACTIONS(2190),
    [anon_sym___host__] = ACTIONS(2190),
    [anon_sym___global__] = ACTIONS(2190),
    [anon_sym___forceinline__] = ACTIONS(2190),
    [anon_sym___noinline__] = ACTIONS(2190),
    [anon_sym_virtual] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym___attribute] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym___cdecl] = ACTIONS(2190),
    [anon_sym___clrcall] = ACTIONS(2190),
    [anon_sym___stdcall] = ACTIONS(2190),
    [anon_sym___fastcall] = ACTIONS(2190),
    [anon_sym___thiscall] = ACTIONS(2190),
    [anon_sym___vectorcall] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_RBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym__Nonnull] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym___shared__] = ACTIONS(2190),
    [anon_sym___local__] = ACTIONS(2190),
    [anon_sym___constant__] = ACTIONS(2190),
    [anon_sym___managed__] = ACTIONS(2190),
    [anon_sym___grid_constant__] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym_default] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [anon_sym___asm] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_namespace] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym_concept] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym___launch_bounds__] = ACTIONS(2190),
  },
  [STATE(439)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_RBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(440)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_RBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(441)] = {
    [sym_identifier] = ACTIONS(2218),
    [aux_sym_preproc_include_token1] = ACTIONS(2218),
    [aux_sym_preproc_def_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2218),
    [sym_preproc_directive] = ACTIONS(2218),
    [anon_sym_LPAREN2] = ACTIONS(2220),
    [anon_sym_BANG] = ACTIONS(2220),
    [anon_sym_TILDE] = ACTIONS(2220),
    [anon_sym_DASH] = ACTIONS(2218),
    [anon_sym_PLUS] = ACTIONS(2218),
    [anon_sym_STAR] = ACTIONS(2220),
    [anon_sym_AMP_AMP] = ACTIONS(2220),
    [anon_sym_AMP] = ACTIONS(2218),
    [anon_sym_SEMI] = ACTIONS(2220),
    [anon_sym___extension__] = ACTIONS(2218),
    [anon_sym_typedef] = ACTIONS(2218),
    [anon_sym___device__] = ACTIONS(2218),
    [anon_sym___host__] = ACTIONS(2218),
    [anon_sym___global__] = ACTIONS(2218),
    [anon_sym___forceinline__] = ACTIONS(2218),
    [anon_sym___noinline__] = ACTIONS(2218),
    [anon_sym_virtual] = ACTIONS(2218),
    [anon_sym_extern] = ACTIONS(2218),
    [anon_sym___attribute__] = ACTIONS(2218),
    [anon_sym___attribute] = ACTIONS(2218),
    [anon_sym_COLON_COLON] = ACTIONS(2220),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2220),
    [anon_sym___declspec] = ACTIONS(2218),
    [anon_sym___based] = ACTIONS(2218),
    [anon_sym___cdecl] = ACTIONS(2218),
    [anon_sym___clrcall] = ACTIONS(2218),
    [anon_sym___stdcall] = ACTIONS(2218),
    [anon_sym___fastcall] = ACTIONS(2218),
    [anon_sym___thiscall] = ACTIONS(2218),
    [anon_sym___vectorcall] = ACTIONS(2218),
    [anon_sym_LBRACE] = ACTIONS(2220),
    [anon_sym_RBRACE] = ACTIONS(2220),
    [anon_sym_signed] = ACTIONS(2218),
    [anon_sym_unsigned] = ACTIONS(2218),
    [anon_sym_long] = ACTIONS(2218),
    [anon_sym_short] = ACTIONS(2218),
    [anon_sym_LBRACK] = ACTIONS(2218),
    [anon_sym_static] = ACTIONS(2218),
    [anon_sym_register] = ACTIONS(2218),
    [anon_sym_inline] = ACTIONS(2218),
    [anon_sym___inline] = ACTIONS(2218),
    [anon_sym___inline__] = ACTIONS(2218),
    [anon_sym___forceinline] = ACTIONS(2218),
    [anon_sym_thread_local] = ACTIONS(2218),
    [anon_sym___thread] = ACTIONS(2218),
    [anon_sym_const] = ACTIONS(2218),
    [anon_sym_constexpr] = ACTIONS(2218),
    [anon_sym_volatile] = ACTIONS(2218),
    [anon_sym_restrict] = ACTIONS(2218),
    [anon_sym___restrict__] = ACTIONS(2218),
    [anon_sym__Atomic] = ACTIONS(2218),
    [anon_sym__Noreturn] = ACTIONS(2218),
    [anon_sym_noreturn] = ACTIONS(2218),
    [anon_sym__Nonnull] = ACTIONS(2218),
    [anon_sym_mutable] = ACTIONS(2218),
    [anon_sym_constinit] = ACTIONS(2218),
    [anon_sym_consteval] = ACTIONS(2218),
    [anon_sym___shared__] = ACTIONS(2218),
    [anon_sym___local__] = ACTIONS(2218),
    [anon_sym___constant__] = ACTIONS(2218),
    [anon_sym___managed__] = ACTIONS(2218),
    [anon_sym___grid_constant__] = ACTIONS(2218),
    [anon_sym_alignas] = ACTIONS(2218),
    [anon_sym__Alignas] = ACTIONS(2218),
    [sym_primitive_type] = ACTIONS(2218),
    [anon_sym_enum] = ACTIONS(2218),
    [anon_sym_class] = ACTIONS(2218),
    [anon_sym_struct] = ACTIONS(2218),
    [anon_sym_union] = ACTIONS(2218),
    [anon_sym_if] = ACTIONS(2218),
    [anon_sym_else] = ACTIONS(2218),
    [anon_sym_switch] = ACTIONS(2218),
    [anon_sym_case] = ACTIONS(2218),
    [anon_sym_default] = ACTIONS(2218),
    [anon_sym_while] = ACTIONS(2218),
    [anon_sym_do] = ACTIONS(2218),
    [anon_sym_for] = ACTIONS(2218),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_break] = ACTIONS(2218),
    [anon_sym_continue] = ACTIONS(2218),
    [anon_sym_goto] = ACTIONS(2218),
    [anon_sym___try] = ACTIONS(2218),
    [anon_sym___leave] = ACTIONS(2218),
    [anon_sym_not] = ACTIONS(2218),
    [anon_sym_compl] = ACTIONS(2218),
    [anon_sym_DASH_DASH] = ACTIONS(2220),
    [anon_sym_PLUS_PLUS] = ACTIONS(2220),
    [anon_sym_sizeof] = ACTIONS(2218),
    [anon_sym___alignof__] = ACTIONS(2218),
    [anon_sym___alignof] = ACTIONS(2218),
    [anon_sym__alignof] = ACTIONS(2218),
    [anon_sym_alignof] = ACTIONS(2218),
    [anon_sym__Alignof] = ACTIONS(2218),
    [anon_sym_offsetof] = ACTIONS(2218),
    [anon_sym__Generic] = ACTIONS(2218),
    [anon_sym_asm] = ACTIONS(2218),
    [anon_sym___asm__] = ACTIONS(2218),
    [anon_sym___asm] = ACTIONS(2218),
    [sym_number_literal] = ACTIONS(2220),
    [anon_sym_L_SQUOTE] = ACTIONS(2220),
    [anon_sym_u_SQUOTE] = ACTIONS(2220),
    [anon_sym_U_SQUOTE] = ACTIONS(2220),
    [anon_sym_u8_SQUOTE] = ACTIONS(2220),
    [anon_sym_SQUOTE] = ACTIONS(2220),
    [anon_sym_L_DQUOTE] = ACTIONS(2220),
    [anon_sym_u_DQUOTE] = ACTIONS(2220),
    [anon_sym_U_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8_DQUOTE] = ACTIONS(2220),
    [anon_sym_DQUOTE] = ACTIONS(2220),
    [sym_true] = ACTIONS(2218),
    [sym_false] = ACTIONS(2218),
    [anon_sym_NULL] = ACTIONS(2218),
    [anon_sym_nullptr] = ACTIONS(2218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2218),
    [anon_sym_decltype] = ACTIONS(2218),
    [anon_sym_explicit] = ACTIONS(2218),
    [anon_sym_typename] = ACTIONS(2218),
    [anon_sym_template] = ACTIONS(2218),
    [anon_sym_operator] = ACTIONS(2218),
    [anon_sym_try] = ACTIONS(2218),
    [anon_sym_delete] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2218),
    [anon_sym_namespace] = ACTIONS(2218),
    [anon_sym_using] = ACTIONS(2218),
    [anon_sym_static_assert] = ACTIONS(2218),
    [anon_sym_concept] = ACTIONS(2218),
    [anon_sym_co_return] = ACTIONS(2218),
    [anon_sym_co_yield] = ACTIONS(2218),
    [anon_sym_R_DQUOTE] = ACTIONS(2220),
    [anon_sym_LR_DQUOTE] = ACTIONS(2220),
    [anon_sym_uR_DQUOTE] = ACTIONS(2220),
    [anon_sym_UR_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2220),
    [anon_sym_co_await] = ACTIONS(2218),
    [anon_sym_new] = ACTIONS(2218),
    [anon_sym_requires] = ACTIONS(2218),
    [sym_this] = ACTIONS(2218),
    [anon_sym___launch_bounds__] = ACTIONS(2218),
  },
  [STATE(442)] = {
    [sym_identifier] = ACTIONS(2044),
    [aux_sym_preproc_include_token1] = ACTIONS(2044),
    [aux_sym_preproc_def_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2044),
    [sym_preproc_directive] = ACTIONS(2044),
    [anon_sym_LPAREN2] = ACTIONS(2046),
    [anon_sym_BANG] = ACTIONS(2046),
    [anon_sym_TILDE] = ACTIONS(2046),
    [anon_sym_DASH] = ACTIONS(2044),
    [anon_sym_PLUS] = ACTIONS(2044),
    [anon_sym_STAR] = ACTIONS(2046),
    [anon_sym_AMP_AMP] = ACTIONS(2046),
    [anon_sym_AMP] = ACTIONS(2044),
    [anon_sym_SEMI] = ACTIONS(2046),
    [anon_sym___extension__] = ACTIONS(2044),
    [anon_sym_typedef] = ACTIONS(2044),
    [anon_sym___device__] = ACTIONS(2044),
    [anon_sym___host__] = ACTIONS(2044),
    [anon_sym___global__] = ACTIONS(2044),
    [anon_sym___forceinline__] = ACTIONS(2044),
    [anon_sym___noinline__] = ACTIONS(2044),
    [anon_sym_virtual] = ACTIONS(2044),
    [anon_sym_extern] = ACTIONS(2044),
    [anon_sym___attribute__] = ACTIONS(2044),
    [anon_sym___attribute] = ACTIONS(2044),
    [anon_sym_COLON_COLON] = ACTIONS(2046),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2046),
    [anon_sym___declspec] = ACTIONS(2044),
    [anon_sym___based] = ACTIONS(2044),
    [anon_sym___cdecl] = ACTIONS(2044),
    [anon_sym___clrcall] = ACTIONS(2044),
    [anon_sym___stdcall] = ACTIONS(2044),
    [anon_sym___fastcall] = ACTIONS(2044),
    [anon_sym___thiscall] = ACTIONS(2044),
    [anon_sym___vectorcall] = ACTIONS(2044),
    [anon_sym_LBRACE] = ACTIONS(2046),
    [anon_sym_RBRACE] = ACTIONS(2046),
    [anon_sym_signed] = ACTIONS(2044),
    [anon_sym_unsigned] = ACTIONS(2044),
    [anon_sym_long] = ACTIONS(2044),
    [anon_sym_short] = ACTIONS(2044),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_static] = ACTIONS(2044),
    [anon_sym_register] = ACTIONS(2044),
    [anon_sym_inline] = ACTIONS(2044),
    [anon_sym___inline] = ACTIONS(2044),
    [anon_sym___inline__] = ACTIONS(2044),
    [anon_sym___forceinline] = ACTIONS(2044),
    [anon_sym_thread_local] = ACTIONS(2044),
    [anon_sym___thread] = ACTIONS(2044),
    [anon_sym_const] = ACTIONS(2044),
    [anon_sym_constexpr] = ACTIONS(2044),
    [anon_sym_volatile] = ACTIONS(2044),
    [anon_sym_restrict] = ACTIONS(2044),
    [anon_sym___restrict__] = ACTIONS(2044),
    [anon_sym__Atomic] = ACTIONS(2044),
    [anon_sym__Noreturn] = ACTIONS(2044),
    [anon_sym_noreturn] = ACTIONS(2044),
    [anon_sym__Nonnull] = ACTIONS(2044),
    [anon_sym_mutable] = ACTIONS(2044),
    [anon_sym_constinit] = ACTIONS(2044),
    [anon_sym_consteval] = ACTIONS(2044),
    [anon_sym___shared__] = ACTIONS(2044),
    [anon_sym___local__] = ACTIONS(2044),
    [anon_sym___constant__] = ACTIONS(2044),
    [anon_sym___managed__] = ACTIONS(2044),
    [anon_sym___grid_constant__] = ACTIONS(2044),
    [anon_sym_alignas] = ACTIONS(2044),
    [anon_sym__Alignas] = ACTIONS(2044),
    [sym_primitive_type] = ACTIONS(2044),
    [anon_sym_enum] = ACTIONS(2044),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2044),
    [anon_sym_union] = ACTIONS(2044),
    [anon_sym_if] = ACTIONS(2044),
    [anon_sym_else] = ACTIONS(2044),
    [anon_sym_switch] = ACTIONS(2044),
    [anon_sym_case] = ACTIONS(2044),
    [anon_sym_default] = ACTIONS(2044),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_do] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2044),
    [anon_sym_return] = ACTIONS(2044),
    [anon_sym_break] = ACTIONS(2044),
    [anon_sym_continue] = ACTIONS(2044),
    [anon_sym_goto] = ACTIONS(2044),
    [anon_sym___try] = ACTIONS(2044),
    [anon_sym___leave] = ACTIONS(2044),
    [anon_sym_not] = ACTIONS(2044),
    [anon_sym_compl] = ACTIONS(2044),
    [anon_sym_DASH_DASH] = ACTIONS(2046),
    [anon_sym_PLUS_PLUS] = ACTIONS(2046),
    [anon_sym_sizeof] = ACTIONS(2044),
    [anon_sym___alignof__] = ACTIONS(2044),
    [anon_sym___alignof] = ACTIONS(2044),
    [anon_sym__alignof] = ACTIONS(2044),
    [anon_sym_alignof] = ACTIONS(2044),
    [anon_sym__Alignof] = ACTIONS(2044),
    [anon_sym_offsetof] = ACTIONS(2044),
    [anon_sym__Generic] = ACTIONS(2044),
    [anon_sym_asm] = ACTIONS(2044),
    [anon_sym___asm__] = ACTIONS(2044),
    [anon_sym___asm] = ACTIONS(2044),
    [sym_number_literal] = ACTIONS(2046),
    [anon_sym_L_SQUOTE] = ACTIONS(2046),
    [anon_sym_u_SQUOTE] = ACTIONS(2046),
    [anon_sym_U_SQUOTE] = ACTIONS(2046),
    [anon_sym_u8_SQUOTE] = ACTIONS(2046),
    [anon_sym_SQUOTE] = ACTIONS(2046),
    [anon_sym_L_DQUOTE] = ACTIONS(2046),
    [anon_sym_u_DQUOTE] = ACTIONS(2046),
    [anon_sym_U_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8_DQUOTE] = ACTIONS(2046),
    [anon_sym_DQUOTE] = ACTIONS(2046),
    [sym_true] = ACTIONS(2044),
    [sym_false] = ACTIONS(2044),
    [anon_sym_NULL] = ACTIONS(2044),
    [anon_sym_nullptr] = ACTIONS(2044),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2044),
    [anon_sym_decltype] = ACTIONS(2044),
    [anon_sym_explicit] = ACTIONS(2044),
    [anon_sym_typename] = ACTIONS(2044),
    [anon_sym_template] = ACTIONS(2044),
    [anon_sym_operator] = ACTIONS(2044),
    [anon_sym_try] = ACTIONS(2044),
    [anon_sym_delete] = ACTIONS(2044),
    [anon_sym_throw] = ACTIONS(2044),
    [anon_sym_namespace] = ACTIONS(2044),
    [anon_sym_using] = ACTIONS(2044),
    [anon_sym_static_assert] = ACTIONS(2044),
    [anon_sym_concept] = ACTIONS(2044),
    [anon_sym_co_return] = ACTIONS(2044),
    [anon_sym_co_yield] = ACTIONS(2044),
    [anon_sym_R_DQUOTE] = ACTIONS(2046),
    [anon_sym_LR_DQUOTE] = ACTIONS(2046),
    [anon_sym_uR_DQUOTE] = ACTIONS(2046),
    [anon_sym_UR_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2046),
    [anon_sym_co_await] = ACTIONS(2044),
    [anon_sym_new] = ACTIONS(2044),
    [anon_sym_requires] = ACTIONS(2044),
    [sym_this] = ACTIONS(2044),
    [anon_sym___launch_bounds__] = ACTIONS(2044),
  },
  [STATE(443)] = {
    [ts_builtin_sym_end] = ACTIONS(2054),
    [sym_identifier] = ACTIONS(2052),
    [aux_sym_preproc_include_token1] = ACTIONS(2052),
    [aux_sym_preproc_def_token1] = ACTIONS(2052),
    [aux_sym_preproc_if_token1] = ACTIONS(2052),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2052),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2052),
    [sym_preproc_directive] = ACTIONS(2052),
    [anon_sym_LPAREN2] = ACTIONS(2054),
    [anon_sym_BANG] = ACTIONS(2054),
    [anon_sym_TILDE] = ACTIONS(2054),
    [anon_sym_DASH] = ACTIONS(2052),
    [anon_sym_PLUS] = ACTIONS(2052),
    [anon_sym_STAR] = ACTIONS(2054),
    [anon_sym_AMP_AMP] = ACTIONS(2054),
    [anon_sym_AMP] = ACTIONS(2052),
    [anon_sym_SEMI] = ACTIONS(2054),
    [anon_sym___extension__] = ACTIONS(2052),
    [anon_sym_typedef] = ACTIONS(2052),
    [anon_sym___device__] = ACTIONS(2052),
    [anon_sym___host__] = ACTIONS(2052),
    [anon_sym___global__] = ACTIONS(2052),
    [anon_sym___forceinline__] = ACTIONS(2052),
    [anon_sym___noinline__] = ACTIONS(2052),
    [anon_sym_virtual] = ACTIONS(2052),
    [anon_sym_extern] = ACTIONS(2052),
    [anon_sym___attribute__] = ACTIONS(2052),
    [anon_sym___attribute] = ACTIONS(2052),
    [anon_sym_COLON_COLON] = ACTIONS(2054),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2054),
    [anon_sym___declspec] = ACTIONS(2052),
    [anon_sym___based] = ACTIONS(2052),
    [anon_sym___cdecl] = ACTIONS(2052),
    [anon_sym___clrcall] = ACTIONS(2052),
    [anon_sym___stdcall] = ACTIONS(2052),
    [anon_sym___fastcall] = ACTIONS(2052),
    [anon_sym___thiscall] = ACTIONS(2052),
    [anon_sym___vectorcall] = ACTIONS(2052),
    [anon_sym_LBRACE] = ACTIONS(2054),
    [anon_sym_signed] = ACTIONS(2052),
    [anon_sym_unsigned] = ACTIONS(2052),
    [anon_sym_long] = ACTIONS(2052),
    [anon_sym_short] = ACTIONS(2052),
    [anon_sym_LBRACK] = ACTIONS(2052),
    [anon_sym_static] = ACTIONS(2052),
    [anon_sym_register] = ACTIONS(2052),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym___inline] = ACTIONS(2052),
    [anon_sym___inline__] = ACTIONS(2052),
    [anon_sym___forceinline] = ACTIONS(2052),
    [anon_sym_thread_local] = ACTIONS(2052),
    [anon_sym___thread] = ACTIONS(2052),
    [anon_sym_const] = ACTIONS(2052),
    [anon_sym_constexpr] = ACTIONS(2052),
    [anon_sym_volatile] = ACTIONS(2052),
    [anon_sym_restrict] = ACTIONS(2052),
    [anon_sym___restrict__] = ACTIONS(2052),
    [anon_sym__Atomic] = ACTIONS(2052),
    [anon_sym__Noreturn] = ACTIONS(2052),
    [anon_sym_noreturn] = ACTIONS(2052),
    [anon_sym__Nonnull] = ACTIONS(2052),
    [anon_sym_mutable] = ACTIONS(2052),
    [anon_sym_constinit] = ACTIONS(2052),
    [anon_sym_consteval] = ACTIONS(2052),
    [anon_sym___shared__] = ACTIONS(2052),
    [anon_sym___local__] = ACTIONS(2052),
    [anon_sym___constant__] = ACTIONS(2052),
    [anon_sym___managed__] = ACTIONS(2052),
    [anon_sym___grid_constant__] = ACTIONS(2052),
    [anon_sym_alignas] = ACTIONS(2052),
    [anon_sym__Alignas] = ACTIONS(2052),
    [sym_primitive_type] = ACTIONS(2052),
    [anon_sym_enum] = ACTIONS(2052),
    [anon_sym_class] = ACTIONS(2052),
    [anon_sym_struct] = ACTIONS(2052),
    [anon_sym_union] = ACTIONS(2052),
    [anon_sym_if] = ACTIONS(2052),
    [anon_sym_else] = ACTIONS(2052),
    [anon_sym_switch] = ACTIONS(2052),
    [anon_sym_case] = ACTIONS(2052),
    [anon_sym_default] = ACTIONS(2052),
    [anon_sym_while] = ACTIONS(2052),
    [anon_sym_do] = ACTIONS(2052),
    [anon_sym_for] = ACTIONS(2052),
    [anon_sym_return] = ACTIONS(2052),
    [anon_sym_break] = ACTIONS(2052),
    [anon_sym_continue] = ACTIONS(2052),
    [anon_sym_goto] = ACTIONS(2052),
    [anon_sym___try] = ACTIONS(2052),
    [anon_sym___leave] = ACTIONS(2052),
    [anon_sym_not] = ACTIONS(2052),
    [anon_sym_compl] = ACTIONS(2052),
    [anon_sym_DASH_DASH] = ACTIONS(2054),
    [anon_sym_PLUS_PLUS] = ACTIONS(2054),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2052),
    [anon_sym___alignof] = ACTIONS(2052),
    [anon_sym__alignof] = ACTIONS(2052),
    [anon_sym_alignof] = ACTIONS(2052),
    [anon_sym__Alignof] = ACTIONS(2052),
    [anon_sym_offsetof] = ACTIONS(2052),
    [anon_sym__Generic] = ACTIONS(2052),
    [anon_sym_asm] = ACTIONS(2052),
    [anon_sym___asm__] = ACTIONS(2052),
    [anon_sym___asm] = ACTIONS(2052),
    [sym_number_literal] = ACTIONS(2054),
    [anon_sym_L_SQUOTE] = ACTIONS(2054),
    [anon_sym_u_SQUOTE] = ACTIONS(2054),
    [anon_sym_U_SQUOTE] = ACTIONS(2054),
    [anon_sym_u8_SQUOTE] = ACTIONS(2054),
    [anon_sym_SQUOTE] = ACTIONS(2054),
    [anon_sym_L_DQUOTE] = ACTIONS(2054),
    [anon_sym_u_DQUOTE] = ACTIONS(2054),
    [anon_sym_U_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8_DQUOTE] = ACTIONS(2054),
    [anon_sym_DQUOTE] = ACTIONS(2054),
    [sym_true] = ACTIONS(2052),
    [sym_false] = ACTIONS(2052),
    [anon_sym_NULL] = ACTIONS(2052),
    [anon_sym_nullptr] = ACTIONS(2052),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2052),
    [anon_sym_decltype] = ACTIONS(2052),
    [anon_sym_explicit] = ACTIONS(2052),
    [anon_sym_typename] = ACTIONS(2052),
    [anon_sym_template] = ACTIONS(2052),
    [anon_sym_operator] = ACTIONS(2052),
    [anon_sym_try] = ACTIONS(2052),
    [anon_sym_delete] = ACTIONS(2052),
    [anon_sym_throw] = ACTIONS(2052),
    [anon_sym_namespace] = ACTIONS(2052),
    [anon_sym_using] = ACTIONS(2052),
    [anon_sym_static_assert] = ACTIONS(2052),
    [anon_sym_concept] = ACTIONS(2052),
    [anon_sym_co_return] = ACTIONS(2052),
    [anon_sym_co_yield] = ACTIONS(2052),
    [anon_sym_R_DQUOTE] = ACTIONS(2054),
    [anon_sym_LR_DQUOTE] = ACTIONS(2054),
    [anon_sym_uR_DQUOTE] = ACTIONS(2054),
    [anon_sym_UR_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2054),
    [anon_sym_co_await] = ACTIONS(2052),
    [anon_sym_new] = ACTIONS(2052),
    [anon_sym_requires] = ACTIONS(2052),
    [sym_this] = ACTIONS(2052),
    [anon_sym___launch_bounds__] = ACTIONS(2052),
  },
  [STATE(444)] = {
    [sym_identifier] = ACTIONS(2154),
    [aux_sym_preproc_include_token1] = ACTIONS(2154),
    [aux_sym_preproc_def_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2154),
    [sym_preproc_directive] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP_AMP] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2154),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym___device__] = ACTIONS(2154),
    [anon_sym___host__] = ACTIONS(2154),
    [anon_sym___global__] = ACTIONS(2154),
    [anon_sym___forceinline__] = ACTIONS(2154),
    [anon_sym___noinline__] = ACTIONS(2154),
    [anon_sym_virtual] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym___attribute] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym___based] = ACTIONS(2154),
    [anon_sym___cdecl] = ACTIONS(2154),
    [anon_sym___clrcall] = ACTIONS(2154),
    [anon_sym___stdcall] = ACTIONS(2154),
    [anon_sym___fastcall] = ACTIONS(2154),
    [anon_sym___thiscall] = ACTIONS(2154),
    [anon_sym___vectorcall] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_RBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym__Nonnull] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym___shared__] = ACTIONS(2154),
    [anon_sym___local__] = ACTIONS(2154),
    [anon_sym___constant__] = ACTIONS(2154),
    [anon_sym___managed__] = ACTIONS(2154),
    [anon_sym___grid_constant__] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_case] = ACTIONS(2154),
    [anon_sym_default] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [anon_sym___asm] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [anon_sym_explicit] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_operator] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_namespace] = ACTIONS(2154),
    [anon_sym_using] = ACTIONS(2154),
    [anon_sym_static_assert] = ACTIONS(2154),
    [anon_sym_concept] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym___launch_bounds__] = ACTIONS(2154),
  },
  [STATE(445)] = {
    [sym_identifier] = ACTIONS(2158),
    [aux_sym_preproc_include_token1] = ACTIONS(2158),
    [aux_sym_preproc_def_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2158),
    [sym_preproc_directive] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP_AMP] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2158),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym___device__] = ACTIONS(2158),
    [anon_sym___host__] = ACTIONS(2158),
    [anon_sym___global__] = ACTIONS(2158),
    [anon_sym___forceinline__] = ACTIONS(2158),
    [anon_sym___noinline__] = ACTIONS(2158),
    [anon_sym_virtual] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym___attribute] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym___based] = ACTIONS(2158),
    [anon_sym___cdecl] = ACTIONS(2158),
    [anon_sym___clrcall] = ACTIONS(2158),
    [anon_sym___stdcall] = ACTIONS(2158),
    [anon_sym___fastcall] = ACTIONS(2158),
    [anon_sym___thiscall] = ACTIONS(2158),
    [anon_sym___vectorcall] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_RBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym__Nonnull] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym___shared__] = ACTIONS(2158),
    [anon_sym___local__] = ACTIONS(2158),
    [anon_sym___constant__] = ACTIONS(2158),
    [anon_sym___managed__] = ACTIONS(2158),
    [anon_sym___grid_constant__] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_case] = ACTIONS(2158),
    [anon_sym_default] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [anon_sym___asm] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [anon_sym_explicit] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_operator] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_namespace] = ACTIONS(2158),
    [anon_sym_using] = ACTIONS(2158),
    [anon_sym_static_assert] = ACTIONS(2158),
    [anon_sym_concept] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym___launch_bounds__] = ACTIONS(2158),
  },
  [STATE(446)] = {
    [sym_identifier] = ACTIONS(2162),
    [aux_sym_preproc_include_token1] = ACTIONS(2162),
    [aux_sym_preproc_def_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2162),
    [sym_preproc_directive] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP_AMP] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2162),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym___device__] = ACTIONS(2162),
    [anon_sym___host__] = ACTIONS(2162),
    [anon_sym___global__] = ACTIONS(2162),
    [anon_sym___forceinline__] = ACTIONS(2162),
    [anon_sym___noinline__] = ACTIONS(2162),
    [anon_sym_virtual] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym___attribute] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym___based] = ACTIONS(2162),
    [anon_sym___cdecl] = ACTIONS(2162),
    [anon_sym___clrcall] = ACTIONS(2162),
    [anon_sym___stdcall] = ACTIONS(2162),
    [anon_sym___fastcall] = ACTIONS(2162),
    [anon_sym___thiscall] = ACTIONS(2162),
    [anon_sym___vectorcall] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_RBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym__Nonnull] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym___shared__] = ACTIONS(2162),
    [anon_sym___local__] = ACTIONS(2162),
    [anon_sym___constant__] = ACTIONS(2162),
    [anon_sym___managed__] = ACTIONS(2162),
    [anon_sym___grid_constant__] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_case] = ACTIONS(2162),
    [anon_sym_default] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [anon_sym___asm] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [anon_sym_explicit] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_operator] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_namespace] = ACTIONS(2162),
    [anon_sym_using] = ACTIONS(2162),
    [anon_sym_static_assert] = ACTIONS(2162),
    [anon_sym_concept] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym___launch_bounds__] = ACTIONS(2162),
  },
  [STATE(447)] = {
    [sym_identifier] = ACTIONS(2186),
    [aux_sym_preproc_include_token1] = ACTIONS(2186),
    [aux_sym_preproc_def_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2186),
    [sym_preproc_directive] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP_AMP] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2186),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym___device__] = ACTIONS(2186),
    [anon_sym___host__] = ACTIONS(2186),
    [anon_sym___global__] = ACTIONS(2186),
    [anon_sym___forceinline__] = ACTIONS(2186),
    [anon_sym___noinline__] = ACTIONS(2186),
    [anon_sym_virtual] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym___attribute] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym___based] = ACTIONS(2186),
    [anon_sym___cdecl] = ACTIONS(2186),
    [anon_sym___clrcall] = ACTIONS(2186),
    [anon_sym___stdcall] = ACTIONS(2186),
    [anon_sym___fastcall] = ACTIONS(2186),
    [anon_sym___thiscall] = ACTIONS(2186),
    [anon_sym___vectorcall] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_RBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym__Nonnull] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym___shared__] = ACTIONS(2186),
    [anon_sym___local__] = ACTIONS(2186),
    [anon_sym___constant__] = ACTIONS(2186),
    [anon_sym___managed__] = ACTIONS(2186),
    [anon_sym___grid_constant__] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_case] = ACTIONS(2186),
    [anon_sym_default] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [anon_sym___asm] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [anon_sym_explicit] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_operator] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_namespace] = ACTIONS(2186),
    [anon_sym_using] = ACTIONS(2186),
    [anon_sym_static_assert] = ACTIONS(2186),
    [anon_sym_concept] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym___launch_bounds__] = ACTIONS(2186),
  },
  [STATE(448)] = {
    [sym_identifier] = ACTIONS(2214),
    [aux_sym_preproc_include_token1] = ACTIONS(2214),
    [aux_sym_preproc_def_token1] = ACTIONS(2214),
    [aux_sym_preproc_if_token1] = ACTIONS(2214),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2214),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2214),
    [sym_preproc_directive] = ACTIONS(2214),
    [anon_sym_LPAREN2] = ACTIONS(2216),
    [anon_sym_BANG] = ACTIONS(2216),
    [anon_sym_TILDE] = ACTIONS(2216),
    [anon_sym_DASH] = ACTIONS(2214),
    [anon_sym_PLUS] = ACTIONS(2214),
    [anon_sym_STAR] = ACTIONS(2216),
    [anon_sym_AMP_AMP] = ACTIONS(2216),
    [anon_sym_AMP] = ACTIONS(2214),
    [anon_sym_SEMI] = ACTIONS(2216),
    [anon_sym___extension__] = ACTIONS(2214),
    [anon_sym_typedef] = ACTIONS(2214),
    [anon_sym___device__] = ACTIONS(2214),
    [anon_sym___host__] = ACTIONS(2214),
    [anon_sym___global__] = ACTIONS(2214),
    [anon_sym___forceinline__] = ACTIONS(2214),
    [anon_sym___noinline__] = ACTIONS(2214),
    [anon_sym_virtual] = ACTIONS(2214),
    [anon_sym_extern] = ACTIONS(2214),
    [anon_sym___attribute__] = ACTIONS(2214),
    [anon_sym___attribute] = ACTIONS(2214),
    [anon_sym_COLON_COLON] = ACTIONS(2216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2216),
    [anon_sym___declspec] = ACTIONS(2214),
    [anon_sym___based] = ACTIONS(2214),
    [anon_sym___cdecl] = ACTIONS(2214),
    [anon_sym___clrcall] = ACTIONS(2214),
    [anon_sym___stdcall] = ACTIONS(2214),
    [anon_sym___fastcall] = ACTIONS(2214),
    [anon_sym___thiscall] = ACTIONS(2214),
    [anon_sym___vectorcall] = ACTIONS(2214),
    [anon_sym_LBRACE] = ACTIONS(2216),
    [anon_sym_RBRACE] = ACTIONS(2216),
    [anon_sym_signed] = ACTIONS(2214),
    [anon_sym_unsigned] = ACTIONS(2214),
    [anon_sym_long] = ACTIONS(2214),
    [anon_sym_short] = ACTIONS(2214),
    [anon_sym_LBRACK] = ACTIONS(2214),
    [anon_sym_static] = ACTIONS(2214),
    [anon_sym_register] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(2214),
    [anon_sym___inline] = ACTIONS(2214),
    [anon_sym___inline__] = ACTIONS(2214),
    [anon_sym___forceinline] = ACTIONS(2214),
    [anon_sym_thread_local] = ACTIONS(2214),
    [anon_sym___thread] = ACTIONS(2214),
    [anon_sym_const] = ACTIONS(2214),
    [anon_sym_constexpr] = ACTIONS(2214),
    [anon_sym_volatile] = ACTIONS(2214),
    [anon_sym_restrict] = ACTIONS(2214),
    [anon_sym___restrict__] = ACTIONS(2214),
    [anon_sym__Atomic] = ACTIONS(2214),
    [anon_sym__Noreturn] = ACTIONS(2214),
    [anon_sym_noreturn] = ACTIONS(2214),
    [anon_sym__Nonnull] = ACTIONS(2214),
    [anon_sym_mutable] = ACTIONS(2214),
    [anon_sym_constinit] = ACTIONS(2214),
    [anon_sym_consteval] = ACTIONS(2214),
    [anon_sym___shared__] = ACTIONS(2214),
    [anon_sym___local__] = ACTIONS(2214),
    [anon_sym___constant__] = ACTIONS(2214),
    [anon_sym___managed__] = ACTIONS(2214),
    [anon_sym___grid_constant__] = ACTIONS(2214),
    [anon_sym_alignas] = ACTIONS(2214),
    [anon_sym__Alignas] = ACTIONS(2214),
    [sym_primitive_type] = ACTIONS(2214),
    [anon_sym_enum] = ACTIONS(2214),
    [anon_sym_class] = ACTIONS(2214),
    [anon_sym_struct] = ACTIONS(2214),
    [anon_sym_union] = ACTIONS(2214),
    [anon_sym_if] = ACTIONS(2214),
    [anon_sym_else] = ACTIONS(2214),
    [anon_sym_switch] = ACTIONS(2214),
    [anon_sym_case] = ACTIONS(2214),
    [anon_sym_default] = ACTIONS(2214),
    [anon_sym_while] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2214),
    [anon_sym_for] = ACTIONS(2214),
    [anon_sym_return] = ACTIONS(2214),
    [anon_sym_break] = ACTIONS(2214),
    [anon_sym_continue] = ACTIONS(2214),
    [anon_sym_goto] = ACTIONS(2214),
    [anon_sym___try] = ACTIONS(2214),
    [anon_sym___leave] = ACTIONS(2214),
    [anon_sym_not] = ACTIONS(2214),
    [anon_sym_compl] = ACTIONS(2214),
    [anon_sym_DASH_DASH] = ACTIONS(2216),
    [anon_sym_PLUS_PLUS] = ACTIONS(2216),
    [anon_sym_sizeof] = ACTIONS(2214),
    [anon_sym___alignof__] = ACTIONS(2214),
    [anon_sym___alignof] = ACTIONS(2214),
    [anon_sym__alignof] = ACTIONS(2214),
    [anon_sym_alignof] = ACTIONS(2214),
    [anon_sym__Alignof] = ACTIONS(2214),
    [anon_sym_offsetof] = ACTIONS(2214),
    [anon_sym__Generic] = ACTIONS(2214),
    [anon_sym_asm] = ACTIONS(2214),
    [anon_sym___asm__] = ACTIONS(2214),
    [anon_sym___asm] = ACTIONS(2214),
    [sym_number_literal] = ACTIONS(2216),
    [anon_sym_L_SQUOTE] = ACTIONS(2216),
    [anon_sym_u_SQUOTE] = ACTIONS(2216),
    [anon_sym_U_SQUOTE] = ACTIONS(2216),
    [anon_sym_u8_SQUOTE] = ACTIONS(2216),
    [anon_sym_SQUOTE] = ACTIONS(2216),
    [anon_sym_L_DQUOTE] = ACTIONS(2216),
    [anon_sym_u_DQUOTE] = ACTIONS(2216),
    [anon_sym_U_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8_DQUOTE] = ACTIONS(2216),
    [anon_sym_DQUOTE] = ACTIONS(2216),
    [sym_true] = ACTIONS(2214),
    [sym_false] = ACTIONS(2214),
    [anon_sym_NULL] = ACTIONS(2214),
    [anon_sym_nullptr] = ACTIONS(2214),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2214),
    [anon_sym_decltype] = ACTIONS(2214),
    [anon_sym_explicit] = ACTIONS(2214),
    [anon_sym_typename] = ACTIONS(2214),
    [anon_sym_template] = ACTIONS(2214),
    [anon_sym_operator] = ACTIONS(2214),
    [anon_sym_try] = ACTIONS(2214),
    [anon_sym_delete] = ACTIONS(2214),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_namespace] = ACTIONS(2214),
    [anon_sym_using] = ACTIONS(2214),
    [anon_sym_static_assert] = ACTIONS(2214),
    [anon_sym_concept] = ACTIONS(2214),
    [anon_sym_co_return] = ACTIONS(2214),
    [anon_sym_co_yield] = ACTIONS(2214),
    [anon_sym_R_DQUOTE] = ACTIONS(2216),
    [anon_sym_LR_DQUOTE] = ACTIONS(2216),
    [anon_sym_uR_DQUOTE] = ACTIONS(2216),
    [anon_sym_UR_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2216),
    [anon_sym_co_await] = ACTIONS(2214),
    [anon_sym_new] = ACTIONS(2214),
    [anon_sym_requires] = ACTIONS(2214),
    [sym_this] = ACTIONS(2214),
    [anon_sym___launch_bounds__] = ACTIONS(2214),
  },
  [STATE(449)] = {
    [ts_builtin_sym_end] = ACTIONS(2144),
    [sym_identifier] = ACTIONS(2142),
    [aux_sym_preproc_include_token1] = ACTIONS(2142),
    [aux_sym_preproc_def_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2142),
    [sym_preproc_directive] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym___device__] = ACTIONS(2142),
    [anon_sym___host__] = ACTIONS(2142),
    [anon_sym___global__] = ACTIONS(2142),
    [anon_sym___forceinline__] = ACTIONS(2142),
    [anon_sym___noinline__] = ACTIONS(2142),
    [anon_sym_virtual] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym___attribute] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym__Nonnull] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym___shared__] = ACTIONS(2142),
    [anon_sym___local__] = ACTIONS(2142),
    [anon_sym___constant__] = ACTIONS(2142),
    [anon_sym___managed__] = ACTIONS(2142),
    [anon_sym___grid_constant__] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_case] = ACTIONS(2142),
    [anon_sym_default] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [anon_sym___asm] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [anon_sym_explicit] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_namespace] = ACTIONS(2142),
    [anon_sym_using] = ACTIONS(2142),
    [anon_sym_static_assert] = ACTIONS(2142),
    [anon_sym_concept] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym___launch_bounds__] = ACTIONS(2142),
  },
  [STATE(450)] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_include_token1] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym___device__] = ACTIONS(2134),
    [anon_sym___host__] = ACTIONS(2134),
    [anon_sym___global__] = ACTIONS(2134),
    [anon_sym___forceinline__] = ACTIONS(2134),
    [anon_sym___noinline__] = ACTIONS(2134),
    [anon_sym_virtual] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym___attribute] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym___cdecl] = ACTIONS(2134),
    [anon_sym___clrcall] = ACTIONS(2134),
    [anon_sym___stdcall] = ACTIONS(2134),
    [anon_sym___fastcall] = ACTIONS(2134),
    [anon_sym___thiscall] = ACTIONS(2134),
    [anon_sym___vectorcall] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_RBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym__Nonnull] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym___shared__] = ACTIONS(2134),
    [anon_sym___local__] = ACTIONS(2134),
    [anon_sym___constant__] = ACTIONS(2134),
    [anon_sym___managed__] = ACTIONS(2134),
    [anon_sym___grid_constant__] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_case] = ACTIONS(2134),
    [anon_sym_default] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [anon_sym___asm] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_namespace] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_concept] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym___launch_bounds__] = ACTIONS(2134),
  },
  [STATE(451)] = {
    [ts_builtin_sym_end] = ACTIONS(2100),
    [sym_identifier] = ACTIONS(2098),
    [aux_sym_preproc_include_token1] = ACTIONS(2098),
    [aux_sym_preproc_def_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2098),
    [sym_preproc_directive] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP_AMP] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2098),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym___device__] = ACTIONS(2098),
    [anon_sym___host__] = ACTIONS(2098),
    [anon_sym___global__] = ACTIONS(2098),
    [anon_sym___forceinline__] = ACTIONS(2098),
    [anon_sym___noinline__] = ACTIONS(2098),
    [anon_sym_virtual] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym___attribute] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym___based] = ACTIONS(2098),
    [anon_sym___cdecl] = ACTIONS(2098),
    [anon_sym___clrcall] = ACTIONS(2098),
    [anon_sym___stdcall] = ACTIONS(2098),
    [anon_sym___fastcall] = ACTIONS(2098),
    [anon_sym___thiscall] = ACTIONS(2098),
    [anon_sym___vectorcall] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym__Nonnull] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym___shared__] = ACTIONS(2098),
    [anon_sym___local__] = ACTIONS(2098),
    [anon_sym___constant__] = ACTIONS(2098),
    [anon_sym___managed__] = ACTIONS(2098),
    [anon_sym___grid_constant__] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_case] = ACTIONS(2098),
    [anon_sym_default] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [anon_sym___asm] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [anon_sym_explicit] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_operator] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_namespace] = ACTIONS(2098),
    [anon_sym_using] = ACTIONS(2098),
    [anon_sym_static_assert] = ACTIONS(2098),
    [anon_sym_concept] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym___launch_bounds__] = ACTIONS(2098),
  },
  [STATE(452)] = {
    [sym_identifier] = ACTIONS(2028),
    [aux_sym_preproc_include_token1] = ACTIONS(2028),
    [aux_sym_preproc_def_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2028),
    [sym_preproc_directive] = ACTIONS(2028),
    [anon_sym_LPAREN2] = ACTIONS(2030),
    [anon_sym_BANG] = ACTIONS(2030),
    [anon_sym_TILDE] = ACTIONS(2030),
    [anon_sym_DASH] = ACTIONS(2028),
    [anon_sym_PLUS] = ACTIONS(2028),
    [anon_sym_STAR] = ACTIONS(2030),
    [anon_sym_AMP_AMP] = ACTIONS(2030),
    [anon_sym_AMP] = ACTIONS(2028),
    [anon_sym_SEMI] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(2028),
    [anon_sym_typedef] = ACTIONS(2028),
    [anon_sym___device__] = ACTIONS(2028),
    [anon_sym___host__] = ACTIONS(2028),
    [anon_sym___global__] = ACTIONS(2028),
    [anon_sym___forceinline__] = ACTIONS(2028),
    [anon_sym___noinline__] = ACTIONS(2028),
    [anon_sym_virtual] = ACTIONS(2028),
    [anon_sym_extern] = ACTIONS(2028),
    [anon_sym___attribute__] = ACTIONS(2028),
    [anon_sym___attribute] = ACTIONS(2028),
    [anon_sym_COLON_COLON] = ACTIONS(2030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2030),
    [anon_sym___declspec] = ACTIONS(2028),
    [anon_sym___based] = ACTIONS(2028),
    [anon_sym___cdecl] = ACTIONS(2028),
    [anon_sym___clrcall] = ACTIONS(2028),
    [anon_sym___stdcall] = ACTIONS(2028),
    [anon_sym___fastcall] = ACTIONS(2028),
    [anon_sym___thiscall] = ACTIONS(2028),
    [anon_sym___vectorcall] = ACTIONS(2028),
    [anon_sym_LBRACE] = ACTIONS(2030),
    [anon_sym_RBRACE] = ACTIONS(2030),
    [anon_sym_signed] = ACTIONS(2028),
    [anon_sym_unsigned] = ACTIONS(2028),
    [anon_sym_long] = ACTIONS(2028),
    [anon_sym_short] = ACTIONS(2028),
    [anon_sym_LBRACK] = ACTIONS(2028),
    [anon_sym_static] = ACTIONS(2028),
    [anon_sym_register] = ACTIONS(2028),
    [anon_sym_inline] = ACTIONS(2028),
    [anon_sym___inline] = ACTIONS(2028),
    [anon_sym___inline__] = ACTIONS(2028),
    [anon_sym___forceinline] = ACTIONS(2028),
    [anon_sym_thread_local] = ACTIONS(2028),
    [anon_sym___thread] = ACTIONS(2028),
    [anon_sym_const] = ACTIONS(2028),
    [anon_sym_constexpr] = ACTIONS(2028),
    [anon_sym_volatile] = ACTIONS(2028),
    [anon_sym_restrict] = ACTIONS(2028),
    [anon_sym___restrict__] = ACTIONS(2028),
    [anon_sym__Atomic] = ACTIONS(2028),
    [anon_sym__Noreturn] = ACTIONS(2028),
    [anon_sym_noreturn] = ACTIONS(2028),
    [anon_sym__Nonnull] = ACTIONS(2028),
    [anon_sym_mutable] = ACTIONS(2028),
    [anon_sym_constinit] = ACTIONS(2028),
    [anon_sym_consteval] = ACTIONS(2028),
    [anon_sym___shared__] = ACTIONS(2028),
    [anon_sym___local__] = ACTIONS(2028),
    [anon_sym___constant__] = ACTIONS(2028),
    [anon_sym___managed__] = ACTIONS(2028),
    [anon_sym___grid_constant__] = ACTIONS(2028),
    [anon_sym_alignas] = ACTIONS(2028),
    [anon_sym__Alignas] = ACTIONS(2028),
    [sym_primitive_type] = ACTIONS(2028),
    [anon_sym_enum] = ACTIONS(2028),
    [anon_sym_class] = ACTIONS(2028),
    [anon_sym_struct] = ACTIONS(2028),
    [anon_sym_union] = ACTIONS(2028),
    [anon_sym_if] = ACTIONS(2028),
    [anon_sym_else] = ACTIONS(2028),
    [anon_sym_switch] = ACTIONS(2028),
    [anon_sym_case] = ACTIONS(2028),
    [anon_sym_default] = ACTIONS(2028),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_do] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2028),
    [anon_sym_return] = ACTIONS(2028),
    [anon_sym_break] = ACTIONS(2028),
    [anon_sym_continue] = ACTIONS(2028),
    [anon_sym_goto] = ACTIONS(2028),
    [anon_sym___try] = ACTIONS(2028),
    [anon_sym___leave] = ACTIONS(2028),
    [anon_sym_not] = ACTIONS(2028),
    [anon_sym_compl] = ACTIONS(2028),
    [anon_sym_DASH_DASH] = ACTIONS(2030),
    [anon_sym_PLUS_PLUS] = ACTIONS(2030),
    [anon_sym_sizeof] = ACTIONS(2028),
    [anon_sym___alignof__] = ACTIONS(2028),
    [anon_sym___alignof] = ACTIONS(2028),
    [anon_sym__alignof] = ACTIONS(2028),
    [anon_sym_alignof] = ACTIONS(2028),
    [anon_sym__Alignof] = ACTIONS(2028),
    [anon_sym_offsetof] = ACTIONS(2028),
    [anon_sym__Generic] = ACTIONS(2028),
    [anon_sym_asm] = ACTIONS(2028),
    [anon_sym___asm__] = ACTIONS(2028),
    [anon_sym___asm] = ACTIONS(2028),
    [sym_number_literal] = ACTIONS(2030),
    [anon_sym_L_SQUOTE] = ACTIONS(2030),
    [anon_sym_u_SQUOTE] = ACTIONS(2030),
    [anon_sym_U_SQUOTE] = ACTIONS(2030),
    [anon_sym_u8_SQUOTE] = ACTIONS(2030),
    [anon_sym_SQUOTE] = ACTIONS(2030),
    [anon_sym_L_DQUOTE] = ACTIONS(2030),
    [anon_sym_u_DQUOTE] = ACTIONS(2030),
    [anon_sym_U_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8_DQUOTE] = ACTIONS(2030),
    [anon_sym_DQUOTE] = ACTIONS(2030),
    [sym_true] = ACTIONS(2028),
    [sym_false] = ACTIONS(2028),
    [anon_sym_NULL] = ACTIONS(2028),
    [anon_sym_nullptr] = ACTIONS(2028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2028),
    [anon_sym_decltype] = ACTIONS(2028),
    [anon_sym_explicit] = ACTIONS(2028),
    [anon_sym_typename] = ACTIONS(2028),
    [anon_sym_template] = ACTIONS(2028),
    [anon_sym_operator] = ACTIONS(2028),
    [anon_sym_try] = ACTIONS(2028),
    [anon_sym_delete] = ACTIONS(2028),
    [anon_sym_throw] = ACTIONS(2028),
    [anon_sym_namespace] = ACTIONS(2028),
    [anon_sym_using] = ACTIONS(2028),
    [anon_sym_static_assert] = ACTIONS(2028),
    [anon_sym_concept] = ACTIONS(2028),
    [anon_sym_co_return] = ACTIONS(2028),
    [anon_sym_co_yield] = ACTIONS(2028),
    [anon_sym_R_DQUOTE] = ACTIONS(2030),
    [anon_sym_LR_DQUOTE] = ACTIONS(2030),
    [anon_sym_uR_DQUOTE] = ACTIONS(2030),
    [anon_sym_UR_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2030),
    [anon_sym_co_await] = ACTIONS(2028),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_requires] = ACTIONS(2028),
    [sym_this] = ACTIONS(2028),
    [anon_sym___launch_bounds__] = ACTIONS(2028),
  },
  [STATE(453)] = {
    [ts_builtin_sym_end] = ACTIONS(2038),
    [sym_identifier] = ACTIONS(2036),
    [aux_sym_preproc_include_token1] = ACTIONS(2036),
    [aux_sym_preproc_def_token1] = ACTIONS(2036),
    [aux_sym_preproc_if_token1] = ACTIONS(2036),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2036),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2036),
    [sym_preproc_directive] = ACTIONS(2036),
    [anon_sym_LPAREN2] = ACTIONS(2038),
    [anon_sym_BANG] = ACTIONS(2038),
    [anon_sym_TILDE] = ACTIONS(2038),
    [anon_sym_DASH] = ACTIONS(2036),
    [anon_sym_PLUS] = ACTIONS(2036),
    [anon_sym_STAR] = ACTIONS(2038),
    [anon_sym_AMP_AMP] = ACTIONS(2038),
    [anon_sym_AMP] = ACTIONS(2036),
    [anon_sym_SEMI] = ACTIONS(2038),
    [anon_sym___extension__] = ACTIONS(2036),
    [anon_sym_typedef] = ACTIONS(2036),
    [anon_sym___device__] = ACTIONS(2036),
    [anon_sym___host__] = ACTIONS(2036),
    [anon_sym___global__] = ACTIONS(2036),
    [anon_sym___forceinline__] = ACTIONS(2036),
    [anon_sym___noinline__] = ACTIONS(2036),
    [anon_sym_virtual] = ACTIONS(2036),
    [anon_sym_extern] = ACTIONS(2036),
    [anon_sym___attribute__] = ACTIONS(2036),
    [anon_sym___attribute] = ACTIONS(2036),
    [anon_sym_COLON_COLON] = ACTIONS(2038),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2038),
    [anon_sym___declspec] = ACTIONS(2036),
    [anon_sym___based] = ACTIONS(2036),
    [anon_sym___cdecl] = ACTIONS(2036),
    [anon_sym___clrcall] = ACTIONS(2036),
    [anon_sym___stdcall] = ACTIONS(2036),
    [anon_sym___fastcall] = ACTIONS(2036),
    [anon_sym___thiscall] = ACTIONS(2036),
    [anon_sym___vectorcall] = ACTIONS(2036),
    [anon_sym_LBRACE] = ACTIONS(2038),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(2036),
    [anon_sym_static] = ACTIONS(2036),
    [anon_sym_register] = ACTIONS(2036),
    [anon_sym_inline] = ACTIONS(2036),
    [anon_sym___inline] = ACTIONS(2036),
    [anon_sym___inline__] = ACTIONS(2036),
    [anon_sym___forceinline] = ACTIONS(2036),
    [anon_sym_thread_local] = ACTIONS(2036),
    [anon_sym___thread] = ACTIONS(2036),
    [anon_sym_const] = ACTIONS(2036),
    [anon_sym_constexpr] = ACTIONS(2036),
    [anon_sym_volatile] = ACTIONS(2036),
    [anon_sym_restrict] = ACTIONS(2036),
    [anon_sym___restrict__] = ACTIONS(2036),
    [anon_sym__Atomic] = ACTIONS(2036),
    [anon_sym__Noreturn] = ACTIONS(2036),
    [anon_sym_noreturn] = ACTIONS(2036),
    [anon_sym__Nonnull] = ACTIONS(2036),
    [anon_sym_mutable] = ACTIONS(2036),
    [anon_sym_constinit] = ACTIONS(2036),
    [anon_sym_consteval] = ACTIONS(2036),
    [anon_sym___shared__] = ACTIONS(2036),
    [anon_sym___local__] = ACTIONS(2036),
    [anon_sym___constant__] = ACTIONS(2036),
    [anon_sym___managed__] = ACTIONS(2036),
    [anon_sym___grid_constant__] = ACTIONS(2036),
    [anon_sym_alignas] = ACTIONS(2036),
    [anon_sym__Alignas] = ACTIONS(2036),
    [sym_primitive_type] = ACTIONS(2036),
    [anon_sym_enum] = ACTIONS(2036),
    [anon_sym_class] = ACTIONS(2036),
    [anon_sym_struct] = ACTIONS(2036),
    [anon_sym_union] = ACTIONS(2036),
    [anon_sym_if] = ACTIONS(2036),
    [anon_sym_else] = ACTIONS(2036),
    [anon_sym_switch] = ACTIONS(2036),
    [anon_sym_case] = ACTIONS(2036),
    [anon_sym_default] = ACTIONS(2036),
    [anon_sym_while] = ACTIONS(2036),
    [anon_sym_do] = ACTIONS(2036),
    [anon_sym_for] = ACTIONS(2036),
    [anon_sym_return] = ACTIONS(2036),
    [anon_sym_break] = ACTIONS(2036),
    [anon_sym_continue] = ACTIONS(2036),
    [anon_sym_goto] = ACTIONS(2036),
    [anon_sym___try] = ACTIONS(2036),
    [anon_sym___leave] = ACTIONS(2036),
    [anon_sym_not] = ACTIONS(2036),
    [anon_sym_compl] = ACTIONS(2036),
    [anon_sym_DASH_DASH] = ACTIONS(2038),
    [anon_sym_PLUS_PLUS] = ACTIONS(2038),
    [anon_sym_sizeof] = ACTIONS(2036),
    [anon_sym___alignof__] = ACTIONS(2036),
    [anon_sym___alignof] = ACTIONS(2036),
    [anon_sym__alignof] = ACTIONS(2036),
    [anon_sym_alignof] = ACTIONS(2036),
    [anon_sym__Alignof] = ACTIONS(2036),
    [anon_sym_offsetof] = ACTIONS(2036),
    [anon_sym__Generic] = ACTIONS(2036),
    [anon_sym_asm] = ACTIONS(2036),
    [anon_sym___asm__] = ACTIONS(2036),
    [anon_sym___asm] = ACTIONS(2036),
    [sym_number_literal] = ACTIONS(2038),
    [anon_sym_L_SQUOTE] = ACTIONS(2038),
    [anon_sym_u_SQUOTE] = ACTIONS(2038),
    [anon_sym_U_SQUOTE] = ACTIONS(2038),
    [anon_sym_u8_SQUOTE] = ACTIONS(2038),
    [anon_sym_SQUOTE] = ACTIONS(2038),
    [anon_sym_L_DQUOTE] = ACTIONS(2038),
    [anon_sym_u_DQUOTE] = ACTIONS(2038),
    [anon_sym_U_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8_DQUOTE] = ACTIONS(2038),
    [anon_sym_DQUOTE] = ACTIONS(2038),
    [sym_true] = ACTIONS(2036),
    [sym_false] = ACTIONS(2036),
    [anon_sym_NULL] = ACTIONS(2036),
    [anon_sym_nullptr] = ACTIONS(2036),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2036),
    [anon_sym_decltype] = ACTIONS(2036),
    [anon_sym_explicit] = ACTIONS(2036),
    [anon_sym_typename] = ACTIONS(2036),
    [anon_sym_template] = ACTIONS(2036),
    [anon_sym_operator] = ACTIONS(2036),
    [anon_sym_try] = ACTIONS(2036),
    [anon_sym_delete] = ACTIONS(2036),
    [anon_sym_throw] = ACTIONS(2036),
    [anon_sym_namespace] = ACTIONS(2036),
    [anon_sym_using] = ACTIONS(2036),
    [anon_sym_static_assert] = ACTIONS(2036),
    [anon_sym_concept] = ACTIONS(2036),
    [anon_sym_co_return] = ACTIONS(2036),
    [anon_sym_co_yield] = ACTIONS(2036),
    [anon_sym_R_DQUOTE] = ACTIONS(2038),
    [anon_sym_LR_DQUOTE] = ACTIONS(2038),
    [anon_sym_uR_DQUOTE] = ACTIONS(2038),
    [anon_sym_UR_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2038),
    [anon_sym_co_await] = ACTIONS(2036),
    [anon_sym_new] = ACTIONS(2036),
    [anon_sym_requires] = ACTIONS(2036),
    [sym_this] = ACTIONS(2036),
    [anon_sym___launch_bounds__] = ACTIONS(2036),
  },
  [STATE(454)] = {
    [ts_builtin_sym_end] = ACTIONS(2172),
    [sym_identifier] = ACTIONS(2170),
    [aux_sym_preproc_include_token1] = ACTIONS(2170),
    [aux_sym_preproc_def_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2170),
    [sym_preproc_directive] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP_AMP] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2170),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym___device__] = ACTIONS(2170),
    [anon_sym___host__] = ACTIONS(2170),
    [anon_sym___global__] = ACTIONS(2170),
    [anon_sym___forceinline__] = ACTIONS(2170),
    [anon_sym___noinline__] = ACTIONS(2170),
    [anon_sym_virtual] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym___attribute] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym___based] = ACTIONS(2170),
    [anon_sym___cdecl] = ACTIONS(2170),
    [anon_sym___clrcall] = ACTIONS(2170),
    [anon_sym___stdcall] = ACTIONS(2170),
    [anon_sym___fastcall] = ACTIONS(2170),
    [anon_sym___thiscall] = ACTIONS(2170),
    [anon_sym___vectorcall] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym__Nonnull] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym___shared__] = ACTIONS(2170),
    [anon_sym___local__] = ACTIONS(2170),
    [anon_sym___constant__] = ACTIONS(2170),
    [anon_sym___managed__] = ACTIONS(2170),
    [anon_sym___grid_constant__] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_case] = ACTIONS(2170),
    [anon_sym_default] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [anon_sym___asm] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [anon_sym_explicit] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_operator] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_namespace] = ACTIONS(2170),
    [anon_sym_using] = ACTIONS(2170),
    [anon_sym_static_assert] = ACTIONS(2170),
    [anon_sym_concept] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym___launch_bounds__] = ACTIONS(2170),
  },
  [STATE(455)] = {
    [ts_builtin_sym_end] = ACTIONS(2176),
    [sym_identifier] = ACTIONS(2174),
    [aux_sym_preproc_include_token1] = ACTIONS(2174),
    [aux_sym_preproc_def_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2174),
    [sym_preproc_directive] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP_AMP] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2174),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym___device__] = ACTIONS(2174),
    [anon_sym___host__] = ACTIONS(2174),
    [anon_sym___global__] = ACTIONS(2174),
    [anon_sym___forceinline__] = ACTIONS(2174),
    [anon_sym___noinline__] = ACTIONS(2174),
    [anon_sym_virtual] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym___attribute] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym___based] = ACTIONS(2174),
    [anon_sym___cdecl] = ACTIONS(2174),
    [anon_sym___clrcall] = ACTIONS(2174),
    [anon_sym___stdcall] = ACTIONS(2174),
    [anon_sym___fastcall] = ACTIONS(2174),
    [anon_sym___thiscall] = ACTIONS(2174),
    [anon_sym___vectorcall] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym__Nonnull] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym___shared__] = ACTIONS(2174),
    [anon_sym___local__] = ACTIONS(2174),
    [anon_sym___constant__] = ACTIONS(2174),
    [anon_sym___managed__] = ACTIONS(2174),
    [anon_sym___grid_constant__] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_case] = ACTIONS(2174),
    [anon_sym_default] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [anon_sym___asm] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [anon_sym_explicit] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_operator] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_namespace] = ACTIONS(2174),
    [anon_sym_using] = ACTIONS(2174),
    [anon_sym_static_assert] = ACTIONS(2174),
    [anon_sym_concept] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym___launch_bounds__] = ACTIONS(2174),
  },
  [STATE(456)] = {
    [ts_builtin_sym_end] = ACTIONS(2180),
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(457)] = {
    [ts_builtin_sym_end] = ACTIONS(2180),
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(458)] = {
    [ts_builtin_sym_end] = ACTIONS(2148),
    [sym_identifier] = ACTIONS(2146),
    [aux_sym_preproc_include_token1] = ACTIONS(2146),
    [aux_sym_preproc_def_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2146),
    [sym_preproc_directive] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP_AMP] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2146),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym___device__] = ACTIONS(2146),
    [anon_sym___host__] = ACTIONS(2146),
    [anon_sym___global__] = ACTIONS(2146),
    [anon_sym___forceinline__] = ACTIONS(2146),
    [anon_sym___noinline__] = ACTIONS(2146),
    [anon_sym_virtual] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym___attribute] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym___based] = ACTIONS(2146),
    [anon_sym___cdecl] = ACTIONS(2146),
    [anon_sym___clrcall] = ACTIONS(2146),
    [anon_sym___stdcall] = ACTIONS(2146),
    [anon_sym___fastcall] = ACTIONS(2146),
    [anon_sym___thiscall] = ACTIONS(2146),
    [anon_sym___vectorcall] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym__Nonnull] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym___shared__] = ACTIONS(2146),
    [anon_sym___local__] = ACTIONS(2146),
    [anon_sym___constant__] = ACTIONS(2146),
    [anon_sym___managed__] = ACTIONS(2146),
    [anon_sym___grid_constant__] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_case] = ACTIONS(2146),
    [anon_sym_default] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [anon_sym___asm] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [anon_sym_explicit] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_operator] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_namespace] = ACTIONS(2146),
    [anon_sym_using] = ACTIONS(2146),
    [anon_sym_static_assert] = ACTIONS(2146),
    [anon_sym_concept] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym___launch_bounds__] = ACTIONS(2146),
  },
  [STATE(459)] = {
    [ts_builtin_sym_end] = ACTIONS(2034),
    [sym_identifier] = ACTIONS(2032),
    [aux_sym_preproc_include_token1] = ACTIONS(2032),
    [aux_sym_preproc_def_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2032),
    [sym_preproc_directive] = ACTIONS(2032),
    [anon_sym_LPAREN2] = ACTIONS(2034),
    [anon_sym_BANG] = ACTIONS(2034),
    [anon_sym_TILDE] = ACTIONS(2034),
    [anon_sym_DASH] = ACTIONS(2032),
    [anon_sym_PLUS] = ACTIONS(2032),
    [anon_sym_STAR] = ACTIONS(2034),
    [anon_sym_AMP_AMP] = ACTIONS(2034),
    [anon_sym_AMP] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(2034),
    [anon_sym___extension__] = ACTIONS(2032),
    [anon_sym_typedef] = ACTIONS(2032),
    [anon_sym___device__] = ACTIONS(2032),
    [anon_sym___host__] = ACTIONS(2032),
    [anon_sym___global__] = ACTIONS(2032),
    [anon_sym___forceinline__] = ACTIONS(2032),
    [anon_sym___noinline__] = ACTIONS(2032),
    [anon_sym_virtual] = ACTIONS(2032),
    [anon_sym_extern] = ACTIONS(2032),
    [anon_sym___attribute__] = ACTIONS(2032),
    [anon_sym___attribute] = ACTIONS(2032),
    [anon_sym_COLON_COLON] = ACTIONS(2034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2034),
    [anon_sym___declspec] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(2032),
    [anon_sym___cdecl] = ACTIONS(2032),
    [anon_sym___clrcall] = ACTIONS(2032),
    [anon_sym___stdcall] = ACTIONS(2032),
    [anon_sym___fastcall] = ACTIONS(2032),
    [anon_sym___thiscall] = ACTIONS(2032),
    [anon_sym___vectorcall] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2032),
    [anon_sym_unsigned] = ACTIONS(2032),
    [anon_sym_long] = ACTIONS(2032),
    [anon_sym_short] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(2032),
    [anon_sym_static] = ACTIONS(2032),
    [anon_sym_register] = ACTIONS(2032),
    [anon_sym_inline] = ACTIONS(2032),
    [anon_sym___inline] = ACTIONS(2032),
    [anon_sym___inline__] = ACTIONS(2032),
    [anon_sym___forceinline] = ACTIONS(2032),
    [anon_sym_thread_local] = ACTIONS(2032),
    [anon_sym___thread] = ACTIONS(2032),
    [anon_sym_const] = ACTIONS(2032),
    [anon_sym_constexpr] = ACTIONS(2032),
    [anon_sym_volatile] = ACTIONS(2032),
    [anon_sym_restrict] = ACTIONS(2032),
    [anon_sym___restrict__] = ACTIONS(2032),
    [anon_sym__Atomic] = ACTIONS(2032),
    [anon_sym__Noreturn] = ACTIONS(2032),
    [anon_sym_noreturn] = ACTIONS(2032),
    [anon_sym__Nonnull] = ACTIONS(2032),
    [anon_sym_mutable] = ACTIONS(2032),
    [anon_sym_constinit] = ACTIONS(2032),
    [anon_sym_consteval] = ACTIONS(2032),
    [anon_sym___shared__] = ACTIONS(2032),
    [anon_sym___local__] = ACTIONS(2032),
    [anon_sym___constant__] = ACTIONS(2032),
    [anon_sym___managed__] = ACTIONS(2032),
    [anon_sym___grid_constant__] = ACTIONS(2032),
    [anon_sym_alignas] = ACTIONS(2032),
    [anon_sym__Alignas] = ACTIONS(2032),
    [sym_primitive_type] = ACTIONS(2032),
    [anon_sym_enum] = ACTIONS(2032),
    [anon_sym_class] = ACTIONS(2032),
    [anon_sym_struct] = ACTIONS(2032),
    [anon_sym_union] = ACTIONS(2032),
    [anon_sym_if] = ACTIONS(2032),
    [anon_sym_else] = ACTIONS(2032),
    [anon_sym_switch] = ACTIONS(2032),
    [anon_sym_case] = ACTIONS(2032),
    [anon_sym_default] = ACTIONS(2032),
    [anon_sym_while] = ACTIONS(2032),
    [anon_sym_do] = ACTIONS(2032),
    [anon_sym_for] = ACTIONS(2032),
    [anon_sym_return] = ACTIONS(2032),
    [anon_sym_break] = ACTIONS(2032),
    [anon_sym_continue] = ACTIONS(2032),
    [anon_sym_goto] = ACTIONS(2032),
    [anon_sym___try] = ACTIONS(2032),
    [anon_sym___leave] = ACTIONS(2032),
    [anon_sym_not] = ACTIONS(2032),
    [anon_sym_compl] = ACTIONS(2032),
    [anon_sym_DASH_DASH] = ACTIONS(2034),
    [anon_sym_PLUS_PLUS] = ACTIONS(2034),
    [anon_sym_sizeof] = ACTIONS(2032),
    [anon_sym___alignof__] = ACTIONS(2032),
    [anon_sym___alignof] = ACTIONS(2032),
    [anon_sym__alignof] = ACTIONS(2032),
    [anon_sym_alignof] = ACTIONS(2032),
    [anon_sym__Alignof] = ACTIONS(2032),
    [anon_sym_offsetof] = ACTIONS(2032),
    [anon_sym__Generic] = ACTIONS(2032),
    [anon_sym_asm] = ACTIONS(2032),
    [anon_sym___asm__] = ACTIONS(2032),
    [anon_sym___asm] = ACTIONS(2032),
    [sym_number_literal] = ACTIONS(2034),
    [anon_sym_L_SQUOTE] = ACTIONS(2034),
    [anon_sym_u_SQUOTE] = ACTIONS(2034),
    [anon_sym_U_SQUOTE] = ACTIONS(2034),
    [anon_sym_u8_SQUOTE] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2034),
    [anon_sym_L_DQUOTE] = ACTIONS(2034),
    [anon_sym_u_DQUOTE] = ACTIONS(2034),
    [anon_sym_U_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8_DQUOTE] = ACTIONS(2034),
    [anon_sym_DQUOTE] = ACTIONS(2034),
    [sym_true] = ACTIONS(2032),
    [sym_false] = ACTIONS(2032),
    [anon_sym_NULL] = ACTIONS(2032),
    [anon_sym_nullptr] = ACTIONS(2032),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2032),
    [anon_sym_decltype] = ACTIONS(2032),
    [anon_sym_explicit] = ACTIONS(2032),
    [anon_sym_typename] = ACTIONS(2032),
    [anon_sym_template] = ACTIONS(2032),
    [anon_sym_operator] = ACTIONS(2032),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_delete] = ACTIONS(2032),
    [anon_sym_throw] = ACTIONS(2032),
    [anon_sym_namespace] = ACTIONS(2032),
    [anon_sym_using] = ACTIONS(2032),
    [anon_sym_static_assert] = ACTIONS(2032),
    [anon_sym_concept] = ACTIONS(2032),
    [anon_sym_co_return] = ACTIONS(2032),
    [anon_sym_co_yield] = ACTIONS(2032),
    [anon_sym_R_DQUOTE] = ACTIONS(2034),
    [anon_sym_LR_DQUOTE] = ACTIONS(2034),
    [anon_sym_uR_DQUOTE] = ACTIONS(2034),
    [anon_sym_UR_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2034),
    [anon_sym_co_await] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(2032),
    [anon_sym_requires] = ACTIONS(2032),
    [sym_this] = ACTIONS(2032),
    [anon_sym___launch_bounds__] = ACTIONS(2032),
  },
  [STATE(460)] = {
    [sym_identifier] = ACTIONS(2040),
    [aux_sym_preproc_include_token1] = ACTIONS(2040),
    [aux_sym_preproc_def_token1] = ACTIONS(2040),
    [aux_sym_preproc_if_token1] = ACTIONS(2040),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2040),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2040),
    [sym_preproc_directive] = ACTIONS(2040),
    [anon_sym_LPAREN2] = ACTIONS(2042),
    [anon_sym_BANG] = ACTIONS(2042),
    [anon_sym_TILDE] = ACTIONS(2042),
    [anon_sym_DASH] = ACTIONS(2040),
    [anon_sym_PLUS] = ACTIONS(2040),
    [anon_sym_STAR] = ACTIONS(2042),
    [anon_sym_AMP_AMP] = ACTIONS(2042),
    [anon_sym_AMP] = ACTIONS(2040),
    [anon_sym_SEMI] = ACTIONS(2042),
    [anon_sym___extension__] = ACTIONS(2040),
    [anon_sym_typedef] = ACTIONS(2040),
    [anon_sym___device__] = ACTIONS(2040),
    [anon_sym___host__] = ACTIONS(2040),
    [anon_sym___global__] = ACTIONS(2040),
    [anon_sym___forceinline__] = ACTIONS(2040),
    [anon_sym___noinline__] = ACTIONS(2040),
    [anon_sym_virtual] = ACTIONS(2040),
    [anon_sym_extern] = ACTIONS(2040),
    [anon_sym___attribute__] = ACTIONS(2040),
    [anon_sym___attribute] = ACTIONS(2040),
    [anon_sym_COLON_COLON] = ACTIONS(2042),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2042),
    [anon_sym___declspec] = ACTIONS(2040),
    [anon_sym___based] = ACTIONS(2040),
    [anon_sym___cdecl] = ACTIONS(2040),
    [anon_sym___clrcall] = ACTIONS(2040),
    [anon_sym___stdcall] = ACTIONS(2040),
    [anon_sym___fastcall] = ACTIONS(2040),
    [anon_sym___thiscall] = ACTIONS(2040),
    [anon_sym___vectorcall] = ACTIONS(2040),
    [anon_sym_LBRACE] = ACTIONS(2042),
    [anon_sym_RBRACE] = ACTIONS(2042),
    [anon_sym_signed] = ACTIONS(2040),
    [anon_sym_unsigned] = ACTIONS(2040),
    [anon_sym_long] = ACTIONS(2040),
    [anon_sym_short] = ACTIONS(2040),
    [anon_sym_LBRACK] = ACTIONS(2040),
    [anon_sym_static] = ACTIONS(2040),
    [anon_sym_register] = ACTIONS(2040),
    [anon_sym_inline] = ACTIONS(2040),
    [anon_sym___inline] = ACTIONS(2040),
    [anon_sym___inline__] = ACTIONS(2040),
    [anon_sym___forceinline] = ACTIONS(2040),
    [anon_sym_thread_local] = ACTIONS(2040),
    [anon_sym___thread] = ACTIONS(2040),
    [anon_sym_const] = ACTIONS(2040),
    [anon_sym_constexpr] = ACTIONS(2040),
    [anon_sym_volatile] = ACTIONS(2040),
    [anon_sym_restrict] = ACTIONS(2040),
    [anon_sym___restrict__] = ACTIONS(2040),
    [anon_sym__Atomic] = ACTIONS(2040),
    [anon_sym__Noreturn] = ACTIONS(2040),
    [anon_sym_noreturn] = ACTIONS(2040),
    [anon_sym__Nonnull] = ACTIONS(2040),
    [anon_sym_mutable] = ACTIONS(2040),
    [anon_sym_constinit] = ACTIONS(2040),
    [anon_sym_consteval] = ACTIONS(2040),
    [anon_sym___shared__] = ACTIONS(2040),
    [anon_sym___local__] = ACTIONS(2040),
    [anon_sym___constant__] = ACTIONS(2040),
    [anon_sym___managed__] = ACTIONS(2040),
    [anon_sym___grid_constant__] = ACTIONS(2040),
    [anon_sym_alignas] = ACTIONS(2040),
    [anon_sym__Alignas] = ACTIONS(2040),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2040),
    [anon_sym_class] = ACTIONS(2040),
    [anon_sym_struct] = ACTIONS(2040),
    [anon_sym_union] = ACTIONS(2040),
    [anon_sym_if] = ACTIONS(2040),
    [anon_sym_else] = ACTIONS(2040),
    [anon_sym_switch] = ACTIONS(2040),
    [anon_sym_case] = ACTIONS(2040),
    [anon_sym_default] = ACTIONS(2040),
    [anon_sym_while] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(2040),
    [anon_sym_for] = ACTIONS(2040),
    [anon_sym_return] = ACTIONS(2040),
    [anon_sym_break] = ACTIONS(2040),
    [anon_sym_continue] = ACTIONS(2040),
    [anon_sym_goto] = ACTIONS(2040),
    [anon_sym___try] = ACTIONS(2040),
    [anon_sym___leave] = ACTIONS(2040),
    [anon_sym_not] = ACTIONS(2040),
    [anon_sym_compl] = ACTIONS(2040),
    [anon_sym_DASH_DASH] = ACTIONS(2042),
    [anon_sym_PLUS_PLUS] = ACTIONS(2042),
    [anon_sym_sizeof] = ACTIONS(2040),
    [anon_sym___alignof__] = ACTIONS(2040),
    [anon_sym___alignof] = ACTIONS(2040),
    [anon_sym__alignof] = ACTIONS(2040),
    [anon_sym_alignof] = ACTIONS(2040),
    [anon_sym__Alignof] = ACTIONS(2040),
    [anon_sym_offsetof] = ACTIONS(2040),
    [anon_sym__Generic] = ACTIONS(2040),
    [anon_sym_asm] = ACTIONS(2040),
    [anon_sym___asm__] = ACTIONS(2040),
    [anon_sym___asm] = ACTIONS(2040),
    [sym_number_literal] = ACTIONS(2042),
    [anon_sym_L_SQUOTE] = ACTIONS(2042),
    [anon_sym_u_SQUOTE] = ACTIONS(2042),
    [anon_sym_U_SQUOTE] = ACTIONS(2042),
    [anon_sym_u8_SQUOTE] = ACTIONS(2042),
    [anon_sym_SQUOTE] = ACTIONS(2042),
    [anon_sym_L_DQUOTE] = ACTIONS(2042),
    [anon_sym_u_DQUOTE] = ACTIONS(2042),
    [anon_sym_U_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8_DQUOTE] = ACTIONS(2042),
    [anon_sym_DQUOTE] = ACTIONS(2042),
    [sym_true] = ACTIONS(2040),
    [sym_false] = ACTIONS(2040),
    [anon_sym_NULL] = ACTIONS(2040),
    [anon_sym_nullptr] = ACTIONS(2040),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2040),
    [anon_sym_decltype] = ACTIONS(2040),
    [anon_sym_explicit] = ACTIONS(2040),
    [anon_sym_typename] = ACTIONS(2040),
    [anon_sym_template] = ACTIONS(2040),
    [anon_sym_operator] = ACTIONS(2040),
    [anon_sym_try] = ACTIONS(2040),
    [anon_sym_delete] = ACTIONS(2040),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_namespace] = ACTIONS(2040),
    [anon_sym_using] = ACTIONS(2040),
    [anon_sym_static_assert] = ACTIONS(2040),
    [anon_sym_concept] = ACTIONS(2040),
    [anon_sym_co_return] = ACTIONS(2040),
    [anon_sym_co_yield] = ACTIONS(2040),
    [anon_sym_R_DQUOTE] = ACTIONS(2042),
    [anon_sym_LR_DQUOTE] = ACTIONS(2042),
    [anon_sym_uR_DQUOTE] = ACTIONS(2042),
    [anon_sym_UR_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2042),
    [anon_sym_co_await] = ACTIONS(2040),
    [anon_sym_new] = ACTIONS(2040),
    [anon_sym_requires] = ACTIONS(2040),
    [sym_this] = ACTIONS(2040),
    [anon_sym___launch_bounds__] = ACTIONS(2040),
  },
  [STATE(461)] = {
    [ts_builtin_sym_end] = ACTIONS(2164),
    [sym_identifier] = ACTIONS(2162),
    [aux_sym_preproc_include_token1] = ACTIONS(2162),
    [aux_sym_preproc_def_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2162),
    [sym_preproc_directive] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP_AMP] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2162),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym___device__] = ACTIONS(2162),
    [anon_sym___host__] = ACTIONS(2162),
    [anon_sym___global__] = ACTIONS(2162),
    [anon_sym___forceinline__] = ACTIONS(2162),
    [anon_sym___noinline__] = ACTIONS(2162),
    [anon_sym_virtual] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym___attribute] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym___based] = ACTIONS(2162),
    [anon_sym___cdecl] = ACTIONS(2162),
    [anon_sym___clrcall] = ACTIONS(2162),
    [anon_sym___stdcall] = ACTIONS(2162),
    [anon_sym___fastcall] = ACTIONS(2162),
    [anon_sym___thiscall] = ACTIONS(2162),
    [anon_sym___vectorcall] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym__Nonnull] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym___shared__] = ACTIONS(2162),
    [anon_sym___local__] = ACTIONS(2162),
    [anon_sym___constant__] = ACTIONS(2162),
    [anon_sym___managed__] = ACTIONS(2162),
    [anon_sym___grid_constant__] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_case] = ACTIONS(2162),
    [anon_sym_default] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [anon_sym___asm] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [anon_sym_explicit] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_operator] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_namespace] = ACTIONS(2162),
    [anon_sym_using] = ACTIONS(2162),
    [anon_sym_static_assert] = ACTIONS(2162),
    [anon_sym_concept] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym___launch_bounds__] = ACTIONS(2162),
  },
  [STATE(462)] = {
    [sym_identifier] = ACTIONS(2489),
    [aux_sym_preproc_include_token1] = ACTIONS(2489),
    [aux_sym_preproc_def_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token2] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2489),
    [sym_preproc_directive] = ACTIONS(2489),
    [anon_sym_LPAREN2] = ACTIONS(2491),
    [anon_sym_BANG] = ACTIONS(2491),
    [anon_sym_TILDE] = ACTIONS(2491),
    [anon_sym_DASH] = ACTIONS(2489),
    [anon_sym_PLUS] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(2491),
    [anon_sym_AMP_AMP] = ACTIONS(2491),
    [anon_sym_AMP] = ACTIONS(2489),
    [anon_sym_SEMI] = ACTIONS(2491),
    [anon_sym___extension__] = ACTIONS(2489),
    [anon_sym_typedef] = ACTIONS(2489),
    [anon_sym___device__] = ACTIONS(2489),
    [anon_sym___host__] = ACTIONS(2489),
    [anon_sym___global__] = ACTIONS(2489),
    [anon_sym___forceinline__] = ACTIONS(2489),
    [anon_sym___noinline__] = ACTIONS(2489),
    [anon_sym_virtual] = ACTIONS(2489),
    [anon_sym_extern] = ACTIONS(2489),
    [anon_sym___attribute__] = ACTIONS(2489),
    [anon_sym___attribute] = ACTIONS(2489),
    [anon_sym_COLON_COLON] = ACTIONS(2491),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2491),
    [anon_sym___declspec] = ACTIONS(2489),
    [anon_sym___based] = ACTIONS(2489),
    [anon_sym___cdecl] = ACTIONS(2489),
    [anon_sym___clrcall] = ACTIONS(2489),
    [anon_sym___stdcall] = ACTIONS(2489),
    [anon_sym___fastcall] = ACTIONS(2489),
    [anon_sym___thiscall] = ACTIONS(2489),
    [anon_sym___vectorcall] = ACTIONS(2489),
    [anon_sym_LBRACE] = ACTIONS(2491),
    [anon_sym_signed] = ACTIONS(2489),
    [anon_sym_unsigned] = ACTIONS(2489),
    [anon_sym_long] = ACTIONS(2489),
    [anon_sym_short] = ACTIONS(2489),
    [anon_sym_LBRACK] = ACTIONS(2489),
    [anon_sym_static] = ACTIONS(2489),
    [anon_sym_register] = ACTIONS(2489),
    [anon_sym_inline] = ACTIONS(2489),
    [anon_sym___inline] = ACTIONS(2489),
    [anon_sym___inline__] = ACTIONS(2489),
    [anon_sym___forceinline] = ACTIONS(2489),
    [anon_sym_thread_local] = ACTIONS(2489),
    [anon_sym___thread] = ACTIONS(2489),
    [anon_sym_const] = ACTIONS(2489),
    [anon_sym_constexpr] = ACTIONS(2489),
    [anon_sym_volatile] = ACTIONS(2489),
    [anon_sym_restrict] = ACTIONS(2489),
    [anon_sym___restrict__] = ACTIONS(2489),
    [anon_sym__Atomic] = ACTIONS(2489),
    [anon_sym__Noreturn] = ACTIONS(2489),
    [anon_sym_noreturn] = ACTIONS(2489),
    [anon_sym__Nonnull] = ACTIONS(2489),
    [anon_sym_mutable] = ACTIONS(2489),
    [anon_sym_constinit] = ACTIONS(2489),
    [anon_sym_consteval] = ACTIONS(2489),
    [anon_sym___shared__] = ACTIONS(2489),
    [anon_sym___local__] = ACTIONS(2489),
    [anon_sym___constant__] = ACTIONS(2489),
    [anon_sym___managed__] = ACTIONS(2489),
    [anon_sym___grid_constant__] = ACTIONS(2489),
    [anon_sym_alignas] = ACTIONS(2489),
    [anon_sym__Alignas] = ACTIONS(2489),
    [sym_primitive_type] = ACTIONS(2489),
    [anon_sym_enum] = ACTIONS(2489),
    [anon_sym_class] = ACTIONS(2489),
    [anon_sym_struct] = ACTIONS(2489),
    [anon_sym_union] = ACTIONS(2489),
    [anon_sym_if] = ACTIONS(2489),
    [anon_sym_switch] = ACTIONS(2489),
    [anon_sym_case] = ACTIONS(2489),
    [anon_sym_default] = ACTIONS(2489),
    [anon_sym_while] = ACTIONS(2489),
    [anon_sym_do] = ACTIONS(2489),
    [anon_sym_for] = ACTIONS(2489),
    [anon_sym_return] = ACTIONS(2489),
    [anon_sym_break] = ACTIONS(2489),
    [anon_sym_continue] = ACTIONS(2489),
    [anon_sym_goto] = ACTIONS(2489),
    [anon_sym___try] = ACTIONS(2489),
    [anon_sym___leave] = ACTIONS(2489),
    [anon_sym_not] = ACTIONS(2489),
    [anon_sym_compl] = ACTIONS(2489),
    [anon_sym_DASH_DASH] = ACTIONS(2491),
    [anon_sym_PLUS_PLUS] = ACTIONS(2491),
    [anon_sym_sizeof] = ACTIONS(2489),
    [anon_sym___alignof__] = ACTIONS(2489),
    [anon_sym___alignof] = ACTIONS(2489),
    [anon_sym__alignof] = ACTIONS(2489),
    [anon_sym_alignof] = ACTIONS(2489),
    [anon_sym__Alignof] = ACTIONS(2489),
    [anon_sym_offsetof] = ACTIONS(2489),
    [anon_sym__Generic] = ACTIONS(2489),
    [anon_sym_asm] = ACTIONS(2489),
    [anon_sym___asm__] = ACTIONS(2489),
    [anon_sym___asm] = ACTIONS(2489),
    [sym_number_literal] = ACTIONS(2491),
    [anon_sym_L_SQUOTE] = ACTIONS(2491),
    [anon_sym_u_SQUOTE] = ACTIONS(2491),
    [anon_sym_U_SQUOTE] = ACTIONS(2491),
    [anon_sym_u8_SQUOTE] = ACTIONS(2491),
    [anon_sym_SQUOTE] = ACTIONS(2491),
    [anon_sym_L_DQUOTE] = ACTIONS(2491),
    [anon_sym_u_DQUOTE] = ACTIONS(2491),
    [anon_sym_U_DQUOTE] = ACTIONS(2491),
    [anon_sym_u8_DQUOTE] = ACTIONS(2491),
    [anon_sym_DQUOTE] = ACTIONS(2491),
    [sym_true] = ACTIONS(2489),
    [sym_false] = ACTIONS(2489),
    [anon_sym_NULL] = ACTIONS(2489),
    [anon_sym_nullptr] = ACTIONS(2489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2489),
    [anon_sym_decltype] = ACTIONS(2489),
    [anon_sym_explicit] = ACTIONS(2489),
    [anon_sym_typename] = ACTIONS(2489),
    [anon_sym_template] = ACTIONS(2489),
    [anon_sym_operator] = ACTIONS(2489),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_delete] = ACTIONS(2489),
    [anon_sym_throw] = ACTIONS(2489),
    [anon_sym_namespace] = ACTIONS(2489),
    [anon_sym_using] = ACTIONS(2489),
    [anon_sym_static_assert] = ACTIONS(2489),
    [anon_sym_concept] = ACTIONS(2489),
    [anon_sym_co_return] = ACTIONS(2489),
    [anon_sym_co_yield] = ACTIONS(2489),
    [anon_sym_R_DQUOTE] = ACTIONS(2491),
    [anon_sym_LR_DQUOTE] = ACTIONS(2491),
    [anon_sym_uR_DQUOTE] = ACTIONS(2491),
    [anon_sym_UR_DQUOTE] = ACTIONS(2491),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2491),
    [anon_sym_co_await] = ACTIONS(2489),
    [anon_sym_new] = ACTIONS(2489),
    [anon_sym_requires] = ACTIONS(2489),
    [sym_this] = ACTIONS(2489),
    [anon_sym___launch_bounds__] = ACTIONS(2489),
  },
  [STATE(463)] = {
    [sym_identifier] = ACTIONS(2489),
    [aux_sym_preproc_include_token1] = ACTIONS(2489),
    [aux_sym_preproc_def_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2489),
    [sym_preproc_directive] = ACTIONS(2489),
    [anon_sym_LPAREN2] = ACTIONS(2491),
    [anon_sym_BANG] = ACTIONS(2491),
    [anon_sym_TILDE] = ACTIONS(2491),
    [anon_sym_DASH] = ACTIONS(2489),
    [anon_sym_PLUS] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(2491),
    [anon_sym_AMP_AMP] = ACTIONS(2491),
    [anon_sym_AMP] = ACTIONS(2489),
    [anon_sym_SEMI] = ACTIONS(2491),
    [anon_sym___extension__] = ACTIONS(2489),
    [anon_sym_typedef] = ACTIONS(2489),
    [anon_sym___device__] = ACTIONS(2489),
    [anon_sym___host__] = ACTIONS(2489),
    [anon_sym___global__] = ACTIONS(2489),
    [anon_sym___forceinline__] = ACTIONS(2489),
    [anon_sym___noinline__] = ACTIONS(2489),
    [anon_sym_virtual] = ACTIONS(2489),
    [anon_sym_extern] = ACTIONS(2489),
    [anon_sym___attribute__] = ACTIONS(2489),
    [anon_sym___attribute] = ACTIONS(2489),
    [anon_sym_COLON_COLON] = ACTIONS(2491),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2491),
    [anon_sym___declspec] = ACTIONS(2489),
    [anon_sym___based] = ACTIONS(2489),
    [anon_sym___cdecl] = ACTIONS(2489),
    [anon_sym___clrcall] = ACTIONS(2489),
    [anon_sym___stdcall] = ACTIONS(2489),
    [anon_sym___fastcall] = ACTIONS(2489),
    [anon_sym___thiscall] = ACTIONS(2489),
    [anon_sym___vectorcall] = ACTIONS(2489),
    [anon_sym_LBRACE] = ACTIONS(2491),
    [anon_sym_RBRACE] = ACTIONS(2491),
    [anon_sym_signed] = ACTIONS(2489),
    [anon_sym_unsigned] = ACTIONS(2489),
    [anon_sym_long] = ACTIONS(2489),
    [anon_sym_short] = ACTIONS(2489),
    [anon_sym_LBRACK] = ACTIONS(2489),
    [anon_sym_static] = ACTIONS(2489),
    [anon_sym_register] = ACTIONS(2489),
    [anon_sym_inline] = ACTIONS(2489),
    [anon_sym___inline] = ACTIONS(2489),
    [anon_sym___inline__] = ACTIONS(2489),
    [anon_sym___forceinline] = ACTIONS(2489),
    [anon_sym_thread_local] = ACTIONS(2489),
    [anon_sym___thread] = ACTIONS(2489),
    [anon_sym_const] = ACTIONS(2489),
    [anon_sym_constexpr] = ACTIONS(2489),
    [anon_sym_volatile] = ACTIONS(2489),
    [anon_sym_restrict] = ACTIONS(2489),
    [anon_sym___restrict__] = ACTIONS(2489),
    [anon_sym__Atomic] = ACTIONS(2489),
    [anon_sym__Noreturn] = ACTIONS(2489),
    [anon_sym_noreturn] = ACTIONS(2489),
    [anon_sym__Nonnull] = ACTIONS(2489),
    [anon_sym_mutable] = ACTIONS(2489),
    [anon_sym_constinit] = ACTIONS(2489),
    [anon_sym_consteval] = ACTIONS(2489),
    [anon_sym___shared__] = ACTIONS(2489),
    [anon_sym___local__] = ACTIONS(2489),
    [anon_sym___constant__] = ACTIONS(2489),
    [anon_sym___managed__] = ACTIONS(2489),
    [anon_sym___grid_constant__] = ACTIONS(2489),
    [anon_sym_alignas] = ACTIONS(2489),
    [anon_sym__Alignas] = ACTIONS(2489),
    [sym_primitive_type] = ACTIONS(2489),
    [anon_sym_enum] = ACTIONS(2489),
    [anon_sym_class] = ACTIONS(2489),
    [anon_sym_struct] = ACTIONS(2489),
    [anon_sym_union] = ACTIONS(2489),
    [anon_sym_if] = ACTIONS(2489),
    [anon_sym_switch] = ACTIONS(2489),
    [anon_sym_case] = ACTIONS(2489),
    [anon_sym_default] = ACTIONS(2489),
    [anon_sym_while] = ACTIONS(2489),
    [anon_sym_do] = ACTIONS(2489),
    [anon_sym_for] = ACTIONS(2489),
    [anon_sym_return] = ACTIONS(2489),
    [anon_sym_break] = ACTIONS(2489),
    [anon_sym_continue] = ACTIONS(2489),
    [anon_sym_goto] = ACTIONS(2489),
    [anon_sym___try] = ACTIONS(2489),
    [anon_sym___leave] = ACTIONS(2489),
    [anon_sym_not] = ACTIONS(2489),
    [anon_sym_compl] = ACTIONS(2489),
    [anon_sym_DASH_DASH] = ACTIONS(2491),
    [anon_sym_PLUS_PLUS] = ACTIONS(2491),
    [anon_sym_sizeof] = ACTIONS(2489),
    [anon_sym___alignof__] = ACTIONS(2489),
    [anon_sym___alignof] = ACTIONS(2489),
    [anon_sym__alignof] = ACTIONS(2489),
    [anon_sym_alignof] = ACTIONS(2489),
    [anon_sym__Alignof] = ACTIONS(2489),
    [anon_sym_offsetof] = ACTIONS(2489),
    [anon_sym__Generic] = ACTIONS(2489),
    [anon_sym_asm] = ACTIONS(2489),
    [anon_sym___asm__] = ACTIONS(2489),
    [anon_sym___asm] = ACTIONS(2489),
    [sym_number_literal] = ACTIONS(2491),
    [anon_sym_L_SQUOTE] = ACTIONS(2491),
    [anon_sym_u_SQUOTE] = ACTIONS(2491),
    [anon_sym_U_SQUOTE] = ACTIONS(2491),
    [anon_sym_u8_SQUOTE] = ACTIONS(2491),
    [anon_sym_SQUOTE] = ACTIONS(2491),
    [anon_sym_L_DQUOTE] = ACTIONS(2491),
    [anon_sym_u_DQUOTE] = ACTIONS(2491),
    [anon_sym_U_DQUOTE] = ACTIONS(2491),
    [anon_sym_u8_DQUOTE] = ACTIONS(2491),
    [anon_sym_DQUOTE] = ACTIONS(2491),
    [sym_true] = ACTIONS(2489),
    [sym_false] = ACTIONS(2489),
    [anon_sym_NULL] = ACTIONS(2489),
    [anon_sym_nullptr] = ACTIONS(2489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2489),
    [anon_sym_decltype] = ACTIONS(2489),
    [anon_sym_explicit] = ACTIONS(2489),
    [anon_sym_typename] = ACTIONS(2489),
    [anon_sym_template] = ACTIONS(2489),
    [anon_sym_operator] = ACTIONS(2489),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_delete] = ACTIONS(2489),
    [anon_sym_throw] = ACTIONS(2489),
    [anon_sym_namespace] = ACTIONS(2489),
    [anon_sym_using] = ACTIONS(2489),
    [anon_sym_static_assert] = ACTIONS(2489),
    [anon_sym_concept] = ACTIONS(2489),
    [anon_sym_co_return] = ACTIONS(2489),
    [anon_sym_co_yield] = ACTIONS(2489),
    [anon_sym_R_DQUOTE] = ACTIONS(2491),
    [anon_sym_LR_DQUOTE] = ACTIONS(2491),
    [anon_sym_uR_DQUOTE] = ACTIONS(2491),
    [anon_sym_UR_DQUOTE] = ACTIONS(2491),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2491),
    [anon_sym_co_await] = ACTIONS(2489),
    [anon_sym_new] = ACTIONS(2489),
    [anon_sym_requires] = ACTIONS(2489),
    [sym_this] = ACTIONS(2489),
    [anon_sym___launch_bounds__] = ACTIONS(2489),
  },
  [STATE(464)] = {
    [sym_identifier] = ACTIONS(2569),
    [aux_sym_preproc_include_token1] = ACTIONS(2569),
    [aux_sym_preproc_def_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token2] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2569),
    [sym_preproc_directive] = ACTIONS(2569),
    [anon_sym_LPAREN2] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2571),
    [anon_sym_TILDE] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2571),
    [anon_sym_AMP_AMP] = ACTIONS(2571),
    [anon_sym_AMP] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym___extension__] = ACTIONS(2569),
    [anon_sym_typedef] = ACTIONS(2569),
    [anon_sym___device__] = ACTIONS(2569),
    [anon_sym___host__] = ACTIONS(2569),
    [anon_sym___global__] = ACTIONS(2569),
    [anon_sym___forceinline__] = ACTIONS(2569),
    [anon_sym___noinline__] = ACTIONS(2569),
    [anon_sym_virtual] = ACTIONS(2569),
    [anon_sym_extern] = ACTIONS(2569),
    [anon_sym___attribute__] = ACTIONS(2569),
    [anon_sym___attribute] = ACTIONS(2569),
    [anon_sym_COLON_COLON] = ACTIONS(2571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2571),
    [anon_sym___declspec] = ACTIONS(2569),
    [anon_sym___based] = ACTIONS(2569),
    [anon_sym___cdecl] = ACTIONS(2569),
    [anon_sym___clrcall] = ACTIONS(2569),
    [anon_sym___stdcall] = ACTIONS(2569),
    [anon_sym___fastcall] = ACTIONS(2569),
    [anon_sym___thiscall] = ACTIONS(2569),
    [anon_sym___vectorcall] = ACTIONS(2569),
    [anon_sym_LBRACE] = ACTIONS(2571),
    [anon_sym_signed] = ACTIONS(2569),
    [anon_sym_unsigned] = ACTIONS(2569),
    [anon_sym_long] = ACTIONS(2569),
    [anon_sym_short] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2569),
    [anon_sym_register] = ACTIONS(2569),
    [anon_sym_inline] = ACTIONS(2569),
    [anon_sym___inline] = ACTIONS(2569),
    [anon_sym___inline__] = ACTIONS(2569),
    [anon_sym___forceinline] = ACTIONS(2569),
    [anon_sym_thread_local] = ACTIONS(2569),
    [anon_sym___thread] = ACTIONS(2569),
    [anon_sym_const] = ACTIONS(2569),
    [anon_sym_constexpr] = ACTIONS(2569),
    [anon_sym_volatile] = ACTIONS(2569),
    [anon_sym_restrict] = ACTIONS(2569),
    [anon_sym___restrict__] = ACTIONS(2569),
    [anon_sym__Atomic] = ACTIONS(2569),
    [anon_sym__Noreturn] = ACTIONS(2569),
    [anon_sym_noreturn] = ACTIONS(2569),
    [anon_sym__Nonnull] = ACTIONS(2569),
    [anon_sym_mutable] = ACTIONS(2569),
    [anon_sym_constinit] = ACTIONS(2569),
    [anon_sym_consteval] = ACTIONS(2569),
    [anon_sym___shared__] = ACTIONS(2569),
    [anon_sym___local__] = ACTIONS(2569),
    [anon_sym___constant__] = ACTIONS(2569),
    [anon_sym___managed__] = ACTIONS(2569),
    [anon_sym___grid_constant__] = ACTIONS(2569),
    [anon_sym_alignas] = ACTIONS(2569),
    [anon_sym__Alignas] = ACTIONS(2569),
    [sym_primitive_type] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2569),
    [anon_sym_struct] = ACTIONS(2569),
    [anon_sym_union] = ACTIONS(2569),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_switch] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_default] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_do] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_return] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_goto] = ACTIONS(2569),
    [anon_sym___try] = ACTIONS(2569),
    [anon_sym___leave] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_compl] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2571),
    [anon_sym_sizeof] = ACTIONS(2569),
    [anon_sym___alignof__] = ACTIONS(2569),
    [anon_sym___alignof] = ACTIONS(2569),
    [anon_sym__alignof] = ACTIONS(2569),
    [anon_sym_alignof] = ACTIONS(2569),
    [anon_sym__Alignof] = ACTIONS(2569),
    [anon_sym_offsetof] = ACTIONS(2569),
    [anon_sym__Generic] = ACTIONS(2569),
    [anon_sym_asm] = ACTIONS(2569),
    [anon_sym___asm__] = ACTIONS(2569),
    [anon_sym___asm] = ACTIONS(2569),
    [sym_number_literal] = ACTIONS(2571),
    [anon_sym_L_SQUOTE] = ACTIONS(2571),
    [anon_sym_u_SQUOTE] = ACTIONS(2571),
    [anon_sym_U_SQUOTE] = ACTIONS(2571),
    [anon_sym_u8_SQUOTE] = ACTIONS(2571),
    [anon_sym_SQUOTE] = ACTIONS(2571),
    [anon_sym_L_DQUOTE] = ACTIONS(2571),
    [anon_sym_u_DQUOTE] = ACTIONS(2571),
    [anon_sym_U_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8_DQUOTE] = ACTIONS(2571),
    [anon_sym_DQUOTE] = ACTIONS(2571),
    [sym_true] = ACTIONS(2569),
    [sym_false] = ACTIONS(2569),
    [anon_sym_NULL] = ACTIONS(2569),
    [anon_sym_nullptr] = ACTIONS(2569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2569),
    [anon_sym_decltype] = ACTIONS(2569),
    [anon_sym_explicit] = ACTIONS(2569),
    [anon_sym_typename] = ACTIONS(2569),
    [anon_sym_template] = ACTIONS(2569),
    [anon_sym_operator] = ACTIONS(2569),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_delete] = ACTIONS(2569),
    [anon_sym_throw] = ACTIONS(2569),
    [anon_sym_namespace] = ACTIONS(2569),
    [anon_sym_using] = ACTIONS(2569),
    [anon_sym_static_assert] = ACTIONS(2569),
    [anon_sym_concept] = ACTIONS(2569),
    [anon_sym_co_return] = ACTIONS(2569),
    [anon_sym_co_yield] = ACTIONS(2569),
    [anon_sym_R_DQUOTE] = ACTIONS(2571),
    [anon_sym_LR_DQUOTE] = ACTIONS(2571),
    [anon_sym_uR_DQUOTE] = ACTIONS(2571),
    [anon_sym_UR_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2571),
    [anon_sym_co_await] = ACTIONS(2569),
    [anon_sym_new] = ACTIONS(2569),
    [anon_sym_requires] = ACTIONS(2569),
    [sym_this] = ACTIONS(2569),
    [anon_sym___launch_bounds__] = ACTIONS(2569),
  },
  [STATE(465)] = {
    [sym_identifier] = ACTIONS(2581),
    [aux_sym_preproc_include_token1] = ACTIONS(2581),
    [aux_sym_preproc_def_token1] = ACTIONS(2581),
    [aux_sym_preproc_if_token1] = ACTIONS(2581),
    [aux_sym_preproc_if_token2] = ACTIONS(2581),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2581),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2581),
    [sym_preproc_directive] = ACTIONS(2581),
    [anon_sym_LPAREN2] = ACTIONS(2583),
    [anon_sym_BANG] = ACTIONS(2583),
    [anon_sym_TILDE] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2583),
    [anon_sym_AMP_AMP] = ACTIONS(2583),
    [anon_sym_AMP] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym___extension__] = ACTIONS(2581),
    [anon_sym_typedef] = ACTIONS(2581),
    [anon_sym___device__] = ACTIONS(2581),
    [anon_sym___host__] = ACTIONS(2581),
    [anon_sym___global__] = ACTIONS(2581),
    [anon_sym___forceinline__] = ACTIONS(2581),
    [anon_sym___noinline__] = ACTIONS(2581),
    [anon_sym_virtual] = ACTIONS(2581),
    [anon_sym_extern] = ACTIONS(2581),
    [anon_sym___attribute__] = ACTIONS(2581),
    [anon_sym___attribute] = ACTIONS(2581),
    [anon_sym_COLON_COLON] = ACTIONS(2583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2583),
    [anon_sym___declspec] = ACTIONS(2581),
    [anon_sym___based] = ACTIONS(2581),
    [anon_sym___cdecl] = ACTIONS(2581),
    [anon_sym___clrcall] = ACTIONS(2581),
    [anon_sym___stdcall] = ACTIONS(2581),
    [anon_sym___fastcall] = ACTIONS(2581),
    [anon_sym___thiscall] = ACTIONS(2581),
    [anon_sym___vectorcall] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_signed] = ACTIONS(2581),
    [anon_sym_unsigned] = ACTIONS(2581),
    [anon_sym_long] = ACTIONS(2581),
    [anon_sym_short] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2581),
    [anon_sym_static] = ACTIONS(2581),
    [anon_sym_register] = ACTIONS(2581),
    [anon_sym_inline] = ACTIONS(2581),
    [anon_sym___inline] = ACTIONS(2581),
    [anon_sym___inline__] = ACTIONS(2581),
    [anon_sym___forceinline] = ACTIONS(2581),
    [anon_sym_thread_local] = ACTIONS(2581),
    [anon_sym___thread] = ACTIONS(2581),
    [anon_sym_const] = ACTIONS(2581),
    [anon_sym_constexpr] = ACTIONS(2581),
    [anon_sym_volatile] = ACTIONS(2581),
    [anon_sym_restrict] = ACTIONS(2581),
    [anon_sym___restrict__] = ACTIONS(2581),
    [anon_sym__Atomic] = ACTIONS(2581),
    [anon_sym__Noreturn] = ACTIONS(2581),
    [anon_sym_noreturn] = ACTIONS(2581),
    [anon_sym__Nonnull] = ACTIONS(2581),
    [anon_sym_mutable] = ACTIONS(2581),
    [anon_sym_constinit] = ACTIONS(2581),
    [anon_sym_consteval] = ACTIONS(2581),
    [anon_sym___shared__] = ACTIONS(2581),
    [anon_sym___local__] = ACTIONS(2581),
    [anon_sym___constant__] = ACTIONS(2581),
    [anon_sym___managed__] = ACTIONS(2581),
    [anon_sym___grid_constant__] = ACTIONS(2581),
    [anon_sym_alignas] = ACTIONS(2581),
    [anon_sym__Alignas] = ACTIONS(2581),
    [sym_primitive_type] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_class] = ACTIONS(2581),
    [anon_sym_struct] = ACTIONS(2581),
    [anon_sym_union] = ACTIONS(2581),
    [anon_sym_if] = ACTIONS(2581),
    [anon_sym_switch] = ACTIONS(2581),
    [anon_sym_case] = ACTIONS(2581),
    [anon_sym_default] = ACTIONS(2581),
    [anon_sym_while] = ACTIONS(2581),
    [anon_sym_do] = ACTIONS(2581),
    [anon_sym_for] = ACTIONS(2581),
    [anon_sym_return] = ACTIONS(2581),
    [anon_sym_break] = ACTIONS(2581),
    [anon_sym_continue] = ACTIONS(2581),
    [anon_sym_goto] = ACTIONS(2581),
    [anon_sym___try] = ACTIONS(2581),
    [anon_sym___leave] = ACTIONS(2581),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_compl] = ACTIONS(2581),
    [anon_sym_DASH_DASH] = ACTIONS(2583),
    [anon_sym_PLUS_PLUS] = ACTIONS(2583),
    [anon_sym_sizeof] = ACTIONS(2581),
    [anon_sym___alignof__] = ACTIONS(2581),
    [anon_sym___alignof] = ACTIONS(2581),
    [anon_sym__alignof] = ACTIONS(2581),
    [anon_sym_alignof] = ACTIONS(2581),
    [anon_sym__Alignof] = ACTIONS(2581),
    [anon_sym_offsetof] = ACTIONS(2581),
    [anon_sym__Generic] = ACTIONS(2581),
    [anon_sym_asm] = ACTIONS(2581),
    [anon_sym___asm__] = ACTIONS(2581),
    [anon_sym___asm] = ACTIONS(2581),
    [sym_number_literal] = ACTIONS(2583),
    [anon_sym_L_SQUOTE] = ACTIONS(2583),
    [anon_sym_u_SQUOTE] = ACTIONS(2583),
    [anon_sym_U_SQUOTE] = ACTIONS(2583),
    [anon_sym_u8_SQUOTE] = ACTIONS(2583),
    [anon_sym_SQUOTE] = ACTIONS(2583),
    [anon_sym_L_DQUOTE] = ACTIONS(2583),
    [anon_sym_u_DQUOTE] = ACTIONS(2583),
    [anon_sym_U_DQUOTE] = ACTIONS(2583),
    [anon_sym_u8_DQUOTE] = ACTIONS(2583),
    [anon_sym_DQUOTE] = ACTIONS(2583),
    [sym_true] = ACTIONS(2581),
    [sym_false] = ACTIONS(2581),
    [anon_sym_NULL] = ACTIONS(2581),
    [anon_sym_nullptr] = ACTIONS(2581),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2581),
    [anon_sym_decltype] = ACTIONS(2581),
    [anon_sym_explicit] = ACTIONS(2581),
    [anon_sym_typename] = ACTIONS(2581),
    [anon_sym_template] = ACTIONS(2581),
    [anon_sym_operator] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2581),
    [anon_sym_delete] = ACTIONS(2581),
    [anon_sym_throw] = ACTIONS(2581),
    [anon_sym_namespace] = ACTIONS(2581),
    [anon_sym_using] = ACTIONS(2581),
    [anon_sym_static_assert] = ACTIONS(2581),
    [anon_sym_concept] = ACTIONS(2581),
    [anon_sym_co_return] = ACTIONS(2581),
    [anon_sym_co_yield] = ACTIONS(2581),
    [anon_sym_R_DQUOTE] = ACTIONS(2583),
    [anon_sym_LR_DQUOTE] = ACTIONS(2583),
    [anon_sym_uR_DQUOTE] = ACTIONS(2583),
    [anon_sym_UR_DQUOTE] = ACTIONS(2583),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2583),
    [anon_sym_co_await] = ACTIONS(2581),
    [anon_sym_new] = ACTIONS(2581),
    [anon_sym_requires] = ACTIONS(2581),
    [sym_this] = ACTIONS(2581),
    [anon_sym___launch_bounds__] = ACTIONS(2581),
  },
  [STATE(466)] = {
    [sym_identifier] = ACTIONS(2613),
    [aux_sym_preproc_include_token1] = ACTIONS(2613),
    [aux_sym_preproc_def_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token2] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2613),
    [sym_preproc_directive] = ACTIONS(2613),
    [anon_sym_LPAREN2] = ACTIONS(2615),
    [anon_sym_BANG] = ACTIONS(2615),
    [anon_sym_TILDE] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2615),
    [anon_sym_AMP_AMP] = ACTIONS(2615),
    [anon_sym_AMP] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym___extension__] = ACTIONS(2613),
    [anon_sym_typedef] = ACTIONS(2613),
    [anon_sym___device__] = ACTIONS(2613),
    [anon_sym___host__] = ACTIONS(2613),
    [anon_sym___global__] = ACTIONS(2613),
    [anon_sym___forceinline__] = ACTIONS(2613),
    [anon_sym___noinline__] = ACTIONS(2613),
    [anon_sym_virtual] = ACTIONS(2613),
    [anon_sym_extern] = ACTIONS(2613),
    [anon_sym___attribute__] = ACTIONS(2613),
    [anon_sym___attribute] = ACTIONS(2613),
    [anon_sym_COLON_COLON] = ACTIONS(2615),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2615),
    [anon_sym___declspec] = ACTIONS(2613),
    [anon_sym___based] = ACTIONS(2613),
    [anon_sym___cdecl] = ACTIONS(2613),
    [anon_sym___clrcall] = ACTIONS(2613),
    [anon_sym___stdcall] = ACTIONS(2613),
    [anon_sym___fastcall] = ACTIONS(2613),
    [anon_sym___thiscall] = ACTIONS(2613),
    [anon_sym___vectorcall] = ACTIONS(2613),
    [anon_sym_LBRACE] = ACTIONS(2615),
    [anon_sym_signed] = ACTIONS(2613),
    [anon_sym_unsigned] = ACTIONS(2613),
    [anon_sym_long] = ACTIONS(2613),
    [anon_sym_short] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2613),
    [anon_sym_static] = ACTIONS(2613),
    [anon_sym_register] = ACTIONS(2613),
    [anon_sym_inline] = ACTIONS(2613),
    [anon_sym___inline] = ACTIONS(2613),
    [anon_sym___inline__] = ACTIONS(2613),
    [anon_sym___forceinline] = ACTIONS(2613),
    [anon_sym_thread_local] = ACTIONS(2613),
    [anon_sym___thread] = ACTIONS(2613),
    [anon_sym_const] = ACTIONS(2613),
    [anon_sym_constexpr] = ACTIONS(2613),
    [anon_sym_volatile] = ACTIONS(2613),
    [anon_sym_restrict] = ACTIONS(2613),
    [anon_sym___restrict__] = ACTIONS(2613),
    [anon_sym__Atomic] = ACTIONS(2613),
    [anon_sym__Noreturn] = ACTIONS(2613),
    [anon_sym_noreturn] = ACTIONS(2613),
    [anon_sym__Nonnull] = ACTIONS(2613),
    [anon_sym_mutable] = ACTIONS(2613),
    [anon_sym_constinit] = ACTIONS(2613),
    [anon_sym_consteval] = ACTIONS(2613),
    [anon_sym___shared__] = ACTIONS(2613),
    [anon_sym___local__] = ACTIONS(2613),
    [anon_sym___constant__] = ACTIONS(2613),
    [anon_sym___managed__] = ACTIONS(2613),
    [anon_sym___grid_constant__] = ACTIONS(2613),
    [anon_sym_alignas] = ACTIONS(2613),
    [anon_sym__Alignas] = ACTIONS(2613),
    [sym_primitive_type] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_class] = ACTIONS(2613),
    [anon_sym_struct] = ACTIONS(2613),
    [anon_sym_union] = ACTIONS(2613),
    [anon_sym_if] = ACTIONS(2613),
    [anon_sym_switch] = ACTIONS(2613),
    [anon_sym_case] = ACTIONS(2613),
    [anon_sym_default] = ACTIONS(2613),
    [anon_sym_while] = ACTIONS(2613),
    [anon_sym_do] = ACTIONS(2613),
    [anon_sym_for] = ACTIONS(2613),
    [anon_sym_return] = ACTIONS(2613),
    [anon_sym_break] = ACTIONS(2613),
    [anon_sym_continue] = ACTIONS(2613),
    [anon_sym_goto] = ACTIONS(2613),
    [anon_sym___try] = ACTIONS(2613),
    [anon_sym___leave] = ACTIONS(2613),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_compl] = ACTIONS(2613),
    [anon_sym_DASH_DASH] = ACTIONS(2615),
    [anon_sym_PLUS_PLUS] = ACTIONS(2615),
    [anon_sym_sizeof] = ACTIONS(2613),
    [anon_sym___alignof__] = ACTIONS(2613),
    [anon_sym___alignof] = ACTIONS(2613),
    [anon_sym__alignof] = ACTIONS(2613),
    [anon_sym_alignof] = ACTIONS(2613),
    [anon_sym__Alignof] = ACTIONS(2613),
    [anon_sym_offsetof] = ACTIONS(2613),
    [anon_sym__Generic] = ACTIONS(2613),
    [anon_sym_asm] = ACTIONS(2613),
    [anon_sym___asm__] = ACTIONS(2613),
    [anon_sym___asm] = ACTIONS(2613),
    [sym_number_literal] = ACTIONS(2615),
    [anon_sym_L_SQUOTE] = ACTIONS(2615),
    [anon_sym_u_SQUOTE] = ACTIONS(2615),
    [anon_sym_U_SQUOTE] = ACTIONS(2615),
    [anon_sym_u8_SQUOTE] = ACTIONS(2615),
    [anon_sym_SQUOTE] = ACTIONS(2615),
    [anon_sym_L_DQUOTE] = ACTIONS(2615),
    [anon_sym_u_DQUOTE] = ACTIONS(2615),
    [anon_sym_U_DQUOTE] = ACTIONS(2615),
    [anon_sym_u8_DQUOTE] = ACTIONS(2615),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_true] = ACTIONS(2613),
    [sym_false] = ACTIONS(2613),
    [anon_sym_NULL] = ACTIONS(2613),
    [anon_sym_nullptr] = ACTIONS(2613),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2613),
    [anon_sym_decltype] = ACTIONS(2613),
    [anon_sym_explicit] = ACTIONS(2613),
    [anon_sym_typename] = ACTIONS(2613),
    [anon_sym_template] = ACTIONS(2613),
    [anon_sym_operator] = ACTIONS(2613),
    [anon_sym_try] = ACTIONS(2613),
    [anon_sym_delete] = ACTIONS(2613),
    [anon_sym_throw] = ACTIONS(2613),
    [anon_sym_namespace] = ACTIONS(2613),
    [anon_sym_using] = ACTIONS(2613),
    [anon_sym_static_assert] = ACTIONS(2613),
    [anon_sym_concept] = ACTIONS(2613),
    [anon_sym_co_return] = ACTIONS(2613),
    [anon_sym_co_yield] = ACTIONS(2613),
    [anon_sym_R_DQUOTE] = ACTIONS(2615),
    [anon_sym_LR_DQUOTE] = ACTIONS(2615),
    [anon_sym_uR_DQUOTE] = ACTIONS(2615),
    [anon_sym_UR_DQUOTE] = ACTIONS(2615),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2615),
    [anon_sym_co_await] = ACTIONS(2613),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_requires] = ACTIONS(2613),
    [sym_this] = ACTIONS(2613),
    [anon_sym___launch_bounds__] = ACTIONS(2613),
  },
  [STATE(467)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_include_token1] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token2] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_BANG] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_DASH] = ACTIONS(2234),
    [anon_sym_PLUS] = ACTIONS(2234),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym___cdecl] = ACTIONS(2234),
    [anon_sym___clrcall] = ACTIONS(2234),
    [anon_sym___stdcall] = ACTIONS(2234),
    [anon_sym___fastcall] = ACTIONS(2234),
    [anon_sym___thiscall] = ACTIONS(2234),
    [anon_sym___vectorcall] = ACTIONS(2234),
    [anon_sym_LBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [anon_sym_if] = ACTIONS(2234),
    [anon_sym_switch] = ACTIONS(2234),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym_default] = ACTIONS(2234),
    [anon_sym_while] = ACTIONS(2234),
    [anon_sym_do] = ACTIONS(2234),
    [anon_sym_for] = ACTIONS(2234),
    [anon_sym_return] = ACTIONS(2234),
    [anon_sym_break] = ACTIONS(2234),
    [anon_sym_continue] = ACTIONS(2234),
    [anon_sym_goto] = ACTIONS(2234),
    [anon_sym___try] = ACTIONS(2234),
    [anon_sym___leave] = ACTIONS(2234),
    [anon_sym_not] = ACTIONS(2234),
    [anon_sym_compl] = ACTIONS(2234),
    [anon_sym_DASH_DASH] = ACTIONS(2236),
    [anon_sym_PLUS_PLUS] = ACTIONS(2236),
    [anon_sym_sizeof] = ACTIONS(2234),
    [anon_sym___alignof__] = ACTIONS(2234),
    [anon_sym___alignof] = ACTIONS(2234),
    [anon_sym__alignof] = ACTIONS(2234),
    [anon_sym_alignof] = ACTIONS(2234),
    [anon_sym__Alignof] = ACTIONS(2234),
    [anon_sym_offsetof] = ACTIONS(2234),
    [anon_sym__Generic] = ACTIONS(2234),
    [anon_sym_asm] = ACTIONS(2234),
    [anon_sym___asm__] = ACTIONS(2234),
    [anon_sym___asm] = ACTIONS(2234),
    [sym_number_literal] = ACTIONS(2236),
    [anon_sym_L_SQUOTE] = ACTIONS(2236),
    [anon_sym_u_SQUOTE] = ACTIONS(2236),
    [anon_sym_U_SQUOTE] = ACTIONS(2236),
    [anon_sym_u8_SQUOTE] = ACTIONS(2236),
    [anon_sym_SQUOTE] = ACTIONS(2236),
    [anon_sym_L_DQUOTE] = ACTIONS(2236),
    [anon_sym_u_DQUOTE] = ACTIONS(2236),
    [anon_sym_U_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8_DQUOTE] = ACTIONS(2236),
    [anon_sym_DQUOTE] = ACTIONS(2236),
    [sym_true] = ACTIONS(2234),
    [sym_false] = ACTIONS(2234),
    [anon_sym_NULL] = ACTIONS(2234),
    [anon_sym_nullptr] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_try] = ACTIONS(2234),
    [anon_sym_delete] = ACTIONS(2234),
    [anon_sym_throw] = ACTIONS(2234),
    [anon_sym_namespace] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym_concept] = ACTIONS(2234),
    [anon_sym_co_return] = ACTIONS(2234),
    [anon_sym_co_yield] = ACTIONS(2234),
    [anon_sym_R_DQUOTE] = ACTIONS(2236),
    [anon_sym_LR_DQUOTE] = ACTIONS(2236),
    [anon_sym_uR_DQUOTE] = ACTIONS(2236),
    [anon_sym_UR_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2236),
    [anon_sym_co_await] = ACTIONS(2234),
    [anon_sym_new] = ACTIONS(2234),
    [anon_sym_requires] = ACTIONS(2234),
    [sym_this] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(468)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_include_token1] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token2] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_BANG] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_DASH] = ACTIONS(2234),
    [anon_sym_PLUS] = ACTIONS(2234),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym___cdecl] = ACTIONS(2234),
    [anon_sym___clrcall] = ACTIONS(2234),
    [anon_sym___stdcall] = ACTIONS(2234),
    [anon_sym___fastcall] = ACTIONS(2234),
    [anon_sym___thiscall] = ACTIONS(2234),
    [anon_sym___vectorcall] = ACTIONS(2234),
    [anon_sym_LBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [anon_sym_if] = ACTIONS(2234),
    [anon_sym_switch] = ACTIONS(2234),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym_default] = ACTIONS(2234),
    [anon_sym_while] = ACTIONS(2234),
    [anon_sym_do] = ACTIONS(2234),
    [anon_sym_for] = ACTIONS(2234),
    [anon_sym_return] = ACTIONS(2234),
    [anon_sym_break] = ACTIONS(2234),
    [anon_sym_continue] = ACTIONS(2234),
    [anon_sym_goto] = ACTIONS(2234),
    [anon_sym___try] = ACTIONS(2234),
    [anon_sym___leave] = ACTIONS(2234),
    [anon_sym_not] = ACTIONS(2234),
    [anon_sym_compl] = ACTIONS(2234),
    [anon_sym_DASH_DASH] = ACTIONS(2236),
    [anon_sym_PLUS_PLUS] = ACTIONS(2236),
    [anon_sym_sizeof] = ACTIONS(2234),
    [anon_sym___alignof__] = ACTIONS(2234),
    [anon_sym___alignof] = ACTIONS(2234),
    [anon_sym__alignof] = ACTIONS(2234),
    [anon_sym_alignof] = ACTIONS(2234),
    [anon_sym__Alignof] = ACTIONS(2234),
    [anon_sym_offsetof] = ACTIONS(2234),
    [anon_sym__Generic] = ACTIONS(2234),
    [anon_sym_asm] = ACTIONS(2234),
    [anon_sym___asm__] = ACTIONS(2234),
    [anon_sym___asm] = ACTIONS(2234),
    [sym_number_literal] = ACTIONS(2236),
    [anon_sym_L_SQUOTE] = ACTIONS(2236),
    [anon_sym_u_SQUOTE] = ACTIONS(2236),
    [anon_sym_U_SQUOTE] = ACTIONS(2236),
    [anon_sym_u8_SQUOTE] = ACTIONS(2236),
    [anon_sym_SQUOTE] = ACTIONS(2236),
    [anon_sym_L_DQUOTE] = ACTIONS(2236),
    [anon_sym_u_DQUOTE] = ACTIONS(2236),
    [anon_sym_U_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8_DQUOTE] = ACTIONS(2236),
    [anon_sym_DQUOTE] = ACTIONS(2236),
    [sym_true] = ACTIONS(2234),
    [sym_false] = ACTIONS(2234),
    [anon_sym_NULL] = ACTIONS(2234),
    [anon_sym_nullptr] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_try] = ACTIONS(2234),
    [anon_sym_delete] = ACTIONS(2234),
    [anon_sym_throw] = ACTIONS(2234),
    [anon_sym_namespace] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym_concept] = ACTIONS(2234),
    [anon_sym_co_return] = ACTIONS(2234),
    [anon_sym_co_yield] = ACTIONS(2234),
    [anon_sym_R_DQUOTE] = ACTIONS(2236),
    [anon_sym_LR_DQUOTE] = ACTIONS(2236),
    [anon_sym_uR_DQUOTE] = ACTIONS(2236),
    [anon_sym_UR_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2236),
    [anon_sym_co_await] = ACTIONS(2234),
    [anon_sym_new] = ACTIONS(2234),
    [anon_sym_requires] = ACTIONS(2234),
    [sym_this] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(469)] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym___device__] = ACTIONS(2324),
    [anon_sym___host__] = ACTIONS(2324),
    [anon_sym___global__] = ACTIONS(2324),
    [anon_sym___forceinline__] = ACTIONS(2324),
    [anon_sym___noinline__] = ACTIONS(2324),
    [anon_sym_virtual] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym___attribute] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym__Nonnull] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym___shared__] = ACTIONS(2324),
    [anon_sym___local__] = ACTIONS(2324),
    [anon_sym___constant__] = ACTIONS(2324),
    [anon_sym___managed__] = ACTIONS(2324),
    [anon_sym___grid_constant__] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [anon_sym___asm] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym___launch_bounds__] = ACTIONS(2324),
  },
  [STATE(470)] = {
    [sym_identifier] = ACTIONS(2521),
    [aux_sym_preproc_include_token1] = ACTIONS(2521),
    [aux_sym_preproc_def_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token2] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2521),
    [sym_preproc_directive] = ACTIONS(2521),
    [anon_sym_LPAREN2] = ACTIONS(2523),
    [anon_sym_BANG] = ACTIONS(2523),
    [anon_sym_TILDE] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2523),
    [anon_sym_AMP_AMP] = ACTIONS(2523),
    [anon_sym_AMP] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym___extension__] = ACTIONS(2521),
    [anon_sym_typedef] = ACTIONS(2521),
    [anon_sym___device__] = ACTIONS(2521),
    [anon_sym___host__] = ACTIONS(2521),
    [anon_sym___global__] = ACTIONS(2521),
    [anon_sym___forceinline__] = ACTIONS(2521),
    [anon_sym___noinline__] = ACTIONS(2521),
    [anon_sym_virtual] = ACTIONS(2521),
    [anon_sym_extern] = ACTIONS(2521),
    [anon_sym___attribute__] = ACTIONS(2521),
    [anon_sym___attribute] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2523),
    [anon_sym___declspec] = ACTIONS(2521),
    [anon_sym___based] = ACTIONS(2521),
    [anon_sym___cdecl] = ACTIONS(2521),
    [anon_sym___clrcall] = ACTIONS(2521),
    [anon_sym___stdcall] = ACTIONS(2521),
    [anon_sym___fastcall] = ACTIONS(2521),
    [anon_sym___thiscall] = ACTIONS(2521),
    [anon_sym___vectorcall] = ACTIONS(2521),
    [anon_sym_LBRACE] = ACTIONS(2523),
    [anon_sym_signed] = ACTIONS(2521),
    [anon_sym_unsigned] = ACTIONS(2521),
    [anon_sym_long] = ACTIONS(2521),
    [anon_sym_short] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2521),
    [anon_sym_static] = ACTIONS(2521),
    [anon_sym_register] = ACTIONS(2521),
    [anon_sym_inline] = ACTIONS(2521),
    [anon_sym___inline] = ACTIONS(2521),
    [anon_sym___inline__] = ACTIONS(2521),
    [anon_sym___forceinline] = ACTIONS(2521),
    [anon_sym_thread_local] = ACTIONS(2521),
    [anon_sym___thread] = ACTIONS(2521),
    [anon_sym_const] = ACTIONS(2521),
    [anon_sym_constexpr] = ACTIONS(2521),
    [anon_sym_volatile] = ACTIONS(2521),
    [anon_sym_restrict] = ACTIONS(2521),
    [anon_sym___restrict__] = ACTIONS(2521),
    [anon_sym__Atomic] = ACTIONS(2521),
    [anon_sym__Noreturn] = ACTIONS(2521),
    [anon_sym_noreturn] = ACTIONS(2521),
    [anon_sym__Nonnull] = ACTIONS(2521),
    [anon_sym_mutable] = ACTIONS(2521),
    [anon_sym_constinit] = ACTIONS(2521),
    [anon_sym_consteval] = ACTIONS(2521),
    [anon_sym___shared__] = ACTIONS(2521),
    [anon_sym___local__] = ACTIONS(2521),
    [anon_sym___constant__] = ACTIONS(2521),
    [anon_sym___managed__] = ACTIONS(2521),
    [anon_sym___grid_constant__] = ACTIONS(2521),
    [anon_sym_alignas] = ACTIONS(2521),
    [anon_sym__Alignas] = ACTIONS(2521),
    [sym_primitive_type] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_class] = ACTIONS(2521),
    [anon_sym_struct] = ACTIONS(2521),
    [anon_sym_union] = ACTIONS(2521),
    [anon_sym_if] = ACTIONS(2521),
    [anon_sym_switch] = ACTIONS(2521),
    [anon_sym_case] = ACTIONS(2521),
    [anon_sym_default] = ACTIONS(2521),
    [anon_sym_while] = ACTIONS(2521),
    [anon_sym_do] = ACTIONS(2521),
    [anon_sym_for] = ACTIONS(2521),
    [anon_sym_return] = ACTIONS(2521),
    [anon_sym_break] = ACTIONS(2521),
    [anon_sym_continue] = ACTIONS(2521),
    [anon_sym_goto] = ACTIONS(2521),
    [anon_sym___try] = ACTIONS(2521),
    [anon_sym___leave] = ACTIONS(2521),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_compl] = ACTIONS(2521),
    [anon_sym_DASH_DASH] = ACTIONS(2523),
    [anon_sym_PLUS_PLUS] = ACTIONS(2523),
    [anon_sym_sizeof] = ACTIONS(2521),
    [anon_sym___alignof__] = ACTIONS(2521),
    [anon_sym___alignof] = ACTIONS(2521),
    [anon_sym__alignof] = ACTIONS(2521),
    [anon_sym_alignof] = ACTIONS(2521),
    [anon_sym__Alignof] = ACTIONS(2521),
    [anon_sym_offsetof] = ACTIONS(2521),
    [anon_sym__Generic] = ACTIONS(2521),
    [anon_sym_asm] = ACTIONS(2521),
    [anon_sym___asm__] = ACTIONS(2521),
    [anon_sym___asm] = ACTIONS(2521),
    [sym_number_literal] = ACTIONS(2523),
    [anon_sym_L_SQUOTE] = ACTIONS(2523),
    [anon_sym_u_SQUOTE] = ACTIONS(2523),
    [anon_sym_U_SQUOTE] = ACTIONS(2523),
    [anon_sym_u8_SQUOTE] = ACTIONS(2523),
    [anon_sym_SQUOTE] = ACTIONS(2523),
    [anon_sym_L_DQUOTE] = ACTIONS(2523),
    [anon_sym_u_DQUOTE] = ACTIONS(2523),
    [anon_sym_U_DQUOTE] = ACTIONS(2523),
    [anon_sym_u8_DQUOTE] = ACTIONS(2523),
    [anon_sym_DQUOTE] = ACTIONS(2523),
    [sym_true] = ACTIONS(2521),
    [sym_false] = ACTIONS(2521),
    [anon_sym_NULL] = ACTIONS(2521),
    [anon_sym_nullptr] = ACTIONS(2521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2521),
    [anon_sym_decltype] = ACTIONS(2521),
    [anon_sym_explicit] = ACTIONS(2521),
    [anon_sym_typename] = ACTIONS(2521),
    [anon_sym_template] = ACTIONS(2521),
    [anon_sym_operator] = ACTIONS(2521),
    [anon_sym_try] = ACTIONS(2521),
    [anon_sym_delete] = ACTIONS(2521),
    [anon_sym_throw] = ACTIONS(2521),
    [anon_sym_namespace] = ACTIONS(2521),
    [anon_sym_using] = ACTIONS(2521),
    [anon_sym_static_assert] = ACTIONS(2521),
    [anon_sym_concept] = ACTIONS(2521),
    [anon_sym_co_return] = ACTIONS(2521),
    [anon_sym_co_yield] = ACTIONS(2521),
    [anon_sym_R_DQUOTE] = ACTIONS(2523),
    [anon_sym_LR_DQUOTE] = ACTIONS(2523),
    [anon_sym_uR_DQUOTE] = ACTIONS(2523),
    [anon_sym_UR_DQUOTE] = ACTIONS(2523),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2523),
    [anon_sym_co_await] = ACTIONS(2521),
    [anon_sym_new] = ACTIONS(2521),
    [anon_sym_requires] = ACTIONS(2521),
    [sym_this] = ACTIONS(2521),
    [anon_sym___launch_bounds__] = ACTIONS(2521),
  },
  [STATE(471)] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_include_token1] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym___device__] = ACTIONS(2561),
    [anon_sym___host__] = ACTIONS(2561),
    [anon_sym___global__] = ACTIONS(2561),
    [anon_sym___forceinline__] = ACTIONS(2561),
    [anon_sym___noinline__] = ACTIONS(2561),
    [anon_sym_virtual] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym___attribute] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym___cdecl] = ACTIONS(2561),
    [anon_sym___clrcall] = ACTIONS(2561),
    [anon_sym___stdcall] = ACTIONS(2561),
    [anon_sym___fastcall] = ACTIONS(2561),
    [anon_sym___thiscall] = ACTIONS(2561),
    [anon_sym___vectorcall] = ACTIONS(2561),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_RBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym__Nonnull] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym___shared__] = ACTIONS(2561),
    [anon_sym___local__] = ACTIONS(2561),
    [anon_sym___constant__] = ACTIONS(2561),
    [anon_sym___managed__] = ACTIONS(2561),
    [anon_sym___grid_constant__] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_switch] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_default] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_do] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_return] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_goto] = ACTIONS(2561),
    [anon_sym___try] = ACTIONS(2561),
    [anon_sym___leave] = ACTIONS(2561),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_compl] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2563),
    [anon_sym_sizeof] = ACTIONS(2561),
    [anon_sym___alignof__] = ACTIONS(2561),
    [anon_sym___alignof] = ACTIONS(2561),
    [anon_sym__alignof] = ACTIONS(2561),
    [anon_sym_alignof] = ACTIONS(2561),
    [anon_sym__Alignof] = ACTIONS(2561),
    [anon_sym_offsetof] = ACTIONS(2561),
    [anon_sym__Generic] = ACTIONS(2561),
    [anon_sym_asm] = ACTIONS(2561),
    [anon_sym___asm__] = ACTIONS(2561),
    [anon_sym___asm] = ACTIONS(2561),
    [sym_number_literal] = ACTIONS(2563),
    [anon_sym_L_SQUOTE] = ACTIONS(2563),
    [anon_sym_u_SQUOTE] = ACTIONS(2563),
    [anon_sym_U_SQUOTE] = ACTIONS(2563),
    [anon_sym_u8_SQUOTE] = ACTIONS(2563),
    [anon_sym_SQUOTE] = ACTIONS(2563),
    [anon_sym_L_DQUOTE] = ACTIONS(2563),
    [anon_sym_u_DQUOTE] = ACTIONS(2563),
    [anon_sym_U_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8_DQUOTE] = ACTIONS(2563),
    [anon_sym_DQUOTE] = ACTIONS(2563),
    [sym_true] = ACTIONS(2561),
    [sym_false] = ACTIONS(2561),
    [anon_sym_NULL] = ACTIONS(2561),
    [anon_sym_nullptr] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_try] = ACTIONS(2561),
    [anon_sym_delete] = ACTIONS(2561),
    [anon_sym_throw] = ACTIONS(2561),
    [anon_sym_namespace] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_concept] = ACTIONS(2561),
    [anon_sym_co_return] = ACTIONS(2561),
    [anon_sym_co_yield] = ACTIONS(2561),
    [anon_sym_R_DQUOTE] = ACTIONS(2563),
    [anon_sym_LR_DQUOTE] = ACTIONS(2563),
    [anon_sym_uR_DQUOTE] = ACTIONS(2563),
    [anon_sym_UR_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2563),
    [anon_sym_co_await] = ACTIONS(2561),
    [anon_sym_new] = ACTIONS(2561),
    [anon_sym_requires] = ACTIONS(2561),
    [sym_this] = ACTIONS(2561),
    [anon_sym___launch_bounds__] = ACTIONS(2561),
  },
  [STATE(472)] = {
    [sym_identifier] = ACTIONS(2513),
    [aux_sym_preproc_include_token1] = ACTIONS(2513),
    [aux_sym_preproc_def_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token2] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2513),
    [sym_preproc_directive] = ACTIONS(2513),
    [anon_sym_LPAREN2] = ACTIONS(2515),
    [anon_sym_BANG] = ACTIONS(2515),
    [anon_sym_TILDE] = ACTIONS(2515),
    [anon_sym_DASH] = ACTIONS(2513),
    [anon_sym_PLUS] = ACTIONS(2513),
    [anon_sym_STAR] = ACTIONS(2515),
    [anon_sym_AMP_AMP] = ACTIONS(2515),
    [anon_sym_AMP] = ACTIONS(2513),
    [anon_sym_SEMI] = ACTIONS(2515),
    [anon_sym___extension__] = ACTIONS(2513),
    [anon_sym_typedef] = ACTIONS(2513),
    [anon_sym___device__] = ACTIONS(2513),
    [anon_sym___host__] = ACTIONS(2513),
    [anon_sym___global__] = ACTIONS(2513),
    [anon_sym___forceinline__] = ACTIONS(2513),
    [anon_sym___noinline__] = ACTIONS(2513),
    [anon_sym_virtual] = ACTIONS(2513),
    [anon_sym_extern] = ACTIONS(2513),
    [anon_sym___attribute__] = ACTIONS(2513),
    [anon_sym___attribute] = ACTIONS(2513),
    [anon_sym_COLON_COLON] = ACTIONS(2515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2515),
    [anon_sym___declspec] = ACTIONS(2513),
    [anon_sym___based] = ACTIONS(2513),
    [anon_sym___cdecl] = ACTIONS(2513),
    [anon_sym___clrcall] = ACTIONS(2513),
    [anon_sym___stdcall] = ACTIONS(2513),
    [anon_sym___fastcall] = ACTIONS(2513),
    [anon_sym___thiscall] = ACTIONS(2513),
    [anon_sym___vectorcall] = ACTIONS(2513),
    [anon_sym_LBRACE] = ACTIONS(2515),
    [anon_sym_signed] = ACTIONS(2513),
    [anon_sym_unsigned] = ACTIONS(2513),
    [anon_sym_long] = ACTIONS(2513),
    [anon_sym_short] = ACTIONS(2513),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_static] = ACTIONS(2513),
    [anon_sym_register] = ACTIONS(2513),
    [anon_sym_inline] = ACTIONS(2513),
    [anon_sym___inline] = ACTIONS(2513),
    [anon_sym___inline__] = ACTIONS(2513),
    [anon_sym___forceinline] = ACTIONS(2513),
    [anon_sym_thread_local] = ACTIONS(2513),
    [anon_sym___thread] = ACTIONS(2513),
    [anon_sym_const] = ACTIONS(2513),
    [anon_sym_constexpr] = ACTIONS(2513),
    [anon_sym_volatile] = ACTIONS(2513),
    [anon_sym_restrict] = ACTIONS(2513),
    [anon_sym___restrict__] = ACTIONS(2513),
    [anon_sym__Atomic] = ACTIONS(2513),
    [anon_sym__Noreturn] = ACTIONS(2513),
    [anon_sym_noreturn] = ACTIONS(2513),
    [anon_sym__Nonnull] = ACTIONS(2513),
    [anon_sym_mutable] = ACTIONS(2513),
    [anon_sym_constinit] = ACTIONS(2513),
    [anon_sym_consteval] = ACTIONS(2513),
    [anon_sym___shared__] = ACTIONS(2513),
    [anon_sym___local__] = ACTIONS(2513),
    [anon_sym___constant__] = ACTIONS(2513),
    [anon_sym___managed__] = ACTIONS(2513),
    [anon_sym___grid_constant__] = ACTIONS(2513),
    [anon_sym_alignas] = ACTIONS(2513),
    [anon_sym__Alignas] = ACTIONS(2513),
    [sym_primitive_type] = ACTIONS(2513),
    [anon_sym_enum] = ACTIONS(2513),
    [anon_sym_class] = ACTIONS(2513),
    [anon_sym_struct] = ACTIONS(2513),
    [anon_sym_union] = ACTIONS(2513),
    [anon_sym_if] = ACTIONS(2513),
    [anon_sym_switch] = ACTIONS(2513),
    [anon_sym_case] = ACTIONS(2513),
    [anon_sym_default] = ACTIONS(2513),
    [anon_sym_while] = ACTIONS(2513),
    [anon_sym_do] = ACTIONS(2513),
    [anon_sym_for] = ACTIONS(2513),
    [anon_sym_return] = ACTIONS(2513),
    [anon_sym_break] = ACTIONS(2513),
    [anon_sym_continue] = ACTIONS(2513),
    [anon_sym_goto] = ACTIONS(2513),
    [anon_sym___try] = ACTIONS(2513),
    [anon_sym___leave] = ACTIONS(2513),
    [anon_sym_not] = ACTIONS(2513),
    [anon_sym_compl] = ACTIONS(2513),
    [anon_sym_DASH_DASH] = ACTIONS(2515),
    [anon_sym_PLUS_PLUS] = ACTIONS(2515),
    [anon_sym_sizeof] = ACTIONS(2513),
    [anon_sym___alignof__] = ACTIONS(2513),
    [anon_sym___alignof] = ACTIONS(2513),
    [anon_sym__alignof] = ACTIONS(2513),
    [anon_sym_alignof] = ACTIONS(2513),
    [anon_sym__Alignof] = ACTIONS(2513),
    [anon_sym_offsetof] = ACTIONS(2513),
    [anon_sym__Generic] = ACTIONS(2513),
    [anon_sym_asm] = ACTIONS(2513),
    [anon_sym___asm__] = ACTIONS(2513),
    [anon_sym___asm] = ACTIONS(2513),
    [sym_number_literal] = ACTIONS(2515),
    [anon_sym_L_SQUOTE] = ACTIONS(2515),
    [anon_sym_u_SQUOTE] = ACTIONS(2515),
    [anon_sym_U_SQUOTE] = ACTIONS(2515),
    [anon_sym_u8_SQUOTE] = ACTIONS(2515),
    [anon_sym_SQUOTE] = ACTIONS(2515),
    [anon_sym_L_DQUOTE] = ACTIONS(2515),
    [anon_sym_u_DQUOTE] = ACTIONS(2515),
    [anon_sym_U_DQUOTE] = ACTIONS(2515),
    [anon_sym_u8_DQUOTE] = ACTIONS(2515),
    [anon_sym_DQUOTE] = ACTIONS(2515),
    [sym_true] = ACTIONS(2513),
    [sym_false] = ACTIONS(2513),
    [anon_sym_NULL] = ACTIONS(2513),
    [anon_sym_nullptr] = ACTIONS(2513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2513),
    [anon_sym_decltype] = ACTIONS(2513),
    [anon_sym_explicit] = ACTIONS(2513),
    [anon_sym_typename] = ACTIONS(2513),
    [anon_sym_template] = ACTIONS(2513),
    [anon_sym_operator] = ACTIONS(2513),
    [anon_sym_try] = ACTIONS(2513),
    [anon_sym_delete] = ACTIONS(2513),
    [anon_sym_throw] = ACTIONS(2513),
    [anon_sym_namespace] = ACTIONS(2513),
    [anon_sym_using] = ACTIONS(2513),
    [anon_sym_static_assert] = ACTIONS(2513),
    [anon_sym_concept] = ACTIONS(2513),
    [anon_sym_co_return] = ACTIONS(2513),
    [anon_sym_co_yield] = ACTIONS(2513),
    [anon_sym_R_DQUOTE] = ACTIONS(2515),
    [anon_sym_LR_DQUOTE] = ACTIONS(2515),
    [anon_sym_uR_DQUOTE] = ACTIONS(2515),
    [anon_sym_UR_DQUOTE] = ACTIONS(2515),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2515),
    [anon_sym_co_await] = ACTIONS(2513),
    [anon_sym_new] = ACTIONS(2513),
    [anon_sym_requires] = ACTIONS(2513),
    [sym_this] = ACTIONS(2513),
    [anon_sym___launch_bounds__] = ACTIONS(2513),
  },
  [STATE(473)] = {
    [sym_identifier] = ACTIONS(2517),
    [aux_sym_preproc_include_token1] = ACTIONS(2517),
    [aux_sym_preproc_def_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token2] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2517),
    [sym_preproc_directive] = ACTIONS(2517),
    [anon_sym_LPAREN2] = ACTIONS(2519),
    [anon_sym_BANG] = ACTIONS(2519),
    [anon_sym_TILDE] = ACTIONS(2519),
    [anon_sym_DASH] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2519),
    [anon_sym_AMP_AMP] = ACTIONS(2519),
    [anon_sym_AMP] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym___extension__] = ACTIONS(2517),
    [anon_sym_typedef] = ACTIONS(2517),
    [anon_sym___device__] = ACTIONS(2517),
    [anon_sym___host__] = ACTIONS(2517),
    [anon_sym___global__] = ACTIONS(2517),
    [anon_sym___forceinline__] = ACTIONS(2517),
    [anon_sym___noinline__] = ACTIONS(2517),
    [anon_sym_virtual] = ACTIONS(2517),
    [anon_sym_extern] = ACTIONS(2517),
    [anon_sym___attribute__] = ACTIONS(2517),
    [anon_sym___attribute] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2519),
    [anon_sym___declspec] = ACTIONS(2517),
    [anon_sym___based] = ACTIONS(2517),
    [anon_sym___cdecl] = ACTIONS(2517),
    [anon_sym___clrcall] = ACTIONS(2517),
    [anon_sym___stdcall] = ACTIONS(2517),
    [anon_sym___fastcall] = ACTIONS(2517),
    [anon_sym___thiscall] = ACTIONS(2517),
    [anon_sym___vectorcall] = ACTIONS(2517),
    [anon_sym_LBRACE] = ACTIONS(2519),
    [anon_sym_signed] = ACTIONS(2517),
    [anon_sym_unsigned] = ACTIONS(2517),
    [anon_sym_long] = ACTIONS(2517),
    [anon_sym_short] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2517),
    [anon_sym_static] = ACTIONS(2517),
    [anon_sym_register] = ACTIONS(2517),
    [anon_sym_inline] = ACTIONS(2517),
    [anon_sym___inline] = ACTIONS(2517),
    [anon_sym___inline__] = ACTIONS(2517),
    [anon_sym___forceinline] = ACTIONS(2517),
    [anon_sym_thread_local] = ACTIONS(2517),
    [anon_sym___thread] = ACTIONS(2517),
    [anon_sym_const] = ACTIONS(2517),
    [anon_sym_constexpr] = ACTIONS(2517),
    [anon_sym_volatile] = ACTIONS(2517),
    [anon_sym_restrict] = ACTIONS(2517),
    [anon_sym___restrict__] = ACTIONS(2517),
    [anon_sym__Atomic] = ACTIONS(2517),
    [anon_sym__Noreturn] = ACTIONS(2517),
    [anon_sym_noreturn] = ACTIONS(2517),
    [anon_sym__Nonnull] = ACTIONS(2517),
    [anon_sym_mutable] = ACTIONS(2517),
    [anon_sym_constinit] = ACTIONS(2517),
    [anon_sym_consteval] = ACTIONS(2517),
    [anon_sym___shared__] = ACTIONS(2517),
    [anon_sym___local__] = ACTIONS(2517),
    [anon_sym___constant__] = ACTIONS(2517),
    [anon_sym___managed__] = ACTIONS(2517),
    [anon_sym___grid_constant__] = ACTIONS(2517),
    [anon_sym_alignas] = ACTIONS(2517),
    [anon_sym__Alignas] = ACTIONS(2517),
    [sym_primitive_type] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_class] = ACTIONS(2517),
    [anon_sym_struct] = ACTIONS(2517),
    [anon_sym_union] = ACTIONS(2517),
    [anon_sym_if] = ACTIONS(2517),
    [anon_sym_switch] = ACTIONS(2517),
    [anon_sym_case] = ACTIONS(2517),
    [anon_sym_default] = ACTIONS(2517),
    [anon_sym_while] = ACTIONS(2517),
    [anon_sym_do] = ACTIONS(2517),
    [anon_sym_for] = ACTIONS(2517),
    [anon_sym_return] = ACTIONS(2517),
    [anon_sym_break] = ACTIONS(2517),
    [anon_sym_continue] = ACTIONS(2517),
    [anon_sym_goto] = ACTIONS(2517),
    [anon_sym___try] = ACTIONS(2517),
    [anon_sym___leave] = ACTIONS(2517),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_compl] = ACTIONS(2517),
    [anon_sym_DASH_DASH] = ACTIONS(2519),
    [anon_sym_PLUS_PLUS] = ACTIONS(2519),
    [anon_sym_sizeof] = ACTIONS(2517),
    [anon_sym___alignof__] = ACTIONS(2517),
    [anon_sym___alignof] = ACTIONS(2517),
    [anon_sym__alignof] = ACTIONS(2517),
    [anon_sym_alignof] = ACTIONS(2517),
    [anon_sym__Alignof] = ACTIONS(2517),
    [anon_sym_offsetof] = ACTIONS(2517),
    [anon_sym__Generic] = ACTIONS(2517),
    [anon_sym_asm] = ACTIONS(2517),
    [anon_sym___asm__] = ACTIONS(2517),
    [anon_sym___asm] = ACTIONS(2517),
    [sym_number_literal] = ACTIONS(2519),
    [anon_sym_L_SQUOTE] = ACTIONS(2519),
    [anon_sym_u_SQUOTE] = ACTIONS(2519),
    [anon_sym_U_SQUOTE] = ACTIONS(2519),
    [anon_sym_u8_SQUOTE] = ACTIONS(2519),
    [anon_sym_SQUOTE] = ACTIONS(2519),
    [anon_sym_L_DQUOTE] = ACTIONS(2519),
    [anon_sym_u_DQUOTE] = ACTIONS(2519),
    [anon_sym_U_DQUOTE] = ACTIONS(2519),
    [anon_sym_u8_DQUOTE] = ACTIONS(2519),
    [anon_sym_DQUOTE] = ACTIONS(2519),
    [sym_true] = ACTIONS(2517),
    [sym_false] = ACTIONS(2517),
    [anon_sym_NULL] = ACTIONS(2517),
    [anon_sym_nullptr] = ACTIONS(2517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2517),
    [anon_sym_decltype] = ACTIONS(2517),
    [anon_sym_explicit] = ACTIONS(2517),
    [anon_sym_typename] = ACTIONS(2517),
    [anon_sym_template] = ACTIONS(2517),
    [anon_sym_operator] = ACTIONS(2517),
    [anon_sym_try] = ACTIONS(2517),
    [anon_sym_delete] = ACTIONS(2517),
    [anon_sym_throw] = ACTIONS(2517),
    [anon_sym_namespace] = ACTIONS(2517),
    [anon_sym_using] = ACTIONS(2517),
    [anon_sym_static_assert] = ACTIONS(2517),
    [anon_sym_concept] = ACTIONS(2517),
    [anon_sym_co_return] = ACTIONS(2517),
    [anon_sym_co_yield] = ACTIONS(2517),
    [anon_sym_R_DQUOTE] = ACTIONS(2519),
    [anon_sym_LR_DQUOTE] = ACTIONS(2519),
    [anon_sym_uR_DQUOTE] = ACTIONS(2519),
    [anon_sym_UR_DQUOTE] = ACTIONS(2519),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2519),
    [anon_sym_co_await] = ACTIONS(2517),
    [anon_sym_new] = ACTIONS(2517),
    [anon_sym_requires] = ACTIONS(2517),
    [sym_this] = ACTIONS(2517),
    [anon_sym___launch_bounds__] = ACTIONS(2517),
  },
  [STATE(474)] = {
    [sym_identifier] = ACTIONS(2525),
    [aux_sym_preproc_include_token1] = ACTIONS(2525),
    [aux_sym_preproc_def_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token2] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2525),
    [sym_preproc_directive] = ACTIONS(2525),
    [anon_sym_LPAREN2] = ACTIONS(2527),
    [anon_sym_BANG] = ACTIONS(2527),
    [anon_sym_TILDE] = ACTIONS(2527),
    [anon_sym_DASH] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2527),
    [anon_sym_AMP_AMP] = ACTIONS(2527),
    [anon_sym_AMP] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym___extension__] = ACTIONS(2525),
    [anon_sym_typedef] = ACTIONS(2525),
    [anon_sym___device__] = ACTIONS(2525),
    [anon_sym___host__] = ACTIONS(2525),
    [anon_sym___global__] = ACTIONS(2525),
    [anon_sym___forceinline__] = ACTIONS(2525),
    [anon_sym___noinline__] = ACTIONS(2525),
    [anon_sym_virtual] = ACTIONS(2525),
    [anon_sym_extern] = ACTIONS(2525),
    [anon_sym___attribute__] = ACTIONS(2525),
    [anon_sym___attribute] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2527),
    [anon_sym___declspec] = ACTIONS(2525),
    [anon_sym___based] = ACTIONS(2525),
    [anon_sym___cdecl] = ACTIONS(2525),
    [anon_sym___clrcall] = ACTIONS(2525),
    [anon_sym___stdcall] = ACTIONS(2525),
    [anon_sym___fastcall] = ACTIONS(2525),
    [anon_sym___thiscall] = ACTIONS(2525),
    [anon_sym___vectorcall] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_signed] = ACTIONS(2525),
    [anon_sym_unsigned] = ACTIONS(2525),
    [anon_sym_long] = ACTIONS(2525),
    [anon_sym_short] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2525),
    [anon_sym_static] = ACTIONS(2525),
    [anon_sym_register] = ACTIONS(2525),
    [anon_sym_inline] = ACTIONS(2525),
    [anon_sym___inline] = ACTIONS(2525),
    [anon_sym___inline__] = ACTIONS(2525),
    [anon_sym___forceinline] = ACTIONS(2525),
    [anon_sym_thread_local] = ACTIONS(2525),
    [anon_sym___thread] = ACTIONS(2525),
    [anon_sym_const] = ACTIONS(2525),
    [anon_sym_constexpr] = ACTIONS(2525),
    [anon_sym_volatile] = ACTIONS(2525),
    [anon_sym_restrict] = ACTIONS(2525),
    [anon_sym___restrict__] = ACTIONS(2525),
    [anon_sym__Atomic] = ACTIONS(2525),
    [anon_sym__Noreturn] = ACTIONS(2525),
    [anon_sym_noreturn] = ACTIONS(2525),
    [anon_sym__Nonnull] = ACTIONS(2525),
    [anon_sym_mutable] = ACTIONS(2525),
    [anon_sym_constinit] = ACTIONS(2525),
    [anon_sym_consteval] = ACTIONS(2525),
    [anon_sym___shared__] = ACTIONS(2525),
    [anon_sym___local__] = ACTIONS(2525),
    [anon_sym___constant__] = ACTIONS(2525),
    [anon_sym___managed__] = ACTIONS(2525),
    [anon_sym___grid_constant__] = ACTIONS(2525),
    [anon_sym_alignas] = ACTIONS(2525),
    [anon_sym__Alignas] = ACTIONS(2525),
    [sym_primitive_type] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_class] = ACTIONS(2525),
    [anon_sym_struct] = ACTIONS(2525),
    [anon_sym_union] = ACTIONS(2525),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_switch] = ACTIONS(2525),
    [anon_sym_case] = ACTIONS(2525),
    [anon_sym_default] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(2525),
    [anon_sym_do] = ACTIONS(2525),
    [anon_sym_for] = ACTIONS(2525),
    [anon_sym_return] = ACTIONS(2525),
    [anon_sym_break] = ACTIONS(2525),
    [anon_sym_continue] = ACTIONS(2525),
    [anon_sym_goto] = ACTIONS(2525),
    [anon_sym___try] = ACTIONS(2525),
    [anon_sym___leave] = ACTIONS(2525),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_compl] = ACTIONS(2525),
    [anon_sym_DASH_DASH] = ACTIONS(2527),
    [anon_sym_PLUS_PLUS] = ACTIONS(2527),
    [anon_sym_sizeof] = ACTIONS(2525),
    [anon_sym___alignof__] = ACTIONS(2525),
    [anon_sym___alignof] = ACTIONS(2525),
    [anon_sym__alignof] = ACTIONS(2525),
    [anon_sym_alignof] = ACTIONS(2525),
    [anon_sym__Alignof] = ACTIONS(2525),
    [anon_sym_offsetof] = ACTIONS(2525),
    [anon_sym__Generic] = ACTIONS(2525),
    [anon_sym_asm] = ACTIONS(2525),
    [anon_sym___asm__] = ACTIONS(2525),
    [anon_sym___asm] = ACTIONS(2525),
    [sym_number_literal] = ACTIONS(2527),
    [anon_sym_L_SQUOTE] = ACTIONS(2527),
    [anon_sym_u_SQUOTE] = ACTIONS(2527),
    [anon_sym_U_SQUOTE] = ACTIONS(2527),
    [anon_sym_u8_SQUOTE] = ACTIONS(2527),
    [anon_sym_SQUOTE] = ACTIONS(2527),
    [anon_sym_L_DQUOTE] = ACTIONS(2527),
    [anon_sym_u_DQUOTE] = ACTIONS(2527),
    [anon_sym_U_DQUOTE] = ACTIONS(2527),
    [anon_sym_u8_DQUOTE] = ACTIONS(2527),
    [anon_sym_DQUOTE] = ACTIONS(2527),
    [sym_true] = ACTIONS(2525),
    [sym_false] = ACTIONS(2525),
    [anon_sym_NULL] = ACTIONS(2525),
    [anon_sym_nullptr] = ACTIONS(2525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2525),
    [anon_sym_decltype] = ACTIONS(2525),
    [anon_sym_explicit] = ACTIONS(2525),
    [anon_sym_typename] = ACTIONS(2525),
    [anon_sym_template] = ACTIONS(2525),
    [anon_sym_operator] = ACTIONS(2525),
    [anon_sym_try] = ACTIONS(2525),
    [anon_sym_delete] = ACTIONS(2525),
    [anon_sym_throw] = ACTIONS(2525),
    [anon_sym_namespace] = ACTIONS(2525),
    [anon_sym_using] = ACTIONS(2525),
    [anon_sym_static_assert] = ACTIONS(2525),
    [anon_sym_concept] = ACTIONS(2525),
    [anon_sym_co_return] = ACTIONS(2525),
    [anon_sym_co_yield] = ACTIONS(2525),
    [anon_sym_R_DQUOTE] = ACTIONS(2527),
    [anon_sym_LR_DQUOTE] = ACTIONS(2527),
    [anon_sym_uR_DQUOTE] = ACTIONS(2527),
    [anon_sym_UR_DQUOTE] = ACTIONS(2527),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2527),
    [anon_sym_co_await] = ACTIONS(2525),
    [anon_sym_new] = ACTIONS(2525),
    [anon_sym_requires] = ACTIONS(2525),
    [sym_this] = ACTIONS(2525),
    [anon_sym___launch_bounds__] = ACTIONS(2525),
  },
  [STATE(475)] = {
    [sym_identifier] = ACTIONS(2529),
    [aux_sym_preproc_include_token1] = ACTIONS(2529),
    [aux_sym_preproc_def_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token2] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2529),
    [sym_preproc_directive] = ACTIONS(2529),
    [anon_sym_LPAREN2] = ACTIONS(2531),
    [anon_sym_BANG] = ACTIONS(2531),
    [anon_sym_TILDE] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2531),
    [anon_sym_AMP_AMP] = ACTIONS(2531),
    [anon_sym_AMP] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym___extension__] = ACTIONS(2529),
    [anon_sym_typedef] = ACTIONS(2529),
    [anon_sym___device__] = ACTIONS(2529),
    [anon_sym___host__] = ACTIONS(2529),
    [anon_sym___global__] = ACTIONS(2529),
    [anon_sym___forceinline__] = ACTIONS(2529),
    [anon_sym___noinline__] = ACTIONS(2529),
    [anon_sym_virtual] = ACTIONS(2529),
    [anon_sym_extern] = ACTIONS(2529),
    [anon_sym___attribute__] = ACTIONS(2529),
    [anon_sym___attribute] = ACTIONS(2529),
    [anon_sym_COLON_COLON] = ACTIONS(2531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2531),
    [anon_sym___declspec] = ACTIONS(2529),
    [anon_sym___based] = ACTIONS(2529),
    [anon_sym___cdecl] = ACTIONS(2529),
    [anon_sym___clrcall] = ACTIONS(2529),
    [anon_sym___stdcall] = ACTIONS(2529),
    [anon_sym___fastcall] = ACTIONS(2529),
    [anon_sym___thiscall] = ACTIONS(2529),
    [anon_sym___vectorcall] = ACTIONS(2529),
    [anon_sym_LBRACE] = ACTIONS(2531),
    [anon_sym_signed] = ACTIONS(2529),
    [anon_sym_unsigned] = ACTIONS(2529),
    [anon_sym_long] = ACTIONS(2529),
    [anon_sym_short] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2529),
    [anon_sym_register] = ACTIONS(2529),
    [anon_sym_inline] = ACTIONS(2529),
    [anon_sym___inline] = ACTIONS(2529),
    [anon_sym___inline__] = ACTIONS(2529),
    [anon_sym___forceinline] = ACTIONS(2529),
    [anon_sym_thread_local] = ACTIONS(2529),
    [anon_sym___thread] = ACTIONS(2529),
    [anon_sym_const] = ACTIONS(2529),
    [anon_sym_constexpr] = ACTIONS(2529),
    [anon_sym_volatile] = ACTIONS(2529),
    [anon_sym_restrict] = ACTIONS(2529),
    [anon_sym___restrict__] = ACTIONS(2529),
    [anon_sym__Atomic] = ACTIONS(2529),
    [anon_sym__Noreturn] = ACTIONS(2529),
    [anon_sym_noreturn] = ACTIONS(2529),
    [anon_sym__Nonnull] = ACTIONS(2529),
    [anon_sym_mutable] = ACTIONS(2529),
    [anon_sym_constinit] = ACTIONS(2529),
    [anon_sym_consteval] = ACTIONS(2529),
    [anon_sym___shared__] = ACTIONS(2529),
    [anon_sym___local__] = ACTIONS(2529),
    [anon_sym___constant__] = ACTIONS(2529),
    [anon_sym___managed__] = ACTIONS(2529),
    [anon_sym___grid_constant__] = ACTIONS(2529),
    [anon_sym_alignas] = ACTIONS(2529),
    [anon_sym__Alignas] = ACTIONS(2529),
    [sym_primitive_type] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2529),
    [anon_sym_struct] = ACTIONS(2529),
    [anon_sym_union] = ACTIONS(2529),
    [anon_sym_if] = ACTIONS(2529),
    [anon_sym_switch] = ACTIONS(2529),
    [anon_sym_case] = ACTIONS(2529),
    [anon_sym_default] = ACTIONS(2529),
    [anon_sym_while] = ACTIONS(2529),
    [anon_sym_do] = ACTIONS(2529),
    [anon_sym_for] = ACTIONS(2529),
    [anon_sym_return] = ACTIONS(2529),
    [anon_sym_break] = ACTIONS(2529),
    [anon_sym_continue] = ACTIONS(2529),
    [anon_sym_goto] = ACTIONS(2529),
    [anon_sym___try] = ACTIONS(2529),
    [anon_sym___leave] = ACTIONS(2529),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_compl] = ACTIONS(2529),
    [anon_sym_DASH_DASH] = ACTIONS(2531),
    [anon_sym_PLUS_PLUS] = ACTIONS(2531),
    [anon_sym_sizeof] = ACTIONS(2529),
    [anon_sym___alignof__] = ACTIONS(2529),
    [anon_sym___alignof] = ACTIONS(2529),
    [anon_sym__alignof] = ACTIONS(2529),
    [anon_sym_alignof] = ACTIONS(2529),
    [anon_sym__Alignof] = ACTIONS(2529),
    [anon_sym_offsetof] = ACTIONS(2529),
    [anon_sym__Generic] = ACTIONS(2529),
    [anon_sym_asm] = ACTIONS(2529),
    [anon_sym___asm__] = ACTIONS(2529),
    [anon_sym___asm] = ACTIONS(2529),
    [sym_number_literal] = ACTIONS(2531),
    [anon_sym_L_SQUOTE] = ACTIONS(2531),
    [anon_sym_u_SQUOTE] = ACTIONS(2531),
    [anon_sym_U_SQUOTE] = ACTIONS(2531),
    [anon_sym_u8_SQUOTE] = ACTIONS(2531),
    [anon_sym_SQUOTE] = ACTIONS(2531),
    [anon_sym_L_DQUOTE] = ACTIONS(2531),
    [anon_sym_u_DQUOTE] = ACTIONS(2531),
    [anon_sym_U_DQUOTE] = ACTIONS(2531),
    [anon_sym_u8_DQUOTE] = ACTIONS(2531),
    [anon_sym_DQUOTE] = ACTIONS(2531),
    [sym_true] = ACTIONS(2529),
    [sym_false] = ACTIONS(2529),
    [anon_sym_NULL] = ACTIONS(2529),
    [anon_sym_nullptr] = ACTIONS(2529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2529),
    [anon_sym_decltype] = ACTIONS(2529),
    [anon_sym_explicit] = ACTIONS(2529),
    [anon_sym_typename] = ACTIONS(2529),
    [anon_sym_template] = ACTIONS(2529),
    [anon_sym_operator] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2529),
    [anon_sym_delete] = ACTIONS(2529),
    [anon_sym_throw] = ACTIONS(2529),
    [anon_sym_namespace] = ACTIONS(2529),
    [anon_sym_using] = ACTIONS(2529),
    [anon_sym_static_assert] = ACTIONS(2529),
    [anon_sym_concept] = ACTIONS(2529),
    [anon_sym_co_return] = ACTIONS(2529),
    [anon_sym_co_yield] = ACTIONS(2529),
    [anon_sym_R_DQUOTE] = ACTIONS(2531),
    [anon_sym_LR_DQUOTE] = ACTIONS(2531),
    [anon_sym_uR_DQUOTE] = ACTIONS(2531),
    [anon_sym_UR_DQUOTE] = ACTIONS(2531),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2531),
    [anon_sym_co_await] = ACTIONS(2529),
    [anon_sym_new] = ACTIONS(2529),
    [anon_sym_requires] = ACTIONS(2529),
    [sym_this] = ACTIONS(2529),
    [anon_sym___launch_bounds__] = ACTIONS(2529),
  },
  [STATE(476)] = {
    [sym_identifier] = ACTIONS(2541),
    [aux_sym_preproc_include_token1] = ACTIONS(2541),
    [aux_sym_preproc_def_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token2] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2541),
    [sym_preproc_directive] = ACTIONS(2541),
    [anon_sym_LPAREN2] = ACTIONS(2543),
    [anon_sym_BANG] = ACTIONS(2543),
    [anon_sym_TILDE] = ACTIONS(2543),
    [anon_sym_DASH] = ACTIONS(2541),
    [anon_sym_PLUS] = ACTIONS(2541),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_AMP_AMP] = ACTIONS(2543),
    [anon_sym_AMP] = ACTIONS(2541),
    [anon_sym_SEMI] = ACTIONS(2543),
    [anon_sym___extension__] = ACTIONS(2541),
    [anon_sym_typedef] = ACTIONS(2541),
    [anon_sym___device__] = ACTIONS(2541),
    [anon_sym___host__] = ACTIONS(2541),
    [anon_sym___global__] = ACTIONS(2541),
    [anon_sym___forceinline__] = ACTIONS(2541),
    [anon_sym___noinline__] = ACTIONS(2541),
    [anon_sym_virtual] = ACTIONS(2541),
    [anon_sym_extern] = ACTIONS(2541),
    [anon_sym___attribute__] = ACTIONS(2541),
    [anon_sym___attribute] = ACTIONS(2541),
    [anon_sym_COLON_COLON] = ACTIONS(2543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2543),
    [anon_sym___declspec] = ACTIONS(2541),
    [anon_sym___based] = ACTIONS(2541),
    [anon_sym___cdecl] = ACTIONS(2541),
    [anon_sym___clrcall] = ACTIONS(2541),
    [anon_sym___stdcall] = ACTIONS(2541),
    [anon_sym___fastcall] = ACTIONS(2541),
    [anon_sym___thiscall] = ACTIONS(2541),
    [anon_sym___vectorcall] = ACTIONS(2541),
    [anon_sym_LBRACE] = ACTIONS(2543),
    [anon_sym_signed] = ACTIONS(2541),
    [anon_sym_unsigned] = ACTIONS(2541),
    [anon_sym_long] = ACTIONS(2541),
    [anon_sym_short] = ACTIONS(2541),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [anon_sym_static] = ACTIONS(2541),
    [anon_sym_register] = ACTIONS(2541),
    [anon_sym_inline] = ACTIONS(2541),
    [anon_sym___inline] = ACTIONS(2541),
    [anon_sym___inline__] = ACTIONS(2541),
    [anon_sym___forceinline] = ACTIONS(2541),
    [anon_sym_thread_local] = ACTIONS(2541),
    [anon_sym___thread] = ACTIONS(2541),
    [anon_sym_const] = ACTIONS(2541),
    [anon_sym_constexpr] = ACTIONS(2541),
    [anon_sym_volatile] = ACTIONS(2541),
    [anon_sym_restrict] = ACTIONS(2541),
    [anon_sym___restrict__] = ACTIONS(2541),
    [anon_sym__Atomic] = ACTIONS(2541),
    [anon_sym__Noreturn] = ACTIONS(2541),
    [anon_sym_noreturn] = ACTIONS(2541),
    [anon_sym__Nonnull] = ACTIONS(2541),
    [anon_sym_mutable] = ACTIONS(2541),
    [anon_sym_constinit] = ACTIONS(2541),
    [anon_sym_consteval] = ACTIONS(2541),
    [anon_sym___shared__] = ACTIONS(2541),
    [anon_sym___local__] = ACTIONS(2541),
    [anon_sym___constant__] = ACTIONS(2541),
    [anon_sym___managed__] = ACTIONS(2541),
    [anon_sym___grid_constant__] = ACTIONS(2541),
    [anon_sym_alignas] = ACTIONS(2541),
    [anon_sym__Alignas] = ACTIONS(2541),
    [sym_primitive_type] = ACTIONS(2541),
    [anon_sym_enum] = ACTIONS(2541),
    [anon_sym_class] = ACTIONS(2541),
    [anon_sym_struct] = ACTIONS(2541),
    [anon_sym_union] = ACTIONS(2541),
    [anon_sym_if] = ACTIONS(2541),
    [anon_sym_switch] = ACTIONS(2541),
    [anon_sym_case] = ACTIONS(2541),
    [anon_sym_default] = ACTIONS(2541),
    [anon_sym_while] = ACTIONS(2541),
    [anon_sym_do] = ACTIONS(2541),
    [anon_sym_for] = ACTIONS(2541),
    [anon_sym_return] = ACTIONS(2541),
    [anon_sym_break] = ACTIONS(2541),
    [anon_sym_continue] = ACTIONS(2541),
    [anon_sym_goto] = ACTIONS(2541),
    [anon_sym___try] = ACTIONS(2541),
    [anon_sym___leave] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2541),
    [anon_sym_compl] = ACTIONS(2541),
    [anon_sym_DASH_DASH] = ACTIONS(2543),
    [anon_sym_PLUS_PLUS] = ACTIONS(2543),
    [anon_sym_sizeof] = ACTIONS(2541),
    [anon_sym___alignof__] = ACTIONS(2541),
    [anon_sym___alignof] = ACTIONS(2541),
    [anon_sym__alignof] = ACTIONS(2541),
    [anon_sym_alignof] = ACTIONS(2541),
    [anon_sym__Alignof] = ACTIONS(2541),
    [anon_sym_offsetof] = ACTIONS(2541),
    [anon_sym__Generic] = ACTIONS(2541),
    [anon_sym_asm] = ACTIONS(2541),
    [anon_sym___asm__] = ACTIONS(2541),
    [anon_sym___asm] = ACTIONS(2541),
    [sym_number_literal] = ACTIONS(2543),
    [anon_sym_L_SQUOTE] = ACTIONS(2543),
    [anon_sym_u_SQUOTE] = ACTIONS(2543),
    [anon_sym_U_SQUOTE] = ACTIONS(2543),
    [anon_sym_u8_SQUOTE] = ACTIONS(2543),
    [anon_sym_SQUOTE] = ACTIONS(2543),
    [anon_sym_L_DQUOTE] = ACTIONS(2543),
    [anon_sym_u_DQUOTE] = ACTIONS(2543),
    [anon_sym_U_DQUOTE] = ACTIONS(2543),
    [anon_sym_u8_DQUOTE] = ACTIONS(2543),
    [anon_sym_DQUOTE] = ACTIONS(2543),
    [sym_true] = ACTIONS(2541),
    [sym_false] = ACTIONS(2541),
    [anon_sym_NULL] = ACTIONS(2541),
    [anon_sym_nullptr] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2541),
    [anon_sym_decltype] = ACTIONS(2541),
    [anon_sym_explicit] = ACTIONS(2541),
    [anon_sym_typename] = ACTIONS(2541),
    [anon_sym_template] = ACTIONS(2541),
    [anon_sym_operator] = ACTIONS(2541),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_delete] = ACTIONS(2541),
    [anon_sym_throw] = ACTIONS(2541),
    [anon_sym_namespace] = ACTIONS(2541),
    [anon_sym_using] = ACTIONS(2541),
    [anon_sym_static_assert] = ACTIONS(2541),
    [anon_sym_concept] = ACTIONS(2541),
    [anon_sym_co_return] = ACTIONS(2541),
    [anon_sym_co_yield] = ACTIONS(2541),
    [anon_sym_R_DQUOTE] = ACTIONS(2543),
    [anon_sym_LR_DQUOTE] = ACTIONS(2543),
    [anon_sym_uR_DQUOTE] = ACTIONS(2543),
    [anon_sym_UR_DQUOTE] = ACTIONS(2543),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2543),
    [anon_sym_co_await] = ACTIONS(2541),
    [anon_sym_new] = ACTIONS(2541),
    [anon_sym_requires] = ACTIONS(2541),
    [sym_this] = ACTIONS(2541),
    [anon_sym___launch_bounds__] = ACTIONS(2541),
  },
  [STATE(477)] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_include_token1] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token2] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2549),
    [anon_sym_PLUS] = ACTIONS(2549),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym___device__] = ACTIONS(2549),
    [anon_sym___host__] = ACTIONS(2549),
    [anon_sym___global__] = ACTIONS(2549),
    [anon_sym___forceinline__] = ACTIONS(2549),
    [anon_sym___noinline__] = ACTIONS(2549),
    [anon_sym_virtual] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym___attribute] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym___cdecl] = ACTIONS(2549),
    [anon_sym___clrcall] = ACTIONS(2549),
    [anon_sym___stdcall] = ACTIONS(2549),
    [anon_sym___fastcall] = ACTIONS(2549),
    [anon_sym___thiscall] = ACTIONS(2549),
    [anon_sym___vectorcall] = ACTIONS(2549),
    [anon_sym_LBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym__Nonnull] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym___shared__] = ACTIONS(2549),
    [anon_sym___local__] = ACTIONS(2549),
    [anon_sym___constant__] = ACTIONS(2549),
    [anon_sym___managed__] = ACTIONS(2549),
    [anon_sym___grid_constant__] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2549),
    [anon_sym_switch] = ACTIONS(2549),
    [anon_sym_case] = ACTIONS(2549),
    [anon_sym_default] = ACTIONS(2549),
    [anon_sym_while] = ACTIONS(2549),
    [anon_sym_do] = ACTIONS(2549),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_return] = ACTIONS(2549),
    [anon_sym_break] = ACTIONS(2549),
    [anon_sym_continue] = ACTIONS(2549),
    [anon_sym_goto] = ACTIONS(2549),
    [anon_sym___try] = ACTIONS(2549),
    [anon_sym___leave] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2549),
    [anon_sym_compl] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2551),
    [anon_sym_sizeof] = ACTIONS(2549),
    [anon_sym___alignof__] = ACTIONS(2549),
    [anon_sym___alignof] = ACTIONS(2549),
    [anon_sym__alignof] = ACTIONS(2549),
    [anon_sym_alignof] = ACTIONS(2549),
    [anon_sym__Alignof] = ACTIONS(2549),
    [anon_sym_offsetof] = ACTIONS(2549),
    [anon_sym__Generic] = ACTIONS(2549),
    [anon_sym_asm] = ACTIONS(2549),
    [anon_sym___asm__] = ACTIONS(2549),
    [anon_sym___asm] = ACTIONS(2549),
    [sym_number_literal] = ACTIONS(2551),
    [anon_sym_L_SQUOTE] = ACTIONS(2551),
    [anon_sym_u_SQUOTE] = ACTIONS(2551),
    [anon_sym_U_SQUOTE] = ACTIONS(2551),
    [anon_sym_u8_SQUOTE] = ACTIONS(2551),
    [anon_sym_SQUOTE] = ACTIONS(2551),
    [anon_sym_L_DQUOTE] = ACTIONS(2551),
    [anon_sym_u_DQUOTE] = ACTIONS(2551),
    [anon_sym_U_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8_DQUOTE] = ACTIONS(2551),
    [anon_sym_DQUOTE] = ACTIONS(2551),
    [sym_true] = ACTIONS(2549),
    [sym_false] = ACTIONS(2549),
    [anon_sym_NULL] = ACTIONS(2549),
    [anon_sym_nullptr] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_try] = ACTIONS(2549),
    [anon_sym_delete] = ACTIONS(2549),
    [anon_sym_throw] = ACTIONS(2549),
    [anon_sym_namespace] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_concept] = ACTIONS(2549),
    [anon_sym_co_return] = ACTIONS(2549),
    [anon_sym_co_yield] = ACTIONS(2549),
    [anon_sym_R_DQUOTE] = ACTIONS(2551),
    [anon_sym_LR_DQUOTE] = ACTIONS(2551),
    [anon_sym_uR_DQUOTE] = ACTIONS(2551),
    [anon_sym_UR_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2551),
    [anon_sym_co_await] = ACTIONS(2549),
    [anon_sym_new] = ACTIONS(2549),
    [anon_sym_requires] = ACTIONS(2549),
    [sym_this] = ACTIONS(2549),
    [anon_sym___launch_bounds__] = ACTIONS(2549),
  },
  [STATE(478)] = {
    [sym_identifier] = ACTIONS(2537),
    [aux_sym_preproc_include_token1] = ACTIONS(2537),
    [aux_sym_preproc_def_token1] = ACTIONS(2537),
    [aux_sym_preproc_if_token1] = ACTIONS(2537),
    [aux_sym_preproc_if_token2] = ACTIONS(2537),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2537),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2537),
    [sym_preproc_directive] = ACTIONS(2537),
    [anon_sym_LPAREN2] = ACTIONS(2539),
    [anon_sym_BANG] = ACTIONS(2539),
    [anon_sym_TILDE] = ACTIONS(2539),
    [anon_sym_DASH] = ACTIONS(2537),
    [anon_sym_PLUS] = ACTIONS(2537),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_AMP_AMP] = ACTIONS(2539),
    [anon_sym_AMP] = ACTIONS(2537),
    [anon_sym_SEMI] = ACTIONS(2539),
    [anon_sym___extension__] = ACTIONS(2537),
    [anon_sym_typedef] = ACTIONS(2537),
    [anon_sym___device__] = ACTIONS(2537),
    [anon_sym___host__] = ACTIONS(2537),
    [anon_sym___global__] = ACTIONS(2537),
    [anon_sym___forceinline__] = ACTIONS(2537),
    [anon_sym___noinline__] = ACTIONS(2537),
    [anon_sym_virtual] = ACTIONS(2537),
    [anon_sym_extern] = ACTIONS(2537),
    [anon_sym___attribute__] = ACTIONS(2537),
    [anon_sym___attribute] = ACTIONS(2537),
    [anon_sym_COLON_COLON] = ACTIONS(2539),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2539),
    [anon_sym___declspec] = ACTIONS(2537),
    [anon_sym___based] = ACTIONS(2537),
    [anon_sym___cdecl] = ACTIONS(2537),
    [anon_sym___clrcall] = ACTIONS(2537),
    [anon_sym___stdcall] = ACTIONS(2537),
    [anon_sym___fastcall] = ACTIONS(2537),
    [anon_sym___thiscall] = ACTIONS(2537),
    [anon_sym___vectorcall] = ACTIONS(2537),
    [anon_sym_LBRACE] = ACTIONS(2539),
    [anon_sym_signed] = ACTIONS(2537),
    [anon_sym_unsigned] = ACTIONS(2537),
    [anon_sym_long] = ACTIONS(2537),
    [anon_sym_short] = ACTIONS(2537),
    [anon_sym_LBRACK] = ACTIONS(2537),
    [anon_sym_static] = ACTIONS(2537),
    [anon_sym_register] = ACTIONS(2537),
    [anon_sym_inline] = ACTIONS(2537),
    [anon_sym___inline] = ACTIONS(2537),
    [anon_sym___inline__] = ACTIONS(2537),
    [anon_sym___forceinline] = ACTIONS(2537),
    [anon_sym_thread_local] = ACTIONS(2537),
    [anon_sym___thread] = ACTIONS(2537),
    [anon_sym_const] = ACTIONS(2537),
    [anon_sym_constexpr] = ACTIONS(2537),
    [anon_sym_volatile] = ACTIONS(2537),
    [anon_sym_restrict] = ACTIONS(2537),
    [anon_sym___restrict__] = ACTIONS(2537),
    [anon_sym__Atomic] = ACTIONS(2537),
    [anon_sym__Noreturn] = ACTIONS(2537),
    [anon_sym_noreturn] = ACTIONS(2537),
    [anon_sym__Nonnull] = ACTIONS(2537),
    [anon_sym_mutable] = ACTIONS(2537),
    [anon_sym_constinit] = ACTIONS(2537),
    [anon_sym_consteval] = ACTIONS(2537),
    [anon_sym___shared__] = ACTIONS(2537),
    [anon_sym___local__] = ACTIONS(2537),
    [anon_sym___constant__] = ACTIONS(2537),
    [anon_sym___managed__] = ACTIONS(2537),
    [anon_sym___grid_constant__] = ACTIONS(2537),
    [anon_sym_alignas] = ACTIONS(2537),
    [anon_sym__Alignas] = ACTIONS(2537),
    [sym_primitive_type] = ACTIONS(2537),
    [anon_sym_enum] = ACTIONS(2537),
    [anon_sym_class] = ACTIONS(2537),
    [anon_sym_struct] = ACTIONS(2537),
    [anon_sym_union] = ACTIONS(2537),
    [anon_sym_if] = ACTIONS(2537),
    [anon_sym_switch] = ACTIONS(2537),
    [anon_sym_case] = ACTIONS(2537),
    [anon_sym_default] = ACTIONS(2537),
    [anon_sym_while] = ACTIONS(2537),
    [anon_sym_do] = ACTIONS(2537),
    [anon_sym_for] = ACTIONS(2537),
    [anon_sym_return] = ACTIONS(2537),
    [anon_sym_break] = ACTIONS(2537),
    [anon_sym_continue] = ACTIONS(2537),
    [anon_sym_goto] = ACTIONS(2537),
    [anon_sym___try] = ACTIONS(2537),
    [anon_sym___leave] = ACTIONS(2537),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_compl] = ACTIONS(2537),
    [anon_sym_DASH_DASH] = ACTIONS(2539),
    [anon_sym_PLUS_PLUS] = ACTIONS(2539),
    [anon_sym_sizeof] = ACTIONS(2537),
    [anon_sym___alignof__] = ACTIONS(2537),
    [anon_sym___alignof] = ACTIONS(2537),
    [anon_sym__alignof] = ACTIONS(2537),
    [anon_sym_alignof] = ACTIONS(2537),
    [anon_sym__Alignof] = ACTIONS(2537),
    [anon_sym_offsetof] = ACTIONS(2537),
    [anon_sym__Generic] = ACTIONS(2537),
    [anon_sym_asm] = ACTIONS(2537),
    [anon_sym___asm__] = ACTIONS(2537),
    [anon_sym___asm] = ACTIONS(2537),
    [sym_number_literal] = ACTIONS(2539),
    [anon_sym_L_SQUOTE] = ACTIONS(2539),
    [anon_sym_u_SQUOTE] = ACTIONS(2539),
    [anon_sym_U_SQUOTE] = ACTIONS(2539),
    [anon_sym_u8_SQUOTE] = ACTIONS(2539),
    [anon_sym_SQUOTE] = ACTIONS(2539),
    [anon_sym_L_DQUOTE] = ACTIONS(2539),
    [anon_sym_u_DQUOTE] = ACTIONS(2539),
    [anon_sym_U_DQUOTE] = ACTIONS(2539),
    [anon_sym_u8_DQUOTE] = ACTIONS(2539),
    [anon_sym_DQUOTE] = ACTIONS(2539),
    [sym_true] = ACTIONS(2537),
    [sym_false] = ACTIONS(2537),
    [anon_sym_NULL] = ACTIONS(2537),
    [anon_sym_nullptr] = ACTIONS(2537),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2537),
    [anon_sym_decltype] = ACTIONS(2537),
    [anon_sym_explicit] = ACTIONS(2537),
    [anon_sym_typename] = ACTIONS(2537),
    [anon_sym_template] = ACTIONS(2537),
    [anon_sym_operator] = ACTIONS(2537),
    [anon_sym_try] = ACTIONS(2537),
    [anon_sym_delete] = ACTIONS(2537),
    [anon_sym_throw] = ACTIONS(2537),
    [anon_sym_namespace] = ACTIONS(2537),
    [anon_sym_using] = ACTIONS(2537),
    [anon_sym_static_assert] = ACTIONS(2537),
    [anon_sym_concept] = ACTIONS(2537),
    [anon_sym_co_return] = ACTIONS(2537),
    [anon_sym_co_yield] = ACTIONS(2537),
    [anon_sym_R_DQUOTE] = ACTIONS(2539),
    [anon_sym_LR_DQUOTE] = ACTIONS(2539),
    [anon_sym_uR_DQUOTE] = ACTIONS(2539),
    [anon_sym_UR_DQUOTE] = ACTIONS(2539),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2539),
    [anon_sym_co_await] = ACTIONS(2537),
    [anon_sym_new] = ACTIONS(2537),
    [anon_sym_requires] = ACTIONS(2537),
    [sym_this] = ACTIONS(2537),
    [anon_sym___launch_bounds__] = ACTIONS(2537),
  },
  [STATE(479)] = {
    [sym_identifier] = ACTIONS(2533),
    [aux_sym_preproc_include_token1] = ACTIONS(2533),
    [aux_sym_preproc_def_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token2] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2533),
    [sym_preproc_directive] = ACTIONS(2533),
    [anon_sym_LPAREN2] = ACTIONS(2535),
    [anon_sym_BANG] = ACTIONS(2535),
    [anon_sym_TILDE] = ACTIONS(2535),
    [anon_sym_DASH] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2535),
    [anon_sym_AMP_AMP] = ACTIONS(2535),
    [anon_sym_AMP] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym___extension__] = ACTIONS(2533),
    [anon_sym_typedef] = ACTIONS(2533),
    [anon_sym___device__] = ACTIONS(2533),
    [anon_sym___host__] = ACTIONS(2533),
    [anon_sym___global__] = ACTIONS(2533),
    [anon_sym___forceinline__] = ACTIONS(2533),
    [anon_sym___noinline__] = ACTIONS(2533),
    [anon_sym_virtual] = ACTIONS(2533),
    [anon_sym_extern] = ACTIONS(2533),
    [anon_sym___attribute__] = ACTIONS(2533),
    [anon_sym___attribute] = ACTIONS(2533),
    [anon_sym_COLON_COLON] = ACTIONS(2535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2535),
    [anon_sym___declspec] = ACTIONS(2533),
    [anon_sym___based] = ACTIONS(2533),
    [anon_sym___cdecl] = ACTIONS(2533),
    [anon_sym___clrcall] = ACTIONS(2533),
    [anon_sym___stdcall] = ACTIONS(2533),
    [anon_sym___fastcall] = ACTIONS(2533),
    [anon_sym___thiscall] = ACTIONS(2533),
    [anon_sym___vectorcall] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2535),
    [anon_sym_signed] = ACTIONS(2533),
    [anon_sym_unsigned] = ACTIONS(2533),
    [anon_sym_long] = ACTIONS(2533),
    [anon_sym_short] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2533),
    [anon_sym_static] = ACTIONS(2533),
    [anon_sym_register] = ACTIONS(2533),
    [anon_sym_inline] = ACTIONS(2533),
    [anon_sym___inline] = ACTIONS(2533),
    [anon_sym___inline__] = ACTIONS(2533),
    [anon_sym___forceinline] = ACTIONS(2533),
    [anon_sym_thread_local] = ACTIONS(2533),
    [anon_sym___thread] = ACTIONS(2533),
    [anon_sym_const] = ACTIONS(2533),
    [anon_sym_constexpr] = ACTIONS(2533),
    [anon_sym_volatile] = ACTIONS(2533),
    [anon_sym_restrict] = ACTIONS(2533),
    [anon_sym___restrict__] = ACTIONS(2533),
    [anon_sym__Atomic] = ACTIONS(2533),
    [anon_sym__Noreturn] = ACTIONS(2533),
    [anon_sym_noreturn] = ACTIONS(2533),
    [anon_sym__Nonnull] = ACTIONS(2533),
    [anon_sym_mutable] = ACTIONS(2533),
    [anon_sym_constinit] = ACTIONS(2533),
    [anon_sym_consteval] = ACTIONS(2533),
    [anon_sym___shared__] = ACTIONS(2533),
    [anon_sym___local__] = ACTIONS(2533),
    [anon_sym___constant__] = ACTIONS(2533),
    [anon_sym___managed__] = ACTIONS(2533),
    [anon_sym___grid_constant__] = ACTIONS(2533),
    [anon_sym_alignas] = ACTIONS(2533),
    [anon_sym__Alignas] = ACTIONS(2533),
    [sym_primitive_type] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_class] = ACTIONS(2533),
    [anon_sym_struct] = ACTIONS(2533),
    [anon_sym_union] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2533),
    [anon_sym_switch] = ACTIONS(2533),
    [anon_sym_case] = ACTIONS(2533),
    [anon_sym_default] = ACTIONS(2533),
    [anon_sym_while] = ACTIONS(2533),
    [anon_sym_do] = ACTIONS(2533),
    [anon_sym_for] = ACTIONS(2533),
    [anon_sym_return] = ACTIONS(2533),
    [anon_sym_break] = ACTIONS(2533),
    [anon_sym_continue] = ACTIONS(2533),
    [anon_sym_goto] = ACTIONS(2533),
    [anon_sym___try] = ACTIONS(2533),
    [anon_sym___leave] = ACTIONS(2533),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_compl] = ACTIONS(2533),
    [anon_sym_DASH_DASH] = ACTIONS(2535),
    [anon_sym_PLUS_PLUS] = ACTIONS(2535),
    [anon_sym_sizeof] = ACTIONS(2533),
    [anon_sym___alignof__] = ACTIONS(2533),
    [anon_sym___alignof] = ACTIONS(2533),
    [anon_sym__alignof] = ACTIONS(2533),
    [anon_sym_alignof] = ACTIONS(2533),
    [anon_sym__Alignof] = ACTIONS(2533),
    [anon_sym_offsetof] = ACTIONS(2533),
    [anon_sym__Generic] = ACTIONS(2533),
    [anon_sym_asm] = ACTIONS(2533),
    [anon_sym___asm__] = ACTIONS(2533),
    [anon_sym___asm] = ACTIONS(2533),
    [sym_number_literal] = ACTIONS(2535),
    [anon_sym_L_SQUOTE] = ACTIONS(2535),
    [anon_sym_u_SQUOTE] = ACTIONS(2535),
    [anon_sym_U_SQUOTE] = ACTIONS(2535),
    [anon_sym_u8_SQUOTE] = ACTIONS(2535),
    [anon_sym_SQUOTE] = ACTIONS(2535),
    [anon_sym_L_DQUOTE] = ACTIONS(2535),
    [anon_sym_u_DQUOTE] = ACTIONS(2535),
    [anon_sym_U_DQUOTE] = ACTIONS(2535),
    [anon_sym_u8_DQUOTE] = ACTIONS(2535),
    [anon_sym_DQUOTE] = ACTIONS(2535),
    [sym_true] = ACTIONS(2533),
    [sym_false] = ACTIONS(2533),
    [anon_sym_NULL] = ACTIONS(2533),
    [anon_sym_nullptr] = ACTIONS(2533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2533),
    [anon_sym_decltype] = ACTIONS(2533),
    [anon_sym_explicit] = ACTIONS(2533),
    [anon_sym_typename] = ACTIONS(2533),
    [anon_sym_template] = ACTIONS(2533),
    [anon_sym_operator] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2533),
    [anon_sym_delete] = ACTIONS(2533),
    [anon_sym_throw] = ACTIONS(2533),
    [anon_sym_namespace] = ACTIONS(2533),
    [anon_sym_using] = ACTIONS(2533),
    [anon_sym_static_assert] = ACTIONS(2533),
    [anon_sym_concept] = ACTIONS(2533),
    [anon_sym_co_return] = ACTIONS(2533),
    [anon_sym_co_yield] = ACTIONS(2533),
    [anon_sym_R_DQUOTE] = ACTIONS(2535),
    [anon_sym_LR_DQUOTE] = ACTIONS(2535),
    [anon_sym_uR_DQUOTE] = ACTIONS(2535),
    [anon_sym_UR_DQUOTE] = ACTIONS(2535),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2535),
    [anon_sym_co_await] = ACTIONS(2533),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_requires] = ACTIONS(2533),
    [sym_this] = ACTIONS(2533),
    [anon_sym___launch_bounds__] = ACTIONS(2533),
  },
  [STATE(480)] = {
    [sym_identifier] = ACTIONS(2463),
    [aux_sym_preproc_include_token1] = ACTIONS(2463),
    [aux_sym_preproc_def_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token2] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2463),
    [sym_preproc_directive] = ACTIONS(2463),
    [anon_sym_LPAREN2] = ACTIONS(2465),
    [anon_sym_BANG] = ACTIONS(2465),
    [anon_sym_TILDE] = ACTIONS(2465),
    [anon_sym_DASH] = ACTIONS(2463),
    [anon_sym_PLUS] = ACTIONS(2463),
    [anon_sym_STAR] = ACTIONS(2465),
    [anon_sym_AMP_AMP] = ACTIONS(2465),
    [anon_sym_AMP] = ACTIONS(2463),
    [anon_sym_SEMI] = ACTIONS(2465),
    [anon_sym___extension__] = ACTIONS(2463),
    [anon_sym_typedef] = ACTIONS(2463),
    [anon_sym___device__] = ACTIONS(2463),
    [anon_sym___host__] = ACTIONS(2463),
    [anon_sym___global__] = ACTIONS(2463),
    [anon_sym___forceinline__] = ACTIONS(2463),
    [anon_sym___noinline__] = ACTIONS(2463),
    [anon_sym_virtual] = ACTIONS(2463),
    [anon_sym_extern] = ACTIONS(2463),
    [anon_sym___attribute__] = ACTIONS(2463),
    [anon_sym___attribute] = ACTIONS(2463),
    [anon_sym_COLON_COLON] = ACTIONS(2465),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2465),
    [anon_sym___declspec] = ACTIONS(2463),
    [anon_sym___based] = ACTIONS(2463),
    [anon_sym___cdecl] = ACTIONS(2463),
    [anon_sym___clrcall] = ACTIONS(2463),
    [anon_sym___stdcall] = ACTIONS(2463),
    [anon_sym___fastcall] = ACTIONS(2463),
    [anon_sym___thiscall] = ACTIONS(2463),
    [anon_sym___vectorcall] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_signed] = ACTIONS(2463),
    [anon_sym_unsigned] = ACTIONS(2463),
    [anon_sym_long] = ACTIONS(2463),
    [anon_sym_short] = ACTIONS(2463),
    [anon_sym_LBRACK] = ACTIONS(2463),
    [anon_sym_static] = ACTIONS(2463),
    [anon_sym_register] = ACTIONS(2463),
    [anon_sym_inline] = ACTIONS(2463),
    [anon_sym___inline] = ACTIONS(2463),
    [anon_sym___inline__] = ACTIONS(2463),
    [anon_sym___forceinline] = ACTIONS(2463),
    [anon_sym_thread_local] = ACTIONS(2463),
    [anon_sym___thread] = ACTIONS(2463),
    [anon_sym_const] = ACTIONS(2463),
    [anon_sym_constexpr] = ACTIONS(2463),
    [anon_sym_volatile] = ACTIONS(2463),
    [anon_sym_restrict] = ACTIONS(2463),
    [anon_sym___restrict__] = ACTIONS(2463),
    [anon_sym__Atomic] = ACTIONS(2463),
    [anon_sym__Noreturn] = ACTIONS(2463),
    [anon_sym_noreturn] = ACTIONS(2463),
    [anon_sym__Nonnull] = ACTIONS(2463),
    [anon_sym_mutable] = ACTIONS(2463),
    [anon_sym_constinit] = ACTIONS(2463),
    [anon_sym_consteval] = ACTIONS(2463),
    [anon_sym___shared__] = ACTIONS(2463),
    [anon_sym___local__] = ACTIONS(2463),
    [anon_sym___constant__] = ACTIONS(2463),
    [anon_sym___managed__] = ACTIONS(2463),
    [anon_sym___grid_constant__] = ACTIONS(2463),
    [anon_sym_alignas] = ACTIONS(2463),
    [anon_sym__Alignas] = ACTIONS(2463),
    [sym_primitive_type] = ACTIONS(2463),
    [anon_sym_enum] = ACTIONS(2463),
    [anon_sym_class] = ACTIONS(2463),
    [anon_sym_struct] = ACTIONS(2463),
    [anon_sym_union] = ACTIONS(2463),
    [anon_sym_if] = ACTIONS(2463),
    [anon_sym_switch] = ACTIONS(2463),
    [anon_sym_case] = ACTIONS(2463),
    [anon_sym_default] = ACTIONS(2463),
    [anon_sym_while] = ACTIONS(2463),
    [anon_sym_do] = ACTIONS(2463),
    [anon_sym_for] = ACTIONS(2463),
    [anon_sym_return] = ACTIONS(2463),
    [anon_sym_break] = ACTIONS(2463),
    [anon_sym_continue] = ACTIONS(2463),
    [anon_sym_goto] = ACTIONS(2463),
    [anon_sym___try] = ACTIONS(2463),
    [anon_sym___leave] = ACTIONS(2463),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_compl] = ACTIONS(2463),
    [anon_sym_DASH_DASH] = ACTIONS(2465),
    [anon_sym_PLUS_PLUS] = ACTIONS(2465),
    [anon_sym_sizeof] = ACTIONS(2463),
    [anon_sym___alignof__] = ACTIONS(2463),
    [anon_sym___alignof] = ACTIONS(2463),
    [anon_sym__alignof] = ACTIONS(2463),
    [anon_sym_alignof] = ACTIONS(2463),
    [anon_sym__Alignof] = ACTIONS(2463),
    [anon_sym_offsetof] = ACTIONS(2463),
    [anon_sym__Generic] = ACTIONS(2463),
    [anon_sym_asm] = ACTIONS(2463),
    [anon_sym___asm__] = ACTIONS(2463),
    [anon_sym___asm] = ACTIONS(2463),
    [sym_number_literal] = ACTIONS(2465),
    [anon_sym_L_SQUOTE] = ACTIONS(2465),
    [anon_sym_u_SQUOTE] = ACTIONS(2465),
    [anon_sym_U_SQUOTE] = ACTIONS(2465),
    [anon_sym_u8_SQUOTE] = ACTIONS(2465),
    [anon_sym_SQUOTE] = ACTIONS(2465),
    [anon_sym_L_DQUOTE] = ACTIONS(2465),
    [anon_sym_u_DQUOTE] = ACTIONS(2465),
    [anon_sym_U_DQUOTE] = ACTIONS(2465),
    [anon_sym_u8_DQUOTE] = ACTIONS(2465),
    [anon_sym_DQUOTE] = ACTIONS(2465),
    [sym_true] = ACTIONS(2463),
    [sym_false] = ACTIONS(2463),
    [anon_sym_NULL] = ACTIONS(2463),
    [anon_sym_nullptr] = ACTIONS(2463),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2463),
    [anon_sym_decltype] = ACTIONS(2463),
    [anon_sym_explicit] = ACTIONS(2463),
    [anon_sym_typename] = ACTIONS(2463),
    [anon_sym_template] = ACTIONS(2463),
    [anon_sym_operator] = ACTIONS(2463),
    [anon_sym_try] = ACTIONS(2463),
    [anon_sym_delete] = ACTIONS(2463),
    [anon_sym_throw] = ACTIONS(2463),
    [anon_sym_namespace] = ACTIONS(2463),
    [anon_sym_using] = ACTIONS(2463),
    [anon_sym_static_assert] = ACTIONS(2463),
    [anon_sym_concept] = ACTIONS(2463),
    [anon_sym_co_return] = ACTIONS(2463),
    [anon_sym_co_yield] = ACTIONS(2463),
    [anon_sym_R_DQUOTE] = ACTIONS(2465),
    [anon_sym_LR_DQUOTE] = ACTIONS(2465),
    [anon_sym_uR_DQUOTE] = ACTIONS(2465),
    [anon_sym_UR_DQUOTE] = ACTIONS(2465),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2465),
    [anon_sym_co_await] = ACTIONS(2463),
    [anon_sym_new] = ACTIONS(2463),
    [anon_sym_requires] = ACTIONS(2463),
    [sym_this] = ACTIONS(2463),
    [anon_sym___launch_bounds__] = ACTIONS(2463),
  },
  [STATE(481)] = {
    [sym_identifier] = ACTIONS(2545),
    [aux_sym_preproc_include_token1] = ACTIONS(2545),
    [aux_sym_preproc_def_token1] = ACTIONS(2545),
    [aux_sym_preproc_if_token1] = ACTIONS(2545),
    [aux_sym_preproc_if_token2] = ACTIONS(2545),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2545),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2545),
    [sym_preproc_directive] = ACTIONS(2545),
    [anon_sym_LPAREN2] = ACTIONS(2547),
    [anon_sym_BANG] = ACTIONS(2547),
    [anon_sym_TILDE] = ACTIONS(2547),
    [anon_sym_DASH] = ACTIONS(2545),
    [anon_sym_PLUS] = ACTIONS(2545),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_AMP_AMP] = ACTIONS(2547),
    [anon_sym_AMP] = ACTIONS(2545),
    [anon_sym_SEMI] = ACTIONS(2547),
    [anon_sym___extension__] = ACTIONS(2545),
    [anon_sym_typedef] = ACTIONS(2545),
    [anon_sym___device__] = ACTIONS(2545),
    [anon_sym___host__] = ACTIONS(2545),
    [anon_sym___global__] = ACTIONS(2545),
    [anon_sym___forceinline__] = ACTIONS(2545),
    [anon_sym___noinline__] = ACTIONS(2545),
    [anon_sym_virtual] = ACTIONS(2545),
    [anon_sym_extern] = ACTIONS(2545),
    [anon_sym___attribute__] = ACTIONS(2545),
    [anon_sym___attribute] = ACTIONS(2545),
    [anon_sym_COLON_COLON] = ACTIONS(2547),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2547),
    [anon_sym___declspec] = ACTIONS(2545),
    [anon_sym___based] = ACTIONS(2545),
    [anon_sym___cdecl] = ACTIONS(2545),
    [anon_sym___clrcall] = ACTIONS(2545),
    [anon_sym___stdcall] = ACTIONS(2545),
    [anon_sym___fastcall] = ACTIONS(2545),
    [anon_sym___thiscall] = ACTIONS(2545),
    [anon_sym___vectorcall] = ACTIONS(2545),
    [anon_sym_LBRACE] = ACTIONS(2547),
    [anon_sym_signed] = ACTIONS(2545),
    [anon_sym_unsigned] = ACTIONS(2545),
    [anon_sym_long] = ACTIONS(2545),
    [anon_sym_short] = ACTIONS(2545),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [anon_sym_static] = ACTIONS(2545),
    [anon_sym_register] = ACTIONS(2545),
    [anon_sym_inline] = ACTIONS(2545),
    [anon_sym___inline] = ACTIONS(2545),
    [anon_sym___inline__] = ACTIONS(2545),
    [anon_sym___forceinline] = ACTIONS(2545),
    [anon_sym_thread_local] = ACTIONS(2545),
    [anon_sym___thread] = ACTIONS(2545),
    [anon_sym_const] = ACTIONS(2545),
    [anon_sym_constexpr] = ACTIONS(2545),
    [anon_sym_volatile] = ACTIONS(2545),
    [anon_sym_restrict] = ACTIONS(2545),
    [anon_sym___restrict__] = ACTIONS(2545),
    [anon_sym__Atomic] = ACTIONS(2545),
    [anon_sym__Noreturn] = ACTIONS(2545),
    [anon_sym_noreturn] = ACTIONS(2545),
    [anon_sym__Nonnull] = ACTIONS(2545),
    [anon_sym_mutable] = ACTIONS(2545),
    [anon_sym_constinit] = ACTIONS(2545),
    [anon_sym_consteval] = ACTIONS(2545),
    [anon_sym___shared__] = ACTIONS(2545),
    [anon_sym___local__] = ACTIONS(2545),
    [anon_sym___constant__] = ACTIONS(2545),
    [anon_sym___managed__] = ACTIONS(2545),
    [anon_sym___grid_constant__] = ACTIONS(2545),
    [anon_sym_alignas] = ACTIONS(2545),
    [anon_sym__Alignas] = ACTIONS(2545),
    [sym_primitive_type] = ACTIONS(2545),
    [anon_sym_enum] = ACTIONS(2545),
    [anon_sym_class] = ACTIONS(2545),
    [anon_sym_struct] = ACTIONS(2545),
    [anon_sym_union] = ACTIONS(2545),
    [anon_sym_if] = ACTIONS(2545),
    [anon_sym_switch] = ACTIONS(2545),
    [anon_sym_case] = ACTIONS(2545),
    [anon_sym_default] = ACTIONS(2545),
    [anon_sym_while] = ACTIONS(2545),
    [anon_sym_do] = ACTIONS(2545),
    [anon_sym_for] = ACTIONS(2545),
    [anon_sym_return] = ACTIONS(2545),
    [anon_sym_break] = ACTIONS(2545),
    [anon_sym_continue] = ACTIONS(2545),
    [anon_sym_goto] = ACTIONS(2545),
    [anon_sym___try] = ACTIONS(2545),
    [anon_sym___leave] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2545),
    [anon_sym_compl] = ACTIONS(2545),
    [anon_sym_DASH_DASH] = ACTIONS(2547),
    [anon_sym_PLUS_PLUS] = ACTIONS(2547),
    [anon_sym_sizeof] = ACTIONS(2545),
    [anon_sym___alignof__] = ACTIONS(2545),
    [anon_sym___alignof] = ACTIONS(2545),
    [anon_sym__alignof] = ACTIONS(2545),
    [anon_sym_alignof] = ACTIONS(2545),
    [anon_sym__Alignof] = ACTIONS(2545),
    [anon_sym_offsetof] = ACTIONS(2545),
    [anon_sym__Generic] = ACTIONS(2545),
    [anon_sym_asm] = ACTIONS(2545),
    [anon_sym___asm__] = ACTIONS(2545),
    [anon_sym___asm] = ACTIONS(2545),
    [sym_number_literal] = ACTIONS(2547),
    [anon_sym_L_SQUOTE] = ACTIONS(2547),
    [anon_sym_u_SQUOTE] = ACTIONS(2547),
    [anon_sym_U_SQUOTE] = ACTIONS(2547),
    [anon_sym_u8_SQUOTE] = ACTIONS(2547),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_L_DQUOTE] = ACTIONS(2547),
    [anon_sym_u_DQUOTE] = ACTIONS(2547),
    [anon_sym_U_DQUOTE] = ACTIONS(2547),
    [anon_sym_u8_DQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2547),
    [sym_true] = ACTIONS(2545),
    [sym_false] = ACTIONS(2545),
    [anon_sym_NULL] = ACTIONS(2545),
    [anon_sym_nullptr] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2545),
    [anon_sym_decltype] = ACTIONS(2545),
    [anon_sym_explicit] = ACTIONS(2545),
    [anon_sym_typename] = ACTIONS(2545),
    [anon_sym_template] = ACTIONS(2545),
    [anon_sym_operator] = ACTIONS(2545),
    [anon_sym_try] = ACTIONS(2545),
    [anon_sym_delete] = ACTIONS(2545),
    [anon_sym_throw] = ACTIONS(2545),
    [anon_sym_namespace] = ACTIONS(2545),
    [anon_sym_using] = ACTIONS(2545),
    [anon_sym_static_assert] = ACTIONS(2545),
    [anon_sym_concept] = ACTIONS(2545),
    [anon_sym_co_return] = ACTIONS(2545),
    [anon_sym_co_yield] = ACTIONS(2545),
    [anon_sym_R_DQUOTE] = ACTIONS(2547),
    [anon_sym_LR_DQUOTE] = ACTIONS(2547),
    [anon_sym_uR_DQUOTE] = ACTIONS(2547),
    [anon_sym_UR_DQUOTE] = ACTIONS(2547),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2547),
    [anon_sym_co_await] = ACTIONS(2545),
    [anon_sym_new] = ACTIONS(2545),
    [anon_sym_requires] = ACTIONS(2545),
    [sym_this] = ACTIONS(2545),
    [anon_sym___launch_bounds__] = ACTIONS(2545),
  },
  [STATE(482)] = {
    [sym_identifier] = ACTIONS(2553),
    [aux_sym_preproc_include_token1] = ACTIONS(2553),
    [aux_sym_preproc_def_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token2] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2553),
    [sym_preproc_directive] = ACTIONS(2553),
    [anon_sym_LPAREN2] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2555),
    [anon_sym_TILDE] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2553),
    [anon_sym_PLUS] = ACTIONS(2553),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_AMP_AMP] = ACTIONS(2555),
    [anon_sym_AMP] = ACTIONS(2553),
    [anon_sym_SEMI] = ACTIONS(2555),
    [anon_sym___extension__] = ACTIONS(2553),
    [anon_sym_typedef] = ACTIONS(2553),
    [anon_sym___device__] = ACTIONS(2553),
    [anon_sym___host__] = ACTIONS(2553),
    [anon_sym___global__] = ACTIONS(2553),
    [anon_sym___forceinline__] = ACTIONS(2553),
    [anon_sym___noinline__] = ACTIONS(2553),
    [anon_sym_virtual] = ACTIONS(2553),
    [anon_sym_extern] = ACTIONS(2553),
    [anon_sym___attribute__] = ACTIONS(2553),
    [anon_sym___attribute] = ACTIONS(2553),
    [anon_sym_COLON_COLON] = ACTIONS(2555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2555),
    [anon_sym___declspec] = ACTIONS(2553),
    [anon_sym___based] = ACTIONS(2553),
    [anon_sym___cdecl] = ACTIONS(2553),
    [anon_sym___clrcall] = ACTIONS(2553),
    [anon_sym___stdcall] = ACTIONS(2553),
    [anon_sym___fastcall] = ACTIONS(2553),
    [anon_sym___thiscall] = ACTIONS(2553),
    [anon_sym___vectorcall] = ACTIONS(2553),
    [anon_sym_LBRACE] = ACTIONS(2555),
    [anon_sym_signed] = ACTIONS(2553),
    [anon_sym_unsigned] = ACTIONS(2553),
    [anon_sym_long] = ACTIONS(2553),
    [anon_sym_short] = ACTIONS(2553),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2553),
    [anon_sym_register] = ACTIONS(2553),
    [anon_sym_inline] = ACTIONS(2553),
    [anon_sym___inline] = ACTIONS(2553),
    [anon_sym___inline__] = ACTIONS(2553),
    [anon_sym___forceinline] = ACTIONS(2553),
    [anon_sym_thread_local] = ACTIONS(2553),
    [anon_sym___thread] = ACTIONS(2553),
    [anon_sym_const] = ACTIONS(2553),
    [anon_sym_constexpr] = ACTIONS(2553),
    [anon_sym_volatile] = ACTIONS(2553),
    [anon_sym_restrict] = ACTIONS(2553),
    [anon_sym___restrict__] = ACTIONS(2553),
    [anon_sym__Atomic] = ACTIONS(2553),
    [anon_sym__Noreturn] = ACTIONS(2553),
    [anon_sym_noreturn] = ACTIONS(2553),
    [anon_sym__Nonnull] = ACTIONS(2553),
    [anon_sym_mutable] = ACTIONS(2553),
    [anon_sym_constinit] = ACTIONS(2553),
    [anon_sym_consteval] = ACTIONS(2553),
    [anon_sym___shared__] = ACTIONS(2553),
    [anon_sym___local__] = ACTIONS(2553),
    [anon_sym___constant__] = ACTIONS(2553),
    [anon_sym___managed__] = ACTIONS(2553),
    [anon_sym___grid_constant__] = ACTIONS(2553),
    [anon_sym_alignas] = ACTIONS(2553),
    [anon_sym__Alignas] = ACTIONS(2553),
    [sym_primitive_type] = ACTIONS(2553),
    [anon_sym_enum] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2553),
    [anon_sym_struct] = ACTIONS(2553),
    [anon_sym_union] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2553),
    [anon_sym_switch] = ACTIONS(2553),
    [anon_sym_case] = ACTIONS(2553),
    [anon_sym_default] = ACTIONS(2553),
    [anon_sym_while] = ACTIONS(2553),
    [anon_sym_do] = ACTIONS(2553),
    [anon_sym_for] = ACTIONS(2553),
    [anon_sym_return] = ACTIONS(2553),
    [anon_sym_break] = ACTIONS(2553),
    [anon_sym_continue] = ACTIONS(2553),
    [anon_sym_goto] = ACTIONS(2553),
    [anon_sym___try] = ACTIONS(2553),
    [anon_sym___leave] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2553),
    [anon_sym_compl] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2555),
    [anon_sym_sizeof] = ACTIONS(2553),
    [anon_sym___alignof__] = ACTIONS(2553),
    [anon_sym___alignof] = ACTIONS(2553),
    [anon_sym__alignof] = ACTIONS(2553),
    [anon_sym_alignof] = ACTIONS(2553),
    [anon_sym__Alignof] = ACTIONS(2553),
    [anon_sym_offsetof] = ACTIONS(2553),
    [anon_sym__Generic] = ACTIONS(2553),
    [anon_sym_asm] = ACTIONS(2553),
    [anon_sym___asm__] = ACTIONS(2553),
    [anon_sym___asm] = ACTIONS(2553),
    [sym_number_literal] = ACTIONS(2555),
    [anon_sym_L_SQUOTE] = ACTIONS(2555),
    [anon_sym_u_SQUOTE] = ACTIONS(2555),
    [anon_sym_U_SQUOTE] = ACTIONS(2555),
    [anon_sym_u8_SQUOTE] = ACTIONS(2555),
    [anon_sym_SQUOTE] = ACTIONS(2555),
    [anon_sym_L_DQUOTE] = ACTIONS(2555),
    [anon_sym_u_DQUOTE] = ACTIONS(2555),
    [anon_sym_U_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8_DQUOTE] = ACTIONS(2555),
    [anon_sym_DQUOTE] = ACTIONS(2555),
    [sym_true] = ACTIONS(2553),
    [sym_false] = ACTIONS(2553),
    [anon_sym_NULL] = ACTIONS(2553),
    [anon_sym_nullptr] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2553),
    [anon_sym_decltype] = ACTIONS(2553),
    [anon_sym_explicit] = ACTIONS(2553),
    [anon_sym_typename] = ACTIONS(2553),
    [anon_sym_template] = ACTIONS(2553),
    [anon_sym_operator] = ACTIONS(2553),
    [anon_sym_try] = ACTIONS(2553),
    [anon_sym_delete] = ACTIONS(2553),
    [anon_sym_throw] = ACTIONS(2553),
    [anon_sym_namespace] = ACTIONS(2553),
    [anon_sym_using] = ACTIONS(2553),
    [anon_sym_static_assert] = ACTIONS(2553),
    [anon_sym_concept] = ACTIONS(2553),
    [anon_sym_co_return] = ACTIONS(2553),
    [anon_sym_co_yield] = ACTIONS(2553),
    [anon_sym_R_DQUOTE] = ACTIONS(2555),
    [anon_sym_LR_DQUOTE] = ACTIONS(2555),
    [anon_sym_uR_DQUOTE] = ACTIONS(2555),
    [anon_sym_UR_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2555),
    [anon_sym_co_await] = ACTIONS(2553),
    [anon_sym_new] = ACTIONS(2553),
    [anon_sym_requires] = ACTIONS(2553),
    [sym_this] = ACTIONS(2553),
    [anon_sym___launch_bounds__] = ACTIONS(2553),
  },
  [STATE(483)] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym___device__] = ACTIONS(2332),
    [anon_sym___host__] = ACTIONS(2332),
    [anon_sym___global__] = ACTIONS(2332),
    [anon_sym___forceinline__] = ACTIONS(2332),
    [anon_sym___noinline__] = ACTIONS(2332),
    [anon_sym_virtual] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym___attribute] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym__Nonnull] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym___shared__] = ACTIONS(2332),
    [anon_sym___local__] = ACTIONS(2332),
    [anon_sym___constant__] = ACTIONS(2332),
    [anon_sym___managed__] = ACTIONS(2332),
    [anon_sym___grid_constant__] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [anon_sym___asm] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym___launch_bounds__] = ACTIONS(2332),
  },
  [STATE(484)] = {
    [sym_identifier] = ACTIONS(2339),
    [aux_sym_preproc_include_token1] = ACTIONS(2339),
    [aux_sym_preproc_def_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token2] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2339),
    [sym_preproc_directive] = ACTIONS(2339),
    [anon_sym_LPAREN2] = ACTIONS(2341),
    [anon_sym_BANG] = ACTIONS(2341),
    [anon_sym_TILDE] = ACTIONS(2341),
    [anon_sym_DASH] = ACTIONS(2339),
    [anon_sym_PLUS] = ACTIONS(2339),
    [anon_sym_STAR] = ACTIONS(2341),
    [anon_sym_AMP_AMP] = ACTIONS(2341),
    [anon_sym_AMP] = ACTIONS(2339),
    [anon_sym_SEMI] = ACTIONS(2341),
    [anon_sym___extension__] = ACTIONS(2339),
    [anon_sym_typedef] = ACTIONS(2339),
    [anon_sym___device__] = ACTIONS(2339),
    [anon_sym___host__] = ACTIONS(2339),
    [anon_sym___global__] = ACTIONS(2339),
    [anon_sym___forceinline__] = ACTIONS(2339),
    [anon_sym___noinline__] = ACTIONS(2339),
    [anon_sym_virtual] = ACTIONS(2339),
    [anon_sym_extern] = ACTIONS(2339),
    [anon_sym___attribute__] = ACTIONS(2339),
    [anon_sym___attribute] = ACTIONS(2339),
    [anon_sym_COLON_COLON] = ACTIONS(2341),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2341),
    [anon_sym___declspec] = ACTIONS(2339),
    [anon_sym___based] = ACTIONS(2339),
    [anon_sym___cdecl] = ACTIONS(2339),
    [anon_sym___clrcall] = ACTIONS(2339),
    [anon_sym___stdcall] = ACTIONS(2339),
    [anon_sym___fastcall] = ACTIONS(2339),
    [anon_sym___thiscall] = ACTIONS(2339),
    [anon_sym___vectorcall] = ACTIONS(2339),
    [anon_sym_LBRACE] = ACTIONS(2341),
    [anon_sym_signed] = ACTIONS(2339),
    [anon_sym_unsigned] = ACTIONS(2339),
    [anon_sym_long] = ACTIONS(2339),
    [anon_sym_short] = ACTIONS(2339),
    [anon_sym_LBRACK] = ACTIONS(2339),
    [anon_sym_static] = ACTIONS(2339),
    [anon_sym_register] = ACTIONS(2339),
    [anon_sym_inline] = ACTIONS(2339),
    [anon_sym___inline] = ACTIONS(2339),
    [anon_sym___inline__] = ACTIONS(2339),
    [anon_sym___forceinline] = ACTIONS(2339),
    [anon_sym_thread_local] = ACTIONS(2339),
    [anon_sym___thread] = ACTIONS(2339),
    [anon_sym_const] = ACTIONS(2339),
    [anon_sym_constexpr] = ACTIONS(2339),
    [anon_sym_volatile] = ACTIONS(2339),
    [anon_sym_restrict] = ACTIONS(2339),
    [anon_sym___restrict__] = ACTIONS(2339),
    [anon_sym__Atomic] = ACTIONS(2339),
    [anon_sym__Noreturn] = ACTIONS(2339),
    [anon_sym_noreturn] = ACTIONS(2339),
    [anon_sym__Nonnull] = ACTIONS(2339),
    [anon_sym_mutable] = ACTIONS(2339),
    [anon_sym_constinit] = ACTIONS(2339),
    [anon_sym_consteval] = ACTIONS(2339),
    [anon_sym___shared__] = ACTIONS(2339),
    [anon_sym___local__] = ACTIONS(2339),
    [anon_sym___constant__] = ACTIONS(2339),
    [anon_sym___managed__] = ACTIONS(2339),
    [anon_sym___grid_constant__] = ACTIONS(2339),
    [anon_sym_alignas] = ACTIONS(2339),
    [anon_sym__Alignas] = ACTIONS(2339),
    [sym_primitive_type] = ACTIONS(2339),
    [anon_sym_enum] = ACTIONS(2339),
    [anon_sym_class] = ACTIONS(2339),
    [anon_sym_struct] = ACTIONS(2339),
    [anon_sym_union] = ACTIONS(2339),
    [anon_sym_if] = ACTIONS(2339),
    [anon_sym_switch] = ACTIONS(2339),
    [anon_sym_case] = ACTIONS(2339),
    [anon_sym_default] = ACTIONS(2339),
    [anon_sym_while] = ACTIONS(2339),
    [anon_sym_do] = ACTIONS(2339),
    [anon_sym_for] = ACTIONS(2339),
    [anon_sym_return] = ACTIONS(2339),
    [anon_sym_break] = ACTIONS(2339),
    [anon_sym_continue] = ACTIONS(2339),
    [anon_sym_goto] = ACTIONS(2339),
    [anon_sym___try] = ACTIONS(2339),
    [anon_sym___leave] = ACTIONS(2339),
    [anon_sym_not] = ACTIONS(2339),
    [anon_sym_compl] = ACTIONS(2339),
    [anon_sym_DASH_DASH] = ACTIONS(2341),
    [anon_sym_PLUS_PLUS] = ACTIONS(2341),
    [anon_sym_sizeof] = ACTIONS(2339),
    [anon_sym___alignof__] = ACTIONS(2339),
    [anon_sym___alignof] = ACTIONS(2339),
    [anon_sym__alignof] = ACTIONS(2339),
    [anon_sym_alignof] = ACTIONS(2339),
    [anon_sym__Alignof] = ACTIONS(2339),
    [anon_sym_offsetof] = ACTIONS(2339),
    [anon_sym__Generic] = ACTIONS(2339),
    [anon_sym_asm] = ACTIONS(2339),
    [anon_sym___asm__] = ACTIONS(2339),
    [anon_sym___asm] = ACTIONS(2339),
    [sym_number_literal] = ACTIONS(2341),
    [anon_sym_L_SQUOTE] = ACTIONS(2341),
    [anon_sym_u_SQUOTE] = ACTIONS(2341),
    [anon_sym_U_SQUOTE] = ACTIONS(2341),
    [anon_sym_u8_SQUOTE] = ACTIONS(2341),
    [anon_sym_SQUOTE] = ACTIONS(2341),
    [anon_sym_L_DQUOTE] = ACTIONS(2341),
    [anon_sym_u_DQUOTE] = ACTIONS(2341),
    [anon_sym_U_DQUOTE] = ACTIONS(2341),
    [anon_sym_u8_DQUOTE] = ACTIONS(2341),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_true] = ACTIONS(2339),
    [sym_false] = ACTIONS(2339),
    [anon_sym_NULL] = ACTIONS(2339),
    [anon_sym_nullptr] = ACTIONS(2339),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2339),
    [anon_sym_decltype] = ACTIONS(2339),
    [anon_sym_explicit] = ACTIONS(2339),
    [anon_sym_typename] = ACTIONS(2339),
    [anon_sym_template] = ACTIONS(2339),
    [anon_sym_operator] = ACTIONS(2339),
    [anon_sym_try] = ACTIONS(2339),
    [anon_sym_delete] = ACTIONS(2339),
    [anon_sym_throw] = ACTIONS(2339),
    [anon_sym_namespace] = ACTIONS(2339),
    [anon_sym_using] = ACTIONS(2339),
    [anon_sym_static_assert] = ACTIONS(2339),
    [anon_sym_concept] = ACTIONS(2339),
    [anon_sym_co_return] = ACTIONS(2339),
    [anon_sym_co_yield] = ACTIONS(2339),
    [anon_sym_R_DQUOTE] = ACTIONS(2341),
    [anon_sym_LR_DQUOTE] = ACTIONS(2341),
    [anon_sym_uR_DQUOTE] = ACTIONS(2341),
    [anon_sym_UR_DQUOTE] = ACTIONS(2341),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2341),
    [anon_sym_co_await] = ACTIONS(2339),
    [anon_sym_new] = ACTIONS(2339),
    [anon_sym_requires] = ACTIONS(2339),
    [sym_this] = ACTIONS(2339),
    [anon_sym___launch_bounds__] = ACTIONS(2339),
  },
  [STATE(485)] = {
    [sym_identifier] = ACTIONS(2343),
    [aux_sym_preproc_include_token1] = ACTIONS(2343),
    [aux_sym_preproc_def_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token2] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2343),
    [sym_preproc_directive] = ACTIONS(2343),
    [anon_sym_LPAREN2] = ACTIONS(2345),
    [anon_sym_BANG] = ACTIONS(2345),
    [anon_sym_TILDE] = ACTIONS(2345),
    [anon_sym_DASH] = ACTIONS(2343),
    [anon_sym_PLUS] = ACTIONS(2343),
    [anon_sym_STAR] = ACTIONS(2345),
    [anon_sym_AMP_AMP] = ACTIONS(2345),
    [anon_sym_AMP] = ACTIONS(2343),
    [anon_sym_SEMI] = ACTIONS(2345),
    [anon_sym___extension__] = ACTIONS(2343),
    [anon_sym_typedef] = ACTIONS(2343),
    [anon_sym___device__] = ACTIONS(2343),
    [anon_sym___host__] = ACTIONS(2343),
    [anon_sym___global__] = ACTIONS(2343),
    [anon_sym___forceinline__] = ACTIONS(2343),
    [anon_sym___noinline__] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2343),
    [anon_sym_extern] = ACTIONS(2343),
    [anon_sym___attribute__] = ACTIONS(2343),
    [anon_sym___attribute] = ACTIONS(2343),
    [anon_sym_COLON_COLON] = ACTIONS(2345),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2345),
    [anon_sym___declspec] = ACTIONS(2343),
    [anon_sym___based] = ACTIONS(2343),
    [anon_sym___cdecl] = ACTIONS(2343),
    [anon_sym___clrcall] = ACTIONS(2343),
    [anon_sym___stdcall] = ACTIONS(2343),
    [anon_sym___fastcall] = ACTIONS(2343),
    [anon_sym___thiscall] = ACTIONS(2343),
    [anon_sym___vectorcall] = ACTIONS(2343),
    [anon_sym_LBRACE] = ACTIONS(2345),
    [anon_sym_signed] = ACTIONS(2343),
    [anon_sym_unsigned] = ACTIONS(2343),
    [anon_sym_long] = ACTIONS(2343),
    [anon_sym_short] = ACTIONS(2343),
    [anon_sym_LBRACK] = ACTIONS(2343),
    [anon_sym_static] = ACTIONS(2343),
    [anon_sym_register] = ACTIONS(2343),
    [anon_sym_inline] = ACTIONS(2343),
    [anon_sym___inline] = ACTIONS(2343),
    [anon_sym___inline__] = ACTIONS(2343),
    [anon_sym___forceinline] = ACTIONS(2343),
    [anon_sym_thread_local] = ACTIONS(2343),
    [anon_sym___thread] = ACTIONS(2343),
    [anon_sym_const] = ACTIONS(2343),
    [anon_sym_constexpr] = ACTIONS(2343),
    [anon_sym_volatile] = ACTIONS(2343),
    [anon_sym_restrict] = ACTIONS(2343),
    [anon_sym___restrict__] = ACTIONS(2343),
    [anon_sym__Atomic] = ACTIONS(2343),
    [anon_sym__Noreturn] = ACTIONS(2343),
    [anon_sym_noreturn] = ACTIONS(2343),
    [anon_sym__Nonnull] = ACTIONS(2343),
    [anon_sym_mutable] = ACTIONS(2343),
    [anon_sym_constinit] = ACTIONS(2343),
    [anon_sym_consteval] = ACTIONS(2343),
    [anon_sym___shared__] = ACTIONS(2343),
    [anon_sym___local__] = ACTIONS(2343),
    [anon_sym___constant__] = ACTIONS(2343),
    [anon_sym___managed__] = ACTIONS(2343),
    [anon_sym___grid_constant__] = ACTIONS(2343),
    [anon_sym_alignas] = ACTIONS(2343),
    [anon_sym__Alignas] = ACTIONS(2343),
    [sym_primitive_type] = ACTIONS(2343),
    [anon_sym_enum] = ACTIONS(2343),
    [anon_sym_class] = ACTIONS(2343),
    [anon_sym_struct] = ACTIONS(2343),
    [anon_sym_union] = ACTIONS(2343),
    [anon_sym_if] = ACTIONS(2343),
    [anon_sym_switch] = ACTIONS(2343),
    [anon_sym_case] = ACTIONS(2343),
    [anon_sym_default] = ACTIONS(2343),
    [anon_sym_while] = ACTIONS(2343),
    [anon_sym_do] = ACTIONS(2343),
    [anon_sym_for] = ACTIONS(2343),
    [anon_sym_return] = ACTIONS(2343),
    [anon_sym_break] = ACTIONS(2343),
    [anon_sym_continue] = ACTIONS(2343),
    [anon_sym_goto] = ACTIONS(2343),
    [anon_sym___try] = ACTIONS(2343),
    [anon_sym___leave] = ACTIONS(2343),
    [anon_sym_not] = ACTIONS(2343),
    [anon_sym_compl] = ACTIONS(2343),
    [anon_sym_DASH_DASH] = ACTIONS(2345),
    [anon_sym_PLUS_PLUS] = ACTIONS(2345),
    [anon_sym_sizeof] = ACTIONS(2343),
    [anon_sym___alignof__] = ACTIONS(2343),
    [anon_sym___alignof] = ACTIONS(2343),
    [anon_sym__alignof] = ACTIONS(2343),
    [anon_sym_alignof] = ACTIONS(2343),
    [anon_sym__Alignof] = ACTIONS(2343),
    [anon_sym_offsetof] = ACTIONS(2343),
    [anon_sym__Generic] = ACTIONS(2343),
    [anon_sym_asm] = ACTIONS(2343),
    [anon_sym___asm__] = ACTIONS(2343),
    [anon_sym___asm] = ACTIONS(2343),
    [sym_number_literal] = ACTIONS(2345),
    [anon_sym_L_SQUOTE] = ACTIONS(2345),
    [anon_sym_u_SQUOTE] = ACTIONS(2345),
    [anon_sym_U_SQUOTE] = ACTIONS(2345),
    [anon_sym_u8_SQUOTE] = ACTIONS(2345),
    [anon_sym_SQUOTE] = ACTIONS(2345),
    [anon_sym_L_DQUOTE] = ACTIONS(2345),
    [anon_sym_u_DQUOTE] = ACTIONS(2345),
    [anon_sym_U_DQUOTE] = ACTIONS(2345),
    [anon_sym_u8_DQUOTE] = ACTIONS(2345),
    [anon_sym_DQUOTE] = ACTIONS(2345),
    [sym_true] = ACTIONS(2343),
    [sym_false] = ACTIONS(2343),
    [anon_sym_NULL] = ACTIONS(2343),
    [anon_sym_nullptr] = ACTIONS(2343),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2343),
    [anon_sym_decltype] = ACTIONS(2343),
    [anon_sym_explicit] = ACTIONS(2343),
    [anon_sym_typename] = ACTIONS(2343),
    [anon_sym_template] = ACTIONS(2343),
    [anon_sym_operator] = ACTIONS(2343),
    [anon_sym_try] = ACTIONS(2343),
    [anon_sym_delete] = ACTIONS(2343),
    [anon_sym_throw] = ACTIONS(2343),
    [anon_sym_namespace] = ACTIONS(2343),
    [anon_sym_using] = ACTIONS(2343),
    [anon_sym_static_assert] = ACTIONS(2343),
    [anon_sym_concept] = ACTIONS(2343),
    [anon_sym_co_return] = ACTIONS(2343),
    [anon_sym_co_yield] = ACTIONS(2343),
    [anon_sym_R_DQUOTE] = ACTIONS(2345),
    [anon_sym_LR_DQUOTE] = ACTIONS(2345),
    [anon_sym_uR_DQUOTE] = ACTIONS(2345),
    [anon_sym_UR_DQUOTE] = ACTIONS(2345),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2345),
    [anon_sym_co_await] = ACTIONS(2343),
    [anon_sym_new] = ACTIONS(2343),
    [anon_sym_requires] = ACTIONS(2343),
    [sym_this] = ACTIONS(2343),
    [anon_sym___launch_bounds__] = ACTIONS(2343),
  },
  [STATE(486)] = {
    [sym_identifier] = ACTIONS(2347),
    [aux_sym_preproc_include_token1] = ACTIONS(2347),
    [aux_sym_preproc_def_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token2] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2347),
    [sym_preproc_directive] = ACTIONS(2347),
    [anon_sym_LPAREN2] = ACTIONS(2349),
    [anon_sym_BANG] = ACTIONS(2349),
    [anon_sym_TILDE] = ACTIONS(2349),
    [anon_sym_DASH] = ACTIONS(2347),
    [anon_sym_PLUS] = ACTIONS(2347),
    [anon_sym_STAR] = ACTIONS(2349),
    [anon_sym_AMP_AMP] = ACTIONS(2349),
    [anon_sym_AMP] = ACTIONS(2347),
    [anon_sym_SEMI] = ACTIONS(2349),
    [anon_sym___extension__] = ACTIONS(2347),
    [anon_sym_typedef] = ACTIONS(2347),
    [anon_sym___device__] = ACTIONS(2347),
    [anon_sym___host__] = ACTIONS(2347),
    [anon_sym___global__] = ACTIONS(2347),
    [anon_sym___forceinline__] = ACTIONS(2347),
    [anon_sym___noinline__] = ACTIONS(2347),
    [anon_sym_virtual] = ACTIONS(2347),
    [anon_sym_extern] = ACTIONS(2347),
    [anon_sym___attribute__] = ACTIONS(2347),
    [anon_sym___attribute] = ACTIONS(2347),
    [anon_sym_COLON_COLON] = ACTIONS(2349),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2349),
    [anon_sym___declspec] = ACTIONS(2347),
    [anon_sym___based] = ACTIONS(2347),
    [anon_sym___cdecl] = ACTIONS(2347),
    [anon_sym___clrcall] = ACTIONS(2347),
    [anon_sym___stdcall] = ACTIONS(2347),
    [anon_sym___fastcall] = ACTIONS(2347),
    [anon_sym___thiscall] = ACTIONS(2347),
    [anon_sym___vectorcall] = ACTIONS(2347),
    [anon_sym_LBRACE] = ACTIONS(2349),
    [anon_sym_signed] = ACTIONS(2347),
    [anon_sym_unsigned] = ACTIONS(2347),
    [anon_sym_long] = ACTIONS(2347),
    [anon_sym_short] = ACTIONS(2347),
    [anon_sym_LBRACK] = ACTIONS(2347),
    [anon_sym_static] = ACTIONS(2347),
    [anon_sym_register] = ACTIONS(2347),
    [anon_sym_inline] = ACTIONS(2347),
    [anon_sym___inline] = ACTIONS(2347),
    [anon_sym___inline__] = ACTIONS(2347),
    [anon_sym___forceinline] = ACTIONS(2347),
    [anon_sym_thread_local] = ACTIONS(2347),
    [anon_sym___thread] = ACTIONS(2347),
    [anon_sym_const] = ACTIONS(2347),
    [anon_sym_constexpr] = ACTIONS(2347),
    [anon_sym_volatile] = ACTIONS(2347),
    [anon_sym_restrict] = ACTIONS(2347),
    [anon_sym___restrict__] = ACTIONS(2347),
    [anon_sym__Atomic] = ACTIONS(2347),
    [anon_sym__Noreturn] = ACTIONS(2347),
    [anon_sym_noreturn] = ACTIONS(2347),
    [anon_sym__Nonnull] = ACTIONS(2347),
    [anon_sym_mutable] = ACTIONS(2347),
    [anon_sym_constinit] = ACTIONS(2347),
    [anon_sym_consteval] = ACTIONS(2347),
    [anon_sym___shared__] = ACTIONS(2347),
    [anon_sym___local__] = ACTIONS(2347),
    [anon_sym___constant__] = ACTIONS(2347),
    [anon_sym___managed__] = ACTIONS(2347),
    [anon_sym___grid_constant__] = ACTIONS(2347),
    [anon_sym_alignas] = ACTIONS(2347),
    [anon_sym__Alignas] = ACTIONS(2347),
    [sym_primitive_type] = ACTIONS(2347),
    [anon_sym_enum] = ACTIONS(2347),
    [anon_sym_class] = ACTIONS(2347),
    [anon_sym_struct] = ACTIONS(2347),
    [anon_sym_union] = ACTIONS(2347),
    [anon_sym_if] = ACTIONS(2347),
    [anon_sym_switch] = ACTIONS(2347),
    [anon_sym_case] = ACTIONS(2347),
    [anon_sym_default] = ACTIONS(2347),
    [anon_sym_while] = ACTIONS(2347),
    [anon_sym_do] = ACTIONS(2347),
    [anon_sym_for] = ACTIONS(2347),
    [anon_sym_return] = ACTIONS(2347),
    [anon_sym_break] = ACTIONS(2347),
    [anon_sym_continue] = ACTIONS(2347),
    [anon_sym_goto] = ACTIONS(2347),
    [anon_sym___try] = ACTIONS(2347),
    [anon_sym___leave] = ACTIONS(2347),
    [anon_sym_not] = ACTIONS(2347),
    [anon_sym_compl] = ACTIONS(2347),
    [anon_sym_DASH_DASH] = ACTIONS(2349),
    [anon_sym_PLUS_PLUS] = ACTIONS(2349),
    [anon_sym_sizeof] = ACTIONS(2347),
    [anon_sym___alignof__] = ACTIONS(2347),
    [anon_sym___alignof] = ACTIONS(2347),
    [anon_sym__alignof] = ACTIONS(2347),
    [anon_sym_alignof] = ACTIONS(2347),
    [anon_sym__Alignof] = ACTIONS(2347),
    [anon_sym_offsetof] = ACTIONS(2347),
    [anon_sym__Generic] = ACTIONS(2347),
    [anon_sym_asm] = ACTIONS(2347),
    [anon_sym___asm__] = ACTIONS(2347),
    [anon_sym___asm] = ACTIONS(2347),
    [sym_number_literal] = ACTIONS(2349),
    [anon_sym_L_SQUOTE] = ACTIONS(2349),
    [anon_sym_u_SQUOTE] = ACTIONS(2349),
    [anon_sym_U_SQUOTE] = ACTIONS(2349),
    [anon_sym_u8_SQUOTE] = ACTIONS(2349),
    [anon_sym_SQUOTE] = ACTIONS(2349),
    [anon_sym_L_DQUOTE] = ACTIONS(2349),
    [anon_sym_u_DQUOTE] = ACTIONS(2349),
    [anon_sym_U_DQUOTE] = ACTIONS(2349),
    [anon_sym_u8_DQUOTE] = ACTIONS(2349),
    [anon_sym_DQUOTE] = ACTIONS(2349),
    [sym_true] = ACTIONS(2347),
    [sym_false] = ACTIONS(2347),
    [anon_sym_NULL] = ACTIONS(2347),
    [anon_sym_nullptr] = ACTIONS(2347),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2347),
    [anon_sym_decltype] = ACTIONS(2347),
    [anon_sym_explicit] = ACTIONS(2347),
    [anon_sym_typename] = ACTIONS(2347),
    [anon_sym_template] = ACTIONS(2347),
    [anon_sym_operator] = ACTIONS(2347),
    [anon_sym_try] = ACTIONS(2347),
    [anon_sym_delete] = ACTIONS(2347),
    [anon_sym_throw] = ACTIONS(2347),
    [anon_sym_namespace] = ACTIONS(2347),
    [anon_sym_using] = ACTIONS(2347),
    [anon_sym_static_assert] = ACTIONS(2347),
    [anon_sym_concept] = ACTIONS(2347),
    [anon_sym_co_return] = ACTIONS(2347),
    [anon_sym_co_yield] = ACTIONS(2347),
    [anon_sym_R_DQUOTE] = ACTIONS(2349),
    [anon_sym_LR_DQUOTE] = ACTIONS(2349),
    [anon_sym_uR_DQUOTE] = ACTIONS(2349),
    [anon_sym_UR_DQUOTE] = ACTIONS(2349),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2349),
    [anon_sym_co_await] = ACTIONS(2347),
    [anon_sym_new] = ACTIONS(2347),
    [anon_sym_requires] = ACTIONS(2347),
    [sym_this] = ACTIONS(2347),
    [anon_sym___launch_bounds__] = ACTIONS(2347),
  },
  [STATE(487)] = {
    [sym_identifier] = ACTIONS(2351),
    [aux_sym_preproc_include_token1] = ACTIONS(2351),
    [aux_sym_preproc_def_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token2] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2351),
    [sym_preproc_directive] = ACTIONS(2351),
    [anon_sym_LPAREN2] = ACTIONS(2353),
    [anon_sym_BANG] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(2353),
    [anon_sym_DASH] = ACTIONS(2351),
    [anon_sym_PLUS] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2353),
    [anon_sym_AMP_AMP] = ACTIONS(2353),
    [anon_sym_AMP] = ACTIONS(2351),
    [anon_sym_SEMI] = ACTIONS(2353),
    [anon_sym___extension__] = ACTIONS(2351),
    [anon_sym_typedef] = ACTIONS(2351),
    [anon_sym___device__] = ACTIONS(2351),
    [anon_sym___host__] = ACTIONS(2351),
    [anon_sym___global__] = ACTIONS(2351),
    [anon_sym___forceinline__] = ACTIONS(2351),
    [anon_sym___noinline__] = ACTIONS(2351),
    [anon_sym_virtual] = ACTIONS(2351),
    [anon_sym_extern] = ACTIONS(2351),
    [anon_sym___attribute__] = ACTIONS(2351),
    [anon_sym___attribute] = ACTIONS(2351),
    [anon_sym_COLON_COLON] = ACTIONS(2353),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2353),
    [anon_sym___declspec] = ACTIONS(2351),
    [anon_sym___based] = ACTIONS(2351),
    [anon_sym___cdecl] = ACTIONS(2351),
    [anon_sym___clrcall] = ACTIONS(2351),
    [anon_sym___stdcall] = ACTIONS(2351),
    [anon_sym___fastcall] = ACTIONS(2351),
    [anon_sym___thiscall] = ACTIONS(2351),
    [anon_sym___vectorcall] = ACTIONS(2351),
    [anon_sym_LBRACE] = ACTIONS(2353),
    [anon_sym_signed] = ACTIONS(2351),
    [anon_sym_unsigned] = ACTIONS(2351),
    [anon_sym_long] = ACTIONS(2351),
    [anon_sym_short] = ACTIONS(2351),
    [anon_sym_LBRACK] = ACTIONS(2351),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_register] = ACTIONS(2351),
    [anon_sym_inline] = ACTIONS(2351),
    [anon_sym___inline] = ACTIONS(2351),
    [anon_sym___inline__] = ACTIONS(2351),
    [anon_sym___forceinline] = ACTIONS(2351),
    [anon_sym_thread_local] = ACTIONS(2351),
    [anon_sym___thread] = ACTIONS(2351),
    [anon_sym_const] = ACTIONS(2351),
    [anon_sym_constexpr] = ACTIONS(2351),
    [anon_sym_volatile] = ACTIONS(2351),
    [anon_sym_restrict] = ACTIONS(2351),
    [anon_sym___restrict__] = ACTIONS(2351),
    [anon_sym__Atomic] = ACTIONS(2351),
    [anon_sym__Noreturn] = ACTIONS(2351),
    [anon_sym_noreturn] = ACTIONS(2351),
    [anon_sym__Nonnull] = ACTIONS(2351),
    [anon_sym_mutable] = ACTIONS(2351),
    [anon_sym_constinit] = ACTIONS(2351),
    [anon_sym_consteval] = ACTIONS(2351),
    [anon_sym___shared__] = ACTIONS(2351),
    [anon_sym___local__] = ACTIONS(2351),
    [anon_sym___constant__] = ACTIONS(2351),
    [anon_sym___managed__] = ACTIONS(2351),
    [anon_sym___grid_constant__] = ACTIONS(2351),
    [anon_sym_alignas] = ACTIONS(2351),
    [anon_sym__Alignas] = ACTIONS(2351),
    [sym_primitive_type] = ACTIONS(2351),
    [anon_sym_enum] = ACTIONS(2351),
    [anon_sym_class] = ACTIONS(2351),
    [anon_sym_struct] = ACTIONS(2351),
    [anon_sym_union] = ACTIONS(2351),
    [anon_sym_if] = ACTIONS(2351),
    [anon_sym_switch] = ACTIONS(2351),
    [anon_sym_case] = ACTIONS(2351),
    [anon_sym_default] = ACTIONS(2351),
    [anon_sym_while] = ACTIONS(2351),
    [anon_sym_do] = ACTIONS(2351),
    [anon_sym_for] = ACTIONS(2351),
    [anon_sym_return] = ACTIONS(2351),
    [anon_sym_break] = ACTIONS(2351),
    [anon_sym_continue] = ACTIONS(2351),
    [anon_sym_goto] = ACTIONS(2351),
    [anon_sym___try] = ACTIONS(2351),
    [anon_sym___leave] = ACTIONS(2351),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_compl] = ACTIONS(2351),
    [anon_sym_DASH_DASH] = ACTIONS(2353),
    [anon_sym_PLUS_PLUS] = ACTIONS(2353),
    [anon_sym_sizeof] = ACTIONS(2351),
    [anon_sym___alignof__] = ACTIONS(2351),
    [anon_sym___alignof] = ACTIONS(2351),
    [anon_sym__alignof] = ACTIONS(2351),
    [anon_sym_alignof] = ACTIONS(2351),
    [anon_sym__Alignof] = ACTIONS(2351),
    [anon_sym_offsetof] = ACTIONS(2351),
    [anon_sym__Generic] = ACTIONS(2351),
    [anon_sym_asm] = ACTIONS(2351),
    [anon_sym___asm__] = ACTIONS(2351),
    [anon_sym___asm] = ACTIONS(2351),
    [sym_number_literal] = ACTIONS(2353),
    [anon_sym_L_SQUOTE] = ACTIONS(2353),
    [anon_sym_u_SQUOTE] = ACTIONS(2353),
    [anon_sym_U_SQUOTE] = ACTIONS(2353),
    [anon_sym_u8_SQUOTE] = ACTIONS(2353),
    [anon_sym_SQUOTE] = ACTIONS(2353),
    [anon_sym_L_DQUOTE] = ACTIONS(2353),
    [anon_sym_u_DQUOTE] = ACTIONS(2353),
    [anon_sym_U_DQUOTE] = ACTIONS(2353),
    [anon_sym_u8_DQUOTE] = ACTIONS(2353),
    [anon_sym_DQUOTE] = ACTIONS(2353),
    [sym_true] = ACTIONS(2351),
    [sym_false] = ACTIONS(2351),
    [anon_sym_NULL] = ACTIONS(2351),
    [anon_sym_nullptr] = ACTIONS(2351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2351),
    [anon_sym_decltype] = ACTIONS(2351),
    [anon_sym_explicit] = ACTIONS(2351),
    [anon_sym_typename] = ACTIONS(2351),
    [anon_sym_template] = ACTIONS(2351),
    [anon_sym_operator] = ACTIONS(2351),
    [anon_sym_try] = ACTIONS(2351),
    [anon_sym_delete] = ACTIONS(2351),
    [anon_sym_throw] = ACTIONS(2351),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_using] = ACTIONS(2351),
    [anon_sym_static_assert] = ACTIONS(2351),
    [anon_sym_concept] = ACTIONS(2351),
    [anon_sym_co_return] = ACTIONS(2351),
    [anon_sym_co_yield] = ACTIONS(2351),
    [anon_sym_R_DQUOTE] = ACTIONS(2353),
    [anon_sym_LR_DQUOTE] = ACTIONS(2353),
    [anon_sym_uR_DQUOTE] = ACTIONS(2353),
    [anon_sym_UR_DQUOTE] = ACTIONS(2353),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2353),
    [anon_sym_co_await] = ACTIONS(2351),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_requires] = ACTIONS(2351),
    [sym_this] = ACTIONS(2351),
    [anon_sym___launch_bounds__] = ACTIONS(2351),
  },
  [STATE(488)] = {
    [sym_identifier] = ACTIONS(2373),
    [aux_sym_preproc_include_token1] = ACTIONS(2373),
    [aux_sym_preproc_def_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token2] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2373),
    [sym_preproc_directive] = ACTIONS(2373),
    [anon_sym_LPAREN2] = ACTIONS(2375),
    [anon_sym_BANG] = ACTIONS(2375),
    [anon_sym_TILDE] = ACTIONS(2375),
    [anon_sym_DASH] = ACTIONS(2373),
    [anon_sym_PLUS] = ACTIONS(2373),
    [anon_sym_STAR] = ACTIONS(2375),
    [anon_sym_AMP_AMP] = ACTIONS(2375),
    [anon_sym_AMP] = ACTIONS(2373),
    [anon_sym_SEMI] = ACTIONS(2375),
    [anon_sym___extension__] = ACTIONS(2373),
    [anon_sym_typedef] = ACTIONS(2373),
    [anon_sym___device__] = ACTIONS(2373),
    [anon_sym___host__] = ACTIONS(2373),
    [anon_sym___global__] = ACTIONS(2373),
    [anon_sym___forceinline__] = ACTIONS(2373),
    [anon_sym___noinline__] = ACTIONS(2373),
    [anon_sym_virtual] = ACTIONS(2373),
    [anon_sym_extern] = ACTIONS(2373),
    [anon_sym___attribute__] = ACTIONS(2373),
    [anon_sym___attribute] = ACTIONS(2373),
    [anon_sym_COLON_COLON] = ACTIONS(2375),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2375),
    [anon_sym___declspec] = ACTIONS(2373),
    [anon_sym___based] = ACTIONS(2373),
    [anon_sym___cdecl] = ACTIONS(2373),
    [anon_sym___clrcall] = ACTIONS(2373),
    [anon_sym___stdcall] = ACTIONS(2373),
    [anon_sym___fastcall] = ACTIONS(2373),
    [anon_sym___thiscall] = ACTIONS(2373),
    [anon_sym___vectorcall] = ACTIONS(2373),
    [anon_sym_LBRACE] = ACTIONS(2375),
    [anon_sym_signed] = ACTIONS(2373),
    [anon_sym_unsigned] = ACTIONS(2373),
    [anon_sym_long] = ACTIONS(2373),
    [anon_sym_short] = ACTIONS(2373),
    [anon_sym_LBRACK] = ACTIONS(2373),
    [anon_sym_static] = ACTIONS(2373),
    [anon_sym_register] = ACTIONS(2373),
    [anon_sym_inline] = ACTIONS(2373),
    [anon_sym___inline] = ACTIONS(2373),
    [anon_sym___inline__] = ACTIONS(2373),
    [anon_sym___forceinline] = ACTIONS(2373),
    [anon_sym_thread_local] = ACTIONS(2373),
    [anon_sym___thread] = ACTIONS(2373),
    [anon_sym_const] = ACTIONS(2373),
    [anon_sym_constexpr] = ACTIONS(2373),
    [anon_sym_volatile] = ACTIONS(2373),
    [anon_sym_restrict] = ACTIONS(2373),
    [anon_sym___restrict__] = ACTIONS(2373),
    [anon_sym__Atomic] = ACTIONS(2373),
    [anon_sym__Noreturn] = ACTIONS(2373),
    [anon_sym_noreturn] = ACTIONS(2373),
    [anon_sym__Nonnull] = ACTIONS(2373),
    [anon_sym_mutable] = ACTIONS(2373),
    [anon_sym_constinit] = ACTIONS(2373),
    [anon_sym_consteval] = ACTIONS(2373),
    [anon_sym___shared__] = ACTIONS(2373),
    [anon_sym___local__] = ACTIONS(2373),
    [anon_sym___constant__] = ACTIONS(2373),
    [anon_sym___managed__] = ACTIONS(2373),
    [anon_sym___grid_constant__] = ACTIONS(2373),
    [anon_sym_alignas] = ACTIONS(2373),
    [anon_sym__Alignas] = ACTIONS(2373),
    [sym_primitive_type] = ACTIONS(2373),
    [anon_sym_enum] = ACTIONS(2373),
    [anon_sym_class] = ACTIONS(2373),
    [anon_sym_struct] = ACTIONS(2373),
    [anon_sym_union] = ACTIONS(2373),
    [anon_sym_if] = ACTIONS(2373),
    [anon_sym_switch] = ACTIONS(2373),
    [anon_sym_case] = ACTIONS(2373),
    [anon_sym_default] = ACTIONS(2373),
    [anon_sym_while] = ACTIONS(2373),
    [anon_sym_do] = ACTIONS(2373),
    [anon_sym_for] = ACTIONS(2373),
    [anon_sym_return] = ACTIONS(2373),
    [anon_sym_break] = ACTIONS(2373),
    [anon_sym_continue] = ACTIONS(2373),
    [anon_sym_goto] = ACTIONS(2373),
    [anon_sym___try] = ACTIONS(2373),
    [anon_sym___leave] = ACTIONS(2373),
    [anon_sym_not] = ACTIONS(2373),
    [anon_sym_compl] = ACTIONS(2373),
    [anon_sym_DASH_DASH] = ACTIONS(2375),
    [anon_sym_PLUS_PLUS] = ACTIONS(2375),
    [anon_sym_sizeof] = ACTIONS(2373),
    [anon_sym___alignof__] = ACTIONS(2373),
    [anon_sym___alignof] = ACTIONS(2373),
    [anon_sym__alignof] = ACTIONS(2373),
    [anon_sym_alignof] = ACTIONS(2373),
    [anon_sym__Alignof] = ACTIONS(2373),
    [anon_sym_offsetof] = ACTIONS(2373),
    [anon_sym__Generic] = ACTIONS(2373),
    [anon_sym_asm] = ACTIONS(2373),
    [anon_sym___asm__] = ACTIONS(2373),
    [anon_sym___asm] = ACTIONS(2373),
    [sym_number_literal] = ACTIONS(2375),
    [anon_sym_L_SQUOTE] = ACTIONS(2375),
    [anon_sym_u_SQUOTE] = ACTIONS(2375),
    [anon_sym_U_SQUOTE] = ACTIONS(2375),
    [anon_sym_u8_SQUOTE] = ACTIONS(2375),
    [anon_sym_SQUOTE] = ACTIONS(2375),
    [anon_sym_L_DQUOTE] = ACTIONS(2375),
    [anon_sym_u_DQUOTE] = ACTIONS(2375),
    [anon_sym_U_DQUOTE] = ACTIONS(2375),
    [anon_sym_u8_DQUOTE] = ACTIONS(2375),
    [anon_sym_DQUOTE] = ACTIONS(2375),
    [sym_true] = ACTIONS(2373),
    [sym_false] = ACTIONS(2373),
    [anon_sym_NULL] = ACTIONS(2373),
    [anon_sym_nullptr] = ACTIONS(2373),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2373),
    [anon_sym_decltype] = ACTIONS(2373),
    [anon_sym_explicit] = ACTIONS(2373),
    [anon_sym_typename] = ACTIONS(2373),
    [anon_sym_template] = ACTIONS(2373),
    [anon_sym_operator] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2373),
    [anon_sym_delete] = ACTIONS(2373),
    [anon_sym_throw] = ACTIONS(2373),
    [anon_sym_namespace] = ACTIONS(2373),
    [anon_sym_using] = ACTIONS(2373),
    [anon_sym_static_assert] = ACTIONS(2373),
    [anon_sym_concept] = ACTIONS(2373),
    [anon_sym_co_return] = ACTIONS(2373),
    [anon_sym_co_yield] = ACTIONS(2373),
    [anon_sym_R_DQUOTE] = ACTIONS(2375),
    [anon_sym_LR_DQUOTE] = ACTIONS(2375),
    [anon_sym_uR_DQUOTE] = ACTIONS(2375),
    [anon_sym_UR_DQUOTE] = ACTIONS(2375),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2375),
    [anon_sym_co_await] = ACTIONS(2373),
    [anon_sym_new] = ACTIONS(2373),
    [anon_sym_requires] = ACTIONS(2373),
    [sym_this] = ACTIONS(2373),
    [anon_sym___launch_bounds__] = ACTIONS(2373),
  },
  [STATE(489)] = {
    [sym_identifier] = ACTIONS(2387),
    [aux_sym_preproc_include_token1] = ACTIONS(2387),
    [aux_sym_preproc_def_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token2] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2387),
    [sym_preproc_directive] = ACTIONS(2387),
    [anon_sym_LPAREN2] = ACTIONS(2389),
    [anon_sym_BANG] = ACTIONS(2389),
    [anon_sym_TILDE] = ACTIONS(2389),
    [anon_sym_DASH] = ACTIONS(2387),
    [anon_sym_PLUS] = ACTIONS(2387),
    [anon_sym_STAR] = ACTIONS(2389),
    [anon_sym_AMP_AMP] = ACTIONS(2389),
    [anon_sym_AMP] = ACTIONS(2387),
    [anon_sym_SEMI] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2387),
    [anon_sym_typedef] = ACTIONS(2387),
    [anon_sym___device__] = ACTIONS(2387),
    [anon_sym___host__] = ACTIONS(2387),
    [anon_sym___global__] = ACTIONS(2387),
    [anon_sym___forceinline__] = ACTIONS(2387),
    [anon_sym___noinline__] = ACTIONS(2387),
    [anon_sym_virtual] = ACTIONS(2387),
    [anon_sym_extern] = ACTIONS(2387),
    [anon_sym___attribute__] = ACTIONS(2387),
    [anon_sym___attribute] = ACTIONS(2387),
    [anon_sym_COLON_COLON] = ACTIONS(2389),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2389),
    [anon_sym___declspec] = ACTIONS(2387),
    [anon_sym___based] = ACTIONS(2387),
    [anon_sym___cdecl] = ACTIONS(2387),
    [anon_sym___clrcall] = ACTIONS(2387),
    [anon_sym___stdcall] = ACTIONS(2387),
    [anon_sym___fastcall] = ACTIONS(2387),
    [anon_sym___thiscall] = ACTIONS(2387),
    [anon_sym___vectorcall] = ACTIONS(2387),
    [anon_sym_LBRACE] = ACTIONS(2389),
    [anon_sym_signed] = ACTIONS(2387),
    [anon_sym_unsigned] = ACTIONS(2387),
    [anon_sym_long] = ACTIONS(2387),
    [anon_sym_short] = ACTIONS(2387),
    [anon_sym_LBRACK] = ACTIONS(2387),
    [anon_sym_static] = ACTIONS(2387),
    [anon_sym_register] = ACTIONS(2387),
    [anon_sym_inline] = ACTIONS(2387),
    [anon_sym___inline] = ACTIONS(2387),
    [anon_sym___inline__] = ACTIONS(2387),
    [anon_sym___forceinline] = ACTIONS(2387),
    [anon_sym_thread_local] = ACTIONS(2387),
    [anon_sym___thread] = ACTIONS(2387),
    [anon_sym_const] = ACTIONS(2387),
    [anon_sym_constexpr] = ACTIONS(2387),
    [anon_sym_volatile] = ACTIONS(2387),
    [anon_sym_restrict] = ACTIONS(2387),
    [anon_sym___restrict__] = ACTIONS(2387),
    [anon_sym__Atomic] = ACTIONS(2387),
    [anon_sym__Noreturn] = ACTIONS(2387),
    [anon_sym_noreturn] = ACTIONS(2387),
    [anon_sym__Nonnull] = ACTIONS(2387),
    [anon_sym_mutable] = ACTIONS(2387),
    [anon_sym_constinit] = ACTIONS(2387),
    [anon_sym_consteval] = ACTIONS(2387),
    [anon_sym___shared__] = ACTIONS(2387),
    [anon_sym___local__] = ACTIONS(2387),
    [anon_sym___constant__] = ACTIONS(2387),
    [anon_sym___managed__] = ACTIONS(2387),
    [anon_sym___grid_constant__] = ACTIONS(2387),
    [anon_sym_alignas] = ACTIONS(2387),
    [anon_sym__Alignas] = ACTIONS(2387),
    [sym_primitive_type] = ACTIONS(2387),
    [anon_sym_enum] = ACTIONS(2387),
    [anon_sym_class] = ACTIONS(2387),
    [anon_sym_struct] = ACTIONS(2387),
    [anon_sym_union] = ACTIONS(2387),
    [anon_sym_if] = ACTIONS(2387),
    [anon_sym_switch] = ACTIONS(2387),
    [anon_sym_case] = ACTIONS(2387),
    [anon_sym_default] = ACTIONS(2387),
    [anon_sym_while] = ACTIONS(2387),
    [anon_sym_do] = ACTIONS(2387),
    [anon_sym_for] = ACTIONS(2387),
    [anon_sym_return] = ACTIONS(2387),
    [anon_sym_break] = ACTIONS(2387),
    [anon_sym_continue] = ACTIONS(2387),
    [anon_sym_goto] = ACTIONS(2387),
    [anon_sym___try] = ACTIONS(2387),
    [anon_sym___leave] = ACTIONS(2387),
    [anon_sym_not] = ACTIONS(2387),
    [anon_sym_compl] = ACTIONS(2387),
    [anon_sym_DASH_DASH] = ACTIONS(2389),
    [anon_sym_PLUS_PLUS] = ACTIONS(2389),
    [anon_sym_sizeof] = ACTIONS(2387),
    [anon_sym___alignof__] = ACTIONS(2387),
    [anon_sym___alignof] = ACTIONS(2387),
    [anon_sym__alignof] = ACTIONS(2387),
    [anon_sym_alignof] = ACTIONS(2387),
    [anon_sym__Alignof] = ACTIONS(2387),
    [anon_sym_offsetof] = ACTIONS(2387),
    [anon_sym__Generic] = ACTIONS(2387),
    [anon_sym_asm] = ACTIONS(2387),
    [anon_sym___asm__] = ACTIONS(2387),
    [anon_sym___asm] = ACTIONS(2387),
    [sym_number_literal] = ACTIONS(2389),
    [anon_sym_L_SQUOTE] = ACTIONS(2389),
    [anon_sym_u_SQUOTE] = ACTIONS(2389),
    [anon_sym_U_SQUOTE] = ACTIONS(2389),
    [anon_sym_u8_SQUOTE] = ACTIONS(2389),
    [anon_sym_SQUOTE] = ACTIONS(2389),
    [anon_sym_L_DQUOTE] = ACTIONS(2389),
    [anon_sym_u_DQUOTE] = ACTIONS(2389),
    [anon_sym_U_DQUOTE] = ACTIONS(2389),
    [anon_sym_u8_DQUOTE] = ACTIONS(2389),
    [anon_sym_DQUOTE] = ACTIONS(2389),
    [sym_true] = ACTIONS(2387),
    [sym_false] = ACTIONS(2387),
    [anon_sym_NULL] = ACTIONS(2387),
    [anon_sym_nullptr] = ACTIONS(2387),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2387),
    [anon_sym_decltype] = ACTIONS(2387),
    [anon_sym_explicit] = ACTIONS(2387),
    [anon_sym_typename] = ACTIONS(2387),
    [anon_sym_template] = ACTIONS(2387),
    [anon_sym_operator] = ACTIONS(2387),
    [anon_sym_try] = ACTIONS(2387),
    [anon_sym_delete] = ACTIONS(2387),
    [anon_sym_throw] = ACTIONS(2387),
    [anon_sym_namespace] = ACTIONS(2387),
    [anon_sym_using] = ACTIONS(2387),
    [anon_sym_static_assert] = ACTIONS(2387),
    [anon_sym_concept] = ACTIONS(2387),
    [anon_sym_co_return] = ACTIONS(2387),
    [anon_sym_co_yield] = ACTIONS(2387),
    [anon_sym_R_DQUOTE] = ACTIONS(2389),
    [anon_sym_LR_DQUOTE] = ACTIONS(2389),
    [anon_sym_uR_DQUOTE] = ACTIONS(2389),
    [anon_sym_UR_DQUOTE] = ACTIONS(2389),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2389),
    [anon_sym_co_await] = ACTIONS(2387),
    [anon_sym_new] = ACTIONS(2387),
    [anon_sym_requires] = ACTIONS(2387),
    [sym_this] = ACTIONS(2387),
    [anon_sym___launch_bounds__] = ACTIONS(2387),
  },
  [STATE(490)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4986),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7637),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8026),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2916),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(491)] = {
    [ts_builtin_sym_end] = ACTIONS(2491),
    [sym_identifier] = ACTIONS(2489),
    [aux_sym_preproc_include_token1] = ACTIONS(2489),
    [aux_sym_preproc_def_token1] = ACTIONS(2489),
    [anon_sym_COMMA] = ACTIONS(2491),
    [aux_sym_preproc_if_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2489),
    [sym_preproc_directive] = ACTIONS(2489),
    [anon_sym_LPAREN2] = ACTIONS(2491),
    [anon_sym_BANG] = ACTIONS(2491),
    [anon_sym_TILDE] = ACTIONS(2491),
    [anon_sym_DASH] = ACTIONS(2489),
    [anon_sym_PLUS] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(2491),
    [anon_sym_AMP_AMP] = ACTIONS(2491),
    [anon_sym_AMP] = ACTIONS(2489),
    [anon_sym_SEMI] = ACTIONS(2491),
    [anon_sym___extension__] = ACTIONS(2489),
    [anon_sym_typedef] = ACTIONS(2489),
    [anon_sym___device__] = ACTIONS(2489),
    [anon_sym___host__] = ACTIONS(2489),
    [anon_sym___global__] = ACTIONS(2489),
    [anon_sym___forceinline__] = ACTIONS(2489),
    [anon_sym___noinline__] = ACTIONS(2489),
    [anon_sym_virtual] = ACTIONS(2489),
    [anon_sym_extern] = ACTIONS(2489),
    [anon_sym___attribute__] = ACTIONS(2489),
    [anon_sym___attribute] = ACTIONS(2489),
    [anon_sym_COLON_COLON] = ACTIONS(2491),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2491),
    [anon_sym___declspec] = ACTIONS(2489),
    [anon_sym___based] = ACTIONS(2489),
    [anon_sym___cdecl] = ACTIONS(2489),
    [anon_sym___clrcall] = ACTIONS(2489),
    [anon_sym___stdcall] = ACTIONS(2489),
    [anon_sym___fastcall] = ACTIONS(2489),
    [anon_sym___thiscall] = ACTIONS(2489),
    [anon_sym___vectorcall] = ACTIONS(2489),
    [anon_sym_LBRACE] = ACTIONS(2491),
    [anon_sym_RBRACE] = ACTIONS(2491),
    [anon_sym_signed] = ACTIONS(2489),
    [anon_sym_unsigned] = ACTIONS(2489),
    [anon_sym_long] = ACTIONS(2489),
    [anon_sym_short] = ACTIONS(2489),
    [anon_sym_LBRACK] = ACTIONS(2489),
    [anon_sym_static] = ACTIONS(2489),
    [anon_sym_register] = ACTIONS(2489),
    [anon_sym_inline] = ACTIONS(2489),
    [anon_sym___inline] = ACTIONS(2489),
    [anon_sym___inline__] = ACTIONS(2489),
    [anon_sym___forceinline] = ACTIONS(2489),
    [anon_sym_thread_local] = ACTIONS(2489),
    [anon_sym___thread] = ACTIONS(2489),
    [anon_sym_const] = ACTIONS(2489),
    [anon_sym_constexpr] = ACTIONS(2489),
    [anon_sym_volatile] = ACTIONS(2489),
    [anon_sym_restrict] = ACTIONS(2489),
    [anon_sym___restrict__] = ACTIONS(2489),
    [anon_sym__Atomic] = ACTIONS(2489),
    [anon_sym__Noreturn] = ACTIONS(2489),
    [anon_sym_noreturn] = ACTIONS(2489),
    [anon_sym__Nonnull] = ACTIONS(2489),
    [anon_sym_mutable] = ACTIONS(2489),
    [anon_sym_constinit] = ACTIONS(2489),
    [anon_sym_consteval] = ACTIONS(2489),
    [anon_sym___shared__] = ACTIONS(2489),
    [anon_sym___local__] = ACTIONS(2489),
    [anon_sym___constant__] = ACTIONS(2489),
    [anon_sym___managed__] = ACTIONS(2489),
    [anon_sym___grid_constant__] = ACTIONS(2489),
    [anon_sym_alignas] = ACTIONS(2489),
    [anon_sym__Alignas] = ACTIONS(2489),
    [sym_primitive_type] = ACTIONS(2489),
    [anon_sym_enum] = ACTIONS(2489),
    [anon_sym_class] = ACTIONS(2489),
    [anon_sym_struct] = ACTIONS(2489),
    [anon_sym_union] = ACTIONS(2489),
    [anon_sym_if] = ACTIONS(2489),
    [anon_sym_switch] = ACTIONS(2489),
    [anon_sym_case] = ACTIONS(2489),
    [anon_sym_default] = ACTIONS(2489),
    [anon_sym_while] = ACTIONS(2489),
    [anon_sym_do] = ACTIONS(2489),
    [anon_sym_for] = ACTIONS(2489),
    [anon_sym_return] = ACTIONS(2489),
    [anon_sym_break] = ACTIONS(2489),
    [anon_sym_continue] = ACTIONS(2489),
    [anon_sym_goto] = ACTIONS(2489),
    [anon_sym_not] = ACTIONS(2489),
    [anon_sym_compl] = ACTIONS(2489),
    [anon_sym_DASH_DASH] = ACTIONS(2491),
    [anon_sym_PLUS_PLUS] = ACTIONS(2491),
    [anon_sym_sizeof] = ACTIONS(2489),
    [anon_sym___alignof__] = ACTIONS(2489),
    [anon_sym___alignof] = ACTIONS(2489),
    [anon_sym__alignof] = ACTIONS(2489),
    [anon_sym_alignof] = ACTIONS(2489),
    [anon_sym__Alignof] = ACTIONS(2489),
    [anon_sym_offsetof] = ACTIONS(2489),
    [anon_sym__Generic] = ACTIONS(2489),
    [anon_sym_asm] = ACTIONS(2489),
    [anon_sym___asm__] = ACTIONS(2489),
    [anon_sym___asm] = ACTIONS(2489),
    [sym_number_literal] = ACTIONS(2491),
    [anon_sym_L_SQUOTE] = ACTIONS(2491),
    [anon_sym_u_SQUOTE] = ACTIONS(2491),
    [anon_sym_U_SQUOTE] = ACTIONS(2491),
    [anon_sym_u8_SQUOTE] = ACTIONS(2491),
    [anon_sym_SQUOTE] = ACTIONS(2491),
    [anon_sym_L_DQUOTE] = ACTIONS(2491),
    [anon_sym_u_DQUOTE] = ACTIONS(2491),
    [anon_sym_U_DQUOTE] = ACTIONS(2491),
    [anon_sym_u8_DQUOTE] = ACTIONS(2491),
    [anon_sym_DQUOTE] = ACTIONS(2491),
    [sym_true] = ACTIONS(2489),
    [sym_false] = ACTIONS(2489),
    [anon_sym_NULL] = ACTIONS(2489),
    [anon_sym_nullptr] = ACTIONS(2489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2489),
    [anon_sym_decltype] = ACTIONS(2489),
    [anon_sym_explicit] = ACTIONS(2489),
    [anon_sym_typename] = ACTIONS(2489),
    [anon_sym_template] = ACTIONS(2489),
    [anon_sym_operator] = ACTIONS(2489),
    [anon_sym_try] = ACTIONS(2489),
    [anon_sym_delete] = ACTIONS(2489),
    [anon_sym_throw] = ACTIONS(2489),
    [anon_sym_namespace] = ACTIONS(2489),
    [anon_sym_using] = ACTIONS(2489),
    [anon_sym_static_assert] = ACTIONS(2489),
    [anon_sym_concept] = ACTIONS(2489),
    [anon_sym_co_return] = ACTIONS(2489),
    [anon_sym_co_yield] = ACTIONS(2489),
    [anon_sym_R_DQUOTE] = ACTIONS(2491),
    [anon_sym_LR_DQUOTE] = ACTIONS(2491),
    [anon_sym_uR_DQUOTE] = ACTIONS(2491),
    [anon_sym_UR_DQUOTE] = ACTIONS(2491),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2491),
    [anon_sym_co_await] = ACTIONS(2489),
    [anon_sym_new] = ACTIONS(2489),
    [anon_sym_requires] = ACTIONS(2489),
    [sym_this] = ACTIONS(2489),
    [anon_sym___launch_bounds__] = ACTIONS(2489),
  },
  [STATE(492)] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_include_token1] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token2] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym___device__] = ACTIONS(2565),
    [anon_sym___host__] = ACTIONS(2565),
    [anon_sym___global__] = ACTIONS(2565),
    [anon_sym___forceinline__] = ACTIONS(2565),
    [anon_sym___noinline__] = ACTIONS(2565),
    [anon_sym_virtual] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym___attribute] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym___cdecl] = ACTIONS(2565),
    [anon_sym___clrcall] = ACTIONS(2565),
    [anon_sym___stdcall] = ACTIONS(2565),
    [anon_sym___fastcall] = ACTIONS(2565),
    [anon_sym___thiscall] = ACTIONS(2565),
    [anon_sym___vectorcall] = ACTIONS(2565),
    [anon_sym_LBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym__Nonnull] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym___shared__] = ACTIONS(2565),
    [anon_sym___local__] = ACTIONS(2565),
    [anon_sym___constant__] = ACTIONS(2565),
    [anon_sym___managed__] = ACTIONS(2565),
    [anon_sym___grid_constant__] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_switch] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_default] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_do] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_return] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_goto] = ACTIONS(2565),
    [anon_sym___try] = ACTIONS(2565),
    [anon_sym___leave] = ACTIONS(2565),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_compl] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2567),
    [anon_sym_sizeof] = ACTIONS(2565),
    [anon_sym___alignof__] = ACTIONS(2565),
    [anon_sym___alignof] = ACTIONS(2565),
    [anon_sym__alignof] = ACTIONS(2565),
    [anon_sym_alignof] = ACTIONS(2565),
    [anon_sym__Alignof] = ACTIONS(2565),
    [anon_sym_offsetof] = ACTIONS(2565),
    [anon_sym__Generic] = ACTIONS(2565),
    [anon_sym_asm] = ACTIONS(2565),
    [anon_sym___asm__] = ACTIONS(2565),
    [anon_sym___asm] = ACTIONS(2565),
    [sym_number_literal] = ACTIONS(2567),
    [anon_sym_L_SQUOTE] = ACTIONS(2567),
    [anon_sym_u_SQUOTE] = ACTIONS(2567),
    [anon_sym_U_SQUOTE] = ACTIONS(2567),
    [anon_sym_u8_SQUOTE] = ACTIONS(2567),
    [anon_sym_SQUOTE] = ACTIONS(2567),
    [anon_sym_L_DQUOTE] = ACTIONS(2567),
    [anon_sym_u_DQUOTE] = ACTIONS(2567),
    [anon_sym_U_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8_DQUOTE] = ACTIONS(2567),
    [anon_sym_DQUOTE] = ACTIONS(2567),
    [sym_true] = ACTIONS(2565),
    [sym_false] = ACTIONS(2565),
    [anon_sym_NULL] = ACTIONS(2565),
    [anon_sym_nullptr] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_try] = ACTIONS(2565),
    [anon_sym_delete] = ACTIONS(2565),
    [anon_sym_throw] = ACTIONS(2565),
    [anon_sym_namespace] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_concept] = ACTIONS(2565),
    [anon_sym_co_return] = ACTIONS(2565),
    [anon_sym_co_yield] = ACTIONS(2565),
    [anon_sym_R_DQUOTE] = ACTIONS(2567),
    [anon_sym_LR_DQUOTE] = ACTIONS(2567),
    [anon_sym_uR_DQUOTE] = ACTIONS(2567),
    [anon_sym_UR_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2567),
    [anon_sym_co_await] = ACTIONS(2565),
    [anon_sym_new] = ACTIONS(2565),
    [anon_sym_requires] = ACTIONS(2565),
    [sym_this] = ACTIONS(2565),
    [anon_sym___launch_bounds__] = ACTIONS(2565),
  },
  [STATE(493)] = {
    [sym_identifier] = ACTIONS(2226),
    [aux_sym_preproc_include_token1] = ACTIONS(2226),
    [aux_sym_preproc_def_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token2] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2226),
    [sym_preproc_directive] = ACTIONS(2226),
    [anon_sym_LPAREN2] = ACTIONS(2228),
    [anon_sym_BANG] = ACTIONS(2228),
    [anon_sym_TILDE] = ACTIONS(2228),
    [anon_sym_DASH] = ACTIONS(2226),
    [anon_sym_PLUS] = ACTIONS(2226),
    [anon_sym_STAR] = ACTIONS(2228),
    [anon_sym_AMP_AMP] = ACTIONS(2228),
    [anon_sym_AMP] = ACTIONS(2226),
    [anon_sym_SEMI] = ACTIONS(2228),
    [anon_sym___extension__] = ACTIONS(2226),
    [anon_sym_typedef] = ACTIONS(2226),
    [anon_sym___device__] = ACTIONS(2226),
    [anon_sym___host__] = ACTIONS(2226),
    [anon_sym___global__] = ACTIONS(2226),
    [anon_sym___forceinline__] = ACTIONS(2226),
    [anon_sym___noinline__] = ACTIONS(2226),
    [anon_sym_virtual] = ACTIONS(2226),
    [anon_sym_extern] = ACTIONS(2226),
    [anon_sym___attribute__] = ACTIONS(2226),
    [anon_sym___attribute] = ACTIONS(2226),
    [anon_sym_COLON_COLON] = ACTIONS(2228),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2228),
    [anon_sym___declspec] = ACTIONS(2226),
    [anon_sym___based] = ACTIONS(2226),
    [anon_sym___cdecl] = ACTIONS(2226),
    [anon_sym___clrcall] = ACTIONS(2226),
    [anon_sym___stdcall] = ACTIONS(2226),
    [anon_sym___fastcall] = ACTIONS(2226),
    [anon_sym___thiscall] = ACTIONS(2226),
    [anon_sym___vectorcall] = ACTIONS(2226),
    [anon_sym_LBRACE] = ACTIONS(2228),
    [anon_sym_signed] = ACTIONS(2226),
    [anon_sym_unsigned] = ACTIONS(2226),
    [anon_sym_long] = ACTIONS(2226),
    [anon_sym_short] = ACTIONS(2226),
    [anon_sym_LBRACK] = ACTIONS(2226),
    [anon_sym_static] = ACTIONS(2226),
    [anon_sym_register] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(2226),
    [anon_sym___inline] = ACTIONS(2226),
    [anon_sym___inline__] = ACTIONS(2226),
    [anon_sym___forceinline] = ACTIONS(2226),
    [anon_sym_thread_local] = ACTIONS(2226),
    [anon_sym___thread] = ACTIONS(2226),
    [anon_sym_const] = ACTIONS(2226),
    [anon_sym_constexpr] = ACTIONS(2226),
    [anon_sym_volatile] = ACTIONS(2226),
    [anon_sym_restrict] = ACTIONS(2226),
    [anon_sym___restrict__] = ACTIONS(2226),
    [anon_sym__Atomic] = ACTIONS(2226),
    [anon_sym__Noreturn] = ACTIONS(2226),
    [anon_sym_noreturn] = ACTIONS(2226),
    [anon_sym__Nonnull] = ACTIONS(2226),
    [anon_sym_mutable] = ACTIONS(2226),
    [anon_sym_constinit] = ACTIONS(2226),
    [anon_sym_consteval] = ACTIONS(2226),
    [anon_sym___shared__] = ACTIONS(2226),
    [anon_sym___local__] = ACTIONS(2226),
    [anon_sym___constant__] = ACTIONS(2226),
    [anon_sym___managed__] = ACTIONS(2226),
    [anon_sym___grid_constant__] = ACTIONS(2226),
    [anon_sym_alignas] = ACTIONS(2226),
    [anon_sym__Alignas] = ACTIONS(2226),
    [sym_primitive_type] = ACTIONS(2226),
    [anon_sym_enum] = ACTIONS(2226),
    [anon_sym_class] = ACTIONS(2226),
    [anon_sym_struct] = ACTIONS(2226),
    [anon_sym_union] = ACTIONS(2226),
    [anon_sym_if] = ACTIONS(2226),
    [anon_sym_switch] = ACTIONS(2226),
    [anon_sym_case] = ACTIONS(2226),
    [anon_sym_default] = ACTIONS(2226),
    [anon_sym_while] = ACTIONS(2226),
    [anon_sym_do] = ACTIONS(2226),
    [anon_sym_for] = ACTIONS(2226),
    [anon_sym_return] = ACTIONS(2226),
    [anon_sym_break] = ACTIONS(2226),
    [anon_sym_continue] = ACTIONS(2226),
    [anon_sym_goto] = ACTIONS(2226),
    [anon_sym___try] = ACTIONS(2226),
    [anon_sym___leave] = ACTIONS(2226),
    [anon_sym_not] = ACTIONS(2226),
    [anon_sym_compl] = ACTIONS(2226),
    [anon_sym_DASH_DASH] = ACTIONS(2228),
    [anon_sym_PLUS_PLUS] = ACTIONS(2228),
    [anon_sym_sizeof] = ACTIONS(2226),
    [anon_sym___alignof__] = ACTIONS(2226),
    [anon_sym___alignof] = ACTIONS(2226),
    [anon_sym__alignof] = ACTIONS(2226),
    [anon_sym_alignof] = ACTIONS(2226),
    [anon_sym__Alignof] = ACTIONS(2226),
    [anon_sym_offsetof] = ACTIONS(2226),
    [anon_sym__Generic] = ACTIONS(2226),
    [anon_sym_asm] = ACTIONS(2226),
    [anon_sym___asm__] = ACTIONS(2226),
    [anon_sym___asm] = ACTIONS(2226),
    [sym_number_literal] = ACTIONS(2228),
    [anon_sym_L_SQUOTE] = ACTIONS(2228),
    [anon_sym_u_SQUOTE] = ACTIONS(2228),
    [anon_sym_U_SQUOTE] = ACTIONS(2228),
    [anon_sym_u8_SQUOTE] = ACTIONS(2228),
    [anon_sym_SQUOTE] = ACTIONS(2228),
    [anon_sym_L_DQUOTE] = ACTIONS(2228),
    [anon_sym_u_DQUOTE] = ACTIONS(2228),
    [anon_sym_U_DQUOTE] = ACTIONS(2228),
    [anon_sym_u8_DQUOTE] = ACTIONS(2228),
    [anon_sym_DQUOTE] = ACTIONS(2228),
    [sym_true] = ACTIONS(2226),
    [sym_false] = ACTIONS(2226),
    [anon_sym_NULL] = ACTIONS(2226),
    [anon_sym_nullptr] = ACTIONS(2226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2226),
    [anon_sym_decltype] = ACTIONS(2226),
    [anon_sym_explicit] = ACTIONS(2226),
    [anon_sym_typename] = ACTIONS(2226),
    [anon_sym_template] = ACTIONS(2226),
    [anon_sym_operator] = ACTIONS(2226),
    [anon_sym_try] = ACTIONS(2226),
    [anon_sym_delete] = ACTIONS(2226),
    [anon_sym_throw] = ACTIONS(2226),
    [anon_sym_namespace] = ACTIONS(2226),
    [anon_sym_using] = ACTIONS(2226),
    [anon_sym_static_assert] = ACTIONS(2226),
    [anon_sym_concept] = ACTIONS(2226),
    [anon_sym_co_return] = ACTIONS(2226),
    [anon_sym_co_yield] = ACTIONS(2226),
    [anon_sym_R_DQUOTE] = ACTIONS(2228),
    [anon_sym_LR_DQUOTE] = ACTIONS(2228),
    [anon_sym_uR_DQUOTE] = ACTIONS(2228),
    [anon_sym_UR_DQUOTE] = ACTIONS(2228),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2228),
    [anon_sym_co_await] = ACTIONS(2226),
    [anon_sym_new] = ACTIONS(2226),
    [anon_sym_requires] = ACTIONS(2226),
    [sym_this] = ACTIONS(2226),
    [anon_sym___launch_bounds__] = ACTIONS(2226),
  },
  [STATE(494)] = {
    [sym_identifier] = ACTIONS(2513),
    [aux_sym_preproc_include_token1] = ACTIONS(2513),
    [aux_sym_preproc_def_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2513),
    [sym_preproc_directive] = ACTIONS(2513),
    [anon_sym_LPAREN2] = ACTIONS(2515),
    [anon_sym_BANG] = ACTIONS(2515),
    [anon_sym_TILDE] = ACTIONS(2515),
    [anon_sym_DASH] = ACTIONS(2513),
    [anon_sym_PLUS] = ACTIONS(2513),
    [anon_sym_STAR] = ACTIONS(2515),
    [anon_sym_AMP_AMP] = ACTIONS(2515),
    [anon_sym_AMP] = ACTIONS(2513),
    [anon_sym_SEMI] = ACTIONS(2515),
    [anon_sym___extension__] = ACTIONS(2513),
    [anon_sym_typedef] = ACTIONS(2513),
    [anon_sym___device__] = ACTIONS(2513),
    [anon_sym___host__] = ACTIONS(2513),
    [anon_sym___global__] = ACTIONS(2513),
    [anon_sym___forceinline__] = ACTIONS(2513),
    [anon_sym___noinline__] = ACTIONS(2513),
    [anon_sym_virtual] = ACTIONS(2513),
    [anon_sym_extern] = ACTIONS(2513),
    [anon_sym___attribute__] = ACTIONS(2513),
    [anon_sym___attribute] = ACTIONS(2513),
    [anon_sym_COLON_COLON] = ACTIONS(2515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2515),
    [anon_sym___declspec] = ACTIONS(2513),
    [anon_sym___based] = ACTIONS(2513),
    [anon_sym___cdecl] = ACTIONS(2513),
    [anon_sym___clrcall] = ACTIONS(2513),
    [anon_sym___stdcall] = ACTIONS(2513),
    [anon_sym___fastcall] = ACTIONS(2513),
    [anon_sym___thiscall] = ACTIONS(2513),
    [anon_sym___vectorcall] = ACTIONS(2513),
    [anon_sym_LBRACE] = ACTIONS(2515),
    [anon_sym_RBRACE] = ACTIONS(2515),
    [anon_sym_signed] = ACTIONS(2513),
    [anon_sym_unsigned] = ACTIONS(2513),
    [anon_sym_long] = ACTIONS(2513),
    [anon_sym_short] = ACTIONS(2513),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_static] = ACTIONS(2513),
    [anon_sym_register] = ACTIONS(2513),
    [anon_sym_inline] = ACTIONS(2513),
    [anon_sym___inline] = ACTIONS(2513),
    [anon_sym___inline__] = ACTIONS(2513),
    [anon_sym___forceinline] = ACTIONS(2513),
    [anon_sym_thread_local] = ACTIONS(2513),
    [anon_sym___thread] = ACTIONS(2513),
    [anon_sym_const] = ACTIONS(2513),
    [anon_sym_constexpr] = ACTIONS(2513),
    [anon_sym_volatile] = ACTIONS(2513),
    [anon_sym_restrict] = ACTIONS(2513),
    [anon_sym___restrict__] = ACTIONS(2513),
    [anon_sym__Atomic] = ACTIONS(2513),
    [anon_sym__Noreturn] = ACTIONS(2513),
    [anon_sym_noreturn] = ACTIONS(2513),
    [anon_sym__Nonnull] = ACTIONS(2513),
    [anon_sym_mutable] = ACTIONS(2513),
    [anon_sym_constinit] = ACTIONS(2513),
    [anon_sym_consteval] = ACTIONS(2513),
    [anon_sym___shared__] = ACTIONS(2513),
    [anon_sym___local__] = ACTIONS(2513),
    [anon_sym___constant__] = ACTIONS(2513),
    [anon_sym___managed__] = ACTIONS(2513),
    [anon_sym___grid_constant__] = ACTIONS(2513),
    [anon_sym_alignas] = ACTIONS(2513),
    [anon_sym__Alignas] = ACTIONS(2513),
    [sym_primitive_type] = ACTIONS(2513),
    [anon_sym_enum] = ACTIONS(2513),
    [anon_sym_class] = ACTIONS(2513),
    [anon_sym_struct] = ACTIONS(2513),
    [anon_sym_union] = ACTIONS(2513),
    [anon_sym_if] = ACTIONS(2513),
    [anon_sym_switch] = ACTIONS(2513),
    [anon_sym_case] = ACTIONS(2513),
    [anon_sym_default] = ACTIONS(2513),
    [anon_sym_while] = ACTIONS(2513),
    [anon_sym_do] = ACTIONS(2513),
    [anon_sym_for] = ACTIONS(2513),
    [anon_sym_return] = ACTIONS(2513),
    [anon_sym_break] = ACTIONS(2513),
    [anon_sym_continue] = ACTIONS(2513),
    [anon_sym_goto] = ACTIONS(2513),
    [anon_sym___try] = ACTIONS(2513),
    [anon_sym___leave] = ACTIONS(2513),
    [anon_sym_not] = ACTIONS(2513),
    [anon_sym_compl] = ACTIONS(2513),
    [anon_sym_DASH_DASH] = ACTIONS(2515),
    [anon_sym_PLUS_PLUS] = ACTIONS(2515),
    [anon_sym_sizeof] = ACTIONS(2513),
    [anon_sym___alignof__] = ACTIONS(2513),
    [anon_sym___alignof] = ACTIONS(2513),
    [anon_sym__alignof] = ACTIONS(2513),
    [anon_sym_alignof] = ACTIONS(2513),
    [anon_sym__Alignof] = ACTIONS(2513),
    [anon_sym_offsetof] = ACTIONS(2513),
    [anon_sym__Generic] = ACTIONS(2513),
    [anon_sym_asm] = ACTIONS(2513),
    [anon_sym___asm__] = ACTIONS(2513),
    [anon_sym___asm] = ACTIONS(2513),
    [sym_number_literal] = ACTIONS(2515),
    [anon_sym_L_SQUOTE] = ACTIONS(2515),
    [anon_sym_u_SQUOTE] = ACTIONS(2515),
    [anon_sym_U_SQUOTE] = ACTIONS(2515),
    [anon_sym_u8_SQUOTE] = ACTIONS(2515),
    [anon_sym_SQUOTE] = ACTIONS(2515),
    [anon_sym_L_DQUOTE] = ACTIONS(2515),
    [anon_sym_u_DQUOTE] = ACTIONS(2515),
    [anon_sym_U_DQUOTE] = ACTIONS(2515),
    [anon_sym_u8_DQUOTE] = ACTIONS(2515),
    [anon_sym_DQUOTE] = ACTIONS(2515),
    [sym_true] = ACTIONS(2513),
    [sym_false] = ACTIONS(2513),
    [anon_sym_NULL] = ACTIONS(2513),
    [anon_sym_nullptr] = ACTIONS(2513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2513),
    [anon_sym_decltype] = ACTIONS(2513),
    [anon_sym_explicit] = ACTIONS(2513),
    [anon_sym_typename] = ACTIONS(2513),
    [anon_sym_template] = ACTIONS(2513),
    [anon_sym_operator] = ACTIONS(2513),
    [anon_sym_try] = ACTIONS(2513),
    [anon_sym_delete] = ACTIONS(2513),
    [anon_sym_throw] = ACTIONS(2513),
    [anon_sym_namespace] = ACTIONS(2513),
    [anon_sym_using] = ACTIONS(2513),
    [anon_sym_static_assert] = ACTIONS(2513),
    [anon_sym_concept] = ACTIONS(2513),
    [anon_sym_co_return] = ACTIONS(2513),
    [anon_sym_co_yield] = ACTIONS(2513),
    [anon_sym_R_DQUOTE] = ACTIONS(2515),
    [anon_sym_LR_DQUOTE] = ACTIONS(2515),
    [anon_sym_uR_DQUOTE] = ACTIONS(2515),
    [anon_sym_UR_DQUOTE] = ACTIONS(2515),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2515),
    [anon_sym_co_await] = ACTIONS(2513),
    [anon_sym_new] = ACTIONS(2513),
    [anon_sym_requires] = ACTIONS(2513),
    [sym_this] = ACTIONS(2513),
    [anon_sym___launch_bounds__] = ACTIONS(2513),
  },
  [STATE(495)] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_include_token1] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token2] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym___device__] = ACTIONS(2561),
    [anon_sym___host__] = ACTIONS(2561),
    [anon_sym___global__] = ACTIONS(2561),
    [anon_sym___forceinline__] = ACTIONS(2561),
    [anon_sym___noinline__] = ACTIONS(2561),
    [anon_sym_virtual] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym___attribute] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym___cdecl] = ACTIONS(2561),
    [anon_sym___clrcall] = ACTIONS(2561),
    [anon_sym___stdcall] = ACTIONS(2561),
    [anon_sym___fastcall] = ACTIONS(2561),
    [anon_sym___thiscall] = ACTIONS(2561),
    [anon_sym___vectorcall] = ACTIONS(2561),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym__Nonnull] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym___shared__] = ACTIONS(2561),
    [anon_sym___local__] = ACTIONS(2561),
    [anon_sym___constant__] = ACTIONS(2561),
    [anon_sym___managed__] = ACTIONS(2561),
    [anon_sym___grid_constant__] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_switch] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_default] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_do] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_return] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_goto] = ACTIONS(2561),
    [anon_sym___try] = ACTIONS(2561),
    [anon_sym___leave] = ACTIONS(2561),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_compl] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2563),
    [anon_sym_sizeof] = ACTIONS(2561),
    [anon_sym___alignof__] = ACTIONS(2561),
    [anon_sym___alignof] = ACTIONS(2561),
    [anon_sym__alignof] = ACTIONS(2561),
    [anon_sym_alignof] = ACTIONS(2561),
    [anon_sym__Alignof] = ACTIONS(2561),
    [anon_sym_offsetof] = ACTIONS(2561),
    [anon_sym__Generic] = ACTIONS(2561),
    [anon_sym_asm] = ACTIONS(2561),
    [anon_sym___asm__] = ACTIONS(2561),
    [anon_sym___asm] = ACTIONS(2561),
    [sym_number_literal] = ACTIONS(2563),
    [anon_sym_L_SQUOTE] = ACTIONS(2563),
    [anon_sym_u_SQUOTE] = ACTIONS(2563),
    [anon_sym_U_SQUOTE] = ACTIONS(2563),
    [anon_sym_u8_SQUOTE] = ACTIONS(2563),
    [anon_sym_SQUOTE] = ACTIONS(2563),
    [anon_sym_L_DQUOTE] = ACTIONS(2563),
    [anon_sym_u_DQUOTE] = ACTIONS(2563),
    [anon_sym_U_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8_DQUOTE] = ACTIONS(2563),
    [anon_sym_DQUOTE] = ACTIONS(2563),
    [sym_true] = ACTIONS(2561),
    [sym_false] = ACTIONS(2561),
    [anon_sym_NULL] = ACTIONS(2561),
    [anon_sym_nullptr] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_try] = ACTIONS(2561),
    [anon_sym_delete] = ACTIONS(2561),
    [anon_sym_throw] = ACTIONS(2561),
    [anon_sym_namespace] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_concept] = ACTIONS(2561),
    [anon_sym_co_return] = ACTIONS(2561),
    [anon_sym_co_yield] = ACTIONS(2561),
    [anon_sym_R_DQUOTE] = ACTIONS(2563),
    [anon_sym_LR_DQUOTE] = ACTIONS(2563),
    [anon_sym_uR_DQUOTE] = ACTIONS(2563),
    [anon_sym_UR_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2563),
    [anon_sym_co_await] = ACTIONS(2561),
    [anon_sym_new] = ACTIONS(2561),
    [anon_sym_requires] = ACTIONS(2561),
    [sym_this] = ACTIONS(2561),
    [anon_sym___launch_bounds__] = ACTIONS(2561),
  },
  [STATE(496)] = {
    [sym_identifier] = ACTIONS(2517),
    [aux_sym_preproc_include_token1] = ACTIONS(2517),
    [aux_sym_preproc_def_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2517),
    [sym_preproc_directive] = ACTIONS(2517),
    [anon_sym_LPAREN2] = ACTIONS(2519),
    [anon_sym_BANG] = ACTIONS(2519),
    [anon_sym_TILDE] = ACTIONS(2519),
    [anon_sym_DASH] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2519),
    [anon_sym_AMP_AMP] = ACTIONS(2519),
    [anon_sym_AMP] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym___extension__] = ACTIONS(2517),
    [anon_sym_typedef] = ACTIONS(2517),
    [anon_sym___device__] = ACTIONS(2517),
    [anon_sym___host__] = ACTIONS(2517),
    [anon_sym___global__] = ACTIONS(2517),
    [anon_sym___forceinline__] = ACTIONS(2517),
    [anon_sym___noinline__] = ACTIONS(2517),
    [anon_sym_virtual] = ACTIONS(2517),
    [anon_sym_extern] = ACTIONS(2517),
    [anon_sym___attribute__] = ACTIONS(2517),
    [anon_sym___attribute] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2519),
    [anon_sym___declspec] = ACTIONS(2517),
    [anon_sym___based] = ACTIONS(2517),
    [anon_sym___cdecl] = ACTIONS(2517),
    [anon_sym___clrcall] = ACTIONS(2517),
    [anon_sym___stdcall] = ACTIONS(2517),
    [anon_sym___fastcall] = ACTIONS(2517),
    [anon_sym___thiscall] = ACTIONS(2517),
    [anon_sym___vectorcall] = ACTIONS(2517),
    [anon_sym_LBRACE] = ACTIONS(2519),
    [anon_sym_RBRACE] = ACTIONS(2519),
    [anon_sym_signed] = ACTIONS(2517),
    [anon_sym_unsigned] = ACTIONS(2517),
    [anon_sym_long] = ACTIONS(2517),
    [anon_sym_short] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2517),
    [anon_sym_static] = ACTIONS(2517),
    [anon_sym_register] = ACTIONS(2517),
    [anon_sym_inline] = ACTIONS(2517),
    [anon_sym___inline] = ACTIONS(2517),
    [anon_sym___inline__] = ACTIONS(2517),
    [anon_sym___forceinline] = ACTIONS(2517),
    [anon_sym_thread_local] = ACTIONS(2517),
    [anon_sym___thread] = ACTIONS(2517),
    [anon_sym_const] = ACTIONS(2517),
    [anon_sym_constexpr] = ACTIONS(2517),
    [anon_sym_volatile] = ACTIONS(2517),
    [anon_sym_restrict] = ACTIONS(2517),
    [anon_sym___restrict__] = ACTIONS(2517),
    [anon_sym__Atomic] = ACTIONS(2517),
    [anon_sym__Noreturn] = ACTIONS(2517),
    [anon_sym_noreturn] = ACTIONS(2517),
    [anon_sym__Nonnull] = ACTIONS(2517),
    [anon_sym_mutable] = ACTIONS(2517),
    [anon_sym_constinit] = ACTIONS(2517),
    [anon_sym_consteval] = ACTIONS(2517),
    [anon_sym___shared__] = ACTIONS(2517),
    [anon_sym___local__] = ACTIONS(2517),
    [anon_sym___constant__] = ACTIONS(2517),
    [anon_sym___managed__] = ACTIONS(2517),
    [anon_sym___grid_constant__] = ACTIONS(2517),
    [anon_sym_alignas] = ACTIONS(2517),
    [anon_sym__Alignas] = ACTIONS(2517),
    [sym_primitive_type] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_class] = ACTIONS(2517),
    [anon_sym_struct] = ACTIONS(2517),
    [anon_sym_union] = ACTIONS(2517),
    [anon_sym_if] = ACTIONS(2517),
    [anon_sym_switch] = ACTIONS(2517),
    [anon_sym_case] = ACTIONS(2517),
    [anon_sym_default] = ACTIONS(2517),
    [anon_sym_while] = ACTIONS(2517),
    [anon_sym_do] = ACTIONS(2517),
    [anon_sym_for] = ACTIONS(2517),
    [anon_sym_return] = ACTIONS(2517),
    [anon_sym_break] = ACTIONS(2517),
    [anon_sym_continue] = ACTIONS(2517),
    [anon_sym_goto] = ACTIONS(2517),
    [anon_sym___try] = ACTIONS(2517),
    [anon_sym___leave] = ACTIONS(2517),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_compl] = ACTIONS(2517),
    [anon_sym_DASH_DASH] = ACTIONS(2519),
    [anon_sym_PLUS_PLUS] = ACTIONS(2519),
    [anon_sym_sizeof] = ACTIONS(2517),
    [anon_sym___alignof__] = ACTIONS(2517),
    [anon_sym___alignof] = ACTIONS(2517),
    [anon_sym__alignof] = ACTIONS(2517),
    [anon_sym_alignof] = ACTIONS(2517),
    [anon_sym__Alignof] = ACTIONS(2517),
    [anon_sym_offsetof] = ACTIONS(2517),
    [anon_sym__Generic] = ACTIONS(2517),
    [anon_sym_asm] = ACTIONS(2517),
    [anon_sym___asm__] = ACTIONS(2517),
    [anon_sym___asm] = ACTIONS(2517),
    [sym_number_literal] = ACTIONS(2519),
    [anon_sym_L_SQUOTE] = ACTIONS(2519),
    [anon_sym_u_SQUOTE] = ACTIONS(2519),
    [anon_sym_U_SQUOTE] = ACTIONS(2519),
    [anon_sym_u8_SQUOTE] = ACTIONS(2519),
    [anon_sym_SQUOTE] = ACTIONS(2519),
    [anon_sym_L_DQUOTE] = ACTIONS(2519),
    [anon_sym_u_DQUOTE] = ACTIONS(2519),
    [anon_sym_U_DQUOTE] = ACTIONS(2519),
    [anon_sym_u8_DQUOTE] = ACTIONS(2519),
    [anon_sym_DQUOTE] = ACTIONS(2519),
    [sym_true] = ACTIONS(2517),
    [sym_false] = ACTIONS(2517),
    [anon_sym_NULL] = ACTIONS(2517),
    [anon_sym_nullptr] = ACTIONS(2517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2517),
    [anon_sym_decltype] = ACTIONS(2517),
    [anon_sym_explicit] = ACTIONS(2517),
    [anon_sym_typename] = ACTIONS(2517),
    [anon_sym_template] = ACTIONS(2517),
    [anon_sym_operator] = ACTIONS(2517),
    [anon_sym_try] = ACTIONS(2517),
    [anon_sym_delete] = ACTIONS(2517),
    [anon_sym_throw] = ACTIONS(2517),
    [anon_sym_namespace] = ACTIONS(2517),
    [anon_sym_using] = ACTIONS(2517),
    [anon_sym_static_assert] = ACTIONS(2517),
    [anon_sym_concept] = ACTIONS(2517),
    [anon_sym_co_return] = ACTIONS(2517),
    [anon_sym_co_yield] = ACTIONS(2517),
    [anon_sym_R_DQUOTE] = ACTIONS(2519),
    [anon_sym_LR_DQUOTE] = ACTIONS(2519),
    [anon_sym_uR_DQUOTE] = ACTIONS(2519),
    [anon_sym_UR_DQUOTE] = ACTIONS(2519),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2519),
    [anon_sym_co_await] = ACTIONS(2517),
    [anon_sym_new] = ACTIONS(2517),
    [anon_sym_requires] = ACTIONS(2517),
    [sym_this] = ACTIONS(2517),
    [anon_sym___launch_bounds__] = ACTIONS(2517),
  },
  [STATE(497)] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_include_token1] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token2] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_BANG] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_DASH] = ACTIONS(2328),
    [anon_sym_PLUS] = ACTIONS(2328),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym___device__] = ACTIONS(2328),
    [anon_sym___host__] = ACTIONS(2328),
    [anon_sym___global__] = ACTIONS(2328),
    [anon_sym___forceinline__] = ACTIONS(2328),
    [anon_sym___noinline__] = ACTIONS(2328),
    [anon_sym_virtual] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym___attribute] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym___cdecl] = ACTIONS(2328),
    [anon_sym___clrcall] = ACTIONS(2328),
    [anon_sym___stdcall] = ACTIONS(2328),
    [anon_sym___fastcall] = ACTIONS(2328),
    [anon_sym___thiscall] = ACTIONS(2328),
    [anon_sym___vectorcall] = ACTIONS(2328),
    [anon_sym_LBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym__Nonnull] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym___shared__] = ACTIONS(2328),
    [anon_sym___local__] = ACTIONS(2328),
    [anon_sym___constant__] = ACTIONS(2328),
    [anon_sym___managed__] = ACTIONS(2328),
    [anon_sym___grid_constant__] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2328),
    [anon_sym_switch] = ACTIONS(2328),
    [anon_sym_case] = ACTIONS(2328),
    [anon_sym_default] = ACTIONS(2328),
    [anon_sym_while] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2328),
    [anon_sym_for] = ACTIONS(2328),
    [anon_sym_return] = ACTIONS(2328),
    [anon_sym_break] = ACTIONS(2328),
    [anon_sym_continue] = ACTIONS(2328),
    [anon_sym_goto] = ACTIONS(2328),
    [anon_sym___try] = ACTIONS(2328),
    [anon_sym___leave] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2328),
    [anon_sym_compl] = ACTIONS(2328),
    [anon_sym_DASH_DASH] = ACTIONS(2330),
    [anon_sym_PLUS_PLUS] = ACTIONS(2330),
    [anon_sym_sizeof] = ACTIONS(2328),
    [anon_sym___alignof__] = ACTIONS(2328),
    [anon_sym___alignof] = ACTIONS(2328),
    [anon_sym__alignof] = ACTIONS(2328),
    [anon_sym_alignof] = ACTIONS(2328),
    [anon_sym__Alignof] = ACTIONS(2328),
    [anon_sym_offsetof] = ACTIONS(2328),
    [anon_sym__Generic] = ACTIONS(2328),
    [anon_sym_asm] = ACTIONS(2328),
    [anon_sym___asm__] = ACTIONS(2328),
    [anon_sym___asm] = ACTIONS(2328),
    [sym_number_literal] = ACTIONS(2330),
    [anon_sym_L_SQUOTE] = ACTIONS(2330),
    [anon_sym_u_SQUOTE] = ACTIONS(2330),
    [anon_sym_U_SQUOTE] = ACTIONS(2330),
    [anon_sym_u8_SQUOTE] = ACTIONS(2330),
    [anon_sym_SQUOTE] = ACTIONS(2330),
    [anon_sym_L_DQUOTE] = ACTIONS(2330),
    [anon_sym_u_DQUOTE] = ACTIONS(2330),
    [anon_sym_U_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8_DQUOTE] = ACTIONS(2330),
    [anon_sym_DQUOTE] = ACTIONS(2330),
    [sym_true] = ACTIONS(2328),
    [sym_false] = ACTIONS(2328),
    [anon_sym_NULL] = ACTIONS(2328),
    [anon_sym_nullptr] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_delete] = ACTIONS(2328),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_namespace] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_concept] = ACTIONS(2328),
    [anon_sym_co_return] = ACTIONS(2328),
    [anon_sym_co_yield] = ACTIONS(2328),
    [anon_sym_R_DQUOTE] = ACTIONS(2330),
    [anon_sym_LR_DQUOTE] = ACTIONS(2330),
    [anon_sym_uR_DQUOTE] = ACTIONS(2330),
    [anon_sym_UR_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2330),
    [anon_sym_co_await] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(2328),
    [anon_sym_requires] = ACTIONS(2328),
    [sym_this] = ACTIONS(2328),
    [anon_sym___launch_bounds__] = ACTIONS(2328),
  },
  [STATE(498)] = {
    [sym_identifier] = ACTIONS(2230),
    [aux_sym_preproc_include_token1] = ACTIONS(2230),
    [aux_sym_preproc_def_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token2] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2230),
    [sym_preproc_directive] = ACTIONS(2230),
    [anon_sym_LPAREN2] = ACTIONS(2232),
    [anon_sym_BANG] = ACTIONS(2232),
    [anon_sym_TILDE] = ACTIONS(2232),
    [anon_sym_DASH] = ACTIONS(2230),
    [anon_sym_PLUS] = ACTIONS(2230),
    [anon_sym_STAR] = ACTIONS(2232),
    [anon_sym_AMP_AMP] = ACTIONS(2232),
    [anon_sym_AMP] = ACTIONS(2230),
    [anon_sym_SEMI] = ACTIONS(2232),
    [anon_sym___extension__] = ACTIONS(2230),
    [anon_sym_typedef] = ACTIONS(2230),
    [anon_sym___device__] = ACTIONS(2230),
    [anon_sym___host__] = ACTIONS(2230),
    [anon_sym___global__] = ACTIONS(2230),
    [anon_sym___forceinline__] = ACTIONS(2230),
    [anon_sym___noinline__] = ACTIONS(2230),
    [anon_sym_virtual] = ACTIONS(2230),
    [anon_sym_extern] = ACTIONS(2230),
    [anon_sym___attribute__] = ACTIONS(2230),
    [anon_sym___attribute] = ACTIONS(2230),
    [anon_sym_COLON_COLON] = ACTIONS(2232),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2232),
    [anon_sym___declspec] = ACTIONS(2230),
    [anon_sym___based] = ACTIONS(2230),
    [anon_sym___cdecl] = ACTIONS(2230),
    [anon_sym___clrcall] = ACTIONS(2230),
    [anon_sym___stdcall] = ACTIONS(2230),
    [anon_sym___fastcall] = ACTIONS(2230),
    [anon_sym___thiscall] = ACTIONS(2230),
    [anon_sym___vectorcall] = ACTIONS(2230),
    [anon_sym_LBRACE] = ACTIONS(2232),
    [anon_sym_signed] = ACTIONS(2230),
    [anon_sym_unsigned] = ACTIONS(2230),
    [anon_sym_long] = ACTIONS(2230),
    [anon_sym_short] = ACTIONS(2230),
    [anon_sym_LBRACK] = ACTIONS(2230),
    [anon_sym_static] = ACTIONS(2230),
    [anon_sym_register] = ACTIONS(2230),
    [anon_sym_inline] = ACTIONS(2230),
    [anon_sym___inline] = ACTIONS(2230),
    [anon_sym___inline__] = ACTIONS(2230),
    [anon_sym___forceinline] = ACTIONS(2230),
    [anon_sym_thread_local] = ACTIONS(2230),
    [anon_sym___thread] = ACTIONS(2230),
    [anon_sym_const] = ACTIONS(2230),
    [anon_sym_constexpr] = ACTIONS(2230),
    [anon_sym_volatile] = ACTIONS(2230),
    [anon_sym_restrict] = ACTIONS(2230),
    [anon_sym___restrict__] = ACTIONS(2230),
    [anon_sym__Atomic] = ACTIONS(2230),
    [anon_sym__Noreturn] = ACTIONS(2230),
    [anon_sym_noreturn] = ACTIONS(2230),
    [anon_sym__Nonnull] = ACTIONS(2230),
    [anon_sym_mutable] = ACTIONS(2230),
    [anon_sym_constinit] = ACTIONS(2230),
    [anon_sym_consteval] = ACTIONS(2230),
    [anon_sym___shared__] = ACTIONS(2230),
    [anon_sym___local__] = ACTIONS(2230),
    [anon_sym___constant__] = ACTIONS(2230),
    [anon_sym___managed__] = ACTIONS(2230),
    [anon_sym___grid_constant__] = ACTIONS(2230),
    [anon_sym_alignas] = ACTIONS(2230),
    [anon_sym__Alignas] = ACTIONS(2230),
    [sym_primitive_type] = ACTIONS(2230),
    [anon_sym_enum] = ACTIONS(2230),
    [anon_sym_class] = ACTIONS(2230),
    [anon_sym_struct] = ACTIONS(2230),
    [anon_sym_union] = ACTIONS(2230),
    [anon_sym_if] = ACTIONS(2230),
    [anon_sym_switch] = ACTIONS(2230),
    [anon_sym_case] = ACTIONS(2230),
    [anon_sym_default] = ACTIONS(2230),
    [anon_sym_while] = ACTIONS(2230),
    [anon_sym_do] = ACTIONS(2230),
    [anon_sym_for] = ACTIONS(2230),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_break] = ACTIONS(2230),
    [anon_sym_continue] = ACTIONS(2230),
    [anon_sym_goto] = ACTIONS(2230),
    [anon_sym___try] = ACTIONS(2230),
    [anon_sym___leave] = ACTIONS(2230),
    [anon_sym_not] = ACTIONS(2230),
    [anon_sym_compl] = ACTIONS(2230),
    [anon_sym_DASH_DASH] = ACTIONS(2232),
    [anon_sym_PLUS_PLUS] = ACTIONS(2232),
    [anon_sym_sizeof] = ACTIONS(2230),
    [anon_sym___alignof__] = ACTIONS(2230),
    [anon_sym___alignof] = ACTIONS(2230),
    [anon_sym__alignof] = ACTIONS(2230),
    [anon_sym_alignof] = ACTIONS(2230),
    [anon_sym__Alignof] = ACTIONS(2230),
    [anon_sym_offsetof] = ACTIONS(2230),
    [anon_sym__Generic] = ACTIONS(2230),
    [anon_sym_asm] = ACTIONS(2230),
    [anon_sym___asm__] = ACTIONS(2230),
    [anon_sym___asm] = ACTIONS(2230),
    [sym_number_literal] = ACTIONS(2232),
    [anon_sym_L_SQUOTE] = ACTIONS(2232),
    [anon_sym_u_SQUOTE] = ACTIONS(2232),
    [anon_sym_U_SQUOTE] = ACTIONS(2232),
    [anon_sym_u8_SQUOTE] = ACTIONS(2232),
    [anon_sym_SQUOTE] = ACTIONS(2232),
    [anon_sym_L_DQUOTE] = ACTIONS(2232),
    [anon_sym_u_DQUOTE] = ACTIONS(2232),
    [anon_sym_U_DQUOTE] = ACTIONS(2232),
    [anon_sym_u8_DQUOTE] = ACTIONS(2232),
    [anon_sym_DQUOTE] = ACTIONS(2232),
    [sym_true] = ACTIONS(2230),
    [sym_false] = ACTIONS(2230),
    [anon_sym_NULL] = ACTIONS(2230),
    [anon_sym_nullptr] = ACTIONS(2230),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2230),
    [anon_sym_decltype] = ACTIONS(2230),
    [anon_sym_explicit] = ACTIONS(2230),
    [anon_sym_typename] = ACTIONS(2230),
    [anon_sym_template] = ACTIONS(2230),
    [anon_sym_operator] = ACTIONS(2230),
    [anon_sym_try] = ACTIONS(2230),
    [anon_sym_delete] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2230),
    [anon_sym_namespace] = ACTIONS(2230),
    [anon_sym_using] = ACTIONS(2230),
    [anon_sym_static_assert] = ACTIONS(2230),
    [anon_sym_concept] = ACTIONS(2230),
    [anon_sym_co_return] = ACTIONS(2230),
    [anon_sym_co_yield] = ACTIONS(2230),
    [anon_sym_R_DQUOTE] = ACTIONS(2232),
    [anon_sym_LR_DQUOTE] = ACTIONS(2232),
    [anon_sym_uR_DQUOTE] = ACTIONS(2232),
    [anon_sym_UR_DQUOTE] = ACTIONS(2232),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2232),
    [anon_sym_co_await] = ACTIONS(2230),
    [anon_sym_new] = ACTIONS(2230),
    [anon_sym_requires] = ACTIONS(2230),
    [sym_this] = ACTIONS(2230),
    [anon_sym___launch_bounds__] = ACTIONS(2230),
  },
  [STATE(499)] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_include_token1] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token2] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_BANG] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym___device__] = ACTIONS(2316),
    [anon_sym___host__] = ACTIONS(2316),
    [anon_sym___global__] = ACTIONS(2316),
    [anon_sym___forceinline__] = ACTIONS(2316),
    [anon_sym___noinline__] = ACTIONS(2316),
    [anon_sym_virtual] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym___attribute] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym___cdecl] = ACTIONS(2316),
    [anon_sym___clrcall] = ACTIONS(2316),
    [anon_sym___stdcall] = ACTIONS(2316),
    [anon_sym___fastcall] = ACTIONS(2316),
    [anon_sym___thiscall] = ACTIONS(2316),
    [anon_sym___vectorcall] = ACTIONS(2316),
    [anon_sym_LBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym__Nonnull] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym___shared__] = ACTIONS(2316),
    [anon_sym___local__] = ACTIONS(2316),
    [anon_sym___constant__] = ACTIONS(2316),
    [anon_sym___managed__] = ACTIONS(2316),
    [anon_sym___grid_constant__] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_switch] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_default] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_return] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_goto] = ACTIONS(2316),
    [anon_sym___try] = ACTIONS(2316),
    [anon_sym___leave] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_compl] = ACTIONS(2316),
    [anon_sym_DASH_DASH] = ACTIONS(2318),
    [anon_sym_PLUS_PLUS] = ACTIONS(2318),
    [anon_sym_sizeof] = ACTIONS(2316),
    [anon_sym___alignof__] = ACTIONS(2316),
    [anon_sym___alignof] = ACTIONS(2316),
    [anon_sym__alignof] = ACTIONS(2316),
    [anon_sym_alignof] = ACTIONS(2316),
    [anon_sym__Alignof] = ACTIONS(2316),
    [anon_sym_offsetof] = ACTIONS(2316),
    [anon_sym__Generic] = ACTIONS(2316),
    [anon_sym_asm] = ACTIONS(2316),
    [anon_sym___asm__] = ACTIONS(2316),
    [anon_sym___asm] = ACTIONS(2316),
    [sym_number_literal] = ACTIONS(2318),
    [anon_sym_L_SQUOTE] = ACTIONS(2318),
    [anon_sym_u_SQUOTE] = ACTIONS(2318),
    [anon_sym_U_SQUOTE] = ACTIONS(2318),
    [anon_sym_u8_SQUOTE] = ACTIONS(2318),
    [anon_sym_SQUOTE] = ACTIONS(2318),
    [anon_sym_L_DQUOTE] = ACTIONS(2318),
    [anon_sym_u_DQUOTE] = ACTIONS(2318),
    [anon_sym_U_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8_DQUOTE] = ACTIONS(2318),
    [anon_sym_DQUOTE] = ACTIONS(2318),
    [sym_true] = ACTIONS(2316),
    [sym_false] = ACTIONS(2316),
    [anon_sym_NULL] = ACTIONS(2316),
    [anon_sym_nullptr] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_try] = ACTIONS(2316),
    [anon_sym_delete] = ACTIONS(2316),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_namespace] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_concept] = ACTIONS(2316),
    [anon_sym_co_return] = ACTIONS(2316),
    [anon_sym_co_yield] = ACTIONS(2316),
    [anon_sym_R_DQUOTE] = ACTIONS(2318),
    [anon_sym_LR_DQUOTE] = ACTIONS(2318),
    [anon_sym_uR_DQUOTE] = ACTIONS(2318),
    [anon_sym_UR_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2318),
    [anon_sym_co_await] = ACTIONS(2316),
    [anon_sym_new] = ACTIONS(2316),
    [anon_sym_requires] = ACTIONS(2316),
    [sym_this] = ACTIONS(2316),
    [anon_sym___launch_bounds__] = ACTIONS(2316),
  },
  [STATE(500)] = {
    [sym_identifier] = ACTIONS(2431),
    [aux_sym_preproc_include_token1] = ACTIONS(2431),
    [aux_sym_preproc_def_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token2] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2431),
    [sym_preproc_directive] = ACTIONS(2431),
    [anon_sym_LPAREN2] = ACTIONS(2433),
    [anon_sym_BANG] = ACTIONS(2433),
    [anon_sym_TILDE] = ACTIONS(2433),
    [anon_sym_DASH] = ACTIONS(2431),
    [anon_sym_PLUS] = ACTIONS(2431),
    [anon_sym_STAR] = ACTIONS(2433),
    [anon_sym_AMP_AMP] = ACTIONS(2433),
    [anon_sym_AMP] = ACTIONS(2431),
    [anon_sym_SEMI] = ACTIONS(2433),
    [anon_sym___extension__] = ACTIONS(2431),
    [anon_sym_typedef] = ACTIONS(2431),
    [anon_sym___device__] = ACTIONS(2431),
    [anon_sym___host__] = ACTIONS(2431),
    [anon_sym___global__] = ACTIONS(2431),
    [anon_sym___forceinline__] = ACTIONS(2431),
    [anon_sym___noinline__] = ACTIONS(2431),
    [anon_sym_virtual] = ACTIONS(2431),
    [anon_sym_extern] = ACTIONS(2431),
    [anon_sym___attribute__] = ACTIONS(2431),
    [anon_sym___attribute] = ACTIONS(2431),
    [anon_sym_COLON_COLON] = ACTIONS(2433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2433),
    [anon_sym___declspec] = ACTIONS(2431),
    [anon_sym___based] = ACTIONS(2431),
    [anon_sym___cdecl] = ACTIONS(2431),
    [anon_sym___clrcall] = ACTIONS(2431),
    [anon_sym___stdcall] = ACTIONS(2431),
    [anon_sym___fastcall] = ACTIONS(2431),
    [anon_sym___thiscall] = ACTIONS(2431),
    [anon_sym___vectorcall] = ACTIONS(2431),
    [anon_sym_LBRACE] = ACTIONS(2433),
    [anon_sym_signed] = ACTIONS(2431),
    [anon_sym_unsigned] = ACTIONS(2431),
    [anon_sym_long] = ACTIONS(2431),
    [anon_sym_short] = ACTIONS(2431),
    [anon_sym_LBRACK] = ACTIONS(2431),
    [anon_sym_static] = ACTIONS(2431),
    [anon_sym_register] = ACTIONS(2431),
    [anon_sym_inline] = ACTIONS(2431),
    [anon_sym___inline] = ACTIONS(2431),
    [anon_sym___inline__] = ACTIONS(2431),
    [anon_sym___forceinline] = ACTIONS(2431),
    [anon_sym_thread_local] = ACTIONS(2431),
    [anon_sym___thread] = ACTIONS(2431),
    [anon_sym_const] = ACTIONS(2431),
    [anon_sym_constexpr] = ACTIONS(2431),
    [anon_sym_volatile] = ACTIONS(2431),
    [anon_sym_restrict] = ACTIONS(2431),
    [anon_sym___restrict__] = ACTIONS(2431),
    [anon_sym__Atomic] = ACTIONS(2431),
    [anon_sym__Noreturn] = ACTIONS(2431),
    [anon_sym_noreturn] = ACTIONS(2431),
    [anon_sym__Nonnull] = ACTIONS(2431),
    [anon_sym_mutable] = ACTIONS(2431),
    [anon_sym_constinit] = ACTIONS(2431),
    [anon_sym_consteval] = ACTIONS(2431),
    [anon_sym___shared__] = ACTIONS(2431),
    [anon_sym___local__] = ACTIONS(2431),
    [anon_sym___constant__] = ACTIONS(2431),
    [anon_sym___managed__] = ACTIONS(2431),
    [anon_sym___grid_constant__] = ACTIONS(2431),
    [anon_sym_alignas] = ACTIONS(2431),
    [anon_sym__Alignas] = ACTIONS(2431),
    [sym_primitive_type] = ACTIONS(2431),
    [anon_sym_enum] = ACTIONS(2431),
    [anon_sym_class] = ACTIONS(2431),
    [anon_sym_struct] = ACTIONS(2431),
    [anon_sym_union] = ACTIONS(2431),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_switch] = ACTIONS(2431),
    [anon_sym_case] = ACTIONS(2431),
    [anon_sym_default] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(2431),
    [anon_sym_do] = ACTIONS(2431),
    [anon_sym_for] = ACTIONS(2431),
    [anon_sym_return] = ACTIONS(2431),
    [anon_sym_break] = ACTIONS(2431),
    [anon_sym_continue] = ACTIONS(2431),
    [anon_sym_goto] = ACTIONS(2431),
    [anon_sym___try] = ACTIONS(2431),
    [anon_sym___leave] = ACTIONS(2431),
    [anon_sym_not] = ACTIONS(2431),
    [anon_sym_compl] = ACTIONS(2431),
    [anon_sym_DASH_DASH] = ACTIONS(2433),
    [anon_sym_PLUS_PLUS] = ACTIONS(2433),
    [anon_sym_sizeof] = ACTIONS(2431),
    [anon_sym___alignof__] = ACTIONS(2431),
    [anon_sym___alignof] = ACTIONS(2431),
    [anon_sym__alignof] = ACTIONS(2431),
    [anon_sym_alignof] = ACTIONS(2431),
    [anon_sym__Alignof] = ACTIONS(2431),
    [anon_sym_offsetof] = ACTIONS(2431),
    [anon_sym__Generic] = ACTIONS(2431),
    [anon_sym_asm] = ACTIONS(2431),
    [anon_sym___asm__] = ACTIONS(2431),
    [anon_sym___asm] = ACTIONS(2431),
    [sym_number_literal] = ACTIONS(2433),
    [anon_sym_L_SQUOTE] = ACTIONS(2433),
    [anon_sym_u_SQUOTE] = ACTIONS(2433),
    [anon_sym_U_SQUOTE] = ACTIONS(2433),
    [anon_sym_u8_SQUOTE] = ACTIONS(2433),
    [anon_sym_SQUOTE] = ACTIONS(2433),
    [anon_sym_L_DQUOTE] = ACTIONS(2433),
    [anon_sym_u_DQUOTE] = ACTIONS(2433),
    [anon_sym_U_DQUOTE] = ACTIONS(2433),
    [anon_sym_u8_DQUOTE] = ACTIONS(2433),
    [anon_sym_DQUOTE] = ACTIONS(2433),
    [sym_true] = ACTIONS(2431),
    [sym_false] = ACTIONS(2431),
    [anon_sym_NULL] = ACTIONS(2431),
    [anon_sym_nullptr] = ACTIONS(2431),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2431),
    [anon_sym_decltype] = ACTIONS(2431),
    [anon_sym_explicit] = ACTIONS(2431),
    [anon_sym_typename] = ACTIONS(2431),
    [anon_sym_template] = ACTIONS(2431),
    [anon_sym_operator] = ACTIONS(2431),
    [anon_sym_try] = ACTIONS(2431),
    [anon_sym_delete] = ACTIONS(2431),
    [anon_sym_throw] = ACTIONS(2431),
    [anon_sym_namespace] = ACTIONS(2431),
    [anon_sym_using] = ACTIONS(2431),
    [anon_sym_static_assert] = ACTIONS(2431),
    [anon_sym_concept] = ACTIONS(2431),
    [anon_sym_co_return] = ACTIONS(2431),
    [anon_sym_co_yield] = ACTIONS(2431),
    [anon_sym_R_DQUOTE] = ACTIONS(2433),
    [anon_sym_LR_DQUOTE] = ACTIONS(2433),
    [anon_sym_uR_DQUOTE] = ACTIONS(2433),
    [anon_sym_UR_DQUOTE] = ACTIONS(2433),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2433),
    [anon_sym_co_await] = ACTIONS(2431),
    [anon_sym_new] = ACTIONS(2431),
    [anon_sym_requires] = ACTIONS(2431),
    [sym_this] = ACTIONS(2431),
    [anon_sym___launch_bounds__] = ACTIONS(2431),
  },
  [STATE(501)] = {
    [sym_identifier] = ACTIONS(2435),
    [aux_sym_preproc_include_token1] = ACTIONS(2435),
    [aux_sym_preproc_def_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token2] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2435),
    [sym_preproc_directive] = ACTIONS(2435),
    [anon_sym_LPAREN2] = ACTIONS(2437),
    [anon_sym_BANG] = ACTIONS(2437),
    [anon_sym_TILDE] = ACTIONS(2437),
    [anon_sym_DASH] = ACTIONS(2435),
    [anon_sym_PLUS] = ACTIONS(2435),
    [anon_sym_STAR] = ACTIONS(2437),
    [anon_sym_AMP_AMP] = ACTIONS(2437),
    [anon_sym_AMP] = ACTIONS(2435),
    [anon_sym_SEMI] = ACTIONS(2437),
    [anon_sym___extension__] = ACTIONS(2435),
    [anon_sym_typedef] = ACTIONS(2435),
    [anon_sym___device__] = ACTIONS(2435),
    [anon_sym___host__] = ACTIONS(2435),
    [anon_sym___global__] = ACTIONS(2435),
    [anon_sym___forceinline__] = ACTIONS(2435),
    [anon_sym___noinline__] = ACTIONS(2435),
    [anon_sym_virtual] = ACTIONS(2435),
    [anon_sym_extern] = ACTIONS(2435),
    [anon_sym___attribute__] = ACTIONS(2435),
    [anon_sym___attribute] = ACTIONS(2435),
    [anon_sym_COLON_COLON] = ACTIONS(2437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2437),
    [anon_sym___declspec] = ACTIONS(2435),
    [anon_sym___based] = ACTIONS(2435),
    [anon_sym___cdecl] = ACTIONS(2435),
    [anon_sym___clrcall] = ACTIONS(2435),
    [anon_sym___stdcall] = ACTIONS(2435),
    [anon_sym___fastcall] = ACTIONS(2435),
    [anon_sym___thiscall] = ACTIONS(2435),
    [anon_sym___vectorcall] = ACTIONS(2435),
    [anon_sym_LBRACE] = ACTIONS(2437),
    [anon_sym_signed] = ACTIONS(2435),
    [anon_sym_unsigned] = ACTIONS(2435),
    [anon_sym_long] = ACTIONS(2435),
    [anon_sym_short] = ACTIONS(2435),
    [anon_sym_LBRACK] = ACTIONS(2435),
    [anon_sym_static] = ACTIONS(2435),
    [anon_sym_register] = ACTIONS(2435),
    [anon_sym_inline] = ACTIONS(2435),
    [anon_sym___inline] = ACTIONS(2435),
    [anon_sym___inline__] = ACTIONS(2435),
    [anon_sym___forceinline] = ACTIONS(2435),
    [anon_sym_thread_local] = ACTIONS(2435),
    [anon_sym___thread] = ACTIONS(2435),
    [anon_sym_const] = ACTIONS(2435),
    [anon_sym_constexpr] = ACTIONS(2435),
    [anon_sym_volatile] = ACTIONS(2435),
    [anon_sym_restrict] = ACTIONS(2435),
    [anon_sym___restrict__] = ACTIONS(2435),
    [anon_sym__Atomic] = ACTIONS(2435),
    [anon_sym__Noreturn] = ACTIONS(2435),
    [anon_sym_noreturn] = ACTIONS(2435),
    [anon_sym__Nonnull] = ACTIONS(2435),
    [anon_sym_mutable] = ACTIONS(2435),
    [anon_sym_constinit] = ACTIONS(2435),
    [anon_sym_consteval] = ACTIONS(2435),
    [anon_sym___shared__] = ACTIONS(2435),
    [anon_sym___local__] = ACTIONS(2435),
    [anon_sym___constant__] = ACTIONS(2435),
    [anon_sym___managed__] = ACTIONS(2435),
    [anon_sym___grid_constant__] = ACTIONS(2435),
    [anon_sym_alignas] = ACTIONS(2435),
    [anon_sym__Alignas] = ACTIONS(2435),
    [sym_primitive_type] = ACTIONS(2435),
    [anon_sym_enum] = ACTIONS(2435),
    [anon_sym_class] = ACTIONS(2435),
    [anon_sym_struct] = ACTIONS(2435),
    [anon_sym_union] = ACTIONS(2435),
    [anon_sym_if] = ACTIONS(2435),
    [anon_sym_switch] = ACTIONS(2435),
    [anon_sym_case] = ACTIONS(2435),
    [anon_sym_default] = ACTIONS(2435),
    [anon_sym_while] = ACTIONS(2435),
    [anon_sym_do] = ACTIONS(2435),
    [anon_sym_for] = ACTIONS(2435),
    [anon_sym_return] = ACTIONS(2435),
    [anon_sym_break] = ACTIONS(2435),
    [anon_sym_continue] = ACTIONS(2435),
    [anon_sym_goto] = ACTIONS(2435),
    [anon_sym___try] = ACTIONS(2435),
    [anon_sym___leave] = ACTIONS(2435),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_compl] = ACTIONS(2435),
    [anon_sym_DASH_DASH] = ACTIONS(2437),
    [anon_sym_PLUS_PLUS] = ACTIONS(2437),
    [anon_sym_sizeof] = ACTIONS(2435),
    [anon_sym___alignof__] = ACTIONS(2435),
    [anon_sym___alignof] = ACTIONS(2435),
    [anon_sym__alignof] = ACTIONS(2435),
    [anon_sym_alignof] = ACTIONS(2435),
    [anon_sym__Alignof] = ACTIONS(2435),
    [anon_sym_offsetof] = ACTIONS(2435),
    [anon_sym__Generic] = ACTIONS(2435),
    [anon_sym_asm] = ACTIONS(2435),
    [anon_sym___asm__] = ACTIONS(2435),
    [anon_sym___asm] = ACTIONS(2435),
    [sym_number_literal] = ACTIONS(2437),
    [anon_sym_L_SQUOTE] = ACTIONS(2437),
    [anon_sym_u_SQUOTE] = ACTIONS(2437),
    [anon_sym_U_SQUOTE] = ACTIONS(2437),
    [anon_sym_u8_SQUOTE] = ACTIONS(2437),
    [anon_sym_SQUOTE] = ACTIONS(2437),
    [anon_sym_L_DQUOTE] = ACTIONS(2437),
    [anon_sym_u_DQUOTE] = ACTIONS(2437),
    [anon_sym_U_DQUOTE] = ACTIONS(2437),
    [anon_sym_u8_DQUOTE] = ACTIONS(2437),
    [anon_sym_DQUOTE] = ACTIONS(2437),
    [sym_true] = ACTIONS(2435),
    [sym_false] = ACTIONS(2435),
    [anon_sym_NULL] = ACTIONS(2435),
    [anon_sym_nullptr] = ACTIONS(2435),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2435),
    [anon_sym_decltype] = ACTIONS(2435),
    [anon_sym_explicit] = ACTIONS(2435),
    [anon_sym_typename] = ACTIONS(2435),
    [anon_sym_template] = ACTIONS(2435),
    [anon_sym_operator] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2435),
    [anon_sym_delete] = ACTIONS(2435),
    [anon_sym_throw] = ACTIONS(2435),
    [anon_sym_namespace] = ACTIONS(2435),
    [anon_sym_using] = ACTIONS(2435),
    [anon_sym_static_assert] = ACTIONS(2435),
    [anon_sym_concept] = ACTIONS(2435),
    [anon_sym_co_return] = ACTIONS(2435),
    [anon_sym_co_yield] = ACTIONS(2435),
    [anon_sym_R_DQUOTE] = ACTIONS(2437),
    [anon_sym_LR_DQUOTE] = ACTIONS(2437),
    [anon_sym_uR_DQUOTE] = ACTIONS(2437),
    [anon_sym_UR_DQUOTE] = ACTIONS(2437),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2437),
    [anon_sym_co_await] = ACTIONS(2435),
    [anon_sym_new] = ACTIONS(2435),
    [anon_sym_requires] = ACTIONS(2435),
    [sym_this] = ACTIONS(2435),
    [anon_sym___launch_bounds__] = ACTIONS(2435),
  },
  [STATE(502)] = {
    [sym_identifier] = ACTIONS(2447),
    [aux_sym_preproc_include_token1] = ACTIONS(2447),
    [aux_sym_preproc_def_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token2] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2447),
    [sym_preproc_directive] = ACTIONS(2447),
    [anon_sym_LPAREN2] = ACTIONS(2449),
    [anon_sym_BANG] = ACTIONS(2449),
    [anon_sym_TILDE] = ACTIONS(2449),
    [anon_sym_DASH] = ACTIONS(2447),
    [anon_sym_PLUS] = ACTIONS(2447),
    [anon_sym_STAR] = ACTIONS(2449),
    [anon_sym_AMP_AMP] = ACTIONS(2449),
    [anon_sym_AMP] = ACTIONS(2447),
    [anon_sym_SEMI] = ACTIONS(2449),
    [anon_sym___extension__] = ACTIONS(2447),
    [anon_sym_typedef] = ACTIONS(2447),
    [anon_sym___device__] = ACTIONS(2447),
    [anon_sym___host__] = ACTIONS(2447),
    [anon_sym___global__] = ACTIONS(2447),
    [anon_sym___forceinline__] = ACTIONS(2447),
    [anon_sym___noinline__] = ACTIONS(2447),
    [anon_sym_virtual] = ACTIONS(2447),
    [anon_sym_extern] = ACTIONS(2447),
    [anon_sym___attribute__] = ACTIONS(2447),
    [anon_sym___attribute] = ACTIONS(2447),
    [anon_sym_COLON_COLON] = ACTIONS(2449),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2449),
    [anon_sym___declspec] = ACTIONS(2447),
    [anon_sym___based] = ACTIONS(2447),
    [anon_sym___cdecl] = ACTIONS(2447),
    [anon_sym___clrcall] = ACTIONS(2447),
    [anon_sym___stdcall] = ACTIONS(2447),
    [anon_sym___fastcall] = ACTIONS(2447),
    [anon_sym___thiscall] = ACTIONS(2447),
    [anon_sym___vectorcall] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2449),
    [anon_sym_signed] = ACTIONS(2447),
    [anon_sym_unsigned] = ACTIONS(2447),
    [anon_sym_long] = ACTIONS(2447),
    [anon_sym_short] = ACTIONS(2447),
    [anon_sym_LBRACK] = ACTIONS(2447),
    [anon_sym_static] = ACTIONS(2447),
    [anon_sym_register] = ACTIONS(2447),
    [anon_sym_inline] = ACTIONS(2447),
    [anon_sym___inline] = ACTIONS(2447),
    [anon_sym___inline__] = ACTIONS(2447),
    [anon_sym___forceinline] = ACTIONS(2447),
    [anon_sym_thread_local] = ACTIONS(2447),
    [anon_sym___thread] = ACTIONS(2447),
    [anon_sym_const] = ACTIONS(2447),
    [anon_sym_constexpr] = ACTIONS(2447),
    [anon_sym_volatile] = ACTIONS(2447),
    [anon_sym_restrict] = ACTIONS(2447),
    [anon_sym___restrict__] = ACTIONS(2447),
    [anon_sym__Atomic] = ACTIONS(2447),
    [anon_sym__Noreturn] = ACTIONS(2447),
    [anon_sym_noreturn] = ACTIONS(2447),
    [anon_sym__Nonnull] = ACTIONS(2447),
    [anon_sym_mutable] = ACTIONS(2447),
    [anon_sym_constinit] = ACTIONS(2447),
    [anon_sym_consteval] = ACTIONS(2447),
    [anon_sym___shared__] = ACTIONS(2447),
    [anon_sym___local__] = ACTIONS(2447),
    [anon_sym___constant__] = ACTIONS(2447),
    [anon_sym___managed__] = ACTIONS(2447),
    [anon_sym___grid_constant__] = ACTIONS(2447),
    [anon_sym_alignas] = ACTIONS(2447),
    [anon_sym__Alignas] = ACTIONS(2447),
    [sym_primitive_type] = ACTIONS(2447),
    [anon_sym_enum] = ACTIONS(2447),
    [anon_sym_class] = ACTIONS(2447),
    [anon_sym_struct] = ACTIONS(2447),
    [anon_sym_union] = ACTIONS(2447),
    [anon_sym_if] = ACTIONS(2447),
    [anon_sym_switch] = ACTIONS(2447),
    [anon_sym_case] = ACTIONS(2447),
    [anon_sym_default] = ACTIONS(2447),
    [anon_sym_while] = ACTIONS(2447),
    [anon_sym_do] = ACTIONS(2447),
    [anon_sym_for] = ACTIONS(2447),
    [anon_sym_return] = ACTIONS(2447),
    [anon_sym_break] = ACTIONS(2447),
    [anon_sym_continue] = ACTIONS(2447),
    [anon_sym_goto] = ACTIONS(2447),
    [anon_sym___try] = ACTIONS(2447),
    [anon_sym___leave] = ACTIONS(2447),
    [anon_sym_not] = ACTIONS(2447),
    [anon_sym_compl] = ACTIONS(2447),
    [anon_sym_DASH_DASH] = ACTIONS(2449),
    [anon_sym_PLUS_PLUS] = ACTIONS(2449),
    [anon_sym_sizeof] = ACTIONS(2447),
    [anon_sym___alignof__] = ACTIONS(2447),
    [anon_sym___alignof] = ACTIONS(2447),
    [anon_sym__alignof] = ACTIONS(2447),
    [anon_sym_alignof] = ACTIONS(2447),
    [anon_sym__Alignof] = ACTIONS(2447),
    [anon_sym_offsetof] = ACTIONS(2447),
    [anon_sym__Generic] = ACTIONS(2447),
    [anon_sym_asm] = ACTIONS(2447),
    [anon_sym___asm__] = ACTIONS(2447),
    [anon_sym___asm] = ACTIONS(2447),
    [sym_number_literal] = ACTIONS(2449),
    [anon_sym_L_SQUOTE] = ACTIONS(2449),
    [anon_sym_u_SQUOTE] = ACTIONS(2449),
    [anon_sym_U_SQUOTE] = ACTIONS(2449),
    [anon_sym_u8_SQUOTE] = ACTIONS(2449),
    [anon_sym_SQUOTE] = ACTIONS(2449),
    [anon_sym_L_DQUOTE] = ACTIONS(2449),
    [anon_sym_u_DQUOTE] = ACTIONS(2449),
    [anon_sym_U_DQUOTE] = ACTIONS(2449),
    [anon_sym_u8_DQUOTE] = ACTIONS(2449),
    [anon_sym_DQUOTE] = ACTIONS(2449),
    [sym_true] = ACTIONS(2447),
    [sym_false] = ACTIONS(2447),
    [anon_sym_NULL] = ACTIONS(2447),
    [anon_sym_nullptr] = ACTIONS(2447),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2447),
    [anon_sym_decltype] = ACTIONS(2447),
    [anon_sym_explicit] = ACTIONS(2447),
    [anon_sym_typename] = ACTIONS(2447),
    [anon_sym_template] = ACTIONS(2447),
    [anon_sym_operator] = ACTIONS(2447),
    [anon_sym_try] = ACTIONS(2447),
    [anon_sym_delete] = ACTIONS(2447),
    [anon_sym_throw] = ACTIONS(2447),
    [anon_sym_namespace] = ACTIONS(2447),
    [anon_sym_using] = ACTIONS(2447),
    [anon_sym_static_assert] = ACTIONS(2447),
    [anon_sym_concept] = ACTIONS(2447),
    [anon_sym_co_return] = ACTIONS(2447),
    [anon_sym_co_yield] = ACTIONS(2447),
    [anon_sym_R_DQUOTE] = ACTIONS(2449),
    [anon_sym_LR_DQUOTE] = ACTIONS(2449),
    [anon_sym_uR_DQUOTE] = ACTIONS(2449),
    [anon_sym_UR_DQUOTE] = ACTIONS(2449),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2449),
    [anon_sym_co_await] = ACTIONS(2447),
    [anon_sym_new] = ACTIONS(2447),
    [anon_sym_requires] = ACTIONS(2447),
    [sym_this] = ACTIONS(2447),
    [anon_sym___launch_bounds__] = ACTIONS(2447),
  },
  [STATE(503)] = {
    [sym_identifier] = ACTIONS(2605),
    [aux_sym_preproc_include_token1] = ACTIONS(2605),
    [aux_sym_preproc_def_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token2] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2605),
    [sym_preproc_directive] = ACTIONS(2605),
    [anon_sym_LPAREN2] = ACTIONS(2607),
    [anon_sym_BANG] = ACTIONS(2607),
    [anon_sym_TILDE] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2607),
    [anon_sym_AMP_AMP] = ACTIONS(2607),
    [anon_sym_AMP] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2605),
    [anon_sym_typedef] = ACTIONS(2605),
    [anon_sym___device__] = ACTIONS(2605),
    [anon_sym___host__] = ACTIONS(2605),
    [anon_sym___global__] = ACTIONS(2605),
    [anon_sym___forceinline__] = ACTIONS(2605),
    [anon_sym___noinline__] = ACTIONS(2605),
    [anon_sym_virtual] = ACTIONS(2605),
    [anon_sym_extern] = ACTIONS(2605),
    [anon_sym___attribute__] = ACTIONS(2605),
    [anon_sym___attribute] = ACTIONS(2605),
    [anon_sym_COLON_COLON] = ACTIONS(2607),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2607),
    [anon_sym___declspec] = ACTIONS(2605),
    [anon_sym___based] = ACTIONS(2605),
    [anon_sym___cdecl] = ACTIONS(2605),
    [anon_sym___clrcall] = ACTIONS(2605),
    [anon_sym___stdcall] = ACTIONS(2605),
    [anon_sym___fastcall] = ACTIONS(2605),
    [anon_sym___thiscall] = ACTIONS(2605),
    [anon_sym___vectorcall] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(2607),
    [anon_sym_signed] = ACTIONS(2605),
    [anon_sym_unsigned] = ACTIONS(2605),
    [anon_sym_long] = ACTIONS(2605),
    [anon_sym_short] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2605),
    [anon_sym_static] = ACTIONS(2605),
    [anon_sym_register] = ACTIONS(2605),
    [anon_sym_inline] = ACTIONS(2605),
    [anon_sym___inline] = ACTIONS(2605),
    [anon_sym___inline__] = ACTIONS(2605),
    [anon_sym___forceinline] = ACTIONS(2605),
    [anon_sym_thread_local] = ACTIONS(2605),
    [anon_sym___thread] = ACTIONS(2605),
    [anon_sym_const] = ACTIONS(2605),
    [anon_sym_constexpr] = ACTIONS(2605),
    [anon_sym_volatile] = ACTIONS(2605),
    [anon_sym_restrict] = ACTIONS(2605),
    [anon_sym___restrict__] = ACTIONS(2605),
    [anon_sym__Atomic] = ACTIONS(2605),
    [anon_sym__Noreturn] = ACTIONS(2605),
    [anon_sym_noreturn] = ACTIONS(2605),
    [anon_sym__Nonnull] = ACTIONS(2605),
    [anon_sym_mutable] = ACTIONS(2605),
    [anon_sym_constinit] = ACTIONS(2605),
    [anon_sym_consteval] = ACTIONS(2605),
    [anon_sym___shared__] = ACTIONS(2605),
    [anon_sym___local__] = ACTIONS(2605),
    [anon_sym___constant__] = ACTIONS(2605),
    [anon_sym___managed__] = ACTIONS(2605),
    [anon_sym___grid_constant__] = ACTIONS(2605),
    [anon_sym_alignas] = ACTIONS(2605),
    [anon_sym__Alignas] = ACTIONS(2605),
    [sym_primitive_type] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_class] = ACTIONS(2605),
    [anon_sym_struct] = ACTIONS(2605),
    [anon_sym_union] = ACTIONS(2605),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_switch] = ACTIONS(2605),
    [anon_sym_case] = ACTIONS(2605),
    [anon_sym_default] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(2605),
    [anon_sym_do] = ACTIONS(2605),
    [anon_sym_for] = ACTIONS(2605),
    [anon_sym_return] = ACTIONS(2605),
    [anon_sym_break] = ACTIONS(2605),
    [anon_sym_continue] = ACTIONS(2605),
    [anon_sym_goto] = ACTIONS(2605),
    [anon_sym___try] = ACTIONS(2605),
    [anon_sym___leave] = ACTIONS(2605),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_compl] = ACTIONS(2605),
    [anon_sym_DASH_DASH] = ACTIONS(2607),
    [anon_sym_PLUS_PLUS] = ACTIONS(2607),
    [anon_sym_sizeof] = ACTIONS(2605),
    [anon_sym___alignof__] = ACTIONS(2605),
    [anon_sym___alignof] = ACTIONS(2605),
    [anon_sym__alignof] = ACTIONS(2605),
    [anon_sym_alignof] = ACTIONS(2605),
    [anon_sym__Alignof] = ACTIONS(2605),
    [anon_sym_offsetof] = ACTIONS(2605),
    [anon_sym__Generic] = ACTIONS(2605),
    [anon_sym_asm] = ACTIONS(2605),
    [anon_sym___asm__] = ACTIONS(2605),
    [anon_sym___asm] = ACTIONS(2605),
    [sym_number_literal] = ACTIONS(2607),
    [anon_sym_L_SQUOTE] = ACTIONS(2607),
    [anon_sym_u_SQUOTE] = ACTIONS(2607),
    [anon_sym_U_SQUOTE] = ACTIONS(2607),
    [anon_sym_u8_SQUOTE] = ACTIONS(2607),
    [anon_sym_SQUOTE] = ACTIONS(2607),
    [anon_sym_L_DQUOTE] = ACTIONS(2607),
    [anon_sym_u_DQUOTE] = ACTIONS(2607),
    [anon_sym_U_DQUOTE] = ACTIONS(2607),
    [anon_sym_u8_DQUOTE] = ACTIONS(2607),
    [anon_sym_DQUOTE] = ACTIONS(2607),
    [sym_true] = ACTIONS(2605),
    [sym_false] = ACTIONS(2605),
    [anon_sym_NULL] = ACTIONS(2605),
    [anon_sym_nullptr] = ACTIONS(2605),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2605),
    [anon_sym_decltype] = ACTIONS(2605),
    [anon_sym_explicit] = ACTIONS(2605),
    [anon_sym_typename] = ACTIONS(2605),
    [anon_sym_template] = ACTIONS(2605),
    [anon_sym_operator] = ACTIONS(2605),
    [anon_sym_try] = ACTIONS(2605),
    [anon_sym_delete] = ACTIONS(2605),
    [anon_sym_throw] = ACTIONS(2605),
    [anon_sym_namespace] = ACTIONS(2605),
    [anon_sym_using] = ACTIONS(2605),
    [anon_sym_static_assert] = ACTIONS(2605),
    [anon_sym_concept] = ACTIONS(2605),
    [anon_sym_co_return] = ACTIONS(2605),
    [anon_sym_co_yield] = ACTIONS(2605),
    [anon_sym_R_DQUOTE] = ACTIONS(2607),
    [anon_sym_LR_DQUOTE] = ACTIONS(2607),
    [anon_sym_uR_DQUOTE] = ACTIONS(2607),
    [anon_sym_UR_DQUOTE] = ACTIONS(2607),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2607),
    [anon_sym_co_await] = ACTIONS(2605),
    [anon_sym_new] = ACTIONS(2605),
    [anon_sym_requires] = ACTIONS(2605),
    [sym_this] = ACTIONS(2605),
    [anon_sym___launch_bounds__] = ACTIONS(2605),
  },
  [STATE(504)] = {
    [sym_identifier] = ACTIONS(2521),
    [aux_sym_preproc_include_token1] = ACTIONS(2521),
    [aux_sym_preproc_def_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2521),
    [sym_preproc_directive] = ACTIONS(2521),
    [anon_sym_LPAREN2] = ACTIONS(2523),
    [anon_sym_BANG] = ACTIONS(2523),
    [anon_sym_TILDE] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2523),
    [anon_sym_AMP_AMP] = ACTIONS(2523),
    [anon_sym_AMP] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym___extension__] = ACTIONS(2521),
    [anon_sym_typedef] = ACTIONS(2521),
    [anon_sym___device__] = ACTIONS(2521),
    [anon_sym___host__] = ACTIONS(2521),
    [anon_sym___global__] = ACTIONS(2521),
    [anon_sym___forceinline__] = ACTIONS(2521),
    [anon_sym___noinline__] = ACTIONS(2521),
    [anon_sym_virtual] = ACTIONS(2521),
    [anon_sym_extern] = ACTIONS(2521),
    [anon_sym___attribute__] = ACTIONS(2521),
    [anon_sym___attribute] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2523),
    [anon_sym___declspec] = ACTIONS(2521),
    [anon_sym___based] = ACTIONS(2521),
    [anon_sym___cdecl] = ACTIONS(2521),
    [anon_sym___clrcall] = ACTIONS(2521),
    [anon_sym___stdcall] = ACTIONS(2521),
    [anon_sym___fastcall] = ACTIONS(2521),
    [anon_sym___thiscall] = ACTIONS(2521),
    [anon_sym___vectorcall] = ACTIONS(2521),
    [anon_sym_LBRACE] = ACTIONS(2523),
    [anon_sym_RBRACE] = ACTIONS(2523),
    [anon_sym_signed] = ACTIONS(2521),
    [anon_sym_unsigned] = ACTIONS(2521),
    [anon_sym_long] = ACTIONS(2521),
    [anon_sym_short] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2521),
    [anon_sym_static] = ACTIONS(2521),
    [anon_sym_register] = ACTIONS(2521),
    [anon_sym_inline] = ACTIONS(2521),
    [anon_sym___inline] = ACTIONS(2521),
    [anon_sym___inline__] = ACTIONS(2521),
    [anon_sym___forceinline] = ACTIONS(2521),
    [anon_sym_thread_local] = ACTIONS(2521),
    [anon_sym___thread] = ACTIONS(2521),
    [anon_sym_const] = ACTIONS(2521),
    [anon_sym_constexpr] = ACTIONS(2521),
    [anon_sym_volatile] = ACTIONS(2521),
    [anon_sym_restrict] = ACTIONS(2521),
    [anon_sym___restrict__] = ACTIONS(2521),
    [anon_sym__Atomic] = ACTIONS(2521),
    [anon_sym__Noreturn] = ACTIONS(2521),
    [anon_sym_noreturn] = ACTIONS(2521),
    [anon_sym__Nonnull] = ACTIONS(2521),
    [anon_sym_mutable] = ACTIONS(2521),
    [anon_sym_constinit] = ACTIONS(2521),
    [anon_sym_consteval] = ACTIONS(2521),
    [anon_sym___shared__] = ACTIONS(2521),
    [anon_sym___local__] = ACTIONS(2521),
    [anon_sym___constant__] = ACTIONS(2521),
    [anon_sym___managed__] = ACTIONS(2521),
    [anon_sym___grid_constant__] = ACTIONS(2521),
    [anon_sym_alignas] = ACTIONS(2521),
    [anon_sym__Alignas] = ACTIONS(2521),
    [sym_primitive_type] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_class] = ACTIONS(2521),
    [anon_sym_struct] = ACTIONS(2521),
    [anon_sym_union] = ACTIONS(2521),
    [anon_sym_if] = ACTIONS(2521),
    [anon_sym_switch] = ACTIONS(2521),
    [anon_sym_case] = ACTIONS(2521),
    [anon_sym_default] = ACTIONS(2521),
    [anon_sym_while] = ACTIONS(2521),
    [anon_sym_do] = ACTIONS(2521),
    [anon_sym_for] = ACTIONS(2521),
    [anon_sym_return] = ACTIONS(2521),
    [anon_sym_break] = ACTIONS(2521),
    [anon_sym_continue] = ACTIONS(2521),
    [anon_sym_goto] = ACTIONS(2521),
    [anon_sym___try] = ACTIONS(2521),
    [anon_sym___leave] = ACTIONS(2521),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_compl] = ACTIONS(2521),
    [anon_sym_DASH_DASH] = ACTIONS(2523),
    [anon_sym_PLUS_PLUS] = ACTIONS(2523),
    [anon_sym_sizeof] = ACTIONS(2521),
    [anon_sym___alignof__] = ACTIONS(2521),
    [anon_sym___alignof] = ACTIONS(2521),
    [anon_sym__alignof] = ACTIONS(2521),
    [anon_sym_alignof] = ACTIONS(2521),
    [anon_sym__Alignof] = ACTIONS(2521),
    [anon_sym_offsetof] = ACTIONS(2521),
    [anon_sym__Generic] = ACTIONS(2521),
    [anon_sym_asm] = ACTIONS(2521),
    [anon_sym___asm__] = ACTIONS(2521),
    [anon_sym___asm] = ACTIONS(2521),
    [sym_number_literal] = ACTIONS(2523),
    [anon_sym_L_SQUOTE] = ACTIONS(2523),
    [anon_sym_u_SQUOTE] = ACTIONS(2523),
    [anon_sym_U_SQUOTE] = ACTIONS(2523),
    [anon_sym_u8_SQUOTE] = ACTIONS(2523),
    [anon_sym_SQUOTE] = ACTIONS(2523),
    [anon_sym_L_DQUOTE] = ACTIONS(2523),
    [anon_sym_u_DQUOTE] = ACTIONS(2523),
    [anon_sym_U_DQUOTE] = ACTIONS(2523),
    [anon_sym_u8_DQUOTE] = ACTIONS(2523),
    [anon_sym_DQUOTE] = ACTIONS(2523),
    [sym_true] = ACTIONS(2521),
    [sym_false] = ACTIONS(2521),
    [anon_sym_NULL] = ACTIONS(2521),
    [anon_sym_nullptr] = ACTIONS(2521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2521),
    [anon_sym_decltype] = ACTIONS(2521),
    [anon_sym_explicit] = ACTIONS(2521),
    [anon_sym_typename] = ACTIONS(2521),
    [anon_sym_template] = ACTIONS(2521),
    [anon_sym_operator] = ACTIONS(2521),
    [anon_sym_try] = ACTIONS(2521),
    [anon_sym_delete] = ACTIONS(2521),
    [anon_sym_throw] = ACTIONS(2521),
    [anon_sym_namespace] = ACTIONS(2521),
    [anon_sym_using] = ACTIONS(2521),
    [anon_sym_static_assert] = ACTIONS(2521),
    [anon_sym_concept] = ACTIONS(2521),
    [anon_sym_co_return] = ACTIONS(2521),
    [anon_sym_co_yield] = ACTIONS(2521),
    [anon_sym_R_DQUOTE] = ACTIONS(2523),
    [anon_sym_LR_DQUOTE] = ACTIONS(2523),
    [anon_sym_uR_DQUOTE] = ACTIONS(2523),
    [anon_sym_UR_DQUOTE] = ACTIONS(2523),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2523),
    [anon_sym_co_await] = ACTIONS(2521),
    [anon_sym_new] = ACTIONS(2521),
    [anon_sym_requires] = ACTIONS(2521),
    [sym_this] = ACTIONS(2521),
    [anon_sym___launch_bounds__] = ACTIONS(2521),
  },
  [STATE(505)] = {
    [sym_identifier] = ACTIONS(2525),
    [aux_sym_preproc_include_token1] = ACTIONS(2525),
    [aux_sym_preproc_def_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2525),
    [sym_preproc_directive] = ACTIONS(2525),
    [anon_sym_LPAREN2] = ACTIONS(2527),
    [anon_sym_BANG] = ACTIONS(2527),
    [anon_sym_TILDE] = ACTIONS(2527),
    [anon_sym_DASH] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2527),
    [anon_sym_AMP_AMP] = ACTIONS(2527),
    [anon_sym_AMP] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym___extension__] = ACTIONS(2525),
    [anon_sym_typedef] = ACTIONS(2525),
    [anon_sym___device__] = ACTIONS(2525),
    [anon_sym___host__] = ACTIONS(2525),
    [anon_sym___global__] = ACTIONS(2525),
    [anon_sym___forceinline__] = ACTIONS(2525),
    [anon_sym___noinline__] = ACTIONS(2525),
    [anon_sym_virtual] = ACTIONS(2525),
    [anon_sym_extern] = ACTIONS(2525),
    [anon_sym___attribute__] = ACTIONS(2525),
    [anon_sym___attribute] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2527),
    [anon_sym___declspec] = ACTIONS(2525),
    [anon_sym___based] = ACTIONS(2525),
    [anon_sym___cdecl] = ACTIONS(2525),
    [anon_sym___clrcall] = ACTIONS(2525),
    [anon_sym___stdcall] = ACTIONS(2525),
    [anon_sym___fastcall] = ACTIONS(2525),
    [anon_sym___thiscall] = ACTIONS(2525),
    [anon_sym___vectorcall] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_RBRACE] = ACTIONS(2527),
    [anon_sym_signed] = ACTIONS(2525),
    [anon_sym_unsigned] = ACTIONS(2525),
    [anon_sym_long] = ACTIONS(2525),
    [anon_sym_short] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2525),
    [anon_sym_static] = ACTIONS(2525),
    [anon_sym_register] = ACTIONS(2525),
    [anon_sym_inline] = ACTIONS(2525),
    [anon_sym___inline] = ACTIONS(2525),
    [anon_sym___inline__] = ACTIONS(2525),
    [anon_sym___forceinline] = ACTIONS(2525),
    [anon_sym_thread_local] = ACTIONS(2525),
    [anon_sym___thread] = ACTIONS(2525),
    [anon_sym_const] = ACTIONS(2525),
    [anon_sym_constexpr] = ACTIONS(2525),
    [anon_sym_volatile] = ACTIONS(2525),
    [anon_sym_restrict] = ACTIONS(2525),
    [anon_sym___restrict__] = ACTIONS(2525),
    [anon_sym__Atomic] = ACTIONS(2525),
    [anon_sym__Noreturn] = ACTIONS(2525),
    [anon_sym_noreturn] = ACTIONS(2525),
    [anon_sym__Nonnull] = ACTIONS(2525),
    [anon_sym_mutable] = ACTIONS(2525),
    [anon_sym_constinit] = ACTIONS(2525),
    [anon_sym_consteval] = ACTIONS(2525),
    [anon_sym___shared__] = ACTIONS(2525),
    [anon_sym___local__] = ACTIONS(2525),
    [anon_sym___constant__] = ACTIONS(2525),
    [anon_sym___managed__] = ACTIONS(2525),
    [anon_sym___grid_constant__] = ACTIONS(2525),
    [anon_sym_alignas] = ACTIONS(2525),
    [anon_sym__Alignas] = ACTIONS(2525),
    [sym_primitive_type] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_class] = ACTIONS(2525),
    [anon_sym_struct] = ACTIONS(2525),
    [anon_sym_union] = ACTIONS(2525),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_switch] = ACTIONS(2525),
    [anon_sym_case] = ACTIONS(2525),
    [anon_sym_default] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(2525),
    [anon_sym_do] = ACTIONS(2525),
    [anon_sym_for] = ACTIONS(2525),
    [anon_sym_return] = ACTIONS(2525),
    [anon_sym_break] = ACTIONS(2525),
    [anon_sym_continue] = ACTIONS(2525),
    [anon_sym_goto] = ACTIONS(2525),
    [anon_sym___try] = ACTIONS(2525),
    [anon_sym___leave] = ACTIONS(2525),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_compl] = ACTIONS(2525),
    [anon_sym_DASH_DASH] = ACTIONS(2527),
    [anon_sym_PLUS_PLUS] = ACTIONS(2527),
    [anon_sym_sizeof] = ACTIONS(2525),
    [anon_sym___alignof__] = ACTIONS(2525),
    [anon_sym___alignof] = ACTIONS(2525),
    [anon_sym__alignof] = ACTIONS(2525),
    [anon_sym_alignof] = ACTIONS(2525),
    [anon_sym__Alignof] = ACTIONS(2525),
    [anon_sym_offsetof] = ACTIONS(2525),
    [anon_sym__Generic] = ACTIONS(2525),
    [anon_sym_asm] = ACTIONS(2525),
    [anon_sym___asm__] = ACTIONS(2525),
    [anon_sym___asm] = ACTIONS(2525),
    [sym_number_literal] = ACTIONS(2527),
    [anon_sym_L_SQUOTE] = ACTIONS(2527),
    [anon_sym_u_SQUOTE] = ACTIONS(2527),
    [anon_sym_U_SQUOTE] = ACTIONS(2527),
    [anon_sym_u8_SQUOTE] = ACTIONS(2527),
    [anon_sym_SQUOTE] = ACTIONS(2527),
    [anon_sym_L_DQUOTE] = ACTIONS(2527),
    [anon_sym_u_DQUOTE] = ACTIONS(2527),
    [anon_sym_U_DQUOTE] = ACTIONS(2527),
    [anon_sym_u8_DQUOTE] = ACTIONS(2527),
    [anon_sym_DQUOTE] = ACTIONS(2527),
    [sym_true] = ACTIONS(2525),
    [sym_false] = ACTIONS(2525),
    [anon_sym_NULL] = ACTIONS(2525),
    [anon_sym_nullptr] = ACTIONS(2525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2525),
    [anon_sym_decltype] = ACTIONS(2525),
    [anon_sym_explicit] = ACTIONS(2525),
    [anon_sym_typename] = ACTIONS(2525),
    [anon_sym_template] = ACTIONS(2525),
    [anon_sym_operator] = ACTIONS(2525),
    [anon_sym_try] = ACTIONS(2525),
    [anon_sym_delete] = ACTIONS(2525),
    [anon_sym_throw] = ACTIONS(2525),
    [anon_sym_namespace] = ACTIONS(2525),
    [anon_sym_using] = ACTIONS(2525),
    [anon_sym_static_assert] = ACTIONS(2525),
    [anon_sym_concept] = ACTIONS(2525),
    [anon_sym_co_return] = ACTIONS(2525),
    [anon_sym_co_yield] = ACTIONS(2525),
    [anon_sym_R_DQUOTE] = ACTIONS(2527),
    [anon_sym_LR_DQUOTE] = ACTIONS(2527),
    [anon_sym_uR_DQUOTE] = ACTIONS(2527),
    [anon_sym_UR_DQUOTE] = ACTIONS(2527),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2527),
    [anon_sym_co_await] = ACTIONS(2525),
    [anon_sym_new] = ACTIONS(2525),
    [anon_sym_requires] = ACTIONS(2525),
    [sym_this] = ACTIONS(2525),
    [anon_sym___launch_bounds__] = ACTIONS(2525),
  },
  [STATE(506)] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_include_token1] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token2] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_BANG] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym___device__] = ACTIONS(2320),
    [anon_sym___host__] = ACTIONS(2320),
    [anon_sym___global__] = ACTIONS(2320),
    [anon_sym___forceinline__] = ACTIONS(2320),
    [anon_sym___noinline__] = ACTIONS(2320),
    [anon_sym_virtual] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym___attribute] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym___cdecl] = ACTIONS(2320),
    [anon_sym___clrcall] = ACTIONS(2320),
    [anon_sym___stdcall] = ACTIONS(2320),
    [anon_sym___fastcall] = ACTIONS(2320),
    [anon_sym___thiscall] = ACTIONS(2320),
    [anon_sym___vectorcall] = ACTIONS(2320),
    [anon_sym_LBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym__Nonnull] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym___shared__] = ACTIONS(2320),
    [anon_sym___local__] = ACTIONS(2320),
    [anon_sym___constant__] = ACTIONS(2320),
    [anon_sym___managed__] = ACTIONS(2320),
    [anon_sym___grid_constant__] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_switch] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_default] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_do] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_return] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_goto] = ACTIONS(2320),
    [anon_sym___try] = ACTIONS(2320),
    [anon_sym___leave] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_compl] = ACTIONS(2320),
    [anon_sym_DASH_DASH] = ACTIONS(2322),
    [anon_sym_PLUS_PLUS] = ACTIONS(2322),
    [anon_sym_sizeof] = ACTIONS(2320),
    [anon_sym___alignof__] = ACTIONS(2320),
    [anon_sym___alignof] = ACTIONS(2320),
    [anon_sym__alignof] = ACTIONS(2320),
    [anon_sym_alignof] = ACTIONS(2320),
    [anon_sym__Alignof] = ACTIONS(2320),
    [anon_sym_offsetof] = ACTIONS(2320),
    [anon_sym__Generic] = ACTIONS(2320),
    [anon_sym_asm] = ACTIONS(2320),
    [anon_sym___asm__] = ACTIONS(2320),
    [anon_sym___asm] = ACTIONS(2320),
    [sym_number_literal] = ACTIONS(2322),
    [anon_sym_L_SQUOTE] = ACTIONS(2322),
    [anon_sym_u_SQUOTE] = ACTIONS(2322),
    [anon_sym_U_SQUOTE] = ACTIONS(2322),
    [anon_sym_u8_SQUOTE] = ACTIONS(2322),
    [anon_sym_SQUOTE] = ACTIONS(2322),
    [anon_sym_L_DQUOTE] = ACTIONS(2322),
    [anon_sym_u_DQUOTE] = ACTIONS(2322),
    [anon_sym_U_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8_DQUOTE] = ACTIONS(2322),
    [anon_sym_DQUOTE] = ACTIONS(2322),
    [sym_true] = ACTIONS(2320),
    [sym_false] = ACTIONS(2320),
    [anon_sym_NULL] = ACTIONS(2320),
    [anon_sym_nullptr] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_delete] = ACTIONS(2320),
    [anon_sym_throw] = ACTIONS(2320),
    [anon_sym_namespace] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_concept] = ACTIONS(2320),
    [anon_sym_co_return] = ACTIONS(2320),
    [anon_sym_co_yield] = ACTIONS(2320),
    [anon_sym_R_DQUOTE] = ACTIONS(2322),
    [anon_sym_LR_DQUOTE] = ACTIONS(2322),
    [anon_sym_uR_DQUOTE] = ACTIONS(2322),
    [anon_sym_UR_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2322),
    [anon_sym_co_await] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(2320),
    [anon_sym_requires] = ACTIONS(2320),
    [sym_this] = ACTIONS(2320),
    [anon_sym___launch_bounds__] = ACTIONS(2320),
  },
  [STATE(507)] = {
    [sym_identifier] = ACTIONS(2415),
    [aux_sym_preproc_include_token1] = ACTIONS(2415),
    [aux_sym_preproc_def_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token2] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2415),
    [sym_preproc_directive] = ACTIONS(2415),
    [anon_sym_LPAREN2] = ACTIONS(2417),
    [anon_sym_BANG] = ACTIONS(2417),
    [anon_sym_TILDE] = ACTIONS(2417),
    [anon_sym_DASH] = ACTIONS(2415),
    [anon_sym_PLUS] = ACTIONS(2415),
    [anon_sym_STAR] = ACTIONS(2417),
    [anon_sym_AMP_AMP] = ACTIONS(2417),
    [anon_sym_AMP] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(2417),
    [anon_sym___extension__] = ACTIONS(2415),
    [anon_sym_typedef] = ACTIONS(2415),
    [anon_sym___device__] = ACTIONS(2415),
    [anon_sym___host__] = ACTIONS(2415),
    [anon_sym___global__] = ACTIONS(2415),
    [anon_sym___forceinline__] = ACTIONS(2415),
    [anon_sym___noinline__] = ACTIONS(2415),
    [anon_sym_virtual] = ACTIONS(2415),
    [anon_sym_extern] = ACTIONS(2415),
    [anon_sym___attribute__] = ACTIONS(2415),
    [anon_sym___attribute] = ACTIONS(2415),
    [anon_sym_COLON_COLON] = ACTIONS(2417),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2417),
    [anon_sym___declspec] = ACTIONS(2415),
    [anon_sym___based] = ACTIONS(2415),
    [anon_sym___cdecl] = ACTIONS(2415),
    [anon_sym___clrcall] = ACTIONS(2415),
    [anon_sym___stdcall] = ACTIONS(2415),
    [anon_sym___fastcall] = ACTIONS(2415),
    [anon_sym___thiscall] = ACTIONS(2415),
    [anon_sym___vectorcall] = ACTIONS(2415),
    [anon_sym_LBRACE] = ACTIONS(2417),
    [anon_sym_signed] = ACTIONS(2415),
    [anon_sym_unsigned] = ACTIONS(2415),
    [anon_sym_long] = ACTIONS(2415),
    [anon_sym_short] = ACTIONS(2415),
    [anon_sym_LBRACK] = ACTIONS(2415),
    [anon_sym_static] = ACTIONS(2415),
    [anon_sym_register] = ACTIONS(2415),
    [anon_sym_inline] = ACTIONS(2415),
    [anon_sym___inline] = ACTIONS(2415),
    [anon_sym___inline__] = ACTIONS(2415),
    [anon_sym___forceinline] = ACTIONS(2415),
    [anon_sym_thread_local] = ACTIONS(2415),
    [anon_sym___thread] = ACTIONS(2415),
    [anon_sym_const] = ACTIONS(2415),
    [anon_sym_constexpr] = ACTIONS(2415),
    [anon_sym_volatile] = ACTIONS(2415),
    [anon_sym_restrict] = ACTIONS(2415),
    [anon_sym___restrict__] = ACTIONS(2415),
    [anon_sym__Atomic] = ACTIONS(2415),
    [anon_sym__Noreturn] = ACTIONS(2415),
    [anon_sym_noreturn] = ACTIONS(2415),
    [anon_sym__Nonnull] = ACTIONS(2415),
    [anon_sym_mutable] = ACTIONS(2415),
    [anon_sym_constinit] = ACTIONS(2415),
    [anon_sym_consteval] = ACTIONS(2415),
    [anon_sym___shared__] = ACTIONS(2415),
    [anon_sym___local__] = ACTIONS(2415),
    [anon_sym___constant__] = ACTIONS(2415),
    [anon_sym___managed__] = ACTIONS(2415),
    [anon_sym___grid_constant__] = ACTIONS(2415),
    [anon_sym_alignas] = ACTIONS(2415),
    [anon_sym__Alignas] = ACTIONS(2415),
    [sym_primitive_type] = ACTIONS(2415),
    [anon_sym_enum] = ACTIONS(2415),
    [anon_sym_class] = ACTIONS(2415),
    [anon_sym_struct] = ACTIONS(2415),
    [anon_sym_union] = ACTIONS(2415),
    [anon_sym_if] = ACTIONS(2415),
    [anon_sym_switch] = ACTIONS(2415),
    [anon_sym_case] = ACTIONS(2415),
    [anon_sym_default] = ACTIONS(2415),
    [anon_sym_while] = ACTIONS(2415),
    [anon_sym_do] = ACTIONS(2415),
    [anon_sym_for] = ACTIONS(2415),
    [anon_sym_return] = ACTIONS(2415),
    [anon_sym_break] = ACTIONS(2415),
    [anon_sym_continue] = ACTIONS(2415),
    [anon_sym_goto] = ACTIONS(2415),
    [anon_sym___try] = ACTIONS(2415),
    [anon_sym___leave] = ACTIONS(2415),
    [anon_sym_not] = ACTIONS(2415),
    [anon_sym_compl] = ACTIONS(2415),
    [anon_sym_DASH_DASH] = ACTIONS(2417),
    [anon_sym_PLUS_PLUS] = ACTIONS(2417),
    [anon_sym_sizeof] = ACTIONS(2415),
    [anon_sym___alignof__] = ACTIONS(2415),
    [anon_sym___alignof] = ACTIONS(2415),
    [anon_sym__alignof] = ACTIONS(2415),
    [anon_sym_alignof] = ACTIONS(2415),
    [anon_sym__Alignof] = ACTIONS(2415),
    [anon_sym_offsetof] = ACTIONS(2415),
    [anon_sym__Generic] = ACTIONS(2415),
    [anon_sym_asm] = ACTIONS(2415),
    [anon_sym___asm__] = ACTIONS(2415),
    [anon_sym___asm] = ACTIONS(2415),
    [sym_number_literal] = ACTIONS(2417),
    [anon_sym_L_SQUOTE] = ACTIONS(2417),
    [anon_sym_u_SQUOTE] = ACTIONS(2417),
    [anon_sym_U_SQUOTE] = ACTIONS(2417),
    [anon_sym_u8_SQUOTE] = ACTIONS(2417),
    [anon_sym_SQUOTE] = ACTIONS(2417),
    [anon_sym_L_DQUOTE] = ACTIONS(2417),
    [anon_sym_u_DQUOTE] = ACTIONS(2417),
    [anon_sym_U_DQUOTE] = ACTIONS(2417),
    [anon_sym_u8_DQUOTE] = ACTIONS(2417),
    [anon_sym_DQUOTE] = ACTIONS(2417),
    [sym_true] = ACTIONS(2415),
    [sym_false] = ACTIONS(2415),
    [anon_sym_NULL] = ACTIONS(2415),
    [anon_sym_nullptr] = ACTIONS(2415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2415),
    [anon_sym_decltype] = ACTIONS(2415),
    [anon_sym_explicit] = ACTIONS(2415),
    [anon_sym_typename] = ACTIONS(2415),
    [anon_sym_template] = ACTIONS(2415),
    [anon_sym_operator] = ACTIONS(2415),
    [anon_sym_try] = ACTIONS(2415),
    [anon_sym_delete] = ACTIONS(2415),
    [anon_sym_throw] = ACTIONS(2415),
    [anon_sym_namespace] = ACTIONS(2415),
    [anon_sym_using] = ACTIONS(2415),
    [anon_sym_static_assert] = ACTIONS(2415),
    [anon_sym_concept] = ACTIONS(2415),
    [anon_sym_co_return] = ACTIONS(2415),
    [anon_sym_co_yield] = ACTIONS(2415),
    [anon_sym_R_DQUOTE] = ACTIONS(2417),
    [anon_sym_LR_DQUOTE] = ACTIONS(2417),
    [anon_sym_uR_DQUOTE] = ACTIONS(2417),
    [anon_sym_UR_DQUOTE] = ACTIONS(2417),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2417),
    [anon_sym_co_await] = ACTIONS(2415),
    [anon_sym_new] = ACTIONS(2415),
    [anon_sym_requires] = ACTIONS(2415),
    [sym_this] = ACTIONS(2415),
    [anon_sym___launch_bounds__] = ACTIONS(2415),
  },
  [STATE(508)] = {
    [ts_builtin_sym_end] = ACTIONS(2551),
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_include_token1] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [anon_sym_COMMA] = ACTIONS(2551),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2549),
    [anon_sym_PLUS] = ACTIONS(2549),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym___device__] = ACTIONS(2549),
    [anon_sym___host__] = ACTIONS(2549),
    [anon_sym___global__] = ACTIONS(2549),
    [anon_sym___forceinline__] = ACTIONS(2549),
    [anon_sym___noinline__] = ACTIONS(2549),
    [anon_sym_virtual] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym___attribute] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym___cdecl] = ACTIONS(2549),
    [anon_sym___clrcall] = ACTIONS(2549),
    [anon_sym___stdcall] = ACTIONS(2549),
    [anon_sym___fastcall] = ACTIONS(2549),
    [anon_sym___thiscall] = ACTIONS(2549),
    [anon_sym___vectorcall] = ACTIONS(2549),
    [anon_sym_LBRACE] = ACTIONS(2551),
    [anon_sym_RBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym__Nonnull] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym___shared__] = ACTIONS(2549),
    [anon_sym___local__] = ACTIONS(2549),
    [anon_sym___constant__] = ACTIONS(2549),
    [anon_sym___managed__] = ACTIONS(2549),
    [anon_sym___grid_constant__] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2549),
    [anon_sym_switch] = ACTIONS(2549),
    [anon_sym_case] = ACTIONS(2549),
    [anon_sym_default] = ACTIONS(2549),
    [anon_sym_while] = ACTIONS(2549),
    [anon_sym_do] = ACTIONS(2549),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_return] = ACTIONS(2549),
    [anon_sym_break] = ACTIONS(2549),
    [anon_sym_continue] = ACTIONS(2549),
    [anon_sym_goto] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2549),
    [anon_sym_compl] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2551),
    [anon_sym_sizeof] = ACTIONS(2549),
    [anon_sym___alignof__] = ACTIONS(2549),
    [anon_sym___alignof] = ACTIONS(2549),
    [anon_sym__alignof] = ACTIONS(2549),
    [anon_sym_alignof] = ACTIONS(2549),
    [anon_sym__Alignof] = ACTIONS(2549),
    [anon_sym_offsetof] = ACTIONS(2549),
    [anon_sym__Generic] = ACTIONS(2549),
    [anon_sym_asm] = ACTIONS(2549),
    [anon_sym___asm__] = ACTIONS(2549),
    [anon_sym___asm] = ACTIONS(2549),
    [sym_number_literal] = ACTIONS(2551),
    [anon_sym_L_SQUOTE] = ACTIONS(2551),
    [anon_sym_u_SQUOTE] = ACTIONS(2551),
    [anon_sym_U_SQUOTE] = ACTIONS(2551),
    [anon_sym_u8_SQUOTE] = ACTIONS(2551),
    [anon_sym_SQUOTE] = ACTIONS(2551),
    [anon_sym_L_DQUOTE] = ACTIONS(2551),
    [anon_sym_u_DQUOTE] = ACTIONS(2551),
    [anon_sym_U_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8_DQUOTE] = ACTIONS(2551),
    [anon_sym_DQUOTE] = ACTIONS(2551),
    [sym_true] = ACTIONS(2549),
    [sym_false] = ACTIONS(2549),
    [anon_sym_NULL] = ACTIONS(2549),
    [anon_sym_nullptr] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_try] = ACTIONS(2549),
    [anon_sym_delete] = ACTIONS(2549),
    [anon_sym_throw] = ACTIONS(2549),
    [anon_sym_namespace] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_concept] = ACTIONS(2549),
    [anon_sym_co_return] = ACTIONS(2549),
    [anon_sym_co_yield] = ACTIONS(2549),
    [anon_sym_R_DQUOTE] = ACTIONS(2551),
    [anon_sym_LR_DQUOTE] = ACTIONS(2551),
    [anon_sym_uR_DQUOTE] = ACTIONS(2551),
    [anon_sym_UR_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2551),
    [anon_sym_co_await] = ACTIONS(2549),
    [anon_sym_new] = ACTIONS(2549),
    [anon_sym_requires] = ACTIONS(2549),
    [sym_this] = ACTIONS(2549),
    [anon_sym___launch_bounds__] = ACTIONS(2549),
  },
  [STATE(509)] = {
    [sym_identifier] = ACTIONS(2617),
    [aux_sym_preproc_include_token1] = ACTIONS(2617),
    [aux_sym_preproc_def_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token2] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2617),
    [sym_preproc_directive] = ACTIONS(2617),
    [anon_sym_LPAREN2] = ACTIONS(2619),
    [anon_sym_BANG] = ACTIONS(2619),
    [anon_sym_TILDE] = ACTIONS(2619),
    [anon_sym_DASH] = ACTIONS(2617),
    [anon_sym_PLUS] = ACTIONS(2617),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_AMP_AMP] = ACTIONS(2619),
    [anon_sym_AMP] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2619),
    [anon_sym___extension__] = ACTIONS(2617),
    [anon_sym_typedef] = ACTIONS(2617),
    [anon_sym___device__] = ACTIONS(2617),
    [anon_sym___host__] = ACTIONS(2617),
    [anon_sym___global__] = ACTIONS(2617),
    [anon_sym___forceinline__] = ACTIONS(2617),
    [anon_sym___noinline__] = ACTIONS(2617),
    [anon_sym_virtual] = ACTIONS(2617),
    [anon_sym_extern] = ACTIONS(2617),
    [anon_sym___attribute__] = ACTIONS(2617),
    [anon_sym___attribute] = ACTIONS(2617),
    [anon_sym_COLON_COLON] = ACTIONS(2619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2619),
    [anon_sym___declspec] = ACTIONS(2617),
    [anon_sym___based] = ACTIONS(2617),
    [anon_sym___cdecl] = ACTIONS(2617),
    [anon_sym___clrcall] = ACTIONS(2617),
    [anon_sym___stdcall] = ACTIONS(2617),
    [anon_sym___fastcall] = ACTIONS(2617),
    [anon_sym___thiscall] = ACTIONS(2617),
    [anon_sym___vectorcall] = ACTIONS(2617),
    [anon_sym_LBRACE] = ACTIONS(2619),
    [anon_sym_signed] = ACTIONS(2617),
    [anon_sym_unsigned] = ACTIONS(2617),
    [anon_sym_long] = ACTIONS(2617),
    [anon_sym_short] = ACTIONS(2617),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2617),
    [anon_sym_register] = ACTIONS(2617),
    [anon_sym_inline] = ACTIONS(2617),
    [anon_sym___inline] = ACTIONS(2617),
    [anon_sym___inline__] = ACTIONS(2617),
    [anon_sym___forceinline] = ACTIONS(2617),
    [anon_sym_thread_local] = ACTIONS(2617),
    [anon_sym___thread] = ACTIONS(2617),
    [anon_sym_const] = ACTIONS(2617),
    [anon_sym_constexpr] = ACTIONS(2617),
    [anon_sym_volatile] = ACTIONS(2617),
    [anon_sym_restrict] = ACTIONS(2617),
    [anon_sym___restrict__] = ACTIONS(2617),
    [anon_sym__Atomic] = ACTIONS(2617),
    [anon_sym__Noreturn] = ACTIONS(2617),
    [anon_sym_noreturn] = ACTIONS(2617),
    [anon_sym__Nonnull] = ACTIONS(2617),
    [anon_sym_mutable] = ACTIONS(2617),
    [anon_sym_constinit] = ACTIONS(2617),
    [anon_sym_consteval] = ACTIONS(2617),
    [anon_sym___shared__] = ACTIONS(2617),
    [anon_sym___local__] = ACTIONS(2617),
    [anon_sym___constant__] = ACTIONS(2617),
    [anon_sym___managed__] = ACTIONS(2617),
    [anon_sym___grid_constant__] = ACTIONS(2617),
    [anon_sym_alignas] = ACTIONS(2617),
    [anon_sym__Alignas] = ACTIONS(2617),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2617),
    [anon_sym_struct] = ACTIONS(2617),
    [anon_sym_union] = ACTIONS(2617),
    [anon_sym_if] = ACTIONS(2617),
    [anon_sym_switch] = ACTIONS(2617),
    [anon_sym_case] = ACTIONS(2617),
    [anon_sym_default] = ACTIONS(2617),
    [anon_sym_while] = ACTIONS(2617),
    [anon_sym_do] = ACTIONS(2617),
    [anon_sym_for] = ACTIONS(2617),
    [anon_sym_return] = ACTIONS(2617),
    [anon_sym_break] = ACTIONS(2617),
    [anon_sym_continue] = ACTIONS(2617),
    [anon_sym_goto] = ACTIONS(2617),
    [anon_sym___try] = ACTIONS(2617),
    [anon_sym___leave] = ACTIONS(2617),
    [anon_sym_not] = ACTIONS(2617),
    [anon_sym_compl] = ACTIONS(2617),
    [anon_sym_DASH_DASH] = ACTIONS(2619),
    [anon_sym_PLUS_PLUS] = ACTIONS(2619),
    [anon_sym_sizeof] = ACTIONS(2617),
    [anon_sym___alignof__] = ACTIONS(2617),
    [anon_sym___alignof] = ACTIONS(2617),
    [anon_sym__alignof] = ACTIONS(2617),
    [anon_sym_alignof] = ACTIONS(2617),
    [anon_sym__Alignof] = ACTIONS(2617),
    [anon_sym_offsetof] = ACTIONS(2617),
    [anon_sym__Generic] = ACTIONS(2617),
    [anon_sym_asm] = ACTIONS(2617),
    [anon_sym___asm__] = ACTIONS(2617),
    [anon_sym___asm] = ACTIONS(2617),
    [sym_number_literal] = ACTIONS(2619),
    [anon_sym_L_SQUOTE] = ACTIONS(2619),
    [anon_sym_u_SQUOTE] = ACTIONS(2619),
    [anon_sym_U_SQUOTE] = ACTIONS(2619),
    [anon_sym_u8_SQUOTE] = ACTIONS(2619),
    [anon_sym_SQUOTE] = ACTIONS(2619),
    [anon_sym_L_DQUOTE] = ACTIONS(2619),
    [anon_sym_u_DQUOTE] = ACTIONS(2619),
    [anon_sym_U_DQUOTE] = ACTIONS(2619),
    [anon_sym_u8_DQUOTE] = ACTIONS(2619),
    [anon_sym_DQUOTE] = ACTIONS(2619),
    [sym_true] = ACTIONS(2617),
    [sym_false] = ACTIONS(2617),
    [anon_sym_NULL] = ACTIONS(2617),
    [anon_sym_nullptr] = ACTIONS(2617),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2617),
    [anon_sym_decltype] = ACTIONS(2617),
    [anon_sym_explicit] = ACTIONS(2617),
    [anon_sym_typename] = ACTIONS(2617),
    [anon_sym_template] = ACTIONS(2617),
    [anon_sym_operator] = ACTIONS(2617),
    [anon_sym_try] = ACTIONS(2617),
    [anon_sym_delete] = ACTIONS(2617),
    [anon_sym_throw] = ACTIONS(2617),
    [anon_sym_namespace] = ACTIONS(2617),
    [anon_sym_using] = ACTIONS(2617),
    [anon_sym_static_assert] = ACTIONS(2617),
    [anon_sym_concept] = ACTIONS(2617),
    [anon_sym_co_return] = ACTIONS(2617),
    [anon_sym_co_yield] = ACTIONS(2617),
    [anon_sym_R_DQUOTE] = ACTIONS(2619),
    [anon_sym_LR_DQUOTE] = ACTIONS(2619),
    [anon_sym_uR_DQUOTE] = ACTIONS(2619),
    [anon_sym_UR_DQUOTE] = ACTIONS(2619),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2619),
    [anon_sym_co_await] = ACTIONS(2617),
    [anon_sym_new] = ACTIONS(2617),
    [anon_sym_requires] = ACTIONS(2617),
    [sym_this] = ACTIONS(2617),
    [anon_sym___launch_bounds__] = ACTIONS(2617),
  },
  [STATE(510)] = {
    [sym_identifier] = ACTIONS(2467),
    [aux_sym_preproc_include_token1] = ACTIONS(2467),
    [aux_sym_preproc_def_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token2] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2467),
    [sym_preproc_directive] = ACTIONS(2467),
    [anon_sym_LPAREN2] = ACTIONS(2469),
    [anon_sym_BANG] = ACTIONS(2469),
    [anon_sym_TILDE] = ACTIONS(2469),
    [anon_sym_DASH] = ACTIONS(2467),
    [anon_sym_PLUS] = ACTIONS(2467),
    [anon_sym_STAR] = ACTIONS(2469),
    [anon_sym_AMP_AMP] = ACTIONS(2469),
    [anon_sym_AMP] = ACTIONS(2467),
    [anon_sym_SEMI] = ACTIONS(2469),
    [anon_sym___extension__] = ACTIONS(2467),
    [anon_sym_typedef] = ACTIONS(2467),
    [anon_sym___device__] = ACTIONS(2467),
    [anon_sym___host__] = ACTIONS(2467),
    [anon_sym___global__] = ACTIONS(2467),
    [anon_sym___forceinline__] = ACTIONS(2467),
    [anon_sym___noinline__] = ACTIONS(2467),
    [anon_sym_virtual] = ACTIONS(2467),
    [anon_sym_extern] = ACTIONS(2467),
    [anon_sym___attribute__] = ACTIONS(2467),
    [anon_sym___attribute] = ACTIONS(2467),
    [anon_sym_COLON_COLON] = ACTIONS(2469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2469),
    [anon_sym___declspec] = ACTIONS(2467),
    [anon_sym___based] = ACTIONS(2467),
    [anon_sym___cdecl] = ACTIONS(2467),
    [anon_sym___clrcall] = ACTIONS(2467),
    [anon_sym___stdcall] = ACTIONS(2467),
    [anon_sym___fastcall] = ACTIONS(2467),
    [anon_sym___thiscall] = ACTIONS(2467),
    [anon_sym___vectorcall] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2469),
    [anon_sym_signed] = ACTIONS(2467),
    [anon_sym_unsigned] = ACTIONS(2467),
    [anon_sym_long] = ACTIONS(2467),
    [anon_sym_short] = ACTIONS(2467),
    [anon_sym_LBRACK] = ACTIONS(2467),
    [anon_sym_static] = ACTIONS(2467),
    [anon_sym_register] = ACTIONS(2467),
    [anon_sym_inline] = ACTIONS(2467),
    [anon_sym___inline] = ACTIONS(2467),
    [anon_sym___inline__] = ACTIONS(2467),
    [anon_sym___forceinline] = ACTIONS(2467),
    [anon_sym_thread_local] = ACTIONS(2467),
    [anon_sym___thread] = ACTIONS(2467),
    [anon_sym_const] = ACTIONS(2467),
    [anon_sym_constexpr] = ACTIONS(2467),
    [anon_sym_volatile] = ACTIONS(2467),
    [anon_sym_restrict] = ACTIONS(2467),
    [anon_sym___restrict__] = ACTIONS(2467),
    [anon_sym__Atomic] = ACTIONS(2467),
    [anon_sym__Noreturn] = ACTIONS(2467),
    [anon_sym_noreturn] = ACTIONS(2467),
    [anon_sym__Nonnull] = ACTIONS(2467),
    [anon_sym_mutable] = ACTIONS(2467),
    [anon_sym_constinit] = ACTIONS(2467),
    [anon_sym_consteval] = ACTIONS(2467),
    [anon_sym___shared__] = ACTIONS(2467),
    [anon_sym___local__] = ACTIONS(2467),
    [anon_sym___constant__] = ACTIONS(2467),
    [anon_sym___managed__] = ACTIONS(2467),
    [anon_sym___grid_constant__] = ACTIONS(2467),
    [anon_sym_alignas] = ACTIONS(2467),
    [anon_sym__Alignas] = ACTIONS(2467),
    [sym_primitive_type] = ACTIONS(2467),
    [anon_sym_enum] = ACTIONS(2467),
    [anon_sym_class] = ACTIONS(2467),
    [anon_sym_struct] = ACTIONS(2467),
    [anon_sym_union] = ACTIONS(2467),
    [anon_sym_if] = ACTIONS(2467),
    [anon_sym_switch] = ACTIONS(2467),
    [anon_sym_case] = ACTIONS(2467),
    [anon_sym_default] = ACTIONS(2467),
    [anon_sym_while] = ACTIONS(2467),
    [anon_sym_do] = ACTIONS(2467),
    [anon_sym_for] = ACTIONS(2467),
    [anon_sym_return] = ACTIONS(2467),
    [anon_sym_break] = ACTIONS(2467),
    [anon_sym_continue] = ACTIONS(2467),
    [anon_sym_goto] = ACTIONS(2467),
    [anon_sym___try] = ACTIONS(2467),
    [anon_sym___leave] = ACTIONS(2467),
    [anon_sym_not] = ACTIONS(2467),
    [anon_sym_compl] = ACTIONS(2467),
    [anon_sym_DASH_DASH] = ACTIONS(2469),
    [anon_sym_PLUS_PLUS] = ACTIONS(2469),
    [anon_sym_sizeof] = ACTIONS(2467),
    [anon_sym___alignof__] = ACTIONS(2467),
    [anon_sym___alignof] = ACTIONS(2467),
    [anon_sym__alignof] = ACTIONS(2467),
    [anon_sym_alignof] = ACTIONS(2467),
    [anon_sym__Alignof] = ACTIONS(2467),
    [anon_sym_offsetof] = ACTIONS(2467),
    [anon_sym__Generic] = ACTIONS(2467),
    [anon_sym_asm] = ACTIONS(2467),
    [anon_sym___asm__] = ACTIONS(2467),
    [anon_sym___asm] = ACTIONS(2467),
    [sym_number_literal] = ACTIONS(2469),
    [anon_sym_L_SQUOTE] = ACTIONS(2469),
    [anon_sym_u_SQUOTE] = ACTIONS(2469),
    [anon_sym_U_SQUOTE] = ACTIONS(2469),
    [anon_sym_u8_SQUOTE] = ACTIONS(2469),
    [anon_sym_SQUOTE] = ACTIONS(2469),
    [anon_sym_L_DQUOTE] = ACTIONS(2469),
    [anon_sym_u_DQUOTE] = ACTIONS(2469),
    [anon_sym_U_DQUOTE] = ACTIONS(2469),
    [anon_sym_u8_DQUOTE] = ACTIONS(2469),
    [anon_sym_DQUOTE] = ACTIONS(2469),
    [sym_true] = ACTIONS(2467),
    [sym_false] = ACTIONS(2467),
    [anon_sym_NULL] = ACTIONS(2467),
    [anon_sym_nullptr] = ACTIONS(2467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2467),
    [anon_sym_decltype] = ACTIONS(2467),
    [anon_sym_explicit] = ACTIONS(2467),
    [anon_sym_typename] = ACTIONS(2467),
    [anon_sym_template] = ACTIONS(2467),
    [anon_sym_operator] = ACTIONS(2467),
    [anon_sym_try] = ACTIONS(2467),
    [anon_sym_delete] = ACTIONS(2467),
    [anon_sym_throw] = ACTIONS(2467),
    [anon_sym_namespace] = ACTIONS(2467),
    [anon_sym_using] = ACTIONS(2467),
    [anon_sym_static_assert] = ACTIONS(2467),
    [anon_sym_concept] = ACTIONS(2467),
    [anon_sym_co_return] = ACTIONS(2467),
    [anon_sym_co_yield] = ACTIONS(2467),
    [anon_sym_R_DQUOTE] = ACTIONS(2469),
    [anon_sym_LR_DQUOTE] = ACTIONS(2469),
    [anon_sym_uR_DQUOTE] = ACTIONS(2469),
    [anon_sym_UR_DQUOTE] = ACTIONS(2469),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2469),
    [anon_sym_co_await] = ACTIONS(2467),
    [anon_sym_new] = ACTIONS(2467),
    [anon_sym_requires] = ACTIONS(2467),
    [sym_this] = ACTIONS(2467),
    [anon_sym___launch_bounds__] = ACTIONS(2467),
  },
  [STATE(511)] = {
    [sym_identifier] = ACTIONS(2485),
    [aux_sym_preproc_include_token1] = ACTIONS(2485),
    [aux_sym_preproc_def_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token2] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2485),
    [sym_preproc_directive] = ACTIONS(2485),
    [anon_sym_LPAREN2] = ACTIONS(2487),
    [anon_sym_BANG] = ACTIONS(2487),
    [anon_sym_TILDE] = ACTIONS(2487),
    [anon_sym_DASH] = ACTIONS(2485),
    [anon_sym_PLUS] = ACTIONS(2485),
    [anon_sym_STAR] = ACTIONS(2487),
    [anon_sym_AMP_AMP] = ACTIONS(2487),
    [anon_sym_AMP] = ACTIONS(2485),
    [anon_sym_SEMI] = ACTIONS(2487),
    [anon_sym___extension__] = ACTIONS(2485),
    [anon_sym_typedef] = ACTIONS(2485),
    [anon_sym___device__] = ACTIONS(2485),
    [anon_sym___host__] = ACTIONS(2485),
    [anon_sym___global__] = ACTIONS(2485),
    [anon_sym___forceinline__] = ACTIONS(2485),
    [anon_sym___noinline__] = ACTIONS(2485),
    [anon_sym_virtual] = ACTIONS(2485),
    [anon_sym_extern] = ACTIONS(2485),
    [anon_sym___attribute__] = ACTIONS(2485),
    [anon_sym___attribute] = ACTIONS(2485),
    [anon_sym_COLON_COLON] = ACTIONS(2487),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2487),
    [anon_sym___declspec] = ACTIONS(2485),
    [anon_sym___based] = ACTIONS(2485),
    [anon_sym___cdecl] = ACTIONS(2485),
    [anon_sym___clrcall] = ACTIONS(2485),
    [anon_sym___stdcall] = ACTIONS(2485),
    [anon_sym___fastcall] = ACTIONS(2485),
    [anon_sym___thiscall] = ACTIONS(2485),
    [anon_sym___vectorcall] = ACTIONS(2485),
    [anon_sym_LBRACE] = ACTIONS(2487),
    [anon_sym_signed] = ACTIONS(2485),
    [anon_sym_unsigned] = ACTIONS(2485),
    [anon_sym_long] = ACTIONS(2485),
    [anon_sym_short] = ACTIONS(2485),
    [anon_sym_LBRACK] = ACTIONS(2485),
    [anon_sym_static] = ACTIONS(2485),
    [anon_sym_register] = ACTIONS(2485),
    [anon_sym_inline] = ACTIONS(2485),
    [anon_sym___inline] = ACTIONS(2485),
    [anon_sym___inline__] = ACTIONS(2485),
    [anon_sym___forceinline] = ACTIONS(2485),
    [anon_sym_thread_local] = ACTIONS(2485),
    [anon_sym___thread] = ACTIONS(2485),
    [anon_sym_const] = ACTIONS(2485),
    [anon_sym_constexpr] = ACTIONS(2485),
    [anon_sym_volatile] = ACTIONS(2485),
    [anon_sym_restrict] = ACTIONS(2485),
    [anon_sym___restrict__] = ACTIONS(2485),
    [anon_sym__Atomic] = ACTIONS(2485),
    [anon_sym__Noreturn] = ACTIONS(2485),
    [anon_sym_noreturn] = ACTIONS(2485),
    [anon_sym__Nonnull] = ACTIONS(2485),
    [anon_sym_mutable] = ACTIONS(2485),
    [anon_sym_constinit] = ACTIONS(2485),
    [anon_sym_consteval] = ACTIONS(2485),
    [anon_sym___shared__] = ACTIONS(2485),
    [anon_sym___local__] = ACTIONS(2485),
    [anon_sym___constant__] = ACTIONS(2485),
    [anon_sym___managed__] = ACTIONS(2485),
    [anon_sym___grid_constant__] = ACTIONS(2485),
    [anon_sym_alignas] = ACTIONS(2485),
    [anon_sym__Alignas] = ACTIONS(2485),
    [sym_primitive_type] = ACTIONS(2485),
    [anon_sym_enum] = ACTIONS(2485),
    [anon_sym_class] = ACTIONS(2485),
    [anon_sym_struct] = ACTIONS(2485),
    [anon_sym_union] = ACTIONS(2485),
    [anon_sym_if] = ACTIONS(2485),
    [anon_sym_switch] = ACTIONS(2485),
    [anon_sym_case] = ACTIONS(2485),
    [anon_sym_default] = ACTIONS(2485),
    [anon_sym_while] = ACTIONS(2485),
    [anon_sym_do] = ACTIONS(2485),
    [anon_sym_for] = ACTIONS(2485),
    [anon_sym_return] = ACTIONS(2485),
    [anon_sym_break] = ACTIONS(2485),
    [anon_sym_continue] = ACTIONS(2485),
    [anon_sym_goto] = ACTIONS(2485),
    [anon_sym___try] = ACTIONS(2485),
    [anon_sym___leave] = ACTIONS(2485),
    [anon_sym_not] = ACTIONS(2485),
    [anon_sym_compl] = ACTIONS(2485),
    [anon_sym_DASH_DASH] = ACTIONS(2487),
    [anon_sym_PLUS_PLUS] = ACTIONS(2487),
    [anon_sym_sizeof] = ACTIONS(2485),
    [anon_sym___alignof__] = ACTIONS(2485),
    [anon_sym___alignof] = ACTIONS(2485),
    [anon_sym__alignof] = ACTIONS(2485),
    [anon_sym_alignof] = ACTIONS(2485),
    [anon_sym__Alignof] = ACTIONS(2485),
    [anon_sym_offsetof] = ACTIONS(2485),
    [anon_sym__Generic] = ACTIONS(2485),
    [anon_sym_asm] = ACTIONS(2485),
    [anon_sym___asm__] = ACTIONS(2485),
    [anon_sym___asm] = ACTIONS(2485),
    [sym_number_literal] = ACTIONS(2487),
    [anon_sym_L_SQUOTE] = ACTIONS(2487),
    [anon_sym_u_SQUOTE] = ACTIONS(2487),
    [anon_sym_U_SQUOTE] = ACTIONS(2487),
    [anon_sym_u8_SQUOTE] = ACTIONS(2487),
    [anon_sym_SQUOTE] = ACTIONS(2487),
    [anon_sym_L_DQUOTE] = ACTIONS(2487),
    [anon_sym_u_DQUOTE] = ACTIONS(2487),
    [anon_sym_U_DQUOTE] = ACTIONS(2487),
    [anon_sym_u8_DQUOTE] = ACTIONS(2487),
    [anon_sym_DQUOTE] = ACTIONS(2487),
    [sym_true] = ACTIONS(2485),
    [sym_false] = ACTIONS(2485),
    [anon_sym_NULL] = ACTIONS(2485),
    [anon_sym_nullptr] = ACTIONS(2485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2485),
    [anon_sym_decltype] = ACTIONS(2485),
    [anon_sym_explicit] = ACTIONS(2485),
    [anon_sym_typename] = ACTIONS(2485),
    [anon_sym_template] = ACTIONS(2485),
    [anon_sym_operator] = ACTIONS(2485),
    [anon_sym_try] = ACTIONS(2485),
    [anon_sym_delete] = ACTIONS(2485),
    [anon_sym_throw] = ACTIONS(2485),
    [anon_sym_namespace] = ACTIONS(2485),
    [anon_sym_using] = ACTIONS(2485),
    [anon_sym_static_assert] = ACTIONS(2485),
    [anon_sym_concept] = ACTIONS(2485),
    [anon_sym_co_return] = ACTIONS(2485),
    [anon_sym_co_yield] = ACTIONS(2485),
    [anon_sym_R_DQUOTE] = ACTIONS(2487),
    [anon_sym_LR_DQUOTE] = ACTIONS(2487),
    [anon_sym_uR_DQUOTE] = ACTIONS(2487),
    [anon_sym_UR_DQUOTE] = ACTIONS(2487),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2487),
    [anon_sym_co_await] = ACTIONS(2485),
    [anon_sym_new] = ACTIONS(2485),
    [anon_sym_requires] = ACTIONS(2485),
    [sym_this] = ACTIONS(2485),
    [anon_sym___launch_bounds__] = ACTIONS(2485),
  },
  [STATE(512)] = {
    [sym_identifier] = ACTIONS(2493),
    [aux_sym_preproc_include_token1] = ACTIONS(2493),
    [aux_sym_preproc_def_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token2] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2493),
    [sym_preproc_directive] = ACTIONS(2493),
    [anon_sym_LPAREN2] = ACTIONS(2495),
    [anon_sym_BANG] = ACTIONS(2495),
    [anon_sym_TILDE] = ACTIONS(2495),
    [anon_sym_DASH] = ACTIONS(2493),
    [anon_sym_PLUS] = ACTIONS(2493),
    [anon_sym_STAR] = ACTIONS(2495),
    [anon_sym_AMP_AMP] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(2493),
    [anon_sym_SEMI] = ACTIONS(2495),
    [anon_sym___extension__] = ACTIONS(2493),
    [anon_sym_typedef] = ACTIONS(2493),
    [anon_sym___device__] = ACTIONS(2493),
    [anon_sym___host__] = ACTIONS(2493),
    [anon_sym___global__] = ACTIONS(2493),
    [anon_sym___forceinline__] = ACTIONS(2493),
    [anon_sym___noinline__] = ACTIONS(2493),
    [anon_sym_virtual] = ACTIONS(2493),
    [anon_sym_extern] = ACTIONS(2493),
    [anon_sym___attribute__] = ACTIONS(2493),
    [anon_sym___attribute] = ACTIONS(2493),
    [anon_sym_COLON_COLON] = ACTIONS(2495),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2495),
    [anon_sym___declspec] = ACTIONS(2493),
    [anon_sym___based] = ACTIONS(2493),
    [anon_sym___cdecl] = ACTIONS(2493),
    [anon_sym___clrcall] = ACTIONS(2493),
    [anon_sym___stdcall] = ACTIONS(2493),
    [anon_sym___fastcall] = ACTIONS(2493),
    [anon_sym___thiscall] = ACTIONS(2493),
    [anon_sym___vectorcall] = ACTIONS(2493),
    [anon_sym_LBRACE] = ACTIONS(2495),
    [anon_sym_signed] = ACTIONS(2493),
    [anon_sym_unsigned] = ACTIONS(2493),
    [anon_sym_long] = ACTIONS(2493),
    [anon_sym_short] = ACTIONS(2493),
    [anon_sym_LBRACK] = ACTIONS(2493),
    [anon_sym_static] = ACTIONS(2493),
    [anon_sym_register] = ACTIONS(2493),
    [anon_sym_inline] = ACTIONS(2493),
    [anon_sym___inline] = ACTIONS(2493),
    [anon_sym___inline__] = ACTIONS(2493),
    [anon_sym___forceinline] = ACTIONS(2493),
    [anon_sym_thread_local] = ACTIONS(2493),
    [anon_sym___thread] = ACTIONS(2493),
    [anon_sym_const] = ACTIONS(2493),
    [anon_sym_constexpr] = ACTIONS(2493),
    [anon_sym_volatile] = ACTIONS(2493),
    [anon_sym_restrict] = ACTIONS(2493),
    [anon_sym___restrict__] = ACTIONS(2493),
    [anon_sym__Atomic] = ACTIONS(2493),
    [anon_sym__Noreturn] = ACTIONS(2493),
    [anon_sym_noreturn] = ACTIONS(2493),
    [anon_sym__Nonnull] = ACTIONS(2493),
    [anon_sym_mutable] = ACTIONS(2493),
    [anon_sym_constinit] = ACTIONS(2493),
    [anon_sym_consteval] = ACTIONS(2493),
    [anon_sym___shared__] = ACTIONS(2493),
    [anon_sym___local__] = ACTIONS(2493),
    [anon_sym___constant__] = ACTIONS(2493),
    [anon_sym___managed__] = ACTIONS(2493),
    [anon_sym___grid_constant__] = ACTIONS(2493),
    [anon_sym_alignas] = ACTIONS(2493),
    [anon_sym__Alignas] = ACTIONS(2493),
    [sym_primitive_type] = ACTIONS(2493),
    [anon_sym_enum] = ACTIONS(2493),
    [anon_sym_class] = ACTIONS(2493),
    [anon_sym_struct] = ACTIONS(2493),
    [anon_sym_union] = ACTIONS(2493),
    [anon_sym_if] = ACTIONS(2493),
    [anon_sym_switch] = ACTIONS(2493),
    [anon_sym_case] = ACTIONS(2493),
    [anon_sym_default] = ACTIONS(2493),
    [anon_sym_while] = ACTIONS(2493),
    [anon_sym_do] = ACTIONS(2493),
    [anon_sym_for] = ACTIONS(2493),
    [anon_sym_return] = ACTIONS(2493),
    [anon_sym_break] = ACTIONS(2493),
    [anon_sym_continue] = ACTIONS(2493),
    [anon_sym_goto] = ACTIONS(2493),
    [anon_sym___try] = ACTIONS(2493),
    [anon_sym___leave] = ACTIONS(2493),
    [anon_sym_not] = ACTIONS(2493),
    [anon_sym_compl] = ACTIONS(2493),
    [anon_sym_DASH_DASH] = ACTIONS(2495),
    [anon_sym_PLUS_PLUS] = ACTIONS(2495),
    [anon_sym_sizeof] = ACTIONS(2493),
    [anon_sym___alignof__] = ACTIONS(2493),
    [anon_sym___alignof] = ACTIONS(2493),
    [anon_sym__alignof] = ACTIONS(2493),
    [anon_sym_alignof] = ACTIONS(2493),
    [anon_sym__Alignof] = ACTIONS(2493),
    [anon_sym_offsetof] = ACTIONS(2493),
    [anon_sym__Generic] = ACTIONS(2493),
    [anon_sym_asm] = ACTIONS(2493),
    [anon_sym___asm__] = ACTIONS(2493),
    [anon_sym___asm] = ACTIONS(2493),
    [sym_number_literal] = ACTIONS(2495),
    [anon_sym_L_SQUOTE] = ACTIONS(2495),
    [anon_sym_u_SQUOTE] = ACTIONS(2495),
    [anon_sym_U_SQUOTE] = ACTIONS(2495),
    [anon_sym_u8_SQUOTE] = ACTIONS(2495),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_L_DQUOTE] = ACTIONS(2495),
    [anon_sym_u_DQUOTE] = ACTIONS(2495),
    [anon_sym_U_DQUOTE] = ACTIONS(2495),
    [anon_sym_u8_DQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2495),
    [sym_true] = ACTIONS(2493),
    [sym_false] = ACTIONS(2493),
    [anon_sym_NULL] = ACTIONS(2493),
    [anon_sym_nullptr] = ACTIONS(2493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2493),
    [anon_sym_decltype] = ACTIONS(2493),
    [anon_sym_explicit] = ACTIONS(2493),
    [anon_sym_typename] = ACTIONS(2493),
    [anon_sym_template] = ACTIONS(2493),
    [anon_sym_operator] = ACTIONS(2493),
    [anon_sym_try] = ACTIONS(2493),
    [anon_sym_delete] = ACTIONS(2493),
    [anon_sym_throw] = ACTIONS(2493),
    [anon_sym_namespace] = ACTIONS(2493),
    [anon_sym_using] = ACTIONS(2493),
    [anon_sym_static_assert] = ACTIONS(2493),
    [anon_sym_concept] = ACTIONS(2493),
    [anon_sym_co_return] = ACTIONS(2493),
    [anon_sym_co_yield] = ACTIONS(2493),
    [anon_sym_R_DQUOTE] = ACTIONS(2495),
    [anon_sym_LR_DQUOTE] = ACTIONS(2495),
    [anon_sym_uR_DQUOTE] = ACTIONS(2495),
    [anon_sym_UR_DQUOTE] = ACTIONS(2495),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2495),
    [anon_sym_co_await] = ACTIONS(2493),
    [anon_sym_new] = ACTIONS(2493),
    [anon_sym_requires] = ACTIONS(2493),
    [sym_this] = ACTIONS(2493),
    [anon_sym___launch_bounds__] = ACTIONS(2493),
  },
  [STATE(513)] = {
    [sym_identifier] = ACTIONS(2497),
    [aux_sym_preproc_include_token1] = ACTIONS(2497),
    [aux_sym_preproc_def_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token2] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2497),
    [sym_preproc_directive] = ACTIONS(2497),
    [anon_sym_LPAREN2] = ACTIONS(2499),
    [anon_sym_BANG] = ACTIONS(2499),
    [anon_sym_TILDE] = ACTIONS(2499),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_STAR] = ACTIONS(2499),
    [anon_sym_AMP_AMP] = ACTIONS(2499),
    [anon_sym_AMP] = ACTIONS(2497),
    [anon_sym_SEMI] = ACTIONS(2499),
    [anon_sym___extension__] = ACTIONS(2497),
    [anon_sym_typedef] = ACTIONS(2497),
    [anon_sym___device__] = ACTIONS(2497),
    [anon_sym___host__] = ACTIONS(2497),
    [anon_sym___global__] = ACTIONS(2497),
    [anon_sym___forceinline__] = ACTIONS(2497),
    [anon_sym___noinline__] = ACTIONS(2497),
    [anon_sym_virtual] = ACTIONS(2497),
    [anon_sym_extern] = ACTIONS(2497),
    [anon_sym___attribute__] = ACTIONS(2497),
    [anon_sym___attribute] = ACTIONS(2497),
    [anon_sym_COLON_COLON] = ACTIONS(2499),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2499),
    [anon_sym___declspec] = ACTIONS(2497),
    [anon_sym___based] = ACTIONS(2497),
    [anon_sym___cdecl] = ACTIONS(2497),
    [anon_sym___clrcall] = ACTIONS(2497),
    [anon_sym___stdcall] = ACTIONS(2497),
    [anon_sym___fastcall] = ACTIONS(2497),
    [anon_sym___thiscall] = ACTIONS(2497),
    [anon_sym___vectorcall] = ACTIONS(2497),
    [anon_sym_LBRACE] = ACTIONS(2499),
    [anon_sym_signed] = ACTIONS(2497),
    [anon_sym_unsigned] = ACTIONS(2497),
    [anon_sym_long] = ACTIONS(2497),
    [anon_sym_short] = ACTIONS(2497),
    [anon_sym_LBRACK] = ACTIONS(2497),
    [anon_sym_static] = ACTIONS(2497),
    [anon_sym_register] = ACTIONS(2497),
    [anon_sym_inline] = ACTIONS(2497),
    [anon_sym___inline] = ACTIONS(2497),
    [anon_sym___inline__] = ACTIONS(2497),
    [anon_sym___forceinline] = ACTIONS(2497),
    [anon_sym_thread_local] = ACTIONS(2497),
    [anon_sym___thread] = ACTIONS(2497),
    [anon_sym_const] = ACTIONS(2497),
    [anon_sym_constexpr] = ACTIONS(2497),
    [anon_sym_volatile] = ACTIONS(2497),
    [anon_sym_restrict] = ACTIONS(2497),
    [anon_sym___restrict__] = ACTIONS(2497),
    [anon_sym__Atomic] = ACTIONS(2497),
    [anon_sym__Noreturn] = ACTIONS(2497),
    [anon_sym_noreturn] = ACTIONS(2497),
    [anon_sym__Nonnull] = ACTIONS(2497),
    [anon_sym_mutable] = ACTIONS(2497),
    [anon_sym_constinit] = ACTIONS(2497),
    [anon_sym_consteval] = ACTIONS(2497),
    [anon_sym___shared__] = ACTIONS(2497),
    [anon_sym___local__] = ACTIONS(2497),
    [anon_sym___constant__] = ACTIONS(2497),
    [anon_sym___managed__] = ACTIONS(2497),
    [anon_sym___grid_constant__] = ACTIONS(2497),
    [anon_sym_alignas] = ACTIONS(2497),
    [anon_sym__Alignas] = ACTIONS(2497),
    [sym_primitive_type] = ACTIONS(2497),
    [anon_sym_enum] = ACTIONS(2497),
    [anon_sym_class] = ACTIONS(2497),
    [anon_sym_struct] = ACTIONS(2497),
    [anon_sym_union] = ACTIONS(2497),
    [anon_sym_if] = ACTIONS(2497),
    [anon_sym_switch] = ACTIONS(2497),
    [anon_sym_case] = ACTIONS(2497),
    [anon_sym_default] = ACTIONS(2497),
    [anon_sym_while] = ACTIONS(2497),
    [anon_sym_do] = ACTIONS(2497),
    [anon_sym_for] = ACTIONS(2497),
    [anon_sym_return] = ACTIONS(2497),
    [anon_sym_break] = ACTIONS(2497),
    [anon_sym_continue] = ACTIONS(2497),
    [anon_sym_goto] = ACTIONS(2497),
    [anon_sym___try] = ACTIONS(2497),
    [anon_sym___leave] = ACTIONS(2497),
    [anon_sym_not] = ACTIONS(2497),
    [anon_sym_compl] = ACTIONS(2497),
    [anon_sym_DASH_DASH] = ACTIONS(2499),
    [anon_sym_PLUS_PLUS] = ACTIONS(2499),
    [anon_sym_sizeof] = ACTIONS(2497),
    [anon_sym___alignof__] = ACTIONS(2497),
    [anon_sym___alignof] = ACTIONS(2497),
    [anon_sym__alignof] = ACTIONS(2497),
    [anon_sym_alignof] = ACTIONS(2497),
    [anon_sym__Alignof] = ACTIONS(2497),
    [anon_sym_offsetof] = ACTIONS(2497),
    [anon_sym__Generic] = ACTIONS(2497),
    [anon_sym_asm] = ACTIONS(2497),
    [anon_sym___asm__] = ACTIONS(2497),
    [anon_sym___asm] = ACTIONS(2497),
    [sym_number_literal] = ACTIONS(2499),
    [anon_sym_L_SQUOTE] = ACTIONS(2499),
    [anon_sym_u_SQUOTE] = ACTIONS(2499),
    [anon_sym_U_SQUOTE] = ACTIONS(2499),
    [anon_sym_u8_SQUOTE] = ACTIONS(2499),
    [anon_sym_SQUOTE] = ACTIONS(2499),
    [anon_sym_L_DQUOTE] = ACTIONS(2499),
    [anon_sym_u_DQUOTE] = ACTIONS(2499),
    [anon_sym_U_DQUOTE] = ACTIONS(2499),
    [anon_sym_u8_DQUOTE] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(2499),
    [sym_true] = ACTIONS(2497),
    [sym_false] = ACTIONS(2497),
    [anon_sym_NULL] = ACTIONS(2497),
    [anon_sym_nullptr] = ACTIONS(2497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2497),
    [anon_sym_decltype] = ACTIONS(2497),
    [anon_sym_explicit] = ACTIONS(2497),
    [anon_sym_typename] = ACTIONS(2497),
    [anon_sym_template] = ACTIONS(2497),
    [anon_sym_operator] = ACTIONS(2497),
    [anon_sym_try] = ACTIONS(2497),
    [anon_sym_delete] = ACTIONS(2497),
    [anon_sym_throw] = ACTIONS(2497),
    [anon_sym_namespace] = ACTIONS(2497),
    [anon_sym_using] = ACTIONS(2497),
    [anon_sym_static_assert] = ACTIONS(2497),
    [anon_sym_concept] = ACTIONS(2497),
    [anon_sym_co_return] = ACTIONS(2497),
    [anon_sym_co_yield] = ACTIONS(2497),
    [anon_sym_R_DQUOTE] = ACTIONS(2499),
    [anon_sym_LR_DQUOTE] = ACTIONS(2499),
    [anon_sym_uR_DQUOTE] = ACTIONS(2499),
    [anon_sym_UR_DQUOTE] = ACTIONS(2499),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2499),
    [anon_sym_co_await] = ACTIONS(2497),
    [anon_sym_new] = ACTIONS(2497),
    [anon_sym_requires] = ACTIONS(2497),
    [sym_this] = ACTIONS(2497),
    [anon_sym___launch_bounds__] = ACTIONS(2497),
  },
  [STATE(514)] = {
    [sym_identifier] = ACTIONS(2501),
    [aux_sym_preproc_include_token1] = ACTIONS(2501),
    [aux_sym_preproc_def_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token2] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2501),
    [sym_preproc_directive] = ACTIONS(2501),
    [anon_sym_LPAREN2] = ACTIONS(2503),
    [anon_sym_BANG] = ACTIONS(2503),
    [anon_sym_TILDE] = ACTIONS(2503),
    [anon_sym_DASH] = ACTIONS(2501),
    [anon_sym_PLUS] = ACTIONS(2501),
    [anon_sym_STAR] = ACTIONS(2503),
    [anon_sym_AMP_AMP] = ACTIONS(2503),
    [anon_sym_AMP] = ACTIONS(2501),
    [anon_sym_SEMI] = ACTIONS(2503),
    [anon_sym___extension__] = ACTIONS(2501),
    [anon_sym_typedef] = ACTIONS(2501),
    [anon_sym___device__] = ACTIONS(2501),
    [anon_sym___host__] = ACTIONS(2501),
    [anon_sym___global__] = ACTIONS(2501),
    [anon_sym___forceinline__] = ACTIONS(2501),
    [anon_sym___noinline__] = ACTIONS(2501),
    [anon_sym_virtual] = ACTIONS(2501),
    [anon_sym_extern] = ACTIONS(2501),
    [anon_sym___attribute__] = ACTIONS(2501),
    [anon_sym___attribute] = ACTIONS(2501),
    [anon_sym_COLON_COLON] = ACTIONS(2503),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2503),
    [anon_sym___declspec] = ACTIONS(2501),
    [anon_sym___based] = ACTIONS(2501),
    [anon_sym___cdecl] = ACTIONS(2501),
    [anon_sym___clrcall] = ACTIONS(2501),
    [anon_sym___stdcall] = ACTIONS(2501),
    [anon_sym___fastcall] = ACTIONS(2501),
    [anon_sym___thiscall] = ACTIONS(2501),
    [anon_sym___vectorcall] = ACTIONS(2501),
    [anon_sym_LBRACE] = ACTIONS(2503),
    [anon_sym_signed] = ACTIONS(2501),
    [anon_sym_unsigned] = ACTIONS(2501),
    [anon_sym_long] = ACTIONS(2501),
    [anon_sym_short] = ACTIONS(2501),
    [anon_sym_LBRACK] = ACTIONS(2501),
    [anon_sym_static] = ACTIONS(2501),
    [anon_sym_register] = ACTIONS(2501),
    [anon_sym_inline] = ACTIONS(2501),
    [anon_sym___inline] = ACTIONS(2501),
    [anon_sym___inline__] = ACTIONS(2501),
    [anon_sym___forceinline] = ACTIONS(2501),
    [anon_sym_thread_local] = ACTIONS(2501),
    [anon_sym___thread] = ACTIONS(2501),
    [anon_sym_const] = ACTIONS(2501),
    [anon_sym_constexpr] = ACTIONS(2501),
    [anon_sym_volatile] = ACTIONS(2501),
    [anon_sym_restrict] = ACTIONS(2501),
    [anon_sym___restrict__] = ACTIONS(2501),
    [anon_sym__Atomic] = ACTIONS(2501),
    [anon_sym__Noreturn] = ACTIONS(2501),
    [anon_sym_noreturn] = ACTIONS(2501),
    [anon_sym__Nonnull] = ACTIONS(2501),
    [anon_sym_mutable] = ACTIONS(2501),
    [anon_sym_constinit] = ACTIONS(2501),
    [anon_sym_consteval] = ACTIONS(2501),
    [anon_sym___shared__] = ACTIONS(2501),
    [anon_sym___local__] = ACTIONS(2501),
    [anon_sym___constant__] = ACTIONS(2501),
    [anon_sym___managed__] = ACTIONS(2501),
    [anon_sym___grid_constant__] = ACTIONS(2501),
    [anon_sym_alignas] = ACTIONS(2501),
    [anon_sym__Alignas] = ACTIONS(2501),
    [sym_primitive_type] = ACTIONS(2501),
    [anon_sym_enum] = ACTIONS(2501),
    [anon_sym_class] = ACTIONS(2501),
    [anon_sym_struct] = ACTIONS(2501),
    [anon_sym_union] = ACTIONS(2501),
    [anon_sym_if] = ACTIONS(2501),
    [anon_sym_switch] = ACTIONS(2501),
    [anon_sym_case] = ACTIONS(2501),
    [anon_sym_default] = ACTIONS(2501),
    [anon_sym_while] = ACTIONS(2501),
    [anon_sym_do] = ACTIONS(2501),
    [anon_sym_for] = ACTIONS(2501),
    [anon_sym_return] = ACTIONS(2501),
    [anon_sym_break] = ACTIONS(2501),
    [anon_sym_continue] = ACTIONS(2501),
    [anon_sym_goto] = ACTIONS(2501),
    [anon_sym___try] = ACTIONS(2501),
    [anon_sym___leave] = ACTIONS(2501),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_compl] = ACTIONS(2501),
    [anon_sym_DASH_DASH] = ACTIONS(2503),
    [anon_sym_PLUS_PLUS] = ACTIONS(2503),
    [anon_sym_sizeof] = ACTIONS(2501),
    [anon_sym___alignof__] = ACTIONS(2501),
    [anon_sym___alignof] = ACTIONS(2501),
    [anon_sym__alignof] = ACTIONS(2501),
    [anon_sym_alignof] = ACTIONS(2501),
    [anon_sym__Alignof] = ACTIONS(2501),
    [anon_sym_offsetof] = ACTIONS(2501),
    [anon_sym__Generic] = ACTIONS(2501),
    [anon_sym_asm] = ACTIONS(2501),
    [anon_sym___asm__] = ACTIONS(2501),
    [anon_sym___asm] = ACTIONS(2501),
    [sym_number_literal] = ACTIONS(2503),
    [anon_sym_L_SQUOTE] = ACTIONS(2503),
    [anon_sym_u_SQUOTE] = ACTIONS(2503),
    [anon_sym_U_SQUOTE] = ACTIONS(2503),
    [anon_sym_u8_SQUOTE] = ACTIONS(2503),
    [anon_sym_SQUOTE] = ACTIONS(2503),
    [anon_sym_L_DQUOTE] = ACTIONS(2503),
    [anon_sym_u_DQUOTE] = ACTIONS(2503),
    [anon_sym_U_DQUOTE] = ACTIONS(2503),
    [anon_sym_u8_DQUOTE] = ACTIONS(2503),
    [anon_sym_DQUOTE] = ACTIONS(2503),
    [sym_true] = ACTIONS(2501),
    [sym_false] = ACTIONS(2501),
    [anon_sym_NULL] = ACTIONS(2501),
    [anon_sym_nullptr] = ACTIONS(2501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2501),
    [anon_sym_decltype] = ACTIONS(2501),
    [anon_sym_explicit] = ACTIONS(2501),
    [anon_sym_typename] = ACTIONS(2501),
    [anon_sym_template] = ACTIONS(2501),
    [anon_sym_operator] = ACTIONS(2501),
    [anon_sym_try] = ACTIONS(2501),
    [anon_sym_delete] = ACTIONS(2501),
    [anon_sym_throw] = ACTIONS(2501),
    [anon_sym_namespace] = ACTIONS(2501),
    [anon_sym_using] = ACTIONS(2501),
    [anon_sym_static_assert] = ACTIONS(2501),
    [anon_sym_concept] = ACTIONS(2501),
    [anon_sym_co_return] = ACTIONS(2501),
    [anon_sym_co_yield] = ACTIONS(2501),
    [anon_sym_R_DQUOTE] = ACTIONS(2503),
    [anon_sym_LR_DQUOTE] = ACTIONS(2503),
    [anon_sym_uR_DQUOTE] = ACTIONS(2503),
    [anon_sym_UR_DQUOTE] = ACTIONS(2503),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2503),
    [anon_sym_co_await] = ACTIONS(2501),
    [anon_sym_new] = ACTIONS(2501),
    [anon_sym_requires] = ACTIONS(2501),
    [sym_this] = ACTIONS(2501),
    [anon_sym___launch_bounds__] = ACTIONS(2501),
  },
  [STATE(515)] = {
    [sym_identifier] = ACTIONS(2509),
    [aux_sym_preproc_include_token1] = ACTIONS(2509),
    [aux_sym_preproc_def_token1] = ACTIONS(2509),
    [aux_sym_preproc_if_token1] = ACTIONS(2509),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2509),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2509),
    [sym_preproc_directive] = ACTIONS(2509),
    [anon_sym_LPAREN2] = ACTIONS(2511),
    [anon_sym_BANG] = ACTIONS(2511),
    [anon_sym_TILDE] = ACTIONS(2511),
    [anon_sym_DASH] = ACTIONS(2509),
    [anon_sym_PLUS] = ACTIONS(2509),
    [anon_sym_STAR] = ACTIONS(2511),
    [anon_sym_AMP_AMP] = ACTIONS(2511),
    [anon_sym_AMP] = ACTIONS(2509),
    [anon_sym_SEMI] = ACTIONS(2511),
    [anon_sym___extension__] = ACTIONS(2509),
    [anon_sym_typedef] = ACTIONS(2509),
    [anon_sym___device__] = ACTIONS(2509),
    [anon_sym___host__] = ACTIONS(2509),
    [anon_sym___global__] = ACTIONS(2509),
    [anon_sym___forceinline__] = ACTIONS(2509),
    [anon_sym___noinline__] = ACTIONS(2509),
    [anon_sym_virtual] = ACTIONS(2509),
    [anon_sym_extern] = ACTIONS(2509),
    [anon_sym___attribute__] = ACTIONS(2509),
    [anon_sym___attribute] = ACTIONS(2509),
    [anon_sym_COLON_COLON] = ACTIONS(2511),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2511),
    [anon_sym___declspec] = ACTIONS(2509),
    [anon_sym___based] = ACTIONS(2509),
    [anon_sym___cdecl] = ACTIONS(2509),
    [anon_sym___clrcall] = ACTIONS(2509),
    [anon_sym___stdcall] = ACTIONS(2509),
    [anon_sym___fastcall] = ACTIONS(2509),
    [anon_sym___thiscall] = ACTIONS(2509),
    [anon_sym___vectorcall] = ACTIONS(2509),
    [anon_sym_LBRACE] = ACTIONS(2511),
    [anon_sym_RBRACE] = ACTIONS(2511),
    [anon_sym_signed] = ACTIONS(2509),
    [anon_sym_unsigned] = ACTIONS(2509),
    [anon_sym_long] = ACTIONS(2509),
    [anon_sym_short] = ACTIONS(2509),
    [anon_sym_LBRACK] = ACTIONS(2509),
    [anon_sym_static] = ACTIONS(2509),
    [anon_sym_register] = ACTIONS(2509),
    [anon_sym_inline] = ACTIONS(2509),
    [anon_sym___inline] = ACTIONS(2509),
    [anon_sym___inline__] = ACTIONS(2509),
    [anon_sym___forceinline] = ACTIONS(2509),
    [anon_sym_thread_local] = ACTIONS(2509),
    [anon_sym___thread] = ACTIONS(2509),
    [anon_sym_const] = ACTIONS(2509),
    [anon_sym_constexpr] = ACTIONS(2509),
    [anon_sym_volatile] = ACTIONS(2509),
    [anon_sym_restrict] = ACTIONS(2509),
    [anon_sym___restrict__] = ACTIONS(2509),
    [anon_sym__Atomic] = ACTIONS(2509),
    [anon_sym__Noreturn] = ACTIONS(2509),
    [anon_sym_noreturn] = ACTIONS(2509),
    [anon_sym__Nonnull] = ACTIONS(2509),
    [anon_sym_mutable] = ACTIONS(2509),
    [anon_sym_constinit] = ACTIONS(2509),
    [anon_sym_consteval] = ACTIONS(2509),
    [anon_sym___shared__] = ACTIONS(2509),
    [anon_sym___local__] = ACTIONS(2509),
    [anon_sym___constant__] = ACTIONS(2509),
    [anon_sym___managed__] = ACTIONS(2509),
    [anon_sym___grid_constant__] = ACTIONS(2509),
    [anon_sym_alignas] = ACTIONS(2509),
    [anon_sym__Alignas] = ACTIONS(2509),
    [sym_primitive_type] = ACTIONS(2509),
    [anon_sym_enum] = ACTIONS(2509),
    [anon_sym_class] = ACTIONS(2509),
    [anon_sym_struct] = ACTIONS(2509),
    [anon_sym_union] = ACTIONS(2509),
    [anon_sym_if] = ACTIONS(2509),
    [anon_sym_switch] = ACTIONS(2509),
    [anon_sym_case] = ACTIONS(2509),
    [anon_sym_default] = ACTIONS(2509),
    [anon_sym_while] = ACTIONS(2509),
    [anon_sym_do] = ACTIONS(2509),
    [anon_sym_for] = ACTIONS(2509),
    [anon_sym_return] = ACTIONS(2509),
    [anon_sym_break] = ACTIONS(2509),
    [anon_sym_continue] = ACTIONS(2509),
    [anon_sym_goto] = ACTIONS(2509),
    [anon_sym___try] = ACTIONS(2509),
    [anon_sym___leave] = ACTIONS(2509),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_compl] = ACTIONS(2509),
    [anon_sym_DASH_DASH] = ACTIONS(2511),
    [anon_sym_PLUS_PLUS] = ACTIONS(2511),
    [anon_sym_sizeof] = ACTIONS(2509),
    [anon_sym___alignof__] = ACTIONS(2509),
    [anon_sym___alignof] = ACTIONS(2509),
    [anon_sym__alignof] = ACTIONS(2509),
    [anon_sym_alignof] = ACTIONS(2509),
    [anon_sym__Alignof] = ACTIONS(2509),
    [anon_sym_offsetof] = ACTIONS(2509),
    [anon_sym__Generic] = ACTIONS(2509),
    [anon_sym_asm] = ACTIONS(2509),
    [anon_sym___asm__] = ACTIONS(2509),
    [anon_sym___asm] = ACTIONS(2509),
    [sym_number_literal] = ACTIONS(2511),
    [anon_sym_L_SQUOTE] = ACTIONS(2511),
    [anon_sym_u_SQUOTE] = ACTIONS(2511),
    [anon_sym_U_SQUOTE] = ACTIONS(2511),
    [anon_sym_u8_SQUOTE] = ACTIONS(2511),
    [anon_sym_SQUOTE] = ACTIONS(2511),
    [anon_sym_L_DQUOTE] = ACTIONS(2511),
    [anon_sym_u_DQUOTE] = ACTIONS(2511),
    [anon_sym_U_DQUOTE] = ACTIONS(2511),
    [anon_sym_u8_DQUOTE] = ACTIONS(2511),
    [anon_sym_DQUOTE] = ACTIONS(2511),
    [sym_true] = ACTIONS(2509),
    [sym_false] = ACTIONS(2509),
    [anon_sym_NULL] = ACTIONS(2509),
    [anon_sym_nullptr] = ACTIONS(2509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2509),
    [anon_sym_decltype] = ACTIONS(2509),
    [anon_sym_explicit] = ACTIONS(2509),
    [anon_sym_typename] = ACTIONS(2509),
    [anon_sym_template] = ACTIONS(2509),
    [anon_sym_operator] = ACTIONS(2509),
    [anon_sym_try] = ACTIONS(2509),
    [anon_sym_delete] = ACTIONS(2509),
    [anon_sym_throw] = ACTIONS(2509),
    [anon_sym_namespace] = ACTIONS(2509),
    [anon_sym_using] = ACTIONS(2509),
    [anon_sym_static_assert] = ACTIONS(2509),
    [anon_sym_concept] = ACTIONS(2509),
    [anon_sym_co_return] = ACTIONS(2509),
    [anon_sym_co_yield] = ACTIONS(2509),
    [anon_sym_R_DQUOTE] = ACTIONS(2511),
    [anon_sym_LR_DQUOTE] = ACTIONS(2511),
    [anon_sym_uR_DQUOTE] = ACTIONS(2511),
    [anon_sym_UR_DQUOTE] = ACTIONS(2511),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2511),
    [anon_sym_co_await] = ACTIONS(2509),
    [anon_sym_new] = ACTIONS(2509),
    [anon_sym_requires] = ACTIONS(2509),
    [sym_this] = ACTIONS(2509),
    [anon_sym___launch_bounds__] = ACTIONS(2509),
  },
  [STATE(516)] = {
    [sym_identifier] = ACTIONS(2533),
    [aux_sym_preproc_include_token1] = ACTIONS(2533),
    [aux_sym_preproc_def_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2533),
    [sym_preproc_directive] = ACTIONS(2533),
    [anon_sym_LPAREN2] = ACTIONS(2535),
    [anon_sym_BANG] = ACTIONS(2535),
    [anon_sym_TILDE] = ACTIONS(2535),
    [anon_sym_DASH] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2535),
    [anon_sym_AMP_AMP] = ACTIONS(2535),
    [anon_sym_AMP] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym___extension__] = ACTIONS(2533),
    [anon_sym_typedef] = ACTIONS(2533),
    [anon_sym___device__] = ACTIONS(2533),
    [anon_sym___host__] = ACTIONS(2533),
    [anon_sym___global__] = ACTIONS(2533),
    [anon_sym___forceinline__] = ACTIONS(2533),
    [anon_sym___noinline__] = ACTIONS(2533),
    [anon_sym_virtual] = ACTIONS(2533),
    [anon_sym_extern] = ACTIONS(2533),
    [anon_sym___attribute__] = ACTIONS(2533),
    [anon_sym___attribute] = ACTIONS(2533),
    [anon_sym_COLON_COLON] = ACTIONS(2535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2535),
    [anon_sym___declspec] = ACTIONS(2533),
    [anon_sym___based] = ACTIONS(2533),
    [anon_sym___cdecl] = ACTIONS(2533),
    [anon_sym___clrcall] = ACTIONS(2533),
    [anon_sym___stdcall] = ACTIONS(2533),
    [anon_sym___fastcall] = ACTIONS(2533),
    [anon_sym___thiscall] = ACTIONS(2533),
    [anon_sym___vectorcall] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2535),
    [anon_sym_RBRACE] = ACTIONS(2535),
    [anon_sym_signed] = ACTIONS(2533),
    [anon_sym_unsigned] = ACTIONS(2533),
    [anon_sym_long] = ACTIONS(2533),
    [anon_sym_short] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2533),
    [anon_sym_static] = ACTIONS(2533),
    [anon_sym_register] = ACTIONS(2533),
    [anon_sym_inline] = ACTIONS(2533),
    [anon_sym___inline] = ACTIONS(2533),
    [anon_sym___inline__] = ACTIONS(2533),
    [anon_sym___forceinline] = ACTIONS(2533),
    [anon_sym_thread_local] = ACTIONS(2533),
    [anon_sym___thread] = ACTIONS(2533),
    [anon_sym_const] = ACTIONS(2533),
    [anon_sym_constexpr] = ACTIONS(2533),
    [anon_sym_volatile] = ACTIONS(2533),
    [anon_sym_restrict] = ACTIONS(2533),
    [anon_sym___restrict__] = ACTIONS(2533),
    [anon_sym__Atomic] = ACTIONS(2533),
    [anon_sym__Noreturn] = ACTIONS(2533),
    [anon_sym_noreturn] = ACTIONS(2533),
    [anon_sym__Nonnull] = ACTIONS(2533),
    [anon_sym_mutable] = ACTIONS(2533),
    [anon_sym_constinit] = ACTIONS(2533),
    [anon_sym_consteval] = ACTIONS(2533),
    [anon_sym___shared__] = ACTIONS(2533),
    [anon_sym___local__] = ACTIONS(2533),
    [anon_sym___constant__] = ACTIONS(2533),
    [anon_sym___managed__] = ACTIONS(2533),
    [anon_sym___grid_constant__] = ACTIONS(2533),
    [anon_sym_alignas] = ACTIONS(2533),
    [anon_sym__Alignas] = ACTIONS(2533),
    [sym_primitive_type] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_class] = ACTIONS(2533),
    [anon_sym_struct] = ACTIONS(2533),
    [anon_sym_union] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2533),
    [anon_sym_switch] = ACTIONS(2533),
    [anon_sym_case] = ACTIONS(2533),
    [anon_sym_default] = ACTIONS(2533),
    [anon_sym_while] = ACTIONS(2533),
    [anon_sym_do] = ACTIONS(2533),
    [anon_sym_for] = ACTIONS(2533),
    [anon_sym_return] = ACTIONS(2533),
    [anon_sym_break] = ACTIONS(2533),
    [anon_sym_continue] = ACTIONS(2533),
    [anon_sym_goto] = ACTIONS(2533),
    [anon_sym___try] = ACTIONS(2533),
    [anon_sym___leave] = ACTIONS(2533),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_compl] = ACTIONS(2533),
    [anon_sym_DASH_DASH] = ACTIONS(2535),
    [anon_sym_PLUS_PLUS] = ACTIONS(2535),
    [anon_sym_sizeof] = ACTIONS(2533),
    [anon_sym___alignof__] = ACTIONS(2533),
    [anon_sym___alignof] = ACTIONS(2533),
    [anon_sym__alignof] = ACTIONS(2533),
    [anon_sym_alignof] = ACTIONS(2533),
    [anon_sym__Alignof] = ACTIONS(2533),
    [anon_sym_offsetof] = ACTIONS(2533),
    [anon_sym__Generic] = ACTIONS(2533),
    [anon_sym_asm] = ACTIONS(2533),
    [anon_sym___asm__] = ACTIONS(2533),
    [anon_sym___asm] = ACTIONS(2533),
    [sym_number_literal] = ACTIONS(2535),
    [anon_sym_L_SQUOTE] = ACTIONS(2535),
    [anon_sym_u_SQUOTE] = ACTIONS(2535),
    [anon_sym_U_SQUOTE] = ACTIONS(2535),
    [anon_sym_u8_SQUOTE] = ACTIONS(2535),
    [anon_sym_SQUOTE] = ACTIONS(2535),
    [anon_sym_L_DQUOTE] = ACTIONS(2535),
    [anon_sym_u_DQUOTE] = ACTIONS(2535),
    [anon_sym_U_DQUOTE] = ACTIONS(2535),
    [anon_sym_u8_DQUOTE] = ACTIONS(2535),
    [anon_sym_DQUOTE] = ACTIONS(2535),
    [sym_true] = ACTIONS(2533),
    [sym_false] = ACTIONS(2533),
    [anon_sym_NULL] = ACTIONS(2533),
    [anon_sym_nullptr] = ACTIONS(2533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2533),
    [anon_sym_decltype] = ACTIONS(2533),
    [anon_sym_explicit] = ACTIONS(2533),
    [anon_sym_typename] = ACTIONS(2533),
    [anon_sym_template] = ACTIONS(2533),
    [anon_sym_operator] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2533),
    [anon_sym_delete] = ACTIONS(2533),
    [anon_sym_throw] = ACTIONS(2533),
    [anon_sym_namespace] = ACTIONS(2533),
    [anon_sym_using] = ACTIONS(2533),
    [anon_sym_static_assert] = ACTIONS(2533),
    [anon_sym_concept] = ACTIONS(2533),
    [anon_sym_co_return] = ACTIONS(2533),
    [anon_sym_co_yield] = ACTIONS(2533),
    [anon_sym_R_DQUOTE] = ACTIONS(2535),
    [anon_sym_LR_DQUOTE] = ACTIONS(2535),
    [anon_sym_uR_DQUOTE] = ACTIONS(2535),
    [anon_sym_UR_DQUOTE] = ACTIONS(2535),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2535),
    [anon_sym_co_await] = ACTIONS(2533),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_requires] = ACTIONS(2533),
    [sym_this] = ACTIONS(2533),
    [anon_sym___launch_bounds__] = ACTIONS(2533),
  },
  [STATE(517)] = {
    [sym_identifier] = ACTIONS(2509),
    [aux_sym_preproc_include_token1] = ACTIONS(2509),
    [aux_sym_preproc_def_token1] = ACTIONS(2509),
    [aux_sym_preproc_if_token1] = ACTIONS(2509),
    [aux_sym_preproc_if_token2] = ACTIONS(2509),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2509),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2509),
    [sym_preproc_directive] = ACTIONS(2509),
    [anon_sym_LPAREN2] = ACTIONS(2511),
    [anon_sym_BANG] = ACTIONS(2511),
    [anon_sym_TILDE] = ACTIONS(2511),
    [anon_sym_DASH] = ACTIONS(2509),
    [anon_sym_PLUS] = ACTIONS(2509),
    [anon_sym_STAR] = ACTIONS(2511),
    [anon_sym_AMP_AMP] = ACTIONS(2511),
    [anon_sym_AMP] = ACTIONS(2509),
    [anon_sym_SEMI] = ACTIONS(2511),
    [anon_sym___extension__] = ACTIONS(2509),
    [anon_sym_typedef] = ACTIONS(2509),
    [anon_sym___device__] = ACTIONS(2509),
    [anon_sym___host__] = ACTIONS(2509),
    [anon_sym___global__] = ACTIONS(2509),
    [anon_sym___forceinline__] = ACTIONS(2509),
    [anon_sym___noinline__] = ACTIONS(2509),
    [anon_sym_virtual] = ACTIONS(2509),
    [anon_sym_extern] = ACTIONS(2509),
    [anon_sym___attribute__] = ACTIONS(2509),
    [anon_sym___attribute] = ACTIONS(2509),
    [anon_sym_COLON_COLON] = ACTIONS(2511),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2511),
    [anon_sym___declspec] = ACTIONS(2509),
    [anon_sym___based] = ACTIONS(2509),
    [anon_sym___cdecl] = ACTIONS(2509),
    [anon_sym___clrcall] = ACTIONS(2509),
    [anon_sym___stdcall] = ACTIONS(2509),
    [anon_sym___fastcall] = ACTIONS(2509),
    [anon_sym___thiscall] = ACTIONS(2509),
    [anon_sym___vectorcall] = ACTIONS(2509),
    [anon_sym_LBRACE] = ACTIONS(2511),
    [anon_sym_signed] = ACTIONS(2509),
    [anon_sym_unsigned] = ACTIONS(2509),
    [anon_sym_long] = ACTIONS(2509),
    [anon_sym_short] = ACTIONS(2509),
    [anon_sym_LBRACK] = ACTIONS(2509),
    [anon_sym_static] = ACTIONS(2509),
    [anon_sym_register] = ACTIONS(2509),
    [anon_sym_inline] = ACTIONS(2509),
    [anon_sym___inline] = ACTIONS(2509),
    [anon_sym___inline__] = ACTIONS(2509),
    [anon_sym___forceinline] = ACTIONS(2509),
    [anon_sym_thread_local] = ACTIONS(2509),
    [anon_sym___thread] = ACTIONS(2509),
    [anon_sym_const] = ACTIONS(2509),
    [anon_sym_constexpr] = ACTIONS(2509),
    [anon_sym_volatile] = ACTIONS(2509),
    [anon_sym_restrict] = ACTIONS(2509),
    [anon_sym___restrict__] = ACTIONS(2509),
    [anon_sym__Atomic] = ACTIONS(2509),
    [anon_sym__Noreturn] = ACTIONS(2509),
    [anon_sym_noreturn] = ACTIONS(2509),
    [anon_sym__Nonnull] = ACTIONS(2509),
    [anon_sym_mutable] = ACTIONS(2509),
    [anon_sym_constinit] = ACTIONS(2509),
    [anon_sym_consteval] = ACTIONS(2509),
    [anon_sym___shared__] = ACTIONS(2509),
    [anon_sym___local__] = ACTIONS(2509),
    [anon_sym___constant__] = ACTIONS(2509),
    [anon_sym___managed__] = ACTIONS(2509),
    [anon_sym___grid_constant__] = ACTIONS(2509),
    [anon_sym_alignas] = ACTIONS(2509),
    [anon_sym__Alignas] = ACTIONS(2509),
    [sym_primitive_type] = ACTIONS(2509),
    [anon_sym_enum] = ACTIONS(2509),
    [anon_sym_class] = ACTIONS(2509),
    [anon_sym_struct] = ACTIONS(2509),
    [anon_sym_union] = ACTIONS(2509),
    [anon_sym_if] = ACTIONS(2509),
    [anon_sym_switch] = ACTIONS(2509),
    [anon_sym_case] = ACTIONS(2509),
    [anon_sym_default] = ACTIONS(2509),
    [anon_sym_while] = ACTIONS(2509),
    [anon_sym_do] = ACTIONS(2509),
    [anon_sym_for] = ACTIONS(2509),
    [anon_sym_return] = ACTIONS(2509),
    [anon_sym_break] = ACTIONS(2509),
    [anon_sym_continue] = ACTIONS(2509),
    [anon_sym_goto] = ACTIONS(2509),
    [anon_sym___try] = ACTIONS(2509),
    [anon_sym___leave] = ACTIONS(2509),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_compl] = ACTIONS(2509),
    [anon_sym_DASH_DASH] = ACTIONS(2511),
    [anon_sym_PLUS_PLUS] = ACTIONS(2511),
    [anon_sym_sizeof] = ACTIONS(2509),
    [anon_sym___alignof__] = ACTIONS(2509),
    [anon_sym___alignof] = ACTIONS(2509),
    [anon_sym__alignof] = ACTIONS(2509),
    [anon_sym_alignof] = ACTIONS(2509),
    [anon_sym__Alignof] = ACTIONS(2509),
    [anon_sym_offsetof] = ACTIONS(2509),
    [anon_sym__Generic] = ACTIONS(2509),
    [anon_sym_asm] = ACTIONS(2509),
    [anon_sym___asm__] = ACTIONS(2509),
    [anon_sym___asm] = ACTIONS(2509),
    [sym_number_literal] = ACTIONS(2511),
    [anon_sym_L_SQUOTE] = ACTIONS(2511),
    [anon_sym_u_SQUOTE] = ACTIONS(2511),
    [anon_sym_U_SQUOTE] = ACTIONS(2511),
    [anon_sym_u8_SQUOTE] = ACTIONS(2511),
    [anon_sym_SQUOTE] = ACTIONS(2511),
    [anon_sym_L_DQUOTE] = ACTIONS(2511),
    [anon_sym_u_DQUOTE] = ACTIONS(2511),
    [anon_sym_U_DQUOTE] = ACTIONS(2511),
    [anon_sym_u8_DQUOTE] = ACTIONS(2511),
    [anon_sym_DQUOTE] = ACTIONS(2511),
    [sym_true] = ACTIONS(2509),
    [sym_false] = ACTIONS(2509),
    [anon_sym_NULL] = ACTIONS(2509),
    [anon_sym_nullptr] = ACTIONS(2509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2509),
    [anon_sym_decltype] = ACTIONS(2509),
    [anon_sym_explicit] = ACTIONS(2509),
    [anon_sym_typename] = ACTIONS(2509),
    [anon_sym_template] = ACTIONS(2509),
    [anon_sym_operator] = ACTIONS(2509),
    [anon_sym_try] = ACTIONS(2509),
    [anon_sym_delete] = ACTIONS(2509),
    [anon_sym_throw] = ACTIONS(2509),
    [anon_sym_namespace] = ACTIONS(2509),
    [anon_sym_using] = ACTIONS(2509),
    [anon_sym_static_assert] = ACTIONS(2509),
    [anon_sym_concept] = ACTIONS(2509),
    [anon_sym_co_return] = ACTIONS(2509),
    [anon_sym_co_yield] = ACTIONS(2509),
    [anon_sym_R_DQUOTE] = ACTIONS(2511),
    [anon_sym_LR_DQUOTE] = ACTIONS(2511),
    [anon_sym_uR_DQUOTE] = ACTIONS(2511),
    [anon_sym_UR_DQUOTE] = ACTIONS(2511),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2511),
    [anon_sym_co_await] = ACTIONS(2509),
    [anon_sym_new] = ACTIONS(2509),
    [anon_sym_requires] = ACTIONS(2509),
    [sym_this] = ACTIONS(2509),
    [anon_sym___launch_bounds__] = ACTIONS(2509),
  },
  [STATE(518)] = {
    [sym_identifier] = ACTIONS(2529),
    [aux_sym_preproc_include_token1] = ACTIONS(2529),
    [aux_sym_preproc_def_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2529),
    [sym_preproc_directive] = ACTIONS(2529),
    [anon_sym_LPAREN2] = ACTIONS(2531),
    [anon_sym_BANG] = ACTIONS(2531),
    [anon_sym_TILDE] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2531),
    [anon_sym_AMP_AMP] = ACTIONS(2531),
    [anon_sym_AMP] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym___extension__] = ACTIONS(2529),
    [anon_sym_typedef] = ACTIONS(2529),
    [anon_sym___device__] = ACTIONS(2529),
    [anon_sym___host__] = ACTIONS(2529),
    [anon_sym___global__] = ACTIONS(2529),
    [anon_sym___forceinline__] = ACTIONS(2529),
    [anon_sym___noinline__] = ACTIONS(2529),
    [anon_sym_virtual] = ACTIONS(2529),
    [anon_sym_extern] = ACTIONS(2529),
    [anon_sym___attribute__] = ACTIONS(2529),
    [anon_sym___attribute] = ACTIONS(2529),
    [anon_sym_COLON_COLON] = ACTIONS(2531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2531),
    [anon_sym___declspec] = ACTIONS(2529),
    [anon_sym___based] = ACTIONS(2529),
    [anon_sym___cdecl] = ACTIONS(2529),
    [anon_sym___clrcall] = ACTIONS(2529),
    [anon_sym___stdcall] = ACTIONS(2529),
    [anon_sym___fastcall] = ACTIONS(2529),
    [anon_sym___thiscall] = ACTIONS(2529),
    [anon_sym___vectorcall] = ACTIONS(2529),
    [anon_sym_LBRACE] = ACTIONS(2531),
    [anon_sym_RBRACE] = ACTIONS(2531),
    [anon_sym_signed] = ACTIONS(2529),
    [anon_sym_unsigned] = ACTIONS(2529),
    [anon_sym_long] = ACTIONS(2529),
    [anon_sym_short] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2529),
    [anon_sym_register] = ACTIONS(2529),
    [anon_sym_inline] = ACTIONS(2529),
    [anon_sym___inline] = ACTIONS(2529),
    [anon_sym___inline__] = ACTIONS(2529),
    [anon_sym___forceinline] = ACTIONS(2529),
    [anon_sym_thread_local] = ACTIONS(2529),
    [anon_sym___thread] = ACTIONS(2529),
    [anon_sym_const] = ACTIONS(2529),
    [anon_sym_constexpr] = ACTIONS(2529),
    [anon_sym_volatile] = ACTIONS(2529),
    [anon_sym_restrict] = ACTIONS(2529),
    [anon_sym___restrict__] = ACTIONS(2529),
    [anon_sym__Atomic] = ACTIONS(2529),
    [anon_sym__Noreturn] = ACTIONS(2529),
    [anon_sym_noreturn] = ACTIONS(2529),
    [anon_sym__Nonnull] = ACTIONS(2529),
    [anon_sym_mutable] = ACTIONS(2529),
    [anon_sym_constinit] = ACTIONS(2529),
    [anon_sym_consteval] = ACTIONS(2529),
    [anon_sym___shared__] = ACTIONS(2529),
    [anon_sym___local__] = ACTIONS(2529),
    [anon_sym___constant__] = ACTIONS(2529),
    [anon_sym___managed__] = ACTIONS(2529),
    [anon_sym___grid_constant__] = ACTIONS(2529),
    [anon_sym_alignas] = ACTIONS(2529),
    [anon_sym__Alignas] = ACTIONS(2529),
    [sym_primitive_type] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2529),
    [anon_sym_struct] = ACTIONS(2529),
    [anon_sym_union] = ACTIONS(2529),
    [anon_sym_if] = ACTIONS(2529),
    [anon_sym_switch] = ACTIONS(2529),
    [anon_sym_case] = ACTIONS(2529),
    [anon_sym_default] = ACTIONS(2529),
    [anon_sym_while] = ACTIONS(2529),
    [anon_sym_do] = ACTIONS(2529),
    [anon_sym_for] = ACTIONS(2529),
    [anon_sym_return] = ACTIONS(2529),
    [anon_sym_break] = ACTIONS(2529),
    [anon_sym_continue] = ACTIONS(2529),
    [anon_sym_goto] = ACTIONS(2529),
    [anon_sym___try] = ACTIONS(2529),
    [anon_sym___leave] = ACTIONS(2529),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_compl] = ACTIONS(2529),
    [anon_sym_DASH_DASH] = ACTIONS(2531),
    [anon_sym_PLUS_PLUS] = ACTIONS(2531),
    [anon_sym_sizeof] = ACTIONS(2529),
    [anon_sym___alignof__] = ACTIONS(2529),
    [anon_sym___alignof] = ACTIONS(2529),
    [anon_sym__alignof] = ACTIONS(2529),
    [anon_sym_alignof] = ACTIONS(2529),
    [anon_sym__Alignof] = ACTIONS(2529),
    [anon_sym_offsetof] = ACTIONS(2529),
    [anon_sym__Generic] = ACTIONS(2529),
    [anon_sym_asm] = ACTIONS(2529),
    [anon_sym___asm__] = ACTIONS(2529),
    [anon_sym___asm] = ACTIONS(2529),
    [sym_number_literal] = ACTIONS(2531),
    [anon_sym_L_SQUOTE] = ACTIONS(2531),
    [anon_sym_u_SQUOTE] = ACTIONS(2531),
    [anon_sym_U_SQUOTE] = ACTIONS(2531),
    [anon_sym_u8_SQUOTE] = ACTIONS(2531),
    [anon_sym_SQUOTE] = ACTIONS(2531),
    [anon_sym_L_DQUOTE] = ACTIONS(2531),
    [anon_sym_u_DQUOTE] = ACTIONS(2531),
    [anon_sym_U_DQUOTE] = ACTIONS(2531),
    [anon_sym_u8_DQUOTE] = ACTIONS(2531),
    [anon_sym_DQUOTE] = ACTIONS(2531),
    [sym_true] = ACTIONS(2529),
    [sym_false] = ACTIONS(2529),
    [anon_sym_NULL] = ACTIONS(2529),
    [anon_sym_nullptr] = ACTIONS(2529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2529),
    [anon_sym_decltype] = ACTIONS(2529),
    [anon_sym_explicit] = ACTIONS(2529),
    [anon_sym_typename] = ACTIONS(2529),
    [anon_sym_template] = ACTIONS(2529),
    [anon_sym_operator] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2529),
    [anon_sym_delete] = ACTIONS(2529),
    [anon_sym_throw] = ACTIONS(2529),
    [anon_sym_namespace] = ACTIONS(2529),
    [anon_sym_using] = ACTIONS(2529),
    [anon_sym_static_assert] = ACTIONS(2529),
    [anon_sym_concept] = ACTIONS(2529),
    [anon_sym_co_return] = ACTIONS(2529),
    [anon_sym_co_yield] = ACTIONS(2529),
    [anon_sym_R_DQUOTE] = ACTIONS(2531),
    [anon_sym_LR_DQUOTE] = ACTIONS(2531),
    [anon_sym_uR_DQUOTE] = ACTIONS(2531),
    [anon_sym_UR_DQUOTE] = ACTIONS(2531),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2531),
    [anon_sym_co_await] = ACTIONS(2529),
    [anon_sym_new] = ACTIONS(2529),
    [anon_sym_requires] = ACTIONS(2529),
    [sym_this] = ACTIONS(2529),
    [anon_sym___launch_bounds__] = ACTIONS(2529),
  },
  [STATE(519)] = {
    [sym_identifier] = ACTIONS(2595),
    [aux_sym_preproc_include_token1] = ACTIONS(2595),
    [aux_sym_preproc_def_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token2] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2595),
    [sym_preproc_directive] = ACTIONS(2595),
    [anon_sym_LPAREN2] = ACTIONS(2597),
    [anon_sym_BANG] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_DASH] = ACTIONS(2595),
    [anon_sym_PLUS] = ACTIONS(2595),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_AMP_AMP] = ACTIONS(2597),
    [anon_sym_AMP] = ACTIONS(2595),
    [anon_sym_SEMI] = ACTIONS(2597),
    [anon_sym___extension__] = ACTIONS(2595),
    [anon_sym_typedef] = ACTIONS(2595),
    [anon_sym___device__] = ACTIONS(2595),
    [anon_sym___host__] = ACTIONS(2595),
    [anon_sym___global__] = ACTIONS(2595),
    [anon_sym___forceinline__] = ACTIONS(2595),
    [anon_sym___noinline__] = ACTIONS(2595),
    [anon_sym_virtual] = ACTIONS(2595),
    [anon_sym_extern] = ACTIONS(2595),
    [anon_sym___attribute__] = ACTIONS(2595),
    [anon_sym___attribute] = ACTIONS(2595),
    [anon_sym_COLON_COLON] = ACTIONS(2597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2597),
    [anon_sym___declspec] = ACTIONS(2595),
    [anon_sym___based] = ACTIONS(2595),
    [anon_sym___cdecl] = ACTIONS(2595),
    [anon_sym___clrcall] = ACTIONS(2595),
    [anon_sym___stdcall] = ACTIONS(2595),
    [anon_sym___fastcall] = ACTIONS(2595),
    [anon_sym___thiscall] = ACTIONS(2595),
    [anon_sym___vectorcall] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_signed] = ACTIONS(2595),
    [anon_sym_unsigned] = ACTIONS(2595),
    [anon_sym_long] = ACTIONS(2595),
    [anon_sym_short] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_register] = ACTIONS(2595),
    [anon_sym_inline] = ACTIONS(2595),
    [anon_sym___inline] = ACTIONS(2595),
    [anon_sym___inline__] = ACTIONS(2595),
    [anon_sym___forceinline] = ACTIONS(2595),
    [anon_sym_thread_local] = ACTIONS(2595),
    [anon_sym___thread] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_constexpr] = ACTIONS(2595),
    [anon_sym_volatile] = ACTIONS(2595),
    [anon_sym_restrict] = ACTIONS(2595),
    [anon_sym___restrict__] = ACTIONS(2595),
    [anon_sym__Atomic] = ACTIONS(2595),
    [anon_sym__Noreturn] = ACTIONS(2595),
    [anon_sym_noreturn] = ACTIONS(2595),
    [anon_sym__Nonnull] = ACTIONS(2595),
    [anon_sym_mutable] = ACTIONS(2595),
    [anon_sym_constinit] = ACTIONS(2595),
    [anon_sym_consteval] = ACTIONS(2595),
    [anon_sym___shared__] = ACTIONS(2595),
    [anon_sym___local__] = ACTIONS(2595),
    [anon_sym___constant__] = ACTIONS(2595),
    [anon_sym___managed__] = ACTIONS(2595),
    [anon_sym___grid_constant__] = ACTIONS(2595),
    [anon_sym_alignas] = ACTIONS(2595),
    [anon_sym__Alignas] = ACTIONS(2595),
    [sym_primitive_type] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_struct] = ACTIONS(2595),
    [anon_sym_union] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2595),
    [anon_sym_switch] = ACTIONS(2595),
    [anon_sym_case] = ACTIONS(2595),
    [anon_sym_default] = ACTIONS(2595),
    [anon_sym_while] = ACTIONS(2595),
    [anon_sym_do] = ACTIONS(2595),
    [anon_sym_for] = ACTIONS(2595),
    [anon_sym_return] = ACTIONS(2595),
    [anon_sym_break] = ACTIONS(2595),
    [anon_sym_continue] = ACTIONS(2595),
    [anon_sym_goto] = ACTIONS(2595),
    [anon_sym___try] = ACTIONS(2595),
    [anon_sym___leave] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2595),
    [anon_sym_compl] = ACTIONS(2595),
    [anon_sym_DASH_DASH] = ACTIONS(2597),
    [anon_sym_PLUS_PLUS] = ACTIONS(2597),
    [anon_sym_sizeof] = ACTIONS(2595),
    [anon_sym___alignof__] = ACTIONS(2595),
    [anon_sym___alignof] = ACTIONS(2595),
    [anon_sym__alignof] = ACTIONS(2595),
    [anon_sym_alignof] = ACTIONS(2595),
    [anon_sym__Alignof] = ACTIONS(2595),
    [anon_sym_offsetof] = ACTIONS(2595),
    [anon_sym__Generic] = ACTIONS(2595),
    [anon_sym_asm] = ACTIONS(2595),
    [anon_sym___asm__] = ACTIONS(2595),
    [anon_sym___asm] = ACTIONS(2595),
    [sym_number_literal] = ACTIONS(2597),
    [anon_sym_L_SQUOTE] = ACTIONS(2597),
    [anon_sym_u_SQUOTE] = ACTIONS(2597),
    [anon_sym_U_SQUOTE] = ACTIONS(2597),
    [anon_sym_u8_SQUOTE] = ACTIONS(2597),
    [anon_sym_SQUOTE] = ACTIONS(2597),
    [anon_sym_L_DQUOTE] = ACTIONS(2597),
    [anon_sym_u_DQUOTE] = ACTIONS(2597),
    [anon_sym_U_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8_DQUOTE] = ACTIONS(2597),
    [anon_sym_DQUOTE] = ACTIONS(2597),
    [sym_true] = ACTIONS(2595),
    [sym_false] = ACTIONS(2595),
    [anon_sym_NULL] = ACTIONS(2595),
    [anon_sym_nullptr] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2595),
    [anon_sym_decltype] = ACTIONS(2595),
    [anon_sym_explicit] = ACTIONS(2595),
    [anon_sym_typename] = ACTIONS(2595),
    [anon_sym_template] = ACTIONS(2595),
    [anon_sym_operator] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2595),
    [anon_sym_delete] = ACTIONS(2595),
    [anon_sym_throw] = ACTIONS(2595),
    [anon_sym_namespace] = ACTIONS(2595),
    [anon_sym_using] = ACTIONS(2595),
    [anon_sym_static_assert] = ACTIONS(2595),
    [anon_sym_concept] = ACTIONS(2595),
    [anon_sym_co_return] = ACTIONS(2595),
    [anon_sym_co_yield] = ACTIONS(2595),
    [anon_sym_R_DQUOTE] = ACTIONS(2597),
    [anon_sym_LR_DQUOTE] = ACTIONS(2597),
    [anon_sym_uR_DQUOTE] = ACTIONS(2597),
    [anon_sym_UR_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2597),
    [anon_sym_co_await] = ACTIONS(2595),
    [anon_sym_new] = ACTIONS(2595),
    [anon_sym_requires] = ACTIONS(2595),
    [sym_this] = ACTIONS(2595),
    [anon_sym___launch_bounds__] = ACTIONS(2595),
  },
  [STATE(520)] = {
    [sym_identifier] = ACTIONS(2591),
    [aux_sym_preproc_include_token1] = ACTIONS(2591),
    [aux_sym_preproc_def_token1] = ACTIONS(2591),
    [aux_sym_preproc_if_token1] = ACTIONS(2591),
    [aux_sym_preproc_if_token2] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [sym_preproc_directive] = ACTIONS(2591),
    [anon_sym_LPAREN2] = ACTIONS(2593),
    [anon_sym_BANG] = ACTIONS(2593),
    [anon_sym_TILDE] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2591),
    [anon_sym_PLUS] = ACTIONS(2591),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_AMP_AMP] = ACTIONS(2593),
    [anon_sym_AMP] = ACTIONS(2591),
    [anon_sym_SEMI] = ACTIONS(2593),
    [anon_sym___extension__] = ACTIONS(2591),
    [anon_sym_typedef] = ACTIONS(2591),
    [anon_sym___device__] = ACTIONS(2591),
    [anon_sym___host__] = ACTIONS(2591),
    [anon_sym___global__] = ACTIONS(2591),
    [anon_sym___forceinline__] = ACTIONS(2591),
    [anon_sym___noinline__] = ACTIONS(2591),
    [anon_sym_virtual] = ACTIONS(2591),
    [anon_sym_extern] = ACTIONS(2591),
    [anon_sym___attribute__] = ACTIONS(2591),
    [anon_sym___attribute] = ACTIONS(2591),
    [anon_sym_COLON_COLON] = ACTIONS(2593),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2593),
    [anon_sym___declspec] = ACTIONS(2591),
    [anon_sym___based] = ACTIONS(2591),
    [anon_sym___cdecl] = ACTIONS(2591),
    [anon_sym___clrcall] = ACTIONS(2591),
    [anon_sym___stdcall] = ACTIONS(2591),
    [anon_sym___fastcall] = ACTIONS(2591),
    [anon_sym___thiscall] = ACTIONS(2591),
    [anon_sym___vectorcall] = ACTIONS(2591),
    [anon_sym_LBRACE] = ACTIONS(2593),
    [anon_sym_signed] = ACTIONS(2591),
    [anon_sym_unsigned] = ACTIONS(2591),
    [anon_sym_long] = ACTIONS(2591),
    [anon_sym_short] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [anon_sym_static] = ACTIONS(2591),
    [anon_sym_register] = ACTIONS(2591),
    [anon_sym_inline] = ACTIONS(2591),
    [anon_sym___inline] = ACTIONS(2591),
    [anon_sym___inline__] = ACTIONS(2591),
    [anon_sym___forceinline] = ACTIONS(2591),
    [anon_sym_thread_local] = ACTIONS(2591),
    [anon_sym___thread] = ACTIONS(2591),
    [anon_sym_const] = ACTIONS(2591),
    [anon_sym_constexpr] = ACTIONS(2591),
    [anon_sym_volatile] = ACTIONS(2591),
    [anon_sym_restrict] = ACTIONS(2591),
    [anon_sym___restrict__] = ACTIONS(2591),
    [anon_sym__Atomic] = ACTIONS(2591),
    [anon_sym__Noreturn] = ACTIONS(2591),
    [anon_sym_noreturn] = ACTIONS(2591),
    [anon_sym__Nonnull] = ACTIONS(2591),
    [anon_sym_mutable] = ACTIONS(2591),
    [anon_sym_constinit] = ACTIONS(2591),
    [anon_sym_consteval] = ACTIONS(2591),
    [anon_sym___shared__] = ACTIONS(2591),
    [anon_sym___local__] = ACTIONS(2591),
    [anon_sym___constant__] = ACTIONS(2591),
    [anon_sym___managed__] = ACTIONS(2591),
    [anon_sym___grid_constant__] = ACTIONS(2591),
    [anon_sym_alignas] = ACTIONS(2591),
    [anon_sym__Alignas] = ACTIONS(2591),
    [sym_primitive_type] = ACTIONS(2591),
    [anon_sym_enum] = ACTIONS(2591),
    [anon_sym_class] = ACTIONS(2591),
    [anon_sym_struct] = ACTIONS(2591),
    [anon_sym_union] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_switch] = ACTIONS(2591),
    [anon_sym_case] = ACTIONS(2591),
    [anon_sym_default] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(2591),
    [anon_sym_do] = ACTIONS(2591),
    [anon_sym_for] = ACTIONS(2591),
    [anon_sym_return] = ACTIONS(2591),
    [anon_sym_break] = ACTIONS(2591),
    [anon_sym_continue] = ACTIONS(2591),
    [anon_sym_goto] = ACTIONS(2591),
    [anon_sym___try] = ACTIONS(2591),
    [anon_sym___leave] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_compl] = ACTIONS(2591),
    [anon_sym_DASH_DASH] = ACTIONS(2593),
    [anon_sym_PLUS_PLUS] = ACTIONS(2593),
    [anon_sym_sizeof] = ACTIONS(2591),
    [anon_sym___alignof__] = ACTIONS(2591),
    [anon_sym___alignof] = ACTIONS(2591),
    [anon_sym__alignof] = ACTIONS(2591),
    [anon_sym_alignof] = ACTIONS(2591),
    [anon_sym__Alignof] = ACTIONS(2591),
    [anon_sym_offsetof] = ACTIONS(2591),
    [anon_sym__Generic] = ACTIONS(2591),
    [anon_sym_asm] = ACTIONS(2591),
    [anon_sym___asm__] = ACTIONS(2591),
    [anon_sym___asm] = ACTIONS(2591),
    [sym_number_literal] = ACTIONS(2593),
    [anon_sym_L_SQUOTE] = ACTIONS(2593),
    [anon_sym_u_SQUOTE] = ACTIONS(2593),
    [anon_sym_U_SQUOTE] = ACTIONS(2593),
    [anon_sym_u8_SQUOTE] = ACTIONS(2593),
    [anon_sym_SQUOTE] = ACTIONS(2593),
    [anon_sym_L_DQUOTE] = ACTIONS(2593),
    [anon_sym_u_DQUOTE] = ACTIONS(2593),
    [anon_sym_U_DQUOTE] = ACTIONS(2593),
    [anon_sym_u8_DQUOTE] = ACTIONS(2593),
    [anon_sym_DQUOTE] = ACTIONS(2593),
    [sym_true] = ACTIONS(2591),
    [sym_false] = ACTIONS(2591),
    [anon_sym_NULL] = ACTIONS(2591),
    [anon_sym_nullptr] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2591),
    [anon_sym_decltype] = ACTIONS(2591),
    [anon_sym_explicit] = ACTIONS(2591),
    [anon_sym_typename] = ACTIONS(2591),
    [anon_sym_template] = ACTIONS(2591),
    [anon_sym_operator] = ACTIONS(2591),
    [anon_sym_try] = ACTIONS(2591),
    [anon_sym_delete] = ACTIONS(2591),
    [anon_sym_throw] = ACTIONS(2591),
    [anon_sym_namespace] = ACTIONS(2591),
    [anon_sym_using] = ACTIONS(2591),
    [anon_sym_static_assert] = ACTIONS(2591),
    [anon_sym_concept] = ACTIONS(2591),
    [anon_sym_co_return] = ACTIONS(2591),
    [anon_sym_co_yield] = ACTIONS(2591),
    [anon_sym_R_DQUOTE] = ACTIONS(2593),
    [anon_sym_LR_DQUOTE] = ACTIONS(2593),
    [anon_sym_uR_DQUOTE] = ACTIONS(2593),
    [anon_sym_UR_DQUOTE] = ACTIONS(2593),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2593),
    [anon_sym_co_await] = ACTIONS(2591),
    [anon_sym_new] = ACTIONS(2591),
    [anon_sym_requires] = ACTIONS(2591),
    [sym_this] = ACTIONS(2591),
    [anon_sym___launch_bounds__] = ACTIONS(2591),
  },
  [STATE(521)] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_include_token1] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token2] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2385),
    [anon_sym_BANG] = ACTIONS(2385),
    [anon_sym_TILDE] = ACTIONS(2385),
    [anon_sym_DASH] = ACTIONS(2383),
    [anon_sym_PLUS] = ACTIONS(2383),
    [anon_sym_STAR] = ACTIONS(2385),
    [anon_sym_AMP_AMP] = ACTIONS(2385),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym___device__] = ACTIONS(2383),
    [anon_sym___host__] = ACTIONS(2383),
    [anon_sym___global__] = ACTIONS(2383),
    [anon_sym___forceinline__] = ACTIONS(2383),
    [anon_sym___noinline__] = ACTIONS(2383),
    [anon_sym_virtual] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym___attribute] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2385),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2385),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym___cdecl] = ACTIONS(2383),
    [anon_sym___clrcall] = ACTIONS(2383),
    [anon_sym___stdcall] = ACTIONS(2383),
    [anon_sym___fastcall] = ACTIONS(2383),
    [anon_sym___thiscall] = ACTIONS(2383),
    [anon_sym___vectorcall] = ACTIONS(2383),
    [anon_sym_LBRACE] = ACTIONS(2385),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym__Nonnull] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym___shared__] = ACTIONS(2383),
    [anon_sym___local__] = ACTIONS(2383),
    [anon_sym___constant__] = ACTIONS(2383),
    [anon_sym___managed__] = ACTIONS(2383),
    [anon_sym___grid_constant__] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [anon_sym_if] = ACTIONS(2383),
    [anon_sym_switch] = ACTIONS(2383),
    [anon_sym_case] = ACTIONS(2383),
    [anon_sym_default] = ACTIONS(2383),
    [anon_sym_while] = ACTIONS(2383),
    [anon_sym_do] = ACTIONS(2383),
    [anon_sym_for] = ACTIONS(2383),
    [anon_sym_return] = ACTIONS(2383),
    [anon_sym_break] = ACTIONS(2383),
    [anon_sym_continue] = ACTIONS(2383),
    [anon_sym_goto] = ACTIONS(2383),
    [anon_sym___try] = ACTIONS(2383),
    [anon_sym___leave] = ACTIONS(2383),
    [anon_sym_not] = ACTIONS(2383),
    [anon_sym_compl] = ACTIONS(2383),
    [anon_sym_DASH_DASH] = ACTIONS(2385),
    [anon_sym_PLUS_PLUS] = ACTIONS(2385),
    [anon_sym_sizeof] = ACTIONS(2383),
    [anon_sym___alignof__] = ACTIONS(2383),
    [anon_sym___alignof] = ACTIONS(2383),
    [anon_sym__alignof] = ACTIONS(2383),
    [anon_sym_alignof] = ACTIONS(2383),
    [anon_sym__Alignof] = ACTIONS(2383),
    [anon_sym_offsetof] = ACTIONS(2383),
    [anon_sym__Generic] = ACTIONS(2383),
    [anon_sym_asm] = ACTIONS(2383),
    [anon_sym___asm__] = ACTIONS(2383),
    [anon_sym___asm] = ACTIONS(2383),
    [sym_number_literal] = ACTIONS(2385),
    [anon_sym_L_SQUOTE] = ACTIONS(2385),
    [anon_sym_u_SQUOTE] = ACTIONS(2385),
    [anon_sym_U_SQUOTE] = ACTIONS(2385),
    [anon_sym_u8_SQUOTE] = ACTIONS(2385),
    [anon_sym_SQUOTE] = ACTIONS(2385),
    [anon_sym_L_DQUOTE] = ACTIONS(2385),
    [anon_sym_u_DQUOTE] = ACTIONS(2385),
    [anon_sym_U_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8_DQUOTE] = ACTIONS(2385),
    [anon_sym_DQUOTE] = ACTIONS(2385),
    [sym_true] = ACTIONS(2383),
    [sym_false] = ACTIONS(2383),
    [anon_sym_NULL] = ACTIONS(2383),
    [anon_sym_nullptr] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_try] = ACTIONS(2383),
    [anon_sym_delete] = ACTIONS(2383),
    [anon_sym_throw] = ACTIONS(2383),
    [anon_sym_namespace] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym_concept] = ACTIONS(2383),
    [anon_sym_co_return] = ACTIONS(2383),
    [anon_sym_co_yield] = ACTIONS(2383),
    [anon_sym_R_DQUOTE] = ACTIONS(2385),
    [anon_sym_LR_DQUOTE] = ACTIONS(2385),
    [anon_sym_uR_DQUOTE] = ACTIONS(2385),
    [anon_sym_UR_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2385),
    [anon_sym_co_await] = ACTIONS(2383),
    [anon_sym_new] = ACTIONS(2383),
    [anon_sym_requires] = ACTIONS(2383),
    [sym_this] = ACTIONS(2383),
    [anon_sym___launch_bounds__] = ACTIONS(2383),
  },
  [STATE(522)] = {
    [sym_identifier] = ACTIONS(2599),
    [aux_sym_preproc_include_token1] = ACTIONS(2599),
    [aux_sym_preproc_def_token1] = ACTIONS(2599),
    [aux_sym_preproc_if_token1] = ACTIONS(2599),
    [aux_sym_preproc_if_token2] = ACTIONS(2599),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2599),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2599),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_BANG] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2601),
    [anon_sym_DASH] = ACTIONS(2599),
    [anon_sym_PLUS] = ACTIONS(2599),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_AMP_AMP] = ACTIONS(2601),
    [anon_sym_AMP] = ACTIONS(2599),
    [anon_sym_SEMI] = ACTIONS(2601),
    [anon_sym___extension__] = ACTIONS(2599),
    [anon_sym_typedef] = ACTIONS(2599),
    [anon_sym___device__] = ACTIONS(2599),
    [anon_sym___host__] = ACTIONS(2599),
    [anon_sym___global__] = ACTIONS(2599),
    [anon_sym___forceinline__] = ACTIONS(2599),
    [anon_sym___noinline__] = ACTIONS(2599),
    [anon_sym_virtual] = ACTIONS(2599),
    [anon_sym_extern] = ACTIONS(2599),
    [anon_sym___attribute__] = ACTIONS(2599),
    [anon_sym___attribute] = ACTIONS(2599),
    [anon_sym_COLON_COLON] = ACTIONS(2601),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2601),
    [anon_sym___declspec] = ACTIONS(2599),
    [anon_sym___based] = ACTIONS(2599),
    [anon_sym___cdecl] = ACTIONS(2599),
    [anon_sym___clrcall] = ACTIONS(2599),
    [anon_sym___stdcall] = ACTIONS(2599),
    [anon_sym___fastcall] = ACTIONS(2599),
    [anon_sym___thiscall] = ACTIONS(2599),
    [anon_sym___vectorcall] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(2601),
    [anon_sym_signed] = ACTIONS(2599),
    [anon_sym_unsigned] = ACTIONS(2599),
    [anon_sym_long] = ACTIONS(2599),
    [anon_sym_short] = ACTIONS(2599),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [anon_sym_static] = ACTIONS(2599),
    [anon_sym_register] = ACTIONS(2599),
    [anon_sym_inline] = ACTIONS(2599),
    [anon_sym___inline] = ACTIONS(2599),
    [anon_sym___inline__] = ACTIONS(2599),
    [anon_sym___forceinline] = ACTIONS(2599),
    [anon_sym_thread_local] = ACTIONS(2599),
    [anon_sym___thread] = ACTIONS(2599),
    [anon_sym_const] = ACTIONS(2599),
    [anon_sym_constexpr] = ACTIONS(2599),
    [anon_sym_volatile] = ACTIONS(2599),
    [anon_sym_restrict] = ACTIONS(2599),
    [anon_sym___restrict__] = ACTIONS(2599),
    [anon_sym__Atomic] = ACTIONS(2599),
    [anon_sym__Noreturn] = ACTIONS(2599),
    [anon_sym_noreturn] = ACTIONS(2599),
    [anon_sym__Nonnull] = ACTIONS(2599),
    [anon_sym_mutable] = ACTIONS(2599),
    [anon_sym_constinit] = ACTIONS(2599),
    [anon_sym_consteval] = ACTIONS(2599),
    [anon_sym___shared__] = ACTIONS(2599),
    [anon_sym___local__] = ACTIONS(2599),
    [anon_sym___constant__] = ACTIONS(2599),
    [anon_sym___managed__] = ACTIONS(2599),
    [anon_sym___grid_constant__] = ACTIONS(2599),
    [anon_sym_alignas] = ACTIONS(2599),
    [anon_sym__Alignas] = ACTIONS(2599),
    [sym_primitive_type] = ACTIONS(2599),
    [anon_sym_enum] = ACTIONS(2599),
    [anon_sym_class] = ACTIONS(2599),
    [anon_sym_struct] = ACTIONS(2599),
    [anon_sym_union] = ACTIONS(2599),
    [anon_sym_if] = ACTIONS(2599),
    [anon_sym_switch] = ACTIONS(2599),
    [anon_sym_case] = ACTIONS(2599),
    [anon_sym_default] = ACTIONS(2599),
    [anon_sym_while] = ACTIONS(2599),
    [anon_sym_do] = ACTIONS(2599),
    [anon_sym_for] = ACTIONS(2599),
    [anon_sym_return] = ACTIONS(2599),
    [anon_sym_break] = ACTIONS(2599),
    [anon_sym_continue] = ACTIONS(2599),
    [anon_sym_goto] = ACTIONS(2599),
    [anon_sym___try] = ACTIONS(2599),
    [anon_sym___leave] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2599),
    [anon_sym_compl] = ACTIONS(2599),
    [anon_sym_DASH_DASH] = ACTIONS(2601),
    [anon_sym_PLUS_PLUS] = ACTIONS(2601),
    [anon_sym_sizeof] = ACTIONS(2599),
    [anon_sym___alignof__] = ACTIONS(2599),
    [anon_sym___alignof] = ACTIONS(2599),
    [anon_sym__alignof] = ACTIONS(2599),
    [anon_sym_alignof] = ACTIONS(2599),
    [anon_sym__Alignof] = ACTIONS(2599),
    [anon_sym_offsetof] = ACTIONS(2599),
    [anon_sym__Generic] = ACTIONS(2599),
    [anon_sym_asm] = ACTIONS(2599),
    [anon_sym___asm__] = ACTIONS(2599),
    [anon_sym___asm] = ACTIONS(2599),
    [sym_number_literal] = ACTIONS(2601),
    [anon_sym_L_SQUOTE] = ACTIONS(2601),
    [anon_sym_u_SQUOTE] = ACTIONS(2601),
    [anon_sym_U_SQUOTE] = ACTIONS(2601),
    [anon_sym_u8_SQUOTE] = ACTIONS(2601),
    [anon_sym_SQUOTE] = ACTIONS(2601),
    [anon_sym_L_DQUOTE] = ACTIONS(2601),
    [anon_sym_u_DQUOTE] = ACTIONS(2601),
    [anon_sym_U_DQUOTE] = ACTIONS(2601),
    [anon_sym_u8_DQUOTE] = ACTIONS(2601),
    [anon_sym_DQUOTE] = ACTIONS(2601),
    [sym_true] = ACTIONS(2599),
    [sym_false] = ACTIONS(2599),
    [anon_sym_NULL] = ACTIONS(2599),
    [anon_sym_nullptr] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2599),
    [anon_sym_decltype] = ACTIONS(2599),
    [anon_sym_explicit] = ACTIONS(2599),
    [anon_sym_typename] = ACTIONS(2599),
    [anon_sym_template] = ACTIONS(2599),
    [anon_sym_operator] = ACTIONS(2599),
    [anon_sym_try] = ACTIONS(2599),
    [anon_sym_delete] = ACTIONS(2599),
    [anon_sym_throw] = ACTIONS(2599),
    [anon_sym_namespace] = ACTIONS(2599),
    [anon_sym_using] = ACTIONS(2599),
    [anon_sym_static_assert] = ACTIONS(2599),
    [anon_sym_concept] = ACTIONS(2599),
    [anon_sym_co_return] = ACTIONS(2599),
    [anon_sym_co_yield] = ACTIONS(2599),
    [anon_sym_R_DQUOTE] = ACTIONS(2601),
    [anon_sym_LR_DQUOTE] = ACTIONS(2601),
    [anon_sym_uR_DQUOTE] = ACTIONS(2601),
    [anon_sym_UR_DQUOTE] = ACTIONS(2601),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2601),
    [anon_sym_co_await] = ACTIONS(2599),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_requires] = ACTIONS(2599),
    [sym_this] = ACTIONS(2599),
    [anon_sym___launch_bounds__] = ACTIONS(2599),
  },
  [STATE(523)] = {
    [sym_identifier] = ACTIONS(2609),
    [aux_sym_preproc_include_token1] = ACTIONS(2609),
    [aux_sym_preproc_def_token1] = ACTIONS(2609),
    [aux_sym_preproc_if_token1] = ACTIONS(2609),
    [aux_sym_preproc_if_token2] = ACTIONS(2609),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2609),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2609),
    [sym_preproc_directive] = ACTIONS(2609),
    [anon_sym_LPAREN2] = ACTIONS(2611),
    [anon_sym_BANG] = ACTIONS(2611),
    [anon_sym_TILDE] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2611),
    [anon_sym_AMP_AMP] = ACTIONS(2611),
    [anon_sym_AMP] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2609),
    [anon_sym___device__] = ACTIONS(2609),
    [anon_sym___host__] = ACTIONS(2609),
    [anon_sym___global__] = ACTIONS(2609),
    [anon_sym___forceinline__] = ACTIONS(2609),
    [anon_sym___noinline__] = ACTIONS(2609),
    [anon_sym_virtual] = ACTIONS(2609),
    [anon_sym_extern] = ACTIONS(2609),
    [anon_sym___attribute__] = ACTIONS(2609),
    [anon_sym___attribute] = ACTIONS(2609),
    [anon_sym_COLON_COLON] = ACTIONS(2611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2611),
    [anon_sym___declspec] = ACTIONS(2609),
    [anon_sym___based] = ACTIONS(2609),
    [anon_sym___cdecl] = ACTIONS(2609),
    [anon_sym___clrcall] = ACTIONS(2609),
    [anon_sym___stdcall] = ACTIONS(2609),
    [anon_sym___fastcall] = ACTIONS(2609),
    [anon_sym___thiscall] = ACTIONS(2609),
    [anon_sym___vectorcall] = ACTIONS(2609),
    [anon_sym_LBRACE] = ACTIONS(2611),
    [anon_sym_signed] = ACTIONS(2609),
    [anon_sym_unsigned] = ACTIONS(2609),
    [anon_sym_long] = ACTIONS(2609),
    [anon_sym_short] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2609),
    [anon_sym_static] = ACTIONS(2609),
    [anon_sym_register] = ACTIONS(2609),
    [anon_sym_inline] = ACTIONS(2609),
    [anon_sym___inline] = ACTIONS(2609),
    [anon_sym___inline__] = ACTIONS(2609),
    [anon_sym___forceinline] = ACTIONS(2609),
    [anon_sym_thread_local] = ACTIONS(2609),
    [anon_sym___thread] = ACTIONS(2609),
    [anon_sym_const] = ACTIONS(2609),
    [anon_sym_constexpr] = ACTIONS(2609),
    [anon_sym_volatile] = ACTIONS(2609),
    [anon_sym_restrict] = ACTIONS(2609),
    [anon_sym___restrict__] = ACTIONS(2609),
    [anon_sym__Atomic] = ACTIONS(2609),
    [anon_sym__Noreturn] = ACTIONS(2609),
    [anon_sym_noreturn] = ACTIONS(2609),
    [anon_sym__Nonnull] = ACTIONS(2609),
    [anon_sym_mutable] = ACTIONS(2609),
    [anon_sym_constinit] = ACTIONS(2609),
    [anon_sym_consteval] = ACTIONS(2609),
    [anon_sym___shared__] = ACTIONS(2609),
    [anon_sym___local__] = ACTIONS(2609),
    [anon_sym___constant__] = ACTIONS(2609),
    [anon_sym___managed__] = ACTIONS(2609),
    [anon_sym___grid_constant__] = ACTIONS(2609),
    [anon_sym_alignas] = ACTIONS(2609),
    [anon_sym__Alignas] = ACTIONS(2609),
    [sym_primitive_type] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_class] = ACTIONS(2609),
    [anon_sym_struct] = ACTIONS(2609),
    [anon_sym_union] = ACTIONS(2609),
    [anon_sym_if] = ACTIONS(2609),
    [anon_sym_switch] = ACTIONS(2609),
    [anon_sym_case] = ACTIONS(2609),
    [anon_sym_default] = ACTIONS(2609),
    [anon_sym_while] = ACTIONS(2609),
    [anon_sym_do] = ACTIONS(2609),
    [anon_sym_for] = ACTIONS(2609),
    [anon_sym_return] = ACTIONS(2609),
    [anon_sym_break] = ACTIONS(2609),
    [anon_sym_continue] = ACTIONS(2609),
    [anon_sym_goto] = ACTIONS(2609),
    [anon_sym___try] = ACTIONS(2609),
    [anon_sym___leave] = ACTIONS(2609),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_compl] = ACTIONS(2609),
    [anon_sym_DASH_DASH] = ACTIONS(2611),
    [anon_sym_PLUS_PLUS] = ACTIONS(2611),
    [anon_sym_sizeof] = ACTIONS(2609),
    [anon_sym___alignof__] = ACTIONS(2609),
    [anon_sym___alignof] = ACTIONS(2609),
    [anon_sym__alignof] = ACTIONS(2609),
    [anon_sym_alignof] = ACTIONS(2609),
    [anon_sym__Alignof] = ACTIONS(2609),
    [anon_sym_offsetof] = ACTIONS(2609),
    [anon_sym__Generic] = ACTIONS(2609),
    [anon_sym_asm] = ACTIONS(2609),
    [anon_sym___asm__] = ACTIONS(2609),
    [anon_sym___asm] = ACTIONS(2609),
    [sym_number_literal] = ACTIONS(2611),
    [anon_sym_L_SQUOTE] = ACTIONS(2611),
    [anon_sym_u_SQUOTE] = ACTIONS(2611),
    [anon_sym_U_SQUOTE] = ACTIONS(2611),
    [anon_sym_u8_SQUOTE] = ACTIONS(2611),
    [anon_sym_SQUOTE] = ACTIONS(2611),
    [anon_sym_L_DQUOTE] = ACTIONS(2611),
    [anon_sym_u_DQUOTE] = ACTIONS(2611),
    [anon_sym_U_DQUOTE] = ACTIONS(2611),
    [anon_sym_u8_DQUOTE] = ACTIONS(2611),
    [anon_sym_DQUOTE] = ACTIONS(2611),
    [sym_true] = ACTIONS(2609),
    [sym_false] = ACTIONS(2609),
    [anon_sym_NULL] = ACTIONS(2609),
    [anon_sym_nullptr] = ACTIONS(2609),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2609),
    [anon_sym_decltype] = ACTIONS(2609),
    [anon_sym_explicit] = ACTIONS(2609),
    [anon_sym_typename] = ACTIONS(2609),
    [anon_sym_template] = ACTIONS(2609),
    [anon_sym_operator] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2609),
    [anon_sym_delete] = ACTIONS(2609),
    [anon_sym_throw] = ACTIONS(2609),
    [anon_sym_namespace] = ACTIONS(2609),
    [anon_sym_using] = ACTIONS(2609),
    [anon_sym_static_assert] = ACTIONS(2609),
    [anon_sym_concept] = ACTIONS(2609),
    [anon_sym_co_return] = ACTIONS(2609),
    [anon_sym_co_yield] = ACTIONS(2609),
    [anon_sym_R_DQUOTE] = ACTIONS(2611),
    [anon_sym_LR_DQUOTE] = ACTIONS(2611),
    [anon_sym_uR_DQUOTE] = ACTIONS(2611),
    [anon_sym_UR_DQUOTE] = ACTIONS(2611),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2611),
    [anon_sym_co_await] = ACTIONS(2609),
    [anon_sym_new] = ACTIONS(2609),
    [anon_sym_requires] = ACTIONS(2609),
    [sym_this] = ACTIONS(2609),
    [anon_sym___launch_bounds__] = ACTIONS(2609),
  },
  [STATE(524)] = {
    [sym_identifier] = ACTIONS(2617),
    [aux_sym_preproc_include_token1] = ACTIONS(2617),
    [aux_sym_preproc_def_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2617),
    [sym_preproc_directive] = ACTIONS(2617),
    [anon_sym_LPAREN2] = ACTIONS(2619),
    [anon_sym_BANG] = ACTIONS(2619),
    [anon_sym_TILDE] = ACTIONS(2619),
    [anon_sym_DASH] = ACTIONS(2617),
    [anon_sym_PLUS] = ACTIONS(2617),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_AMP_AMP] = ACTIONS(2619),
    [anon_sym_AMP] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2619),
    [anon_sym___extension__] = ACTIONS(2617),
    [anon_sym_typedef] = ACTIONS(2617),
    [anon_sym___device__] = ACTIONS(2617),
    [anon_sym___host__] = ACTIONS(2617),
    [anon_sym___global__] = ACTIONS(2617),
    [anon_sym___forceinline__] = ACTIONS(2617),
    [anon_sym___noinline__] = ACTIONS(2617),
    [anon_sym_virtual] = ACTIONS(2617),
    [anon_sym_extern] = ACTIONS(2617),
    [anon_sym___attribute__] = ACTIONS(2617),
    [anon_sym___attribute] = ACTIONS(2617),
    [anon_sym_COLON_COLON] = ACTIONS(2619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2619),
    [anon_sym___declspec] = ACTIONS(2617),
    [anon_sym___based] = ACTIONS(2617),
    [anon_sym___cdecl] = ACTIONS(2617),
    [anon_sym___clrcall] = ACTIONS(2617),
    [anon_sym___stdcall] = ACTIONS(2617),
    [anon_sym___fastcall] = ACTIONS(2617),
    [anon_sym___thiscall] = ACTIONS(2617),
    [anon_sym___vectorcall] = ACTIONS(2617),
    [anon_sym_LBRACE] = ACTIONS(2619),
    [anon_sym_RBRACE] = ACTIONS(2619),
    [anon_sym_signed] = ACTIONS(2617),
    [anon_sym_unsigned] = ACTIONS(2617),
    [anon_sym_long] = ACTIONS(2617),
    [anon_sym_short] = ACTIONS(2617),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2617),
    [anon_sym_register] = ACTIONS(2617),
    [anon_sym_inline] = ACTIONS(2617),
    [anon_sym___inline] = ACTIONS(2617),
    [anon_sym___inline__] = ACTIONS(2617),
    [anon_sym___forceinline] = ACTIONS(2617),
    [anon_sym_thread_local] = ACTIONS(2617),
    [anon_sym___thread] = ACTIONS(2617),
    [anon_sym_const] = ACTIONS(2617),
    [anon_sym_constexpr] = ACTIONS(2617),
    [anon_sym_volatile] = ACTIONS(2617),
    [anon_sym_restrict] = ACTIONS(2617),
    [anon_sym___restrict__] = ACTIONS(2617),
    [anon_sym__Atomic] = ACTIONS(2617),
    [anon_sym__Noreturn] = ACTIONS(2617),
    [anon_sym_noreturn] = ACTIONS(2617),
    [anon_sym__Nonnull] = ACTIONS(2617),
    [anon_sym_mutable] = ACTIONS(2617),
    [anon_sym_constinit] = ACTIONS(2617),
    [anon_sym_consteval] = ACTIONS(2617),
    [anon_sym___shared__] = ACTIONS(2617),
    [anon_sym___local__] = ACTIONS(2617),
    [anon_sym___constant__] = ACTIONS(2617),
    [anon_sym___managed__] = ACTIONS(2617),
    [anon_sym___grid_constant__] = ACTIONS(2617),
    [anon_sym_alignas] = ACTIONS(2617),
    [anon_sym__Alignas] = ACTIONS(2617),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2617),
    [anon_sym_struct] = ACTIONS(2617),
    [anon_sym_union] = ACTIONS(2617),
    [anon_sym_if] = ACTIONS(2617),
    [anon_sym_switch] = ACTIONS(2617),
    [anon_sym_case] = ACTIONS(2617),
    [anon_sym_default] = ACTIONS(2617),
    [anon_sym_while] = ACTIONS(2617),
    [anon_sym_do] = ACTIONS(2617),
    [anon_sym_for] = ACTIONS(2617),
    [anon_sym_return] = ACTIONS(2617),
    [anon_sym_break] = ACTIONS(2617),
    [anon_sym_continue] = ACTIONS(2617),
    [anon_sym_goto] = ACTIONS(2617),
    [anon_sym___try] = ACTIONS(2617),
    [anon_sym___leave] = ACTIONS(2617),
    [anon_sym_not] = ACTIONS(2617),
    [anon_sym_compl] = ACTIONS(2617),
    [anon_sym_DASH_DASH] = ACTIONS(2619),
    [anon_sym_PLUS_PLUS] = ACTIONS(2619),
    [anon_sym_sizeof] = ACTIONS(2617),
    [anon_sym___alignof__] = ACTIONS(2617),
    [anon_sym___alignof] = ACTIONS(2617),
    [anon_sym__alignof] = ACTIONS(2617),
    [anon_sym_alignof] = ACTIONS(2617),
    [anon_sym__Alignof] = ACTIONS(2617),
    [anon_sym_offsetof] = ACTIONS(2617),
    [anon_sym__Generic] = ACTIONS(2617),
    [anon_sym_asm] = ACTIONS(2617),
    [anon_sym___asm__] = ACTIONS(2617),
    [anon_sym___asm] = ACTIONS(2617),
    [sym_number_literal] = ACTIONS(2619),
    [anon_sym_L_SQUOTE] = ACTIONS(2619),
    [anon_sym_u_SQUOTE] = ACTIONS(2619),
    [anon_sym_U_SQUOTE] = ACTIONS(2619),
    [anon_sym_u8_SQUOTE] = ACTIONS(2619),
    [anon_sym_SQUOTE] = ACTIONS(2619),
    [anon_sym_L_DQUOTE] = ACTIONS(2619),
    [anon_sym_u_DQUOTE] = ACTIONS(2619),
    [anon_sym_U_DQUOTE] = ACTIONS(2619),
    [anon_sym_u8_DQUOTE] = ACTIONS(2619),
    [anon_sym_DQUOTE] = ACTIONS(2619),
    [sym_true] = ACTIONS(2617),
    [sym_false] = ACTIONS(2617),
    [anon_sym_NULL] = ACTIONS(2617),
    [anon_sym_nullptr] = ACTIONS(2617),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2617),
    [anon_sym_decltype] = ACTIONS(2617),
    [anon_sym_explicit] = ACTIONS(2617),
    [anon_sym_typename] = ACTIONS(2617),
    [anon_sym_template] = ACTIONS(2617),
    [anon_sym_operator] = ACTIONS(2617),
    [anon_sym_try] = ACTIONS(2617),
    [anon_sym_delete] = ACTIONS(2617),
    [anon_sym_throw] = ACTIONS(2617),
    [anon_sym_namespace] = ACTIONS(2617),
    [anon_sym_using] = ACTIONS(2617),
    [anon_sym_static_assert] = ACTIONS(2617),
    [anon_sym_concept] = ACTIONS(2617),
    [anon_sym_co_return] = ACTIONS(2617),
    [anon_sym_co_yield] = ACTIONS(2617),
    [anon_sym_R_DQUOTE] = ACTIONS(2619),
    [anon_sym_LR_DQUOTE] = ACTIONS(2619),
    [anon_sym_uR_DQUOTE] = ACTIONS(2619),
    [anon_sym_UR_DQUOTE] = ACTIONS(2619),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2619),
    [anon_sym_co_await] = ACTIONS(2617),
    [anon_sym_new] = ACTIONS(2617),
    [anon_sym_requires] = ACTIONS(2617),
    [sym_this] = ACTIONS(2617),
    [anon_sym___launch_bounds__] = ACTIONS(2617),
  },
  [STATE(525)] = {
    [sym_identifier] = ACTIONS(2591),
    [aux_sym_preproc_include_token1] = ACTIONS(2591),
    [aux_sym_preproc_def_token1] = ACTIONS(2591),
    [aux_sym_preproc_if_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [sym_preproc_directive] = ACTIONS(2591),
    [anon_sym_LPAREN2] = ACTIONS(2593),
    [anon_sym_BANG] = ACTIONS(2593),
    [anon_sym_TILDE] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2591),
    [anon_sym_PLUS] = ACTIONS(2591),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_AMP_AMP] = ACTIONS(2593),
    [anon_sym_AMP] = ACTIONS(2591),
    [anon_sym_SEMI] = ACTIONS(2593),
    [anon_sym___extension__] = ACTIONS(2591),
    [anon_sym_typedef] = ACTIONS(2591),
    [anon_sym___device__] = ACTIONS(2591),
    [anon_sym___host__] = ACTIONS(2591),
    [anon_sym___global__] = ACTIONS(2591),
    [anon_sym___forceinline__] = ACTIONS(2591),
    [anon_sym___noinline__] = ACTIONS(2591),
    [anon_sym_virtual] = ACTIONS(2591),
    [anon_sym_extern] = ACTIONS(2591),
    [anon_sym___attribute__] = ACTIONS(2591),
    [anon_sym___attribute] = ACTIONS(2591),
    [anon_sym_COLON_COLON] = ACTIONS(2593),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2593),
    [anon_sym___declspec] = ACTIONS(2591),
    [anon_sym___based] = ACTIONS(2591),
    [anon_sym___cdecl] = ACTIONS(2591),
    [anon_sym___clrcall] = ACTIONS(2591),
    [anon_sym___stdcall] = ACTIONS(2591),
    [anon_sym___fastcall] = ACTIONS(2591),
    [anon_sym___thiscall] = ACTIONS(2591),
    [anon_sym___vectorcall] = ACTIONS(2591),
    [anon_sym_LBRACE] = ACTIONS(2593),
    [anon_sym_RBRACE] = ACTIONS(2593),
    [anon_sym_signed] = ACTIONS(2591),
    [anon_sym_unsigned] = ACTIONS(2591),
    [anon_sym_long] = ACTIONS(2591),
    [anon_sym_short] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [anon_sym_static] = ACTIONS(2591),
    [anon_sym_register] = ACTIONS(2591),
    [anon_sym_inline] = ACTIONS(2591),
    [anon_sym___inline] = ACTIONS(2591),
    [anon_sym___inline__] = ACTIONS(2591),
    [anon_sym___forceinline] = ACTIONS(2591),
    [anon_sym_thread_local] = ACTIONS(2591),
    [anon_sym___thread] = ACTIONS(2591),
    [anon_sym_const] = ACTIONS(2591),
    [anon_sym_constexpr] = ACTIONS(2591),
    [anon_sym_volatile] = ACTIONS(2591),
    [anon_sym_restrict] = ACTIONS(2591),
    [anon_sym___restrict__] = ACTIONS(2591),
    [anon_sym__Atomic] = ACTIONS(2591),
    [anon_sym__Noreturn] = ACTIONS(2591),
    [anon_sym_noreturn] = ACTIONS(2591),
    [anon_sym__Nonnull] = ACTIONS(2591),
    [anon_sym_mutable] = ACTIONS(2591),
    [anon_sym_constinit] = ACTIONS(2591),
    [anon_sym_consteval] = ACTIONS(2591),
    [anon_sym___shared__] = ACTIONS(2591),
    [anon_sym___local__] = ACTIONS(2591),
    [anon_sym___constant__] = ACTIONS(2591),
    [anon_sym___managed__] = ACTIONS(2591),
    [anon_sym___grid_constant__] = ACTIONS(2591),
    [anon_sym_alignas] = ACTIONS(2591),
    [anon_sym__Alignas] = ACTIONS(2591),
    [sym_primitive_type] = ACTIONS(2591),
    [anon_sym_enum] = ACTIONS(2591),
    [anon_sym_class] = ACTIONS(2591),
    [anon_sym_struct] = ACTIONS(2591),
    [anon_sym_union] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_switch] = ACTIONS(2591),
    [anon_sym_case] = ACTIONS(2591),
    [anon_sym_default] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(2591),
    [anon_sym_do] = ACTIONS(2591),
    [anon_sym_for] = ACTIONS(2591),
    [anon_sym_return] = ACTIONS(2591),
    [anon_sym_break] = ACTIONS(2591),
    [anon_sym_continue] = ACTIONS(2591),
    [anon_sym_goto] = ACTIONS(2591),
    [anon_sym___try] = ACTIONS(2591),
    [anon_sym___leave] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_compl] = ACTIONS(2591),
    [anon_sym_DASH_DASH] = ACTIONS(2593),
    [anon_sym_PLUS_PLUS] = ACTIONS(2593),
    [anon_sym_sizeof] = ACTIONS(2591),
    [anon_sym___alignof__] = ACTIONS(2591),
    [anon_sym___alignof] = ACTIONS(2591),
    [anon_sym__alignof] = ACTIONS(2591),
    [anon_sym_alignof] = ACTIONS(2591),
    [anon_sym__Alignof] = ACTIONS(2591),
    [anon_sym_offsetof] = ACTIONS(2591),
    [anon_sym__Generic] = ACTIONS(2591),
    [anon_sym_asm] = ACTIONS(2591),
    [anon_sym___asm__] = ACTIONS(2591),
    [anon_sym___asm] = ACTIONS(2591),
    [sym_number_literal] = ACTIONS(2593),
    [anon_sym_L_SQUOTE] = ACTIONS(2593),
    [anon_sym_u_SQUOTE] = ACTIONS(2593),
    [anon_sym_U_SQUOTE] = ACTIONS(2593),
    [anon_sym_u8_SQUOTE] = ACTIONS(2593),
    [anon_sym_SQUOTE] = ACTIONS(2593),
    [anon_sym_L_DQUOTE] = ACTIONS(2593),
    [anon_sym_u_DQUOTE] = ACTIONS(2593),
    [anon_sym_U_DQUOTE] = ACTIONS(2593),
    [anon_sym_u8_DQUOTE] = ACTIONS(2593),
    [anon_sym_DQUOTE] = ACTIONS(2593),
    [sym_true] = ACTIONS(2591),
    [sym_false] = ACTIONS(2591),
    [anon_sym_NULL] = ACTIONS(2591),
    [anon_sym_nullptr] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2591),
    [anon_sym_decltype] = ACTIONS(2591),
    [anon_sym_explicit] = ACTIONS(2591),
    [anon_sym_typename] = ACTIONS(2591),
    [anon_sym_template] = ACTIONS(2591),
    [anon_sym_operator] = ACTIONS(2591),
    [anon_sym_try] = ACTIONS(2591),
    [anon_sym_delete] = ACTIONS(2591),
    [anon_sym_throw] = ACTIONS(2591),
    [anon_sym_namespace] = ACTIONS(2591),
    [anon_sym_using] = ACTIONS(2591),
    [anon_sym_static_assert] = ACTIONS(2591),
    [anon_sym_concept] = ACTIONS(2591),
    [anon_sym_co_return] = ACTIONS(2591),
    [anon_sym_co_yield] = ACTIONS(2591),
    [anon_sym_R_DQUOTE] = ACTIONS(2593),
    [anon_sym_LR_DQUOTE] = ACTIONS(2593),
    [anon_sym_uR_DQUOTE] = ACTIONS(2593),
    [anon_sym_UR_DQUOTE] = ACTIONS(2593),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2593),
    [anon_sym_co_await] = ACTIONS(2591),
    [anon_sym_new] = ACTIONS(2591),
    [anon_sym_requires] = ACTIONS(2591),
    [sym_this] = ACTIONS(2591),
    [anon_sym___launch_bounds__] = ACTIONS(2591),
  },
  [STATE(526)] = {
    [sym_identifier] = ACTIONS(2599),
    [aux_sym_preproc_include_token1] = ACTIONS(2599),
    [aux_sym_preproc_def_token1] = ACTIONS(2599),
    [aux_sym_preproc_if_token1] = ACTIONS(2599),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2599),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2599),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_BANG] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2601),
    [anon_sym_DASH] = ACTIONS(2599),
    [anon_sym_PLUS] = ACTIONS(2599),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_AMP_AMP] = ACTIONS(2601),
    [anon_sym_AMP] = ACTIONS(2599),
    [anon_sym_SEMI] = ACTIONS(2601),
    [anon_sym___extension__] = ACTIONS(2599),
    [anon_sym_typedef] = ACTIONS(2599),
    [anon_sym___device__] = ACTIONS(2599),
    [anon_sym___host__] = ACTIONS(2599),
    [anon_sym___global__] = ACTIONS(2599),
    [anon_sym___forceinline__] = ACTIONS(2599),
    [anon_sym___noinline__] = ACTIONS(2599),
    [anon_sym_virtual] = ACTIONS(2599),
    [anon_sym_extern] = ACTIONS(2599),
    [anon_sym___attribute__] = ACTIONS(2599),
    [anon_sym___attribute] = ACTIONS(2599),
    [anon_sym_COLON_COLON] = ACTIONS(2601),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2601),
    [anon_sym___declspec] = ACTIONS(2599),
    [anon_sym___based] = ACTIONS(2599),
    [anon_sym___cdecl] = ACTIONS(2599),
    [anon_sym___clrcall] = ACTIONS(2599),
    [anon_sym___stdcall] = ACTIONS(2599),
    [anon_sym___fastcall] = ACTIONS(2599),
    [anon_sym___thiscall] = ACTIONS(2599),
    [anon_sym___vectorcall] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(2601),
    [anon_sym_RBRACE] = ACTIONS(2601),
    [anon_sym_signed] = ACTIONS(2599),
    [anon_sym_unsigned] = ACTIONS(2599),
    [anon_sym_long] = ACTIONS(2599),
    [anon_sym_short] = ACTIONS(2599),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [anon_sym_static] = ACTIONS(2599),
    [anon_sym_register] = ACTIONS(2599),
    [anon_sym_inline] = ACTIONS(2599),
    [anon_sym___inline] = ACTIONS(2599),
    [anon_sym___inline__] = ACTIONS(2599),
    [anon_sym___forceinline] = ACTIONS(2599),
    [anon_sym_thread_local] = ACTIONS(2599),
    [anon_sym___thread] = ACTIONS(2599),
    [anon_sym_const] = ACTIONS(2599),
    [anon_sym_constexpr] = ACTIONS(2599),
    [anon_sym_volatile] = ACTIONS(2599),
    [anon_sym_restrict] = ACTIONS(2599),
    [anon_sym___restrict__] = ACTIONS(2599),
    [anon_sym__Atomic] = ACTIONS(2599),
    [anon_sym__Noreturn] = ACTIONS(2599),
    [anon_sym_noreturn] = ACTIONS(2599),
    [anon_sym__Nonnull] = ACTIONS(2599),
    [anon_sym_mutable] = ACTIONS(2599),
    [anon_sym_constinit] = ACTIONS(2599),
    [anon_sym_consteval] = ACTIONS(2599),
    [anon_sym___shared__] = ACTIONS(2599),
    [anon_sym___local__] = ACTIONS(2599),
    [anon_sym___constant__] = ACTIONS(2599),
    [anon_sym___managed__] = ACTIONS(2599),
    [anon_sym___grid_constant__] = ACTIONS(2599),
    [anon_sym_alignas] = ACTIONS(2599),
    [anon_sym__Alignas] = ACTIONS(2599),
    [sym_primitive_type] = ACTIONS(2599),
    [anon_sym_enum] = ACTIONS(2599),
    [anon_sym_class] = ACTIONS(2599),
    [anon_sym_struct] = ACTIONS(2599),
    [anon_sym_union] = ACTIONS(2599),
    [anon_sym_if] = ACTIONS(2599),
    [anon_sym_switch] = ACTIONS(2599),
    [anon_sym_case] = ACTIONS(2599),
    [anon_sym_default] = ACTIONS(2599),
    [anon_sym_while] = ACTIONS(2599),
    [anon_sym_do] = ACTIONS(2599),
    [anon_sym_for] = ACTIONS(2599),
    [anon_sym_return] = ACTIONS(2599),
    [anon_sym_break] = ACTIONS(2599),
    [anon_sym_continue] = ACTIONS(2599),
    [anon_sym_goto] = ACTIONS(2599),
    [anon_sym___try] = ACTIONS(2599),
    [anon_sym___leave] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2599),
    [anon_sym_compl] = ACTIONS(2599),
    [anon_sym_DASH_DASH] = ACTIONS(2601),
    [anon_sym_PLUS_PLUS] = ACTIONS(2601),
    [anon_sym_sizeof] = ACTIONS(2599),
    [anon_sym___alignof__] = ACTIONS(2599),
    [anon_sym___alignof] = ACTIONS(2599),
    [anon_sym__alignof] = ACTIONS(2599),
    [anon_sym_alignof] = ACTIONS(2599),
    [anon_sym__Alignof] = ACTIONS(2599),
    [anon_sym_offsetof] = ACTIONS(2599),
    [anon_sym__Generic] = ACTIONS(2599),
    [anon_sym_asm] = ACTIONS(2599),
    [anon_sym___asm__] = ACTIONS(2599),
    [anon_sym___asm] = ACTIONS(2599),
    [sym_number_literal] = ACTIONS(2601),
    [anon_sym_L_SQUOTE] = ACTIONS(2601),
    [anon_sym_u_SQUOTE] = ACTIONS(2601),
    [anon_sym_U_SQUOTE] = ACTIONS(2601),
    [anon_sym_u8_SQUOTE] = ACTIONS(2601),
    [anon_sym_SQUOTE] = ACTIONS(2601),
    [anon_sym_L_DQUOTE] = ACTIONS(2601),
    [anon_sym_u_DQUOTE] = ACTIONS(2601),
    [anon_sym_U_DQUOTE] = ACTIONS(2601),
    [anon_sym_u8_DQUOTE] = ACTIONS(2601),
    [anon_sym_DQUOTE] = ACTIONS(2601),
    [sym_true] = ACTIONS(2599),
    [sym_false] = ACTIONS(2599),
    [anon_sym_NULL] = ACTIONS(2599),
    [anon_sym_nullptr] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2599),
    [anon_sym_decltype] = ACTIONS(2599),
    [anon_sym_explicit] = ACTIONS(2599),
    [anon_sym_typename] = ACTIONS(2599),
    [anon_sym_template] = ACTIONS(2599),
    [anon_sym_operator] = ACTIONS(2599),
    [anon_sym_try] = ACTIONS(2599),
    [anon_sym_delete] = ACTIONS(2599),
    [anon_sym_throw] = ACTIONS(2599),
    [anon_sym_namespace] = ACTIONS(2599),
    [anon_sym_using] = ACTIONS(2599),
    [anon_sym_static_assert] = ACTIONS(2599),
    [anon_sym_concept] = ACTIONS(2599),
    [anon_sym_co_return] = ACTIONS(2599),
    [anon_sym_co_yield] = ACTIONS(2599),
    [anon_sym_R_DQUOTE] = ACTIONS(2601),
    [anon_sym_LR_DQUOTE] = ACTIONS(2601),
    [anon_sym_uR_DQUOTE] = ACTIONS(2601),
    [anon_sym_UR_DQUOTE] = ACTIONS(2601),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2601),
    [anon_sym_co_await] = ACTIONS(2599),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_requires] = ACTIONS(2599),
    [sym_this] = ACTIONS(2599),
    [anon_sym___launch_bounds__] = ACTIONS(2599),
  },
  [STATE(527)] = {
    [sym_identifier] = ACTIONS(2609),
    [aux_sym_preproc_include_token1] = ACTIONS(2609),
    [aux_sym_preproc_def_token1] = ACTIONS(2609),
    [aux_sym_preproc_if_token1] = ACTIONS(2609),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2609),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2609),
    [sym_preproc_directive] = ACTIONS(2609),
    [anon_sym_LPAREN2] = ACTIONS(2611),
    [anon_sym_BANG] = ACTIONS(2611),
    [anon_sym_TILDE] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2611),
    [anon_sym_AMP_AMP] = ACTIONS(2611),
    [anon_sym_AMP] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2609),
    [anon_sym___device__] = ACTIONS(2609),
    [anon_sym___host__] = ACTIONS(2609),
    [anon_sym___global__] = ACTIONS(2609),
    [anon_sym___forceinline__] = ACTIONS(2609),
    [anon_sym___noinline__] = ACTIONS(2609),
    [anon_sym_virtual] = ACTIONS(2609),
    [anon_sym_extern] = ACTIONS(2609),
    [anon_sym___attribute__] = ACTIONS(2609),
    [anon_sym___attribute] = ACTIONS(2609),
    [anon_sym_COLON_COLON] = ACTIONS(2611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2611),
    [anon_sym___declspec] = ACTIONS(2609),
    [anon_sym___based] = ACTIONS(2609),
    [anon_sym___cdecl] = ACTIONS(2609),
    [anon_sym___clrcall] = ACTIONS(2609),
    [anon_sym___stdcall] = ACTIONS(2609),
    [anon_sym___fastcall] = ACTIONS(2609),
    [anon_sym___thiscall] = ACTIONS(2609),
    [anon_sym___vectorcall] = ACTIONS(2609),
    [anon_sym_LBRACE] = ACTIONS(2611),
    [anon_sym_RBRACE] = ACTIONS(2611),
    [anon_sym_signed] = ACTIONS(2609),
    [anon_sym_unsigned] = ACTIONS(2609),
    [anon_sym_long] = ACTIONS(2609),
    [anon_sym_short] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2609),
    [anon_sym_static] = ACTIONS(2609),
    [anon_sym_register] = ACTIONS(2609),
    [anon_sym_inline] = ACTIONS(2609),
    [anon_sym___inline] = ACTIONS(2609),
    [anon_sym___inline__] = ACTIONS(2609),
    [anon_sym___forceinline] = ACTIONS(2609),
    [anon_sym_thread_local] = ACTIONS(2609),
    [anon_sym___thread] = ACTIONS(2609),
    [anon_sym_const] = ACTIONS(2609),
    [anon_sym_constexpr] = ACTIONS(2609),
    [anon_sym_volatile] = ACTIONS(2609),
    [anon_sym_restrict] = ACTIONS(2609),
    [anon_sym___restrict__] = ACTIONS(2609),
    [anon_sym__Atomic] = ACTIONS(2609),
    [anon_sym__Noreturn] = ACTIONS(2609),
    [anon_sym_noreturn] = ACTIONS(2609),
    [anon_sym__Nonnull] = ACTIONS(2609),
    [anon_sym_mutable] = ACTIONS(2609),
    [anon_sym_constinit] = ACTIONS(2609),
    [anon_sym_consteval] = ACTIONS(2609),
    [anon_sym___shared__] = ACTIONS(2609),
    [anon_sym___local__] = ACTIONS(2609),
    [anon_sym___constant__] = ACTIONS(2609),
    [anon_sym___managed__] = ACTIONS(2609),
    [anon_sym___grid_constant__] = ACTIONS(2609),
    [anon_sym_alignas] = ACTIONS(2609),
    [anon_sym__Alignas] = ACTIONS(2609),
    [sym_primitive_type] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_class] = ACTIONS(2609),
    [anon_sym_struct] = ACTIONS(2609),
    [anon_sym_union] = ACTIONS(2609),
    [anon_sym_if] = ACTIONS(2609),
    [anon_sym_switch] = ACTIONS(2609),
    [anon_sym_case] = ACTIONS(2609),
    [anon_sym_default] = ACTIONS(2609),
    [anon_sym_while] = ACTIONS(2609),
    [anon_sym_do] = ACTIONS(2609),
    [anon_sym_for] = ACTIONS(2609),
    [anon_sym_return] = ACTIONS(2609),
    [anon_sym_break] = ACTIONS(2609),
    [anon_sym_continue] = ACTIONS(2609),
    [anon_sym_goto] = ACTIONS(2609),
    [anon_sym___try] = ACTIONS(2609),
    [anon_sym___leave] = ACTIONS(2609),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_compl] = ACTIONS(2609),
    [anon_sym_DASH_DASH] = ACTIONS(2611),
    [anon_sym_PLUS_PLUS] = ACTIONS(2611),
    [anon_sym_sizeof] = ACTIONS(2609),
    [anon_sym___alignof__] = ACTIONS(2609),
    [anon_sym___alignof] = ACTIONS(2609),
    [anon_sym__alignof] = ACTIONS(2609),
    [anon_sym_alignof] = ACTIONS(2609),
    [anon_sym__Alignof] = ACTIONS(2609),
    [anon_sym_offsetof] = ACTIONS(2609),
    [anon_sym__Generic] = ACTIONS(2609),
    [anon_sym_asm] = ACTIONS(2609),
    [anon_sym___asm__] = ACTIONS(2609),
    [anon_sym___asm] = ACTIONS(2609),
    [sym_number_literal] = ACTIONS(2611),
    [anon_sym_L_SQUOTE] = ACTIONS(2611),
    [anon_sym_u_SQUOTE] = ACTIONS(2611),
    [anon_sym_U_SQUOTE] = ACTIONS(2611),
    [anon_sym_u8_SQUOTE] = ACTIONS(2611),
    [anon_sym_SQUOTE] = ACTIONS(2611),
    [anon_sym_L_DQUOTE] = ACTIONS(2611),
    [anon_sym_u_DQUOTE] = ACTIONS(2611),
    [anon_sym_U_DQUOTE] = ACTIONS(2611),
    [anon_sym_u8_DQUOTE] = ACTIONS(2611),
    [anon_sym_DQUOTE] = ACTIONS(2611),
    [sym_true] = ACTIONS(2609),
    [sym_false] = ACTIONS(2609),
    [anon_sym_NULL] = ACTIONS(2609),
    [anon_sym_nullptr] = ACTIONS(2609),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2609),
    [anon_sym_decltype] = ACTIONS(2609),
    [anon_sym_explicit] = ACTIONS(2609),
    [anon_sym_typename] = ACTIONS(2609),
    [anon_sym_template] = ACTIONS(2609),
    [anon_sym_operator] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2609),
    [anon_sym_delete] = ACTIONS(2609),
    [anon_sym_throw] = ACTIONS(2609),
    [anon_sym_namespace] = ACTIONS(2609),
    [anon_sym_using] = ACTIONS(2609),
    [anon_sym_static_assert] = ACTIONS(2609),
    [anon_sym_concept] = ACTIONS(2609),
    [anon_sym_co_return] = ACTIONS(2609),
    [anon_sym_co_yield] = ACTIONS(2609),
    [anon_sym_R_DQUOTE] = ACTIONS(2611),
    [anon_sym_LR_DQUOTE] = ACTIONS(2611),
    [anon_sym_uR_DQUOTE] = ACTIONS(2611),
    [anon_sym_UR_DQUOTE] = ACTIONS(2611),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2611),
    [anon_sym_co_await] = ACTIONS(2609),
    [anon_sym_new] = ACTIONS(2609),
    [anon_sym_requires] = ACTIONS(2609),
    [sym_this] = ACTIONS(2609),
    [anon_sym___launch_bounds__] = ACTIONS(2609),
  },
  [STATE(528)] = {
    [sym_identifier] = ACTIONS(2463),
    [aux_sym_preproc_include_token1] = ACTIONS(2463),
    [aux_sym_preproc_def_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2463),
    [sym_preproc_directive] = ACTIONS(2463),
    [anon_sym_LPAREN2] = ACTIONS(2465),
    [anon_sym_BANG] = ACTIONS(2465),
    [anon_sym_TILDE] = ACTIONS(2465),
    [anon_sym_DASH] = ACTIONS(2463),
    [anon_sym_PLUS] = ACTIONS(2463),
    [anon_sym_STAR] = ACTIONS(2465),
    [anon_sym_AMP_AMP] = ACTIONS(2465),
    [anon_sym_AMP] = ACTIONS(2463),
    [anon_sym_SEMI] = ACTIONS(2465),
    [anon_sym___extension__] = ACTIONS(2463),
    [anon_sym_typedef] = ACTIONS(2463),
    [anon_sym___device__] = ACTIONS(2463),
    [anon_sym___host__] = ACTIONS(2463),
    [anon_sym___global__] = ACTIONS(2463),
    [anon_sym___forceinline__] = ACTIONS(2463),
    [anon_sym___noinline__] = ACTIONS(2463),
    [anon_sym_virtual] = ACTIONS(2463),
    [anon_sym_extern] = ACTIONS(2463),
    [anon_sym___attribute__] = ACTIONS(2463),
    [anon_sym___attribute] = ACTIONS(2463),
    [anon_sym_COLON_COLON] = ACTIONS(2465),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2465),
    [anon_sym___declspec] = ACTIONS(2463),
    [anon_sym___based] = ACTIONS(2463),
    [anon_sym___cdecl] = ACTIONS(2463),
    [anon_sym___clrcall] = ACTIONS(2463),
    [anon_sym___stdcall] = ACTIONS(2463),
    [anon_sym___fastcall] = ACTIONS(2463),
    [anon_sym___thiscall] = ACTIONS(2463),
    [anon_sym___vectorcall] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_RBRACE] = ACTIONS(2465),
    [anon_sym_signed] = ACTIONS(2463),
    [anon_sym_unsigned] = ACTIONS(2463),
    [anon_sym_long] = ACTIONS(2463),
    [anon_sym_short] = ACTIONS(2463),
    [anon_sym_LBRACK] = ACTIONS(2463),
    [anon_sym_static] = ACTIONS(2463),
    [anon_sym_register] = ACTIONS(2463),
    [anon_sym_inline] = ACTIONS(2463),
    [anon_sym___inline] = ACTIONS(2463),
    [anon_sym___inline__] = ACTIONS(2463),
    [anon_sym___forceinline] = ACTIONS(2463),
    [anon_sym_thread_local] = ACTIONS(2463),
    [anon_sym___thread] = ACTIONS(2463),
    [anon_sym_const] = ACTIONS(2463),
    [anon_sym_constexpr] = ACTIONS(2463),
    [anon_sym_volatile] = ACTIONS(2463),
    [anon_sym_restrict] = ACTIONS(2463),
    [anon_sym___restrict__] = ACTIONS(2463),
    [anon_sym__Atomic] = ACTIONS(2463),
    [anon_sym__Noreturn] = ACTIONS(2463),
    [anon_sym_noreturn] = ACTIONS(2463),
    [anon_sym__Nonnull] = ACTIONS(2463),
    [anon_sym_mutable] = ACTIONS(2463),
    [anon_sym_constinit] = ACTIONS(2463),
    [anon_sym_consteval] = ACTIONS(2463),
    [anon_sym___shared__] = ACTIONS(2463),
    [anon_sym___local__] = ACTIONS(2463),
    [anon_sym___constant__] = ACTIONS(2463),
    [anon_sym___managed__] = ACTIONS(2463),
    [anon_sym___grid_constant__] = ACTIONS(2463),
    [anon_sym_alignas] = ACTIONS(2463),
    [anon_sym__Alignas] = ACTIONS(2463),
    [sym_primitive_type] = ACTIONS(2463),
    [anon_sym_enum] = ACTIONS(2463),
    [anon_sym_class] = ACTIONS(2463),
    [anon_sym_struct] = ACTIONS(2463),
    [anon_sym_union] = ACTIONS(2463),
    [anon_sym_if] = ACTIONS(2463),
    [anon_sym_switch] = ACTIONS(2463),
    [anon_sym_case] = ACTIONS(2463),
    [anon_sym_default] = ACTIONS(2463),
    [anon_sym_while] = ACTIONS(2463),
    [anon_sym_do] = ACTIONS(2463),
    [anon_sym_for] = ACTIONS(2463),
    [anon_sym_return] = ACTIONS(2463),
    [anon_sym_break] = ACTIONS(2463),
    [anon_sym_continue] = ACTIONS(2463),
    [anon_sym_goto] = ACTIONS(2463),
    [anon_sym___try] = ACTIONS(2463),
    [anon_sym___leave] = ACTIONS(2463),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_compl] = ACTIONS(2463),
    [anon_sym_DASH_DASH] = ACTIONS(2465),
    [anon_sym_PLUS_PLUS] = ACTIONS(2465),
    [anon_sym_sizeof] = ACTIONS(2463),
    [anon_sym___alignof__] = ACTIONS(2463),
    [anon_sym___alignof] = ACTIONS(2463),
    [anon_sym__alignof] = ACTIONS(2463),
    [anon_sym_alignof] = ACTIONS(2463),
    [anon_sym__Alignof] = ACTIONS(2463),
    [anon_sym_offsetof] = ACTIONS(2463),
    [anon_sym__Generic] = ACTIONS(2463),
    [anon_sym_asm] = ACTIONS(2463),
    [anon_sym___asm__] = ACTIONS(2463),
    [anon_sym___asm] = ACTIONS(2463),
    [sym_number_literal] = ACTIONS(2465),
    [anon_sym_L_SQUOTE] = ACTIONS(2465),
    [anon_sym_u_SQUOTE] = ACTIONS(2465),
    [anon_sym_U_SQUOTE] = ACTIONS(2465),
    [anon_sym_u8_SQUOTE] = ACTIONS(2465),
    [anon_sym_SQUOTE] = ACTIONS(2465),
    [anon_sym_L_DQUOTE] = ACTIONS(2465),
    [anon_sym_u_DQUOTE] = ACTIONS(2465),
    [anon_sym_U_DQUOTE] = ACTIONS(2465),
    [anon_sym_u8_DQUOTE] = ACTIONS(2465),
    [anon_sym_DQUOTE] = ACTIONS(2465),
    [sym_true] = ACTIONS(2463),
    [sym_false] = ACTIONS(2463),
    [anon_sym_NULL] = ACTIONS(2463),
    [anon_sym_nullptr] = ACTIONS(2463),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2463),
    [anon_sym_decltype] = ACTIONS(2463),
    [anon_sym_explicit] = ACTIONS(2463),
    [anon_sym_typename] = ACTIONS(2463),
    [anon_sym_template] = ACTIONS(2463),
    [anon_sym_operator] = ACTIONS(2463),
    [anon_sym_try] = ACTIONS(2463),
    [anon_sym_delete] = ACTIONS(2463),
    [anon_sym_throw] = ACTIONS(2463),
    [anon_sym_namespace] = ACTIONS(2463),
    [anon_sym_using] = ACTIONS(2463),
    [anon_sym_static_assert] = ACTIONS(2463),
    [anon_sym_concept] = ACTIONS(2463),
    [anon_sym_co_return] = ACTIONS(2463),
    [anon_sym_co_yield] = ACTIONS(2463),
    [anon_sym_R_DQUOTE] = ACTIONS(2465),
    [anon_sym_LR_DQUOTE] = ACTIONS(2465),
    [anon_sym_uR_DQUOTE] = ACTIONS(2465),
    [anon_sym_UR_DQUOTE] = ACTIONS(2465),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2465),
    [anon_sym_co_await] = ACTIONS(2463),
    [anon_sym_new] = ACTIONS(2463),
    [anon_sym_requires] = ACTIONS(2463),
    [sym_this] = ACTIONS(2463),
    [anon_sym___launch_bounds__] = ACTIONS(2463),
  },
  [STATE(529)] = {
    [sym_identifier] = ACTIONS(2497),
    [aux_sym_preproc_include_token1] = ACTIONS(2497),
    [aux_sym_preproc_def_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2497),
    [sym_preproc_directive] = ACTIONS(2497),
    [anon_sym_LPAREN2] = ACTIONS(2499),
    [anon_sym_BANG] = ACTIONS(2499),
    [anon_sym_TILDE] = ACTIONS(2499),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_STAR] = ACTIONS(2499),
    [anon_sym_AMP_AMP] = ACTIONS(2499),
    [anon_sym_AMP] = ACTIONS(2497),
    [anon_sym_SEMI] = ACTIONS(2499),
    [anon_sym___extension__] = ACTIONS(2497),
    [anon_sym_typedef] = ACTIONS(2497),
    [anon_sym___device__] = ACTIONS(2497),
    [anon_sym___host__] = ACTIONS(2497),
    [anon_sym___global__] = ACTIONS(2497),
    [anon_sym___forceinline__] = ACTIONS(2497),
    [anon_sym___noinline__] = ACTIONS(2497),
    [anon_sym_virtual] = ACTIONS(2497),
    [anon_sym_extern] = ACTIONS(2497),
    [anon_sym___attribute__] = ACTIONS(2497),
    [anon_sym___attribute] = ACTIONS(2497),
    [anon_sym_COLON_COLON] = ACTIONS(2499),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2499),
    [anon_sym___declspec] = ACTIONS(2497),
    [anon_sym___based] = ACTIONS(2497),
    [anon_sym___cdecl] = ACTIONS(2497),
    [anon_sym___clrcall] = ACTIONS(2497),
    [anon_sym___stdcall] = ACTIONS(2497),
    [anon_sym___fastcall] = ACTIONS(2497),
    [anon_sym___thiscall] = ACTIONS(2497),
    [anon_sym___vectorcall] = ACTIONS(2497),
    [anon_sym_LBRACE] = ACTIONS(2499),
    [anon_sym_RBRACE] = ACTIONS(2499),
    [anon_sym_signed] = ACTIONS(2497),
    [anon_sym_unsigned] = ACTIONS(2497),
    [anon_sym_long] = ACTIONS(2497),
    [anon_sym_short] = ACTIONS(2497),
    [anon_sym_LBRACK] = ACTIONS(2497),
    [anon_sym_static] = ACTIONS(2497),
    [anon_sym_register] = ACTIONS(2497),
    [anon_sym_inline] = ACTIONS(2497),
    [anon_sym___inline] = ACTIONS(2497),
    [anon_sym___inline__] = ACTIONS(2497),
    [anon_sym___forceinline] = ACTIONS(2497),
    [anon_sym_thread_local] = ACTIONS(2497),
    [anon_sym___thread] = ACTIONS(2497),
    [anon_sym_const] = ACTIONS(2497),
    [anon_sym_constexpr] = ACTIONS(2497),
    [anon_sym_volatile] = ACTIONS(2497),
    [anon_sym_restrict] = ACTIONS(2497),
    [anon_sym___restrict__] = ACTIONS(2497),
    [anon_sym__Atomic] = ACTIONS(2497),
    [anon_sym__Noreturn] = ACTIONS(2497),
    [anon_sym_noreturn] = ACTIONS(2497),
    [anon_sym__Nonnull] = ACTIONS(2497),
    [anon_sym_mutable] = ACTIONS(2497),
    [anon_sym_constinit] = ACTIONS(2497),
    [anon_sym_consteval] = ACTIONS(2497),
    [anon_sym___shared__] = ACTIONS(2497),
    [anon_sym___local__] = ACTIONS(2497),
    [anon_sym___constant__] = ACTIONS(2497),
    [anon_sym___managed__] = ACTIONS(2497),
    [anon_sym___grid_constant__] = ACTIONS(2497),
    [anon_sym_alignas] = ACTIONS(2497),
    [anon_sym__Alignas] = ACTIONS(2497),
    [sym_primitive_type] = ACTIONS(2497),
    [anon_sym_enum] = ACTIONS(2497),
    [anon_sym_class] = ACTIONS(2497),
    [anon_sym_struct] = ACTIONS(2497),
    [anon_sym_union] = ACTIONS(2497),
    [anon_sym_if] = ACTIONS(2497),
    [anon_sym_switch] = ACTIONS(2497),
    [anon_sym_case] = ACTIONS(2497),
    [anon_sym_default] = ACTIONS(2497),
    [anon_sym_while] = ACTIONS(2497),
    [anon_sym_do] = ACTIONS(2497),
    [anon_sym_for] = ACTIONS(2497),
    [anon_sym_return] = ACTIONS(2497),
    [anon_sym_break] = ACTIONS(2497),
    [anon_sym_continue] = ACTIONS(2497),
    [anon_sym_goto] = ACTIONS(2497),
    [anon_sym___try] = ACTIONS(2497),
    [anon_sym___leave] = ACTIONS(2497),
    [anon_sym_not] = ACTIONS(2497),
    [anon_sym_compl] = ACTIONS(2497),
    [anon_sym_DASH_DASH] = ACTIONS(2499),
    [anon_sym_PLUS_PLUS] = ACTIONS(2499),
    [anon_sym_sizeof] = ACTIONS(2497),
    [anon_sym___alignof__] = ACTIONS(2497),
    [anon_sym___alignof] = ACTIONS(2497),
    [anon_sym__alignof] = ACTIONS(2497),
    [anon_sym_alignof] = ACTIONS(2497),
    [anon_sym__Alignof] = ACTIONS(2497),
    [anon_sym_offsetof] = ACTIONS(2497),
    [anon_sym__Generic] = ACTIONS(2497),
    [anon_sym_asm] = ACTIONS(2497),
    [anon_sym___asm__] = ACTIONS(2497),
    [anon_sym___asm] = ACTIONS(2497),
    [sym_number_literal] = ACTIONS(2499),
    [anon_sym_L_SQUOTE] = ACTIONS(2499),
    [anon_sym_u_SQUOTE] = ACTIONS(2499),
    [anon_sym_U_SQUOTE] = ACTIONS(2499),
    [anon_sym_u8_SQUOTE] = ACTIONS(2499),
    [anon_sym_SQUOTE] = ACTIONS(2499),
    [anon_sym_L_DQUOTE] = ACTIONS(2499),
    [anon_sym_u_DQUOTE] = ACTIONS(2499),
    [anon_sym_U_DQUOTE] = ACTIONS(2499),
    [anon_sym_u8_DQUOTE] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(2499),
    [sym_true] = ACTIONS(2497),
    [sym_false] = ACTIONS(2497),
    [anon_sym_NULL] = ACTIONS(2497),
    [anon_sym_nullptr] = ACTIONS(2497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2497),
    [anon_sym_decltype] = ACTIONS(2497),
    [anon_sym_explicit] = ACTIONS(2497),
    [anon_sym_typename] = ACTIONS(2497),
    [anon_sym_template] = ACTIONS(2497),
    [anon_sym_operator] = ACTIONS(2497),
    [anon_sym_try] = ACTIONS(2497),
    [anon_sym_delete] = ACTIONS(2497),
    [anon_sym_throw] = ACTIONS(2497),
    [anon_sym_namespace] = ACTIONS(2497),
    [anon_sym_using] = ACTIONS(2497),
    [anon_sym_static_assert] = ACTIONS(2497),
    [anon_sym_concept] = ACTIONS(2497),
    [anon_sym_co_return] = ACTIONS(2497),
    [anon_sym_co_yield] = ACTIONS(2497),
    [anon_sym_R_DQUOTE] = ACTIONS(2499),
    [anon_sym_LR_DQUOTE] = ACTIONS(2499),
    [anon_sym_uR_DQUOTE] = ACTIONS(2499),
    [anon_sym_UR_DQUOTE] = ACTIONS(2499),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2499),
    [anon_sym_co_await] = ACTIONS(2497),
    [anon_sym_new] = ACTIONS(2497),
    [anon_sym_requires] = ACTIONS(2497),
    [sym_this] = ACTIONS(2497),
    [anon_sym___launch_bounds__] = ACTIONS(2497),
  },
  [STATE(530)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4910),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7549),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7843),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2928),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(531)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [anon_sym___asm] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(532)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [anon_sym___asm] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(533)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_RBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [anon_sym___asm] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(534)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_RBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [anon_sym___asm] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(535)] = {
    [sym_identifier] = ACTIONS(2395),
    [aux_sym_preproc_include_token1] = ACTIONS(2395),
    [aux_sym_preproc_def_token1] = ACTIONS(2395),
    [aux_sym_preproc_if_token1] = ACTIONS(2395),
    [aux_sym_preproc_if_token2] = ACTIONS(2395),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2395),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2395),
    [sym_preproc_directive] = ACTIONS(2395),
    [anon_sym_LPAREN2] = ACTIONS(2397),
    [anon_sym_BANG] = ACTIONS(2397),
    [anon_sym_TILDE] = ACTIONS(2397),
    [anon_sym_DASH] = ACTIONS(2395),
    [anon_sym_PLUS] = ACTIONS(2395),
    [anon_sym_STAR] = ACTIONS(2397),
    [anon_sym_AMP_AMP] = ACTIONS(2397),
    [anon_sym_AMP] = ACTIONS(2395),
    [anon_sym_SEMI] = ACTIONS(2397),
    [anon_sym___extension__] = ACTIONS(2395),
    [anon_sym_typedef] = ACTIONS(2395),
    [anon_sym___device__] = ACTIONS(2395),
    [anon_sym___host__] = ACTIONS(2395),
    [anon_sym___global__] = ACTIONS(2395),
    [anon_sym___forceinline__] = ACTIONS(2395),
    [anon_sym___noinline__] = ACTIONS(2395),
    [anon_sym_virtual] = ACTIONS(2395),
    [anon_sym_extern] = ACTIONS(2395),
    [anon_sym___attribute__] = ACTIONS(2395),
    [anon_sym___attribute] = ACTIONS(2395),
    [anon_sym_COLON_COLON] = ACTIONS(2397),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2397),
    [anon_sym___declspec] = ACTIONS(2395),
    [anon_sym___based] = ACTIONS(2395),
    [anon_sym___cdecl] = ACTIONS(2395),
    [anon_sym___clrcall] = ACTIONS(2395),
    [anon_sym___stdcall] = ACTIONS(2395),
    [anon_sym___fastcall] = ACTIONS(2395),
    [anon_sym___thiscall] = ACTIONS(2395),
    [anon_sym___vectorcall] = ACTIONS(2395),
    [anon_sym_LBRACE] = ACTIONS(2397),
    [anon_sym_signed] = ACTIONS(2395),
    [anon_sym_unsigned] = ACTIONS(2395),
    [anon_sym_long] = ACTIONS(2395),
    [anon_sym_short] = ACTIONS(2395),
    [anon_sym_LBRACK] = ACTIONS(2395),
    [anon_sym_static] = ACTIONS(2395),
    [anon_sym_register] = ACTIONS(2395),
    [anon_sym_inline] = ACTIONS(2395),
    [anon_sym___inline] = ACTIONS(2395),
    [anon_sym___inline__] = ACTIONS(2395),
    [anon_sym___forceinline] = ACTIONS(2395),
    [anon_sym_thread_local] = ACTIONS(2395),
    [anon_sym___thread] = ACTIONS(2395),
    [anon_sym_const] = ACTIONS(2395),
    [anon_sym_constexpr] = ACTIONS(2395),
    [anon_sym_volatile] = ACTIONS(2395),
    [anon_sym_restrict] = ACTIONS(2395),
    [anon_sym___restrict__] = ACTIONS(2395),
    [anon_sym__Atomic] = ACTIONS(2395),
    [anon_sym__Noreturn] = ACTIONS(2395),
    [anon_sym_noreturn] = ACTIONS(2395),
    [anon_sym__Nonnull] = ACTIONS(2395),
    [anon_sym_mutable] = ACTIONS(2395),
    [anon_sym_constinit] = ACTIONS(2395),
    [anon_sym_consteval] = ACTIONS(2395),
    [anon_sym___shared__] = ACTIONS(2395),
    [anon_sym___local__] = ACTIONS(2395),
    [anon_sym___constant__] = ACTIONS(2395),
    [anon_sym___managed__] = ACTIONS(2395),
    [anon_sym___grid_constant__] = ACTIONS(2395),
    [anon_sym_alignas] = ACTIONS(2395),
    [anon_sym__Alignas] = ACTIONS(2395),
    [sym_primitive_type] = ACTIONS(2395),
    [anon_sym_enum] = ACTIONS(2395),
    [anon_sym_class] = ACTIONS(2395),
    [anon_sym_struct] = ACTIONS(2395),
    [anon_sym_union] = ACTIONS(2395),
    [anon_sym_if] = ACTIONS(2395),
    [anon_sym_switch] = ACTIONS(2395),
    [anon_sym_case] = ACTIONS(2395),
    [anon_sym_default] = ACTIONS(2395),
    [anon_sym_while] = ACTIONS(2395),
    [anon_sym_do] = ACTIONS(2395),
    [anon_sym_for] = ACTIONS(2395),
    [anon_sym_return] = ACTIONS(2395),
    [anon_sym_break] = ACTIONS(2395),
    [anon_sym_continue] = ACTIONS(2395),
    [anon_sym_goto] = ACTIONS(2395),
    [anon_sym___try] = ACTIONS(2395),
    [anon_sym___leave] = ACTIONS(2395),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_compl] = ACTIONS(2395),
    [anon_sym_DASH_DASH] = ACTIONS(2397),
    [anon_sym_PLUS_PLUS] = ACTIONS(2397),
    [anon_sym_sizeof] = ACTIONS(2395),
    [anon_sym___alignof__] = ACTIONS(2395),
    [anon_sym___alignof] = ACTIONS(2395),
    [anon_sym__alignof] = ACTIONS(2395),
    [anon_sym_alignof] = ACTIONS(2395),
    [anon_sym__Alignof] = ACTIONS(2395),
    [anon_sym_offsetof] = ACTIONS(2395),
    [anon_sym__Generic] = ACTIONS(2395),
    [anon_sym_asm] = ACTIONS(2395),
    [anon_sym___asm__] = ACTIONS(2395),
    [anon_sym___asm] = ACTIONS(2395),
    [sym_number_literal] = ACTIONS(2397),
    [anon_sym_L_SQUOTE] = ACTIONS(2397),
    [anon_sym_u_SQUOTE] = ACTIONS(2397),
    [anon_sym_U_SQUOTE] = ACTIONS(2397),
    [anon_sym_u8_SQUOTE] = ACTIONS(2397),
    [anon_sym_SQUOTE] = ACTIONS(2397),
    [anon_sym_L_DQUOTE] = ACTIONS(2397),
    [anon_sym_u_DQUOTE] = ACTIONS(2397),
    [anon_sym_U_DQUOTE] = ACTIONS(2397),
    [anon_sym_u8_DQUOTE] = ACTIONS(2397),
    [anon_sym_DQUOTE] = ACTIONS(2397),
    [sym_true] = ACTIONS(2395),
    [sym_false] = ACTIONS(2395),
    [anon_sym_NULL] = ACTIONS(2395),
    [anon_sym_nullptr] = ACTIONS(2395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2395),
    [anon_sym_decltype] = ACTIONS(2395),
    [anon_sym_explicit] = ACTIONS(2395),
    [anon_sym_typename] = ACTIONS(2395),
    [anon_sym_template] = ACTIONS(2395),
    [anon_sym_operator] = ACTIONS(2395),
    [anon_sym_try] = ACTIONS(2395),
    [anon_sym_delete] = ACTIONS(2395),
    [anon_sym_throw] = ACTIONS(2395),
    [anon_sym_namespace] = ACTIONS(2395),
    [anon_sym_using] = ACTIONS(2395),
    [anon_sym_static_assert] = ACTIONS(2395),
    [anon_sym_concept] = ACTIONS(2395),
    [anon_sym_co_return] = ACTIONS(2395),
    [anon_sym_co_yield] = ACTIONS(2395),
    [anon_sym_R_DQUOTE] = ACTIONS(2397),
    [anon_sym_LR_DQUOTE] = ACTIONS(2397),
    [anon_sym_uR_DQUOTE] = ACTIONS(2397),
    [anon_sym_UR_DQUOTE] = ACTIONS(2397),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2397),
    [anon_sym_co_await] = ACTIONS(2395),
    [anon_sym_new] = ACTIONS(2395),
    [anon_sym_requires] = ACTIONS(2395),
    [sym_this] = ACTIONS(2395),
    [anon_sym___launch_bounds__] = ACTIONS(2395),
  },
  [STATE(536)] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym___device__] = ACTIONS(2332),
    [anon_sym___host__] = ACTIONS(2332),
    [anon_sym___global__] = ACTIONS(2332),
    [anon_sym___forceinline__] = ACTIONS(2332),
    [anon_sym___noinline__] = ACTIONS(2332),
    [anon_sym_virtual] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym___attribute] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym__Nonnull] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym___shared__] = ACTIONS(2332),
    [anon_sym___local__] = ACTIONS(2332),
    [anon_sym___constant__] = ACTIONS(2332),
    [anon_sym___managed__] = ACTIONS(2332),
    [anon_sym___grid_constant__] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [anon_sym___asm] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym___launch_bounds__] = ACTIONS(2332),
  },
  [STATE(537)] = {
    [sym_identifier] = ACTIONS(2339),
    [aux_sym_preproc_include_token1] = ACTIONS(2339),
    [aux_sym_preproc_def_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2339),
    [sym_preproc_directive] = ACTIONS(2339),
    [anon_sym_LPAREN2] = ACTIONS(2341),
    [anon_sym_BANG] = ACTIONS(2341),
    [anon_sym_TILDE] = ACTIONS(2341),
    [anon_sym_DASH] = ACTIONS(2339),
    [anon_sym_PLUS] = ACTIONS(2339),
    [anon_sym_STAR] = ACTIONS(2341),
    [anon_sym_AMP_AMP] = ACTIONS(2341),
    [anon_sym_AMP] = ACTIONS(2339),
    [anon_sym_SEMI] = ACTIONS(2341),
    [anon_sym___extension__] = ACTIONS(2339),
    [anon_sym_typedef] = ACTIONS(2339),
    [anon_sym___device__] = ACTIONS(2339),
    [anon_sym___host__] = ACTIONS(2339),
    [anon_sym___global__] = ACTIONS(2339),
    [anon_sym___forceinline__] = ACTIONS(2339),
    [anon_sym___noinline__] = ACTIONS(2339),
    [anon_sym_virtual] = ACTIONS(2339),
    [anon_sym_extern] = ACTIONS(2339),
    [anon_sym___attribute__] = ACTIONS(2339),
    [anon_sym___attribute] = ACTIONS(2339),
    [anon_sym_COLON_COLON] = ACTIONS(2341),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2341),
    [anon_sym___declspec] = ACTIONS(2339),
    [anon_sym___based] = ACTIONS(2339),
    [anon_sym___cdecl] = ACTIONS(2339),
    [anon_sym___clrcall] = ACTIONS(2339),
    [anon_sym___stdcall] = ACTIONS(2339),
    [anon_sym___fastcall] = ACTIONS(2339),
    [anon_sym___thiscall] = ACTIONS(2339),
    [anon_sym___vectorcall] = ACTIONS(2339),
    [anon_sym_LBRACE] = ACTIONS(2341),
    [anon_sym_RBRACE] = ACTIONS(2341),
    [anon_sym_signed] = ACTIONS(2339),
    [anon_sym_unsigned] = ACTIONS(2339),
    [anon_sym_long] = ACTIONS(2339),
    [anon_sym_short] = ACTIONS(2339),
    [anon_sym_LBRACK] = ACTIONS(2339),
    [anon_sym_static] = ACTIONS(2339),
    [anon_sym_register] = ACTIONS(2339),
    [anon_sym_inline] = ACTIONS(2339),
    [anon_sym___inline] = ACTIONS(2339),
    [anon_sym___inline__] = ACTIONS(2339),
    [anon_sym___forceinline] = ACTIONS(2339),
    [anon_sym_thread_local] = ACTIONS(2339),
    [anon_sym___thread] = ACTIONS(2339),
    [anon_sym_const] = ACTIONS(2339),
    [anon_sym_constexpr] = ACTIONS(2339),
    [anon_sym_volatile] = ACTIONS(2339),
    [anon_sym_restrict] = ACTIONS(2339),
    [anon_sym___restrict__] = ACTIONS(2339),
    [anon_sym__Atomic] = ACTIONS(2339),
    [anon_sym__Noreturn] = ACTIONS(2339),
    [anon_sym_noreturn] = ACTIONS(2339),
    [anon_sym__Nonnull] = ACTIONS(2339),
    [anon_sym_mutable] = ACTIONS(2339),
    [anon_sym_constinit] = ACTIONS(2339),
    [anon_sym_consteval] = ACTIONS(2339),
    [anon_sym___shared__] = ACTIONS(2339),
    [anon_sym___local__] = ACTIONS(2339),
    [anon_sym___constant__] = ACTIONS(2339),
    [anon_sym___managed__] = ACTIONS(2339),
    [anon_sym___grid_constant__] = ACTIONS(2339),
    [anon_sym_alignas] = ACTIONS(2339),
    [anon_sym__Alignas] = ACTIONS(2339),
    [sym_primitive_type] = ACTIONS(2339),
    [anon_sym_enum] = ACTIONS(2339),
    [anon_sym_class] = ACTIONS(2339),
    [anon_sym_struct] = ACTIONS(2339),
    [anon_sym_union] = ACTIONS(2339),
    [anon_sym_if] = ACTIONS(2339),
    [anon_sym_switch] = ACTIONS(2339),
    [anon_sym_case] = ACTIONS(2339),
    [anon_sym_default] = ACTIONS(2339),
    [anon_sym_while] = ACTIONS(2339),
    [anon_sym_do] = ACTIONS(2339),
    [anon_sym_for] = ACTIONS(2339),
    [anon_sym_return] = ACTIONS(2339),
    [anon_sym_break] = ACTIONS(2339),
    [anon_sym_continue] = ACTIONS(2339),
    [anon_sym_goto] = ACTIONS(2339),
    [anon_sym___try] = ACTIONS(2339),
    [anon_sym___leave] = ACTIONS(2339),
    [anon_sym_not] = ACTIONS(2339),
    [anon_sym_compl] = ACTIONS(2339),
    [anon_sym_DASH_DASH] = ACTIONS(2341),
    [anon_sym_PLUS_PLUS] = ACTIONS(2341),
    [anon_sym_sizeof] = ACTIONS(2339),
    [anon_sym___alignof__] = ACTIONS(2339),
    [anon_sym___alignof] = ACTIONS(2339),
    [anon_sym__alignof] = ACTIONS(2339),
    [anon_sym_alignof] = ACTIONS(2339),
    [anon_sym__Alignof] = ACTIONS(2339),
    [anon_sym_offsetof] = ACTIONS(2339),
    [anon_sym__Generic] = ACTIONS(2339),
    [anon_sym_asm] = ACTIONS(2339),
    [anon_sym___asm__] = ACTIONS(2339),
    [anon_sym___asm] = ACTIONS(2339),
    [sym_number_literal] = ACTIONS(2341),
    [anon_sym_L_SQUOTE] = ACTIONS(2341),
    [anon_sym_u_SQUOTE] = ACTIONS(2341),
    [anon_sym_U_SQUOTE] = ACTIONS(2341),
    [anon_sym_u8_SQUOTE] = ACTIONS(2341),
    [anon_sym_SQUOTE] = ACTIONS(2341),
    [anon_sym_L_DQUOTE] = ACTIONS(2341),
    [anon_sym_u_DQUOTE] = ACTIONS(2341),
    [anon_sym_U_DQUOTE] = ACTIONS(2341),
    [anon_sym_u8_DQUOTE] = ACTIONS(2341),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_true] = ACTIONS(2339),
    [sym_false] = ACTIONS(2339),
    [anon_sym_NULL] = ACTIONS(2339),
    [anon_sym_nullptr] = ACTIONS(2339),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2339),
    [anon_sym_decltype] = ACTIONS(2339),
    [anon_sym_explicit] = ACTIONS(2339),
    [anon_sym_typename] = ACTIONS(2339),
    [anon_sym_template] = ACTIONS(2339),
    [anon_sym_operator] = ACTIONS(2339),
    [anon_sym_try] = ACTIONS(2339),
    [anon_sym_delete] = ACTIONS(2339),
    [anon_sym_throw] = ACTIONS(2339),
    [anon_sym_namespace] = ACTIONS(2339),
    [anon_sym_using] = ACTIONS(2339),
    [anon_sym_static_assert] = ACTIONS(2339),
    [anon_sym_concept] = ACTIONS(2339),
    [anon_sym_co_return] = ACTIONS(2339),
    [anon_sym_co_yield] = ACTIONS(2339),
    [anon_sym_R_DQUOTE] = ACTIONS(2341),
    [anon_sym_LR_DQUOTE] = ACTIONS(2341),
    [anon_sym_uR_DQUOTE] = ACTIONS(2341),
    [anon_sym_UR_DQUOTE] = ACTIONS(2341),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2341),
    [anon_sym_co_await] = ACTIONS(2339),
    [anon_sym_new] = ACTIONS(2339),
    [anon_sym_requires] = ACTIONS(2339),
    [sym_this] = ACTIONS(2339),
    [anon_sym___launch_bounds__] = ACTIONS(2339),
  },
  [STATE(538)] = {
    [sym_identifier] = ACTIONS(2343),
    [aux_sym_preproc_include_token1] = ACTIONS(2343),
    [aux_sym_preproc_def_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2343),
    [sym_preproc_directive] = ACTIONS(2343),
    [anon_sym_LPAREN2] = ACTIONS(2345),
    [anon_sym_BANG] = ACTIONS(2345),
    [anon_sym_TILDE] = ACTIONS(2345),
    [anon_sym_DASH] = ACTIONS(2343),
    [anon_sym_PLUS] = ACTIONS(2343),
    [anon_sym_STAR] = ACTIONS(2345),
    [anon_sym_AMP_AMP] = ACTIONS(2345),
    [anon_sym_AMP] = ACTIONS(2343),
    [anon_sym_SEMI] = ACTIONS(2345),
    [anon_sym___extension__] = ACTIONS(2343),
    [anon_sym_typedef] = ACTIONS(2343),
    [anon_sym___device__] = ACTIONS(2343),
    [anon_sym___host__] = ACTIONS(2343),
    [anon_sym___global__] = ACTIONS(2343),
    [anon_sym___forceinline__] = ACTIONS(2343),
    [anon_sym___noinline__] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2343),
    [anon_sym_extern] = ACTIONS(2343),
    [anon_sym___attribute__] = ACTIONS(2343),
    [anon_sym___attribute] = ACTIONS(2343),
    [anon_sym_COLON_COLON] = ACTIONS(2345),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2345),
    [anon_sym___declspec] = ACTIONS(2343),
    [anon_sym___based] = ACTIONS(2343),
    [anon_sym___cdecl] = ACTIONS(2343),
    [anon_sym___clrcall] = ACTIONS(2343),
    [anon_sym___stdcall] = ACTIONS(2343),
    [anon_sym___fastcall] = ACTIONS(2343),
    [anon_sym___thiscall] = ACTIONS(2343),
    [anon_sym___vectorcall] = ACTIONS(2343),
    [anon_sym_LBRACE] = ACTIONS(2345),
    [anon_sym_RBRACE] = ACTIONS(2345),
    [anon_sym_signed] = ACTIONS(2343),
    [anon_sym_unsigned] = ACTIONS(2343),
    [anon_sym_long] = ACTIONS(2343),
    [anon_sym_short] = ACTIONS(2343),
    [anon_sym_LBRACK] = ACTIONS(2343),
    [anon_sym_static] = ACTIONS(2343),
    [anon_sym_register] = ACTIONS(2343),
    [anon_sym_inline] = ACTIONS(2343),
    [anon_sym___inline] = ACTIONS(2343),
    [anon_sym___inline__] = ACTIONS(2343),
    [anon_sym___forceinline] = ACTIONS(2343),
    [anon_sym_thread_local] = ACTIONS(2343),
    [anon_sym___thread] = ACTIONS(2343),
    [anon_sym_const] = ACTIONS(2343),
    [anon_sym_constexpr] = ACTIONS(2343),
    [anon_sym_volatile] = ACTIONS(2343),
    [anon_sym_restrict] = ACTIONS(2343),
    [anon_sym___restrict__] = ACTIONS(2343),
    [anon_sym__Atomic] = ACTIONS(2343),
    [anon_sym__Noreturn] = ACTIONS(2343),
    [anon_sym_noreturn] = ACTIONS(2343),
    [anon_sym__Nonnull] = ACTIONS(2343),
    [anon_sym_mutable] = ACTIONS(2343),
    [anon_sym_constinit] = ACTIONS(2343),
    [anon_sym_consteval] = ACTIONS(2343),
    [anon_sym___shared__] = ACTIONS(2343),
    [anon_sym___local__] = ACTIONS(2343),
    [anon_sym___constant__] = ACTIONS(2343),
    [anon_sym___managed__] = ACTIONS(2343),
    [anon_sym___grid_constant__] = ACTIONS(2343),
    [anon_sym_alignas] = ACTIONS(2343),
    [anon_sym__Alignas] = ACTIONS(2343),
    [sym_primitive_type] = ACTIONS(2343),
    [anon_sym_enum] = ACTIONS(2343),
    [anon_sym_class] = ACTIONS(2343),
    [anon_sym_struct] = ACTIONS(2343),
    [anon_sym_union] = ACTIONS(2343),
    [anon_sym_if] = ACTIONS(2343),
    [anon_sym_switch] = ACTIONS(2343),
    [anon_sym_case] = ACTIONS(2343),
    [anon_sym_default] = ACTIONS(2343),
    [anon_sym_while] = ACTIONS(2343),
    [anon_sym_do] = ACTIONS(2343),
    [anon_sym_for] = ACTIONS(2343),
    [anon_sym_return] = ACTIONS(2343),
    [anon_sym_break] = ACTIONS(2343),
    [anon_sym_continue] = ACTIONS(2343),
    [anon_sym_goto] = ACTIONS(2343),
    [anon_sym___try] = ACTIONS(2343),
    [anon_sym___leave] = ACTIONS(2343),
    [anon_sym_not] = ACTIONS(2343),
    [anon_sym_compl] = ACTIONS(2343),
    [anon_sym_DASH_DASH] = ACTIONS(2345),
    [anon_sym_PLUS_PLUS] = ACTIONS(2345),
    [anon_sym_sizeof] = ACTIONS(2343),
    [anon_sym___alignof__] = ACTIONS(2343),
    [anon_sym___alignof] = ACTIONS(2343),
    [anon_sym__alignof] = ACTIONS(2343),
    [anon_sym_alignof] = ACTIONS(2343),
    [anon_sym__Alignof] = ACTIONS(2343),
    [anon_sym_offsetof] = ACTIONS(2343),
    [anon_sym__Generic] = ACTIONS(2343),
    [anon_sym_asm] = ACTIONS(2343),
    [anon_sym___asm__] = ACTIONS(2343),
    [anon_sym___asm] = ACTIONS(2343),
    [sym_number_literal] = ACTIONS(2345),
    [anon_sym_L_SQUOTE] = ACTIONS(2345),
    [anon_sym_u_SQUOTE] = ACTIONS(2345),
    [anon_sym_U_SQUOTE] = ACTIONS(2345),
    [anon_sym_u8_SQUOTE] = ACTIONS(2345),
    [anon_sym_SQUOTE] = ACTIONS(2345),
    [anon_sym_L_DQUOTE] = ACTIONS(2345),
    [anon_sym_u_DQUOTE] = ACTIONS(2345),
    [anon_sym_U_DQUOTE] = ACTIONS(2345),
    [anon_sym_u8_DQUOTE] = ACTIONS(2345),
    [anon_sym_DQUOTE] = ACTIONS(2345),
    [sym_true] = ACTIONS(2343),
    [sym_false] = ACTIONS(2343),
    [anon_sym_NULL] = ACTIONS(2343),
    [anon_sym_nullptr] = ACTIONS(2343),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2343),
    [anon_sym_decltype] = ACTIONS(2343),
    [anon_sym_explicit] = ACTIONS(2343),
    [anon_sym_typename] = ACTIONS(2343),
    [anon_sym_template] = ACTIONS(2343),
    [anon_sym_operator] = ACTIONS(2343),
    [anon_sym_try] = ACTIONS(2343),
    [anon_sym_delete] = ACTIONS(2343),
    [anon_sym_throw] = ACTIONS(2343),
    [anon_sym_namespace] = ACTIONS(2343),
    [anon_sym_using] = ACTIONS(2343),
    [anon_sym_static_assert] = ACTIONS(2343),
    [anon_sym_concept] = ACTIONS(2343),
    [anon_sym_co_return] = ACTIONS(2343),
    [anon_sym_co_yield] = ACTIONS(2343),
    [anon_sym_R_DQUOTE] = ACTIONS(2345),
    [anon_sym_LR_DQUOTE] = ACTIONS(2345),
    [anon_sym_uR_DQUOTE] = ACTIONS(2345),
    [anon_sym_UR_DQUOTE] = ACTIONS(2345),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2345),
    [anon_sym_co_await] = ACTIONS(2343),
    [anon_sym_new] = ACTIONS(2343),
    [anon_sym_requires] = ACTIONS(2343),
    [sym_this] = ACTIONS(2343),
    [anon_sym___launch_bounds__] = ACTIONS(2343),
  },
  [STATE(539)] = {
    [sym_identifier] = ACTIONS(2347),
    [aux_sym_preproc_include_token1] = ACTIONS(2347),
    [aux_sym_preproc_def_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2347),
    [sym_preproc_directive] = ACTIONS(2347),
    [anon_sym_LPAREN2] = ACTIONS(2349),
    [anon_sym_BANG] = ACTIONS(2349),
    [anon_sym_TILDE] = ACTIONS(2349),
    [anon_sym_DASH] = ACTIONS(2347),
    [anon_sym_PLUS] = ACTIONS(2347),
    [anon_sym_STAR] = ACTIONS(2349),
    [anon_sym_AMP_AMP] = ACTIONS(2349),
    [anon_sym_AMP] = ACTIONS(2347),
    [anon_sym_SEMI] = ACTIONS(2349),
    [anon_sym___extension__] = ACTIONS(2347),
    [anon_sym_typedef] = ACTIONS(2347),
    [anon_sym___device__] = ACTIONS(2347),
    [anon_sym___host__] = ACTIONS(2347),
    [anon_sym___global__] = ACTIONS(2347),
    [anon_sym___forceinline__] = ACTIONS(2347),
    [anon_sym___noinline__] = ACTIONS(2347),
    [anon_sym_virtual] = ACTIONS(2347),
    [anon_sym_extern] = ACTIONS(2347),
    [anon_sym___attribute__] = ACTIONS(2347),
    [anon_sym___attribute] = ACTIONS(2347),
    [anon_sym_COLON_COLON] = ACTIONS(2349),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2349),
    [anon_sym___declspec] = ACTIONS(2347),
    [anon_sym___based] = ACTIONS(2347),
    [anon_sym___cdecl] = ACTIONS(2347),
    [anon_sym___clrcall] = ACTIONS(2347),
    [anon_sym___stdcall] = ACTIONS(2347),
    [anon_sym___fastcall] = ACTIONS(2347),
    [anon_sym___thiscall] = ACTIONS(2347),
    [anon_sym___vectorcall] = ACTIONS(2347),
    [anon_sym_LBRACE] = ACTIONS(2349),
    [anon_sym_RBRACE] = ACTIONS(2349),
    [anon_sym_signed] = ACTIONS(2347),
    [anon_sym_unsigned] = ACTIONS(2347),
    [anon_sym_long] = ACTIONS(2347),
    [anon_sym_short] = ACTIONS(2347),
    [anon_sym_LBRACK] = ACTIONS(2347),
    [anon_sym_static] = ACTIONS(2347),
    [anon_sym_register] = ACTIONS(2347),
    [anon_sym_inline] = ACTIONS(2347),
    [anon_sym___inline] = ACTIONS(2347),
    [anon_sym___inline__] = ACTIONS(2347),
    [anon_sym___forceinline] = ACTIONS(2347),
    [anon_sym_thread_local] = ACTIONS(2347),
    [anon_sym___thread] = ACTIONS(2347),
    [anon_sym_const] = ACTIONS(2347),
    [anon_sym_constexpr] = ACTIONS(2347),
    [anon_sym_volatile] = ACTIONS(2347),
    [anon_sym_restrict] = ACTIONS(2347),
    [anon_sym___restrict__] = ACTIONS(2347),
    [anon_sym__Atomic] = ACTIONS(2347),
    [anon_sym__Noreturn] = ACTIONS(2347),
    [anon_sym_noreturn] = ACTIONS(2347),
    [anon_sym__Nonnull] = ACTIONS(2347),
    [anon_sym_mutable] = ACTIONS(2347),
    [anon_sym_constinit] = ACTIONS(2347),
    [anon_sym_consteval] = ACTIONS(2347),
    [anon_sym___shared__] = ACTIONS(2347),
    [anon_sym___local__] = ACTIONS(2347),
    [anon_sym___constant__] = ACTIONS(2347),
    [anon_sym___managed__] = ACTIONS(2347),
    [anon_sym___grid_constant__] = ACTIONS(2347),
    [anon_sym_alignas] = ACTIONS(2347),
    [anon_sym__Alignas] = ACTIONS(2347),
    [sym_primitive_type] = ACTIONS(2347),
    [anon_sym_enum] = ACTIONS(2347),
    [anon_sym_class] = ACTIONS(2347),
    [anon_sym_struct] = ACTIONS(2347),
    [anon_sym_union] = ACTIONS(2347),
    [anon_sym_if] = ACTIONS(2347),
    [anon_sym_switch] = ACTIONS(2347),
    [anon_sym_case] = ACTIONS(2347),
    [anon_sym_default] = ACTIONS(2347),
    [anon_sym_while] = ACTIONS(2347),
    [anon_sym_do] = ACTIONS(2347),
    [anon_sym_for] = ACTIONS(2347),
    [anon_sym_return] = ACTIONS(2347),
    [anon_sym_break] = ACTIONS(2347),
    [anon_sym_continue] = ACTIONS(2347),
    [anon_sym_goto] = ACTIONS(2347),
    [anon_sym___try] = ACTIONS(2347),
    [anon_sym___leave] = ACTIONS(2347),
    [anon_sym_not] = ACTIONS(2347),
    [anon_sym_compl] = ACTIONS(2347),
    [anon_sym_DASH_DASH] = ACTIONS(2349),
    [anon_sym_PLUS_PLUS] = ACTIONS(2349),
    [anon_sym_sizeof] = ACTIONS(2347),
    [anon_sym___alignof__] = ACTIONS(2347),
    [anon_sym___alignof] = ACTIONS(2347),
    [anon_sym__alignof] = ACTIONS(2347),
    [anon_sym_alignof] = ACTIONS(2347),
    [anon_sym__Alignof] = ACTIONS(2347),
    [anon_sym_offsetof] = ACTIONS(2347),
    [anon_sym__Generic] = ACTIONS(2347),
    [anon_sym_asm] = ACTIONS(2347),
    [anon_sym___asm__] = ACTIONS(2347),
    [anon_sym___asm] = ACTIONS(2347),
    [sym_number_literal] = ACTIONS(2349),
    [anon_sym_L_SQUOTE] = ACTIONS(2349),
    [anon_sym_u_SQUOTE] = ACTIONS(2349),
    [anon_sym_U_SQUOTE] = ACTIONS(2349),
    [anon_sym_u8_SQUOTE] = ACTIONS(2349),
    [anon_sym_SQUOTE] = ACTIONS(2349),
    [anon_sym_L_DQUOTE] = ACTIONS(2349),
    [anon_sym_u_DQUOTE] = ACTIONS(2349),
    [anon_sym_U_DQUOTE] = ACTIONS(2349),
    [anon_sym_u8_DQUOTE] = ACTIONS(2349),
    [anon_sym_DQUOTE] = ACTIONS(2349),
    [sym_true] = ACTIONS(2347),
    [sym_false] = ACTIONS(2347),
    [anon_sym_NULL] = ACTIONS(2347),
    [anon_sym_nullptr] = ACTIONS(2347),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2347),
    [anon_sym_decltype] = ACTIONS(2347),
    [anon_sym_explicit] = ACTIONS(2347),
    [anon_sym_typename] = ACTIONS(2347),
    [anon_sym_template] = ACTIONS(2347),
    [anon_sym_operator] = ACTIONS(2347),
    [anon_sym_try] = ACTIONS(2347),
    [anon_sym_delete] = ACTIONS(2347),
    [anon_sym_throw] = ACTIONS(2347),
    [anon_sym_namespace] = ACTIONS(2347),
    [anon_sym_using] = ACTIONS(2347),
    [anon_sym_static_assert] = ACTIONS(2347),
    [anon_sym_concept] = ACTIONS(2347),
    [anon_sym_co_return] = ACTIONS(2347),
    [anon_sym_co_yield] = ACTIONS(2347),
    [anon_sym_R_DQUOTE] = ACTIONS(2349),
    [anon_sym_LR_DQUOTE] = ACTIONS(2349),
    [anon_sym_uR_DQUOTE] = ACTIONS(2349),
    [anon_sym_UR_DQUOTE] = ACTIONS(2349),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2349),
    [anon_sym_co_await] = ACTIONS(2347),
    [anon_sym_new] = ACTIONS(2347),
    [anon_sym_requires] = ACTIONS(2347),
    [sym_this] = ACTIONS(2347),
    [anon_sym___launch_bounds__] = ACTIONS(2347),
  },
  [STATE(540)] = {
    [sym_identifier] = ACTIONS(2351),
    [aux_sym_preproc_include_token1] = ACTIONS(2351),
    [aux_sym_preproc_def_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2351),
    [sym_preproc_directive] = ACTIONS(2351),
    [anon_sym_LPAREN2] = ACTIONS(2353),
    [anon_sym_BANG] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(2353),
    [anon_sym_DASH] = ACTIONS(2351),
    [anon_sym_PLUS] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2353),
    [anon_sym_AMP_AMP] = ACTIONS(2353),
    [anon_sym_AMP] = ACTIONS(2351),
    [anon_sym_SEMI] = ACTIONS(2353),
    [anon_sym___extension__] = ACTIONS(2351),
    [anon_sym_typedef] = ACTIONS(2351),
    [anon_sym___device__] = ACTIONS(2351),
    [anon_sym___host__] = ACTIONS(2351),
    [anon_sym___global__] = ACTIONS(2351),
    [anon_sym___forceinline__] = ACTIONS(2351),
    [anon_sym___noinline__] = ACTIONS(2351),
    [anon_sym_virtual] = ACTIONS(2351),
    [anon_sym_extern] = ACTIONS(2351),
    [anon_sym___attribute__] = ACTIONS(2351),
    [anon_sym___attribute] = ACTIONS(2351),
    [anon_sym_COLON_COLON] = ACTIONS(2353),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2353),
    [anon_sym___declspec] = ACTIONS(2351),
    [anon_sym___based] = ACTIONS(2351),
    [anon_sym___cdecl] = ACTIONS(2351),
    [anon_sym___clrcall] = ACTIONS(2351),
    [anon_sym___stdcall] = ACTIONS(2351),
    [anon_sym___fastcall] = ACTIONS(2351),
    [anon_sym___thiscall] = ACTIONS(2351),
    [anon_sym___vectorcall] = ACTIONS(2351),
    [anon_sym_LBRACE] = ACTIONS(2353),
    [anon_sym_RBRACE] = ACTIONS(2353),
    [anon_sym_signed] = ACTIONS(2351),
    [anon_sym_unsigned] = ACTIONS(2351),
    [anon_sym_long] = ACTIONS(2351),
    [anon_sym_short] = ACTIONS(2351),
    [anon_sym_LBRACK] = ACTIONS(2351),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_register] = ACTIONS(2351),
    [anon_sym_inline] = ACTIONS(2351),
    [anon_sym___inline] = ACTIONS(2351),
    [anon_sym___inline__] = ACTIONS(2351),
    [anon_sym___forceinline] = ACTIONS(2351),
    [anon_sym_thread_local] = ACTIONS(2351),
    [anon_sym___thread] = ACTIONS(2351),
    [anon_sym_const] = ACTIONS(2351),
    [anon_sym_constexpr] = ACTIONS(2351),
    [anon_sym_volatile] = ACTIONS(2351),
    [anon_sym_restrict] = ACTIONS(2351),
    [anon_sym___restrict__] = ACTIONS(2351),
    [anon_sym__Atomic] = ACTIONS(2351),
    [anon_sym__Noreturn] = ACTIONS(2351),
    [anon_sym_noreturn] = ACTIONS(2351),
    [anon_sym__Nonnull] = ACTIONS(2351),
    [anon_sym_mutable] = ACTIONS(2351),
    [anon_sym_constinit] = ACTIONS(2351),
    [anon_sym_consteval] = ACTIONS(2351),
    [anon_sym___shared__] = ACTIONS(2351),
    [anon_sym___local__] = ACTIONS(2351),
    [anon_sym___constant__] = ACTIONS(2351),
    [anon_sym___managed__] = ACTIONS(2351),
    [anon_sym___grid_constant__] = ACTIONS(2351),
    [anon_sym_alignas] = ACTIONS(2351),
    [anon_sym__Alignas] = ACTIONS(2351),
    [sym_primitive_type] = ACTIONS(2351),
    [anon_sym_enum] = ACTIONS(2351),
    [anon_sym_class] = ACTIONS(2351),
    [anon_sym_struct] = ACTIONS(2351),
    [anon_sym_union] = ACTIONS(2351),
    [anon_sym_if] = ACTIONS(2351),
    [anon_sym_switch] = ACTIONS(2351),
    [anon_sym_case] = ACTIONS(2351),
    [anon_sym_default] = ACTIONS(2351),
    [anon_sym_while] = ACTIONS(2351),
    [anon_sym_do] = ACTIONS(2351),
    [anon_sym_for] = ACTIONS(2351),
    [anon_sym_return] = ACTIONS(2351),
    [anon_sym_break] = ACTIONS(2351),
    [anon_sym_continue] = ACTIONS(2351),
    [anon_sym_goto] = ACTIONS(2351),
    [anon_sym___try] = ACTIONS(2351),
    [anon_sym___leave] = ACTIONS(2351),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_compl] = ACTIONS(2351),
    [anon_sym_DASH_DASH] = ACTIONS(2353),
    [anon_sym_PLUS_PLUS] = ACTIONS(2353),
    [anon_sym_sizeof] = ACTIONS(2351),
    [anon_sym___alignof__] = ACTIONS(2351),
    [anon_sym___alignof] = ACTIONS(2351),
    [anon_sym__alignof] = ACTIONS(2351),
    [anon_sym_alignof] = ACTIONS(2351),
    [anon_sym__Alignof] = ACTIONS(2351),
    [anon_sym_offsetof] = ACTIONS(2351),
    [anon_sym__Generic] = ACTIONS(2351),
    [anon_sym_asm] = ACTIONS(2351),
    [anon_sym___asm__] = ACTIONS(2351),
    [anon_sym___asm] = ACTIONS(2351),
    [sym_number_literal] = ACTIONS(2353),
    [anon_sym_L_SQUOTE] = ACTIONS(2353),
    [anon_sym_u_SQUOTE] = ACTIONS(2353),
    [anon_sym_U_SQUOTE] = ACTIONS(2353),
    [anon_sym_u8_SQUOTE] = ACTIONS(2353),
    [anon_sym_SQUOTE] = ACTIONS(2353),
    [anon_sym_L_DQUOTE] = ACTIONS(2353),
    [anon_sym_u_DQUOTE] = ACTIONS(2353),
    [anon_sym_U_DQUOTE] = ACTIONS(2353),
    [anon_sym_u8_DQUOTE] = ACTIONS(2353),
    [anon_sym_DQUOTE] = ACTIONS(2353),
    [sym_true] = ACTIONS(2351),
    [sym_false] = ACTIONS(2351),
    [anon_sym_NULL] = ACTIONS(2351),
    [anon_sym_nullptr] = ACTIONS(2351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2351),
    [anon_sym_decltype] = ACTIONS(2351),
    [anon_sym_explicit] = ACTIONS(2351),
    [anon_sym_typename] = ACTIONS(2351),
    [anon_sym_template] = ACTIONS(2351),
    [anon_sym_operator] = ACTIONS(2351),
    [anon_sym_try] = ACTIONS(2351),
    [anon_sym_delete] = ACTIONS(2351),
    [anon_sym_throw] = ACTIONS(2351),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_using] = ACTIONS(2351),
    [anon_sym_static_assert] = ACTIONS(2351),
    [anon_sym_concept] = ACTIONS(2351),
    [anon_sym_co_return] = ACTIONS(2351),
    [anon_sym_co_yield] = ACTIONS(2351),
    [anon_sym_R_DQUOTE] = ACTIONS(2353),
    [anon_sym_LR_DQUOTE] = ACTIONS(2353),
    [anon_sym_uR_DQUOTE] = ACTIONS(2353),
    [anon_sym_UR_DQUOTE] = ACTIONS(2353),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2353),
    [anon_sym_co_await] = ACTIONS(2351),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_requires] = ACTIONS(2351),
    [sym_this] = ACTIONS(2351),
    [anon_sym___launch_bounds__] = ACTIONS(2351),
  },
  [STATE(541)] = {
    [sym_identifier] = ACTIONS(2373),
    [aux_sym_preproc_include_token1] = ACTIONS(2373),
    [aux_sym_preproc_def_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2373),
    [sym_preproc_directive] = ACTIONS(2373),
    [anon_sym_LPAREN2] = ACTIONS(2375),
    [anon_sym_BANG] = ACTIONS(2375),
    [anon_sym_TILDE] = ACTIONS(2375),
    [anon_sym_DASH] = ACTIONS(2373),
    [anon_sym_PLUS] = ACTIONS(2373),
    [anon_sym_STAR] = ACTIONS(2375),
    [anon_sym_AMP_AMP] = ACTIONS(2375),
    [anon_sym_AMP] = ACTIONS(2373),
    [anon_sym_SEMI] = ACTIONS(2375),
    [anon_sym___extension__] = ACTIONS(2373),
    [anon_sym_typedef] = ACTIONS(2373),
    [anon_sym___device__] = ACTIONS(2373),
    [anon_sym___host__] = ACTIONS(2373),
    [anon_sym___global__] = ACTIONS(2373),
    [anon_sym___forceinline__] = ACTIONS(2373),
    [anon_sym___noinline__] = ACTIONS(2373),
    [anon_sym_virtual] = ACTIONS(2373),
    [anon_sym_extern] = ACTIONS(2373),
    [anon_sym___attribute__] = ACTIONS(2373),
    [anon_sym___attribute] = ACTIONS(2373),
    [anon_sym_COLON_COLON] = ACTIONS(2375),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2375),
    [anon_sym___declspec] = ACTIONS(2373),
    [anon_sym___based] = ACTIONS(2373),
    [anon_sym___cdecl] = ACTIONS(2373),
    [anon_sym___clrcall] = ACTIONS(2373),
    [anon_sym___stdcall] = ACTIONS(2373),
    [anon_sym___fastcall] = ACTIONS(2373),
    [anon_sym___thiscall] = ACTIONS(2373),
    [anon_sym___vectorcall] = ACTIONS(2373),
    [anon_sym_LBRACE] = ACTIONS(2375),
    [anon_sym_RBRACE] = ACTIONS(2375),
    [anon_sym_signed] = ACTIONS(2373),
    [anon_sym_unsigned] = ACTIONS(2373),
    [anon_sym_long] = ACTIONS(2373),
    [anon_sym_short] = ACTIONS(2373),
    [anon_sym_LBRACK] = ACTIONS(2373),
    [anon_sym_static] = ACTIONS(2373),
    [anon_sym_register] = ACTIONS(2373),
    [anon_sym_inline] = ACTIONS(2373),
    [anon_sym___inline] = ACTIONS(2373),
    [anon_sym___inline__] = ACTIONS(2373),
    [anon_sym___forceinline] = ACTIONS(2373),
    [anon_sym_thread_local] = ACTIONS(2373),
    [anon_sym___thread] = ACTIONS(2373),
    [anon_sym_const] = ACTIONS(2373),
    [anon_sym_constexpr] = ACTIONS(2373),
    [anon_sym_volatile] = ACTIONS(2373),
    [anon_sym_restrict] = ACTIONS(2373),
    [anon_sym___restrict__] = ACTIONS(2373),
    [anon_sym__Atomic] = ACTIONS(2373),
    [anon_sym__Noreturn] = ACTIONS(2373),
    [anon_sym_noreturn] = ACTIONS(2373),
    [anon_sym__Nonnull] = ACTIONS(2373),
    [anon_sym_mutable] = ACTIONS(2373),
    [anon_sym_constinit] = ACTIONS(2373),
    [anon_sym_consteval] = ACTIONS(2373),
    [anon_sym___shared__] = ACTIONS(2373),
    [anon_sym___local__] = ACTIONS(2373),
    [anon_sym___constant__] = ACTIONS(2373),
    [anon_sym___managed__] = ACTIONS(2373),
    [anon_sym___grid_constant__] = ACTIONS(2373),
    [anon_sym_alignas] = ACTIONS(2373),
    [anon_sym__Alignas] = ACTIONS(2373),
    [sym_primitive_type] = ACTIONS(2373),
    [anon_sym_enum] = ACTIONS(2373),
    [anon_sym_class] = ACTIONS(2373),
    [anon_sym_struct] = ACTIONS(2373),
    [anon_sym_union] = ACTIONS(2373),
    [anon_sym_if] = ACTIONS(2373),
    [anon_sym_switch] = ACTIONS(2373),
    [anon_sym_case] = ACTIONS(2373),
    [anon_sym_default] = ACTIONS(2373),
    [anon_sym_while] = ACTIONS(2373),
    [anon_sym_do] = ACTIONS(2373),
    [anon_sym_for] = ACTIONS(2373),
    [anon_sym_return] = ACTIONS(2373),
    [anon_sym_break] = ACTIONS(2373),
    [anon_sym_continue] = ACTIONS(2373),
    [anon_sym_goto] = ACTIONS(2373),
    [anon_sym___try] = ACTIONS(2373),
    [anon_sym___leave] = ACTIONS(2373),
    [anon_sym_not] = ACTIONS(2373),
    [anon_sym_compl] = ACTIONS(2373),
    [anon_sym_DASH_DASH] = ACTIONS(2375),
    [anon_sym_PLUS_PLUS] = ACTIONS(2375),
    [anon_sym_sizeof] = ACTIONS(2373),
    [anon_sym___alignof__] = ACTIONS(2373),
    [anon_sym___alignof] = ACTIONS(2373),
    [anon_sym__alignof] = ACTIONS(2373),
    [anon_sym_alignof] = ACTIONS(2373),
    [anon_sym__Alignof] = ACTIONS(2373),
    [anon_sym_offsetof] = ACTIONS(2373),
    [anon_sym__Generic] = ACTIONS(2373),
    [anon_sym_asm] = ACTIONS(2373),
    [anon_sym___asm__] = ACTIONS(2373),
    [anon_sym___asm] = ACTIONS(2373),
    [sym_number_literal] = ACTIONS(2375),
    [anon_sym_L_SQUOTE] = ACTIONS(2375),
    [anon_sym_u_SQUOTE] = ACTIONS(2375),
    [anon_sym_U_SQUOTE] = ACTIONS(2375),
    [anon_sym_u8_SQUOTE] = ACTIONS(2375),
    [anon_sym_SQUOTE] = ACTIONS(2375),
    [anon_sym_L_DQUOTE] = ACTIONS(2375),
    [anon_sym_u_DQUOTE] = ACTIONS(2375),
    [anon_sym_U_DQUOTE] = ACTIONS(2375),
    [anon_sym_u8_DQUOTE] = ACTIONS(2375),
    [anon_sym_DQUOTE] = ACTIONS(2375),
    [sym_true] = ACTIONS(2373),
    [sym_false] = ACTIONS(2373),
    [anon_sym_NULL] = ACTIONS(2373),
    [anon_sym_nullptr] = ACTIONS(2373),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2373),
    [anon_sym_decltype] = ACTIONS(2373),
    [anon_sym_explicit] = ACTIONS(2373),
    [anon_sym_typename] = ACTIONS(2373),
    [anon_sym_template] = ACTIONS(2373),
    [anon_sym_operator] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2373),
    [anon_sym_delete] = ACTIONS(2373),
    [anon_sym_throw] = ACTIONS(2373),
    [anon_sym_namespace] = ACTIONS(2373),
    [anon_sym_using] = ACTIONS(2373),
    [anon_sym_static_assert] = ACTIONS(2373),
    [anon_sym_concept] = ACTIONS(2373),
    [anon_sym_co_return] = ACTIONS(2373),
    [anon_sym_co_yield] = ACTIONS(2373),
    [anon_sym_R_DQUOTE] = ACTIONS(2375),
    [anon_sym_LR_DQUOTE] = ACTIONS(2375),
    [anon_sym_uR_DQUOTE] = ACTIONS(2375),
    [anon_sym_UR_DQUOTE] = ACTIONS(2375),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2375),
    [anon_sym_co_await] = ACTIONS(2373),
    [anon_sym_new] = ACTIONS(2373),
    [anon_sym_requires] = ACTIONS(2373),
    [sym_this] = ACTIONS(2373),
    [anon_sym___launch_bounds__] = ACTIONS(2373),
  },
  [STATE(542)] = {
    [sym_identifier] = ACTIONS(2387),
    [aux_sym_preproc_include_token1] = ACTIONS(2387),
    [aux_sym_preproc_def_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2387),
    [sym_preproc_directive] = ACTIONS(2387),
    [anon_sym_LPAREN2] = ACTIONS(2389),
    [anon_sym_BANG] = ACTIONS(2389),
    [anon_sym_TILDE] = ACTIONS(2389),
    [anon_sym_DASH] = ACTIONS(2387),
    [anon_sym_PLUS] = ACTIONS(2387),
    [anon_sym_STAR] = ACTIONS(2389),
    [anon_sym_AMP_AMP] = ACTIONS(2389),
    [anon_sym_AMP] = ACTIONS(2387),
    [anon_sym_SEMI] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2387),
    [anon_sym_typedef] = ACTIONS(2387),
    [anon_sym___device__] = ACTIONS(2387),
    [anon_sym___host__] = ACTIONS(2387),
    [anon_sym___global__] = ACTIONS(2387),
    [anon_sym___forceinline__] = ACTIONS(2387),
    [anon_sym___noinline__] = ACTIONS(2387),
    [anon_sym_virtual] = ACTIONS(2387),
    [anon_sym_extern] = ACTIONS(2387),
    [anon_sym___attribute__] = ACTIONS(2387),
    [anon_sym___attribute] = ACTIONS(2387),
    [anon_sym_COLON_COLON] = ACTIONS(2389),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2389),
    [anon_sym___declspec] = ACTIONS(2387),
    [anon_sym___based] = ACTIONS(2387),
    [anon_sym___cdecl] = ACTIONS(2387),
    [anon_sym___clrcall] = ACTIONS(2387),
    [anon_sym___stdcall] = ACTIONS(2387),
    [anon_sym___fastcall] = ACTIONS(2387),
    [anon_sym___thiscall] = ACTIONS(2387),
    [anon_sym___vectorcall] = ACTIONS(2387),
    [anon_sym_LBRACE] = ACTIONS(2389),
    [anon_sym_RBRACE] = ACTIONS(2389),
    [anon_sym_signed] = ACTIONS(2387),
    [anon_sym_unsigned] = ACTIONS(2387),
    [anon_sym_long] = ACTIONS(2387),
    [anon_sym_short] = ACTIONS(2387),
    [anon_sym_LBRACK] = ACTIONS(2387),
    [anon_sym_static] = ACTIONS(2387),
    [anon_sym_register] = ACTIONS(2387),
    [anon_sym_inline] = ACTIONS(2387),
    [anon_sym___inline] = ACTIONS(2387),
    [anon_sym___inline__] = ACTIONS(2387),
    [anon_sym___forceinline] = ACTIONS(2387),
    [anon_sym_thread_local] = ACTIONS(2387),
    [anon_sym___thread] = ACTIONS(2387),
    [anon_sym_const] = ACTIONS(2387),
    [anon_sym_constexpr] = ACTIONS(2387),
    [anon_sym_volatile] = ACTIONS(2387),
    [anon_sym_restrict] = ACTIONS(2387),
    [anon_sym___restrict__] = ACTIONS(2387),
    [anon_sym__Atomic] = ACTIONS(2387),
    [anon_sym__Noreturn] = ACTIONS(2387),
    [anon_sym_noreturn] = ACTIONS(2387),
    [anon_sym__Nonnull] = ACTIONS(2387),
    [anon_sym_mutable] = ACTIONS(2387),
    [anon_sym_constinit] = ACTIONS(2387),
    [anon_sym_consteval] = ACTIONS(2387),
    [anon_sym___shared__] = ACTIONS(2387),
    [anon_sym___local__] = ACTIONS(2387),
    [anon_sym___constant__] = ACTIONS(2387),
    [anon_sym___managed__] = ACTIONS(2387),
    [anon_sym___grid_constant__] = ACTIONS(2387),
    [anon_sym_alignas] = ACTIONS(2387),
    [anon_sym__Alignas] = ACTIONS(2387),
    [sym_primitive_type] = ACTIONS(2387),
    [anon_sym_enum] = ACTIONS(2387),
    [anon_sym_class] = ACTIONS(2387),
    [anon_sym_struct] = ACTIONS(2387),
    [anon_sym_union] = ACTIONS(2387),
    [anon_sym_if] = ACTIONS(2387),
    [anon_sym_switch] = ACTIONS(2387),
    [anon_sym_case] = ACTIONS(2387),
    [anon_sym_default] = ACTIONS(2387),
    [anon_sym_while] = ACTIONS(2387),
    [anon_sym_do] = ACTIONS(2387),
    [anon_sym_for] = ACTIONS(2387),
    [anon_sym_return] = ACTIONS(2387),
    [anon_sym_break] = ACTIONS(2387),
    [anon_sym_continue] = ACTIONS(2387),
    [anon_sym_goto] = ACTIONS(2387),
    [anon_sym___try] = ACTIONS(2387),
    [anon_sym___leave] = ACTIONS(2387),
    [anon_sym_not] = ACTIONS(2387),
    [anon_sym_compl] = ACTIONS(2387),
    [anon_sym_DASH_DASH] = ACTIONS(2389),
    [anon_sym_PLUS_PLUS] = ACTIONS(2389),
    [anon_sym_sizeof] = ACTIONS(2387),
    [anon_sym___alignof__] = ACTIONS(2387),
    [anon_sym___alignof] = ACTIONS(2387),
    [anon_sym__alignof] = ACTIONS(2387),
    [anon_sym_alignof] = ACTIONS(2387),
    [anon_sym__Alignof] = ACTIONS(2387),
    [anon_sym_offsetof] = ACTIONS(2387),
    [anon_sym__Generic] = ACTIONS(2387),
    [anon_sym_asm] = ACTIONS(2387),
    [anon_sym___asm__] = ACTIONS(2387),
    [anon_sym___asm] = ACTIONS(2387),
    [sym_number_literal] = ACTIONS(2389),
    [anon_sym_L_SQUOTE] = ACTIONS(2389),
    [anon_sym_u_SQUOTE] = ACTIONS(2389),
    [anon_sym_U_SQUOTE] = ACTIONS(2389),
    [anon_sym_u8_SQUOTE] = ACTIONS(2389),
    [anon_sym_SQUOTE] = ACTIONS(2389),
    [anon_sym_L_DQUOTE] = ACTIONS(2389),
    [anon_sym_u_DQUOTE] = ACTIONS(2389),
    [anon_sym_U_DQUOTE] = ACTIONS(2389),
    [anon_sym_u8_DQUOTE] = ACTIONS(2389),
    [anon_sym_DQUOTE] = ACTIONS(2389),
    [sym_true] = ACTIONS(2387),
    [sym_false] = ACTIONS(2387),
    [anon_sym_NULL] = ACTIONS(2387),
    [anon_sym_nullptr] = ACTIONS(2387),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2387),
    [anon_sym_decltype] = ACTIONS(2387),
    [anon_sym_explicit] = ACTIONS(2387),
    [anon_sym_typename] = ACTIONS(2387),
    [anon_sym_template] = ACTIONS(2387),
    [anon_sym_operator] = ACTIONS(2387),
    [anon_sym_try] = ACTIONS(2387),
    [anon_sym_delete] = ACTIONS(2387),
    [anon_sym_throw] = ACTIONS(2387),
    [anon_sym_namespace] = ACTIONS(2387),
    [anon_sym_using] = ACTIONS(2387),
    [anon_sym_static_assert] = ACTIONS(2387),
    [anon_sym_concept] = ACTIONS(2387),
    [anon_sym_co_return] = ACTIONS(2387),
    [anon_sym_co_yield] = ACTIONS(2387),
    [anon_sym_R_DQUOTE] = ACTIONS(2389),
    [anon_sym_LR_DQUOTE] = ACTIONS(2389),
    [anon_sym_uR_DQUOTE] = ACTIONS(2389),
    [anon_sym_UR_DQUOTE] = ACTIONS(2389),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2389),
    [anon_sym_co_await] = ACTIONS(2387),
    [anon_sym_new] = ACTIONS(2387),
    [anon_sym_requires] = ACTIONS(2387),
    [sym_this] = ACTIONS(2387),
    [anon_sym___launch_bounds__] = ACTIONS(2387),
  },
  [STATE(543)] = {
    [sym_identifier] = ACTIONS(2395),
    [aux_sym_preproc_include_token1] = ACTIONS(2395),
    [aux_sym_preproc_def_token1] = ACTIONS(2395),
    [aux_sym_preproc_if_token1] = ACTIONS(2395),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2395),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2395),
    [sym_preproc_directive] = ACTIONS(2395),
    [anon_sym_LPAREN2] = ACTIONS(2397),
    [anon_sym_BANG] = ACTIONS(2397),
    [anon_sym_TILDE] = ACTIONS(2397),
    [anon_sym_DASH] = ACTIONS(2395),
    [anon_sym_PLUS] = ACTIONS(2395),
    [anon_sym_STAR] = ACTIONS(2397),
    [anon_sym_AMP_AMP] = ACTIONS(2397),
    [anon_sym_AMP] = ACTIONS(2395),
    [anon_sym_SEMI] = ACTIONS(2397),
    [anon_sym___extension__] = ACTIONS(2395),
    [anon_sym_typedef] = ACTIONS(2395),
    [anon_sym___device__] = ACTIONS(2395),
    [anon_sym___host__] = ACTIONS(2395),
    [anon_sym___global__] = ACTIONS(2395),
    [anon_sym___forceinline__] = ACTIONS(2395),
    [anon_sym___noinline__] = ACTIONS(2395),
    [anon_sym_virtual] = ACTIONS(2395),
    [anon_sym_extern] = ACTIONS(2395),
    [anon_sym___attribute__] = ACTIONS(2395),
    [anon_sym___attribute] = ACTIONS(2395),
    [anon_sym_COLON_COLON] = ACTIONS(2397),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2397),
    [anon_sym___declspec] = ACTIONS(2395),
    [anon_sym___based] = ACTIONS(2395),
    [anon_sym___cdecl] = ACTIONS(2395),
    [anon_sym___clrcall] = ACTIONS(2395),
    [anon_sym___stdcall] = ACTIONS(2395),
    [anon_sym___fastcall] = ACTIONS(2395),
    [anon_sym___thiscall] = ACTIONS(2395),
    [anon_sym___vectorcall] = ACTIONS(2395),
    [anon_sym_LBRACE] = ACTIONS(2397),
    [anon_sym_RBRACE] = ACTIONS(2397),
    [anon_sym_signed] = ACTIONS(2395),
    [anon_sym_unsigned] = ACTIONS(2395),
    [anon_sym_long] = ACTIONS(2395),
    [anon_sym_short] = ACTIONS(2395),
    [anon_sym_LBRACK] = ACTIONS(2395),
    [anon_sym_static] = ACTIONS(2395),
    [anon_sym_register] = ACTIONS(2395),
    [anon_sym_inline] = ACTIONS(2395),
    [anon_sym___inline] = ACTIONS(2395),
    [anon_sym___inline__] = ACTIONS(2395),
    [anon_sym___forceinline] = ACTIONS(2395),
    [anon_sym_thread_local] = ACTIONS(2395),
    [anon_sym___thread] = ACTIONS(2395),
    [anon_sym_const] = ACTIONS(2395),
    [anon_sym_constexpr] = ACTIONS(2395),
    [anon_sym_volatile] = ACTIONS(2395),
    [anon_sym_restrict] = ACTIONS(2395),
    [anon_sym___restrict__] = ACTIONS(2395),
    [anon_sym__Atomic] = ACTIONS(2395),
    [anon_sym__Noreturn] = ACTIONS(2395),
    [anon_sym_noreturn] = ACTIONS(2395),
    [anon_sym__Nonnull] = ACTIONS(2395),
    [anon_sym_mutable] = ACTIONS(2395),
    [anon_sym_constinit] = ACTIONS(2395),
    [anon_sym_consteval] = ACTIONS(2395),
    [anon_sym___shared__] = ACTIONS(2395),
    [anon_sym___local__] = ACTIONS(2395),
    [anon_sym___constant__] = ACTIONS(2395),
    [anon_sym___managed__] = ACTIONS(2395),
    [anon_sym___grid_constant__] = ACTIONS(2395),
    [anon_sym_alignas] = ACTIONS(2395),
    [anon_sym__Alignas] = ACTIONS(2395),
    [sym_primitive_type] = ACTIONS(2395),
    [anon_sym_enum] = ACTIONS(2395),
    [anon_sym_class] = ACTIONS(2395),
    [anon_sym_struct] = ACTIONS(2395),
    [anon_sym_union] = ACTIONS(2395),
    [anon_sym_if] = ACTIONS(2395),
    [anon_sym_switch] = ACTIONS(2395),
    [anon_sym_case] = ACTIONS(2395),
    [anon_sym_default] = ACTIONS(2395),
    [anon_sym_while] = ACTIONS(2395),
    [anon_sym_do] = ACTIONS(2395),
    [anon_sym_for] = ACTIONS(2395),
    [anon_sym_return] = ACTIONS(2395),
    [anon_sym_break] = ACTIONS(2395),
    [anon_sym_continue] = ACTIONS(2395),
    [anon_sym_goto] = ACTIONS(2395),
    [anon_sym___try] = ACTIONS(2395),
    [anon_sym___leave] = ACTIONS(2395),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_compl] = ACTIONS(2395),
    [anon_sym_DASH_DASH] = ACTIONS(2397),
    [anon_sym_PLUS_PLUS] = ACTIONS(2397),
    [anon_sym_sizeof] = ACTIONS(2395),
    [anon_sym___alignof__] = ACTIONS(2395),
    [anon_sym___alignof] = ACTIONS(2395),
    [anon_sym__alignof] = ACTIONS(2395),
    [anon_sym_alignof] = ACTIONS(2395),
    [anon_sym__Alignof] = ACTIONS(2395),
    [anon_sym_offsetof] = ACTIONS(2395),
    [anon_sym__Generic] = ACTIONS(2395),
    [anon_sym_asm] = ACTIONS(2395),
    [anon_sym___asm__] = ACTIONS(2395),
    [anon_sym___asm] = ACTIONS(2395),
    [sym_number_literal] = ACTIONS(2397),
    [anon_sym_L_SQUOTE] = ACTIONS(2397),
    [anon_sym_u_SQUOTE] = ACTIONS(2397),
    [anon_sym_U_SQUOTE] = ACTIONS(2397),
    [anon_sym_u8_SQUOTE] = ACTIONS(2397),
    [anon_sym_SQUOTE] = ACTIONS(2397),
    [anon_sym_L_DQUOTE] = ACTIONS(2397),
    [anon_sym_u_DQUOTE] = ACTIONS(2397),
    [anon_sym_U_DQUOTE] = ACTIONS(2397),
    [anon_sym_u8_DQUOTE] = ACTIONS(2397),
    [anon_sym_DQUOTE] = ACTIONS(2397),
    [sym_true] = ACTIONS(2395),
    [sym_false] = ACTIONS(2395),
    [anon_sym_NULL] = ACTIONS(2395),
    [anon_sym_nullptr] = ACTIONS(2395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2395),
    [anon_sym_decltype] = ACTIONS(2395),
    [anon_sym_explicit] = ACTIONS(2395),
    [anon_sym_typename] = ACTIONS(2395),
    [anon_sym_template] = ACTIONS(2395),
    [anon_sym_operator] = ACTIONS(2395),
    [anon_sym_try] = ACTIONS(2395),
    [anon_sym_delete] = ACTIONS(2395),
    [anon_sym_throw] = ACTIONS(2395),
    [anon_sym_namespace] = ACTIONS(2395),
    [anon_sym_using] = ACTIONS(2395),
    [anon_sym_static_assert] = ACTIONS(2395),
    [anon_sym_concept] = ACTIONS(2395),
    [anon_sym_co_return] = ACTIONS(2395),
    [anon_sym_co_yield] = ACTIONS(2395),
    [anon_sym_R_DQUOTE] = ACTIONS(2397),
    [anon_sym_LR_DQUOTE] = ACTIONS(2397),
    [anon_sym_uR_DQUOTE] = ACTIONS(2397),
    [anon_sym_UR_DQUOTE] = ACTIONS(2397),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2397),
    [anon_sym_co_await] = ACTIONS(2395),
    [anon_sym_new] = ACTIONS(2395),
    [anon_sym_requires] = ACTIONS(2395),
    [sym_this] = ACTIONS(2395),
    [anon_sym___launch_bounds__] = ACTIONS(2395),
  },
  [STATE(544)] = {
    [sym_identifier] = ACTIONS(2419),
    [aux_sym_preproc_include_token1] = ACTIONS(2419),
    [aux_sym_preproc_def_token1] = ACTIONS(2419),
    [aux_sym_preproc_if_token1] = ACTIONS(2419),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2419),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2419),
    [sym_preproc_directive] = ACTIONS(2419),
    [anon_sym_LPAREN2] = ACTIONS(2421),
    [anon_sym_BANG] = ACTIONS(2421),
    [anon_sym_TILDE] = ACTIONS(2421),
    [anon_sym_DASH] = ACTIONS(2419),
    [anon_sym_PLUS] = ACTIONS(2419),
    [anon_sym_STAR] = ACTIONS(2421),
    [anon_sym_AMP_AMP] = ACTIONS(2421),
    [anon_sym_AMP] = ACTIONS(2419),
    [anon_sym_SEMI] = ACTIONS(2421),
    [anon_sym___extension__] = ACTIONS(2419),
    [anon_sym_typedef] = ACTIONS(2419),
    [anon_sym___device__] = ACTIONS(2419),
    [anon_sym___host__] = ACTIONS(2419),
    [anon_sym___global__] = ACTIONS(2419),
    [anon_sym___forceinline__] = ACTIONS(2419),
    [anon_sym___noinline__] = ACTIONS(2419),
    [anon_sym_virtual] = ACTIONS(2419),
    [anon_sym_extern] = ACTIONS(2419),
    [anon_sym___attribute__] = ACTIONS(2419),
    [anon_sym___attribute] = ACTIONS(2419),
    [anon_sym_COLON_COLON] = ACTIONS(2421),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2421),
    [anon_sym___declspec] = ACTIONS(2419),
    [anon_sym___based] = ACTIONS(2419),
    [anon_sym___cdecl] = ACTIONS(2419),
    [anon_sym___clrcall] = ACTIONS(2419),
    [anon_sym___stdcall] = ACTIONS(2419),
    [anon_sym___fastcall] = ACTIONS(2419),
    [anon_sym___thiscall] = ACTIONS(2419),
    [anon_sym___vectorcall] = ACTIONS(2419),
    [anon_sym_LBRACE] = ACTIONS(2421),
    [anon_sym_RBRACE] = ACTIONS(2421),
    [anon_sym_signed] = ACTIONS(2419),
    [anon_sym_unsigned] = ACTIONS(2419),
    [anon_sym_long] = ACTIONS(2419),
    [anon_sym_short] = ACTIONS(2419),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_static] = ACTIONS(2419),
    [anon_sym_register] = ACTIONS(2419),
    [anon_sym_inline] = ACTIONS(2419),
    [anon_sym___inline] = ACTIONS(2419),
    [anon_sym___inline__] = ACTIONS(2419),
    [anon_sym___forceinline] = ACTIONS(2419),
    [anon_sym_thread_local] = ACTIONS(2419),
    [anon_sym___thread] = ACTIONS(2419),
    [anon_sym_const] = ACTIONS(2419),
    [anon_sym_constexpr] = ACTIONS(2419),
    [anon_sym_volatile] = ACTIONS(2419),
    [anon_sym_restrict] = ACTIONS(2419),
    [anon_sym___restrict__] = ACTIONS(2419),
    [anon_sym__Atomic] = ACTIONS(2419),
    [anon_sym__Noreturn] = ACTIONS(2419),
    [anon_sym_noreturn] = ACTIONS(2419),
    [anon_sym__Nonnull] = ACTIONS(2419),
    [anon_sym_mutable] = ACTIONS(2419),
    [anon_sym_constinit] = ACTIONS(2419),
    [anon_sym_consteval] = ACTIONS(2419),
    [anon_sym___shared__] = ACTIONS(2419),
    [anon_sym___local__] = ACTIONS(2419),
    [anon_sym___constant__] = ACTIONS(2419),
    [anon_sym___managed__] = ACTIONS(2419),
    [anon_sym___grid_constant__] = ACTIONS(2419),
    [anon_sym_alignas] = ACTIONS(2419),
    [anon_sym__Alignas] = ACTIONS(2419),
    [sym_primitive_type] = ACTIONS(2419),
    [anon_sym_enum] = ACTIONS(2419),
    [anon_sym_class] = ACTIONS(2419),
    [anon_sym_struct] = ACTIONS(2419),
    [anon_sym_union] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2419),
    [anon_sym_switch] = ACTIONS(2419),
    [anon_sym_case] = ACTIONS(2419),
    [anon_sym_default] = ACTIONS(2419),
    [anon_sym_while] = ACTIONS(2419),
    [anon_sym_do] = ACTIONS(2419),
    [anon_sym_for] = ACTIONS(2419),
    [anon_sym_return] = ACTIONS(2419),
    [anon_sym_break] = ACTIONS(2419),
    [anon_sym_continue] = ACTIONS(2419),
    [anon_sym_goto] = ACTIONS(2419),
    [anon_sym___try] = ACTIONS(2419),
    [anon_sym___leave] = ACTIONS(2419),
    [anon_sym_not] = ACTIONS(2419),
    [anon_sym_compl] = ACTIONS(2419),
    [anon_sym_DASH_DASH] = ACTIONS(2421),
    [anon_sym_PLUS_PLUS] = ACTIONS(2421),
    [anon_sym_sizeof] = ACTIONS(2419),
    [anon_sym___alignof__] = ACTIONS(2419),
    [anon_sym___alignof] = ACTIONS(2419),
    [anon_sym__alignof] = ACTIONS(2419),
    [anon_sym_alignof] = ACTIONS(2419),
    [anon_sym__Alignof] = ACTIONS(2419),
    [anon_sym_offsetof] = ACTIONS(2419),
    [anon_sym__Generic] = ACTIONS(2419),
    [anon_sym_asm] = ACTIONS(2419),
    [anon_sym___asm__] = ACTIONS(2419),
    [anon_sym___asm] = ACTIONS(2419),
    [sym_number_literal] = ACTIONS(2421),
    [anon_sym_L_SQUOTE] = ACTIONS(2421),
    [anon_sym_u_SQUOTE] = ACTIONS(2421),
    [anon_sym_U_SQUOTE] = ACTIONS(2421),
    [anon_sym_u8_SQUOTE] = ACTIONS(2421),
    [anon_sym_SQUOTE] = ACTIONS(2421),
    [anon_sym_L_DQUOTE] = ACTIONS(2421),
    [anon_sym_u_DQUOTE] = ACTIONS(2421),
    [anon_sym_U_DQUOTE] = ACTIONS(2421),
    [anon_sym_u8_DQUOTE] = ACTIONS(2421),
    [anon_sym_DQUOTE] = ACTIONS(2421),
    [sym_true] = ACTIONS(2419),
    [sym_false] = ACTIONS(2419),
    [anon_sym_NULL] = ACTIONS(2419),
    [anon_sym_nullptr] = ACTIONS(2419),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2419),
    [anon_sym_decltype] = ACTIONS(2419),
    [anon_sym_explicit] = ACTIONS(2419),
    [anon_sym_typename] = ACTIONS(2419),
    [anon_sym_template] = ACTIONS(2419),
    [anon_sym_operator] = ACTIONS(2419),
    [anon_sym_try] = ACTIONS(2419),
    [anon_sym_delete] = ACTIONS(2419),
    [anon_sym_throw] = ACTIONS(2419),
    [anon_sym_namespace] = ACTIONS(2419),
    [anon_sym_using] = ACTIONS(2419),
    [anon_sym_static_assert] = ACTIONS(2419),
    [anon_sym_concept] = ACTIONS(2419),
    [anon_sym_co_return] = ACTIONS(2419),
    [anon_sym_co_yield] = ACTIONS(2419),
    [anon_sym_R_DQUOTE] = ACTIONS(2421),
    [anon_sym_LR_DQUOTE] = ACTIONS(2421),
    [anon_sym_uR_DQUOTE] = ACTIONS(2421),
    [anon_sym_UR_DQUOTE] = ACTIONS(2421),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2421),
    [anon_sym_co_await] = ACTIONS(2419),
    [anon_sym_new] = ACTIONS(2419),
    [anon_sym_requires] = ACTIONS(2419),
    [sym_this] = ACTIONS(2419),
    [anon_sym___launch_bounds__] = ACTIONS(2419),
  },
  [STATE(545)] = {
    [sym_identifier] = ACTIONS(2427),
    [aux_sym_preproc_include_token1] = ACTIONS(2427),
    [aux_sym_preproc_def_token1] = ACTIONS(2427),
    [aux_sym_preproc_if_token1] = ACTIONS(2427),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2427),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2427),
    [sym_preproc_directive] = ACTIONS(2427),
    [anon_sym_LPAREN2] = ACTIONS(2429),
    [anon_sym_BANG] = ACTIONS(2429),
    [anon_sym_TILDE] = ACTIONS(2429),
    [anon_sym_DASH] = ACTIONS(2427),
    [anon_sym_PLUS] = ACTIONS(2427),
    [anon_sym_STAR] = ACTIONS(2429),
    [anon_sym_AMP_AMP] = ACTIONS(2429),
    [anon_sym_AMP] = ACTIONS(2427),
    [anon_sym_SEMI] = ACTIONS(2429),
    [anon_sym___extension__] = ACTIONS(2427),
    [anon_sym_typedef] = ACTIONS(2427),
    [anon_sym___device__] = ACTIONS(2427),
    [anon_sym___host__] = ACTIONS(2427),
    [anon_sym___global__] = ACTIONS(2427),
    [anon_sym___forceinline__] = ACTIONS(2427),
    [anon_sym___noinline__] = ACTIONS(2427),
    [anon_sym_virtual] = ACTIONS(2427),
    [anon_sym_extern] = ACTIONS(2427),
    [anon_sym___attribute__] = ACTIONS(2427),
    [anon_sym___attribute] = ACTIONS(2427),
    [anon_sym_COLON_COLON] = ACTIONS(2429),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2429),
    [anon_sym___declspec] = ACTIONS(2427),
    [anon_sym___based] = ACTIONS(2427),
    [anon_sym___cdecl] = ACTIONS(2427),
    [anon_sym___clrcall] = ACTIONS(2427),
    [anon_sym___stdcall] = ACTIONS(2427),
    [anon_sym___fastcall] = ACTIONS(2427),
    [anon_sym___thiscall] = ACTIONS(2427),
    [anon_sym___vectorcall] = ACTIONS(2427),
    [anon_sym_LBRACE] = ACTIONS(2429),
    [anon_sym_RBRACE] = ACTIONS(2429),
    [anon_sym_signed] = ACTIONS(2427),
    [anon_sym_unsigned] = ACTIONS(2427),
    [anon_sym_long] = ACTIONS(2427),
    [anon_sym_short] = ACTIONS(2427),
    [anon_sym_LBRACK] = ACTIONS(2427),
    [anon_sym_static] = ACTIONS(2427),
    [anon_sym_register] = ACTIONS(2427),
    [anon_sym_inline] = ACTIONS(2427),
    [anon_sym___inline] = ACTIONS(2427),
    [anon_sym___inline__] = ACTIONS(2427),
    [anon_sym___forceinline] = ACTIONS(2427),
    [anon_sym_thread_local] = ACTIONS(2427),
    [anon_sym___thread] = ACTIONS(2427),
    [anon_sym_const] = ACTIONS(2427),
    [anon_sym_constexpr] = ACTIONS(2427),
    [anon_sym_volatile] = ACTIONS(2427),
    [anon_sym_restrict] = ACTIONS(2427),
    [anon_sym___restrict__] = ACTIONS(2427),
    [anon_sym__Atomic] = ACTIONS(2427),
    [anon_sym__Noreturn] = ACTIONS(2427),
    [anon_sym_noreturn] = ACTIONS(2427),
    [anon_sym__Nonnull] = ACTIONS(2427),
    [anon_sym_mutable] = ACTIONS(2427),
    [anon_sym_constinit] = ACTIONS(2427),
    [anon_sym_consteval] = ACTIONS(2427),
    [anon_sym___shared__] = ACTIONS(2427),
    [anon_sym___local__] = ACTIONS(2427),
    [anon_sym___constant__] = ACTIONS(2427),
    [anon_sym___managed__] = ACTIONS(2427),
    [anon_sym___grid_constant__] = ACTIONS(2427),
    [anon_sym_alignas] = ACTIONS(2427),
    [anon_sym__Alignas] = ACTIONS(2427),
    [sym_primitive_type] = ACTIONS(2427),
    [anon_sym_enum] = ACTIONS(2427),
    [anon_sym_class] = ACTIONS(2427),
    [anon_sym_struct] = ACTIONS(2427),
    [anon_sym_union] = ACTIONS(2427),
    [anon_sym_if] = ACTIONS(2427),
    [anon_sym_switch] = ACTIONS(2427),
    [anon_sym_case] = ACTIONS(2427),
    [anon_sym_default] = ACTIONS(2427),
    [anon_sym_while] = ACTIONS(2427),
    [anon_sym_do] = ACTIONS(2427),
    [anon_sym_for] = ACTIONS(2427),
    [anon_sym_return] = ACTIONS(2427),
    [anon_sym_break] = ACTIONS(2427),
    [anon_sym_continue] = ACTIONS(2427),
    [anon_sym_goto] = ACTIONS(2427),
    [anon_sym___try] = ACTIONS(2427),
    [anon_sym___leave] = ACTIONS(2427),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_compl] = ACTIONS(2427),
    [anon_sym_DASH_DASH] = ACTIONS(2429),
    [anon_sym_PLUS_PLUS] = ACTIONS(2429),
    [anon_sym_sizeof] = ACTIONS(2427),
    [anon_sym___alignof__] = ACTIONS(2427),
    [anon_sym___alignof] = ACTIONS(2427),
    [anon_sym__alignof] = ACTIONS(2427),
    [anon_sym_alignof] = ACTIONS(2427),
    [anon_sym__Alignof] = ACTIONS(2427),
    [anon_sym_offsetof] = ACTIONS(2427),
    [anon_sym__Generic] = ACTIONS(2427),
    [anon_sym_asm] = ACTIONS(2427),
    [anon_sym___asm__] = ACTIONS(2427),
    [anon_sym___asm] = ACTIONS(2427),
    [sym_number_literal] = ACTIONS(2429),
    [anon_sym_L_SQUOTE] = ACTIONS(2429),
    [anon_sym_u_SQUOTE] = ACTIONS(2429),
    [anon_sym_U_SQUOTE] = ACTIONS(2429),
    [anon_sym_u8_SQUOTE] = ACTIONS(2429),
    [anon_sym_SQUOTE] = ACTIONS(2429),
    [anon_sym_L_DQUOTE] = ACTIONS(2429),
    [anon_sym_u_DQUOTE] = ACTIONS(2429),
    [anon_sym_U_DQUOTE] = ACTIONS(2429),
    [anon_sym_u8_DQUOTE] = ACTIONS(2429),
    [anon_sym_DQUOTE] = ACTIONS(2429),
    [sym_true] = ACTIONS(2427),
    [sym_false] = ACTIONS(2427),
    [anon_sym_NULL] = ACTIONS(2427),
    [anon_sym_nullptr] = ACTIONS(2427),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2427),
    [anon_sym_decltype] = ACTIONS(2427),
    [anon_sym_explicit] = ACTIONS(2427),
    [anon_sym_typename] = ACTIONS(2427),
    [anon_sym_template] = ACTIONS(2427),
    [anon_sym_operator] = ACTIONS(2427),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_delete] = ACTIONS(2427),
    [anon_sym_throw] = ACTIONS(2427),
    [anon_sym_namespace] = ACTIONS(2427),
    [anon_sym_using] = ACTIONS(2427),
    [anon_sym_static_assert] = ACTIONS(2427),
    [anon_sym_concept] = ACTIONS(2427),
    [anon_sym_co_return] = ACTIONS(2427),
    [anon_sym_co_yield] = ACTIONS(2427),
    [anon_sym_R_DQUOTE] = ACTIONS(2429),
    [anon_sym_LR_DQUOTE] = ACTIONS(2429),
    [anon_sym_uR_DQUOTE] = ACTIONS(2429),
    [anon_sym_UR_DQUOTE] = ACTIONS(2429),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2429),
    [anon_sym_co_await] = ACTIONS(2427),
    [anon_sym_new] = ACTIONS(2427),
    [anon_sym_requires] = ACTIONS(2427),
    [sym_this] = ACTIONS(2427),
    [anon_sym___launch_bounds__] = ACTIONS(2427),
  },
  [STATE(546)] = {
    [sym_identifier] = ACTIONS(2419),
    [aux_sym_preproc_include_token1] = ACTIONS(2419),
    [aux_sym_preproc_def_token1] = ACTIONS(2419),
    [aux_sym_preproc_if_token1] = ACTIONS(2419),
    [aux_sym_preproc_if_token2] = ACTIONS(2419),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2419),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2419),
    [sym_preproc_directive] = ACTIONS(2419),
    [anon_sym_LPAREN2] = ACTIONS(2421),
    [anon_sym_BANG] = ACTIONS(2421),
    [anon_sym_TILDE] = ACTIONS(2421),
    [anon_sym_DASH] = ACTIONS(2419),
    [anon_sym_PLUS] = ACTIONS(2419),
    [anon_sym_STAR] = ACTIONS(2421),
    [anon_sym_AMP_AMP] = ACTIONS(2421),
    [anon_sym_AMP] = ACTIONS(2419),
    [anon_sym_SEMI] = ACTIONS(2421),
    [anon_sym___extension__] = ACTIONS(2419),
    [anon_sym_typedef] = ACTIONS(2419),
    [anon_sym___device__] = ACTIONS(2419),
    [anon_sym___host__] = ACTIONS(2419),
    [anon_sym___global__] = ACTIONS(2419),
    [anon_sym___forceinline__] = ACTIONS(2419),
    [anon_sym___noinline__] = ACTIONS(2419),
    [anon_sym_virtual] = ACTIONS(2419),
    [anon_sym_extern] = ACTIONS(2419),
    [anon_sym___attribute__] = ACTIONS(2419),
    [anon_sym___attribute] = ACTIONS(2419),
    [anon_sym_COLON_COLON] = ACTIONS(2421),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2421),
    [anon_sym___declspec] = ACTIONS(2419),
    [anon_sym___based] = ACTIONS(2419),
    [anon_sym___cdecl] = ACTIONS(2419),
    [anon_sym___clrcall] = ACTIONS(2419),
    [anon_sym___stdcall] = ACTIONS(2419),
    [anon_sym___fastcall] = ACTIONS(2419),
    [anon_sym___thiscall] = ACTIONS(2419),
    [anon_sym___vectorcall] = ACTIONS(2419),
    [anon_sym_LBRACE] = ACTIONS(2421),
    [anon_sym_signed] = ACTIONS(2419),
    [anon_sym_unsigned] = ACTIONS(2419),
    [anon_sym_long] = ACTIONS(2419),
    [anon_sym_short] = ACTIONS(2419),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_static] = ACTIONS(2419),
    [anon_sym_register] = ACTIONS(2419),
    [anon_sym_inline] = ACTIONS(2419),
    [anon_sym___inline] = ACTIONS(2419),
    [anon_sym___inline__] = ACTIONS(2419),
    [anon_sym___forceinline] = ACTIONS(2419),
    [anon_sym_thread_local] = ACTIONS(2419),
    [anon_sym___thread] = ACTIONS(2419),
    [anon_sym_const] = ACTIONS(2419),
    [anon_sym_constexpr] = ACTIONS(2419),
    [anon_sym_volatile] = ACTIONS(2419),
    [anon_sym_restrict] = ACTIONS(2419),
    [anon_sym___restrict__] = ACTIONS(2419),
    [anon_sym__Atomic] = ACTIONS(2419),
    [anon_sym__Noreturn] = ACTIONS(2419),
    [anon_sym_noreturn] = ACTIONS(2419),
    [anon_sym__Nonnull] = ACTIONS(2419),
    [anon_sym_mutable] = ACTIONS(2419),
    [anon_sym_constinit] = ACTIONS(2419),
    [anon_sym_consteval] = ACTIONS(2419),
    [anon_sym___shared__] = ACTIONS(2419),
    [anon_sym___local__] = ACTIONS(2419),
    [anon_sym___constant__] = ACTIONS(2419),
    [anon_sym___managed__] = ACTIONS(2419),
    [anon_sym___grid_constant__] = ACTIONS(2419),
    [anon_sym_alignas] = ACTIONS(2419),
    [anon_sym__Alignas] = ACTIONS(2419),
    [sym_primitive_type] = ACTIONS(2419),
    [anon_sym_enum] = ACTIONS(2419),
    [anon_sym_class] = ACTIONS(2419),
    [anon_sym_struct] = ACTIONS(2419),
    [anon_sym_union] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2419),
    [anon_sym_switch] = ACTIONS(2419),
    [anon_sym_case] = ACTIONS(2419),
    [anon_sym_default] = ACTIONS(2419),
    [anon_sym_while] = ACTIONS(2419),
    [anon_sym_do] = ACTIONS(2419),
    [anon_sym_for] = ACTIONS(2419),
    [anon_sym_return] = ACTIONS(2419),
    [anon_sym_break] = ACTIONS(2419),
    [anon_sym_continue] = ACTIONS(2419),
    [anon_sym_goto] = ACTIONS(2419),
    [anon_sym___try] = ACTIONS(2419),
    [anon_sym___leave] = ACTIONS(2419),
    [anon_sym_not] = ACTIONS(2419),
    [anon_sym_compl] = ACTIONS(2419),
    [anon_sym_DASH_DASH] = ACTIONS(2421),
    [anon_sym_PLUS_PLUS] = ACTIONS(2421),
    [anon_sym_sizeof] = ACTIONS(2419),
    [anon_sym___alignof__] = ACTIONS(2419),
    [anon_sym___alignof] = ACTIONS(2419),
    [anon_sym__alignof] = ACTIONS(2419),
    [anon_sym_alignof] = ACTIONS(2419),
    [anon_sym__Alignof] = ACTIONS(2419),
    [anon_sym_offsetof] = ACTIONS(2419),
    [anon_sym__Generic] = ACTIONS(2419),
    [anon_sym_asm] = ACTIONS(2419),
    [anon_sym___asm__] = ACTIONS(2419),
    [anon_sym___asm] = ACTIONS(2419),
    [sym_number_literal] = ACTIONS(2421),
    [anon_sym_L_SQUOTE] = ACTIONS(2421),
    [anon_sym_u_SQUOTE] = ACTIONS(2421),
    [anon_sym_U_SQUOTE] = ACTIONS(2421),
    [anon_sym_u8_SQUOTE] = ACTIONS(2421),
    [anon_sym_SQUOTE] = ACTIONS(2421),
    [anon_sym_L_DQUOTE] = ACTIONS(2421),
    [anon_sym_u_DQUOTE] = ACTIONS(2421),
    [anon_sym_U_DQUOTE] = ACTIONS(2421),
    [anon_sym_u8_DQUOTE] = ACTIONS(2421),
    [anon_sym_DQUOTE] = ACTIONS(2421),
    [sym_true] = ACTIONS(2419),
    [sym_false] = ACTIONS(2419),
    [anon_sym_NULL] = ACTIONS(2419),
    [anon_sym_nullptr] = ACTIONS(2419),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2419),
    [anon_sym_decltype] = ACTIONS(2419),
    [anon_sym_explicit] = ACTIONS(2419),
    [anon_sym_typename] = ACTIONS(2419),
    [anon_sym_template] = ACTIONS(2419),
    [anon_sym_operator] = ACTIONS(2419),
    [anon_sym_try] = ACTIONS(2419),
    [anon_sym_delete] = ACTIONS(2419),
    [anon_sym_throw] = ACTIONS(2419),
    [anon_sym_namespace] = ACTIONS(2419),
    [anon_sym_using] = ACTIONS(2419),
    [anon_sym_static_assert] = ACTIONS(2419),
    [anon_sym_concept] = ACTIONS(2419),
    [anon_sym_co_return] = ACTIONS(2419),
    [anon_sym_co_yield] = ACTIONS(2419),
    [anon_sym_R_DQUOTE] = ACTIONS(2421),
    [anon_sym_LR_DQUOTE] = ACTIONS(2421),
    [anon_sym_uR_DQUOTE] = ACTIONS(2421),
    [anon_sym_UR_DQUOTE] = ACTIONS(2421),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2421),
    [anon_sym_co_await] = ACTIONS(2419),
    [anon_sym_new] = ACTIONS(2419),
    [anon_sym_requires] = ACTIONS(2419),
    [sym_this] = ACTIONS(2419),
    [anon_sym___launch_bounds__] = ACTIONS(2419),
  },
  [STATE(547)] = {
    [sym_identifier] = ACTIONS(2427),
    [aux_sym_preproc_include_token1] = ACTIONS(2427),
    [aux_sym_preproc_def_token1] = ACTIONS(2427),
    [aux_sym_preproc_if_token1] = ACTIONS(2427),
    [aux_sym_preproc_if_token2] = ACTIONS(2427),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2427),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2427),
    [sym_preproc_directive] = ACTIONS(2427),
    [anon_sym_LPAREN2] = ACTIONS(2429),
    [anon_sym_BANG] = ACTIONS(2429),
    [anon_sym_TILDE] = ACTIONS(2429),
    [anon_sym_DASH] = ACTIONS(2427),
    [anon_sym_PLUS] = ACTIONS(2427),
    [anon_sym_STAR] = ACTIONS(2429),
    [anon_sym_AMP_AMP] = ACTIONS(2429),
    [anon_sym_AMP] = ACTIONS(2427),
    [anon_sym_SEMI] = ACTIONS(2429),
    [anon_sym___extension__] = ACTIONS(2427),
    [anon_sym_typedef] = ACTIONS(2427),
    [anon_sym___device__] = ACTIONS(2427),
    [anon_sym___host__] = ACTIONS(2427),
    [anon_sym___global__] = ACTIONS(2427),
    [anon_sym___forceinline__] = ACTIONS(2427),
    [anon_sym___noinline__] = ACTIONS(2427),
    [anon_sym_virtual] = ACTIONS(2427),
    [anon_sym_extern] = ACTIONS(2427),
    [anon_sym___attribute__] = ACTIONS(2427),
    [anon_sym___attribute] = ACTIONS(2427),
    [anon_sym_COLON_COLON] = ACTIONS(2429),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2429),
    [anon_sym___declspec] = ACTIONS(2427),
    [anon_sym___based] = ACTIONS(2427),
    [anon_sym___cdecl] = ACTIONS(2427),
    [anon_sym___clrcall] = ACTIONS(2427),
    [anon_sym___stdcall] = ACTIONS(2427),
    [anon_sym___fastcall] = ACTIONS(2427),
    [anon_sym___thiscall] = ACTIONS(2427),
    [anon_sym___vectorcall] = ACTIONS(2427),
    [anon_sym_LBRACE] = ACTIONS(2429),
    [anon_sym_signed] = ACTIONS(2427),
    [anon_sym_unsigned] = ACTIONS(2427),
    [anon_sym_long] = ACTIONS(2427),
    [anon_sym_short] = ACTIONS(2427),
    [anon_sym_LBRACK] = ACTIONS(2427),
    [anon_sym_static] = ACTIONS(2427),
    [anon_sym_register] = ACTIONS(2427),
    [anon_sym_inline] = ACTIONS(2427),
    [anon_sym___inline] = ACTIONS(2427),
    [anon_sym___inline__] = ACTIONS(2427),
    [anon_sym___forceinline] = ACTIONS(2427),
    [anon_sym_thread_local] = ACTIONS(2427),
    [anon_sym___thread] = ACTIONS(2427),
    [anon_sym_const] = ACTIONS(2427),
    [anon_sym_constexpr] = ACTIONS(2427),
    [anon_sym_volatile] = ACTIONS(2427),
    [anon_sym_restrict] = ACTIONS(2427),
    [anon_sym___restrict__] = ACTIONS(2427),
    [anon_sym__Atomic] = ACTIONS(2427),
    [anon_sym__Noreturn] = ACTIONS(2427),
    [anon_sym_noreturn] = ACTIONS(2427),
    [anon_sym__Nonnull] = ACTIONS(2427),
    [anon_sym_mutable] = ACTIONS(2427),
    [anon_sym_constinit] = ACTIONS(2427),
    [anon_sym_consteval] = ACTIONS(2427),
    [anon_sym___shared__] = ACTIONS(2427),
    [anon_sym___local__] = ACTIONS(2427),
    [anon_sym___constant__] = ACTIONS(2427),
    [anon_sym___managed__] = ACTIONS(2427),
    [anon_sym___grid_constant__] = ACTIONS(2427),
    [anon_sym_alignas] = ACTIONS(2427),
    [anon_sym__Alignas] = ACTIONS(2427),
    [sym_primitive_type] = ACTIONS(2427),
    [anon_sym_enum] = ACTIONS(2427),
    [anon_sym_class] = ACTIONS(2427),
    [anon_sym_struct] = ACTIONS(2427),
    [anon_sym_union] = ACTIONS(2427),
    [anon_sym_if] = ACTIONS(2427),
    [anon_sym_switch] = ACTIONS(2427),
    [anon_sym_case] = ACTIONS(2427),
    [anon_sym_default] = ACTIONS(2427),
    [anon_sym_while] = ACTIONS(2427),
    [anon_sym_do] = ACTIONS(2427),
    [anon_sym_for] = ACTIONS(2427),
    [anon_sym_return] = ACTIONS(2427),
    [anon_sym_break] = ACTIONS(2427),
    [anon_sym_continue] = ACTIONS(2427),
    [anon_sym_goto] = ACTIONS(2427),
    [anon_sym___try] = ACTIONS(2427),
    [anon_sym___leave] = ACTIONS(2427),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_compl] = ACTIONS(2427),
    [anon_sym_DASH_DASH] = ACTIONS(2429),
    [anon_sym_PLUS_PLUS] = ACTIONS(2429),
    [anon_sym_sizeof] = ACTIONS(2427),
    [anon_sym___alignof__] = ACTIONS(2427),
    [anon_sym___alignof] = ACTIONS(2427),
    [anon_sym__alignof] = ACTIONS(2427),
    [anon_sym_alignof] = ACTIONS(2427),
    [anon_sym__Alignof] = ACTIONS(2427),
    [anon_sym_offsetof] = ACTIONS(2427),
    [anon_sym__Generic] = ACTIONS(2427),
    [anon_sym_asm] = ACTIONS(2427),
    [anon_sym___asm__] = ACTIONS(2427),
    [anon_sym___asm] = ACTIONS(2427),
    [sym_number_literal] = ACTIONS(2429),
    [anon_sym_L_SQUOTE] = ACTIONS(2429),
    [anon_sym_u_SQUOTE] = ACTIONS(2429),
    [anon_sym_U_SQUOTE] = ACTIONS(2429),
    [anon_sym_u8_SQUOTE] = ACTIONS(2429),
    [anon_sym_SQUOTE] = ACTIONS(2429),
    [anon_sym_L_DQUOTE] = ACTIONS(2429),
    [anon_sym_u_DQUOTE] = ACTIONS(2429),
    [anon_sym_U_DQUOTE] = ACTIONS(2429),
    [anon_sym_u8_DQUOTE] = ACTIONS(2429),
    [anon_sym_DQUOTE] = ACTIONS(2429),
    [sym_true] = ACTIONS(2427),
    [sym_false] = ACTIONS(2427),
    [anon_sym_NULL] = ACTIONS(2427),
    [anon_sym_nullptr] = ACTIONS(2427),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2427),
    [anon_sym_decltype] = ACTIONS(2427),
    [anon_sym_explicit] = ACTIONS(2427),
    [anon_sym_typename] = ACTIONS(2427),
    [anon_sym_template] = ACTIONS(2427),
    [anon_sym_operator] = ACTIONS(2427),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_delete] = ACTIONS(2427),
    [anon_sym_throw] = ACTIONS(2427),
    [anon_sym_namespace] = ACTIONS(2427),
    [anon_sym_using] = ACTIONS(2427),
    [anon_sym_static_assert] = ACTIONS(2427),
    [anon_sym_concept] = ACTIONS(2427),
    [anon_sym_co_return] = ACTIONS(2427),
    [anon_sym_co_yield] = ACTIONS(2427),
    [anon_sym_R_DQUOTE] = ACTIONS(2429),
    [anon_sym_LR_DQUOTE] = ACTIONS(2429),
    [anon_sym_uR_DQUOTE] = ACTIONS(2429),
    [anon_sym_UR_DQUOTE] = ACTIONS(2429),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2429),
    [anon_sym_co_await] = ACTIONS(2427),
    [anon_sym_new] = ACTIONS(2427),
    [anon_sym_requires] = ACTIONS(2427),
    [sym_this] = ACTIONS(2427),
    [anon_sym___launch_bounds__] = ACTIONS(2427),
  },
  [STATE(548)] = {
    [sym_identifier] = ACTIONS(2485),
    [aux_sym_preproc_include_token1] = ACTIONS(2485),
    [aux_sym_preproc_def_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2485),
    [sym_preproc_directive] = ACTIONS(2485),
    [anon_sym_LPAREN2] = ACTIONS(2487),
    [anon_sym_BANG] = ACTIONS(2487),
    [anon_sym_TILDE] = ACTIONS(2487),
    [anon_sym_DASH] = ACTIONS(2485),
    [anon_sym_PLUS] = ACTIONS(2485),
    [anon_sym_STAR] = ACTIONS(2487),
    [anon_sym_AMP_AMP] = ACTIONS(2487),
    [anon_sym_AMP] = ACTIONS(2485),
    [anon_sym_SEMI] = ACTIONS(2487),
    [anon_sym___extension__] = ACTIONS(2485),
    [anon_sym_typedef] = ACTIONS(2485),
    [anon_sym___device__] = ACTIONS(2485),
    [anon_sym___host__] = ACTIONS(2485),
    [anon_sym___global__] = ACTIONS(2485),
    [anon_sym___forceinline__] = ACTIONS(2485),
    [anon_sym___noinline__] = ACTIONS(2485),
    [anon_sym_virtual] = ACTIONS(2485),
    [anon_sym_extern] = ACTIONS(2485),
    [anon_sym___attribute__] = ACTIONS(2485),
    [anon_sym___attribute] = ACTIONS(2485),
    [anon_sym_COLON_COLON] = ACTIONS(2487),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2487),
    [anon_sym___declspec] = ACTIONS(2485),
    [anon_sym___based] = ACTIONS(2485),
    [anon_sym___cdecl] = ACTIONS(2485),
    [anon_sym___clrcall] = ACTIONS(2485),
    [anon_sym___stdcall] = ACTIONS(2485),
    [anon_sym___fastcall] = ACTIONS(2485),
    [anon_sym___thiscall] = ACTIONS(2485),
    [anon_sym___vectorcall] = ACTIONS(2485),
    [anon_sym_LBRACE] = ACTIONS(2487),
    [anon_sym_RBRACE] = ACTIONS(2487),
    [anon_sym_signed] = ACTIONS(2485),
    [anon_sym_unsigned] = ACTIONS(2485),
    [anon_sym_long] = ACTIONS(2485),
    [anon_sym_short] = ACTIONS(2485),
    [anon_sym_LBRACK] = ACTIONS(2485),
    [anon_sym_static] = ACTIONS(2485),
    [anon_sym_register] = ACTIONS(2485),
    [anon_sym_inline] = ACTIONS(2485),
    [anon_sym___inline] = ACTIONS(2485),
    [anon_sym___inline__] = ACTIONS(2485),
    [anon_sym___forceinline] = ACTIONS(2485),
    [anon_sym_thread_local] = ACTIONS(2485),
    [anon_sym___thread] = ACTIONS(2485),
    [anon_sym_const] = ACTIONS(2485),
    [anon_sym_constexpr] = ACTIONS(2485),
    [anon_sym_volatile] = ACTIONS(2485),
    [anon_sym_restrict] = ACTIONS(2485),
    [anon_sym___restrict__] = ACTIONS(2485),
    [anon_sym__Atomic] = ACTIONS(2485),
    [anon_sym__Noreturn] = ACTIONS(2485),
    [anon_sym_noreturn] = ACTIONS(2485),
    [anon_sym__Nonnull] = ACTIONS(2485),
    [anon_sym_mutable] = ACTIONS(2485),
    [anon_sym_constinit] = ACTIONS(2485),
    [anon_sym_consteval] = ACTIONS(2485),
    [anon_sym___shared__] = ACTIONS(2485),
    [anon_sym___local__] = ACTIONS(2485),
    [anon_sym___constant__] = ACTIONS(2485),
    [anon_sym___managed__] = ACTIONS(2485),
    [anon_sym___grid_constant__] = ACTIONS(2485),
    [anon_sym_alignas] = ACTIONS(2485),
    [anon_sym__Alignas] = ACTIONS(2485),
    [sym_primitive_type] = ACTIONS(2485),
    [anon_sym_enum] = ACTIONS(2485),
    [anon_sym_class] = ACTIONS(2485),
    [anon_sym_struct] = ACTIONS(2485),
    [anon_sym_union] = ACTIONS(2485),
    [anon_sym_if] = ACTIONS(2485),
    [anon_sym_switch] = ACTIONS(2485),
    [anon_sym_case] = ACTIONS(2485),
    [anon_sym_default] = ACTIONS(2485),
    [anon_sym_while] = ACTIONS(2485),
    [anon_sym_do] = ACTIONS(2485),
    [anon_sym_for] = ACTIONS(2485),
    [anon_sym_return] = ACTIONS(2485),
    [anon_sym_break] = ACTIONS(2485),
    [anon_sym_continue] = ACTIONS(2485),
    [anon_sym_goto] = ACTIONS(2485),
    [anon_sym___try] = ACTIONS(2485),
    [anon_sym___leave] = ACTIONS(2485),
    [anon_sym_not] = ACTIONS(2485),
    [anon_sym_compl] = ACTIONS(2485),
    [anon_sym_DASH_DASH] = ACTIONS(2487),
    [anon_sym_PLUS_PLUS] = ACTIONS(2487),
    [anon_sym_sizeof] = ACTIONS(2485),
    [anon_sym___alignof__] = ACTIONS(2485),
    [anon_sym___alignof] = ACTIONS(2485),
    [anon_sym__alignof] = ACTIONS(2485),
    [anon_sym_alignof] = ACTIONS(2485),
    [anon_sym__Alignof] = ACTIONS(2485),
    [anon_sym_offsetof] = ACTIONS(2485),
    [anon_sym__Generic] = ACTIONS(2485),
    [anon_sym_asm] = ACTIONS(2485),
    [anon_sym___asm__] = ACTIONS(2485),
    [anon_sym___asm] = ACTIONS(2485),
    [sym_number_literal] = ACTIONS(2487),
    [anon_sym_L_SQUOTE] = ACTIONS(2487),
    [anon_sym_u_SQUOTE] = ACTIONS(2487),
    [anon_sym_U_SQUOTE] = ACTIONS(2487),
    [anon_sym_u8_SQUOTE] = ACTIONS(2487),
    [anon_sym_SQUOTE] = ACTIONS(2487),
    [anon_sym_L_DQUOTE] = ACTIONS(2487),
    [anon_sym_u_DQUOTE] = ACTIONS(2487),
    [anon_sym_U_DQUOTE] = ACTIONS(2487),
    [anon_sym_u8_DQUOTE] = ACTIONS(2487),
    [anon_sym_DQUOTE] = ACTIONS(2487),
    [sym_true] = ACTIONS(2485),
    [sym_false] = ACTIONS(2485),
    [anon_sym_NULL] = ACTIONS(2485),
    [anon_sym_nullptr] = ACTIONS(2485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2485),
    [anon_sym_decltype] = ACTIONS(2485),
    [anon_sym_explicit] = ACTIONS(2485),
    [anon_sym_typename] = ACTIONS(2485),
    [anon_sym_template] = ACTIONS(2485),
    [anon_sym_operator] = ACTIONS(2485),
    [anon_sym_try] = ACTIONS(2485),
    [anon_sym_delete] = ACTIONS(2485),
    [anon_sym_throw] = ACTIONS(2485),
    [anon_sym_namespace] = ACTIONS(2485),
    [anon_sym_using] = ACTIONS(2485),
    [anon_sym_static_assert] = ACTIONS(2485),
    [anon_sym_concept] = ACTIONS(2485),
    [anon_sym_co_return] = ACTIONS(2485),
    [anon_sym_co_yield] = ACTIONS(2485),
    [anon_sym_R_DQUOTE] = ACTIONS(2487),
    [anon_sym_LR_DQUOTE] = ACTIONS(2487),
    [anon_sym_uR_DQUOTE] = ACTIONS(2487),
    [anon_sym_UR_DQUOTE] = ACTIONS(2487),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2487),
    [anon_sym_co_await] = ACTIONS(2485),
    [anon_sym_new] = ACTIONS(2485),
    [anon_sym_requires] = ACTIONS(2485),
    [sym_this] = ACTIONS(2485),
    [anon_sym___launch_bounds__] = ACTIONS(2485),
  },
  [STATE(549)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4927),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7521),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7789),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2930),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(550)] = {
    [sym_identifier] = ACTIONS(2439),
    [aux_sym_preproc_include_token1] = ACTIONS(2439),
    [aux_sym_preproc_def_token1] = ACTIONS(2439),
    [aux_sym_preproc_if_token1] = ACTIONS(2439),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2439),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2439),
    [sym_preproc_directive] = ACTIONS(2439),
    [anon_sym_LPAREN2] = ACTIONS(2441),
    [anon_sym_BANG] = ACTIONS(2441),
    [anon_sym_TILDE] = ACTIONS(2441),
    [anon_sym_DASH] = ACTIONS(2439),
    [anon_sym_PLUS] = ACTIONS(2439),
    [anon_sym_STAR] = ACTIONS(2441),
    [anon_sym_AMP_AMP] = ACTIONS(2441),
    [anon_sym_AMP] = ACTIONS(2439),
    [anon_sym_SEMI] = ACTIONS(2441),
    [anon_sym___extension__] = ACTIONS(2439),
    [anon_sym_typedef] = ACTIONS(2439),
    [anon_sym___device__] = ACTIONS(2439),
    [anon_sym___host__] = ACTIONS(2439),
    [anon_sym___global__] = ACTIONS(2439),
    [anon_sym___forceinline__] = ACTIONS(2439),
    [anon_sym___noinline__] = ACTIONS(2439),
    [anon_sym_virtual] = ACTIONS(2439),
    [anon_sym_extern] = ACTIONS(2439),
    [anon_sym___attribute__] = ACTIONS(2439),
    [anon_sym___attribute] = ACTIONS(2439),
    [anon_sym_COLON_COLON] = ACTIONS(2441),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2441),
    [anon_sym___declspec] = ACTIONS(2439),
    [anon_sym___based] = ACTIONS(2439),
    [anon_sym___cdecl] = ACTIONS(2439),
    [anon_sym___clrcall] = ACTIONS(2439),
    [anon_sym___stdcall] = ACTIONS(2439),
    [anon_sym___fastcall] = ACTIONS(2439),
    [anon_sym___thiscall] = ACTIONS(2439),
    [anon_sym___vectorcall] = ACTIONS(2439),
    [anon_sym_LBRACE] = ACTIONS(2441),
    [anon_sym_RBRACE] = ACTIONS(2441),
    [anon_sym_signed] = ACTIONS(2439),
    [anon_sym_unsigned] = ACTIONS(2439),
    [anon_sym_long] = ACTIONS(2439),
    [anon_sym_short] = ACTIONS(2439),
    [anon_sym_LBRACK] = ACTIONS(2439),
    [anon_sym_static] = ACTIONS(2439),
    [anon_sym_register] = ACTIONS(2439),
    [anon_sym_inline] = ACTIONS(2439),
    [anon_sym___inline] = ACTIONS(2439),
    [anon_sym___inline__] = ACTIONS(2439),
    [anon_sym___forceinline] = ACTIONS(2439),
    [anon_sym_thread_local] = ACTIONS(2439),
    [anon_sym___thread] = ACTIONS(2439),
    [anon_sym_const] = ACTIONS(2439),
    [anon_sym_constexpr] = ACTIONS(2439),
    [anon_sym_volatile] = ACTIONS(2439),
    [anon_sym_restrict] = ACTIONS(2439),
    [anon_sym___restrict__] = ACTIONS(2439),
    [anon_sym__Atomic] = ACTIONS(2439),
    [anon_sym__Noreturn] = ACTIONS(2439),
    [anon_sym_noreturn] = ACTIONS(2439),
    [anon_sym__Nonnull] = ACTIONS(2439),
    [anon_sym_mutable] = ACTIONS(2439),
    [anon_sym_constinit] = ACTIONS(2439),
    [anon_sym_consteval] = ACTIONS(2439),
    [anon_sym___shared__] = ACTIONS(2439),
    [anon_sym___local__] = ACTIONS(2439),
    [anon_sym___constant__] = ACTIONS(2439),
    [anon_sym___managed__] = ACTIONS(2439),
    [anon_sym___grid_constant__] = ACTIONS(2439),
    [anon_sym_alignas] = ACTIONS(2439),
    [anon_sym__Alignas] = ACTIONS(2439),
    [sym_primitive_type] = ACTIONS(2439),
    [anon_sym_enum] = ACTIONS(2439),
    [anon_sym_class] = ACTIONS(2439),
    [anon_sym_struct] = ACTIONS(2439),
    [anon_sym_union] = ACTIONS(2439),
    [anon_sym_if] = ACTIONS(2439),
    [anon_sym_switch] = ACTIONS(2439),
    [anon_sym_case] = ACTIONS(2439),
    [anon_sym_default] = ACTIONS(2439),
    [anon_sym_while] = ACTIONS(2439),
    [anon_sym_do] = ACTIONS(2439),
    [anon_sym_for] = ACTIONS(2439),
    [anon_sym_return] = ACTIONS(2439),
    [anon_sym_break] = ACTIONS(2439),
    [anon_sym_continue] = ACTIONS(2439),
    [anon_sym_goto] = ACTIONS(2439),
    [anon_sym___try] = ACTIONS(2439),
    [anon_sym___leave] = ACTIONS(2439),
    [anon_sym_not] = ACTIONS(2439),
    [anon_sym_compl] = ACTIONS(2439),
    [anon_sym_DASH_DASH] = ACTIONS(2441),
    [anon_sym_PLUS_PLUS] = ACTIONS(2441),
    [anon_sym_sizeof] = ACTIONS(2439),
    [anon_sym___alignof__] = ACTIONS(2439),
    [anon_sym___alignof] = ACTIONS(2439),
    [anon_sym__alignof] = ACTIONS(2439),
    [anon_sym_alignof] = ACTIONS(2439),
    [anon_sym__Alignof] = ACTIONS(2439),
    [anon_sym_offsetof] = ACTIONS(2439),
    [anon_sym__Generic] = ACTIONS(2439),
    [anon_sym_asm] = ACTIONS(2439),
    [anon_sym___asm__] = ACTIONS(2439),
    [anon_sym___asm] = ACTIONS(2439),
    [sym_number_literal] = ACTIONS(2441),
    [anon_sym_L_SQUOTE] = ACTIONS(2441),
    [anon_sym_u_SQUOTE] = ACTIONS(2441),
    [anon_sym_U_SQUOTE] = ACTIONS(2441),
    [anon_sym_u8_SQUOTE] = ACTIONS(2441),
    [anon_sym_SQUOTE] = ACTIONS(2441),
    [anon_sym_L_DQUOTE] = ACTIONS(2441),
    [anon_sym_u_DQUOTE] = ACTIONS(2441),
    [anon_sym_U_DQUOTE] = ACTIONS(2441),
    [anon_sym_u8_DQUOTE] = ACTIONS(2441),
    [anon_sym_DQUOTE] = ACTIONS(2441),
    [sym_true] = ACTIONS(2439),
    [sym_false] = ACTIONS(2439),
    [anon_sym_NULL] = ACTIONS(2439),
    [anon_sym_nullptr] = ACTIONS(2439),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2439),
    [anon_sym_decltype] = ACTIONS(2439),
    [anon_sym_explicit] = ACTIONS(2439),
    [anon_sym_typename] = ACTIONS(2439),
    [anon_sym_template] = ACTIONS(2439),
    [anon_sym_operator] = ACTIONS(2439),
    [anon_sym_try] = ACTIONS(2439),
    [anon_sym_delete] = ACTIONS(2439),
    [anon_sym_throw] = ACTIONS(2439),
    [anon_sym_namespace] = ACTIONS(2439),
    [anon_sym_using] = ACTIONS(2439),
    [anon_sym_static_assert] = ACTIONS(2439),
    [anon_sym_concept] = ACTIONS(2439),
    [anon_sym_co_return] = ACTIONS(2439),
    [anon_sym_co_yield] = ACTIONS(2439),
    [anon_sym_R_DQUOTE] = ACTIONS(2441),
    [anon_sym_LR_DQUOTE] = ACTIONS(2441),
    [anon_sym_uR_DQUOTE] = ACTIONS(2441),
    [anon_sym_UR_DQUOTE] = ACTIONS(2441),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2441),
    [anon_sym_co_await] = ACTIONS(2439),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_requires] = ACTIONS(2439),
    [sym_this] = ACTIONS(2439),
    [anon_sym___launch_bounds__] = ACTIONS(2439),
  },
  [STATE(551)] = {
    [sym_identifier] = ACTIONS(2443),
    [aux_sym_preproc_include_token1] = ACTIONS(2443),
    [aux_sym_preproc_def_token1] = ACTIONS(2443),
    [aux_sym_preproc_if_token1] = ACTIONS(2443),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2443),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2443),
    [sym_preproc_directive] = ACTIONS(2443),
    [anon_sym_LPAREN2] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(2445),
    [anon_sym_TILDE] = ACTIONS(2445),
    [anon_sym_DASH] = ACTIONS(2443),
    [anon_sym_PLUS] = ACTIONS(2443),
    [anon_sym_STAR] = ACTIONS(2445),
    [anon_sym_AMP_AMP] = ACTIONS(2445),
    [anon_sym_AMP] = ACTIONS(2443),
    [anon_sym_SEMI] = ACTIONS(2445),
    [anon_sym___extension__] = ACTIONS(2443),
    [anon_sym_typedef] = ACTIONS(2443),
    [anon_sym___device__] = ACTIONS(2443),
    [anon_sym___host__] = ACTIONS(2443),
    [anon_sym___global__] = ACTIONS(2443),
    [anon_sym___forceinline__] = ACTIONS(2443),
    [anon_sym___noinline__] = ACTIONS(2443),
    [anon_sym_virtual] = ACTIONS(2443),
    [anon_sym_extern] = ACTIONS(2443),
    [anon_sym___attribute__] = ACTIONS(2443),
    [anon_sym___attribute] = ACTIONS(2443),
    [anon_sym_COLON_COLON] = ACTIONS(2445),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2445),
    [anon_sym___declspec] = ACTIONS(2443),
    [anon_sym___based] = ACTIONS(2443),
    [anon_sym___cdecl] = ACTIONS(2443),
    [anon_sym___clrcall] = ACTIONS(2443),
    [anon_sym___stdcall] = ACTIONS(2443),
    [anon_sym___fastcall] = ACTIONS(2443),
    [anon_sym___thiscall] = ACTIONS(2443),
    [anon_sym___vectorcall] = ACTIONS(2443),
    [anon_sym_LBRACE] = ACTIONS(2445),
    [anon_sym_RBRACE] = ACTIONS(2445),
    [anon_sym_signed] = ACTIONS(2443),
    [anon_sym_unsigned] = ACTIONS(2443),
    [anon_sym_long] = ACTIONS(2443),
    [anon_sym_short] = ACTIONS(2443),
    [anon_sym_LBRACK] = ACTIONS(2443),
    [anon_sym_static] = ACTIONS(2443),
    [anon_sym_register] = ACTIONS(2443),
    [anon_sym_inline] = ACTIONS(2443),
    [anon_sym___inline] = ACTIONS(2443),
    [anon_sym___inline__] = ACTIONS(2443),
    [anon_sym___forceinline] = ACTIONS(2443),
    [anon_sym_thread_local] = ACTIONS(2443),
    [anon_sym___thread] = ACTIONS(2443),
    [anon_sym_const] = ACTIONS(2443),
    [anon_sym_constexpr] = ACTIONS(2443),
    [anon_sym_volatile] = ACTIONS(2443),
    [anon_sym_restrict] = ACTIONS(2443),
    [anon_sym___restrict__] = ACTIONS(2443),
    [anon_sym__Atomic] = ACTIONS(2443),
    [anon_sym__Noreturn] = ACTIONS(2443),
    [anon_sym_noreturn] = ACTIONS(2443),
    [anon_sym__Nonnull] = ACTIONS(2443),
    [anon_sym_mutable] = ACTIONS(2443),
    [anon_sym_constinit] = ACTIONS(2443),
    [anon_sym_consteval] = ACTIONS(2443),
    [anon_sym___shared__] = ACTIONS(2443),
    [anon_sym___local__] = ACTIONS(2443),
    [anon_sym___constant__] = ACTIONS(2443),
    [anon_sym___managed__] = ACTIONS(2443),
    [anon_sym___grid_constant__] = ACTIONS(2443),
    [anon_sym_alignas] = ACTIONS(2443),
    [anon_sym__Alignas] = ACTIONS(2443),
    [sym_primitive_type] = ACTIONS(2443),
    [anon_sym_enum] = ACTIONS(2443),
    [anon_sym_class] = ACTIONS(2443),
    [anon_sym_struct] = ACTIONS(2443),
    [anon_sym_union] = ACTIONS(2443),
    [anon_sym_if] = ACTIONS(2443),
    [anon_sym_switch] = ACTIONS(2443),
    [anon_sym_case] = ACTIONS(2443),
    [anon_sym_default] = ACTIONS(2443),
    [anon_sym_while] = ACTIONS(2443),
    [anon_sym_do] = ACTIONS(2443),
    [anon_sym_for] = ACTIONS(2443),
    [anon_sym_return] = ACTIONS(2443),
    [anon_sym_break] = ACTIONS(2443),
    [anon_sym_continue] = ACTIONS(2443),
    [anon_sym_goto] = ACTIONS(2443),
    [anon_sym___try] = ACTIONS(2443),
    [anon_sym___leave] = ACTIONS(2443),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_compl] = ACTIONS(2443),
    [anon_sym_DASH_DASH] = ACTIONS(2445),
    [anon_sym_PLUS_PLUS] = ACTIONS(2445),
    [anon_sym_sizeof] = ACTIONS(2443),
    [anon_sym___alignof__] = ACTIONS(2443),
    [anon_sym___alignof] = ACTIONS(2443),
    [anon_sym__alignof] = ACTIONS(2443),
    [anon_sym_alignof] = ACTIONS(2443),
    [anon_sym__Alignof] = ACTIONS(2443),
    [anon_sym_offsetof] = ACTIONS(2443),
    [anon_sym__Generic] = ACTIONS(2443),
    [anon_sym_asm] = ACTIONS(2443),
    [anon_sym___asm__] = ACTIONS(2443),
    [anon_sym___asm] = ACTIONS(2443),
    [sym_number_literal] = ACTIONS(2445),
    [anon_sym_L_SQUOTE] = ACTIONS(2445),
    [anon_sym_u_SQUOTE] = ACTIONS(2445),
    [anon_sym_U_SQUOTE] = ACTIONS(2445),
    [anon_sym_u8_SQUOTE] = ACTIONS(2445),
    [anon_sym_SQUOTE] = ACTIONS(2445),
    [anon_sym_L_DQUOTE] = ACTIONS(2445),
    [anon_sym_u_DQUOTE] = ACTIONS(2445),
    [anon_sym_U_DQUOTE] = ACTIONS(2445),
    [anon_sym_u8_DQUOTE] = ACTIONS(2445),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_true] = ACTIONS(2443),
    [sym_false] = ACTIONS(2443),
    [anon_sym_NULL] = ACTIONS(2443),
    [anon_sym_nullptr] = ACTIONS(2443),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2443),
    [anon_sym_decltype] = ACTIONS(2443),
    [anon_sym_explicit] = ACTIONS(2443),
    [anon_sym_typename] = ACTIONS(2443),
    [anon_sym_template] = ACTIONS(2443),
    [anon_sym_operator] = ACTIONS(2443),
    [anon_sym_try] = ACTIONS(2443),
    [anon_sym_delete] = ACTIONS(2443),
    [anon_sym_throw] = ACTIONS(2443),
    [anon_sym_namespace] = ACTIONS(2443),
    [anon_sym_using] = ACTIONS(2443),
    [anon_sym_static_assert] = ACTIONS(2443),
    [anon_sym_concept] = ACTIONS(2443),
    [anon_sym_co_return] = ACTIONS(2443),
    [anon_sym_co_yield] = ACTIONS(2443),
    [anon_sym_R_DQUOTE] = ACTIONS(2445),
    [anon_sym_LR_DQUOTE] = ACTIONS(2445),
    [anon_sym_uR_DQUOTE] = ACTIONS(2445),
    [anon_sym_UR_DQUOTE] = ACTIONS(2445),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2445),
    [anon_sym_co_await] = ACTIONS(2443),
    [anon_sym_new] = ACTIONS(2443),
    [anon_sym_requires] = ACTIONS(2443),
    [sym_this] = ACTIONS(2443),
    [anon_sym___launch_bounds__] = ACTIONS(2443),
  },
  [STATE(552)] = {
    [sym_identifier] = ACTIONS(2451),
    [aux_sym_preproc_include_token1] = ACTIONS(2451),
    [aux_sym_preproc_def_token1] = ACTIONS(2451),
    [aux_sym_preproc_if_token1] = ACTIONS(2451),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2451),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2451),
    [sym_preproc_directive] = ACTIONS(2451),
    [anon_sym_LPAREN2] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(2453),
    [anon_sym_TILDE] = ACTIONS(2453),
    [anon_sym_DASH] = ACTIONS(2451),
    [anon_sym_PLUS] = ACTIONS(2451),
    [anon_sym_STAR] = ACTIONS(2453),
    [anon_sym_AMP_AMP] = ACTIONS(2453),
    [anon_sym_AMP] = ACTIONS(2451),
    [anon_sym_SEMI] = ACTIONS(2453),
    [anon_sym___extension__] = ACTIONS(2451),
    [anon_sym_typedef] = ACTIONS(2451),
    [anon_sym___device__] = ACTIONS(2451),
    [anon_sym___host__] = ACTIONS(2451),
    [anon_sym___global__] = ACTIONS(2451),
    [anon_sym___forceinline__] = ACTIONS(2451),
    [anon_sym___noinline__] = ACTIONS(2451),
    [anon_sym_virtual] = ACTIONS(2451),
    [anon_sym_extern] = ACTIONS(2451),
    [anon_sym___attribute__] = ACTIONS(2451),
    [anon_sym___attribute] = ACTIONS(2451),
    [anon_sym_COLON_COLON] = ACTIONS(2453),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2453),
    [anon_sym___declspec] = ACTIONS(2451),
    [anon_sym___based] = ACTIONS(2451),
    [anon_sym___cdecl] = ACTIONS(2451),
    [anon_sym___clrcall] = ACTIONS(2451),
    [anon_sym___stdcall] = ACTIONS(2451),
    [anon_sym___fastcall] = ACTIONS(2451),
    [anon_sym___thiscall] = ACTIONS(2451),
    [anon_sym___vectorcall] = ACTIONS(2451),
    [anon_sym_LBRACE] = ACTIONS(2453),
    [anon_sym_RBRACE] = ACTIONS(2453),
    [anon_sym_signed] = ACTIONS(2451),
    [anon_sym_unsigned] = ACTIONS(2451),
    [anon_sym_long] = ACTIONS(2451),
    [anon_sym_short] = ACTIONS(2451),
    [anon_sym_LBRACK] = ACTIONS(2451),
    [anon_sym_static] = ACTIONS(2451),
    [anon_sym_register] = ACTIONS(2451),
    [anon_sym_inline] = ACTIONS(2451),
    [anon_sym___inline] = ACTIONS(2451),
    [anon_sym___inline__] = ACTIONS(2451),
    [anon_sym___forceinline] = ACTIONS(2451),
    [anon_sym_thread_local] = ACTIONS(2451),
    [anon_sym___thread] = ACTIONS(2451),
    [anon_sym_const] = ACTIONS(2451),
    [anon_sym_constexpr] = ACTIONS(2451),
    [anon_sym_volatile] = ACTIONS(2451),
    [anon_sym_restrict] = ACTIONS(2451),
    [anon_sym___restrict__] = ACTIONS(2451),
    [anon_sym__Atomic] = ACTIONS(2451),
    [anon_sym__Noreturn] = ACTIONS(2451),
    [anon_sym_noreturn] = ACTIONS(2451),
    [anon_sym__Nonnull] = ACTIONS(2451),
    [anon_sym_mutable] = ACTIONS(2451),
    [anon_sym_constinit] = ACTIONS(2451),
    [anon_sym_consteval] = ACTIONS(2451),
    [anon_sym___shared__] = ACTIONS(2451),
    [anon_sym___local__] = ACTIONS(2451),
    [anon_sym___constant__] = ACTIONS(2451),
    [anon_sym___managed__] = ACTIONS(2451),
    [anon_sym___grid_constant__] = ACTIONS(2451),
    [anon_sym_alignas] = ACTIONS(2451),
    [anon_sym__Alignas] = ACTIONS(2451),
    [sym_primitive_type] = ACTIONS(2451),
    [anon_sym_enum] = ACTIONS(2451),
    [anon_sym_class] = ACTIONS(2451),
    [anon_sym_struct] = ACTIONS(2451),
    [anon_sym_union] = ACTIONS(2451),
    [anon_sym_if] = ACTIONS(2451),
    [anon_sym_switch] = ACTIONS(2451),
    [anon_sym_case] = ACTIONS(2451),
    [anon_sym_default] = ACTIONS(2451),
    [anon_sym_while] = ACTIONS(2451),
    [anon_sym_do] = ACTIONS(2451),
    [anon_sym_for] = ACTIONS(2451),
    [anon_sym_return] = ACTIONS(2451),
    [anon_sym_break] = ACTIONS(2451),
    [anon_sym_continue] = ACTIONS(2451),
    [anon_sym_goto] = ACTIONS(2451),
    [anon_sym___try] = ACTIONS(2451),
    [anon_sym___leave] = ACTIONS(2451),
    [anon_sym_not] = ACTIONS(2451),
    [anon_sym_compl] = ACTIONS(2451),
    [anon_sym_DASH_DASH] = ACTIONS(2453),
    [anon_sym_PLUS_PLUS] = ACTIONS(2453),
    [anon_sym_sizeof] = ACTIONS(2451),
    [anon_sym___alignof__] = ACTIONS(2451),
    [anon_sym___alignof] = ACTIONS(2451),
    [anon_sym__alignof] = ACTIONS(2451),
    [anon_sym_alignof] = ACTIONS(2451),
    [anon_sym__Alignof] = ACTIONS(2451),
    [anon_sym_offsetof] = ACTIONS(2451),
    [anon_sym__Generic] = ACTIONS(2451),
    [anon_sym_asm] = ACTIONS(2451),
    [anon_sym___asm__] = ACTIONS(2451),
    [anon_sym___asm] = ACTIONS(2451),
    [sym_number_literal] = ACTIONS(2453),
    [anon_sym_L_SQUOTE] = ACTIONS(2453),
    [anon_sym_u_SQUOTE] = ACTIONS(2453),
    [anon_sym_U_SQUOTE] = ACTIONS(2453),
    [anon_sym_u8_SQUOTE] = ACTIONS(2453),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_L_DQUOTE] = ACTIONS(2453),
    [anon_sym_u_DQUOTE] = ACTIONS(2453),
    [anon_sym_U_DQUOTE] = ACTIONS(2453),
    [anon_sym_u8_DQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2453),
    [sym_true] = ACTIONS(2451),
    [sym_false] = ACTIONS(2451),
    [anon_sym_NULL] = ACTIONS(2451),
    [anon_sym_nullptr] = ACTIONS(2451),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2451),
    [anon_sym_decltype] = ACTIONS(2451),
    [anon_sym_explicit] = ACTIONS(2451),
    [anon_sym_typename] = ACTIONS(2451),
    [anon_sym_template] = ACTIONS(2451),
    [anon_sym_operator] = ACTIONS(2451),
    [anon_sym_try] = ACTIONS(2451),
    [anon_sym_delete] = ACTIONS(2451),
    [anon_sym_throw] = ACTIONS(2451),
    [anon_sym_namespace] = ACTIONS(2451),
    [anon_sym_using] = ACTIONS(2451),
    [anon_sym_static_assert] = ACTIONS(2451),
    [anon_sym_concept] = ACTIONS(2451),
    [anon_sym_co_return] = ACTIONS(2451),
    [anon_sym_co_yield] = ACTIONS(2451),
    [anon_sym_R_DQUOTE] = ACTIONS(2453),
    [anon_sym_LR_DQUOTE] = ACTIONS(2453),
    [anon_sym_uR_DQUOTE] = ACTIONS(2453),
    [anon_sym_UR_DQUOTE] = ACTIONS(2453),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2453),
    [anon_sym_co_await] = ACTIONS(2451),
    [anon_sym_new] = ACTIONS(2451),
    [anon_sym_requires] = ACTIONS(2451),
    [sym_this] = ACTIONS(2451),
    [anon_sym___launch_bounds__] = ACTIONS(2451),
  },
  [STATE(553)] = {
    [sym_identifier] = ACTIONS(2501),
    [aux_sym_preproc_include_token1] = ACTIONS(2501),
    [aux_sym_preproc_def_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2501),
    [sym_preproc_directive] = ACTIONS(2501),
    [anon_sym_LPAREN2] = ACTIONS(2503),
    [anon_sym_BANG] = ACTIONS(2503),
    [anon_sym_TILDE] = ACTIONS(2503),
    [anon_sym_DASH] = ACTIONS(2501),
    [anon_sym_PLUS] = ACTIONS(2501),
    [anon_sym_STAR] = ACTIONS(2503),
    [anon_sym_AMP_AMP] = ACTIONS(2503),
    [anon_sym_AMP] = ACTIONS(2501),
    [anon_sym_SEMI] = ACTIONS(2503),
    [anon_sym___extension__] = ACTIONS(2501),
    [anon_sym_typedef] = ACTIONS(2501),
    [anon_sym___device__] = ACTIONS(2501),
    [anon_sym___host__] = ACTIONS(2501),
    [anon_sym___global__] = ACTIONS(2501),
    [anon_sym___forceinline__] = ACTIONS(2501),
    [anon_sym___noinline__] = ACTIONS(2501),
    [anon_sym_virtual] = ACTIONS(2501),
    [anon_sym_extern] = ACTIONS(2501),
    [anon_sym___attribute__] = ACTIONS(2501),
    [anon_sym___attribute] = ACTIONS(2501),
    [anon_sym_COLON_COLON] = ACTIONS(2503),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2503),
    [anon_sym___declspec] = ACTIONS(2501),
    [anon_sym___based] = ACTIONS(2501),
    [anon_sym___cdecl] = ACTIONS(2501),
    [anon_sym___clrcall] = ACTIONS(2501),
    [anon_sym___stdcall] = ACTIONS(2501),
    [anon_sym___fastcall] = ACTIONS(2501),
    [anon_sym___thiscall] = ACTIONS(2501),
    [anon_sym___vectorcall] = ACTIONS(2501),
    [anon_sym_LBRACE] = ACTIONS(2503),
    [anon_sym_RBRACE] = ACTIONS(2503),
    [anon_sym_signed] = ACTIONS(2501),
    [anon_sym_unsigned] = ACTIONS(2501),
    [anon_sym_long] = ACTIONS(2501),
    [anon_sym_short] = ACTIONS(2501),
    [anon_sym_LBRACK] = ACTIONS(2501),
    [anon_sym_static] = ACTIONS(2501),
    [anon_sym_register] = ACTIONS(2501),
    [anon_sym_inline] = ACTIONS(2501),
    [anon_sym___inline] = ACTIONS(2501),
    [anon_sym___inline__] = ACTIONS(2501),
    [anon_sym___forceinline] = ACTIONS(2501),
    [anon_sym_thread_local] = ACTIONS(2501),
    [anon_sym___thread] = ACTIONS(2501),
    [anon_sym_const] = ACTIONS(2501),
    [anon_sym_constexpr] = ACTIONS(2501),
    [anon_sym_volatile] = ACTIONS(2501),
    [anon_sym_restrict] = ACTIONS(2501),
    [anon_sym___restrict__] = ACTIONS(2501),
    [anon_sym__Atomic] = ACTIONS(2501),
    [anon_sym__Noreturn] = ACTIONS(2501),
    [anon_sym_noreturn] = ACTIONS(2501),
    [anon_sym__Nonnull] = ACTIONS(2501),
    [anon_sym_mutable] = ACTIONS(2501),
    [anon_sym_constinit] = ACTIONS(2501),
    [anon_sym_consteval] = ACTIONS(2501),
    [anon_sym___shared__] = ACTIONS(2501),
    [anon_sym___local__] = ACTIONS(2501),
    [anon_sym___constant__] = ACTIONS(2501),
    [anon_sym___managed__] = ACTIONS(2501),
    [anon_sym___grid_constant__] = ACTIONS(2501),
    [anon_sym_alignas] = ACTIONS(2501),
    [anon_sym__Alignas] = ACTIONS(2501),
    [sym_primitive_type] = ACTIONS(2501),
    [anon_sym_enum] = ACTIONS(2501),
    [anon_sym_class] = ACTIONS(2501),
    [anon_sym_struct] = ACTIONS(2501),
    [anon_sym_union] = ACTIONS(2501),
    [anon_sym_if] = ACTIONS(2501),
    [anon_sym_switch] = ACTIONS(2501),
    [anon_sym_case] = ACTIONS(2501),
    [anon_sym_default] = ACTIONS(2501),
    [anon_sym_while] = ACTIONS(2501),
    [anon_sym_do] = ACTIONS(2501),
    [anon_sym_for] = ACTIONS(2501),
    [anon_sym_return] = ACTIONS(2501),
    [anon_sym_break] = ACTIONS(2501),
    [anon_sym_continue] = ACTIONS(2501),
    [anon_sym_goto] = ACTIONS(2501),
    [anon_sym___try] = ACTIONS(2501),
    [anon_sym___leave] = ACTIONS(2501),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_compl] = ACTIONS(2501),
    [anon_sym_DASH_DASH] = ACTIONS(2503),
    [anon_sym_PLUS_PLUS] = ACTIONS(2503),
    [anon_sym_sizeof] = ACTIONS(2501),
    [anon_sym___alignof__] = ACTIONS(2501),
    [anon_sym___alignof] = ACTIONS(2501),
    [anon_sym__alignof] = ACTIONS(2501),
    [anon_sym_alignof] = ACTIONS(2501),
    [anon_sym__Alignof] = ACTIONS(2501),
    [anon_sym_offsetof] = ACTIONS(2501),
    [anon_sym__Generic] = ACTIONS(2501),
    [anon_sym_asm] = ACTIONS(2501),
    [anon_sym___asm__] = ACTIONS(2501),
    [anon_sym___asm] = ACTIONS(2501),
    [sym_number_literal] = ACTIONS(2503),
    [anon_sym_L_SQUOTE] = ACTIONS(2503),
    [anon_sym_u_SQUOTE] = ACTIONS(2503),
    [anon_sym_U_SQUOTE] = ACTIONS(2503),
    [anon_sym_u8_SQUOTE] = ACTIONS(2503),
    [anon_sym_SQUOTE] = ACTIONS(2503),
    [anon_sym_L_DQUOTE] = ACTIONS(2503),
    [anon_sym_u_DQUOTE] = ACTIONS(2503),
    [anon_sym_U_DQUOTE] = ACTIONS(2503),
    [anon_sym_u8_DQUOTE] = ACTIONS(2503),
    [anon_sym_DQUOTE] = ACTIONS(2503),
    [sym_true] = ACTIONS(2501),
    [sym_false] = ACTIONS(2501),
    [anon_sym_NULL] = ACTIONS(2501),
    [anon_sym_nullptr] = ACTIONS(2501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2501),
    [anon_sym_decltype] = ACTIONS(2501),
    [anon_sym_explicit] = ACTIONS(2501),
    [anon_sym_typename] = ACTIONS(2501),
    [anon_sym_template] = ACTIONS(2501),
    [anon_sym_operator] = ACTIONS(2501),
    [anon_sym_try] = ACTIONS(2501),
    [anon_sym_delete] = ACTIONS(2501),
    [anon_sym_throw] = ACTIONS(2501),
    [anon_sym_namespace] = ACTIONS(2501),
    [anon_sym_using] = ACTIONS(2501),
    [anon_sym_static_assert] = ACTIONS(2501),
    [anon_sym_concept] = ACTIONS(2501),
    [anon_sym_co_return] = ACTIONS(2501),
    [anon_sym_co_yield] = ACTIONS(2501),
    [anon_sym_R_DQUOTE] = ACTIONS(2503),
    [anon_sym_LR_DQUOTE] = ACTIONS(2503),
    [anon_sym_uR_DQUOTE] = ACTIONS(2503),
    [anon_sym_UR_DQUOTE] = ACTIONS(2503),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2503),
    [anon_sym_co_await] = ACTIONS(2501),
    [anon_sym_new] = ACTIONS(2501),
    [anon_sym_requires] = ACTIONS(2501),
    [sym_this] = ACTIONS(2501),
    [anon_sym___launch_bounds__] = ACTIONS(2501),
  },
  [STATE(554)] = {
    [sym_identifier] = ACTIONS(2439),
    [aux_sym_preproc_include_token1] = ACTIONS(2439),
    [aux_sym_preproc_def_token1] = ACTIONS(2439),
    [aux_sym_preproc_if_token1] = ACTIONS(2439),
    [aux_sym_preproc_if_token2] = ACTIONS(2439),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2439),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2439),
    [sym_preproc_directive] = ACTIONS(2439),
    [anon_sym_LPAREN2] = ACTIONS(2441),
    [anon_sym_BANG] = ACTIONS(2441),
    [anon_sym_TILDE] = ACTIONS(2441),
    [anon_sym_DASH] = ACTIONS(2439),
    [anon_sym_PLUS] = ACTIONS(2439),
    [anon_sym_STAR] = ACTIONS(2441),
    [anon_sym_AMP_AMP] = ACTIONS(2441),
    [anon_sym_AMP] = ACTIONS(2439),
    [anon_sym_SEMI] = ACTIONS(2441),
    [anon_sym___extension__] = ACTIONS(2439),
    [anon_sym_typedef] = ACTIONS(2439),
    [anon_sym___device__] = ACTIONS(2439),
    [anon_sym___host__] = ACTIONS(2439),
    [anon_sym___global__] = ACTIONS(2439),
    [anon_sym___forceinline__] = ACTIONS(2439),
    [anon_sym___noinline__] = ACTIONS(2439),
    [anon_sym_virtual] = ACTIONS(2439),
    [anon_sym_extern] = ACTIONS(2439),
    [anon_sym___attribute__] = ACTIONS(2439),
    [anon_sym___attribute] = ACTIONS(2439),
    [anon_sym_COLON_COLON] = ACTIONS(2441),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2441),
    [anon_sym___declspec] = ACTIONS(2439),
    [anon_sym___based] = ACTIONS(2439),
    [anon_sym___cdecl] = ACTIONS(2439),
    [anon_sym___clrcall] = ACTIONS(2439),
    [anon_sym___stdcall] = ACTIONS(2439),
    [anon_sym___fastcall] = ACTIONS(2439),
    [anon_sym___thiscall] = ACTIONS(2439),
    [anon_sym___vectorcall] = ACTIONS(2439),
    [anon_sym_LBRACE] = ACTIONS(2441),
    [anon_sym_signed] = ACTIONS(2439),
    [anon_sym_unsigned] = ACTIONS(2439),
    [anon_sym_long] = ACTIONS(2439),
    [anon_sym_short] = ACTIONS(2439),
    [anon_sym_LBRACK] = ACTIONS(2439),
    [anon_sym_static] = ACTIONS(2439),
    [anon_sym_register] = ACTIONS(2439),
    [anon_sym_inline] = ACTIONS(2439),
    [anon_sym___inline] = ACTIONS(2439),
    [anon_sym___inline__] = ACTIONS(2439),
    [anon_sym___forceinline] = ACTIONS(2439),
    [anon_sym_thread_local] = ACTIONS(2439),
    [anon_sym___thread] = ACTIONS(2439),
    [anon_sym_const] = ACTIONS(2439),
    [anon_sym_constexpr] = ACTIONS(2439),
    [anon_sym_volatile] = ACTIONS(2439),
    [anon_sym_restrict] = ACTIONS(2439),
    [anon_sym___restrict__] = ACTIONS(2439),
    [anon_sym__Atomic] = ACTIONS(2439),
    [anon_sym__Noreturn] = ACTIONS(2439),
    [anon_sym_noreturn] = ACTIONS(2439),
    [anon_sym__Nonnull] = ACTIONS(2439),
    [anon_sym_mutable] = ACTIONS(2439),
    [anon_sym_constinit] = ACTIONS(2439),
    [anon_sym_consteval] = ACTIONS(2439),
    [anon_sym___shared__] = ACTIONS(2439),
    [anon_sym___local__] = ACTIONS(2439),
    [anon_sym___constant__] = ACTIONS(2439),
    [anon_sym___managed__] = ACTIONS(2439),
    [anon_sym___grid_constant__] = ACTIONS(2439),
    [anon_sym_alignas] = ACTIONS(2439),
    [anon_sym__Alignas] = ACTIONS(2439),
    [sym_primitive_type] = ACTIONS(2439),
    [anon_sym_enum] = ACTIONS(2439),
    [anon_sym_class] = ACTIONS(2439),
    [anon_sym_struct] = ACTIONS(2439),
    [anon_sym_union] = ACTIONS(2439),
    [anon_sym_if] = ACTIONS(2439),
    [anon_sym_switch] = ACTIONS(2439),
    [anon_sym_case] = ACTIONS(2439),
    [anon_sym_default] = ACTIONS(2439),
    [anon_sym_while] = ACTIONS(2439),
    [anon_sym_do] = ACTIONS(2439),
    [anon_sym_for] = ACTIONS(2439),
    [anon_sym_return] = ACTIONS(2439),
    [anon_sym_break] = ACTIONS(2439),
    [anon_sym_continue] = ACTIONS(2439),
    [anon_sym_goto] = ACTIONS(2439),
    [anon_sym___try] = ACTIONS(2439),
    [anon_sym___leave] = ACTIONS(2439),
    [anon_sym_not] = ACTIONS(2439),
    [anon_sym_compl] = ACTIONS(2439),
    [anon_sym_DASH_DASH] = ACTIONS(2441),
    [anon_sym_PLUS_PLUS] = ACTIONS(2441),
    [anon_sym_sizeof] = ACTIONS(2439),
    [anon_sym___alignof__] = ACTIONS(2439),
    [anon_sym___alignof] = ACTIONS(2439),
    [anon_sym__alignof] = ACTIONS(2439),
    [anon_sym_alignof] = ACTIONS(2439),
    [anon_sym__Alignof] = ACTIONS(2439),
    [anon_sym_offsetof] = ACTIONS(2439),
    [anon_sym__Generic] = ACTIONS(2439),
    [anon_sym_asm] = ACTIONS(2439),
    [anon_sym___asm__] = ACTIONS(2439),
    [anon_sym___asm] = ACTIONS(2439),
    [sym_number_literal] = ACTIONS(2441),
    [anon_sym_L_SQUOTE] = ACTIONS(2441),
    [anon_sym_u_SQUOTE] = ACTIONS(2441),
    [anon_sym_U_SQUOTE] = ACTIONS(2441),
    [anon_sym_u8_SQUOTE] = ACTIONS(2441),
    [anon_sym_SQUOTE] = ACTIONS(2441),
    [anon_sym_L_DQUOTE] = ACTIONS(2441),
    [anon_sym_u_DQUOTE] = ACTIONS(2441),
    [anon_sym_U_DQUOTE] = ACTIONS(2441),
    [anon_sym_u8_DQUOTE] = ACTIONS(2441),
    [anon_sym_DQUOTE] = ACTIONS(2441),
    [sym_true] = ACTIONS(2439),
    [sym_false] = ACTIONS(2439),
    [anon_sym_NULL] = ACTIONS(2439),
    [anon_sym_nullptr] = ACTIONS(2439),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2439),
    [anon_sym_decltype] = ACTIONS(2439),
    [anon_sym_explicit] = ACTIONS(2439),
    [anon_sym_typename] = ACTIONS(2439),
    [anon_sym_template] = ACTIONS(2439),
    [anon_sym_operator] = ACTIONS(2439),
    [anon_sym_try] = ACTIONS(2439),
    [anon_sym_delete] = ACTIONS(2439),
    [anon_sym_throw] = ACTIONS(2439),
    [anon_sym_namespace] = ACTIONS(2439),
    [anon_sym_using] = ACTIONS(2439),
    [anon_sym_static_assert] = ACTIONS(2439),
    [anon_sym_concept] = ACTIONS(2439),
    [anon_sym_co_return] = ACTIONS(2439),
    [anon_sym_co_yield] = ACTIONS(2439),
    [anon_sym_R_DQUOTE] = ACTIONS(2441),
    [anon_sym_LR_DQUOTE] = ACTIONS(2441),
    [anon_sym_uR_DQUOTE] = ACTIONS(2441),
    [anon_sym_UR_DQUOTE] = ACTIONS(2441),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2441),
    [anon_sym_co_await] = ACTIONS(2439),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_requires] = ACTIONS(2439),
    [sym_this] = ACTIONS(2439),
    [anon_sym___launch_bounds__] = ACTIONS(2439),
  },
  [STATE(555)] = {
    [sym_identifier] = ACTIONS(2443),
    [aux_sym_preproc_include_token1] = ACTIONS(2443),
    [aux_sym_preproc_def_token1] = ACTIONS(2443),
    [aux_sym_preproc_if_token1] = ACTIONS(2443),
    [aux_sym_preproc_if_token2] = ACTIONS(2443),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2443),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2443),
    [sym_preproc_directive] = ACTIONS(2443),
    [anon_sym_LPAREN2] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(2445),
    [anon_sym_TILDE] = ACTIONS(2445),
    [anon_sym_DASH] = ACTIONS(2443),
    [anon_sym_PLUS] = ACTIONS(2443),
    [anon_sym_STAR] = ACTIONS(2445),
    [anon_sym_AMP_AMP] = ACTIONS(2445),
    [anon_sym_AMP] = ACTIONS(2443),
    [anon_sym_SEMI] = ACTIONS(2445),
    [anon_sym___extension__] = ACTIONS(2443),
    [anon_sym_typedef] = ACTIONS(2443),
    [anon_sym___device__] = ACTIONS(2443),
    [anon_sym___host__] = ACTIONS(2443),
    [anon_sym___global__] = ACTIONS(2443),
    [anon_sym___forceinline__] = ACTIONS(2443),
    [anon_sym___noinline__] = ACTIONS(2443),
    [anon_sym_virtual] = ACTIONS(2443),
    [anon_sym_extern] = ACTIONS(2443),
    [anon_sym___attribute__] = ACTIONS(2443),
    [anon_sym___attribute] = ACTIONS(2443),
    [anon_sym_COLON_COLON] = ACTIONS(2445),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2445),
    [anon_sym___declspec] = ACTIONS(2443),
    [anon_sym___based] = ACTIONS(2443),
    [anon_sym___cdecl] = ACTIONS(2443),
    [anon_sym___clrcall] = ACTIONS(2443),
    [anon_sym___stdcall] = ACTIONS(2443),
    [anon_sym___fastcall] = ACTIONS(2443),
    [anon_sym___thiscall] = ACTIONS(2443),
    [anon_sym___vectorcall] = ACTIONS(2443),
    [anon_sym_LBRACE] = ACTIONS(2445),
    [anon_sym_signed] = ACTIONS(2443),
    [anon_sym_unsigned] = ACTIONS(2443),
    [anon_sym_long] = ACTIONS(2443),
    [anon_sym_short] = ACTIONS(2443),
    [anon_sym_LBRACK] = ACTIONS(2443),
    [anon_sym_static] = ACTIONS(2443),
    [anon_sym_register] = ACTIONS(2443),
    [anon_sym_inline] = ACTIONS(2443),
    [anon_sym___inline] = ACTIONS(2443),
    [anon_sym___inline__] = ACTIONS(2443),
    [anon_sym___forceinline] = ACTIONS(2443),
    [anon_sym_thread_local] = ACTIONS(2443),
    [anon_sym___thread] = ACTIONS(2443),
    [anon_sym_const] = ACTIONS(2443),
    [anon_sym_constexpr] = ACTIONS(2443),
    [anon_sym_volatile] = ACTIONS(2443),
    [anon_sym_restrict] = ACTIONS(2443),
    [anon_sym___restrict__] = ACTIONS(2443),
    [anon_sym__Atomic] = ACTIONS(2443),
    [anon_sym__Noreturn] = ACTIONS(2443),
    [anon_sym_noreturn] = ACTIONS(2443),
    [anon_sym__Nonnull] = ACTIONS(2443),
    [anon_sym_mutable] = ACTIONS(2443),
    [anon_sym_constinit] = ACTIONS(2443),
    [anon_sym_consteval] = ACTIONS(2443),
    [anon_sym___shared__] = ACTIONS(2443),
    [anon_sym___local__] = ACTIONS(2443),
    [anon_sym___constant__] = ACTIONS(2443),
    [anon_sym___managed__] = ACTIONS(2443),
    [anon_sym___grid_constant__] = ACTIONS(2443),
    [anon_sym_alignas] = ACTIONS(2443),
    [anon_sym__Alignas] = ACTIONS(2443),
    [sym_primitive_type] = ACTIONS(2443),
    [anon_sym_enum] = ACTIONS(2443),
    [anon_sym_class] = ACTIONS(2443),
    [anon_sym_struct] = ACTIONS(2443),
    [anon_sym_union] = ACTIONS(2443),
    [anon_sym_if] = ACTIONS(2443),
    [anon_sym_switch] = ACTIONS(2443),
    [anon_sym_case] = ACTIONS(2443),
    [anon_sym_default] = ACTIONS(2443),
    [anon_sym_while] = ACTIONS(2443),
    [anon_sym_do] = ACTIONS(2443),
    [anon_sym_for] = ACTIONS(2443),
    [anon_sym_return] = ACTIONS(2443),
    [anon_sym_break] = ACTIONS(2443),
    [anon_sym_continue] = ACTIONS(2443),
    [anon_sym_goto] = ACTIONS(2443),
    [anon_sym___try] = ACTIONS(2443),
    [anon_sym___leave] = ACTIONS(2443),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_compl] = ACTIONS(2443),
    [anon_sym_DASH_DASH] = ACTIONS(2445),
    [anon_sym_PLUS_PLUS] = ACTIONS(2445),
    [anon_sym_sizeof] = ACTIONS(2443),
    [anon_sym___alignof__] = ACTIONS(2443),
    [anon_sym___alignof] = ACTIONS(2443),
    [anon_sym__alignof] = ACTIONS(2443),
    [anon_sym_alignof] = ACTIONS(2443),
    [anon_sym__Alignof] = ACTIONS(2443),
    [anon_sym_offsetof] = ACTIONS(2443),
    [anon_sym__Generic] = ACTIONS(2443),
    [anon_sym_asm] = ACTIONS(2443),
    [anon_sym___asm__] = ACTIONS(2443),
    [anon_sym___asm] = ACTIONS(2443),
    [sym_number_literal] = ACTIONS(2445),
    [anon_sym_L_SQUOTE] = ACTIONS(2445),
    [anon_sym_u_SQUOTE] = ACTIONS(2445),
    [anon_sym_U_SQUOTE] = ACTIONS(2445),
    [anon_sym_u8_SQUOTE] = ACTIONS(2445),
    [anon_sym_SQUOTE] = ACTIONS(2445),
    [anon_sym_L_DQUOTE] = ACTIONS(2445),
    [anon_sym_u_DQUOTE] = ACTIONS(2445),
    [anon_sym_U_DQUOTE] = ACTIONS(2445),
    [anon_sym_u8_DQUOTE] = ACTIONS(2445),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_true] = ACTIONS(2443),
    [sym_false] = ACTIONS(2443),
    [anon_sym_NULL] = ACTIONS(2443),
    [anon_sym_nullptr] = ACTIONS(2443),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2443),
    [anon_sym_decltype] = ACTIONS(2443),
    [anon_sym_explicit] = ACTIONS(2443),
    [anon_sym_typename] = ACTIONS(2443),
    [anon_sym_template] = ACTIONS(2443),
    [anon_sym_operator] = ACTIONS(2443),
    [anon_sym_try] = ACTIONS(2443),
    [anon_sym_delete] = ACTIONS(2443),
    [anon_sym_throw] = ACTIONS(2443),
    [anon_sym_namespace] = ACTIONS(2443),
    [anon_sym_using] = ACTIONS(2443),
    [anon_sym_static_assert] = ACTIONS(2443),
    [anon_sym_concept] = ACTIONS(2443),
    [anon_sym_co_return] = ACTIONS(2443),
    [anon_sym_co_yield] = ACTIONS(2443),
    [anon_sym_R_DQUOTE] = ACTIONS(2445),
    [anon_sym_LR_DQUOTE] = ACTIONS(2445),
    [anon_sym_uR_DQUOTE] = ACTIONS(2445),
    [anon_sym_UR_DQUOTE] = ACTIONS(2445),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2445),
    [anon_sym_co_await] = ACTIONS(2443),
    [anon_sym_new] = ACTIONS(2443),
    [anon_sym_requires] = ACTIONS(2443),
    [sym_this] = ACTIONS(2443),
    [anon_sym___launch_bounds__] = ACTIONS(2443),
  },
  [STATE(556)] = {
    [sym_identifier] = ACTIONS(2451),
    [aux_sym_preproc_include_token1] = ACTIONS(2451),
    [aux_sym_preproc_def_token1] = ACTIONS(2451),
    [aux_sym_preproc_if_token1] = ACTIONS(2451),
    [aux_sym_preproc_if_token2] = ACTIONS(2451),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2451),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2451),
    [sym_preproc_directive] = ACTIONS(2451),
    [anon_sym_LPAREN2] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(2453),
    [anon_sym_TILDE] = ACTIONS(2453),
    [anon_sym_DASH] = ACTIONS(2451),
    [anon_sym_PLUS] = ACTIONS(2451),
    [anon_sym_STAR] = ACTIONS(2453),
    [anon_sym_AMP_AMP] = ACTIONS(2453),
    [anon_sym_AMP] = ACTIONS(2451),
    [anon_sym_SEMI] = ACTIONS(2453),
    [anon_sym___extension__] = ACTIONS(2451),
    [anon_sym_typedef] = ACTIONS(2451),
    [anon_sym___device__] = ACTIONS(2451),
    [anon_sym___host__] = ACTIONS(2451),
    [anon_sym___global__] = ACTIONS(2451),
    [anon_sym___forceinline__] = ACTIONS(2451),
    [anon_sym___noinline__] = ACTIONS(2451),
    [anon_sym_virtual] = ACTIONS(2451),
    [anon_sym_extern] = ACTIONS(2451),
    [anon_sym___attribute__] = ACTIONS(2451),
    [anon_sym___attribute] = ACTIONS(2451),
    [anon_sym_COLON_COLON] = ACTIONS(2453),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2453),
    [anon_sym___declspec] = ACTIONS(2451),
    [anon_sym___based] = ACTIONS(2451),
    [anon_sym___cdecl] = ACTIONS(2451),
    [anon_sym___clrcall] = ACTIONS(2451),
    [anon_sym___stdcall] = ACTIONS(2451),
    [anon_sym___fastcall] = ACTIONS(2451),
    [anon_sym___thiscall] = ACTIONS(2451),
    [anon_sym___vectorcall] = ACTIONS(2451),
    [anon_sym_LBRACE] = ACTIONS(2453),
    [anon_sym_signed] = ACTIONS(2451),
    [anon_sym_unsigned] = ACTIONS(2451),
    [anon_sym_long] = ACTIONS(2451),
    [anon_sym_short] = ACTIONS(2451),
    [anon_sym_LBRACK] = ACTIONS(2451),
    [anon_sym_static] = ACTIONS(2451),
    [anon_sym_register] = ACTIONS(2451),
    [anon_sym_inline] = ACTIONS(2451),
    [anon_sym___inline] = ACTIONS(2451),
    [anon_sym___inline__] = ACTIONS(2451),
    [anon_sym___forceinline] = ACTIONS(2451),
    [anon_sym_thread_local] = ACTIONS(2451),
    [anon_sym___thread] = ACTIONS(2451),
    [anon_sym_const] = ACTIONS(2451),
    [anon_sym_constexpr] = ACTIONS(2451),
    [anon_sym_volatile] = ACTIONS(2451),
    [anon_sym_restrict] = ACTIONS(2451),
    [anon_sym___restrict__] = ACTIONS(2451),
    [anon_sym__Atomic] = ACTIONS(2451),
    [anon_sym__Noreturn] = ACTIONS(2451),
    [anon_sym_noreturn] = ACTIONS(2451),
    [anon_sym__Nonnull] = ACTIONS(2451),
    [anon_sym_mutable] = ACTIONS(2451),
    [anon_sym_constinit] = ACTIONS(2451),
    [anon_sym_consteval] = ACTIONS(2451),
    [anon_sym___shared__] = ACTIONS(2451),
    [anon_sym___local__] = ACTIONS(2451),
    [anon_sym___constant__] = ACTIONS(2451),
    [anon_sym___managed__] = ACTIONS(2451),
    [anon_sym___grid_constant__] = ACTIONS(2451),
    [anon_sym_alignas] = ACTIONS(2451),
    [anon_sym__Alignas] = ACTIONS(2451),
    [sym_primitive_type] = ACTIONS(2451),
    [anon_sym_enum] = ACTIONS(2451),
    [anon_sym_class] = ACTIONS(2451),
    [anon_sym_struct] = ACTIONS(2451),
    [anon_sym_union] = ACTIONS(2451),
    [anon_sym_if] = ACTIONS(2451),
    [anon_sym_switch] = ACTIONS(2451),
    [anon_sym_case] = ACTIONS(2451),
    [anon_sym_default] = ACTIONS(2451),
    [anon_sym_while] = ACTIONS(2451),
    [anon_sym_do] = ACTIONS(2451),
    [anon_sym_for] = ACTIONS(2451),
    [anon_sym_return] = ACTIONS(2451),
    [anon_sym_break] = ACTIONS(2451),
    [anon_sym_continue] = ACTIONS(2451),
    [anon_sym_goto] = ACTIONS(2451),
    [anon_sym___try] = ACTIONS(2451),
    [anon_sym___leave] = ACTIONS(2451),
    [anon_sym_not] = ACTIONS(2451),
    [anon_sym_compl] = ACTIONS(2451),
    [anon_sym_DASH_DASH] = ACTIONS(2453),
    [anon_sym_PLUS_PLUS] = ACTIONS(2453),
    [anon_sym_sizeof] = ACTIONS(2451),
    [anon_sym___alignof__] = ACTIONS(2451),
    [anon_sym___alignof] = ACTIONS(2451),
    [anon_sym__alignof] = ACTIONS(2451),
    [anon_sym_alignof] = ACTIONS(2451),
    [anon_sym__Alignof] = ACTIONS(2451),
    [anon_sym_offsetof] = ACTIONS(2451),
    [anon_sym__Generic] = ACTIONS(2451),
    [anon_sym_asm] = ACTIONS(2451),
    [anon_sym___asm__] = ACTIONS(2451),
    [anon_sym___asm] = ACTIONS(2451),
    [sym_number_literal] = ACTIONS(2453),
    [anon_sym_L_SQUOTE] = ACTIONS(2453),
    [anon_sym_u_SQUOTE] = ACTIONS(2453),
    [anon_sym_U_SQUOTE] = ACTIONS(2453),
    [anon_sym_u8_SQUOTE] = ACTIONS(2453),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_L_DQUOTE] = ACTIONS(2453),
    [anon_sym_u_DQUOTE] = ACTIONS(2453),
    [anon_sym_U_DQUOTE] = ACTIONS(2453),
    [anon_sym_u8_DQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2453),
    [sym_true] = ACTIONS(2451),
    [sym_false] = ACTIONS(2451),
    [anon_sym_NULL] = ACTIONS(2451),
    [anon_sym_nullptr] = ACTIONS(2451),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2451),
    [anon_sym_decltype] = ACTIONS(2451),
    [anon_sym_explicit] = ACTIONS(2451),
    [anon_sym_typename] = ACTIONS(2451),
    [anon_sym_template] = ACTIONS(2451),
    [anon_sym_operator] = ACTIONS(2451),
    [anon_sym_try] = ACTIONS(2451),
    [anon_sym_delete] = ACTIONS(2451),
    [anon_sym_throw] = ACTIONS(2451),
    [anon_sym_namespace] = ACTIONS(2451),
    [anon_sym_using] = ACTIONS(2451),
    [anon_sym_static_assert] = ACTIONS(2451),
    [anon_sym_concept] = ACTIONS(2451),
    [anon_sym_co_return] = ACTIONS(2451),
    [anon_sym_co_yield] = ACTIONS(2451),
    [anon_sym_R_DQUOTE] = ACTIONS(2453),
    [anon_sym_LR_DQUOTE] = ACTIONS(2453),
    [anon_sym_uR_DQUOTE] = ACTIONS(2453),
    [anon_sym_UR_DQUOTE] = ACTIONS(2453),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2453),
    [anon_sym_co_await] = ACTIONS(2451),
    [anon_sym_new] = ACTIONS(2451),
    [anon_sym_requires] = ACTIONS(2451),
    [sym_this] = ACTIONS(2451),
    [anon_sym___launch_bounds__] = ACTIONS(2451),
  },
  [STATE(557)] = {
    [sym_expression] = STATE(3298),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_initializer_list] = STATE(3925),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_RPAREN] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(1860),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2633),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2633),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(2936),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_EQ] = ACTIONS(2633),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_STAR_EQ] = ACTIONS(2635),
    [anon_sym_SLASH_EQ] = ACTIONS(2635),
    [anon_sym_PERCENT_EQ] = ACTIONS(2635),
    [anon_sym_PLUS_EQ] = ACTIONS(2635),
    [anon_sym_DASH_EQ] = ACTIONS(2635),
    [anon_sym_LT_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT_GT_EQ] = ACTIONS(2635),
    [anon_sym_AMP_EQ] = ACTIONS(2635),
    [anon_sym_CARET_EQ] = ACTIONS(2635),
    [anon_sym_PIPE_EQ] = ACTIONS(2635),
    [anon_sym_and_eq] = ACTIONS(2633),
    [anon_sym_or_eq] = ACTIONS(2633),
    [anon_sym_xor_eq] = ACTIONS(2633),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2633),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [anon_sym_DASH_GT_STAR] = ACTIONS(2635),
    [sym_this] = ACTIONS(1904),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(558)] = {
    [sym_identifier] = ACTIONS(2557),
    [aux_sym_preproc_include_token1] = ACTIONS(2557),
    [aux_sym_preproc_def_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2557),
    [sym_preproc_directive] = ACTIONS(2557),
    [anon_sym_LPAREN2] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2557),
    [anon_sym_PLUS] = ACTIONS(2557),
    [anon_sym_STAR] = ACTIONS(2559),
    [anon_sym_AMP_AMP] = ACTIONS(2559),
    [anon_sym_AMP] = ACTIONS(2557),
    [anon_sym_SEMI] = ACTIONS(2559),
    [anon_sym___extension__] = ACTIONS(2557),
    [anon_sym_typedef] = ACTIONS(2557),
    [anon_sym___device__] = ACTIONS(2557),
    [anon_sym___host__] = ACTIONS(2557),
    [anon_sym___global__] = ACTIONS(2557),
    [anon_sym___forceinline__] = ACTIONS(2557),
    [anon_sym___noinline__] = ACTIONS(2557),
    [anon_sym_virtual] = ACTIONS(2557),
    [anon_sym_extern] = ACTIONS(2557),
    [anon_sym___attribute__] = ACTIONS(2557),
    [anon_sym___attribute] = ACTIONS(2557),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2559),
    [anon_sym___declspec] = ACTIONS(2557),
    [anon_sym___based] = ACTIONS(2557),
    [anon_sym___cdecl] = ACTIONS(2557),
    [anon_sym___clrcall] = ACTIONS(2557),
    [anon_sym___stdcall] = ACTIONS(2557),
    [anon_sym___fastcall] = ACTIONS(2557),
    [anon_sym___thiscall] = ACTIONS(2557),
    [anon_sym___vectorcall] = ACTIONS(2557),
    [anon_sym_LBRACE] = ACTIONS(2559),
    [anon_sym_RBRACE] = ACTIONS(2559),
    [anon_sym_signed] = ACTIONS(2557),
    [anon_sym_unsigned] = ACTIONS(2557),
    [anon_sym_long] = ACTIONS(2557),
    [anon_sym_short] = ACTIONS(2557),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2557),
    [anon_sym_register] = ACTIONS(2557),
    [anon_sym_inline] = ACTIONS(2557),
    [anon_sym___inline] = ACTIONS(2557),
    [anon_sym___inline__] = ACTIONS(2557),
    [anon_sym___forceinline] = ACTIONS(2557),
    [anon_sym_thread_local] = ACTIONS(2557),
    [anon_sym___thread] = ACTIONS(2557),
    [anon_sym_const] = ACTIONS(2557),
    [anon_sym_constexpr] = ACTIONS(2557),
    [anon_sym_volatile] = ACTIONS(2557),
    [anon_sym_restrict] = ACTIONS(2557),
    [anon_sym___restrict__] = ACTIONS(2557),
    [anon_sym__Atomic] = ACTIONS(2557),
    [anon_sym__Noreturn] = ACTIONS(2557),
    [anon_sym_noreturn] = ACTIONS(2557),
    [anon_sym__Nonnull] = ACTIONS(2557),
    [anon_sym_mutable] = ACTIONS(2557),
    [anon_sym_constinit] = ACTIONS(2557),
    [anon_sym_consteval] = ACTIONS(2557),
    [anon_sym___shared__] = ACTIONS(2557),
    [anon_sym___local__] = ACTIONS(2557),
    [anon_sym___constant__] = ACTIONS(2557),
    [anon_sym___managed__] = ACTIONS(2557),
    [anon_sym___grid_constant__] = ACTIONS(2557),
    [anon_sym_alignas] = ACTIONS(2557),
    [anon_sym__Alignas] = ACTIONS(2557),
    [sym_primitive_type] = ACTIONS(2557),
    [anon_sym_enum] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2557),
    [anon_sym_struct] = ACTIONS(2557),
    [anon_sym_union] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2557),
    [anon_sym_switch] = ACTIONS(2557),
    [anon_sym_case] = ACTIONS(2557),
    [anon_sym_default] = ACTIONS(2557),
    [anon_sym_while] = ACTIONS(2557),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_for] = ACTIONS(2557),
    [anon_sym_return] = ACTIONS(2557),
    [anon_sym_break] = ACTIONS(2557),
    [anon_sym_continue] = ACTIONS(2557),
    [anon_sym_goto] = ACTIONS(2557),
    [anon_sym___try] = ACTIONS(2557),
    [anon_sym___leave] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2557),
    [anon_sym_compl] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2559),
    [anon_sym_sizeof] = ACTIONS(2557),
    [anon_sym___alignof__] = ACTIONS(2557),
    [anon_sym___alignof] = ACTIONS(2557),
    [anon_sym__alignof] = ACTIONS(2557),
    [anon_sym_alignof] = ACTIONS(2557),
    [anon_sym__Alignof] = ACTIONS(2557),
    [anon_sym_offsetof] = ACTIONS(2557),
    [anon_sym__Generic] = ACTIONS(2557),
    [anon_sym_asm] = ACTIONS(2557),
    [anon_sym___asm__] = ACTIONS(2557),
    [anon_sym___asm] = ACTIONS(2557),
    [sym_number_literal] = ACTIONS(2559),
    [anon_sym_L_SQUOTE] = ACTIONS(2559),
    [anon_sym_u_SQUOTE] = ACTIONS(2559),
    [anon_sym_U_SQUOTE] = ACTIONS(2559),
    [anon_sym_u8_SQUOTE] = ACTIONS(2559),
    [anon_sym_SQUOTE] = ACTIONS(2559),
    [anon_sym_L_DQUOTE] = ACTIONS(2559),
    [anon_sym_u_DQUOTE] = ACTIONS(2559),
    [anon_sym_U_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8_DQUOTE] = ACTIONS(2559),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_true] = ACTIONS(2557),
    [sym_false] = ACTIONS(2557),
    [anon_sym_NULL] = ACTIONS(2557),
    [anon_sym_nullptr] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2557),
    [anon_sym_decltype] = ACTIONS(2557),
    [anon_sym_explicit] = ACTIONS(2557),
    [anon_sym_typename] = ACTIONS(2557),
    [anon_sym_template] = ACTIONS(2557),
    [anon_sym_operator] = ACTIONS(2557),
    [anon_sym_try] = ACTIONS(2557),
    [anon_sym_delete] = ACTIONS(2557),
    [anon_sym_throw] = ACTIONS(2557),
    [anon_sym_namespace] = ACTIONS(2557),
    [anon_sym_using] = ACTIONS(2557),
    [anon_sym_static_assert] = ACTIONS(2557),
    [anon_sym_concept] = ACTIONS(2557),
    [anon_sym_co_return] = ACTIONS(2557),
    [anon_sym_co_yield] = ACTIONS(2557),
    [anon_sym_R_DQUOTE] = ACTIONS(2559),
    [anon_sym_LR_DQUOTE] = ACTIONS(2559),
    [anon_sym_uR_DQUOTE] = ACTIONS(2559),
    [anon_sym_UR_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2559),
    [anon_sym_co_await] = ACTIONS(2557),
    [anon_sym_new] = ACTIONS(2557),
    [anon_sym_requires] = ACTIONS(2557),
    [sym_this] = ACTIONS(2557),
    [anon_sym___launch_bounds__] = ACTIONS(2557),
  },
  [STATE(559)] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_include_token1] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym___device__] = ACTIONS(2565),
    [anon_sym___host__] = ACTIONS(2565),
    [anon_sym___global__] = ACTIONS(2565),
    [anon_sym___forceinline__] = ACTIONS(2565),
    [anon_sym___noinline__] = ACTIONS(2565),
    [anon_sym_virtual] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym___attribute] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym___cdecl] = ACTIONS(2565),
    [anon_sym___clrcall] = ACTIONS(2565),
    [anon_sym___stdcall] = ACTIONS(2565),
    [anon_sym___fastcall] = ACTIONS(2565),
    [anon_sym___thiscall] = ACTIONS(2565),
    [anon_sym___vectorcall] = ACTIONS(2565),
    [anon_sym_LBRACE] = ACTIONS(2567),
    [anon_sym_RBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym__Nonnull] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym___shared__] = ACTIONS(2565),
    [anon_sym___local__] = ACTIONS(2565),
    [anon_sym___constant__] = ACTIONS(2565),
    [anon_sym___managed__] = ACTIONS(2565),
    [anon_sym___grid_constant__] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_switch] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_default] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_do] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_return] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_goto] = ACTIONS(2565),
    [anon_sym___try] = ACTIONS(2565),
    [anon_sym___leave] = ACTIONS(2565),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_compl] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2567),
    [anon_sym_sizeof] = ACTIONS(2565),
    [anon_sym___alignof__] = ACTIONS(2565),
    [anon_sym___alignof] = ACTIONS(2565),
    [anon_sym__alignof] = ACTIONS(2565),
    [anon_sym_alignof] = ACTIONS(2565),
    [anon_sym__Alignof] = ACTIONS(2565),
    [anon_sym_offsetof] = ACTIONS(2565),
    [anon_sym__Generic] = ACTIONS(2565),
    [anon_sym_asm] = ACTIONS(2565),
    [anon_sym___asm__] = ACTIONS(2565),
    [anon_sym___asm] = ACTIONS(2565),
    [sym_number_literal] = ACTIONS(2567),
    [anon_sym_L_SQUOTE] = ACTIONS(2567),
    [anon_sym_u_SQUOTE] = ACTIONS(2567),
    [anon_sym_U_SQUOTE] = ACTIONS(2567),
    [anon_sym_u8_SQUOTE] = ACTIONS(2567),
    [anon_sym_SQUOTE] = ACTIONS(2567),
    [anon_sym_L_DQUOTE] = ACTIONS(2567),
    [anon_sym_u_DQUOTE] = ACTIONS(2567),
    [anon_sym_U_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8_DQUOTE] = ACTIONS(2567),
    [anon_sym_DQUOTE] = ACTIONS(2567),
    [sym_true] = ACTIONS(2565),
    [sym_false] = ACTIONS(2565),
    [anon_sym_NULL] = ACTIONS(2565),
    [anon_sym_nullptr] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_try] = ACTIONS(2565),
    [anon_sym_delete] = ACTIONS(2565),
    [anon_sym_throw] = ACTIONS(2565),
    [anon_sym_namespace] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_concept] = ACTIONS(2565),
    [anon_sym_co_return] = ACTIONS(2565),
    [anon_sym_co_yield] = ACTIONS(2565),
    [anon_sym_R_DQUOTE] = ACTIONS(2567),
    [anon_sym_LR_DQUOTE] = ACTIONS(2567),
    [anon_sym_uR_DQUOTE] = ACTIONS(2567),
    [anon_sym_UR_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2567),
    [anon_sym_co_await] = ACTIONS(2565),
    [anon_sym_new] = ACTIONS(2565),
    [anon_sym_requires] = ACTIONS(2565),
    [sym_this] = ACTIONS(2565),
    [anon_sym___launch_bounds__] = ACTIONS(2565),
  },
  [STATE(560)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(5005),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7588),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8145),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2940),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(561)] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_include_token1] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_BANG] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym___device__] = ACTIONS(2577),
    [anon_sym___host__] = ACTIONS(2577),
    [anon_sym___global__] = ACTIONS(2577),
    [anon_sym___forceinline__] = ACTIONS(2577),
    [anon_sym___noinline__] = ACTIONS(2577),
    [anon_sym_virtual] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym___attribute] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym___cdecl] = ACTIONS(2577),
    [anon_sym___clrcall] = ACTIONS(2577),
    [anon_sym___stdcall] = ACTIONS(2577),
    [anon_sym___fastcall] = ACTIONS(2577),
    [anon_sym___thiscall] = ACTIONS(2577),
    [anon_sym___vectorcall] = ACTIONS(2577),
    [anon_sym_LBRACE] = ACTIONS(2579),
    [anon_sym_RBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym__Nonnull] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym___shared__] = ACTIONS(2577),
    [anon_sym___local__] = ACTIONS(2577),
    [anon_sym___constant__] = ACTIONS(2577),
    [anon_sym___managed__] = ACTIONS(2577),
    [anon_sym___grid_constant__] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_switch] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_default] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_do] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_return] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_goto] = ACTIONS(2577),
    [anon_sym___try] = ACTIONS(2577),
    [anon_sym___leave] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_compl] = ACTIONS(2577),
    [anon_sym_DASH_DASH] = ACTIONS(2579),
    [anon_sym_PLUS_PLUS] = ACTIONS(2579),
    [anon_sym_sizeof] = ACTIONS(2577),
    [anon_sym___alignof__] = ACTIONS(2577),
    [anon_sym___alignof] = ACTIONS(2577),
    [anon_sym__alignof] = ACTIONS(2577),
    [anon_sym_alignof] = ACTIONS(2577),
    [anon_sym__Alignof] = ACTIONS(2577),
    [anon_sym_offsetof] = ACTIONS(2577),
    [anon_sym__Generic] = ACTIONS(2577),
    [anon_sym_asm] = ACTIONS(2577),
    [anon_sym___asm__] = ACTIONS(2577),
    [anon_sym___asm] = ACTIONS(2577),
    [sym_number_literal] = ACTIONS(2579),
    [anon_sym_L_SQUOTE] = ACTIONS(2579),
    [anon_sym_u_SQUOTE] = ACTIONS(2579),
    [anon_sym_U_SQUOTE] = ACTIONS(2579),
    [anon_sym_u8_SQUOTE] = ACTIONS(2579),
    [anon_sym_SQUOTE] = ACTIONS(2579),
    [anon_sym_L_DQUOTE] = ACTIONS(2579),
    [anon_sym_u_DQUOTE] = ACTIONS(2579),
    [anon_sym_U_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8_DQUOTE] = ACTIONS(2579),
    [anon_sym_DQUOTE] = ACTIONS(2579),
    [sym_true] = ACTIONS(2577),
    [sym_false] = ACTIONS(2577),
    [anon_sym_NULL] = ACTIONS(2577),
    [anon_sym_nullptr] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_try] = ACTIONS(2577),
    [anon_sym_delete] = ACTIONS(2577),
    [anon_sym_throw] = ACTIONS(2577),
    [anon_sym_namespace] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_concept] = ACTIONS(2577),
    [anon_sym_co_return] = ACTIONS(2577),
    [anon_sym_co_yield] = ACTIONS(2577),
    [anon_sym_R_DQUOTE] = ACTIONS(2579),
    [anon_sym_LR_DQUOTE] = ACTIONS(2579),
    [anon_sym_uR_DQUOTE] = ACTIONS(2579),
    [anon_sym_UR_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2579),
    [anon_sym_co_await] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(2577),
    [anon_sym_requires] = ACTIONS(2577),
    [sym_this] = ACTIONS(2577),
    [anon_sym___launch_bounds__] = ACTIONS(2577),
  },
  [STATE(562)] = {
    [sym_identifier] = ACTIONS(2226),
    [aux_sym_preproc_include_token1] = ACTIONS(2226),
    [aux_sym_preproc_def_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2226),
    [sym_preproc_directive] = ACTIONS(2226),
    [anon_sym_LPAREN2] = ACTIONS(2228),
    [anon_sym_BANG] = ACTIONS(2228),
    [anon_sym_TILDE] = ACTIONS(2228),
    [anon_sym_DASH] = ACTIONS(2226),
    [anon_sym_PLUS] = ACTIONS(2226),
    [anon_sym_STAR] = ACTIONS(2228),
    [anon_sym_AMP_AMP] = ACTIONS(2228),
    [anon_sym_AMP] = ACTIONS(2226),
    [anon_sym_SEMI] = ACTIONS(2228),
    [anon_sym___extension__] = ACTIONS(2226),
    [anon_sym_typedef] = ACTIONS(2226),
    [anon_sym___device__] = ACTIONS(2226),
    [anon_sym___host__] = ACTIONS(2226),
    [anon_sym___global__] = ACTIONS(2226),
    [anon_sym___forceinline__] = ACTIONS(2226),
    [anon_sym___noinline__] = ACTIONS(2226),
    [anon_sym_virtual] = ACTIONS(2226),
    [anon_sym_extern] = ACTIONS(2226),
    [anon_sym___attribute__] = ACTIONS(2226),
    [anon_sym___attribute] = ACTIONS(2226),
    [anon_sym_COLON_COLON] = ACTIONS(2228),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2228),
    [anon_sym___declspec] = ACTIONS(2226),
    [anon_sym___based] = ACTIONS(2226),
    [anon_sym___cdecl] = ACTIONS(2226),
    [anon_sym___clrcall] = ACTIONS(2226),
    [anon_sym___stdcall] = ACTIONS(2226),
    [anon_sym___fastcall] = ACTIONS(2226),
    [anon_sym___thiscall] = ACTIONS(2226),
    [anon_sym___vectorcall] = ACTIONS(2226),
    [anon_sym_LBRACE] = ACTIONS(2228),
    [anon_sym_RBRACE] = ACTIONS(2228),
    [anon_sym_signed] = ACTIONS(2226),
    [anon_sym_unsigned] = ACTIONS(2226),
    [anon_sym_long] = ACTIONS(2226),
    [anon_sym_short] = ACTIONS(2226),
    [anon_sym_LBRACK] = ACTIONS(2226),
    [anon_sym_static] = ACTIONS(2226),
    [anon_sym_register] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(2226),
    [anon_sym___inline] = ACTIONS(2226),
    [anon_sym___inline__] = ACTIONS(2226),
    [anon_sym___forceinline] = ACTIONS(2226),
    [anon_sym_thread_local] = ACTIONS(2226),
    [anon_sym___thread] = ACTIONS(2226),
    [anon_sym_const] = ACTIONS(2226),
    [anon_sym_constexpr] = ACTIONS(2226),
    [anon_sym_volatile] = ACTIONS(2226),
    [anon_sym_restrict] = ACTIONS(2226),
    [anon_sym___restrict__] = ACTIONS(2226),
    [anon_sym__Atomic] = ACTIONS(2226),
    [anon_sym__Noreturn] = ACTIONS(2226),
    [anon_sym_noreturn] = ACTIONS(2226),
    [anon_sym__Nonnull] = ACTIONS(2226),
    [anon_sym_mutable] = ACTIONS(2226),
    [anon_sym_constinit] = ACTIONS(2226),
    [anon_sym_consteval] = ACTIONS(2226),
    [anon_sym___shared__] = ACTIONS(2226),
    [anon_sym___local__] = ACTIONS(2226),
    [anon_sym___constant__] = ACTIONS(2226),
    [anon_sym___managed__] = ACTIONS(2226),
    [anon_sym___grid_constant__] = ACTIONS(2226),
    [anon_sym_alignas] = ACTIONS(2226),
    [anon_sym__Alignas] = ACTIONS(2226),
    [sym_primitive_type] = ACTIONS(2226),
    [anon_sym_enum] = ACTIONS(2226),
    [anon_sym_class] = ACTIONS(2226),
    [anon_sym_struct] = ACTIONS(2226),
    [anon_sym_union] = ACTIONS(2226),
    [anon_sym_if] = ACTIONS(2226),
    [anon_sym_switch] = ACTIONS(2226),
    [anon_sym_case] = ACTIONS(2226),
    [anon_sym_default] = ACTIONS(2226),
    [anon_sym_while] = ACTIONS(2226),
    [anon_sym_do] = ACTIONS(2226),
    [anon_sym_for] = ACTIONS(2226),
    [anon_sym_return] = ACTIONS(2226),
    [anon_sym_break] = ACTIONS(2226),
    [anon_sym_continue] = ACTIONS(2226),
    [anon_sym_goto] = ACTIONS(2226),
    [anon_sym___try] = ACTIONS(2226),
    [anon_sym___leave] = ACTIONS(2226),
    [anon_sym_not] = ACTIONS(2226),
    [anon_sym_compl] = ACTIONS(2226),
    [anon_sym_DASH_DASH] = ACTIONS(2228),
    [anon_sym_PLUS_PLUS] = ACTIONS(2228),
    [anon_sym_sizeof] = ACTIONS(2226),
    [anon_sym___alignof__] = ACTIONS(2226),
    [anon_sym___alignof] = ACTIONS(2226),
    [anon_sym__alignof] = ACTIONS(2226),
    [anon_sym_alignof] = ACTIONS(2226),
    [anon_sym__Alignof] = ACTIONS(2226),
    [anon_sym_offsetof] = ACTIONS(2226),
    [anon_sym__Generic] = ACTIONS(2226),
    [anon_sym_asm] = ACTIONS(2226),
    [anon_sym___asm__] = ACTIONS(2226),
    [anon_sym___asm] = ACTIONS(2226),
    [sym_number_literal] = ACTIONS(2228),
    [anon_sym_L_SQUOTE] = ACTIONS(2228),
    [anon_sym_u_SQUOTE] = ACTIONS(2228),
    [anon_sym_U_SQUOTE] = ACTIONS(2228),
    [anon_sym_u8_SQUOTE] = ACTIONS(2228),
    [anon_sym_SQUOTE] = ACTIONS(2228),
    [anon_sym_L_DQUOTE] = ACTIONS(2228),
    [anon_sym_u_DQUOTE] = ACTIONS(2228),
    [anon_sym_U_DQUOTE] = ACTIONS(2228),
    [anon_sym_u8_DQUOTE] = ACTIONS(2228),
    [anon_sym_DQUOTE] = ACTIONS(2228),
    [sym_true] = ACTIONS(2226),
    [sym_false] = ACTIONS(2226),
    [anon_sym_NULL] = ACTIONS(2226),
    [anon_sym_nullptr] = ACTIONS(2226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2226),
    [anon_sym_decltype] = ACTIONS(2226),
    [anon_sym_explicit] = ACTIONS(2226),
    [anon_sym_typename] = ACTIONS(2226),
    [anon_sym_template] = ACTIONS(2226),
    [anon_sym_operator] = ACTIONS(2226),
    [anon_sym_try] = ACTIONS(2226),
    [anon_sym_delete] = ACTIONS(2226),
    [anon_sym_throw] = ACTIONS(2226),
    [anon_sym_namespace] = ACTIONS(2226),
    [anon_sym_using] = ACTIONS(2226),
    [anon_sym_static_assert] = ACTIONS(2226),
    [anon_sym_concept] = ACTIONS(2226),
    [anon_sym_co_return] = ACTIONS(2226),
    [anon_sym_co_yield] = ACTIONS(2226),
    [anon_sym_R_DQUOTE] = ACTIONS(2228),
    [anon_sym_LR_DQUOTE] = ACTIONS(2228),
    [anon_sym_uR_DQUOTE] = ACTIONS(2228),
    [anon_sym_UR_DQUOTE] = ACTIONS(2228),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2228),
    [anon_sym_co_await] = ACTIONS(2226),
    [anon_sym_new] = ACTIONS(2226),
    [anon_sym_requires] = ACTIONS(2226),
    [sym_this] = ACTIONS(2226),
    [anon_sym___launch_bounds__] = ACTIONS(2226),
  },
  [STATE(563)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_include_token1] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym___cdecl] = ACTIONS(2585),
    [anon_sym___clrcall] = ACTIONS(2585),
    [anon_sym___stdcall] = ACTIONS(2585),
    [anon_sym___fastcall] = ACTIONS(2585),
    [anon_sym___thiscall] = ACTIONS(2585),
    [anon_sym___vectorcall] = ACTIONS(2585),
    [anon_sym_LBRACE] = ACTIONS(2587),
    [anon_sym_RBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_switch] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_default] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_do] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_return] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_goto] = ACTIONS(2585),
    [anon_sym___try] = ACTIONS(2585),
    [anon_sym___leave] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_compl] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2587),
    [anon_sym_sizeof] = ACTIONS(2585),
    [anon_sym___alignof__] = ACTIONS(2585),
    [anon_sym___alignof] = ACTIONS(2585),
    [anon_sym__alignof] = ACTIONS(2585),
    [anon_sym_alignof] = ACTIONS(2585),
    [anon_sym__Alignof] = ACTIONS(2585),
    [anon_sym_offsetof] = ACTIONS(2585),
    [anon_sym__Generic] = ACTIONS(2585),
    [anon_sym_asm] = ACTIONS(2585),
    [anon_sym___asm__] = ACTIONS(2585),
    [anon_sym___asm] = ACTIONS(2585),
    [sym_number_literal] = ACTIONS(2587),
    [anon_sym_L_SQUOTE] = ACTIONS(2587),
    [anon_sym_u_SQUOTE] = ACTIONS(2587),
    [anon_sym_U_SQUOTE] = ACTIONS(2587),
    [anon_sym_u8_SQUOTE] = ACTIONS(2587),
    [anon_sym_SQUOTE] = ACTIONS(2587),
    [anon_sym_L_DQUOTE] = ACTIONS(2587),
    [anon_sym_u_DQUOTE] = ACTIONS(2587),
    [anon_sym_U_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8_DQUOTE] = ACTIONS(2587),
    [anon_sym_DQUOTE] = ACTIONS(2587),
    [sym_true] = ACTIONS(2585),
    [sym_false] = ACTIONS(2585),
    [anon_sym_NULL] = ACTIONS(2585),
    [anon_sym_nullptr] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_try] = ACTIONS(2585),
    [anon_sym_delete] = ACTIONS(2585),
    [anon_sym_throw] = ACTIONS(2585),
    [anon_sym_namespace] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym_concept] = ACTIONS(2585),
    [anon_sym_co_return] = ACTIONS(2585),
    [anon_sym_co_yield] = ACTIONS(2585),
    [anon_sym_R_DQUOTE] = ACTIONS(2587),
    [anon_sym_LR_DQUOTE] = ACTIONS(2587),
    [anon_sym_uR_DQUOTE] = ACTIONS(2587),
    [anon_sym_UR_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2587),
    [anon_sym_co_await] = ACTIONS(2585),
    [anon_sym_new] = ACTIONS(2585),
    [anon_sym_requires] = ACTIONS(2585),
    [sym_this] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(564)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_include_token1] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym___cdecl] = ACTIONS(2585),
    [anon_sym___clrcall] = ACTIONS(2585),
    [anon_sym___stdcall] = ACTIONS(2585),
    [anon_sym___fastcall] = ACTIONS(2585),
    [anon_sym___thiscall] = ACTIONS(2585),
    [anon_sym___vectorcall] = ACTIONS(2585),
    [anon_sym_LBRACE] = ACTIONS(2587),
    [anon_sym_RBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_switch] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_default] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_do] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_return] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_goto] = ACTIONS(2585),
    [anon_sym___try] = ACTIONS(2585),
    [anon_sym___leave] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_compl] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2587),
    [anon_sym_sizeof] = ACTIONS(2585),
    [anon_sym___alignof__] = ACTIONS(2585),
    [anon_sym___alignof] = ACTIONS(2585),
    [anon_sym__alignof] = ACTIONS(2585),
    [anon_sym_alignof] = ACTIONS(2585),
    [anon_sym__Alignof] = ACTIONS(2585),
    [anon_sym_offsetof] = ACTIONS(2585),
    [anon_sym__Generic] = ACTIONS(2585),
    [anon_sym_asm] = ACTIONS(2585),
    [anon_sym___asm__] = ACTIONS(2585),
    [anon_sym___asm] = ACTIONS(2585),
    [sym_number_literal] = ACTIONS(2587),
    [anon_sym_L_SQUOTE] = ACTIONS(2587),
    [anon_sym_u_SQUOTE] = ACTIONS(2587),
    [anon_sym_U_SQUOTE] = ACTIONS(2587),
    [anon_sym_u8_SQUOTE] = ACTIONS(2587),
    [anon_sym_SQUOTE] = ACTIONS(2587),
    [anon_sym_L_DQUOTE] = ACTIONS(2587),
    [anon_sym_u_DQUOTE] = ACTIONS(2587),
    [anon_sym_U_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8_DQUOTE] = ACTIONS(2587),
    [anon_sym_DQUOTE] = ACTIONS(2587),
    [sym_true] = ACTIONS(2585),
    [sym_false] = ACTIONS(2585),
    [anon_sym_NULL] = ACTIONS(2585),
    [anon_sym_nullptr] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_try] = ACTIONS(2585),
    [anon_sym_delete] = ACTIONS(2585),
    [anon_sym_throw] = ACTIONS(2585),
    [anon_sym_namespace] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym_concept] = ACTIONS(2585),
    [anon_sym_co_return] = ACTIONS(2585),
    [anon_sym_co_yield] = ACTIONS(2585),
    [anon_sym_R_DQUOTE] = ACTIONS(2587),
    [anon_sym_LR_DQUOTE] = ACTIONS(2587),
    [anon_sym_uR_DQUOTE] = ACTIONS(2587),
    [anon_sym_UR_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2587),
    [anon_sym_co_await] = ACTIONS(2585),
    [anon_sym_new] = ACTIONS(2585),
    [anon_sym_requires] = ACTIONS(2585),
    [sym_this] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(565)] = {
    [sym_identifier] = ACTIONS(2537),
    [aux_sym_preproc_include_token1] = ACTIONS(2537),
    [aux_sym_preproc_def_token1] = ACTIONS(2537),
    [aux_sym_preproc_if_token1] = ACTIONS(2537),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2537),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2537),
    [sym_preproc_directive] = ACTIONS(2537),
    [anon_sym_LPAREN2] = ACTIONS(2539),
    [anon_sym_BANG] = ACTIONS(2539),
    [anon_sym_TILDE] = ACTIONS(2539),
    [anon_sym_DASH] = ACTIONS(2537),
    [anon_sym_PLUS] = ACTIONS(2537),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_AMP_AMP] = ACTIONS(2539),
    [anon_sym_AMP] = ACTIONS(2537),
    [anon_sym_SEMI] = ACTIONS(2539),
    [anon_sym___extension__] = ACTIONS(2537),
    [anon_sym_typedef] = ACTIONS(2537),
    [anon_sym___device__] = ACTIONS(2537),
    [anon_sym___host__] = ACTIONS(2537),
    [anon_sym___global__] = ACTIONS(2537),
    [anon_sym___forceinline__] = ACTIONS(2537),
    [anon_sym___noinline__] = ACTIONS(2537),
    [anon_sym_virtual] = ACTIONS(2537),
    [anon_sym_extern] = ACTIONS(2537),
    [anon_sym___attribute__] = ACTIONS(2537),
    [anon_sym___attribute] = ACTIONS(2537),
    [anon_sym_COLON_COLON] = ACTIONS(2539),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2539),
    [anon_sym___declspec] = ACTIONS(2537),
    [anon_sym___based] = ACTIONS(2537),
    [anon_sym___cdecl] = ACTIONS(2537),
    [anon_sym___clrcall] = ACTIONS(2537),
    [anon_sym___stdcall] = ACTIONS(2537),
    [anon_sym___fastcall] = ACTIONS(2537),
    [anon_sym___thiscall] = ACTIONS(2537),
    [anon_sym___vectorcall] = ACTIONS(2537),
    [anon_sym_LBRACE] = ACTIONS(2539),
    [anon_sym_RBRACE] = ACTIONS(2539),
    [anon_sym_signed] = ACTIONS(2537),
    [anon_sym_unsigned] = ACTIONS(2537),
    [anon_sym_long] = ACTIONS(2537),
    [anon_sym_short] = ACTIONS(2537),
    [anon_sym_LBRACK] = ACTIONS(2537),
    [anon_sym_static] = ACTIONS(2537),
    [anon_sym_register] = ACTIONS(2537),
    [anon_sym_inline] = ACTIONS(2537),
    [anon_sym___inline] = ACTIONS(2537),
    [anon_sym___inline__] = ACTIONS(2537),
    [anon_sym___forceinline] = ACTIONS(2537),
    [anon_sym_thread_local] = ACTIONS(2537),
    [anon_sym___thread] = ACTIONS(2537),
    [anon_sym_const] = ACTIONS(2537),
    [anon_sym_constexpr] = ACTIONS(2537),
    [anon_sym_volatile] = ACTIONS(2537),
    [anon_sym_restrict] = ACTIONS(2537),
    [anon_sym___restrict__] = ACTIONS(2537),
    [anon_sym__Atomic] = ACTIONS(2537),
    [anon_sym__Noreturn] = ACTIONS(2537),
    [anon_sym_noreturn] = ACTIONS(2537),
    [anon_sym__Nonnull] = ACTIONS(2537),
    [anon_sym_mutable] = ACTIONS(2537),
    [anon_sym_constinit] = ACTIONS(2537),
    [anon_sym_consteval] = ACTIONS(2537),
    [anon_sym___shared__] = ACTIONS(2537),
    [anon_sym___local__] = ACTIONS(2537),
    [anon_sym___constant__] = ACTIONS(2537),
    [anon_sym___managed__] = ACTIONS(2537),
    [anon_sym___grid_constant__] = ACTIONS(2537),
    [anon_sym_alignas] = ACTIONS(2537),
    [anon_sym__Alignas] = ACTIONS(2537),
    [sym_primitive_type] = ACTIONS(2537),
    [anon_sym_enum] = ACTIONS(2537),
    [anon_sym_class] = ACTIONS(2537),
    [anon_sym_struct] = ACTIONS(2537),
    [anon_sym_union] = ACTIONS(2537),
    [anon_sym_if] = ACTIONS(2537),
    [anon_sym_switch] = ACTIONS(2537),
    [anon_sym_case] = ACTIONS(2537),
    [anon_sym_default] = ACTIONS(2537),
    [anon_sym_while] = ACTIONS(2537),
    [anon_sym_do] = ACTIONS(2537),
    [anon_sym_for] = ACTIONS(2537),
    [anon_sym_return] = ACTIONS(2537),
    [anon_sym_break] = ACTIONS(2537),
    [anon_sym_continue] = ACTIONS(2537),
    [anon_sym_goto] = ACTIONS(2537),
    [anon_sym___try] = ACTIONS(2537),
    [anon_sym___leave] = ACTIONS(2537),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_compl] = ACTIONS(2537),
    [anon_sym_DASH_DASH] = ACTIONS(2539),
    [anon_sym_PLUS_PLUS] = ACTIONS(2539),
    [anon_sym_sizeof] = ACTIONS(2537),
    [anon_sym___alignof__] = ACTIONS(2537),
    [anon_sym___alignof] = ACTIONS(2537),
    [anon_sym__alignof] = ACTIONS(2537),
    [anon_sym_alignof] = ACTIONS(2537),
    [anon_sym__Alignof] = ACTIONS(2537),
    [anon_sym_offsetof] = ACTIONS(2537),
    [anon_sym__Generic] = ACTIONS(2537),
    [anon_sym_asm] = ACTIONS(2537),
    [anon_sym___asm__] = ACTIONS(2537),
    [anon_sym___asm] = ACTIONS(2537),
    [sym_number_literal] = ACTIONS(2539),
    [anon_sym_L_SQUOTE] = ACTIONS(2539),
    [anon_sym_u_SQUOTE] = ACTIONS(2539),
    [anon_sym_U_SQUOTE] = ACTIONS(2539),
    [anon_sym_u8_SQUOTE] = ACTIONS(2539),
    [anon_sym_SQUOTE] = ACTIONS(2539),
    [anon_sym_L_DQUOTE] = ACTIONS(2539),
    [anon_sym_u_DQUOTE] = ACTIONS(2539),
    [anon_sym_U_DQUOTE] = ACTIONS(2539),
    [anon_sym_u8_DQUOTE] = ACTIONS(2539),
    [anon_sym_DQUOTE] = ACTIONS(2539),
    [sym_true] = ACTIONS(2537),
    [sym_false] = ACTIONS(2537),
    [anon_sym_NULL] = ACTIONS(2537),
    [anon_sym_nullptr] = ACTIONS(2537),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2537),
    [anon_sym_decltype] = ACTIONS(2537),
    [anon_sym_explicit] = ACTIONS(2537),
    [anon_sym_typename] = ACTIONS(2537),
    [anon_sym_template] = ACTIONS(2537),
    [anon_sym_operator] = ACTIONS(2537),
    [anon_sym_try] = ACTIONS(2537),
    [anon_sym_delete] = ACTIONS(2537),
    [anon_sym_throw] = ACTIONS(2537),
    [anon_sym_namespace] = ACTIONS(2537),
    [anon_sym_using] = ACTIONS(2537),
    [anon_sym_static_assert] = ACTIONS(2537),
    [anon_sym_concept] = ACTIONS(2537),
    [anon_sym_co_return] = ACTIONS(2537),
    [anon_sym_co_yield] = ACTIONS(2537),
    [anon_sym_R_DQUOTE] = ACTIONS(2539),
    [anon_sym_LR_DQUOTE] = ACTIONS(2539),
    [anon_sym_uR_DQUOTE] = ACTIONS(2539),
    [anon_sym_UR_DQUOTE] = ACTIONS(2539),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2539),
    [anon_sym_co_await] = ACTIONS(2537),
    [anon_sym_new] = ACTIONS(2537),
    [anon_sym_requires] = ACTIONS(2537),
    [sym_this] = ACTIONS(2537),
    [anon_sym___launch_bounds__] = ACTIONS(2537),
  },
  [STATE(566)] = {
    [sym_identifier] = ACTIONS(2541),
    [aux_sym_preproc_include_token1] = ACTIONS(2541),
    [aux_sym_preproc_def_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2541),
    [sym_preproc_directive] = ACTIONS(2541),
    [anon_sym_LPAREN2] = ACTIONS(2543),
    [anon_sym_BANG] = ACTIONS(2543),
    [anon_sym_TILDE] = ACTIONS(2543),
    [anon_sym_DASH] = ACTIONS(2541),
    [anon_sym_PLUS] = ACTIONS(2541),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_AMP_AMP] = ACTIONS(2543),
    [anon_sym_AMP] = ACTIONS(2541),
    [anon_sym_SEMI] = ACTIONS(2543),
    [anon_sym___extension__] = ACTIONS(2541),
    [anon_sym_typedef] = ACTIONS(2541),
    [anon_sym___device__] = ACTIONS(2541),
    [anon_sym___host__] = ACTIONS(2541),
    [anon_sym___global__] = ACTIONS(2541),
    [anon_sym___forceinline__] = ACTIONS(2541),
    [anon_sym___noinline__] = ACTIONS(2541),
    [anon_sym_virtual] = ACTIONS(2541),
    [anon_sym_extern] = ACTIONS(2541),
    [anon_sym___attribute__] = ACTIONS(2541),
    [anon_sym___attribute] = ACTIONS(2541),
    [anon_sym_COLON_COLON] = ACTIONS(2543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2543),
    [anon_sym___declspec] = ACTIONS(2541),
    [anon_sym___based] = ACTIONS(2541),
    [anon_sym___cdecl] = ACTIONS(2541),
    [anon_sym___clrcall] = ACTIONS(2541),
    [anon_sym___stdcall] = ACTIONS(2541),
    [anon_sym___fastcall] = ACTIONS(2541),
    [anon_sym___thiscall] = ACTIONS(2541),
    [anon_sym___vectorcall] = ACTIONS(2541),
    [anon_sym_LBRACE] = ACTIONS(2543),
    [anon_sym_RBRACE] = ACTIONS(2543),
    [anon_sym_signed] = ACTIONS(2541),
    [anon_sym_unsigned] = ACTIONS(2541),
    [anon_sym_long] = ACTIONS(2541),
    [anon_sym_short] = ACTIONS(2541),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [anon_sym_static] = ACTIONS(2541),
    [anon_sym_register] = ACTIONS(2541),
    [anon_sym_inline] = ACTIONS(2541),
    [anon_sym___inline] = ACTIONS(2541),
    [anon_sym___inline__] = ACTIONS(2541),
    [anon_sym___forceinline] = ACTIONS(2541),
    [anon_sym_thread_local] = ACTIONS(2541),
    [anon_sym___thread] = ACTIONS(2541),
    [anon_sym_const] = ACTIONS(2541),
    [anon_sym_constexpr] = ACTIONS(2541),
    [anon_sym_volatile] = ACTIONS(2541),
    [anon_sym_restrict] = ACTIONS(2541),
    [anon_sym___restrict__] = ACTIONS(2541),
    [anon_sym__Atomic] = ACTIONS(2541),
    [anon_sym__Noreturn] = ACTIONS(2541),
    [anon_sym_noreturn] = ACTIONS(2541),
    [anon_sym__Nonnull] = ACTIONS(2541),
    [anon_sym_mutable] = ACTIONS(2541),
    [anon_sym_constinit] = ACTIONS(2541),
    [anon_sym_consteval] = ACTIONS(2541),
    [anon_sym___shared__] = ACTIONS(2541),
    [anon_sym___local__] = ACTIONS(2541),
    [anon_sym___constant__] = ACTIONS(2541),
    [anon_sym___managed__] = ACTIONS(2541),
    [anon_sym___grid_constant__] = ACTIONS(2541),
    [anon_sym_alignas] = ACTIONS(2541),
    [anon_sym__Alignas] = ACTIONS(2541),
    [sym_primitive_type] = ACTIONS(2541),
    [anon_sym_enum] = ACTIONS(2541),
    [anon_sym_class] = ACTIONS(2541),
    [anon_sym_struct] = ACTIONS(2541),
    [anon_sym_union] = ACTIONS(2541),
    [anon_sym_if] = ACTIONS(2541),
    [anon_sym_switch] = ACTIONS(2541),
    [anon_sym_case] = ACTIONS(2541),
    [anon_sym_default] = ACTIONS(2541),
    [anon_sym_while] = ACTIONS(2541),
    [anon_sym_do] = ACTIONS(2541),
    [anon_sym_for] = ACTIONS(2541),
    [anon_sym_return] = ACTIONS(2541),
    [anon_sym_break] = ACTIONS(2541),
    [anon_sym_continue] = ACTIONS(2541),
    [anon_sym_goto] = ACTIONS(2541),
    [anon_sym___try] = ACTIONS(2541),
    [anon_sym___leave] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2541),
    [anon_sym_compl] = ACTIONS(2541),
    [anon_sym_DASH_DASH] = ACTIONS(2543),
    [anon_sym_PLUS_PLUS] = ACTIONS(2543),
    [anon_sym_sizeof] = ACTIONS(2541),
    [anon_sym___alignof__] = ACTIONS(2541),
    [anon_sym___alignof] = ACTIONS(2541),
    [anon_sym__alignof] = ACTIONS(2541),
    [anon_sym_alignof] = ACTIONS(2541),
    [anon_sym__Alignof] = ACTIONS(2541),
    [anon_sym_offsetof] = ACTIONS(2541),
    [anon_sym__Generic] = ACTIONS(2541),
    [anon_sym_asm] = ACTIONS(2541),
    [anon_sym___asm__] = ACTIONS(2541),
    [anon_sym___asm] = ACTIONS(2541),
    [sym_number_literal] = ACTIONS(2543),
    [anon_sym_L_SQUOTE] = ACTIONS(2543),
    [anon_sym_u_SQUOTE] = ACTIONS(2543),
    [anon_sym_U_SQUOTE] = ACTIONS(2543),
    [anon_sym_u8_SQUOTE] = ACTIONS(2543),
    [anon_sym_SQUOTE] = ACTIONS(2543),
    [anon_sym_L_DQUOTE] = ACTIONS(2543),
    [anon_sym_u_DQUOTE] = ACTIONS(2543),
    [anon_sym_U_DQUOTE] = ACTIONS(2543),
    [anon_sym_u8_DQUOTE] = ACTIONS(2543),
    [anon_sym_DQUOTE] = ACTIONS(2543),
    [sym_true] = ACTIONS(2541),
    [sym_false] = ACTIONS(2541),
    [anon_sym_NULL] = ACTIONS(2541),
    [anon_sym_nullptr] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2541),
    [anon_sym_decltype] = ACTIONS(2541),
    [anon_sym_explicit] = ACTIONS(2541),
    [anon_sym_typename] = ACTIONS(2541),
    [anon_sym_template] = ACTIONS(2541),
    [anon_sym_operator] = ACTIONS(2541),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_delete] = ACTIONS(2541),
    [anon_sym_throw] = ACTIONS(2541),
    [anon_sym_namespace] = ACTIONS(2541),
    [anon_sym_using] = ACTIONS(2541),
    [anon_sym_static_assert] = ACTIONS(2541),
    [anon_sym_concept] = ACTIONS(2541),
    [anon_sym_co_return] = ACTIONS(2541),
    [anon_sym_co_yield] = ACTIONS(2541),
    [anon_sym_R_DQUOTE] = ACTIONS(2543),
    [anon_sym_LR_DQUOTE] = ACTIONS(2543),
    [anon_sym_uR_DQUOTE] = ACTIONS(2543),
    [anon_sym_UR_DQUOTE] = ACTIONS(2543),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2543),
    [anon_sym_co_await] = ACTIONS(2541),
    [anon_sym_new] = ACTIONS(2541),
    [anon_sym_requires] = ACTIONS(2541),
    [sym_this] = ACTIONS(2541),
    [anon_sym___launch_bounds__] = ACTIONS(2541),
  },
  [STATE(567)] = {
    [sym_identifier] = ACTIONS(2493),
    [aux_sym_preproc_include_token1] = ACTIONS(2493),
    [aux_sym_preproc_def_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2493),
    [sym_preproc_directive] = ACTIONS(2493),
    [anon_sym_LPAREN2] = ACTIONS(2495),
    [anon_sym_BANG] = ACTIONS(2495),
    [anon_sym_TILDE] = ACTIONS(2495),
    [anon_sym_DASH] = ACTIONS(2493),
    [anon_sym_PLUS] = ACTIONS(2493),
    [anon_sym_STAR] = ACTIONS(2495),
    [anon_sym_AMP_AMP] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(2493),
    [anon_sym_SEMI] = ACTIONS(2495),
    [anon_sym___extension__] = ACTIONS(2493),
    [anon_sym_typedef] = ACTIONS(2493),
    [anon_sym___device__] = ACTIONS(2493),
    [anon_sym___host__] = ACTIONS(2493),
    [anon_sym___global__] = ACTIONS(2493),
    [anon_sym___forceinline__] = ACTIONS(2493),
    [anon_sym___noinline__] = ACTIONS(2493),
    [anon_sym_virtual] = ACTIONS(2493),
    [anon_sym_extern] = ACTIONS(2493),
    [anon_sym___attribute__] = ACTIONS(2493),
    [anon_sym___attribute] = ACTIONS(2493),
    [anon_sym_COLON_COLON] = ACTIONS(2495),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2495),
    [anon_sym___declspec] = ACTIONS(2493),
    [anon_sym___based] = ACTIONS(2493),
    [anon_sym___cdecl] = ACTIONS(2493),
    [anon_sym___clrcall] = ACTIONS(2493),
    [anon_sym___stdcall] = ACTIONS(2493),
    [anon_sym___fastcall] = ACTIONS(2493),
    [anon_sym___thiscall] = ACTIONS(2493),
    [anon_sym___vectorcall] = ACTIONS(2493),
    [anon_sym_LBRACE] = ACTIONS(2495),
    [anon_sym_RBRACE] = ACTIONS(2495),
    [anon_sym_signed] = ACTIONS(2493),
    [anon_sym_unsigned] = ACTIONS(2493),
    [anon_sym_long] = ACTIONS(2493),
    [anon_sym_short] = ACTIONS(2493),
    [anon_sym_LBRACK] = ACTIONS(2493),
    [anon_sym_static] = ACTIONS(2493),
    [anon_sym_register] = ACTIONS(2493),
    [anon_sym_inline] = ACTIONS(2493),
    [anon_sym___inline] = ACTIONS(2493),
    [anon_sym___inline__] = ACTIONS(2493),
    [anon_sym___forceinline] = ACTIONS(2493),
    [anon_sym_thread_local] = ACTIONS(2493),
    [anon_sym___thread] = ACTIONS(2493),
    [anon_sym_const] = ACTIONS(2493),
    [anon_sym_constexpr] = ACTIONS(2493),
    [anon_sym_volatile] = ACTIONS(2493),
    [anon_sym_restrict] = ACTIONS(2493),
    [anon_sym___restrict__] = ACTIONS(2493),
    [anon_sym__Atomic] = ACTIONS(2493),
    [anon_sym__Noreturn] = ACTIONS(2493),
    [anon_sym_noreturn] = ACTIONS(2493),
    [anon_sym__Nonnull] = ACTIONS(2493),
    [anon_sym_mutable] = ACTIONS(2493),
    [anon_sym_constinit] = ACTIONS(2493),
    [anon_sym_consteval] = ACTIONS(2493),
    [anon_sym___shared__] = ACTIONS(2493),
    [anon_sym___local__] = ACTIONS(2493),
    [anon_sym___constant__] = ACTIONS(2493),
    [anon_sym___managed__] = ACTIONS(2493),
    [anon_sym___grid_constant__] = ACTIONS(2493),
    [anon_sym_alignas] = ACTIONS(2493),
    [anon_sym__Alignas] = ACTIONS(2493),
    [sym_primitive_type] = ACTIONS(2493),
    [anon_sym_enum] = ACTIONS(2493),
    [anon_sym_class] = ACTIONS(2493),
    [anon_sym_struct] = ACTIONS(2493),
    [anon_sym_union] = ACTIONS(2493),
    [anon_sym_if] = ACTIONS(2493),
    [anon_sym_switch] = ACTIONS(2493),
    [anon_sym_case] = ACTIONS(2493),
    [anon_sym_default] = ACTIONS(2493),
    [anon_sym_while] = ACTIONS(2493),
    [anon_sym_do] = ACTIONS(2493),
    [anon_sym_for] = ACTIONS(2493),
    [anon_sym_return] = ACTIONS(2493),
    [anon_sym_break] = ACTIONS(2493),
    [anon_sym_continue] = ACTIONS(2493),
    [anon_sym_goto] = ACTIONS(2493),
    [anon_sym___try] = ACTIONS(2493),
    [anon_sym___leave] = ACTIONS(2493),
    [anon_sym_not] = ACTIONS(2493),
    [anon_sym_compl] = ACTIONS(2493),
    [anon_sym_DASH_DASH] = ACTIONS(2495),
    [anon_sym_PLUS_PLUS] = ACTIONS(2495),
    [anon_sym_sizeof] = ACTIONS(2493),
    [anon_sym___alignof__] = ACTIONS(2493),
    [anon_sym___alignof] = ACTIONS(2493),
    [anon_sym__alignof] = ACTIONS(2493),
    [anon_sym_alignof] = ACTIONS(2493),
    [anon_sym__Alignof] = ACTIONS(2493),
    [anon_sym_offsetof] = ACTIONS(2493),
    [anon_sym__Generic] = ACTIONS(2493),
    [anon_sym_asm] = ACTIONS(2493),
    [anon_sym___asm__] = ACTIONS(2493),
    [anon_sym___asm] = ACTIONS(2493),
    [sym_number_literal] = ACTIONS(2495),
    [anon_sym_L_SQUOTE] = ACTIONS(2495),
    [anon_sym_u_SQUOTE] = ACTIONS(2495),
    [anon_sym_U_SQUOTE] = ACTIONS(2495),
    [anon_sym_u8_SQUOTE] = ACTIONS(2495),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_L_DQUOTE] = ACTIONS(2495),
    [anon_sym_u_DQUOTE] = ACTIONS(2495),
    [anon_sym_U_DQUOTE] = ACTIONS(2495),
    [anon_sym_u8_DQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2495),
    [sym_true] = ACTIONS(2493),
    [sym_false] = ACTIONS(2493),
    [anon_sym_NULL] = ACTIONS(2493),
    [anon_sym_nullptr] = ACTIONS(2493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2493),
    [anon_sym_decltype] = ACTIONS(2493),
    [anon_sym_explicit] = ACTIONS(2493),
    [anon_sym_typename] = ACTIONS(2493),
    [anon_sym_template] = ACTIONS(2493),
    [anon_sym_operator] = ACTIONS(2493),
    [anon_sym_try] = ACTIONS(2493),
    [anon_sym_delete] = ACTIONS(2493),
    [anon_sym_throw] = ACTIONS(2493),
    [anon_sym_namespace] = ACTIONS(2493),
    [anon_sym_using] = ACTIONS(2493),
    [anon_sym_static_assert] = ACTIONS(2493),
    [anon_sym_concept] = ACTIONS(2493),
    [anon_sym_co_return] = ACTIONS(2493),
    [anon_sym_co_yield] = ACTIONS(2493),
    [anon_sym_R_DQUOTE] = ACTIONS(2495),
    [anon_sym_LR_DQUOTE] = ACTIONS(2495),
    [anon_sym_uR_DQUOTE] = ACTIONS(2495),
    [anon_sym_UR_DQUOTE] = ACTIONS(2495),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2495),
    [anon_sym_co_await] = ACTIONS(2493),
    [anon_sym_new] = ACTIONS(2493),
    [anon_sym_requires] = ACTIONS(2493),
    [sym_this] = ACTIONS(2493),
    [anon_sym___launch_bounds__] = ACTIONS(2493),
  },
  [STATE(568)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_RBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [anon_sym___asm] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(569)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_RBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [anon_sym___asm] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(570)] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_include_token1] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_BANG] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_DASH] = ACTIONS(2328),
    [anon_sym_PLUS] = ACTIONS(2328),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym___device__] = ACTIONS(2328),
    [anon_sym___host__] = ACTIONS(2328),
    [anon_sym___global__] = ACTIONS(2328),
    [anon_sym___forceinline__] = ACTIONS(2328),
    [anon_sym___noinline__] = ACTIONS(2328),
    [anon_sym_virtual] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym___attribute] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym___cdecl] = ACTIONS(2328),
    [anon_sym___clrcall] = ACTIONS(2328),
    [anon_sym___stdcall] = ACTIONS(2328),
    [anon_sym___fastcall] = ACTIONS(2328),
    [anon_sym___thiscall] = ACTIONS(2328),
    [anon_sym___vectorcall] = ACTIONS(2328),
    [anon_sym_LBRACE] = ACTIONS(2330),
    [anon_sym_RBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym__Nonnull] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym___shared__] = ACTIONS(2328),
    [anon_sym___local__] = ACTIONS(2328),
    [anon_sym___constant__] = ACTIONS(2328),
    [anon_sym___managed__] = ACTIONS(2328),
    [anon_sym___grid_constant__] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2328),
    [anon_sym_switch] = ACTIONS(2328),
    [anon_sym_case] = ACTIONS(2328),
    [anon_sym_default] = ACTIONS(2328),
    [anon_sym_while] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2328),
    [anon_sym_for] = ACTIONS(2328),
    [anon_sym_return] = ACTIONS(2328),
    [anon_sym_break] = ACTIONS(2328),
    [anon_sym_continue] = ACTIONS(2328),
    [anon_sym_goto] = ACTIONS(2328),
    [anon_sym___try] = ACTIONS(2328),
    [anon_sym___leave] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2328),
    [anon_sym_compl] = ACTIONS(2328),
    [anon_sym_DASH_DASH] = ACTIONS(2330),
    [anon_sym_PLUS_PLUS] = ACTIONS(2330),
    [anon_sym_sizeof] = ACTIONS(2328),
    [anon_sym___alignof__] = ACTIONS(2328),
    [anon_sym___alignof] = ACTIONS(2328),
    [anon_sym__alignof] = ACTIONS(2328),
    [anon_sym_alignof] = ACTIONS(2328),
    [anon_sym__Alignof] = ACTIONS(2328),
    [anon_sym_offsetof] = ACTIONS(2328),
    [anon_sym__Generic] = ACTIONS(2328),
    [anon_sym_asm] = ACTIONS(2328),
    [anon_sym___asm__] = ACTIONS(2328),
    [anon_sym___asm] = ACTIONS(2328),
    [sym_number_literal] = ACTIONS(2330),
    [anon_sym_L_SQUOTE] = ACTIONS(2330),
    [anon_sym_u_SQUOTE] = ACTIONS(2330),
    [anon_sym_U_SQUOTE] = ACTIONS(2330),
    [anon_sym_u8_SQUOTE] = ACTIONS(2330),
    [anon_sym_SQUOTE] = ACTIONS(2330),
    [anon_sym_L_DQUOTE] = ACTIONS(2330),
    [anon_sym_u_DQUOTE] = ACTIONS(2330),
    [anon_sym_U_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8_DQUOTE] = ACTIONS(2330),
    [anon_sym_DQUOTE] = ACTIONS(2330),
    [sym_true] = ACTIONS(2328),
    [sym_false] = ACTIONS(2328),
    [anon_sym_NULL] = ACTIONS(2328),
    [anon_sym_nullptr] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_delete] = ACTIONS(2328),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_namespace] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_concept] = ACTIONS(2328),
    [anon_sym_co_return] = ACTIONS(2328),
    [anon_sym_co_yield] = ACTIONS(2328),
    [anon_sym_R_DQUOTE] = ACTIONS(2330),
    [anon_sym_LR_DQUOTE] = ACTIONS(2330),
    [anon_sym_uR_DQUOTE] = ACTIONS(2330),
    [anon_sym_UR_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2330),
    [anon_sym_co_await] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(2328),
    [anon_sym_requires] = ACTIONS(2328),
    [sym_this] = ACTIONS(2328),
    [anon_sym___launch_bounds__] = ACTIONS(2328),
  },
  [STATE(571)] = {
    [sym_identifier] = ACTIONS(2230),
    [aux_sym_preproc_include_token1] = ACTIONS(2230),
    [aux_sym_preproc_def_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2230),
    [sym_preproc_directive] = ACTIONS(2230),
    [anon_sym_LPAREN2] = ACTIONS(2232),
    [anon_sym_BANG] = ACTIONS(2232),
    [anon_sym_TILDE] = ACTIONS(2232),
    [anon_sym_DASH] = ACTIONS(2230),
    [anon_sym_PLUS] = ACTIONS(2230),
    [anon_sym_STAR] = ACTIONS(2232),
    [anon_sym_AMP_AMP] = ACTIONS(2232),
    [anon_sym_AMP] = ACTIONS(2230),
    [anon_sym_SEMI] = ACTIONS(2232),
    [anon_sym___extension__] = ACTIONS(2230),
    [anon_sym_typedef] = ACTIONS(2230),
    [anon_sym___device__] = ACTIONS(2230),
    [anon_sym___host__] = ACTIONS(2230),
    [anon_sym___global__] = ACTIONS(2230),
    [anon_sym___forceinline__] = ACTIONS(2230),
    [anon_sym___noinline__] = ACTIONS(2230),
    [anon_sym_virtual] = ACTIONS(2230),
    [anon_sym_extern] = ACTIONS(2230),
    [anon_sym___attribute__] = ACTIONS(2230),
    [anon_sym___attribute] = ACTIONS(2230),
    [anon_sym_COLON_COLON] = ACTIONS(2232),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2232),
    [anon_sym___declspec] = ACTIONS(2230),
    [anon_sym___based] = ACTIONS(2230),
    [anon_sym___cdecl] = ACTIONS(2230),
    [anon_sym___clrcall] = ACTIONS(2230),
    [anon_sym___stdcall] = ACTIONS(2230),
    [anon_sym___fastcall] = ACTIONS(2230),
    [anon_sym___thiscall] = ACTIONS(2230),
    [anon_sym___vectorcall] = ACTIONS(2230),
    [anon_sym_LBRACE] = ACTIONS(2232),
    [anon_sym_RBRACE] = ACTIONS(2232),
    [anon_sym_signed] = ACTIONS(2230),
    [anon_sym_unsigned] = ACTIONS(2230),
    [anon_sym_long] = ACTIONS(2230),
    [anon_sym_short] = ACTIONS(2230),
    [anon_sym_LBRACK] = ACTIONS(2230),
    [anon_sym_static] = ACTIONS(2230),
    [anon_sym_register] = ACTIONS(2230),
    [anon_sym_inline] = ACTIONS(2230),
    [anon_sym___inline] = ACTIONS(2230),
    [anon_sym___inline__] = ACTIONS(2230),
    [anon_sym___forceinline] = ACTIONS(2230),
    [anon_sym_thread_local] = ACTIONS(2230),
    [anon_sym___thread] = ACTIONS(2230),
    [anon_sym_const] = ACTIONS(2230),
    [anon_sym_constexpr] = ACTIONS(2230),
    [anon_sym_volatile] = ACTIONS(2230),
    [anon_sym_restrict] = ACTIONS(2230),
    [anon_sym___restrict__] = ACTIONS(2230),
    [anon_sym__Atomic] = ACTIONS(2230),
    [anon_sym__Noreturn] = ACTIONS(2230),
    [anon_sym_noreturn] = ACTIONS(2230),
    [anon_sym__Nonnull] = ACTIONS(2230),
    [anon_sym_mutable] = ACTIONS(2230),
    [anon_sym_constinit] = ACTIONS(2230),
    [anon_sym_consteval] = ACTIONS(2230),
    [anon_sym___shared__] = ACTIONS(2230),
    [anon_sym___local__] = ACTIONS(2230),
    [anon_sym___constant__] = ACTIONS(2230),
    [anon_sym___managed__] = ACTIONS(2230),
    [anon_sym___grid_constant__] = ACTIONS(2230),
    [anon_sym_alignas] = ACTIONS(2230),
    [anon_sym__Alignas] = ACTIONS(2230),
    [sym_primitive_type] = ACTIONS(2230),
    [anon_sym_enum] = ACTIONS(2230),
    [anon_sym_class] = ACTIONS(2230),
    [anon_sym_struct] = ACTIONS(2230),
    [anon_sym_union] = ACTIONS(2230),
    [anon_sym_if] = ACTIONS(2230),
    [anon_sym_switch] = ACTIONS(2230),
    [anon_sym_case] = ACTIONS(2230),
    [anon_sym_default] = ACTIONS(2230),
    [anon_sym_while] = ACTIONS(2230),
    [anon_sym_do] = ACTIONS(2230),
    [anon_sym_for] = ACTIONS(2230),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_break] = ACTIONS(2230),
    [anon_sym_continue] = ACTIONS(2230),
    [anon_sym_goto] = ACTIONS(2230),
    [anon_sym___try] = ACTIONS(2230),
    [anon_sym___leave] = ACTIONS(2230),
    [anon_sym_not] = ACTIONS(2230),
    [anon_sym_compl] = ACTIONS(2230),
    [anon_sym_DASH_DASH] = ACTIONS(2232),
    [anon_sym_PLUS_PLUS] = ACTIONS(2232),
    [anon_sym_sizeof] = ACTIONS(2230),
    [anon_sym___alignof__] = ACTIONS(2230),
    [anon_sym___alignof] = ACTIONS(2230),
    [anon_sym__alignof] = ACTIONS(2230),
    [anon_sym_alignof] = ACTIONS(2230),
    [anon_sym__Alignof] = ACTIONS(2230),
    [anon_sym_offsetof] = ACTIONS(2230),
    [anon_sym__Generic] = ACTIONS(2230),
    [anon_sym_asm] = ACTIONS(2230),
    [anon_sym___asm__] = ACTIONS(2230),
    [anon_sym___asm] = ACTIONS(2230),
    [sym_number_literal] = ACTIONS(2232),
    [anon_sym_L_SQUOTE] = ACTIONS(2232),
    [anon_sym_u_SQUOTE] = ACTIONS(2232),
    [anon_sym_U_SQUOTE] = ACTIONS(2232),
    [anon_sym_u8_SQUOTE] = ACTIONS(2232),
    [anon_sym_SQUOTE] = ACTIONS(2232),
    [anon_sym_L_DQUOTE] = ACTIONS(2232),
    [anon_sym_u_DQUOTE] = ACTIONS(2232),
    [anon_sym_U_DQUOTE] = ACTIONS(2232),
    [anon_sym_u8_DQUOTE] = ACTIONS(2232),
    [anon_sym_DQUOTE] = ACTIONS(2232),
    [sym_true] = ACTIONS(2230),
    [sym_false] = ACTIONS(2230),
    [anon_sym_NULL] = ACTIONS(2230),
    [anon_sym_nullptr] = ACTIONS(2230),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2230),
    [anon_sym_decltype] = ACTIONS(2230),
    [anon_sym_explicit] = ACTIONS(2230),
    [anon_sym_typename] = ACTIONS(2230),
    [anon_sym_template] = ACTIONS(2230),
    [anon_sym_operator] = ACTIONS(2230),
    [anon_sym_try] = ACTIONS(2230),
    [anon_sym_delete] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2230),
    [anon_sym_namespace] = ACTIONS(2230),
    [anon_sym_using] = ACTIONS(2230),
    [anon_sym_static_assert] = ACTIONS(2230),
    [anon_sym_concept] = ACTIONS(2230),
    [anon_sym_co_return] = ACTIONS(2230),
    [anon_sym_co_yield] = ACTIONS(2230),
    [anon_sym_R_DQUOTE] = ACTIONS(2232),
    [anon_sym_LR_DQUOTE] = ACTIONS(2232),
    [anon_sym_uR_DQUOTE] = ACTIONS(2232),
    [anon_sym_UR_DQUOTE] = ACTIONS(2232),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2232),
    [anon_sym_co_await] = ACTIONS(2230),
    [anon_sym_new] = ACTIONS(2230),
    [anon_sym_requires] = ACTIONS(2230),
    [sym_this] = ACTIONS(2230),
    [anon_sym___launch_bounds__] = ACTIONS(2230),
  },
  [STATE(572)] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_include_token1] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_BANG] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym___device__] = ACTIONS(2316),
    [anon_sym___host__] = ACTIONS(2316),
    [anon_sym___global__] = ACTIONS(2316),
    [anon_sym___forceinline__] = ACTIONS(2316),
    [anon_sym___noinline__] = ACTIONS(2316),
    [anon_sym_virtual] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym___attribute] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym___cdecl] = ACTIONS(2316),
    [anon_sym___clrcall] = ACTIONS(2316),
    [anon_sym___stdcall] = ACTIONS(2316),
    [anon_sym___fastcall] = ACTIONS(2316),
    [anon_sym___thiscall] = ACTIONS(2316),
    [anon_sym___vectorcall] = ACTIONS(2316),
    [anon_sym_LBRACE] = ACTIONS(2318),
    [anon_sym_RBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym__Nonnull] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym___shared__] = ACTIONS(2316),
    [anon_sym___local__] = ACTIONS(2316),
    [anon_sym___constant__] = ACTIONS(2316),
    [anon_sym___managed__] = ACTIONS(2316),
    [anon_sym___grid_constant__] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_switch] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_default] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_return] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_goto] = ACTIONS(2316),
    [anon_sym___try] = ACTIONS(2316),
    [anon_sym___leave] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_compl] = ACTIONS(2316),
    [anon_sym_DASH_DASH] = ACTIONS(2318),
    [anon_sym_PLUS_PLUS] = ACTIONS(2318),
    [anon_sym_sizeof] = ACTIONS(2316),
    [anon_sym___alignof__] = ACTIONS(2316),
    [anon_sym___alignof] = ACTIONS(2316),
    [anon_sym__alignof] = ACTIONS(2316),
    [anon_sym_alignof] = ACTIONS(2316),
    [anon_sym__Alignof] = ACTIONS(2316),
    [anon_sym_offsetof] = ACTIONS(2316),
    [anon_sym__Generic] = ACTIONS(2316),
    [anon_sym_asm] = ACTIONS(2316),
    [anon_sym___asm__] = ACTIONS(2316),
    [anon_sym___asm] = ACTIONS(2316),
    [sym_number_literal] = ACTIONS(2318),
    [anon_sym_L_SQUOTE] = ACTIONS(2318),
    [anon_sym_u_SQUOTE] = ACTIONS(2318),
    [anon_sym_U_SQUOTE] = ACTIONS(2318),
    [anon_sym_u8_SQUOTE] = ACTIONS(2318),
    [anon_sym_SQUOTE] = ACTIONS(2318),
    [anon_sym_L_DQUOTE] = ACTIONS(2318),
    [anon_sym_u_DQUOTE] = ACTIONS(2318),
    [anon_sym_U_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8_DQUOTE] = ACTIONS(2318),
    [anon_sym_DQUOTE] = ACTIONS(2318),
    [sym_true] = ACTIONS(2316),
    [sym_false] = ACTIONS(2316),
    [anon_sym_NULL] = ACTIONS(2316),
    [anon_sym_nullptr] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_try] = ACTIONS(2316),
    [anon_sym_delete] = ACTIONS(2316),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_namespace] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_concept] = ACTIONS(2316),
    [anon_sym_co_return] = ACTIONS(2316),
    [anon_sym_co_yield] = ACTIONS(2316),
    [anon_sym_R_DQUOTE] = ACTIONS(2318),
    [anon_sym_LR_DQUOTE] = ACTIONS(2318),
    [anon_sym_uR_DQUOTE] = ACTIONS(2318),
    [anon_sym_UR_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2318),
    [anon_sym_co_await] = ACTIONS(2316),
    [anon_sym_new] = ACTIONS(2316),
    [anon_sym_requires] = ACTIONS(2316),
    [sym_this] = ACTIONS(2316),
    [anon_sym___launch_bounds__] = ACTIONS(2316),
  },
  [STATE(573)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4973),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7560),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7862),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2942),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(574)] = {
    [sym_identifier] = ACTIONS(2431),
    [aux_sym_preproc_include_token1] = ACTIONS(2431),
    [aux_sym_preproc_def_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2431),
    [sym_preproc_directive] = ACTIONS(2431),
    [anon_sym_LPAREN2] = ACTIONS(2433),
    [anon_sym_BANG] = ACTIONS(2433),
    [anon_sym_TILDE] = ACTIONS(2433),
    [anon_sym_DASH] = ACTIONS(2431),
    [anon_sym_PLUS] = ACTIONS(2431),
    [anon_sym_STAR] = ACTIONS(2433),
    [anon_sym_AMP_AMP] = ACTIONS(2433),
    [anon_sym_AMP] = ACTIONS(2431),
    [anon_sym_SEMI] = ACTIONS(2433),
    [anon_sym___extension__] = ACTIONS(2431),
    [anon_sym_typedef] = ACTIONS(2431),
    [anon_sym___device__] = ACTIONS(2431),
    [anon_sym___host__] = ACTIONS(2431),
    [anon_sym___global__] = ACTIONS(2431),
    [anon_sym___forceinline__] = ACTIONS(2431),
    [anon_sym___noinline__] = ACTIONS(2431),
    [anon_sym_virtual] = ACTIONS(2431),
    [anon_sym_extern] = ACTIONS(2431),
    [anon_sym___attribute__] = ACTIONS(2431),
    [anon_sym___attribute] = ACTIONS(2431),
    [anon_sym_COLON_COLON] = ACTIONS(2433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2433),
    [anon_sym___declspec] = ACTIONS(2431),
    [anon_sym___based] = ACTIONS(2431),
    [anon_sym___cdecl] = ACTIONS(2431),
    [anon_sym___clrcall] = ACTIONS(2431),
    [anon_sym___stdcall] = ACTIONS(2431),
    [anon_sym___fastcall] = ACTIONS(2431),
    [anon_sym___thiscall] = ACTIONS(2431),
    [anon_sym___vectorcall] = ACTIONS(2431),
    [anon_sym_LBRACE] = ACTIONS(2433),
    [anon_sym_RBRACE] = ACTIONS(2433),
    [anon_sym_signed] = ACTIONS(2431),
    [anon_sym_unsigned] = ACTIONS(2431),
    [anon_sym_long] = ACTIONS(2431),
    [anon_sym_short] = ACTIONS(2431),
    [anon_sym_LBRACK] = ACTIONS(2431),
    [anon_sym_static] = ACTIONS(2431),
    [anon_sym_register] = ACTIONS(2431),
    [anon_sym_inline] = ACTIONS(2431),
    [anon_sym___inline] = ACTIONS(2431),
    [anon_sym___inline__] = ACTIONS(2431),
    [anon_sym___forceinline] = ACTIONS(2431),
    [anon_sym_thread_local] = ACTIONS(2431),
    [anon_sym___thread] = ACTIONS(2431),
    [anon_sym_const] = ACTIONS(2431),
    [anon_sym_constexpr] = ACTIONS(2431),
    [anon_sym_volatile] = ACTIONS(2431),
    [anon_sym_restrict] = ACTIONS(2431),
    [anon_sym___restrict__] = ACTIONS(2431),
    [anon_sym__Atomic] = ACTIONS(2431),
    [anon_sym__Noreturn] = ACTIONS(2431),
    [anon_sym_noreturn] = ACTIONS(2431),
    [anon_sym__Nonnull] = ACTIONS(2431),
    [anon_sym_mutable] = ACTIONS(2431),
    [anon_sym_constinit] = ACTIONS(2431),
    [anon_sym_consteval] = ACTIONS(2431),
    [anon_sym___shared__] = ACTIONS(2431),
    [anon_sym___local__] = ACTIONS(2431),
    [anon_sym___constant__] = ACTIONS(2431),
    [anon_sym___managed__] = ACTIONS(2431),
    [anon_sym___grid_constant__] = ACTIONS(2431),
    [anon_sym_alignas] = ACTIONS(2431),
    [anon_sym__Alignas] = ACTIONS(2431),
    [sym_primitive_type] = ACTIONS(2431),
    [anon_sym_enum] = ACTIONS(2431),
    [anon_sym_class] = ACTIONS(2431),
    [anon_sym_struct] = ACTIONS(2431),
    [anon_sym_union] = ACTIONS(2431),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_switch] = ACTIONS(2431),
    [anon_sym_case] = ACTIONS(2431),
    [anon_sym_default] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(2431),
    [anon_sym_do] = ACTIONS(2431),
    [anon_sym_for] = ACTIONS(2431),
    [anon_sym_return] = ACTIONS(2431),
    [anon_sym_break] = ACTIONS(2431),
    [anon_sym_continue] = ACTIONS(2431),
    [anon_sym_goto] = ACTIONS(2431),
    [anon_sym___try] = ACTIONS(2431),
    [anon_sym___leave] = ACTIONS(2431),
    [anon_sym_not] = ACTIONS(2431),
    [anon_sym_compl] = ACTIONS(2431),
    [anon_sym_DASH_DASH] = ACTIONS(2433),
    [anon_sym_PLUS_PLUS] = ACTIONS(2433),
    [anon_sym_sizeof] = ACTIONS(2431),
    [anon_sym___alignof__] = ACTIONS(2431),
    [anon_sym___alignof] = ACTIONS(2431),
    [anon_sym__alignof] = ACTIONS(2431),
    [anon_sym_alignof] = ACTIONS(2431),
    [anon_sym__Alignof] = ACTIONS(2431),
    [anon_sym_offsetof] = ACTIONS(2431),
    [anon_sym__Generic] = ACTIONS(2431),
    [anon_sym_asm] = ACTIONS(2431),
    [anon_sym___asm__] = ACTIONS(2431),
    [anon_sym___asm] = ACTIONS(2431),
    [sym_number_literal] = ACTIONS(2433),
    [anon_sym_L_SQUOTE] = ACTIONS(2433),
    [anon_sym_u_SQUOTE] = ACTIONS(2433),
    [anon_sym_U_SQUOTE] = ACTIONS(2433),
    [anon_sym_u8_SQUOTE] = ACTIONS(2433),
    [anon_sym_SQUOTE] = ACTIONS(2433),
    [anon_sym_L_DQUOTE] = ACTIONS(2433),
    [anon_sym_u_DQUOTE] = ACTIONS(2433),
    [anon_sym_U_DQUOTE] = ACTIONS(2433),
    [anon_sym_u8_DQUOTE] = ACTIONS(2433),
    [anon_sym_DQUOTE] = ACTIONS(2433),
    [sym_true] = ACTIONS(2431),
    [sym_false] = ACTIONS(2431),
    [anon_sym_NULL] = ACTIONS(2431),
    [anon_sym_nullptr] = ACTIONS(2431),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2431),
    [anon_sym_decltype] = ACTIONS(2431),
    [anon_sym_explicit] = ACTIONS(2431),
    [anon_sym_typename] = ACTIONS(2431),
    [anon_sym_template] = ACTIONS(2431),
    [anon_sym_operator] = ACTIONS(2431),
    [anon_sym_try] = ACTIONS(2431),
    [anon_sym_delete] = ACTIONS(2431),
    [anon_sym_throw] = ACTIONS(2431),
    [anon_sym_namespace] = ACTIONS(2431),
    [anon_sym_using] = ACTIONS(2431),
    [anon_sym_static_assert] = ACTIONS(2431),
    [anon_sym_concept] = ACTIONS(2431),
    [anon_sym_co_return] = ACTIONS(2431),
    [anon_sym_co_yield] = ACTIONS(2431),
    [anon_sym_R_DQUOTE] = ACTIONS(2433),
    [anon_sym_LR_DQUOTE] = ACTIONS(2433),
    [anon_sym_uR_DQUOTE] = ACTIONS(2433),
    [anon_sym_UR_DQUOTE] = ACTIONS(2433),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2433),
    [anon_sym_co_await] = ACTIONS(2431),
    [anon_sym_new] = ACTIONS(2431),
    [anon_sym_requires] = ACTIONS(2431),
    [sym_this] = ACTIONS(2431),
    [anon_sym___launch_bounds__] = ACTIONS(2431),
  },
  [STATE(575)] = {
    [sym_identifier] = ACTIONS(2435),
    [aux_sym_preproc_include_token1] = ACTIONS(2435),
    [aux_sym_preproc_def_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2435),
    [sym_preproc_directive] = ACTIONS(2435),
    [anon_sym_LPAREN2] = ACTIONS(2437),
    [anon_sym_BANG] = ACTIONS(2437),
    [anon_sym_TILDE] = ACTIONS(2437),
    [anon_sym_DASH] = ACTIONS(2435),
    [anon_sym_PLUS] = ACTIONS(2435),
    [anon_sym_STAR] = ACTIONS(2437),
    [anon_sym_AMP_AMP] = ACTIONS(2437),
    [anon_sym_AMP] = ACTIONS(2435),
    [anon_sym_SEMI] = ACTIONS(2437),
    [anon_sym___extension__] = ACTIONS(2435),
    [anon_sym_typedef] = ACTIONS(2435),
    [anon_sym___device__] = ACTIONS(2435),
    [anon_sym___host__] = ACTIONS(2435),
    [anon_sym___global__] = ACTIONS(2435),
    [anon_sym___forceinline__] = ACTIONS(2435),
    [anon_sym___noinline__] = ACTIONS(2435),
    [anon_sym_virtual] = ACTIONS(2435),
    [anon_sym_extern] = ACTIONS(2435),
    [anon_sym___attribute__] = ACTIONS(2435),
    [anon_sym___attribute] = ACTIONS(2435),
    [anon_sym_COLON_COLON] = ACTIONS(2437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2437),
    [anon_sym___declspec] = ACTIONS(2435),
    [anon_sym___based] = ACTIONS(2435),
    [anon_sym___cdecl] = ACTIONS(2435),
    [anon_sym___clrcall] = ACTIONS(2435),
    [anon_sym___stdcall] = ACTIONS(2435),
    [anon_sym___fastcall] = ACTIONS(2435),
    [anon_sym___thiscall] = ACTIONS(2435),
    [anon_sym___vectorcall] = ACTIONS(2435),
    [anon_sym_LBRACE] = ACTIONS(2437),
    [anon_sym_RBRACE] = ACTIONS(2437),
    [anon_sym_signed] = ACTIONS(2435),
    [anon_sym_unsigned] = ACTIONS(2435),
    [anon_sym_long] = ACTIONS(2435),
    [anon_sym_short] = ACTIONS(2435),
    [anon_sym_LBRACK] = ACTIONS(2435),
    [anon_sym_static] = ACTIONS(2435),
    [anon_sym_register] = ACTIONS(2435),
    [anon_sym_inline] = ACTIONS(2435),
    [anon_sym___inline] = ACTIONS(2435),
    [anon_sym___inline__] = ACTIONS(2435),
    [anon_sym___forceinline] = ACTIONS(2435),
    [anon_sym_thread_local] = ACTIONS(2435),
    [anon_sym___thread] = ACTIONS(2435),
    [anon_sym_const] = ACTIONS(2435),
    [anon_sym_constexpr] = ACTIONS(2435),
    [anon_sym_volatile] = ACTIONS(2435),
    [anon_sym_restrict] = ACTIONS(2435),
    [anon_sym___restrict__] = ACTIONS(2435),
    [anon_sym__Atomic] = ACTIONS(2435),
    [anon_sym__Noreturn] = ACTIONS(2435),
    [anon_sym_noreturn] = ACTIONS(2435),
    [anon_sym__Nonnull] = ACTIONS(2435),
    [anon_sym_mutable] = ACTIONS(2435),
    [anon_sym_constinit] = ACTIONS(2435),
    [anon_sym_consteval] = ACTIONS(2435),
    [anon_sym___shared__] = ACTIONS(2435),
    [anon_sym___local__] = ACTIONS(2435),
    [anon_sym___constant__] = ACTIONS(2435),
    [anon_sym___managed__] = ACTIONS(2435),
    [anon_sym___grid_constant__] = ACTIONS(2435),
    [anon_sym_alignas] = ACTIONS(2435),
    [anon_sym__Alignas] = ACTIONS(2435),
    [sym_primitive_type] = ACTIONS(2435),
    [anon_sym_enum] = ACTIONS(2435),
    [anon_sym_class] = ACTIONS(2435),
    [anon_sym_struct] = ACTIONS(2435),
    [anon_sym_union] = ACTIONS(2435),
    [anon_sym_if] = ACTIONS(2435),
    [anon_sym_switch] = ACTIONS(2435),
    [anon_sym_case] = ACTIONS(2435),
    [anon_sym_default] = ACTIONS(2435),
    [anon_sym_while] = ACTIONS(2435),
    [anon_sym_do] = ACTIONS(2435),
    [anon_sym_for] = ACTIONS(2435),
    [anon_sym_return] = ACTIONS(2435),
    [anon_sym_break] = ACTIONS(2435),
    [anon_sym_continue] = ACTIONS(2435),
    [anon_sym_goto] = ACTIONS(2435),
    [anon_sym___try] = ACTIONS(2435),
    [anon_sym___leave] = ACTIONS(2435),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_compl] = ACTIONS(2435),
    [anon_sym_DASH_DASH] = ACTIONS(2437),
    [anon_sym_PLUS_PLUS] = ACTIONS(2437),
    [anon_sym_sizeof] = ACTIONS(2435),
    [anon_sym___alignof__] = ACTIONS(2435),
    [anon_sym___alignof] = ACTIONS(2435),
    [anon_sym__alignof] = ACTIONS(2435),
    [anon_sym_alignof] = ACTIONS(2435),
    [anon_sym__Alignof] = ACTIONS(2435),
    [anon_sym_offsetof] = ACTIONS(2435),
    [anon_sym__Generic] = ACTIONS(2435),
    [anon_sym_asm] = ACTIONS(2435),
    [anon_sym___asm__] = ACTIONS(2435),
    [anon_sym___asm] = ACTIONS(2435),
    [sym_number_literal] = ACTIONS(2437),
    [anon_sym_L_SQUOTE] = ACTIONS(2437),
    [anon_sym_u_SQUOTE] = ACTIONS(2437),
    [anon_sym_U_SQUOTE] = ACTIONS(2437),
    [anon_sym_u8_SQUOTE] = ACTIONS(2437),
    [anon_sym_SQUOTE] = ACTIONS(2437),
    [anon_sym_L_DQUOTE] = ACTIONS(2437),
    [anon_sym_u_DQUOTE] = ACTIONS(2437),
    [anon_sym_U_DQUOTE] = ACTIONS(2437),
    [anon_sym_u8_DQUOTE] = ACTIONS(2437),
    [anon_sym_DQUOTE] = ACTIONS(2437),
    [sym_true] = ACTIONS(2435),
    [sym_false] = ACTIONS(2435),
    [anon_sym_NULL] = ACTIONS(2435),
    [anon_sym_nullptr] = ACTIONS(2435),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2435),
    [anon_sym_decltype] = ACTIONS(2435),
    [anon_sym_explicit] = ACTIONS(2435),
    [anon_sym_typename] = ACTIONS(2435),
    [anon_sym_template] = ACTIONS(2435),
    [anon_sym_operator] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2435),
    [anon_sym_delete] = ACTIONS(2435),
    [anon_sym_throw] = ACTIONS(2435),
    [anon_sym_namespace] = ACTIONS(2435),
    [anon_sym_using] = ACTIONS(2435),
    [anon_sym_static_assert] = ACTIONS(2435),
    [anon_sym_concept] = ACTIONS(2435),
    [anon_sym_co_return] = ACTIONS(2435),
    [anon_sym_co_yield] = ACTIONS(2435),
    [anon_sym_R_DQUOTE] = ACTIONS(2437),
    [anon_sym_LR_DQUOTE] = ACTIONS(2437),
    [anon_sym_uR_DQUOTE] = ACTIONS(2437),
    [anon_sym_UR_DQUOTE] = ACTIONS(2437),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2437),
    [anon_sym_co_await] = ACTIONS(2435),
    [anon_sym_new] = ACTIONS(2435),
    [anon_sym_requires] = ACTIONS(2435),
    [sym_this] = ACTIONS(2435),
    [anon_sym___launch_bounds__] = ACTIONS(2435),
  },
  [STATE(576)] = {
    [sym_identifier] = ACTIONS(2447),
    [aux_sym_preproc_include_token1] = ACTIONS(2447),
    [aux_sym_preproc_def_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2447),
    [sym_preproc_directive] = ACTIONS(2447),
    [anon_sym_LPAREN2] = ACTIONS(2449),
    [anon_sym_BANG] = ACTIONS(2449),
    [anon_sym_TILDE] = ACTIONS(2449),
    [anon_sym_DASH] = ACTIONS(2447),
    [anon_sym_PLUS] = ACTIONS(2447),
    [anon_sym_STAR] = ACTIONS(2449),
    [anon_sym_AMP_AMP] = ACTIONS(2449),
    [anon_sym_AMP] = ACTIONS(2447),
    [anon_sym_SEMI] = ACTIONS(2449),
    [anon_sym___extension__] = ACTIONS(2447),
    [anon_sym_typedef] = ACTIONS(2447),
    [anon_sym___device__] = ACTIONS(2447),
    [anon_sym___host__] = ACTIONS(2447),
    [anon_sym___global__] = ACTIONS(2447),
    [anon_sym___forceinline__] = ACTIONS(2447),
    [anon_sym___noinline__] = ACTIONS(2447),
    [anon_sym_virtual] = ACTIONS(2447),
    [anon_sym_extern] = ACTIONS(2447),
    [anon_sym___attribute__] = ACTIONS(2447),
    [anon_sym___attribute] = ACTIONS(2447),
    [anon_sym_COLON_COLON] = ACTIONS(2449),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2449),
    [anon_sym___declspec] = ACTIONS(2447),
    [anon_sym___based] = ACTIONS(2447),
    [anon_sym___cdecl] = ACTIONS(2447),
    [anon_sym___clrcall] = ACTIONS(2447),
    [anon_sym___stdcall] = ACTIONS(2447),
    [anon_sym___fastcall] = ACTIONS(2447),
    [anon_sym___thiscall] = ACTIONS(2447),
    [anon_sym___vectorcall] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2449),
    [anon_sym_RBRACE] = ACTIONS(2449),
    [anon_sym_signed] = ACTIONS(2447),
    [anon_sym_unsigned] = ACTIONS(2447),
    [anon_sym_long] = ACTIONS(2447),
    [anon_sym_short] = ACTIONS(2447),
    [anon_sym_LBRACK] = ACTIONS(2447),
    [anon_sym_static] = ACTIONS(2447),
    [anon_sym_register] = ACTIONS(2447),
    [anon_sym_inline] = ACTIONS(2447),
    [anon_sym___inline] = ACTIONS(2447),
    [anon_sym___inline__] = ACTIONS(2447),
    [anon_sym___forceinline] = ACTIONS(2447),
    [anon_sym_thread_local] = ACTIONS(2447),
    [anon_sym___thread] = ACTIONS(2447),
    [anon_sym_const] = ACTIONS(2447),
    [anon_sym_constexpr] = ACTIONS(2447),
    [anon_sym_volatile] = ACTIONS(2447),
    [anon_sym_restrict] = ACTIONS(2447),
    [anon_sym___restrict__] = ACTIONS(2447),
    [anon_sym__Atomic] = ACTIONS(2447),
    [anon_sym__Noreturn] = ACTIONS(2447),
    [anon_sym_noreturn] = ACTIONS(2447),
    [anon_sym__Nonnull] = ACTIONS(2447),
    [anon_sym_mutable] = ACTIONS(2447),
    [anon_sym_constinit] = ACTIONS(2447),
    [anon_sym_consteval] = ACTIONS(2447),
    [anon_sym___shared__] = ACTIONS(2447),
    [anon_sym___local__] = ACTIONS(2447),
    [anon_sym___constant__] = ACTIONS(2447),
    [anon_sym___managed__] = ACTIONS(2447),
    [anon_sym___grid_constant__] = ACTIONS(2447),
    [anon_sym_alignas] = ACTIONS(2447),
    [anon_sym__Alignas] = ACTIONS(2447),
    [sym_primitive_type] = ACTIONS(2447),
    [anon_sym_enum] = ACTIONS(2447),
    [anon_sym_class] = ACTIONS(2447),
    [anon_sym_struct] = ACTIONS(2447),
    [anon_sym_union] = ACTIONS(2447),
    [anon_sym_if] = ACTIONS(2447),
    [anon_sym_switch] = ACTIONS(2447),
    [anon_sym_case] = ACTIONS(2447),
    [anon_sym_default] = ACTIONS(2447),
    [anon_sym_while] = ACTIONS(2447),
    [anon_sym_do] = ACTIONS(2447),
    [anon_sym_for] = ACTIONS(2447),
    [anon_sym_return] = ACTIONS(2447),
    [anon_sym_break] = ACTIONS(2447),
    [anon_sym_continue] = ACTIONS(2447),
    [anon_sym_goto] = ACTIONS(2447),
    [anon_sym___try] = ACTIONS(2447),
    [anon_sym___leave] = ACTIONS(2447),
    [anon_sym_not] = ACTIONS(2447),
    [anon_sym_compl] = ACTIONS(2447),
    [anon_sym_DASH_DASH] = ACTIONS(2449),
    [anon_sym_PLUS_PLUS] = ACTIONS(2449),
    [anon_sym_sizeof] = ACTIONS(2447),
    [anon_sym___alignof__] = ACTIONS(2447),
    [anon_sym___alignof] = ACTIONS(2447),
    [anon_sym__alignof] = ACTIONS(2447),
    [anon_sym_alignof] = ACTIONS(2447),
    [anon_sym__Alignof] = ACTIONS(2447),
    [anon_sym_offsetof] = ACTIONS(2447),
    [anon_sym__Generic] = ACTIONS(2447),
    [anon_sym_asm] = ACTIONS(2447),
    [anon_sym___asm__] = ACTIONS(2447),
    [anon_sym___asm] = ACTIONS(2447),
    [sym_number_literal] = ACTIONS(2449),
    [anon_sym_L_SQUOTE] = ACTIONS(2449),
    [anon_sym_u_SQUOTE] = ACTIONS(2449),
    [anon_sym_U_SQUOTE] = ACTIONS(2449),
    [anon_sym_u8_SQUOTE] = ACTIONS(2449),
    [anon_sym_SQUOTE] = ACTIONS(2449),
    [anon_sym_L_DQUOTE] = ACTIONS(2449),
    [anon_sym_u_DQUOTE] = ACTIONS(2449),
    [anon_sym_U_DQUOTE] = ACTIONS(2449),
    [anon_sym_u8_DQUOTE] = ACTIONS(2449),
    [anon_sym_DQUOTE] = ACTIONS(2449),
    [sym_true] = ACTIONS(2447),
    [sym_false] = ACTIONS(2447),
    [anon_sym_NULL] = ACTIONS(2447),
    [anon_sym_nullptr] = ACTIONS(2447),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2447),
    [anon_sym_decltype] = ACTIONS(2447),
    [anon_sym_explicit] = ACTIONS(2447),
    [anon_sym_typename] = ACTIONS(2447),
    [anon_sym_template] = ACTIONS(2447),
    [anon_sym_operator] = ACTIONS(2447),
    [anon_sym_try] = ACTIONS(2447),
    [anon_sym_delete] = ACTIONS(2447),
    [anon_sym_throw] = ACTIONS(2447),
    [anon_sym_namespace] = ACTIONS(2447),
    [anon_sym_using] = ACTIONS(2447),
    [anon_sym_static_assert] = ACTIONS(2447),
    [anon_sym_concept] = ACTIONS(2447),
    [anon_sym_co_return] = ACTIONS(2447),
    [anon_sym_co_yield] = ACTIONS(2447),
    [anon_sym_R_DQUOTE] = ACTIONS(2449),
    [anon_sym_LR_DQUOTE] = ACTIONS(2449),
    [anon_sym_uR_DQUOTE] = ACTIONS(2449),
    [anon_sym_UR_DQUOTE] = ACTIONS(2449),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2449),
    [anon_sym_co_await] = ACTIONS(2447),
    [anon_sym_new] = ACTIONS(2447),
    [anon_sym_requires] = ACTIONS(2447),
    [sym_this] = ACTIONS(2447),
    [anon_sym___launch_bounds__] = ACTIONS(2447),
  },
  [STATE(577)] = {
    [sym_identifier] = ACTIONS(2457),
    [aux_sym_preproc_include_token1] = ACTIONS(2457),
    [aux_sym_preproc_def_token1] = ACTIONS(2457),
    [aux_sym_preproc_if_token1] = ACTIONS(2457),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2457),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2457),
    [sym_preproc_directive] = ACTIONS(2457),
    [anon_sym_LPAREN2] = ACTIONS(2459),
    [anon_sym_BANG] = ACTIONS(2459),
    [anon_sym_TILDE] = ACTIONS(2459),
    [anon_sym_DASH] = ACTIONS(2457),
    [anon_sym_PLUS] = ACTIONS(2457),
    [anon_sym_STAR] = ACTIONS(2459),
    [anon_sym_AMP_AMP] = ACTIONS(2459),
    [anon_sym_AMP] = ACTIONS(2457),
    [anon_sym_SEMI] = ACTIONS(2459),
    [anon_sym___extension__] = ACTIONS(2457),
    [anon_sym_typedef] = ACTIONS(2457),
    [anon_sym___device__] = ACTIONS(2457),
    [anon_sym___host__] = ACTIONS(2457),
    [anon_sym___global__] = ACTIONS(2457),
    [anon_sym___forceinline__] = ACTIONS(2457),
    [anon_sym___noinline__] = ACTIONS(2457),
    [anon_sym_virtual] = ACTIONS(2457),
    [anon_sym_extern] = ACTIONS(2457),
    [anon_sym___attribute__] = ACTIONS(2457),
    [anon_sym___attribute] = ACTIONS(2457),
    [anon_sym_COLON_COLON] = ACTIONS(2459),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2459),
    [anon_sym___declspec] = ACTIONS(2457),
    [anon_sym___based] = ACTIONS(2457),
    [anon_sym___cdecl] = ACTIONS(2457),
    [anon_sym___clrcall] = ACTIONS(2457),
    [anon_sym___stdcall] = ACTIONS(2457),
    [anon_sym___fastcall] = ACTIONS(2457),
    [anon_sym___thiscall] = ACTIONS(2457),
    [anon_sym___vectorcall] = ACTIONS(2457),
    [anon_sym_LBRACE] = ACTIONS(2459),
    [anon_sym_RBRACE] = ACTIONS(2459),
    [anon_sym_signed] = ACTIONS(2457),
    [anon_sym_unsigned] = ACTIONS(2457),
    [anon_sym_long] = ACTIONS(2457),
    [anon_sym_short] = ACTIONS(2457),
    [anon_sym_LBRACK] = ACTIONS(2457),
    [anon_sym_static] = ACTIONS(2457),
    [anon_sym_register] = ACTIONS(2457),
    [anon_sym_inline] = ACTIONS(2457),
    [anon_sym___inline] = ACTIONS(2457),
    [anon_sym___inline__] = ACTIONS(2457),
    [anon_sym___forceinline] = ACTIONS(2457),
    [anon_sym_thread_local] = ACTIONS(2457),
    [anon_sym___thread] = ACTIONS(2457),
    [anon_sym_const] = ACTIONS(2457),
    [anon_sym_constexpr] = ACTIONS(2457),
    [anon_sym_volatile] = ACTIONS(2457),
    [anon_sym_restrict] = ACTIONS(2457),
    [anon_sym___restrict__] = ACTIONS(2457),
    [anon_sym__Atomic] = ACTIONS(2457),
    [anon_sym__Noreturn] = ACTIONS(2457),
    [anon_sym_noreturn] = ACTIONS(2457),
    [anon_sym__Nonnull] = ACTIONS(2457),
    [anon_sym_mutable] = ACTIONS(2457),
    [anon_sym_constinit] = ACTIONS(2457),
    [anon_sym_consteval] = ACTIONS(2457),
    [anon_sym___shared__] = ACTIONS(2457),
    [anon_sym___local__] = ACTIONS(2457),
    [anon_sym___constant__] = ACTIONS(2457),
    [anon_sym___managed__] = ACTIONS(2457),
    [anon_sym___grid_constant__] = ACTIONS(2457),
    [anon_sym_alignas] = ACTIONS(2457),
    [anon_sym__Alignas] = ACTIONS(2457),
    [sym_primitive_type] = ACTIONS(2457),
    [anon_sym_enum] = ACTIONS(2457),
    [anon_sym_class] = ACTIONS(2457),
    [anon_sym_struct] = ACTIONS(2457),
    [anon_sym_union] = ACTIONS(2457),
    [anon_sym_if] = ACTIONS(2457),
    [anon_sym_switch] = ACTIONS(2457),
    [anon_sym_case] = ACTIONS(2457),
    [anon_sym_default] = ACTIONS(2457),
    [anon_sym_while] = ACTIONS(2457),
    [anon_sym_do] = ACTIONS(2457),
    [anon_sym_for] = ACTIONS(2457),
    [anon_sym_return] = ACTIONS(2457),
    [anon_sym_break] = ACTIONS(2457),
    [anon_sym_continue] = ACTIONS(2457),
    [anon_sym_goto] = ACTIONS(2457),
    [anon_sym___try] = ACTIONS(2457),
    [anon_sym___leave] = ACTIONS(2457),
    [anon_sym_not] = ACTIONS(2457),
    [anon_sym_compl] = ACTIONS(2457),
    [anon_sym_DASH_DASH] = ACTIONS(2459),
    [anon_sym_PLUS_PLUS] = ACTIONS(2459),
    [anon_sym_sizeof] = ACTIONS(2457),
    [anon_sym___alignof__] = ACTIONS(2457),
    [anon_sym___alignof] = ACTIONS(2457),
    [anon_sym__alignof] = ACTIONS(2457),
    [anon_sym_alignof] = ACTIONS(2457),
    [anon_sym__Alignof] = ACTIONS(2457),
    [anon_sym_offsetof] = ACTIONS(2457),
    [anon_sym__Generic] = ACTIONS(2457),
    [anon_sym_asm] = ACTIONS(2457),
    [anon_sym___asm__] = ACTIONS(2457),
    [anon_sym___asm] = ACTIONS(2457),
    [sym_number_literal] = ACTIONS(2459),
    [anon_sym_L_SQUOTE] = ACTIONS(2459),
    [anon_sym_u_SQUOTE] = ACTIONS(2459),
    [anon_sym_U_SQUOTE] = ACTIONS(2459),
    [anon_sym_u8_SQUOTE] = ACTIONS(2459),
    [anon_sym_SQUOTE] = ACTIONS(2459),
    [anon_sym_L_DQUOTE] = ACTIONS(2459),
    [anon_sym_u_DQUOTE] = ACTIONS(2459),
    [anon_sym_U_DQUOTE] = ACTIONS(2459),
    [anon_sym_u8_DQUOTE] = ACTIONS(2459),
    [anon_sym_DQUOTE] = ACTIONS(2459),
    [sym_true] = ACTIONS(2457),
    [sym_false] = ACTIONS(2457),
    [anon_sym_NULL] = ACTIONS(2457),
    [anon_sym_nullptr] = ACTIONS(2457),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2457),
    [anon_sym_decltype] = ACTIONS(2457),
    [anon_sym_explicit] = ACTIONS(2457),
    [anon_sym_typename] = ACTIONS(2457),
    [anon_sym_template] = ACTIONS(2457),
    [anon_sym_operator] = ACTIONS(2457),
    [anon_sym_try] = ACTIONS(2457),
    [anon_sym_delete] = ACTIONS(2457),
    [anon_sym_throw] = ACTIONS(2457),
    [anon_sym_namespace] = ACTIONS(2457),
    [anon_sym_using] = ACTIONS(2457),
    [anon_sym_static_assert] = ACTIONS(2457),
    [anon_sym_concept] = ACTIONS(2457),
    [anon_sym_co_return] = ACTIONS(2457),
    [anon_sym_co_yield] = ACTIONS(2457),
    [anon_sym_R_DQUOTE] = ACTIONS(2459),
    [anon_sym_LR_DQUOTE] = ACTIONS(2459),
    [anon_sym_uR_DQUOTE] = ACTIONS(2459),
    [anon_sym_UR_DQUOTE] = ACTIONS(2459),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2459),
    [anon_sym_co_await] = ACTIONS(2457),
    [anon_sym_new] = ACTIONS(2457),
    [anon_sym_requires] = ACTIONS(2457),
    [sym_this] = ACTIONS(2457),
    [anon_sym___launch_bounds__] = ACTIONS(2457),
  },
  [STATE(578)] = {
    [sym_identifier] = ACTIONS(2471),
    [aux_sym_preproc_include_token1] = ACTIONS(2471),
    [aux_sym_preproc_def_token1] = ACTIONS(2471),
    [aux_sym_preproc_if_token1] = ACTIONS(2471),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2471),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2471),
    [sym_preproc_directive] = ACTIONS(2471),
    [anon_sym_LPAREN2] = ACTIONS(2473),
    [anon_sym_BANG] = ACTIONS(2473),
    [anon_sym_TILDE] = ACTIONS(2473),
    [anon_sym_DASH] = ACTIONS(2471),
    [anon_sym_PLUS] = ACTIONS(2471),
    [anon_sym_STAR] = ACTIONS(2473),
    [anon_sym_AMP_AMP] = ACTIONS(2473),
    [anon_sym_AMP] = ACTIONS(2471),
    [anon_sym_SEMI] = ACTIONS(2473),
    [anon_sym___extension__] = ACTIONS(2471),
    [anon_sym_typedef] = ACTIONS(2471),
    [anon_sym___device__] = ACTIONS(2471),
    [anon_sym___host__] = ACTIONS(2471),
    [anon_sym___global__] = ACTIONS(2471),
    [anon_sym___forceinline__] = ACTIONS(2471),
    [anon_sym___noinline__] = ACTIONS(2471),
    [anon_sym_virtual] = ACTIONS(2471),
    [anon_sym_extern] = ACTIONS(2471),
    [anon_sym___attribute__] = ACTIONS(2471),
    [anon_sym___attribute] = ACTIONS(2471),
    [anon_sym_COLON_COLON] = ACTIONS(2473),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2473),
    [anon_sym___declspec] = ACTIONS(2471),
    [anon_sym___based] = ACTIONS(2471),
    [anon_sym___cdecl] = ACTIONS(2471),
    [anon_sym___clrcall] = ACTIONS(2471),
    [anon_sym___stdcall] = ACTIONS(2471),
    [anon_sym___fastcall] = ACTIONS(2471),
    [anon_sym___thiscall] = ACTIONS(2471),
    [anon_sym___vectorcall] = ACTIONS(2471),
    [anon_sym_LBRACE] = ACTIONS(2473),
    [anon_sym_RBRACE] = ACTIONS(2473),
    [anon_sym_signed] = ACTIONS(2471),
    [anon_sym_unsigned] = ACTIONS(2471),
    [anon_sym_long] = ACTIONS(2471),
    [anon_sym_short] = ACTIONS(2471),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_static] = ACTIONS(2471),
    [anon_sym_register] = ACTIONS(2471),
    [anon_sym_inline] = ACTIONS(2471),
    [anon_sym___inline] = ACTIONS(2471),
    [anon_sym___inline__] = ACTIONS(2471),
    [anon_sym___forceinline] = ACTIONS(2471),
    [anon_sym_thread_local] = ACTIONS(2471),
    [anon_sym___thread] = ACTIONS(2471),
    [anon_sym_const] = ACTIONS(2471),
    [anon_sym_constexpr] = ACTIONS(2471),
    [anon_sym_volatile] = ACTIONS(2471),
    [anon_sym_restrict] = ACTIONS(2471),
    [anon_sym___restrict__] = ACTIONS(2471),
    [anon_sym__Atomic] = ACTIONS(2471),
    [anon_sym__Noreturn] = ACTIONS(2471),
    [anon_sym_noreturn] = ACTIONS(2471),
    [anon_sym__Nonnull] = ACTIONS(2471),
    [anon_sym_mutable] = ACTIONS(2471),
    [anon_sym_constinit] = ACTIONS(2471),
    [anon_sym_consteval] = ACTIONS(2471),
    [anon_sym___shared__] = ACTIONS(2471),
    [anon_sym___local__] = ACTIONS(2471),
    [anon_sym___constant__] = ACTIONS(2471),
    [anon_sym___managed__] = ACTIONS(2471),
    [anon_sym___grid_constant__] = ACTIONS(2471),
    [anon_sym_alignas] = ACTIONS(2471),
    [anon_sym__Alignas] = ACTIONS(2471),
    [sym_primitive_type] = ACTIONS(2471),
    [anon_sym_enum] = ACTIONS(2471),
    [anon_sym_class] = ACTIONS(2471),
    [anon_sym_struct] = ACTIONS(2471),
    [anon_sym_union] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2471),
    [anon_sym_switch] = ACTIONS(2471),
    [anon_sym_case] = ACTIONS(2471),
    [anon_sym_default] = ACTIONS(2471),
    [anon_sym_while] = ACTIONS(2471),
    [anon_sym_do] = ACTIONS(2471),
    [anon_sym_for] = ACTIONS(2471),
    [anon_sym_return] = ACTIONS(2471),
    [anon_sym_break] = ACTIONS(2471),
    [anon_sym_continue] = ACTIONS(2471),
    [anon_sym_goto] = ACTIONS(2471),
    [anon_sym___try] = ACTIONS(2471),
    [anon_sym___leave] = ACTIONS(2471),
    [anon_sym_not] = ACTIONS(2471),
    [anon_sym_compl] = ACTIONS(2471),
    [anon_sym_DASH_DASH] = ACTIONS(2473),
    [anon_sym_PLUS_PLUS] = ACTIONS(2473),
    [anon_sym_sizeof] = ACTIONS(2471),
    [anon_sym___alignof__] = ACTIONS(2471),
    [anon_sym___alignof] = ACTIONS(2471),
    [anon_sym__alignof] = ACTIONS(2471),
    [anon_sym_alignof] = ACTIONS(2471),
    [anon_sym__Alignof] = ACTIONS(2471),
    [anon_sym_offsetof] = ACTIONS(2471),
    [anon_sym__Generic] = ACTIONS(2471),
    [anon_sym_asm] = ACTIONS(2471),
    [anon_sym___asm__] = ACTIONS(2471),
    [anon_sym___asm] = ACTIONS(2471),
    [sym_number_literal] = ACTIONS(2473),
    [anon_sym_L_SQUOTE] = ACTIONS(2473),
    [anon_sym_u_SQUOTE] = ACTIONS(2473),
    [anon_sym_U_SQUOTE] = ACTIONS(2473),
    [anon_sym_u8_SQUOTE] = ACTIONS(2473),
    [anon_sym_SQUOTE] = ACTIONS(2473),
    [anon_sym_L_DQUOTE] = ACTIONS(2473),
    [anon_sym_u_DQUOTE] = ACTIONS(2473),
    [anon_sym_U_DQUOTE] = ACTIONS(2473),
    [anon_sym_u8_DQUOTE] = ACTIONS(2473),
    [anon_sym_DQUOTE] = ACTIONS(2473),
    [sym_true] = ACTIONS(2471),
    [sym_false] = ACTIONS(2471),
    [anon_sym_NULL] = ACTIONS(2471),
    [anon_sym_nullptr] = ACTIONS(2471),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2471),
    [anon_sym_decltype] = ACTIONS(2471),
    [anon_sym_explicit] = ACTIONS(2471),
    [anon_sym_typename] = ACTIONS(2471),
    [anon_sym_template] = ACTIONS(2471),
    [anon_sym_operator] = ACTIONS(2471),
    [anon_sym_try] = ACTIONS(2471),
    [anon_sym_delete] = ACTIONS(2471),
    [anon_sym_throw] = ACTIONS(2471),
    [anon_sym_namespace] = ACTIONS(2471),
    [anon_sym_using] = ACTIONS(2471),
    [anon_sym_static_assert] = ACTIONS(2471),
    [anon_sym_concept] = ACTIONS(2471),
    [anon_sym_co_return] = ACTIONS(2471),
    [anon_sym_co_yield] = ACTIONS(2471),
    [anon_sym_R_DQUOTE] = ACTIONS(2473),
    [anon_sym_LR_DQUOTE] = ACTIONS(2473),
    [anon_sym_uR_DQUOTE] = ACTIONS(2473),
    [anon_sym_UR_DQUOTE] = ACTIONS(2473),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2473),
    [anon_sym_co_await] = ACTIONS(2471),
    [anon_sym_new] = ACTIONS(2471),
    [anon_sym_requires] = ACTIONS(2471),
    [sym_this] = ACTIONS(2471),
    [anon_sym___launch_bounds__] = ACTIONS(2471),
  },
  [STATE(579)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4971),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7694),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8117),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2944),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(580)] = {
    [sym_identifier] = ACTIONS(2475),
    [aux_sym_preproc_include_token1] = ACTIONS(2475),
    [aux_sym_preproc_def_token1] = ACTIONS(2475),
    [aux_sym_preproc_if_token1] = ACTIONS(2475),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2475),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2475),
    [sym_preproc_directive] = ACTIONS(2475),
    [anon_sym_LPAREN2] = ACTIONS(2477),
    [anon_sym_BANG] = ACTIONS(2477),
    [anon_sym_TILDE] = ACTIONS(2477),
    [anon_sym_DASH] = ACTIONS(2475),
    [anon_sym_PLUS] = ACTIONS(2475),
    [anon_sym_STAR] = ACTIONS(2477),
    [anon_sym_AMP_AMP] = ACTIONS(2477),
    [anon_sym_AMP] = ACTIONS(2475),
    [anon_sym_SEMI] = ACTIONS(2477),
    [anon_sym___extension__] = ACTIONS(2475),
    [anon_sym_typedef] = ACTIONS(2475),
    [anon_sym___device__] = ACTIONS(2475),
    [anon_sym___host__] = ACTIONS(2475),
    [anon_sym___global__] = ACTIONS(2475),
    [anon_sym___forceinline__] = ACTIONS(2475),
    [anon_sym___noinline__] = ACTIONS(2475),
    [anon_sym_virtual] = ACTIONS(2475),
    [anon_sym_extern] = ACTIONS(2475),
    [anon_sym___attribute__] = ACTIONS(2475),
    [anon_sym___attribute] = ACTIONS(2475),
    [anon_sym_COLON_COLON] = ACTIONS(2477),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2477),
    [anon_sym___declspec] = ACTIONS(2475),
    [anon_sym___based] = ACTIONS(2475),
    [anon_sym___cdecl] = ACTIONS(2475),
    [anon_sym___clrcall] = ACTIONS(2475),
    [anon_sym___stdcall] = ACTIONS(2475),
    [anon_sym___fastcall] = ACTIONS(2475),
    [anon_sym___thiscall] = ACTIONS(2475),
    [anon_sym___vectorcall] = ACTIONS(2475),
    [anon_sym_LBRACE] = ACTIONS(2477),
    [anon_sym_RBRACE] = ACTIONS(2477),
    [anon_sym_signed] = ACTIONS(2475),
    [anon_sym_unsigned] = ACTIONS(2475),
    [anon_sym_long] = ACTIONS(2475),
    [anon_sym_short] = ACTIONS(2475),
    [anon_sym_LBRACK] = ACTIONS(2475),
    [anon_sym_static] = ACTIONS(2475),
    [anon_sym_register] = ACTIONS(2475),
    [anon_sym_inline] = ACTIONS(2475),
    [anon_sym___inline] = ACTIONS(2475),
    [anon_sym___inline__] = ACTIONS(2475),
    [anon_sym___forceinline] = ACTIONS(2475),
    [anon_sym_thread_local] = ACTIONS(2475),
    [anon_sym___thread] = ACTIONS(2475),
    [anon_sym_const] = ACTIONS(2475),
    [anon_sym_constexpr] = ACTIONS(2475),
    [anon_sym_volatile] = ACTIONS(2475),
    [anon_sym_restrict] = ACTIONS(2475),
    [anon_sym___restrict__] = ACTIONS(2475),
    [anon_sym__Atomic] = ACTIONS(2475),
    [anon_sym__Noreturn] = ACTIONS(2475),
    [anon_sym_noreturn] = ACTIONS(2475),
    [anon_sym__Nonnull] = ACTIONS(2475),
    [anon_sym_mutable] = ACTIONS(2475),
    [anon_sym_constinit] = ACTIONS(2475),
    [anon_sym_consteval] = ACTIONS(2475),
    [anon_sym___shared__] = ACTIONS(2475),
    [anon_sym___local__] = ACTIONS(2475),
    [anon_sym___constant__] = ACTIONS(2475),
    [anon_sym___managed__] = ACTIONS(2475),
    [anon_sym___grid_constant__] = ACTIONS(2475),
    [anon_sym_alignas] = ACTIONS(2475),
    [anon_sym__Alignas] = ACTIONS(2475),
    [sym_primitive_type] = ACTIONS(2475),
    [anon_sym_enum] = ACTIONS(2475),
    [anon_sym_class] = ACTIONS(2475),
    [anon_sym_struct] = ACTIONS(2475),
    [anon_sym_union] = ACTIONS(2475),
    [anon_sym_if] = ACTIONS(2475),
    [anon_sym_switch] = ACTIONS(2475),
    [anon_sym_case] = ACTIONS(2475),
    [anon_sym_default] = ACTIONS(2475),
    [anon_sym_while] = ACTIONS(2475),
    [anon_sym_do] = ACTIONS(2475),
    [anon_sym_for] = ACTIONS(2475),
    [anon_sym_return] = ACTIONS(2475),
    [anon_sym_break] = ACTIONS(2475),
    [anon_sym_continue] = ACTIONS(2475),
    [anon_sym_goto] = ACTIONS(2475),
    [anon_sym___try] = ACTIONS(2475),
    [anon_sym___leave] = ACTIONS(2475),
    [anon_sym_not] = ACTIONS(2475),
    [anon_sym_compl] = ACTIONS(2475),
    [anon_sym_DASH_DASH] = ACTIONS(2477),
    [anon_sym_PLUS_PLUS] = ACTIONS(2477),
    [anon_sym_sizeof] = ACTIONS(2475),
    [anon_sym___alignof__] = ACTIONS(2475),
    [anon_sym___alignof] = ACTIONS(2475),
    [anon_sym__alignof] = ACTIONS(2475),
    [anon_sym_alignof] = ACTIONS(2475),
    [anon_sym__Alignof] = ACTIONS(2475),
    [anon_sym_offsetof] = ACTIONS(2475),
    [anon_sym__Generic] = ACTIONS(2475),
    [anon_sym_asm] = ACTIONS(2475),
    [anon_sym___asm__] = ACTIONS(2475),
    [anon_sym___asm] = ACTIONS(2475),
    [sym_number_literal] = ACTIONS(2477),
    [anon_sym_L_SQUOTE] = ACTIONS(2477),
    [anon_sym_u_SQUOTE] = ACTIONS(2477),
    [anon_sym_U_SQUOTE] = ACTIONS(2477),
    [anon_sym_u8_SQUOTE] = ACTIONS(2477),
    [anon_sym_SQUOTE] = ACTIONS(2477),
    [anon_sym_L_DQUOTE] = ACTIONS(2477),
    [anon_sym_u_DQUOTE] = ACTIONS(2477),
    [anon_sym_U_DQUOTE] = ACTIONS(2477),
    [anon_sym_u8_DQUOTE] = ACTIONS(2477),
    [anon_sym_DQUOTE] = ACTIONS(2477),
    [sym_true] = ACTIONS(2475),
    [sym_false] = ACTIONS(2475),
    [anon_sym_NULL] = ACTIONS(2475),
    [anon_sym_nullptr] = ACTIONS(2475),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2475),
    [anon_sym_decltype] = ACTIONS(2475),
    [anon_sym_explicit] = ACTIONS(2475),
    [anon_sym_typename] = ACTIONS(2475),
    [anon_sym_template] = ACTIONS(2475),
    [anon_sym_operator] = ACTIONS(2475),
    [anon_sym_try] = ACTIONS(2475),
    [anon_sym_delete] = ACTIONS(2475),
    [anon_sym_throw] = ACTIONS(2475),
    [anon_sym_namespace] = ACTIONS(2475),
    [anon_sym_using] = ACTIONS(2475),
    [anon_sym_static_assert] = ACTIONS(2475),
    [anon_sym_concept] = ACTIONS(2475),
    [anon_sym_co_return] = ACTIONS(2475),
    [anon_sym_co_yield] = ACTIONS(2475),
    [anon_sym_R_DQUOTE] = ACTIONS(2477),
    [anon_sym_LR_DQUOTE] = ACTIONS(2477),
    [anon_sym_uR_DQUOTE] = ACTIONS(2477),
    [anon_sym_UR_DQUOTE] = ACTIONS(2477),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2477),
    [anon_sym_co_await] = ACTIONS(2475),
    [anon_sym_new] = ACTIONS(2475),
    [anon_sym_requires] = ACTIONS(2475),
    [sym_this] = ACTIONS(2475),
    [anon_sym___launch_bounds__] = ACTIONS(2475),
  },
  [STATE(581)] = {
    [sym_identifier] = ACTIONS(2545),
    [aux_sym_preproc_include_token1] = ACTIONS(2545),
    [aux_sym_preproc_def_token1] = ACTIONS(2545),
    [aux_sym_preproc_if_token1] = ACTIONS(2545),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2545),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2545),
    [sym_preproc_directive] = ACTIONS(2545),
    [anon_sym_LPAREN2] = ACTIONS(2547),
    [anon_sym_BANG] = ACTIONS(2547),
    [anon_sym_TILDE] = ACTIONS(2547),
    [anon_sym_DASH] = ACTIONS(2545),
    [anon_sym_PLUS] = ACTIONS(2545),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_AMP_AMP] = ACTIONS(2547),
    [anon_sym_AMP] = ACTIONS(2545),
    [anon_sym_SEMI] = ACTIONS(2547),
    [anon_sym___extension__] = ACTIONS(2545),
    [anon_sym_typedef] = ACTIONS(2545),
    [anon_sym___device__] = ACTIONS(2545),
    [anon_sym___host__] = ACTIONS(2545),
    [anon_sym___global__] = ACTIONS(2545),
    [anon_sym___forceinline__] = ACTIONS(2545),
    [anon_sym___noinline__] = ACTIONS(2545),
    [anon_sym_virtual] = ACTIONS(2545),
    [anon_sym_extern] = ACTIONS(2545),
    [anon_sym___attribute__] = ACTIONS(2545),
    [anon_sym___attribute] = ACTIONS(2545),
    [anon_sym_COLON_COLON] = ACTIONS(2547),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2547),
    [anon_sym___declspec] = ACTIONS(2545),
    [anon_sym___based] = ACTIONS(2545),
    [anon_sym___cdecl] = ACTIONS(2545),
    [anon_sym___clrcall] = ACTIONS(2545),
    [anon_sym___stdcall] = ACTIONS(2545),
    [anon_sym___fastcall] = ACTIONS(2545),
    [anon_sym___thiscall] = ACTIONS(2545),
    [anon_sym___vectorcall] = ACTIONS(2545),
    [anon_sym_LBRACE] = ACTIONS(2547),
    [anon_sym_RBRACE] = ACTIONS(2547),
    [anon_sym_signed] = ACTIONS(2545),
    [anon_sym_unsigned] = ACTIONS(2545),
    [anon_sym_long] = ACTIONS(2545),
    [anon_sym_short] = ACTIONS(2545),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [anon_sym_static] = ACTIONS(2545),
    [anon_sym_register] = ACTIONS(2545),
    [anon_sym_inline] = ACTIONS(2545),
    [anon_sym___inline] = ACTIONS(2545),
    [anon_sym___inline__] = ACTIONS(2545),
    [anon_sym___forceinline] = ACTIONS(2545),
    [anon_sym_thread_local] = ACTIONS(2545),
    [anon_sym___thread] = ACTIONS(2545),
    [anon_sym_const] = ACTIONS(2545),
    [anon_sym_constexpr] = ACTIONS(2545),
    [anon_sym_volatile] = ACTIONS(2545),
    [anon_sym_restrict] = ACTIONS(2545),
    [anon_sym___restrict__] = ACTIONS(2545),
    [anon_sym__Atomic] = ACTIONS(2545),
    [anon_sym__Noreturn] = ACTIONS(2545),
    [anon_sym_noreturn] = ACTIONS(2545),
    [anon_sym__Nonnull] = ACTIONS(2545),
    [anon_sym_mutable] = ACTIONS(2545),
    [anon_sym_constinit] = ACTIONS(2545),
    [anon_sym_consteval] = ACTIONS(2545),
    [anon_sym___shared__] = ACTIONS(2545),
    [anon_sym___local__] = ACTIONS(2545),
    [anon_sym___constant__] = ACTIONS(2545),
    [anon_sym___managed__] = ACTIONS(2545),
    [anon_sym___grid_constant__] = ACTIONS(2545),
    [anon_sym_alignas] = ACTIONS(2545),
    [anon_sym__Alignas] = ACTIONS(2545),
    [sym_primitive_type] = ACTIONS(2545),
    [anon_sym_enum] = ACTIONS(2545),
    [anon_sym_class] = ACTIONS(2545),
    [anon_sym_struct] = ACTIONS(2545),
    [anon_sym_union] = ACTIONS(2545),
    [anon_sym_if] = ACTIONS(2545),
    [anon_sym_switch] = ACTIONS(2545),
    [anon_sym_case] = ACTIONS(2545),
    [anon_sym_default] = ACTIONS(2545),
    [anon_sym_while] = ACTIONS(2545),
    [anon_sym_do] = ACTIONS(2545),
    [anon_sym_for] = ACTIONS(2545),
    [anon_sym_return] = ACTIONS(2545),
    [anon_sym_break] = ACTIONS(2545),
    [anon_sym_continue] = ACTIONS(2545),
    [anon_sym_goto] = ACTIONS(2545),
    [anon_sym___try] = ACTIONS(2545),
    [anon_sym___leave] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2545),
    [anon_sym_compl] = ACTIONS(2545),
    [anon_sym_DASH_DASH] = ACTIONS(2547),
    [anon_sym_PLUS_PLUS] = ACTIONS(2547),
    [anon_sym_sizeof] = ACTIONS(2545),
    [anon_sym___alignof__] = ACTIONS(2545),
    [anon_sym___alignof] = ACTIONS(2545),
    [anon_sym__alignof] = ACTIONS(2545),
    [anon_sym_alignof] = ACTIONS(2545),
    [anon_sym__Alignof] = ACTIONS(2545),
    [anon_sym_offsetof] = ACTIONS(2545),
    [anon_sym__Generic] = ACTIONS(2545),
    [anon_sym_asm] = ACTIONS(2545),
    [anon_sym___asm__] = ACTIONS(2545),
    [anon_sym___asm] = ACTIONS(2545),
    [sym_number_literal] = ACTIONS(2547),
    [anon_sym_L_SQUOTE] = ACTIONS(2547),
    [anon_sym_u_SQUOTE] = ACTIONS(2547),
    [anon_sym_U_SQUOTE] = ACTIONS(2547),
    [anon_sym_u8_SQUOTE] = ACTIONS(2547),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_L_DQUOTE] = ACTIONS(2547),
    [anon_sym_u_DQUOTE] = ACTIONS(2547),
    [anon_sym_U_DQUOTE] = ACTIONS(2547),
    [anon_sym_u8_DQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2547),
    [sym_true] = ACTIONS(2545),
    [sym_false] = ACTIONS(2545),
    [anon_sym_NULL] = ACTIONS(2545),
    [anon_sym_nullptr] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2545),
    [anon_sym_decltype] = ACTIONS(2545),
    [anon_sym_explicit] = ACTIONS(2545),
    [anon_sym_typename] = ACTIONS(2545),
    [anon_sym_template] = ACTIONS(2545),
    [anon_sym_operator] = ACTIONS(2545),
    [anon_sym_try] = ACTIONS(2545),
    [anon_sym_delete] = ACTIONS(2545),
    [anon_sym_throw] = ACTIONS(2545),
    [anon_sym_namespace] = ACTIONS(2545),
    [anon_sym_using] = ACTIONS(2545),
    [anon_sym_static_assert] = ACTIONS(2545),
    [anon_sym_concept] = ACTIONS(2545),
    [anon_sym_co_return] = ACTIONS(2545),
    [anon_sym_co_yield] = ACTIONS(2545),
    [anon_sym_R_DQUOTE] = ACTIONS(2547),
    [anon_sym_LR_DQUOTE] = ACTIONS(2547),
    [anon_sym_uR_DQUOTE] = ACTIONS(2547),
    [anon_sym_UR_DQUOTE] = ACTIONS(2547),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2547),
    [anon_sym_co_await] = ACTIONS(2545),
    [anon_sym_new] = ACTIONS(2545),
    [anon_sym_requires] = ACTIONS(2545),
    [sym_this] = ACTIONS(2545),
    [anon_sym___launch_bounds__] = ACTIONS(2545),
  },
  [STATE(582)] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_include_token1] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2549),
    [anon_sym_PLUS] = ACTIONS(2549),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym___device__] = ACTIONS(2549),
    [anon_sym___host__] = ACTIONS(2549),
    [anon_sym___global__] = ACTIONS(2549),
    [anon_sym___forceinline__] = ACTIONS(2549),
    [anon_sym___noinline__] = ACTIONS(2549),
    [anon_sym_virtual] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym___attribute] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym___cdecl] = ACTIONS(2549),
    [anon_sym___clrcall] = ACTIONS(2549),
    [anon_sym___stdcall] = ACTIONS(2549),
    [anon_sym___fastcall] = ACTIONS(2549),
    [anon_sym___thiscall] = ACTIONS(2549),
    [anon_sym___vectorcall] = ACTIONS(2549),
    [anon_sym_LBRACE] = ACTIONS(2551),
    [anon_sym_RBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym__Nonnull] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym___shared__] = ACTIONS(2549),
    [anon_sym___local__] = ACTIONS(2549),
    [anon_sym___constant__] = ACTIONS(2549),
    [anon_sym___managed__] = ACTIONS(2549),
    [anon_sym___grid_constant__] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2549),
    [anon_sym_switch] = ACTIONS(2549),
    [anon_sym_case] = ACTIONS(2549),
    [anon_sym_default] = ACTIONS(2549),
    [anon_sym_while] = ACTIONS(2549),
    [anon_sym_do] = ACTIONS(2549),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_return] = ACTIONS(2549),
    [anon_sym_break] = ACTIONS(2549),
    [anon_sym_continue] = ACTIONS(2549),
    [anon_sym_goto] = ACTIONS(2549),
    [anon_sym___try] = ACTIONS(2549),
    [anon_sym___leave] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2549),
    [anon_sym_compl] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2551),
    [anon_sym_sizeof] = ACTIONS(2549),
    [anon_sym___alignof__] = ACTIONS(2549),
    [anon_sym___alignof] = ACTIONS(2549),
    [anon_sym__alignof] = ACTIONS(2549),
    [anon_sym_alignof] = ACTIONS(2549),
    [anon_sym__Alignof] = ACTIONS(2549),
    [anon_sym_offsetof] = ACTIONS(2549),
    [anon_sym__Generic] = ACTIONS(2549),
    [anon_sym_asm] = ACTIONS(2549),
    [anon_sym___asm__] = ACTIONS(2549),
    [anon_sym___asm] = ACTIONS(2549),
    [sym_number_literal] = ACTIONS(2551),
    [anon_sym_L_SQUOTE] = ACTIONS(2551),
    [anon_sym_u_SQUOTE] = ACTIONS(2551),
    [anon_sym_U_SQUOTE] = ACTIONS(2551),
    [anon_sym_u8_SQUOTE] = ACTIONS(2551),
    [anon_sym_SQUOTE] = ACTIONS(2551),
    [anon_sym_L_DQUOTE] = ACTIONS(2551),
    [anon_sym_u_DQUOTE] = ACTIONS(2551),
    [anon_sym_U_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8_DQUOTE] = ACTIONS(2551),
    [anon_sym_DQUOTE] = ACTIONS(2551),
    [sym_true] = ACTIONS(2549),
    [sym_false] = ACTIONS(2549),
    [anon_sym_NULL] = ACTIONS(2549),
    [anon_sym_nullptr] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_try] = ACTIONS(2549),
    [anon_sym_delete] = ACTIONS(2549),
    [anon_sym_throw] = ACTIONS(2549),
    [anon_sym_namespace] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_concept] = ACTIONS(2549),
    [anon_sym_co_return] = ACTIONS(2549),
    [anon_sym_co_yield] = ACTIONS(2549),
    [anon_sym_R_DQUOTE] = ACTIONS(2551),
    [anon_sym_LR_DQUOTE] = ACTIONS(2551),
    [anon_sym_uR_DQUOTE] = ACTIONS(2551),
    [anon_sym_UR_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2551),
    [anon_sym_co_await] = ACTIONS(2549),
    [anon_sym_new] = ACTIONS(2549),
    [anon_sym_requires] = ACTIONS(2549),
    [sym_this] = ACTIONS(2549),
    [anon_sym___launch_bounds__] = ACTIONS(2549),
  },
  [STATE(583)] = {
    [sym_identifier] = ACTIONS(2557),
    [aux_sym_preproc_include_token1] = ACTIONS(2557),
    [aux_sym_preproc_def_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token2] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2557),
    [sym_preproc_directive] = ACTIONS(2557),
    [anon_sym_LPAREN2] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2557),
    [anon_sym_PLUS] = ACTIONS(2557),
    [anon_sym_STAR] = ACTIONS(2559),
    [anon_sym_AMP_AMP] = ACTIONS(2559),
    [anon_sym_AMP] = ACTIONS(2557),
    [anon_sym_SEMI] = ACTIONS(2559),
    [anon_sym___extension__] = ACTIONS(2557),
    [anon_sym_typedef] = ACTIONS(2557),
    [anon_sym___device__] = ACTIONS(2557),
    [anon_sym___host__] = ACTIONS(2557),
    [anon_sym___global__] = ACTIONS(2557),
    [anon_sym___forceinline__] = ACTIONS(2557),
    [anon_sym___noinline__] = ACTIONS(2557),
    [anon_sym_virtual] = ACTIONS(2557),
    [anon_sym_extern] = ACTIONS(2557),
    [anon_sym___attribute__] = ACTIONS(2557),
    [anon_sym___attribute] = ACTIONS(2557),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2559),
    [anon_sym___declspec] = ACTIONS(2557),
    [anon_sym___based] = ACTIONS(2557),
    [anon_sym___cdecl] = ACTIONS(2557),
    [anon_sym___clrcall] = ACTIONS(2557),
    [anon_sym___stdcall] = ACTIONS(2557),
    [anon_sym___fastcall] = ACTIONS(2557),
    [anon_sym___thiscall] = ACTIONS(2557),
    [anon_sym___vectorcall] = ACTIONS(2557),
    [anon_sym_LBRACE] = ACTIONS(2559),
    [anon_sym_signed] = ACTIONS(2557),
    [anon_sym_unsigned] = ACTIONS(2557),
    [anon_sym_long] = ACTIONS(2557),
    [anon_sym_short] = ACTIONS(2557),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2557),
    [anon_sym_register] = ACTIONS(2557),
    [anon_sym_inline] = ACTIONS(2557),
    [anon_sym___inline] = ACTIONS(2557),
    [anon_sym___inline__] = ACTIONS(2557),
    [anon_sym___forceinline] = ACTIONS(2557),
    [anon_sym_thread_local] = ACTIONS(2557),
    [anon_sym___thread] = ACTIONS(2557),
    [anon_sym_const] = ACTIONS(2557),
    [anon_sym_constexpr] = ACTIONS(2557),
    [anon_sym_volatile] = ACTIONS(2557),
    [anon_sym_restrict] = ACTIONS(2557),
    [anon_sym___restrict__] = ACTIONS(2557),
    [anon_sym__Atomic] = ACTIONS(2557),
    [anon_sym__Noreturn] = ACTIONS(2557),
    [anon_sym_noreturn] = ACTIONS(2557),
    [anon_sym__Nonnull] = ACTIONS(2557),
    [anon_sym_mutable] = ACTIONS(2557),
    [anon_sym_constinit] = ACTIONS(2557),
    [anon_sym_consteval] = ACTIONS(2557),
    [anon_sym___shared__] = ACTIONS(2557),
    [anon_sym___local__] = ACTIONS(2557),
    [anon_sym___constant__] = ACTIONS(2557),
    [anon_sym___managed__] = ACTIONS(2557),
    [anon_sym___grid_constant__] = ACTIONS(2557),
    [anon_sym_alignas] = ACTIONS(2557),
    [anon_sym__Alignas] = ACTIONS(2557),
    [sym_primitive_type] = ACTIONS(2557),
    [anon_sym_enum] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2557),
    [anon_sym_struct] = ACTIONS(2557),
    [anon_sym_union] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2557),
    [anon_sym_switch] = ACTIONS(2557),
    [anon_sym_case] = ACTIONS(2557),
    [anon_sym_default] = ACTIONS(2557),
    [anon_sym_while] = ACTIONS(2557),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_for] = ACTIONS(2557),
    [anon_sym_return] = ACTIONS(2557),
    [anon_sym_break] = ACTIONS(2557),
    [anon_sym_continue] = ACTIONS(2557),
    [anon_sym_goto] = ACTIONS(2557),
    [anon_sym___try] = ACTIONS(2557),
    [anon_sym___leave] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2557),
    [anon_sym_compl] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2559),
    [anon_sym_sizeof] = ACTIONS(2557),
    [anon_sym___alignof__] = ACTIONS(2557),
    [anon_sym___alignof] = ACTIONS(2557),
    [anon_sym__alignof] = ACTIONS(2557),
    [anon_sym_alignof] = ACTIONS(2557),
    [anon_sym__Alignof] = ACTIONS(2557),
    [anon_sym_offsetof] = ACTIONS(2557),
    [anon_sym__Generic] = ACTIONS(2557),
    [anon_sym_asm] = ACTIONS(2557),
    [anon_sym___asm__] = ACTIONS(2557),
    [anon_sym___asm] = ACTIONS(2557),
    [sym_number_literal] = ACTIONS(2559),
    [anon_sym_L_SQUOTE] = ACTIONS(2559),
    [anon_sym_u_SQUOTE] = ACTIONS(2559),
    [anon_sym_U_SQUOTE] = ACTIONS(2559),
    [anon_sym_u8_SQUOTE] = ACTIONS(2559),
    [anon_sym_SQUOTE] = ACTIONS(2559),
    [anon_sym_L_DQUOTE] = ACTIONS(2559),
    [anon_sym_u_DQUOTE] = ACTIONS(2559),
    [anon_sym_U_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8_DQUOTE] = ACTIONS(2559),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_true] = ACTIONS(2557),
    [sym_false] = ACTIONS(2557),
    [anon_sym_NULL] = ACTIONS(2557),
    [anon_sym_nullptr] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2557),
    [anon_sym_decltype] = ACTIONS(2557),
    [anon_sym_explicit] = ACTIONS(2557),
    [anon_sym_typename] = ACTIONS(2557),
    [anon_sym_template] = ACTIONS(2557),
    [anon_sym_operator] = ACTIONS(2557),
    [anon_sym_try] = ACTIONS(2557),
    [anon_sym_delete] = ACTIONS(2557),
    [anon_sym_throw] = ACTIONS(2557),
    [anon_sym_namespace] = ACTIONS(2557),
    [anon_sym_using] = ACTIONS(2557),
    [anon_sym_static_assert] = ACTIONS(2557),
    [anon_sym_concept] = ACTIONS(2557),
    [anon_sym_co_return] = ACTIONS(2557),
    [anon_sym_co_yield] = ACTIONS(2557),
    [anon_sym_R_DQUOTE] = ACTIONS(2559),
    [anon_sym_LR_DQUOTE] = ACTIONS(2559),
    [anon_sym_uR_DQUOTE] = ACTIONS(2559),
    [anon_sym_UR_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2559),
    [anon_sym_co_await] = ACTIONS(2557),
    [anon_sym_new] = ACTIONS(2557),
    [anon_sym_requires] = ACTIONS(2557),
    [sym_this] = ACTIONS(2557),
    [anon_sym___launch_bounds__] = ACTIONS(2557),
  },
  [STATE(584)] = {
    [sym_identifier] = ACTIONS(2377),
    [aux_sym_preproc_include_token1] = ACTIONS(2377),
    [aux_sym_preproc_def_token1] = ACTIONS(2377),
    [aux_sym_preproc_if_token1] = ACTIONS(2377),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2377),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2377),
    [sym_preproc_directive] = ACTIONS(2377),
    [anon_sym_LPAREN2] = ACTIONS(2379),
    [anon_sym_BANG] = ACTIONS(2379),
    [anon_sym_TILDE] = ACTIONS(2379),
    [anon_sym_DASH] = ACTIONS(2377),
    [anon_sym_PLUS] = ACTIONS(2377),
    [anon_sym_STAR] = ACTIONS(2379),
    [anon_sym_AMP_AMP] = ACTIONS(2379),
    [anon_sym_AMP] = ACTIONS(2377),
    [anon_sym_SEMI] = ACTIONS(2379),
    [anon_sym___extension__] = ACTIONS(2377),
    [anon_sym_typedef] = ACTIONS(2377),
    [anon_sym___device__] = ACTIONS(2377),
    [anon_sym___host__] = ACTIONS(2377),
    [anon_sym___global__] = ACTIONS(2377),
    [anon_sym___forceinline__] = ACTIONS(2377),
    [anon_sym___noinline__] = ACTIONS(2377),
    [anon_sym_virtual] = ACTIONS(2377),
    [anon_sym_extern] = ACTIONS(2377),
    [anon_sym___attribute__] = ACTIONS(2377),
    [anon_sym___attribute] = ACTIONS(2377),
    [anon_sym_COLON_COLON] = ACTIONS(2379),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2379),
    [anon_sym___declspec] = ACTIONS(2377),
    [anon_sym___based] = ACTIONS(2377),
    [anon_sym___cdecl] = ACTIONS(2377),
    [anon_sym___clrcall] = ACTIONS(2377),
    [anon_sym___stdcall] = ACTIONS(2377),
    [anon_sym___fastcall] = ACTIONS(2377),
    [anon_sym___thiscall] = ACTIONS(2377),
    [anon_sym___vectorcall] = ACTIONS(2377),
    [anon_sym_LBRACE] = ACTIONS(2379),
    [anon_sym_RBRACE] = ACTIONS(2379),
    [anon_sym_signed] = ACTIONS(2377),
    [anon_sym_unsigned] = ACTIONS(2377),
    [anon_sym_long] = ACTIONS(2377),
    [anon_sym_short] = ACTIONS(2377),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_static] = ACTIONS(2377),
    [anon_sym_register] = ACTIONS(2377),
    [anon_sym_inline] = ACTIONS(2377),
    [anon_sym___inline] = ACTIONS(2377),
    [anon_sym___inline__] = ACTIONS(2377),
    [anon_sym___forceinline] = ACTIONS(2377),
    [anon_sym_thread_local] = ACTIONS(2377),
    [anon_sym___thread] = ACTIONS(2377),
    [anon_sym_const] = ACTIONS(2377),
    [anon_sym_constexpr] = ACTIONS(2377),
    [anon_sym_volatile] = ACTIONS(2377),
    [anon_sym_restrict] = ACTIONS(2377),
    [anon_sym___restrict__] = ACTIONS(2377),
    [anon_sym__Atomic] = ACTIONS(2377),
    [anon_sym__Noreturn] = ACTIONS(2377),
    [anon_sym_noreturn] = ACTIONS(2377),
    [anon_sym__Nonnull] = ACTIONS(2377),
    [anon_sym_mutable] = ACTIONS(2377),
    [anon_sym_constinit] = ACTIONS(2377),
    [anon_sym_consteval] = ACTIONS(2377),
    [anon_sym___shared__] = ACTIONS(2377),
    [anon_sym___local__] = ACTIONS(2377),
    [anon_sym___constant__] = ACTIONS(2377),
    [anon_sym___managed__] = ACTIONS(2377),
    [anon_sym___grid_constant__] = ACTIONS(2377),
    [anon_sym_alignas] = ACTIONS(2377),
    [anon_sym__Alignas] = ACTIONS(2377),
    [sym_primitive_type] = ACTIONS(2377),
    [anon_sym_enum] = ACTIONS(2377),
    [anon_sym_class] = ACTIONS(2377),
    [anon_sym_struct] = ACTIONS(2377),
    [anon_sym_union] = ACTIONS(2377),
    [anon_sym_if] = ACTIONS(2377),
    [anon_sym_switch] = ACTIONS(2377),
    [anon_sym_case] = ACTIONS(2377),
    [anon_sym_default] = ACTIONS(2377),
    [anon_sym_while] = ACTIONS(2377),
    [anon_sym_do] = ACTIONS(2377),
    [anon_sym_for] = ACTIONS(2377),
    [anon_sym_return] = ACTIONS(2377),
    [anon_sym_break] = ACTIONS(2377),
    [anon_sym_continue] = ACTIONS(2377),
    [anon_sym_goto] = ACTIONS(2377),
    [anon_sym___try] = ACTIONS(2377),
    [anon_sym___leave] = ACTIONS(2377),
    [anon_sym_not] = ACTIONS(2377),
    [anon_sym_compl] = ACTIONS(2377),
    [anon_sym_DASH_DASH] = ACTIONS(2379),
    [anon_sym_PLUS_PLUS] = ACTIONS(2379),
    [anon_sym_sizeof] = ACTIONS(2377),
    [anon_sym___alignof__] = ACTIONS(2377),
    [anon_sym___alignof] = ACTIONS(2377),
    [anon_sym__alignof] = ACTIONS(2377),
    [anon_sym_alignof] = ACTIONS(2377),
    [anon_sym__Alignof] = ACTIONS(2377),
    [anon_sym_offsetof] = ACTIONS(2377),
    [anon_sym__Generic] = ACTIONS(2377),
    [anon_sym_asm] = ACTIONS(2377),
    [anon_sym___asm__] = ACTIONS(2377),
    [anon_sym___asm] = ACTIONS(2377),
    [sym_number_literal] = ACTIONS(2379),
    [anon_sym_L_SQUOTE] = ACTIONS(2379),
    [anon_sym_u_SQUOTE] = ACTIONS(2379),
    [anon_sym_U_SQUOTE] = ACTIONS(2379),
    [anon_sym_u8_SQUOTE] = ACTIONS(2379),
    [anon_sym_SQUOTE] = ACTIONS(2379),
    [anon_sym_L_DQUOTE] = ACTIONS(2379),
    [anon_sym_u_DQUOTE] = ACTIONS(2379),
    [anon_sym_U_DQUOTE] = ACTIONS(2379),
    [anon_sym_u8_DQUOTE] = ACTIONS(2379),
    [anon_sym_DQUOTE] = ACTIONS(2379),
    [sym_true] = ACTIONS(2377),
    [sym_false] = ACTIONS(2377),
    [anon_sym_NULL] = ACTIONS(2377),
    [anon_sym_nullptr] = ACTIONS(2377),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2377),
    [anon_sym_decltype] = ACTIONS(2377),
    [anon_sym_explicit] = ACTIONS(2377),
    [anon_sym_typename] = ACTIONS(2377),
    [anon_sym_template] = ACTIONS(2377),
    [anon_sym_operator] = ACTIONS(2377),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_delete] = ACTIONS(2377),
    [anon_sym_throw] = ACTIONS(2377),
    [anon_sym_namespace] = ACTIONS(2377),
    [anon_sym_using] = ACTIONS(2377),
    [anon_sym_static_assert] = ACTIONS(2377),
    [anon_sym_concept] = ACTIONS(2377),
    [anon_sym_co_return] = ACTIONS(2377),
    [anon_sym_co_yield] = ACTIONS(2377),
    [anon_sym_R_DQUOTE] = ACTIONS(2379),
    [anon_sym_LR_DQUOTE] = ACTIONS(2379),
    [anon_sym_uR_DQUOTE] = ACTIONS(2379),
    [anon_sym_UR_DQUOTE] = ACTIONS(2379),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2379),
    [anon_sym_co_await] = ACTIONS(2377),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_requires] = ACTIONS(2377),
    [sym_this] = ACTIONS(2377),
    [anon_sym___launch_bounds__] = ACTIONS(2377),
  },
  [STATE(585)] = {
    [sym_identifier] = ACTIONS(2423),
    [aux_sym_preproc_include_token1] = ACTIONS(2423),
    [aux_sym_preproc_def_token1] = ACTIONS(2423),
    [aux_sym_preproc_if_token1] = ACTIONS(2423),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2423),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2423),
    [sym_preproc_directive] = ACTIONS(2423),
    [anon_sym_LPAREN2] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(2425),
    [anon_sym_TILDE] = ACTIONS(2425),
    [anon_sym_DASH] = ACTIONS(2423),
    [anon_sym_PLUS] = ACTIONS(2423),
    [anon_sym_STAR] = ACTIONS(2425),
    [anon_sym_AMP_AMP] = ACTIONS(2425),
    [anon_sym_AMP] = ACTIONS(2423),
    [anon_sym_SEMI] = ACTIONS(2425),
    [anon_sym___extension__] = ACTIONS(2423),
    [anon_sym_typedef] = ACTIONS(2423),
    [anon_sym___device__] = ACTIONS(2423),
    [anon_sym___host__] = ACTIONS(2423),
    [anon_sym___global__] = ACTIONS(2423),
    [anon_sym___forceinline__] = ACTIONS(2423),
    [anon_sym___noinline__] = ACTIONS(2423),
    [anon_sym_virtual] = ACTIONS(2423),
    [anon_sym_extern] = ACTIONS(2423),
    [anon_sym___attribute__] = ACTIONS(2423),
    [anon_sym___attribute] = ACTIONS(2423),
    [anon_sym_COLON_COLON] = ACTIONS(2425),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2425),
    [anon_sym___declspec] = ACTIONS(2423),
    [anon_sym___based] = ACTIONS(2423),
    [anon_sym___cdecl] = ACTIONS(2423),
    [anon_sym___clrcall] = ACTIONS(2423),
    [anon_sym___stdcall] = ACTIONS(2423),
    [anon_sym___fastcall] = ACTIONS(2423),
    [anon_sym___thiscall] = ACTIONS(2423),
    [anon_sym___vectorcall] = ACTIONS(2423),
    [anon_sym_LBRACE] = ACTIONS(2425),
    [anon_sym_RBRACE] = ACTIONS(2425),
    [anon_sym_signed] = ACTIONS(2423),
    [anon_sym_unsigned] = ACTIONS(2423),
    [anon_sym_long] = ACTIONS(2423),
    [anon_sym_short] = ACTIONS(2423),
    [anon_sym_LBRACK] = ACTIONS(2423),
    [anon_sym_static] = ACTIONS(2423),
    [anon_sym_register] = ACTIONS(2423),
    [anon_sym_inline] = ACTIONS(2423),
    [anon_sym___inline] = ACTIONS(2423),
    [anon_sym___inline__] = ACTIONS(2423),
    [anon_sym___forceinline] = ACTIONS(2423),
    [anon_sym_thread_local] = ACTIONS(2423),
    [anon_sym___thread] = ACTIONS(2423),
    [anon_sym_const] = ACTIONS(2423),
    [anon_sym_constexpr] = ACTIONS(2423),
    [anon_sym_volatile] = ACTIONS(2423),
    [anon_sym_restrict] = ACTIONS(2423),
    [anon_sym___restrict__] = ACTIONS(2423),
    [anon_sym__Atomic] = ACTIONS(2423),
    [anon_sym__Noreturn] = ACTIONS(2423),
    [anon_sym_noreturn] = ACTIONS(2423),
    [anon_sym__Nonnull] = ACTIONS(2423),
    [anon_sym_mutable] = ACTIONS(2423),
    [anon_sym_constinit] = ACTIONS(2423),
    [anon_sym_consteval] = ACTIONS(2423),
    [anon_sym___shared__] = ACTIONS(2423),
    [anon_sym___local__] = ACTIONS(2423),
    [anon_sym___constant__] = ACTIONS(2423),
    [anon_sym___managed__] = ACTIONS(2423),
    [anon_sym___grid_constant__] = ACTIONS(2423),
    [anon_sym_alignas] = ACTIONS(2423),
    [anon_sym__Alignas] = ACTIONS(2423),
    [sym_primitive_type] = ACTIONS(2423),
    [anon_sym_enum] = ACTIONS(2423),
    [anon_sym_class] = ACTIONS(2423),
    [anon_sym_struct] = ACTIONS(2423),
    [anon_sym_union] = ACTIONS(2423),
    [anon_sym_if] = ACTIONS(2423),
    [anon_sym_switch] = ACTIONS(2423),
    [anon_sym_case] = ACTIONS(2423),
    [anon_sym_default] = ACTIONS(2423),
    [anon_sym_while] = ACTIONS(2423),
    [anon_sym_do] = ACTIONS(2423),
    [anon_sym_for] = ACTIONS(2423),
    [anon_sym_return] = ACTIONS(2423),
    [anon_sym_break] = ACTIONS(2423),
    [anon_sym_continue] = ACTIONS(2423),
    [anon_sym_goto] = ACTIONS(2423),
    [anon_sym___try] = ACTIONS(2423),
    [anon_sym___leave] = ACTIONS(2423),
    [anon_sym_not] = ACTIONS(2423),
    [anon_sym_compl] = ACTIONS(2423),
    [anon_sym_DASH_DASH] = ACTIONS(2425),
    [anon_sym_PLUS_PLUS] = ACTIONS(2425),
    [anon_sym_sizeof] = ACTIONS(2423),
    [anon_sym___alignof__] = ACTIONS(2423),
    [anon_sym___alignof] = ACTIONS(2423),
    [anon_sym__alignof] = ACTIONS(2423),
    [anon_sym_alignof] = ACTIONS(2423),
    [anon_sym__Alignof] = ACTIONS(2423),
    [anon_sym_offsetof] = ACTIONS(2423),
    [anon_sym__Generic] = ACTIONS(2423),
    [anon_sym_asm] = ACTIONS(2423),
    [anon_sym___asm__] = ACTIONS(2423),
    [anon_sym___asm] = ACTIONS(2423),
    [sym_number_literal] = ACTIONS(2425),
    [anon_sym_L_SQUOTE] = ACTIONS(2425),
    [anon_sym_u_SQUOTE] = ACTIONS(2425),
    [anon_sym_U_SQUOTE] = ACTIONS(2425),
    [anon_sym_u8_SQUOTE] = ACTIONS(2425),
    [anon_sym_SQUOTE] = ACTIONS(2425),
    [anon_sym_L_DQUOTE] = ACTIONS(2425),
    [anon_sym_u_DQUOTE] = ACTIONS(2425),
    [anon_sym_U_DQUOTE] = ACTIONS(2425),
    [anon_sym_u8_DQUOTE] = ACTIONS(2425),
    [anon_sym_DQUOTE] = ACTIONS(2425),
    [sym_true] = ACTIONS(2423),
    [sym_false] = ACTIONS(2423),
    [anon_sym_NULL] = ACTIONS(2423),
    [anon_sym_nullptr] = ACTIONS(2423),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2423),
    [anon_sym_decltype] = ACTIONS(2423),
    [anon_sym_explicit] = ACTIONS(2423),
    [anon_sym_typename] = ACTIONS(2423),
    [anon_sym_template] = ACTIONS(2423),
    [anon_sym_operator] = ACTIONS(2423),
    [anon_sym_try] = ACTIONS(2423),
    [anon_sym_delete] = ACTIONS(2423),
    [anon_sym_throw] = ACTIONS(2423),
    [anon_sym_namespace] = ACTIONS(2423),
    [anon_sym_using] = ACTIONS(2423),
    [anon_sym_static_assert] = ACTIONS(2423),
    [anon_sym_concept] = ACTIONS(2423),
    [anon_sym_co_return] = ACTIONS(2423),
    [anon_sym_co_yield] = ACTIONS(2423),
    [anon_sym_R_DQUOTE] = ACTIONS(2425),
    [anon_sym_LR_DQUOTE] = ACTIONS(2425),
    [anon_sym_uR_DQUOTE] = ACTIONS(2425),
    [anon_sym_UR_DQUOTE] = ACTIONS(2425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2425),
    [anon_sym_co_await] = ACTIONS(2423),
    [anon_sym_new] = ACTIONS(2423),
    [anon_sym_requires] = ACTIONS(2423),
    [sym_this] = ACTIONS(2423),
    [anon_sym___launch_bounds__] = ACTIONS(2423),
  },
  [STATE(586)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4964),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7607),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7769),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2946),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(587)] = {
    [sym_identifier] = ACTIONS(2553),
    [aux_sym_preproc_include_token1] = ACTIONS(2553),
    [aux_sym_preproc_def_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2553),
    [sym_preproc_directive] = ACTIONS(2553),
    [anon_sym_LPAREN2] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2555),
    [anon_sym_TILDE] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2553),
    [anon_sym_PLUS] = ACTIONS(2553),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_AMP_AMP] = ACTIONS(2555),
    [anon_sym_AMP] = ACTIONS(2553),
    [anon_sym_SEMI] = ACTIONS(2555),
    [anon_sym___extension__] = ACTIONS(2553),
    [anon_sym_typedef] = ACTIONS(2553),
    [anon_sym___device__] = ACTIONS(2553),
    [anon_sym___host__] = ACTIONS(2553),
    [anon_sym___global__] = ACTIONS(2553),
    [anon_sym___forceinline__] = ACTIONS(2553),
    [anon_sym___noinline__] = ACTIONS(2553),
    [anon_sym_virtual] = ACTIONS(2553),
    [anon_sym_extern] = ACTIONS(2553),
    [anon_sym___attribute__] = ACTIONS(2553),
    [anon_sym___attribute] = ACTIONS(2553),
    [anon_sym_COLON_COLON] = ACTIONS(2555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2555),
    [anon_sym___declspec] = ACTIONS(2553),
    [anon_sym___based] = ACTIONS(2553),
    [anon_sym___cdecl] = ACTIONS(2553),
    [anon_sym___clrcall] = ACTIONS(2553),
    [anon_sym___stdcall] = ACTIONS(2553),
    [anon_sym___fastcall] = ACTIONS(2553),
    [anon_sym___thiscall] = ACTIONS(2553),
    [anon_sym___vectorcall] = ACTIONS(2553),
    [anon_sym_LBRACE] = ACTIONS(2555),
    [anon_sym_RBRACE] = ACTIONS(2555),
    [anon_sym_signed] = ACTIONS(2553),
    [anon_sym_unsigned] = ACTIONS(2553),
    [anon_sym_long] = ACTIONS(2553),
    [anon_sym_short] = ACTIONS(2553),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2553),
    [anon_sym_register] = ACTIONS(2553),
    [anon_sym_inline] = ACTIONS(2553),
    [anon_sym___inline] = ACTIONS(2553),
    [anon_sym___inline__] = ACTIONS(2553),
    [anon_sym___forceinline] = ACTIONS(2553),
    [anon_sym_thread_local] = ACTIONS(2553),
    [anon_sym___thread] = ACTIONS(2553),
    [anon_sym_const] = ACTIONS(2553),
    [anon_sym_constexpr] = ACTIONS(2553),
    [anon_sym_volatile] = ACTIONS(2553),
    [anon_sym_restrict] = ACTIONS(2553),
    [anon_sym___restrict__] = ACTIONS(2553),
    [anon_sym__Atomic] = ACTIONS(2553),
    [anon_sym__Noreturn] = ACTIONS(2553),
    [anon_sym_noreturn] = ACTIONS(2553),
    [anon_sym__Nonnull] = ACTIONS(2553),
    [anon_sym_mutable] = ACTIONS(2553),
    [anon_sym_constinit] = ACTIONS(2553),
    [anon_sym_consteval] = ACTIONS(2553),
    [anon_sym___shared__] = ACTIONS(2553),
    [anon_sym___local__] = ACTIONS(2553),
    [anon_sym___constant__] = ACTIONS(2553),
    [anon_sym___managed__] = ACTIONS(2553),
    [anon_sym___grid_constant__] = ACTIONS(2553),
    [anon_sym_alignas] = ACTIONS(2553),
    [anon_sym__Alignas] = ACTIONS(2553),
    [sym_primitive_type] = ACTIONS(2553),
    [anon_sym_enum] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2553),
    [anon_sym_struct] = ACTIONS(2553),
    [anon_sym_union] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2553),
    [anon_sym_switch] = ACTIONS(2553),
    [anon_sym_case] = ACTIONS(2553),
    [anon_sym_default] = ACTIONS(2553),
    [anon_sym_while] = ACTIONS(2553),
    [anon_sym_do] = ACTIONS(2553),
    [anon_sym_for] = ACTIONS(2553),
    [anon_sym_return] = ACTIONS(2553),
    [anon_sym_break] = ACTIONS(2553),
    [anon_sym_continue] = ACTIONS(2553),
    [anon_sym_goto] = ACTIONS(2553),
    [anon_sym___try] = ACTIONS(2553),
    [anon_sym___leave] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2553),
    [anon_sym_compl] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2555),
    [anon_sym_sizeof] = ACTIONS(2553),
    [anon_sym___alignof__] = ACTIONS(2553),
    [anon_sym___alignof] = ACTIONS(2553),
    [anon_sym__alignof] = ACTIONS(2553),
    [anon_sym_alignof] = ACTIONS(2553),
    [anon_sym__Alignof] = ACTIONS(2553),
    [anon_sym_offsetof] = ACTIONS(2553),
    [anon_sym__Generic] = ACTIONS(2553),
    [anon_sym_asm] = ACTIONS(2553),
    [anon_sym___asm__] = ACTIONS(2553),
    [anon_sym___asm] = ACTIONS(2553),
    [sym_number_literal] = ACTIONS(2555),
    [anon_sym_L_SQUOTE] = ACTIONS(2555),
    [anon_sym_u_SQUOTE] = ACTIONS(2555),
    [anon_sym_U_SQUOTE] = ACTIONS(2555),
    [anon_sym_u8_SQUOTE] = ACTIONS(2555),
    [anon_sym_SQUOTE] = ACTIONS(2555),
    [anon_sym_L_DQUOTE] = ACTIONS(2555),
    [anon_sym_u_DQUOTE] = ACTIONS(2555),
    [anon_sym_U_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8_DQUOTE] = ACTIONS(2555),
    [anon_sym_DQUOTE] = ACTIONS(2555),
    [sym_true] = ACTIONS(2553),
    [sym_false] = ACTIONS(2553),
    [anon_sym_NULL] = ACTIONS(2553),
    [anon_sym_nullptr] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2553),
    [anon_sym_decltype] = ACTIONS(2553),
    [anon_sym_explicit] = ACTIONS(2553),
    [anon_sym_typename] = ACTIONS(2553),
    [anon_sym_template] = ACTIONS(2553),
    [anon_sym_operator] = ACTIONS(2553),
    [anon_sym_try] = ACTIONS(2553),
    [anon_sym_delete] = ACTIONS(2553),
    [anon_sym_throw] = ACTIONS(2553),
    [anon_sym_namespace] = ACTIONS(2553),
    [anon_sym_using] = ACTIONS(2553),
    [anon_sym_static_assert] = ACTIONS(2553),
    [anon_sym_concept] = ACTIONS(2553),
    [anon_sym_co_return] = ACTIONS(2553),
    [anon_sym_co_yield] = ACTIONS(2553),
    [anon_sym_R_DQUOTE] = ACTIONS(2555),
    [anon_sym_LR_DQUOTE] = ACTIONS(2555),
    [anon_sym_uR_DQUOTE] = ACTIONS(2555),
    [anon_sym_UR_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2555),
    [anon_sym_co_await] = ACTIONS(2553),
    [anon_sym_new] = ACTIONS(2553),
    [anon_sym_requires] = ACTIONS(2553),
    [sym_this] = ACTIONS(2553),
    [anon_sym___launch_bounds__] = ACTIONS(2553),
  },
  [STATE(588)] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_include_token1] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token2] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_BANG] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym___device__] = ACTIONS(2577),
    [anon_sym___host__] = ACTIONS(2577),
    [anon_sym___global__] = ACTIONS(2577),
    [anon_sym___forceinline__] = ACTIONS(2577),
    [anon_sym___noinline__] = ACTIONS(2577),
    [anon_sym_virtual] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym___attribute] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym___cdecl] = ACTIONS(2577),
    [anon_sym___clrcall] = ACTIONS(2577),
    [anon_sym___stdcall] = ACTIONS(2577),
    [anon_sym___fastcall] = ACTIONS(2577),
    [anon_sym___thiscall] = ACTIONS(2577),
    [anon_sym___vectorcall] = ACTIONS(2577),
    [anon_sym_LBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym__Nonnull] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym___shared__] = ACTIONS(2577),
    [anon_sym___local__] = ACTIONS(2577),
    [anon_sym___constant__] = ACTIONS(2577),
    [anon_sym___managed__] = ACTIONS(2577),
    [anon_sym___grid_constant__] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_switch] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_default] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_do] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_return] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_goto] = ACTIONS(2577),
    [anon_sym___try] = ACTIONS(2577),
    [anon_sym___leave] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_compl] = ACTIONS(2577),
    [anon_sym_DASH_DASH] = ACTIONS(2579),
    [anon_sym_PLUS_PLUS] = ACTIONS(2579),
    [anon_sym_sizeof] = ACTIONS(2577),
    [anon_sym___alignof__] = ACTIONS(2577),
    [anon_sym___alignof] = ACTIONS(2577),
    [anon_sym__alignof] = ACTIONS(2577),
    [anon_sym_alignof] = ACTIONS(2577),
    [anon_sym__Alignof] = ACTIONS(2577),
    [anon_sym_offsetof] = ACTIONS(2577),
    [anon_sym__Generic] = ACTIONS(2577),
    [anon_sym_asm] = ACTIONS(2577),
    [anon_sym___asm__] = ACTIONS(2577),
    [anon_sym___asm] = ACTIONS(2577),
    [sym_number_literal] = ACTIONS(2579),
    [anon_sym_L_SQUOTE] = ACTIONS(2579),
    [anon_sym_u_SQUOTE] = ACTIONS(2579),
    [anon_sym_U_SQUOTE] = ACTIONS(2579),
    [anon_sym_u8_SQUOTE] = ACTIONS(2579),
    [anon_sym_SQUOTE] = ACTIONS(2579),
    [anon_sym_L_DQUOTE] = ACTIONS(2579),
    [anon_sym_u_DQUOTE] = ACTIONS(2579),
    [anon_sym_U_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8_DQUOTE] = ACTIONS(2579),
    [anon_sym_DQUOTE] = ACTIONS(2579),
    [sym_true] = ACTIONS(2577),
    [sym_false] = ACTIONS(2577),
    [anon_sym_NULL] = ACTIONS(2577),
    [anon_sym_nullptr] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_try] = ACTIONS(2577),
    [anon_sym_delete] = ACTIONS(2577),
    [anon_sym_throw] = ACTIONS(2577),
    [anon_sym_namespace] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_concept] = ACTIONS(2577),
    [anon_sym_co_return] = ACTIONS(2577),
    [anon_sym_co_yield] = ACTIONS(2577),
    [anon_sym_R_DQUOTE] = ACTIONS(2579),
    [anon_sym_LR_DQUOTE] = ACTIONS(2579),
    [anon_sym_uR_DQUOTE] = ACTIONS(2579),
    [anon_sym_UR_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2579),
    [anon_sym_co_await] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(2577),
    [anon_sym_requires] = ACTIONS(2577),
    [sym_this] = ACTIONS(2577),
    [anon_sym___launch_bounds__] = ACTIONS(2577),
  },
  [STATE(589)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_include_token1] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token2] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym___cdecl] = ACTIONS(2585),
    [anon_sym___clrcall] = ACTIONS(2585),
    [anon_sym___stdcall] = ACTIONS(2585),
    [anon_sym___fastcall] = ACTIONS(2585),
    [anon_sym___thiscall] = ACTIONS(2585),
    [anon_sym___vectorcall] = ACTIONS(2585),
    [anon_sym_LBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_switch] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_default] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_do] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_return] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_goto] = ACTIONS(2585),
    [anon_sym___try] = ACTIONS(2585),
    [anon_sym___leave] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_compl] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2587),
    [anon_sym_sizeof] = ACTIONS(2585),
    [anon_sym___alignof__] = ACTIONS(2585),
    [anon_sym___alignof] = ACTIONS(2585),
    [anon_sym__alignof] = ACTIONS(2585),
    [anon_sym_alignof] = ACTIONS(2585),
    [anon_sym__Alignof] = ACTIONS(2585),
    [anon_sym_offsetof] = ACTIONS(2585),
    [anon_sym__Generic] = ACTIONS(2585),
    [anon_sym_asm] = ACTIONS(2585),
    [anon_sym___asm__] = ACTIONS(2585),
    [anon_sym___asm] = ACTIONS(2585),
    [sym_number_literal] = ACTIONS(2587),
    [anon_sym_L_SQUOTE] = ACTIONS(2587),
    [anon_sym_u_SQUOTE] = ACTIONS(2587),
    [anon_sym_U_SQUOTE] = ACTIONS(2587),
    [anon_sym_u8_SQUOTE] = ACTIONS(2587),
    [anon_sym_SQUOTE] = ACTIONS(2587),
    [anon_sym_L_DQUOTE] = ACTIONS(2587),
    [anon_sym_u_DQUOTE] = ACTIONS(2587),
    [anon_sym_U_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8_DQUOTE] = ACTIONS(2587),
    [anon_sym_DQUOTE] = ACTIONS(2587),
    [sym_true] = ACTIONS(2585),
    [sym_false] = ACTIONS(2585),
    [anon_sym_NULL] = ACTIONS(2585),
    [anon_sym_nullptr] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_try] = ACTIONS(2585),
    [anon_sym_delete] = ACTIONS(2585),
    [anon_sym_throw] = ACTIONS(2585),
    [anon_sym_namespace] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym_concept] = ACTIONS(2585),
    [anon_sym_co_return] = ACTIONS(2585),
    [anon_sym_co_yield] = ACTIONS(2585),
    [anon_sym_R_DQUOTE] = ACTIONS(2587),
    [anon_sym_LR_DQUOTE] = ACTIONS(2587),
    [anon_sym_uR_DQUOTE] = ACTIONS(2587),
    [anon_sym_UR_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2587),
    [anon_sym_co_await] = ACTIONS(2585),
    [anon_sym_new] = ACTIONS(2585),
    [anon_sym_requires] = ACTIONS(2585),
    [sym_this] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(590)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_include_token1] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token2] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym___cdecl] = ACTIONS(2585),
    [anon_sym___clrcall] = ACTIONS(2585),
    [anon_sym___stdcall] = ACTIONS(2585),
    [anon_sym___fastcall] = ACTIONS(2585),
    [anon_sym___thiscall] = ACTIONS(2585),
    [anon_sym___vectorcall] = ACTIONS(2585),
    [anon_sym_LBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_switch] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_default] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_do] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_return] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_goto] = ACTIONS(2585),
    [anon_sym___try] = ACTIONS(2585),
    [anon_sym___leave] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_compl] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2587),
    [anon_sym_sizeof] = ACTIONS(2585),
    [anon_sym___alignof__] = ACTIONS(2585),
    [anon_sym___alignof] = ACTIONS(2585),
    [anon_sym__alignof] = ACTIONS(2585),
    [anon_sym_alignof] = ACTIONS(2585),
    [anon_sym__Alignof] = ACTIONS(2585),
    [anon_sym_offsetof] = ACTIONS(2585),
    [anon_sym__Generic] = ACTIONS(2585),
    [anon_sym_asm] = ACTIONS(2585),
    [anon_sym___asm__] = ACTIONS(2585),
    [anon_sym___asm] = ACTIONS(2585),
    [sym_number_literal] = ACTIONS(2587),
    [anon_sym_L_SQUOTE] = ACTIONS(2587),
    [anon_sym_u_SQUOTE] = ACTIONS(2587),
    [anon_sym_U_SQUOTE] = ACTIONS(2587),
    [anon_sym_u8_SQUOTE] = ACTIONS(2587),
    [anon_sym_SQUOTE] = ACTIONS(2587),
    [anon_sym_L_DQUOTE] = ACTIONS(2587),
    [anon_sym_u_DQUOTE] = ACTIONS(2587),
    [anon_sym_U_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8_DQUOTE] = ACTIONS(2587),
    [anon_sym_DQUOTE] = ACTIONS(2587),
    [sym_true] = ACTIONS(2585),
    [sym_false] = ACTIONS(2585),
    [anon_sym_NULL] = ACTIONS(2585),
    [anon_sym_nullptr] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_try] = ACTIONS(2585),
    [anon_sym_delete] = ACTIONS(2585),
    [anon_sym_throw] = ACTIONS(2585),
    [anon_sym_namespace] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym_concept] = ACTIONS(2585),
    [anon_sym_co_return] = ACTIONS(2585),
    [anon_sym_co_yield] = ACTIONS(2585),
    [anon_sym_R_DQUOTE] = ACTIONS(2587),
    [anon_sym_LR_DQUOTE] = ACTIONS(2587),
    [anon_sym_uR_DQUOTE] = ACTIONS(2587),
    [anon_sym_UR_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2587),
    [anon_sym_co_await] = ACTIONS(2585),
    [anon_sym_new] = ACTIONS(2585),
    [anon_sym_requires] = ACTIONS(2585),
    [sym_this] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(591)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4962),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7516),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7819),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2948),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(592)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [anon_sym___asm] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(593)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [anon_sym___asm] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(594)] = {
    [sym_identifier] = ACTIONS(2569),
    [aux_sym_preproc_include_token1] = ACTIONS(2569),
    [aux_sym_preproc_def_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2569),
    [sym_preproc_directive] = ACTIONS(2569),
    [anon_sym_LPAREN2] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2571),
    [anon_sym_TILDE] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2571),
    [anon_sym_AMP_AMP] = ACTIONS(2571),
    [anon_sym_AMP] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym___extension__] = ACTIONS(2569),
    [anon_sym_typedef] = ACTIONS(2569),
    [anon_sym___device__] = ACTIONS(2569),
    [anon_sym___host__] = ACTIONS(2569),
    [anon_sym___global__] = ACTIONS(2569),
    [anon_sym___forceinline__] = ACTIONS(2569),
    [anon_sym___noinline__] = ACTIONS(2569),
    [anon_sym_virtual] = ACTIONS(2569),
    [anon_sym_extern] = ACTIONS(2569),
    [anon_sym___attribute__] = ACTIONS(2569),
    [anon_sym___attribute] = ACTIONS(2569),
    [anon_sym_COLON_COLON] = ACTIONS(2571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2571),
    [anon_sym___declspec] = ACTIONS(2569),
    [anon_sym___based] = ACTIONS(2569),
    [anon_sym___cdecl] = ACTIONS(2569),
    [anon_sym___clrcall] = ACTIONS(2569),
    [anon_sym___stdcall] = ACTIONS(2569),
    [anon_sym___fastcall] = ACTIONS(2569),
    [anon_sym___thiscall] = ACTIONS(2569),
    [anon_sym___vectorcall] = ACTIONS(2569),
    [anon_sym_LBRACE] = ACTIONS(2571),
    [anon_sym_RBRACE] = ACTIONS(2571),
    [anon_sym_signed] = ACTIONS(2569),
    [anon_sym_unsigned] = ACTIONS(2569),
    [anon_sym_long] = ACTIONS(2569),
    [anon_sym_short] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2569),
    [anon_sym_register] = ACTIONS(2569),
    [anon_sym_inline] = ACTIONS(2569),
    [anon_sym___inline] = ACTIONS(2569),
    [anon_sym___inline__] = ACTIONS(2569),
    [anon_sym___forceinline] = ACTIONS(2569),
    [anon_sym_thread_local] = ACTIONS(2569),
    [anon_sym___thread] = ACTIONS(2569),
    [anon_sym_const] = ACTIONS(2569),
    [anon_sym_constexpr] = ACTIONS(2569),
    [anon_sym_volatile] = ACTIONS(2569),
    [anon_sym_restrict] = ACTIONS(2569),
    [anon_sym___restrict__] = ACTIONS(2569),
    [anon_sym__Atomic] = ACTIONS(2569),
    [anon_sym__Noreturn] = ACTIONS(2569),
    [anon_sym_noreturn] = ACTIONS(2569),
    [anon_sym__Nonnull] = ACTIONS(2569),
    [anon_sym_mutable] = ACTIONS(2569),
    [anon_sym_constinit] = ACTIONS(2569),
    [anon_sym_consteval] = ACTIONS(2569),
    [anon_sym___shared__] = ACTIONS(2569),
    [anon_sym___local__] = ACTIONS(2569),
    [anon_sym___constant__] = ACTIONS(2569),
    [anon_sym___managed__] = ACTIONS(2569),
    [anon_sym___grid_constant__] = ACTIONS(2569),
    [anon_sym_alignas] = ACTIONS(2569),
    [anon_sym__Alignas] = ACTIONS(2569),
    [sym_primitive_type] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2569),
    [anon_sym_struct] = ACTIONS(2569),
    [anon_sym_union] = ACTIONS(2569),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_switch] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_default] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_do] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_return] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_goto] = ACTIONS(2569),
    [anon_sym___try] = ACTIONS(2569),
    [anon_sym___leave] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_compl] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2571),
    [anon_sym_sizeof] = ACTIONS(2569),
    [anon_sym___alignof__] = ACTIONS(2569),
    [anon_sym___alignof] = ACTIONS(2569),
    [anon_sym__alignof] = ACTIONS(2569),
    [anon_sym_alignof] = ACTIONS(2569),
    [anon_sym__Alignof] = ACTIONS(2569),
    [anon_sym_offsetof] = ACTIONS(2569),
    [anon_sym__Generic] = ACTIONS(2569),
    [anon_sym_asm] = ACTIONS(2569),
    [anon_sym___asm__] = ACTIONS(2569),
    [anon_sym___asm] = ACTIONS(2569),
    [sym_number_literal] = ACTIONS(2571),
    [anon_sym_L_SQUOTE] = ACTIONS(2571),
    [anon_sym_u_SQUOTE] = ACTIONS(2571),
    [anon_sym_U_SQUOTE] = ACTIONS(2571),
    [anon_sym_u8_SQUOTE] = ACTIONS(2571),
    [anon_sym_SQUOTE] = ACTIONS(2571),
    [anon_sym_L_DQUOTE] = ACTIONS(2571),
    [anon_sym_u_DQUOTE] = ACTIONS(2571),
    [anon_sym_U_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8_DQUOTE] = ACTIONS(2571),
    [anon_sym_DQUOTE] = ACTIONS(2571),
    [sym_true] = ACTIONS(2569),
    [sym_false] = ACTIONS(2569),
    [anon_sym_NULL] = ACTIONS(2569),
    [anon_sym_nullptr] = ACTIONS(2569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2569),
    [anon_sym_decltype] = ACTIONS(2569),
    [anon_sym_explicit] = ACTIONS(2569),
    [anon_sym_typename] = ACTIONS(2569),
    [anon_sym_template] = ACTIONS(2569),
    [anon_sym_operator] = ACTIONS(2569),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_delete] = ACTIONS(2569),
    [anon_sym_throw] = ACTIONS(2569),
    [anon_sym_namespace] = ACTIONS(2569),
    [anon_sym_using] = ACTIONS(2569),
    [anon_sym_static_assert] = ACTIONS(2569),
    [anon_sym_concept] = ACTIONS(2569),
    [anon_sym_co_return] = ACTIONS(2569),
    [anon_sym_co_yield] = ACTIONS(2569),
    [anon_sym_R_DQUOTE] = ACTIONS(2571),
    [anon_sym_LR_DQUOTE] = ACTIONS(2571),
    [anon_sym_uR_DQUOTE] = ACTIONS(2571),
    [anon_sym_UR_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2571),
    [anon_sym_co_await] = ACTIONS(2569),
    [anon_sym_new] = ACTIONS(2569),
    [anon_sym_requires] = ACTIONS(2569),
    [sym_this] = ACTIONS(2569),
    [anon_sym___launch_bounds__] = ACTIONS(2569),
  },
  [STATE(595)] = {
    [sym_identifier] = ACTIONS(2581),
    [aux_sym_preproc_include_token1] = ACTIONS(2581),
    [aux_sym_preproc_def_token1] = ACTIONS(2581),
    [aux_sym_preproc_if_token1] = ACTIONS(2581),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2581),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2581),
    [sym_preproc_directive] = ACTIONS(2581),
    [anon_sym_LPAREN2] = ACTIONS(2583),
    [anon_sym_BANG] = ACTIONS(2583),
    [anon_sym_TILDE] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2583),
    [anon_sym_AMP_AMP] = ACTIONS(2583),
    [anon_sym_AMP] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym___extension__] = ACTIONS(2581),
    [anon_sym_typedef] = ACTIONS(2581),
    [anon_sym___device__] = ACTIONS(2581),
    [anon_sym___host__] = ACTIONS(2581),
    [anon_sym___global__] = ACTIONS(2581),
    [anon_sym___forceinline__] = ACTIONS(2581),
    [anon_sym___noinline__] = ACTIONS(2581),
    [anon_sym_virtual] = ACTIONS(2581),
    [anon_sym_extern] = ACTIONS(2581),
    [anon_sym___attribute__] = ACTIONS(2581),
    [anon_sym___attribute] = ACTIONS(2581),
    [anon_sym_COLON_COLON] = ACTIONS(2583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2583),
    [anon_sym___declspec] = ACTIONS(2581),
    [anon_sym___based] = ACTIONS(2581),
    [anon_sym___cdecl] = ACTIONS(2581),
    [anon_sym___clrcall] = ACTIONS(2581),
    [anon_sym___stdcall] = ACTIONS(2581),
    [anon_sym___fastcall] = ACTIONS(2581),
    [anon_sym___thiscall] = ACTIONS(2581),
    [anon_sym___vectorcall] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_RBRACE] = ACTIONS(2583),
    [anon_sym_signed] = ACTIONS(2581),
    [anon_sym_unsigned] = ACTIONS(2581),
    [anon_sym_long] = ACTIONS(2581),
    [anon_sym_short] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2581),
    [anon_sym_static] = ACTIONS(2581),
    [anon_sym_register] = ACTIONS(2581),
    [anon_sym_inline] = ACTIONS(2581),
    [anon_sym___inline] = ACTIONS(2581),
    [anon_sym___inline__] = ACTIONS(2581),
    [anon_sym___forceinline] = ACTIONS(2581),
    [anon_sym_thread_local] = ACTIONS(2581),
    [anon_sym___thread] = ACTIONS(2581),
    [anon_sym_const] = ACTIONS(2581),
    [anon_sym_constexpr] = ACTIONS(2581),
    [anon_sym_volatile] = ACTIONS(2581),
    [anon_sym_restrict] = ACTIONS(2581),
    [anon_sym___restrict__] = ACTIONS(2581),
    [anon_sym__Atomic] = ACTIONS(2581),
    [anon_sym__Noreturn] = ACTIONS(2581),
    [anon_sym_noreturn] = ACTIONS(2581),
    [anon_sym__Nonnull] = ACTIONS(2581),
    [anon_sym_mutable] = ACTIONS(2581),
    [anon_sym_constinit] = ACTIONS(2581),
    [anon_sym_consteval] = ACTIONS(2581),
    [anon_sym___shared__] = ACTIONS(2581),
    [anon_sym___local__] = ACTIONS(2581),
    [anon_sym___constant__] = ACTIONS(2581),
    [anon_sym___managed__] = ACTIONS(2581),
    [anon_sym___grid_constant__] = ACTIONS(2581),
    [anon_sym_alignas] = ACTIONS(2581),
    [anon_sym__Alignas] = ACTIONS(2581),
    [sym_primitive_type] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_class] = ACTIONS(2581),
    [anon_sym_struct] = ACTIONS(2581),
    [anon_sym_union] = ACTIONS(2581),
    [anon_sym_if] = ACTIONS(2581),
    [anon_sym_switch] = ACTIONS(2581),
    [anon_sym_case] = ACTIONS(2581),
    [anon_sym_default] = ACTIONS(2581),
    [anon_sym_while] = ACTIONS(2581),
    [anon_sym_do] = ACTIONS(2581),
    [anon_sym_for] = ACTIONS(2581),
    [anon_sym_return] = ACTIONS(2581),
    [anon_sym_break] = ACTIONS(2581),
    [anon_sym_continue] = ACTIONS(2581),
    [anon_sym_goto] = ACTIONS(2581),
    [anon_sym___try] = ACTIONS(2581),
    [anon_sym___leave] = ACTIONS(2581),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_compl] = ACTIONS(2581),
    [anon_sym_DASH_DASH] = ACTIONS(2583),
    [anon_sym_PLUS_PLUS] = ACTIONS(2583),
    [anon_sym_sizeof] = ACTIONS(2581),
    [anon_sym___alignof__] = ACTIONS(2581),
    [anon_sym___alignof] = ACTIONS(2581),
    [anon_sym__alignof] = ACTIONS(2581),
    [anon_sym_alignof] = ACTIONS(2581),
    [anon_sym__Alignof] = ACTIONS(2581),
    [anon_sym_offsetof] = ACTIONS(2581),
    [anon_sym__Generic] = ACTIONS(2581),
    [anon_sym_asm] = ACTIONS(2581),
    [anon_sym___asm__] = ACTIONS(2581),
    [anon_sym___asm] = ACTIONS(2581),
    [sym_number_literal] = ACTIONS(2583),
    [anon_sym_L_SQUOTE] = ACTIONS(2583),
    [anon_sym_u_SQUOTE] = ACTIONS(2583),
    [anon_sym_U_SQUOTE] = ACTIONS(2583),
    [anon_sym_u8_SQUOTE] = ACTIONS(2583),
    [anon_sym_SQUOTE] = ACTIONS(2583),
    [anon_sym_L_DQUOTE] = ACTIONS(2583),
    [anon_sym_u_DQUOTE] = ACTIONS(2583),
    [anon_sym_U_DQUOTE] = ACTIONS(2583),
    [anon_sym_u8_DQUOTE] = ACTIONS(2583),
    [anon_sym_DQUOTE] = ACTIONS(2583),
    [sym_true] = ACTIONS(2581),
    [sym_false] = ACTIONS(2581),
    [anon_sym_NULL] = ACTIONS(2581),
    [anon_sym_nullptr] = ACTIONS(2581),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2581),
    [anon_sym_decltype] = ACTIONS(2581),
    [anon_sym_explicit] = ACTIONS(2581),
    [anon_sym_typename] = ACTIONS(2581),
    [anon_sym_template] = ACTIONS(2581),
    [anon_sym_operator] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2581),
    [anon_sym_delete] = ACTIONS(2581),
    [anon_sym_throw] = ACTIONS(2581),
    [anon_sym_namespace] = ACTIONS(2581),
    [anon_sym_using] = ACTIONS(2581),
    [anon_sym_static_assert] = ACTIONS(2581),
    [anon_sym_concept] = ACTIONS(2581),
    [anon_sym_co_return] = ACTIONS(2581),
    [anon_sym_co_yield] = ACTIONS(2581),
    [anon_sym_R_DQUOTE] = ACTIONS(2583),
    [anon_sym_LR_DQUOTE] = ACTIONS(2583),
    [anon_sym_uR_DQUOTE] = ACTIONS(2583),
    [anon_sym_UR_DQUOTE] = ACTIONS(2583),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2583),
    [anon_sym_co_await] = ACTIONS(2581),
    [anon_sym_new] = ACTIONS(2581),
    [anon_sym_requires] = ACTIONS(2581),
    [sym_this] = ACTIONS(2581),
    [anon_sym___launch_bounds__] = ACTIONS(2581),
  },
  [STATE(596)] = {
    [sym_identifier] = ACTIONS(2595),
    [aux_sym_preproc_include_token1] = ACTIONS(2595),
    [aux_sym_preproc_def_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2595),
    [sym_preproc_directive] = ACTIONS(2595),
    [anon_sym_LPAREN2] = ACTIONS(2597),
    [anon_sym_BANG] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_DASH] = ACTIONS(2595),
    [anon_sym_PLUS] = ACTIONS(2595),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_AMP_AMP] = ACTIONS(2597),
    [anon_sym_AMP] = ACTIONS(2595),
    [anon_sym_SEMI] = ACTIONS(2597),
    [anon_sym___extension__] = ACTIONS(2595),
    [anon_sym_typedef] = ACTIONS(2595),
    [anon_sym___device__] = ACTIONS(2595),
    [anon_sym___host__] = ACTIONS(2595),
    [anon_sym___global__] = ACTIONS(2595),
    [anon_sym___forceinline__] = ACTIONS(2595),
    [anon_sym___noinline__] = ACTIONS(2595),
    [anon_sym_virtual] = ACTIONS(2595),
    [anon_sym_extern] = ACTIONS(2595),
    [anon_sym___attribute__] = ACTIONS(2595),
    [anon_sym___attribute] = ACTIONS(2595),
    [anon_sym_COLON_COLON] = ACTIONS(2597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2597),
    [anon_sym___declspec] = ACTIONS(2595),
    [anon_sym___based] = ACTIONS(2595),
    [anon_sym___cdecl] = ACTIONS(2595),
    [anon_sym___clrcall] = ACTIONS(2595),
    [anon_sym___stdcall] = ACTIONS(2595),
    [anon_sym___fastcall] = ACTIONS(2595),
    [anon_sym___thiscall] = ACTIONS(2595),
    [anon_sym___vectorcall] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_RBRACE] = ACTIONS(2597),
    [anon_sym_signed] = ACTIONS(2595),
    [anon_sym_unsigned] = ACTIONS(2595),
    [anon_sym_long] = ACTIONS(2595),
    [anon_sym_short] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_register] = ACTIONS(2595),
    [anon_sym_inline] = ACTIONS(2595),
    [anon_sym___inline] = ACTIONS(2595),
    [anon_sym___inline__] = ACTIONS(2595),
    [anon_sym___forceinline] = ACTIONS(2595),
    [anon_sym_thread_local] = ACTIONS(2595),
    [anon_sym___thread] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_constexpr] = ACTIONS(2595),
    [anon_sym_volatile] = ACTIONS(2595),
    [anon_sym_restrict] = ACTIONS(2595),
    [anon_sym___restrict__] = ACTIONS(2595),
    [anon_sym__Atomic] = ACTIONS(2595),
    [anon_sym__Noreturn] = ACTIONS(2595),
    [anon_sym_noreturn] = ACTIONS(2595),
    [anon_sym__Nonnull] = ACTIONS(2595),
    [anon_sym_mutable] = ACTIONS(2595),
    [anon_sym_constinit] = ACTIONS(2595),
    [anon_sym_consteval] = ACTIONS(2595),
    [anon_sym___shared__] = ACTIONS(2595),
    [anon_sym___local__] = ACTIONS(2595),
    [anon_sym___constant__] = ACTIONS(2595),
    [anon_sym___managed__] = ACTIONS(2595),
    [anon_sym___grid_constant__] = ACTIONS(2595),
    [anon_sym_alignas] = ACTIONS(2595),
    [anon_sym__Alignas] = ACTIONS(2595),
    [sym_primitive_type] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_struct] = ACTIONS(2595),
    [anon_sym_union] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2595),
    [anon_sym_switch] = ACTIONS(2595),
    [anon_sym_case] = ACTIONS(2595),
    [anon_sym_default] = ACTIONS(2595),
    [anon_sym_while] = ACTIONS(2595),
    [anon_sym_do] = ACTIONS(2595),
    [anon_sym_for] = ACTIONS(2595),
    [anon_sym_return] = ACTIONS(2595),
    [anon_sym_break] = ACTIONS(2595),
    [anon_sym_continue] = ACTIONS(2595),
    [anon_sym_goto] = ACTIONS(2595),
    [anon_sym___try] = ACTIONS(2595),
    [anon_sym___leave] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2595),
    [anon_sym_compl] = ACTIONS(2595),
    [anon_sym_DASH_DASH] = ACTIONS(2597),
    [anon_sym_PLUS_PLUS] = ACTIONS(2597),
    [anon_sym_sizeof] = ACTIONS(2595),
    [anon_sym___alignof__] = ACTIONS(2595),
    [anon_sym___alignof] = ACTIONS(2595),
    [anon_sym__alignof] = ACTIONS(2595),
    [anon_sym_alignof] = ACTIONS(2595),
    [anon_sym__Alignof] = ACTIONS(2595),
    [anon_sym_offsetof] = ACTIONS(2595),
    [anon_sym__Generic] = ACTIONS(2595),
    [anon_sym_asm] = ACTIONS(2595),
    [anon_sym___asm__] = ACTIONS(2595),
    [anon_sym___asm] = ACTIONS(2595),
    [sym_number_literal] = ACTIONS(2597),
    [anon_sym_L_SQUOTE] = ACTIONS(2597),
    [anon_sym_u_SQUOTE] = ACTIONS(2597),
    [anon_sym_U_SQUOTE] = ACTIONS(2597),
    [anon_sym_u8_SQUOTE] = ACTIONS(2597),
    [anon_sym_SQUOTE] = ACTIONS(2597),
    [anon_sym_L_DQUOTE] = ACTIONS(2597),
    [anon_sym_u_DQUOTE] = ACTIONS(2597),
    [anon_sym_U_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8_DQUOTE] = ACTIONS(2597),
    [anon_sym_DQUOTE] = ACTIONS(2597),
    [sym_true] = ACTIONS(2595),
    [sym_false] = ACTIONS(2595),
    [anon_sym_NULL] = ACTIONS(2595),
    [anon_sym_nullptr] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2595),
    [anon_sym_decltype] = ACTIONS(2595),
    [anon_sym_explicit] = ACTIONS(2595),
    [anon_sym_typename] = ACTIONS(2595),
    [anon_sym_template] = ACTIONS(2595),
    [anon_sym_operator] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2595),
    [anon_sym_delete] = ACTIONS(2595),
    [anon_sym_throw] = ACTIONS(2595),
    [anon_sym_namespace] = ACTIONS(2595),
    [anon_sym_using] = ACTIONS(2595),
    [anon_sym_static_assert] = ACTIONS(2595),
    [anon_sym_concept] = ACTIONS(2595),
    [anon_sym_co_return] = ACTIONS(2595),
    [anon_sym_co_yield] = ACTIONS(2595),
    [anon_sym_R_DQUOTE] = ACTIONS(2597),
    [anon_sym_LR_DQUOTE] = ACTIONS(2597),
    [anon_sym_uR_DQUOTE] = ACTIONS(2597),
    [anon_sym_UR_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2597),
    [anon_sym_co_await] = ACTIONS(2595),
    [anon_sym_new] = ACTIONS(2595),
    [anon_sym_requires] = ACTIONS(2595),
    [sym_this] = ACTIONS(2595),
    [anon_sym___launch_bounds__] = ACTIONS(2595),
  },
  [STATE(597)] = {
    [sym_identifier] = ACTIONS(2605),
    [aux_sym_preproc_include_token1] = ACTIONS(2605),
    [aux_sym_preproc_def_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2605),
    [sym_preproc_directive] = ACTIONS(2605),
    [anon_sym_LPAREN2] = ACTIONS(2607),
    [anon_sym_BANG] = ACTIONS(2607),
    [anon_sym_TILDE] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2607),
    [anon_sym_AMP_AMP] = ACTIONS(2607),
    [anon_sym_AMP] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2605),
    [anon_sym_typedef] = ACTIONS(2605),
    [anon_sym___device__] = ACTIONS(2605),
    [anon_sym___host__] = ACTIONS(2605),
    [anon_sym___global__] = ACTIONS(2605),
    [anon_sym___forceinline__] = ACTIONS(2605),
    [anon_sym___noinline__] = ACTIONS(2605),
    [anon_sym_virtual] = ACTIONS(2605),
    [anon_sym_extern] = ACTIONS(2605),
    [anon_sym___attribute__] = ACTIONS(2605),
    [anon_sym___attribute] = ACTIONS(2605),
    [anon_sym_COLON_COLON] = ACTIONS(2607),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2607),
    [anon_sym___declspec] = ACTIONS(2605),
    [anon_sym___based] = ACTIONS(2605),
    [anon_sym___cdecl] = ACTIONS(2605),
    [anon_sym___clrcall] = ACTIONS(2605),
    [anon_sym___stdcall] = ACTIONS(2605),
    [anon_sym___fastcall] = ACTIONS(2605),
    [anon_sym___thiscall] = ACTIONS(2605),
    [anon_sym___vectorcall] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(2607),
    [anon_sym_RBRACE] = ACTIONS(2607),
    [anon_sym_signed] = ACTIONS(2605),
    [anon_sym_unsigned] = ACTIONS(2605),
    [anon_sym_long] = ACTIONS(2605),
    [anon_sym_short] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2605),
    [anon_sym_static] = ACTIONS(2605),
    [anon_sym_register] = ACTIONS(2605),
    [anon_sym_inline] = ACTIONS(2605),
    [anon_sym___inline] = ACTIONS(2605),
    [anon_sym___inline__] = ACTIONS(2605),
    [anon_sym___forceinline] = ACTIONS(2605),
    [anon_sym_thread_local] = ACTIONS(2605),
    [anon_sym___thread] = ACTIONS(2605),
    [anon_sym_const] = ACTIONS(2605),
    [anon_sym_constexpr] = ACTIONS(2605),
    [anon_sym_volatile] = ACTIONS(2605),
    [anon_sym_restrict] = ACTIONS(2605),
    [anon_sym___restrict__] = ACTIONS(2605),
    [anon_sym__Atomic] = ACTIONS(2605),
    [anon_sym__Noreturn] = ACTIONS(2605),
    [anon_sym_noreturn] = ACTIONS(2605),
    [anon_sym__Nonnull] = ACTIONS(2605),
    [anon_sym_mutable] = ACTIONS(2605),
    [anon_sym_constinit] = ACTIONS(2605),
    [anon_sym_consteval] = ACTIONS(2605),
    [anon_sym___shared__] = ACTIONS(2605),
    [anon_sym___local__] = ACTIONS(2605),
    [anon_sym___constant__] = ACTIONS(2605),
    [anon_sym___managed__] = ACTIONS(2605),
    [anon_sym___grid_constant__] = ACTIONS(2605),
    [anon_sym_alignas] = ACTIONS(2605),
    [anon_sym__Alignas] = ACTIONS(2605),
    [sym_primitive_type] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_class] = ACTIONS(2605),
    [anon_sym_struct] = ACTIONS(2605),
    [anon_sym_union] = ACTIONS(2605),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_switch] = ACTIONS(2605),
    [anon_sym_case] = ACTIONS(2605),
    [anon_sym_default] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(2605),
    [anon_sym_do] = ACTIONS(2605),
    [anon_sym_for] = ACTIONS(2605),
    [anon_sym_return] = ACTIONS(2605),
    [anon_sym_break] = ACTIONS(2605),
    [anon_sym_continue] = ACTIONS(2605),
    [anon_sym_goto] = ACTIONS(2605),
    [anon_sym___try] = ACTIONS(2605),
    [anon_sym___leave] = ACTIONS(2605),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_compl] = ACTIONS(2605),
    [anon_sym_DASH_DASH] = ACTIONS(2607),
    [anon_sym_PLUS_PLUS] = ACTIONS(2607),
    [anon_sym_sizeof] = ACTIONS(2605),
    [anon_sym___alignof__] = ACTIONS(2605),
    [anon_sym___alignof] = ACTIONS(2605),
    [anon_sym__alignof] = ACTIONS(2605),
    [anon_sym_alignof] = ACTIONS(2605),
    [anon_sym__Alignof] = ACTIONS(2605),
    [anon_sym_offsetof] = ACTIONS(2605),
    [anon_sym__Generic] = ACTIONS(2605),
    [anon_sym_asm] = ACTIONS(2605),
    [anon_sym___asm__] = ACTIONS(2605),
    [anon_sym___asm] = ACTIONS(2605),
    [sym_number_literal] = ACTIONS(2607),
    [anon_sym_L_SQUOTE] = ACTIONS(2607),
    [anon_sym_u_SQUOTE] = ACTIONS(2607),
    [anon_sym_U_SQUOTE] = ACTIONS(2607),
    [anon_sym_u8_SQUOTE] = ACTIONS(2607),
    [anon_sym_SQUOTE] = ACTIONS(2607),
    [anon_sym_L_DQUOTE] = ACTIONS(2607),
    [anon_sym_u_DQUOTE] = ACTIONS(2607),
    [anon_sym_U_DQUOTE] = ACTIONS(2607),
    [anon_sym_u8_DQUOTE] = ACTIONS(2607),
    [anon_sym_DQUOTE] = ACTIONS(2607),
    [sym_true] = ACTIONS(2605),
    [sym_false] = ACTIONS(2605),
    [anon_sym_NULL] = ACTIONS(2605),
    [anon_sym_nullptr] = ACTIONS(2605),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2605),
    [anon_sym_decltype] = ACTIONS(2605),
    [anon_sym_explicit] = ACTIONS(2605),
    [anon_sym_typename] = ACTIONS(2605),
    [anon_sym_template] = ACTIONS(2605),
    [anon_sym_operator] = ACTIONS(2605),
    [anon_sym_try] = ACTIONS(2605),
    [anon_sym_delete] = ACTIONS(2605),
    [anon_sym_throw] = ACTIONS(2605),
    [anon_sym_namespace] = ACTIONS(2605),
    [anon_sym_using] = ACTIONS(2605),
    [anon_sym_static_assert] = ACTIONS(2605),
    [anon_sym_concept] = ACTIONS(2605),
    [anon_sym_co_return] = ACTIONS(2605),
    [anon_sym_co_yield] = ACTIONS(2605),
    [anon_sym_R_DQUOTE] = ACTIONS(2607),
    [anon_sym_LR_DQUOTE] = ACTIONS(2607),
    [anon_sym_uR_DQUOTE] = ACTIONS(2607),
    [anon_sym_UR_DQUOTE] = ACTIONS(2607),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2607),
    [anon_sym_co_await] = ACTIONS(2605),
    [anon_sym_new] = ACTIONS(2605),
    [anon_sym_requires] = ACTIONS(2605),
    [sym_this] = ACTIONS(2605),
    [anon_sym___launch_bounds__] = ACTIONS(2605),
  },
  [STATE(598)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4935),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7569),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8062),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2950),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(599)] = {
    [sym_identifier] = ACTIONS(2613),
    [aux_sym_preproc_include_token1] = ACTIONS(2613),
    [aux_sym_preproc_def_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2613),
    [sym_preproc_directive] = ACTIONS(2613),
    [anon_sym_LPAREN2] = ACTIONS(2615),
    [anon_sym_BANG] = ACTIONS(2615),
    [anon_sym_TILDE] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2615),
    [anon_sym_AMP_AMP] = ACTIONS(2615),
    [anon_sym_AMP] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym___extension__] = ACTIONS(2613),
    [anon_sym_typedef] = ACTIONS(2613),
    [anon_sym___device__] = ACTIONS(2613),
    [anon_sym___host__] = ACTIONS(2613),
    [anon_sym___global__] = ACTIONS(2613),
    [anon_sym___forceinline__] = ACTIONS(2613),
    [anon_sym___noinline__] = ACTIONS(2613),
    [anon_sym_virtual] = ACTIONS(2613),
    [anon_sym_extern] = ACTIONS(2613),
    [anon_sym___attribute__] = ACTIONS(2613),
    [anon_sym___attribute] = ACTIONS(2613),
    [anon_sym_COLON_COLON] = ACTIONS(2615),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2615),
    [anon_sym___declspec] = ACTIONS(2613),
    [anon_sym___based] = ACTIONS(2613),
    [anon_sym___cdecl] = ACTIONS(2613),
    [anon_sym___clrcall] = ACTIONS(2613),
    [anon_sym___stdcall] = ACTIONS(2613),
    [anon_sym___fastcall] = ACTIONS(2613),
    [anon_sym___thiscall] = ACTIONS(2613),
    [anon_sym___vectorcall] = ACTIONS(2613),
    [anon_sym_LBRACE] = ACTIONS(2615),
    [anon_sym_RBRACE] = ACTIONS(2615),
    [anon_sym_signed] = ACTIONS(2613),
    [anon_sym_unsigned] = ACTIONS(2613),
    [anon_sym_long] = ACTIONS(2613),
    [anon_sym_short] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2613),
    [anon_sym_static] = ACTIONS(2613),
    [anon_sym_register] = ACTIONS(2613),
    [anon_sym_inline] = ACTIONS(2613),
    [anon_sym___inline] = ACTIONS(2613),
    [anon_sym___inline__] = ACTIONS(2613),
    [anon_sym___forceinline] = ACTIONS(2613),
    [anon_sym_thread_local] = ACTIONS(2613),
    [anon_sym___thread] = ACTIONS(2613),
    [anon_sym_const] = ACTIONS(2613),
    [anon_sym_constexpr] = ACTIONS(2613),
    [anon_sym_volatile] = ACTIONS(2613),
    [anon_sym_restrict] = ACTIONS(2613),
    [anon_sym___restrict__] = ACTIONS(2613),
    [anon_sym__Atomic] = ACTIONS(2613),
    [anon_sym__Noreturn] = ACTIONS(2613),
    [anon_sym_noreturn] = ACTIONS(2613),
    [anon_sym__Nonnull] = ACTIONS(2613),
    [anon_sym_mutable] = ACTIONS(2613),
    [anon_sym_constinit] = ACTIONS(2613),
    [anon_sym_consteval] = ACTIONS(2613),
    [anon_sym___shared__] = ACTIONS(2613),
    [anon_sym___local__] = ACTIONS(2613),
    [anon_sym___constant__] = ACTIONS(2613),
    [anon_sym___managed__] = ACTIONS(2613),
    [anon_sym___grid_constant__] = ACTIONS(2613),
    [anon_sym_alignas] = ACTIONS(2613),
    [anon_sym__Alignas] = ACTIONS(2613),
    [sym_primitive_type] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_class] = ACTIONS(2613),
    [anon_sym_struct] = ACTIONS(2613),
    [anon_sym_union] = ACTIONS(2613),
    [anon_sym_if] = ACTIONS(2613),
    [anon_sym_switch] = ACTIONS(2613),
    [anon_sym_case] = ACTIONS(2613),
    [anon_sym_default] = ACTIONS(2613),
    [anon_sym_while] = ACTIONS(2613),
    [anon_sym_do] = ACTIONS(2613),
    [anon_sym_for] = ACTIONS(2613),
    [anon_sym_return] = ACTIONS(2613),
    [anon_sym_break] = ACTIONS(2613),
    [anon_sym_continue] = ACTIONS(2613),
    [anon_sym_goto] = ACTIONS(2613),
    [anon_sym___try] = ACTIONS(2613),
    [anon_sym___leave] = ACTIONS(2613),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_compl] = ACTIONS(2613),
    [anon_sym_DASH_DASH] = ACTIONS(2615),
    [anon_sym_PLUS_PLUS] = ACTIONS(2615),
    [anon_sym_sizeof] = ACTIONS(2613),
    [anon_sym___alignof__] = ACTIONS(2613),
    [anon_sym___alignof] = ACTIONS(2613),
    [anon_sym__alignof] = ACTIONS(2613),
    [anon_sym_alignof] = ACTIONS(2613),
    [anon_sym__Alignof] = ACTIONS(2613),
    [anon_sym_offsetof] = ACTIONS(2613),
    [anon_sym__Generic] = ACTIONS(2613),
    [anon_sym_asm] = ACTIONS(2613),
    [anon_sym___asm__] = ACTIONS(2613),
    [anon_sym___asm] = ACTIONS(2613),
    [sym_number_literal] = ACTIONS(2615),
    [anon_sym_L_SQUOTE] = ACTIONS(2615),
    [anon_sym_u_SQUOTE] = ACTIONS(2615),
    [anon_sym_U_SQUOTE] = ACTIONS(2615),
    [anon_sym_u8_SQUOTE] = ACTIONS(2615),
    [anon_sym_SQUOTE] = ACTIONS(2615),
    [anon_sym_L_DQUOTE] = ACTIONS(2615),
    [anon_sym_u_DQUOTE] = ACTIONS(2615),
    [anon_sym_U_DQUOTE] = ACTIONS(2615),
    [anon_sym_u8_DQUOTE] = ACTIONS(2615),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_true] = ACTIONS(2613),
    [sym_false] = ACTIONS(2613),
    [anon_sym_NULL] = ACTIONS(2613),
    [anon_sym_nullptr] = ACTIONS(2613),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2613),
    [anon_sym_decltype] = ACTIONS(2613),
    [anon_sym_explicit] = ACTIONS(2613),
    [anon_sym_typename] = ACTIONS(2613),
    [anon_sym_template] = ACTIONS(2613),
    [anon_sym_operator] = ACTIONS(2613),
    [anon_sym_try] = ACTIONS(2613),
    [anon_sym_delete] = ACTIONS(2613),
    [anon_sym_throw] = ACTIONS(2613),
    [anon_sym_namespace] = ACTIONS(2613),
    [anon_sym_using] = ACTIONS(2613),
    [anon_sym_static_assert] = ACTIONS(2613),
    [anon_sym_concept] = ACTIONS(2613),
    [anon_sym_co_return] = ACTIONS(2613),
    [anon_sym_co_yield] = ACTIONS(2613),
    [anon_sym_R_DQUOTE] = ACTIONS(2615),
    [anon_sym_LR_DQUOTE] = ACTIONS(2615),
    [anon_sym_uR_DQUOTE] = ACTIONS(2615),
    [anon_sym_UR_DQUOTE] = ACTIONS(2615),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2615),
    [anon_sym_co_await] = ACTIONS(2613),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_requires] = ACTIONS(2613),
    [sym_this] = ACTIONS(2613),
    [anon_sym___launch_bounds__] = ACTIONS(2613),
  },
  [STATE(600)] = {
    [sym_identifier] = ACTIONS(2457),
    [aux_sym_preproc_include_token1] = ACTIONS(2457),
    [aux_sym_preproc_def_token1] = ACTIONS(2457),
    [aux_sym_preproc_if_token1] = ACTIONS(2457),
    [aux_sym_preproc_if_token2] = ACTIONS(2457),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2457),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2457),
    [sym_preproc_directive] = ACTIONS(2457),
    [anon_sym_LPAREN2] = ACTIONS(2459),
    [anon_sym_BANG] = ACTIONS(2459),
    [anon_sym_TILDE] = ACTIONS(2459),
    [anon_sym_DASH] = ACTIONS(2457),
    [anon_sym_PLUS] = ACTIONS(2457),
    [anon_sym_STAR] = ACTIONS(2459),
    [anon_sym_AMP_AMP] = ACTIONS(2459),
    [anon_sym_AMP] = ACTIONS(2457),
    [anon_sym_SEMI] = ACTIONS(2459),
    [anon_sym___extension__] = ACTIONS(2457),
    [anon_sym_typedef] = ACTIONS(2457),
    [anon_sym___device__] = ACTIONS(2457),
    [anon_sym___host__] = ACTIONS(2457),
    [anon_sym___global__] = ACTIONS(2457),
    [anon_sym___forceinline__] = ACTIONS(2457),
    [anon_sym___noinline__] = ACTIONS(2457),
    [anon_sym_virtual] = ACTIONS(2457),
    [anon_sym_extern] = ACTIONS(2457),
    [anon_sym___attribute__] = ACTIONS(2457),
    [anon_sym___attribute] = ACTIONS(2457),
    [anon_sym_COLON_COLON] = ACTIONS(2459),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2459),
    [anon_sym___declspec] = ACTIONS(2457),
    [anon_sym___based] = ACTIONS(2457),
    [anon_sym___cdecl] = ACTIONS(2457),
    [anon_sym___clrcall] = ACTIONS(2457),
    [anon_sym___stdcall] = ACTIONS(2457),
    [anon_sym___fastcall] = ACTIONS(2457),
    [anon_sym___thiscall] = ACTIONS(2457),
    [anon_sym___vectorcall] = ACTIONS(2457),
    [anon_sym_LBRACE] = ACTIONS(2459),
    [anon_sym_signed] = ACTIONS(2457),
    [anon_sym_unsigned] = ACTIONS(2457),
    [anon_sym_long] = ACTIONS(2457),
    [anon_sym_short] = ACTIONS(2457),
    [anon_sym_LBRACK] = ACTIONS(2457),
    [anon_sym_static] = ACTIONS(2457),
    [anon_sym_register] = ACTIONS(2457),
    [anon_sym_inline] = ACTIONS(2457),
    [anon_sym___inline] = ACTIONS(2457),
    [anon_sym___inline__] = ACTIONS(2457),
    [anon_sym___forceinline] = ACTIONS(2457),
    [anon_sym_thread_local] = ACTIONS(2457),
    [anon_sym___thread] = ACTIONS(2457),
    [anon_sym_const] = ACTIONS(2457),
    [anon_sym_constexpr] = ACTIONS(2457),
    [anon_sym_volatile] = ACTIONS(2457),
    [anon_sym_restrict] = ACTIONS(2457),
    [anon_sym___restrict__] = ACTIONS(2457),
    [anon_sym__Atomic] = ACTIONS(2457),
    [anon_sym__Noreturn] = ACTIONS(2457),
    [anon_sym_noreturn] = ACTIONS(2457),
    [anon_sym__Nonnull] = ACTIONS(2457),
    [anon_sym_mutable] = ACTIONS(2457),
    [anon_sym_constinit] = ACTIONS(2457),
    [anon_sym_consteval] = ACTIONS(2457),
    [anon_sym___shared__] = ACTIONS(2457),
    [anon_sym___local__] = ACTIONS(2457),
    [anon_sym___constant__] = ACTIONS(2457),
    [anon_sym___managed__] = ACTIONS(2457),
    [anon_sym___grid_constant__] = ACTIONS(2457),
    [anon_sym_alignas] = ACTIONS(2457),
    [anon_sym__Alignas] = ACTIONS(2457),
    [sym_primitive_type] = ACTIONS(2457),
    [anon_sym_enum] = ACTIONS(2457),
    [anon_sym_class] = ACTIONS(2457),
    [anon_sym_struct] = ACTIONS(2457),
    [anon_sym_union] = ACTIONS(2457),
    [anon_sym_if] = ACTIONS(2457),
    [anon_sym_switch] = ACTIONS(2457),
    [anon_sym_case] = ACTIONS(2457),
    [anon_sym_default] = ACTIONS(2457),
    [anon_sym_while] = ACTIONS(2457),
    [anon_sym_do] = ACTIONS(2457),
    [anon_sym_for] = ACTIONS(2457),
    [anon_sym_return] = ACTIONS(2457),
    [anon_sym_break] = ACTIONS(2457),
    [anon_sym_continue] = ACTIONS(2457),
    [anon_sym_goto] = ACTIONS(2457),
    [anon_sym___try] = ACTIONS(2457),
    [anon_sym___leave] = ACTIONS(2457),
    [anon_sym_not] = ACTIONS(2457),
    [anon_sym_compl] = ACTIONS(2457),
    [anon_sym_DASH_DASH] = ACTIONS(2459),
    [anon_sym_PLUS_PLUS] = ACTIONS(2459),
    [anon_sym_sizeof] = ACTIONS(2457),
    [anon_sym___alignof__] = ACTIONS(2457),
    [anon_sym___alignof] = ACTIONS(2457),
    [anon_sym__alignof] = ACTIONS(2457),
    [anon_sym_alignof] = ACTIONS(2457),
    [anon_sym__Alignof] = ACTIONS(2457),
    [anon_sym_offsetof] = ACTIONS(2457),
    [anon_sym__Generic] = ACTIONS(2457),
    [anon_sym_asm] = ACTIONS(2457),
    [anon_sym___asm__] = ACTIONS(2457),
    [anon_sym___asm] = ACTIONS(2457),
    [sym_number_literal] = ACTIONS(2459),
    [anon_sym_L_SQUOTE] = ACTIONS(2459),
    [anon_sym_u_SQUOTE] = ACTIONS(2459),
    [anon_sym_U_SQUOTE] = ACTIONS(2459),
    [anon_sym_u8_SQUOTE] = ACTIONS(2459),
    [anon_sym_SQUOTE] = ACTIONS(2459),
    [anon_sym_L_DQUOTE] = ACTIONS(2459),
    [anon_sym_u_DQUOTE] = ACTIONS(2459),
    [anon_sym_U_DQUOTE] = ACTIONS(2459),
    [anon_sym_u8_DQUOTE] = ACTIONS(2459),
    [anon_sym_DQUOTE] = ACTIONS(2459),
    [sym_true] = ACTIONS(2457),
    [sym_false] = ACTIONS(2457),
    [anon_sym_NULL] = ACTIONS(2457),
    [anon_sym_nullptr] = ACTIONS(2457),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2457),
    [anon_sym_decltype] = ACTIONS(2457),
    [anon_sym_explicit] = ACTIONS(2457),
    [anon_sym_typename] = ACTIONS(2457),
    [anon_sym_template] = ACTIONS(2457),
    [anon_sym_operator] = ACTIONS(2457),
    [anon_sym_try] = ACTIONS(2457),
    [anon_sym_delete] = ACTIONS(2457),
    [anon_sym_throw] = ACTIONS(2457),
    [anon_sym_namespace] = ACTIONS(2457),
    [anon_sym_using] = ACTIONS(2457),
    [anon_sym_static_assert] = ACTIONS(2457),
    [anon_sym_concept] = ACTIONS(2457),
    [anon_sym_co_return] = ACTIONS(2457),
    [anon_sym_co_yield] = ACTIONS(2457),
    [anon_sym_R_DQUOTE] = ACTIONS(2459),
    [anon_sym_LR_DQUOTE] = ACTIONS(2459),
    [anon_sym_uR_DQUOTE] = ACTIONS(2459),
    [anon_sym_UR_DQUOTE] = ACTIONS(2459),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2459),
    [anon_sym_co_await] = ACTIONS(2457),
    [anon_sym_new] = ACTIONS(2457),
    [anon_sym_requires] = ACTIONS(2457),
    [sym_this] = ACTIONS(2457),
    [anon_sym___launch_bounds__] = ACTIONS(2457),
  },
  [STATE(601)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_include_token1] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_BANG] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_DASH] = ACTIONS(2234),
    [anon_sym_PLUS] = ACTIONS(2234),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym___cdecl] = ACTIONS(2234),
    [anon_sym___clrcall] = ACTIONS(2234),
    [anon_sym___stdcall] = ACTIONS(2234),
    [anon_sym___fastcall] = ACTIONS(2234),
    [anon_sym___thiscall] = ACTIONS(2234),
    [anon_sym___vectorcall] = ACTIONS(2234),
    [anon_sym_LBRACE] = ACTIONS(2236),
    [anon_sym_RBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [anon_sym_if] = ACTIONS(2234),
    [anon_sym_switch] = ACTIONS(2234),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym_default] = ACTIONS(2234),
    [anon_sym_while] = ACTIONS(2234),
    [anon_sym_do] = ACTIONS(2234),
    [anon_sym_for] = ACTIONS(2234),
    [anon_sym_return] = ACTIONS(2234),
    [anon_sym_break] = ACTIONS(2234),
    [anon_sym_continue] = ACTIONS(2234),
    [anon_sym_goto] = ACTIONS(2234),
    [anon_sym___try] = ACTIONS(2234),
    [anon_sym___leave] = ACTIONS(2234),
    [anon_sym_not] = ACTIONS(2234),
    [anon_sym_compl] = ACTIONS(2234),
    [anon_sym_DASH_DASH] = ACTIONS(2236),
    [anon_sym_PLUS_PLUS] = ACTIONS(2236),
    [anon_sym_sizeof] = ACTIONS(2234),
    [anon_sym___alignof__] = ACTIONS(2234),
    [anon_sym___alignof] = ACTIONS(2234),
    [anon_sym__alignof] = ACTIONS(2234),
    [anon_sym_alignof] = ACTIONS(2234),
    [anon_sym__Alignof] = ACTIONS(2234),
    [anon_sym_offsetof] = ACTIONS(2234),
    [anon_sym__Generic] = ACTIONS(2234),
    [anon_sym_asm] = ACTIONS(2234),
    [anon_sym___asm__] = ACTIONS(2234),
    [anon_sym___asm] = ACTIONS(2234),
    [sym_number_literal] = ACTIONS(2236),
    [anon_sym_L_SQUOTE] = ACTIONS(2236),
    [anon_sym_u_SQUOTE] = ACTIONS(2236),
    [anon_sym_U_SQUOTE] = ACTIONS(2236),
    [anon_sym_u8_SQUOTE] = ACTIONS(2236),
    [anon_sym_SQUOTE] = ACTIONS(2236),
    [anon_sym_L_DQUOTE] = ACTIONS(2236),
    [anon_sym_u_DQUOTE] = ACTIONS(2236),
    [anon_sym_U_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8_DQUOTE] = ACTIONS(2236),
    [anon_sym_DQUOTE] = ACTIONS(2236),
    [sym_true] = ACTIONS(2234),
    [sym_false] = ACTIONS(2234),
    [anon_sym_NULL] = ACTIONS(2234),
    [anon_sym_nullptr] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_try] = ACTIONS(2234),
    [anon_sym_delete] = ACTIONS(2234),
    [anon_sym_throw] = ACTIONS(2234),
    [anon_sym_namespace] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym_concept] = ACTIONS(2234),
    [anon_sym_co_return] = ACTIONS(2234),
    [anon_sym_co_yield] = ACTIONS(2234),
    [anon_sym_R_DQUOTE] = ACTIONS(2236),
    [anon_sym_LR_DQUOTE] = ACTIONS(2236),
    [anon_sym_uR_DQUOTE] = ACTIONS(2236),
    [anon_sym_UR_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2236),
    [anon_sym_co_await] = ACTIONS(2234),
    [anon_sym_new] = ACTIONS(2234),
    [anon_sym_requires] = ACTIONS(2234),
    [sym_this] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(602)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_include_token1] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_BANG] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_DASH] = ACTIONS(2234),
    [anon_sym_PLUS] = ACTIONS(2234),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym___cdecl] = ACTIONS(2234),
    [anon_sym___clrcall] = ACTIONS(2234),
    [anon_sym___stdcall] = ACTIONS(2234),
    [anon_sym___fastcall] = ACTIONS(2234),
    [anon_sym___thiscall] = ACTIONS(2234),
    [anon_sym___vectorcall] = ACTIONS(2234),
    [anon_sym_LBRACE] = ACTIONS(2236),
    [anon_sym_RBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [anon_sym_if] = ACTIONS(2234),
    [anon_sym_switch] = ACTIONS(2234),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym_default] = ACTIONS(2234),
    [anon_sym_while] = ACTIONS(2234),
    [anon_sym_do] = ACTIONS(2234),
    [anon_sym_for] = ACTIONS(2234),
    [anon_sym_return] = ACTIONS(2234),
    [anon_sym_break] = ACTIONS(2234),
    [anon_sym_continue] = ACTIONS(2234),
    [anon_sym_goto] = ACTIONS(2234),
    [anon_sym___try] = ACTIONS(2234),
    [anon_sym___leave] = ACTIONS(2234),
    [anon_sym_not] = ACTIONS(2234),
    [anon_sym_compl] = ACTIONS(2234),
    [anon_sym_DASH_DASH] = ACTIONS(2236),
    [anon_sym_PLUS_PLUS] = ACTIONS(2236),
    [anon_sym_sizeof] = ACTIONS(2234),
    [anon_sym___alignof__] = ACTIONS(2234),
    [anon_sym___alignof] = ACTIONS(2234),
    [anon_sym__alignof] = ACTIONS(2234),
    [anon_sym_alignof] = ACTIONS(2234),
    [anon_sym__Alignof] = ACTIONS(2234),
    [anon_sym_offsetof] = ACTIONS(2234),
    [anon_sym__Generic] = ACTIONS(2234),
    [anon_sym_asm] = ACTIONS(2234),
    [anon_sym___asm__] = ACTIONS(2234),
    [anon_sym___asm] = ACTIONS(2234),
    [sym_number_literal] = ACTIONS(2236),
    [anon_sym_L_SQUOTE] = ACTIONS(2236),
    [anon_sym_u_SQUOTE] = ACTIONS(2236),
    [anon_sym_U_SQUOTE] = ACTIONS(2236),
    [anon_sym_u8_SQUOTE] = ACTIONS(2236),
    [anon_sym_SQUOTE] = ACTIONS(2236),
    [anon_sym_L_DQUOTE] = ACTIONS(2236),
    [anon_sym_u_DQUOTE] = ACTIONS(2236),
    [anon_sym_U_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8_DQUOTE] = ACTIONS(2236),
    [anon_sym_DQUOTE] = ACTIONS(2236),
    [sym_true] = ACTIONS(2234),
    [sym_false] = ACTIONS(2234),
    [anon_sym_NULL] = ACTIONS(2234),
    [anon_sym_nullptr] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_try] = ACTIONS(2234),
    [anon_sym_delete] = ACTIONS(2234),
    [anon_sym_throw] = ACTIONS(2234),
    [anon_sym_namespace] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym_concept] = ACTIONS(2234),
    [anon_sym_co_return] = ACTIONS(2234),
    [anon_sym_co_yield] = ACTIONS(2234),
    [anon_sym_R_DQUOTE] = ACTIONS(2236),
    [anon_sym_LR_DQUOTE] = ACTIONS(2236),
    [anon_sym_uR_DQUOTE] = ACTIONS(2236),
    [anon_sym_UR_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2236),
    [anon_sym_co_await] = ACTIONS(2234),
    [anon_sym_new] = ACTIONS(2234),
    [anon_sym_requires] = ACTIONS(2234),
    [sym_this] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(603)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4936),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7624),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7775),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2952),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(604)] = {
    [sym_identifier] = ACTIONS(2471),
    [aux_sym_preproc_include_token1] = ACTIONS(2471),
    [aux_sym_preproc_def_token1] = ACTIONS(2471),
    [aux_sym_preproc_if_token1] = ACTIONS(2471),
    [aux_sym_preproc_if_token2] = ACTIONS(2471),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2471),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2471),
    [sym_preproc_directive] = ACTIONS(2471),
    [anon_sym_LPAREN2] = ACTIONS(2473),
    [anon_sym_BANG] = ACTIONS(2473),
    [anon_sym_TILDE] = ACTIONS(2473),
    [anon_sym_DASH] = ACTIONS(2471),
    [anon_sym_PLUS] = ACTIONS(2471),
    [anon_sym_STAR] = ACTIONS(2473),
    [anon_sym_AMP_AMP] = ACTIONS(2473),
    [anon_sym_AMP] = ACTIONS(2471),
    [anon_sym_SEMI] = ACTIONS(2473),
    [anon_sym___extension__] = ACTIONS(2471),
    [anon_sym_typedef] = ACTIONS(2471),
    [anon_sym___device__] = ACTIONS(2471),
    [anon_sym___host__] = ACTIONS(2471),
    [anon_sym___global__] = ACTIONS(2471),
    [anon_sym___forceinline__] = ACTIONS(2471),
    [anon_sym___noinline__] = ACTIONS(2471),
    [anon_sym_virtual] = ACTIONS(2471),
    [anon_sym_extern] = ACTIONS(2471),
    [anon_sym___attribute__] = ACTIONS(2471),
    [anon_sym___attribute] = ACTIONS(2471),
    [anon_sym_COLON_COLON] = ACTIONS(2473),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2473),
    [anon_sym___declspec] = ACTIONS(2471),
    [anon_sym___based] = ACTIONS(2471),
    [anon_sym___cdecl] = ACTIONS(2471),
    [anon_sym___clrcall] = ACTIONS(2471),
    [anon_sym___stdcall] = ACTIONS(2471),
    [anon_sym___fastcall] = ACTIONS(2471),
    [anon_sym___thiscall] = ACTIONS(2471),
    [anon_sym___vectorcall] = ACTIONS(2471),
    [anon_sym_LBRACE] = ACTIONS(2473),
    [anon_sym_signed] = ACTIONS(2471),
    [anon_sym_unsigned] = ACTIONS(2471),
    [anon_sym_long] = ACTIONS(2471),
    [anon_sym_short] = ACTIONS(2471),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_static] = ACTIONS(2471),
    [anon_sym_register] = ACTIONS(2471),
    [anon_sym_inline] = ACTIONS(2471),
    [anon_sym___inline] = ACTIONS(2471),
    [anon_sym___inline__] = ACTIONS(2471),
    [anon_sym___forceinline] = ACTIONS(2471),
    [anon_sym_thread_local] = ACTIONS(2471),
    [anon_sym___thread] = ACTIONS(2471),
    [anon_sym_const] = ACTIONS(2471),
    [anon_sym_constexpr] = ACTIONS(2471),
    [anon_sym_volatile] = ACTIONS(2471),
    [anon_sym_restrict] = ACTIONS(2471),
    [anon_sym___restrict__] = ACTIONS(2471),
    [anon_sym__Atomic] = ACTIONS(2471),
    [anon_sym__Noreturn] = ACTIONS(2471),
    [anon_sym_noreturn] = ACTIONS(2471),
    [anon_sym__Nonnull] = ACTIONS(2471),
    [anon_sym_mutable] = ACTIONS(2471),
    [anon_sym_constinit] = ACTIONS(2471),
    [anon_sym_consteval] = ACTIONS(2471),
    [anon_sym___shared__] = ACTIONS(2471),
    [anon_sym___local__] = ACTIONS(2471),
    [anon_sym___constant__] = ACTIONS(2471),
    [anon_sym___managed__] = ACTIONS(2471),
    [anon_sym___grid_constant__] = ACTIONS(2471),
    [anon_sym_alignas] = ACTIONS(2471),
    [anon_sym__Alignas] = ACTIONS(2471),
    [sym_primitive_type] = ACTIONS(2471),
    [anon_sym_enum] = ACTIONS(2471),
    [anon_sym_class] = ACTIONS(2471),
    [anon_sym_struct] = ACTIONS(2471),
    [anon_sym_union] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2471),
    [anon_sym_switch] = ACTIONS(2471),
    [anon_sym_case] = ACTIONS(2471),
    [anon_sym_default] = ACTIONS(2471),
    [anon_sym_while] = ACTIONS(2471),
    [anon_sym_do] = ACTIONS(2471),
    [anon_sym_for] = ACTIONS(2471),
    [anon_sym_return] = ACTIONS(2471),
    [anon_sym_break] = ACTIONS(2471),
    [anon_sym_continue] = ACTIONS(2471),
    [anon_sym_goto] = ACTIONS(2471),
    [anon_sym___try] = ACTIONS(2471),
    [anon_sym___leave] = ACTIONS(2471),
    [anon_sym_not] = ACTIONS(2471),
    [anon_sym_compl] = ACTIONS(2471),
    [anon_sym_DASH_DASH] = ACTIONS(2473),
    [anon_sym_PLUS_PLUS] = ACTIONS(2473),
    [anon_sym_sizeof] = ACTIONS(2471),
    [anon_sym___alignof__] = ACTIONS(2471),
    [anon_sym___alignof] = ACTIONS(2471),
    [anon_sym__alignof] = ACTIONS(2471),
    [anon_sym_alignof] = ACTIONS(2471),
    [anon_sym__Alignof] = ACTIONS(2471),
    [anon_sym_offsetof] = ACTIONS(2471),
    [anon_sym__Generic] = ACTIONS(2471),
    [anon_sym_asm] = ACTIONS(2471),
    [anon_sym___asm__] = ACTIONS(2471),
    [anon_sym___asm] = ACTIONS(2471),
    [sym_number_literal] = ACTIONS(2473),
    [anon_sym_L_SQUOTE] = ACTIONS(2473),
    [anon_sym_u_SQUOTE] = ACTIONS(2473),
    [anon_sym_U_SQUOTE] = ACTIONS(2473),
    [anon_sym_u8_SQUOTE] = ACTIONS(2473),
    [anon_sym_SQUOTE] = ACTIONS(2473),
    [anon_sym_L_DQUOTE] = ACTIONS(2473),
    [anon_sym_u_DQUOTE] = ACTIONS(2473),
    [anon_sym_U_DQUOTE] = ACTIONS(2473),
    [anon_sym_u8_DQUOTE] = ACTIONS(2473),
    [anon_sym_DQUOTE] = ACTIONS(2473),
    [sym_true] = ACTIONS(2471),
    [sym_false] = ACTIONS(2471),
    [anon_sym_NULL] = ACTIONS(2471),
    [anon_sym_nullptr] = ACTIONS(2471),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2471),
    [anon_sym_decltype] = ACTIONS(2471),
    [anon_sym_explicit] = ACTIONS(2471),
    [anon_sym_typename] = ACTIONS(2471),
    [anon_sym_template] = ACTIONS(2471),
    [anon_sym_operator] = ACTIONS(2471),
    [anon_sym_try] = ACTIONS(2471),
    [anon_sym_delete] = ACTIONS(2471),
    [anon_sym_throw] = ACTIONS(2471),
    [anon_sym_namespace] = ACTIONS(2471),
    [anon_sym_using] = ACTIONS(2471),
    [anon_sym_static_assert] = ACTIONS(2471),
    [anon_sym_concept] = ACTIONS(2471),
    [anon_sym_co_return] = ACTIONS(2471),
    [anon_sym_co_yield] = ACTIONS(2471),
    [anon_sym_R_DQUOTE] = ACTIONS(2473),
    [anon_sym_LR_DQUOTE] = ACTIONS(2473),
    [anon_sym_uR_DQUOTE] = ACTIONS(2473),
    [anon_sym_UR_DQUOTE] = ACTIONS(2473),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2473),
    [anon_sym_co_await] = ACTIONS(2471),
    [anon_sym_new] = ACTIONS(2471),
    [anon_sym_requires] = ACTIONS(2471),
    [sym_this] = ACTIONS(2471),
    [anon_sym___launch_bounds__] = ACTIONS(2471),
  },
  [STATE(605)] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_include_token1] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_BANG] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym___device__] = ACTIONS(2320),
    [anon_sym___host__] = ACTIONS(2320),
    [anon_sym___global__] = ACTIONS(2320),
    [anon_sym___forceinline__] = ACTIONS(2320),
    [anon_sym___noinline__] = ACTIONS(2320),
    [anon_sym_virtual] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym___attribute] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym___cdecl] = ACTIONS(2320),
    [anon_sym___clrcall] = ACTIONS(2320),
    [anon_sym___stdcall] = ACTIONS(2320),
    [anon_sym___fastcall] = ACTIONS(2320),
    [anon_sym___thiscall] = ACTIONS(2320),
    [anon_sym___vectorcall] = ACTIONS(2320),
    [anon_sym_LBRACE] = ACTIONS(2322),
    [anon_sym_RBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym__Nonnull] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym___shared__] = ACTIONS(2320),
    [anon_sym___local__] = ACTIONS(2320),
    [anon_sym___constant__] = ACTIONS(2320),
    [anon_sym___managed__] = ACTIONS(2320),
    [anon_sym___grid_constant__] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_switch] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_default] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_do] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_return] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_goto] = ACTIONS(2320),
    [anon_sym___try] = ACTIONS(2320),
    [anon_sym___leave] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_compl] = ACTIONS(2320),
    [anon_sym_DASH_DASH] = ACTIONS(2322),
    [anon_sym_PLUS_PLUS] = ACTIONS(2322),
    [anon_sym_sizeof] = ACTIONS(2320),
    [anon_sym___alignof__] = ACTIONS(2320),
    [anon_sym___alignof] = ACTIONS(2320),
    [anon_sym__alignof] = ACTIONS(2320),
    [anon_sym_alignof] = ACTIONS(2320),
    [anon_sym__Alignof] = ACTIONS(2320),
    [anon_sym_offsetof] = ACTIONS(2320),
    [anon_sym__Generic] = ACTIONS(2320),
    [anon_sym_asm] = ACTIONS(2320),
    [anon_sym___asm__] = ACTIONS(2320),
    [anon_sym___asm] = ACTIONS(2320),
    [sym_number_literal] = ACTIONS(2322),
    [anon_sym_L_SQUOTE] = ACTIONS(2322),
    [anon_sym_u_SQUOTE] = ACTIONS(2322),
    [anon_sym_U_SQUOTE] = ACTIONS(2322),
    [anon_sym_u8_SQUOTE] = ACTIONS(2322),
    [anon_sym_SQUOTE] = ACTIONS(2322),
    [anon_sym_L_DQUOTE] = ACTIONS(2322),
    [anon_sym_u_DQUOTE] = ACTIONS(2322),
    [anon_sym_U_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8_DQUOTE] = ACTIONS(2322),
    [anon_sym_DQUOTE] = ACTIONS(2322),
    [sym_true] = ACTIONS(2320),
    [sym_false] = ACTIONS(2320),
    [anon_sym_NULL] = ACTIONS(2320),
    [anon_sym_nullptr] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_delete] = ACTIONS(2320),
    [anon_sym_throw] = ACTIONS(2320),
    [anon_sym_namespace] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_concept] = ACTIONS(2320),
    [anon_sym_co_return] = ACTIONS(2320),
    [anon_sym_co_yield] = ACTIONS(2320),
    [anon_sym_R_DQUOTE] = ACTIONS(2322),
    [anon_sym_LR_DQUOTE] = ACTIONS(2322),
    [anon_sym_uR_DQUOTE] = ACTIONS(2322),
    [anon_sym_UR_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2322),
    [anon_sym_co_await] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(2320),
    [anon_sym_requires] = ACTIONS(2320),
    [sym_this] = ACTIONS(2320),
    [anon_sym___launch_bounds__] = ACTIONS(2320),
  },
  [STATE(606)] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym___device__] = ACTIONS(2324),
    [anon_sym___host__] = ACTIONS(2324),
    [anon_sym___global__] = ACTIONS(2324),
    [anon_sym___forceinline__] = ACTIONS(2324),
    [anon_sym___noinline__] = ACTIONS(2324),
    [anon_sym_virtual] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym___attribute] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym__Nonnull] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym___shared__] = ACTIONS(2324),
    [anon_sym___local__] = ACTIONS(2324),
    [anon_sym___constant__] = ACTIONS(2324),
    [anon_sym___managed__] = ACTIONS(2324),
    [anon_sym___grid_constant__] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [anon_sym___asm] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym___launch_bounds__] = ACTIONS(2324),
  },
  [STATE(607)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4978),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7673),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7851),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2954),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(608)] = {
    [sym_identifier] = ACTIONS(2475),
    [aux_sym_preproc_include_token1] = ACTIONS(2475),
    [aux_sym_preproc_def_token1] = ACTIONS(2475),
    [aux_sym_preproc_if_token1] = ACTIONS(2475),
    [aux_sym_preproc_if_token2] = ACTIONS(2475),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2475),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2475),
    [sym_preproc_directive] = ACTIONS(2475),
    [anon_sym_LPAREN2] = ACTIONS(2477),
    [anon_sym_BANG] = ACTIONS(2477),
    [anon_sym_TILDE] = ACTIONS(2477),
    [anon_sym_DASH] = ACTIONS(2475),
    [anon_sym_PLUS] = ACTIONS(2475),
    [anon_sym_STAR] = ACTIONS(2477),
    [anon_sym_AMP_AMP] = ACTIONS(2477),
    [anon_sym_AMP] = ACTIONS(2475),
    [anon_sym_SEMI] = ACTIONS(2477),
    [anon_sym___extension__] = ACTIONS(2475),
    [anon_sym_typedef] = ACTIONS(2475),
    [anon_sym___device__] = ACTIONS(2475),
    [anon_sym___host__] = ACTIONS(2475),
    [anon_sym___global__] = ACTIONS(2475),
    [anon_sym___forceinline__] = ACTIONS(2475),
    [anon_sym___noinline__] = ACTIONS(2475),
    [anon_sym_virtual] = ACTIONS(2475),
    [anon_sym_extern] = ACTIONS(2475),
    [anon_sym___attribute__] = ACTIONS(2475),
    [anon_sym___attribute] = ACTIONS(2475),
    [anon_sym_COLON_COLON] = ACTIONS(2477),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2477),
    [anon_sym___declspec] = ACTIONS(2475),
    [anon_sym___based] = ACTIONS(2475),
    [anon_sym___cdecl] = ACTIONS(2475),
    [anon_sym___clrcall] = ACTIONS(2475),
    [anon_sym___stdcall] = ACTIONS(2475),
    [anon_sym___fastcall] = ACTIONS(2475),
    [anon_sym___thiscall] = ACTIONS(2475),
    [anon_sym___vectorcall] = ACTIONS(2475),
    [anon_sym_LBRACE] = ACTIONS(2477),
    [anon_sym_signed] = ACTIONS(2475),
    [anon_sym_unsigned] = ACTIONS(2475),
    [anon_sym_long] = ACTIONS(2475),
    [anon_sym_short] = ACTIONS(2475),
    [anon_sym_LBRACK] = ACTIONS(2475),
    [anon_sym_static] = ACTIONS(2475),
    [anon_sym_register] = ACTIONS(2475),
    [anon_sym_inline] = ACTIONS(2475),
    [anon_sym___inline] = ACTIONS(2475),
    [anon_sym___inline__] = ACTIONS(2475),
    [anon_sym___forceinline] = ACTIONS(2475),
    [anon_sym_thread_local] = ACTIONS(2475),
    [anon_sym___thread] = ACTIONS(2475),
    [anon_sym_const] = ACTIONS(2475),
    [anon_sym_constexpr] = ACTIONS(2475),
    [anon_sym_volatile] = ACTIONS(2475),
    [anon_sym_restrict] = ACTIONS(2475),
    [anon_sym___restrict__] = ACTIONS(2475),
    [anon_sym__Atomic] = ACTIONS(2475),
    [anon_sym__Noreturn] = ACTIONS(2475),
    [anon_sym_noreturn] = ACTIONS(2475),
    [anon_sym__Nonnull] = ACTIONS(2475),
    [anon_sym_mutable] = ACTIONS(2475),
    [anon_sym_constinit] = ACTIONS(2475),
    [anon_sym_consteval] = ACTIONS(2475),
    [anon_sym___shared__] = ACTIONS(2475),
    [anon_sym___local__] = ACTIONS(2475),
    [anon_sym___constant__] = ACTIONS(2475),
    [anon_sym___managed__] = ACTIONS(2475),
    [anon_sym___grid_constant__] = ACTIONS(2475),
    [anon_sym_alignas] = ACTIONS(2475),
    [anon_sym__Alignas] = ACTIONS(2475),
    [sym_primitive_type] = ACTIONS(2475),
    [anon_sym_enum] = ACTIONS(2475),
    [anon_sym_class] = ACTIONS(2475),
    [anon_sym_struct] = ACTIONS(2475),
    [anon_sym_union] = ACTIONS(2475),
    [anon_sym_if] = ACTIONS(2475),
    [anon_sym_switch] = ACTIONS(2475),
    [anon_sym_case] = ACTIONS(2475),
    [anon_sym_default] = ACTIONS(2475),
    [anon_sym_while] = ACTIONS(2475),
    [anon_sym_do] = ACTIONS(2475),
    [anon_sym_for] = ACTIONS(2475),
    [anon_sym_return] = ACTIONS(2475),
    [anon_sym_break] = ACTIONS(2475),
    [anon_sym_continue] = ACTIONS(2475),
    [anon_sym_goto] = ACTIONS(2475),
    [anon_sym___try] = ACTIONS(2475),
    [anon_sym___leave] = ACTIONS(2475),
    [anon_sym_not] = ACTIONS(2475),
    [anon_sym_compl] = ACTIONS(2475),
    [anon_sym_DASH_DASH] = ACTIONS(2477),
    [anon_sym_PLUS_PLUS] = ACTIONS(2477),
    [anon_sym_sizeof] = ACTIONS(2475),
    [anon_sym___alignof__] = ACTIONS(2475),
    [anon_sym___alignof] = ACTIONS(2475),
    [anon_sym__alignof] = ACTIONS(2475),
    [anon_sym_alignof] = ACTIONS(2475),
    [anon_sym__Alignof] = ACTIONS(2475),
    [anon_sym_offsetof] = ACTIONS(2475),
    [anon_sym__Generic] = ACTIONS(2475),
    [anon_sym_asm] = ACTIONS(2475),
    [anon_sym___asm__] = ACTIONS(2475),
    [anon_sym___asm] = ACTIONS(2475),
    [sym_number_literal] = ACTIONS(2477),
    [anon_sym_L_SQUOTE] = ACTIONS(2477),
    [anon_sym_u_SQUOTE] = ACTIONS(2477),
    [anon_sym_U_SQUOTE] = ACTIONS(2477),
    [anon_sym_u8_SQUOTE] = ACTIONS(2477),
    [anon_sym_SQUOTE] = ACTIONS(2477),
    [anon_sym_L_DQUOTE] = ACTIONS(2477),
    [anon_sym_u_DQUOTE] = ACTIONS(2477),
    [anon_sym_U_DQUOTE] = ACTIONS(2477),
    [anon_sym_u8_DQUOTE] = ACTIONS(2477),
    [anon_sym_DQUOTE] = ACTIONS(2477),
    [sym_true] = ACTIONS(2475),
    [sym_false] = ACTIONS(2475),
    [anon_sym_NULL] = ACTIONS(2475),
    [anon_sym_nullptr] = ACTIONS(2475),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2475),
    [anon_sym_decltype] = ACTIONS(2475),
    [anon_sym_explicit] = ACTIONS(2475),
    [anon_sym_typename] = ACTIONS(2475),
    [anon_sym_template] = ACTIONS(2475),
    [anon_sym_operator] = ACTIONS(2475),
    [anon_sym_try] = ACTIONS(2475),
    [anon_sym_delete] = ACTIONS(2475),
    [anon_sym_throw] = ACTIONS(2475),
    [anon_sym_namespace] = ACTIONS(2475),
    [anon_sym_using] = ACTIONS(2475),
    [anon_sym_static_assert] = ACTIONS(2475),
    [anon_sym_concept] = ACTIONS(2475),
    [anon_sym_co_return] = ACTIONS(2475),
    [anon_sym_co_yield] = ACTIONS(2475),
    [anon_sym_R_DQUOTE] = ACTIONS(2477),
    [anon_sym_LR_DQUOTE] = ACTIONS(2477),
    [anon_sym_uR_DQUOTE] = ACTIONS(2477),
    [anon_sym_UR_DQUOTE] = ACTIONS(2477),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2477),
    [anon_sym_co_await] = ACTIONS(2475),
    [anon_sym_new] = ACTIONS(2475),
    [anon_sym_requires] = ACTIONS(2475),
    [sym_this] = ACTIONS(2475),
    [anon_sym___launch_bounds__] = ACTIONS(2475),
  },
  [STATE(609)] = {
    [sym_identifier] = ACTIONS(2505),
    [aux_sym_preproc_include_token1] = ACTIONS(2505),
    [aux_sym_preproc_def_token1] = ACTIONS(2505),
    [aux_sym_preproc_if_token1] = ACTIONS(2505),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2505),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2505),
    [sym_preproc_directive] = ACTIONS(2505),
    [anon_sym_LPAREN2] = ACTIONS(2507),
    [anon_sym_BANG] = ACTIONS(2507),
    [anon_sym_TILDE] = ACTIONS(2507),
    [anon_sym_DASH] = ACTIONS(2505),
    [anon_sym_PLUS] = ACTIONS(2505),
    [anon_sym_STAR] = ACTIONS(2507),
    [anon_sym_AMP_AMP] = ACTIONS(2507),
    [anon_sym_AMP] = ACTIONS(2505),
    [anon_sym_SEMI] = ACTIONS(2507),
    [anon_sym___extension__] = ACTIONS(2505),
    [anon_sym_typedef] = ACTIONS(2505),
    [anon_sym___device__] = ACTIONS(2505),
    [anon_sym___host__] = ACTIONS(2505),
    [anon_sym___global__] = ACTIONS(2505),
    [anon_sym___forceinline__] = ACTIONS(2505),
    [anon_sym___noinline__] = ACTIONS(2505),
    [anon_sym_virtual] = ACTIONS(2505),
    [anon_sym_extern] = ACTIONS(2505),
    [anon_sym___attribute__] = ACTIONS(2505),
    [anon_sym___attribute] = ACTIONS(2505),
    [anon_sym_COLON_COLON] = ACTIONS(2507),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2507),
    [anon_sym___declspec] = ACTIONS(2505),
    [anon_sym___based] = ACTIONS(2505),
    [anon_sym___cdecl] = ACTIONS(2505),
    [anon_sym___clrcall] = ACTIONS(2505),
    [anon_sym___stdcall] = ACTIONS(2505),
    [anon_sym___fastcall] = ACTIONS(2505),
    [anon_sym___thiscall] = ACTIONS(2505),
    [anon_sym___vectorcall] = ACTIONS(2505),
    [anon_sym_LBRACE] = ACTIONS(2507),
    [anon_sym_RBRACE] = ACTIONS(2507),
    [anon_sym_signed] = ACTIONS(2505),
    [anon_sym_unsigned] = ACTIONS(2505),
    [anon_sym_long] = ACTIONS(2505),
    [anon_sym_short] = ACTIONS(2505),
    [anon_sym_LBRACK] = ACTIONS(2505),
    [anon_sym_static] = ACTIONS(2505),
    [anon_sym_register] = ACTIONS(2505),
    [anon_sym_inline] = ACTIONS(2505),
    [anon_sym___inline] = ACTIONS(2505),
    [anon_sym___inline__] = ACTIONS(2505),
    [anon_sym___forceinline] = ACTIONS(2505),
    [anon_sym_thread_local] = ACTIONS(2505),
    [anon_sym___thread] = ACTIONS(2505),
    [anon_sym_const] = ACTIONS(2505),
    [anon_sym_constexpr] = ACTIONS(2505),
    [anon_sym_volatile] = ACTIONS(2505),
    [anon_sym_restrict] = ACTIONS(2505),
    [anon_sym___restrict__] = ACTIONS(2505),
    [anon_sym__Atomic] = ACTIONS(2505),
    [anon_sym__Noreturn] = ACTIONS(2505),
    [anon_sym_noreturn] = ACTIONS(2505),
    [anon_sym__Nonnull] = ACTIONS(2505),
    [anon_sym_mutable] = ACTIONS(2505),
    [anon_sym_constinit] = ACTIONS(2505),
    [anon_sym_consteval] = ACTIONS(2505),
    [anon_sym___shared__] = ACTIONS(2505),
    [anon_sym___local__] = ACTIONS(2505),
    [anon_sym___constant__] = ACTIONS(2505),
    [anon_sym___managed__] = ACTIONS(2505),
    [anon_sym___grid_constant__] = ACTIONS(2505),
    [anon_sym_alignas] = ACTIONS(2505),
    [anon_sym__Alignas] = ACTIONS(2505),
    [sym_primitive_type] = ACTIONS(2505),
    [anon_sym_enum] = ACTIONS(2505),
    [anon_sym_class] = ACTIONS(2505),
    [anon_sym_struct] = ACTIONS(2505),
    [anon_sym_union] = ACTIONS(2505),
    [anon_sym_if] = ACTIONS(2505),
    [anon_sym_switch] = ACTIONS(2505),
    [anon_sym_case] = ACTIONS(2505),
    [anon_sym_default] = ACTIONS(2505),
    [anon_sym_while] = ACTIONS(2505),
    [anon_sym_do] = ACTIONS(2505),
    [anon_sym_for] = ACTIONS(2505),
    [anon_sym_return] = ACTIONS(2505),
    [anon_sym_break] = ACTIONS(2505),
    [anon_sym_continue] = ACTIONS(2505),
    [anon_sym_goto] = ACTIONS(2505),
    [anon_sym___try] = ACTIONS(2505),
    [anon_sym___leave] = ACTIONS(2505),
    [anon_sym_not] = ACTIONS(2505),
    [anon_sym_compl] = ACTIONS(2505),
    [anon_sym_DASH_DASH] = ACTIONS(2507),
    [anon_sym_PLUS_PLUS] = ACTIONS(2507),
    [anon_sym_sizeof] = ACTIONS(2505),
    [anon_sym___alignof__] = ACTIONS(2505),
    [anon_sym___alignof] = ACTIONS(2505),
    [anon_sym__alignof] = ACTIONS(2505),
    [anon_sym_alignof] = ACTIONS(2505),
    [anon_sym__Alignof] = ACTIONS(2505),
    [anon_sym_offsetof] = ACTIONS(2505),
    [anon_sym__Generic] = ACTIONS(2505),
    [anon_sym_asm] = ACTIONS(2505),
    [anon_sym___asm__] = ACTIONS(2505),
    [anon_sym___asm] = ACTIONS(2505),
    [sym_number_literal] = ACTIONS(2507),
    [anon_sym_L_SQUOTE] = ACTIONS(2507),
    [anon_sym_u_SQUOTE] = ACTIONS(2507),
    [anon_sym_U_SQUOTE] = ACTIONS(2507),
    [anon_sym_u8_SQUOTE] = ACTIONS(2507),
    [anon_sym_SQUOTE] = ACTIONS(2507),
    [anon_sym_L_DQUOTE] = ACTIONS(2507),
    [anon_sym_u_DQUOTE] = ACTIONS(2507),
    [anon_sym_U_DQUOTE] = ACTIONS(2507),
    [anon_sym_u8_DQUOTE] = ACTIONS(2507),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_true] = ACTIONS(2505),
    [sym_false] = ACTIONS(2505),
    [anon_sym_NULL] = ACTIONS(2505),
    [anon_sym_nullptr] = ACTIONS(2505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2505),
    [anon_sym_decltype] = ACTIONS(2505),
    [anon_sym_explicit] = ACTIONS(2505),
    [anon_sym_typename] = ACTIONS(2505),
    [anon_sym_template] = ACTIONS(2505),
    [anon_sym_operator] = ACTIONS(2505),
    [anon_sym_try] = ACTIONS(2505),
    [anon_sym_delete] = ACTIONS(2505),
    [anon_sym_throw] = ACTIONS(2505),
    [anon_sym_namespace] = ACTIONS(2505),
    [anon_sym_using] = ACTIONS(2505),
    [anon_sym_static_assert] = ACTIONS(2505),
    [anon_sym_concept] = ACTIONS(2505),
    [anon_sym_co_return] = ACTIONS(2505),
    [anon_sym_co_yield] = ACTIONS(2505),
    [anon_sym_R_DQUOTE] = ACTIONS(2507),
    [anon_sym_LR_DQUOTE] = ACTIONS(2507),
    [anon_sym_uR_DQUOTE] = ACTIONS(2507),
    [anon_sym_UR_DQUOTE] = ACTIONS(2507),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2507),
    [anon_sym_co_await] = ACTIONS(2505),
    [anon_sym_new] = ACTIONS(2505),
    [anon_sym_requires] = ACTIONS(2505),
    [sym_this] = ACTIONS(2505),
    [anon_sym___launch_bounds__] = ACTIONS(2505),
  },
  [STATE(610)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4932),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7711),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7900),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2956),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(611)] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_include_token1] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2385),
    [anon_sym_BANG] = ACTIONS(2385),
    [anon_sym_TILDE] = ACTIONS(2385),
    [anon_sym_DASH] = ACTIONS(2383),
    [anon_sym_PLUS] = ACTIONS(2383),
    [anon_sym_STAR] = ACTIONS(2385),
    [anon_sym_AMP_AMP] = ACTIONS(2385),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym___device__] = ACTIONS(2383),
    [anon_sym___host__] = ACTIONS(2383),
    [anon_sym___global__] = ACTIONS(2383),
    [anon_sym___forceinline__] = ACTIONS(2383),
    [anon_sym___noinline__] = ACTIONS(2383),
    [anon_sym_virtual] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym___attribute] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2385),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2385),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym___cdecl] = ACTIONS(2383),
    [anon_sym___clrcall] = ACTIONS(2383),
    [anon_sym___stdcall] = ACTIONS(2383),
    [anon_sym___fastcall] = ACTIONS(2383),
    [anon_sym___thiscall] = ACTIONS(2383),
    [anon_sym___vectorcall] = ACTIONS(2383),
    [anon_sym_LBRACE] = ACTIONS(2385),
    [anon_sym_RBRACE] = ACTIONS(2385),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym__Nonnull] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym___shared__] = ACTIONS(2383),
    [anon_sym___local__] = ACTIONS(2383),
    [anon_sym___constant__] = ACTIONS(2383),
    [anon_sym___managed__] = ACTIONS(2383),
    [anon_sym___grid_constant__] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [anon_sym_if] = ACTIONS(2383),
    [anon_sym_switch] = ACTIONS(2383),
    [anon_sym_case] = ACTIONS(2383),
    [anon_sym_default] = ACTIONS(2383),
    [anon_sym_while] = ACTIONS(2383),
    [anon_sym_do] = ACTIONS(2383),
    [anon_sym_for] = ACTIONS(2383),
    [anon_sym_return] = ACTIONS(2383),
    [anon_sym_break] = ACTIONS(2383),
    [anon_sym_continue] = ACTIONS(2383),
    [anon_sym_goto] = ACTIONS(2383),
    [anon_sym___try] = ACTIONS(2383),
    [anon_sym___leave] = ACTIONS(2383),
    [anon_sym_not] = ACTIONS(2383),
    [anon_sym_compl] = ACTIONS(2383),
    [anon_sym_DASH_DASH] = ACTIONS(2385),
    [anon_sym_PLUS_PLUS] = ACTIONS(2385),
    [anon_sym_sizeof] = ACTIONS(2383),
    [anon_sym___alignof__] = ACTIONS(2383),
    [anon_sym___alignof] = ACTIONS(2383),
    [anon_sym__alignof] = ACTIONS(2383),
    [anon_sym_alignof] = ACTIONS(2383),
    [anon_sym__Alignof] = ACTIONS(2383),
    [anon_sym_offsetof] = ACTIONS(2383),
    [anon_sym__Generic] = ACTIONS(2383),
    [anon_sym_asm] = ACTIONS(2383),
    [anon_sym___asm__] = ACTIONS(2383),
    [anon_sym___asm] = ACTIONS(2383),
    [sym_number_literal] = ACTIONS(2385),
    [anon_sym_L_SQUOTE] = ACTIONS(2385),
    [anon_sym_u_SQUOTE] = ACTIONS(2385),
    [anon_sym_U_SQUOTE] = ACTIONS(2385),
    [anon_sym_u8_SQUOTE] = ACTIONS(2385),
    [anon_sym_SQUOTE] = ACTIONS(2385),
    [anon_sym_L_DQUOTE] = ACTIONS(2385),
    [anon_sym_u_DQUOTE] = ACTIONS(2385),
    [anon_sym_U_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8_DQUOTE] = ACTIONS(2385),
    [anon_sym_DQUOTE] = ACTIONS(2385),
    [sym_true] = ACTIONS(2383),
    [sym_false] = ACTIONS(2383),
    [anon_sym_NULL] = ACTIONS(2383),
    [anon_sym_nullptr] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_try] = ACTIONS(2383),
    [anon_sym_delete] = ACTIONS(2383),
    [anon_sym_throw] = ACTIONS(2383),
    [anon_sym_namespace] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym_concept] = ACTIONS(2383),
    [anon_sym_co_return] = ACTIONS(2383),
    [anon_sym_co_yield] = ACTIONS(2383),
    [anon_sym_R_DQUOTE] = ACTIONS(2385),
    [anon_sym_LR_DQUOTE] = ACTIONS(2385),
    [anon_sym_uR_DQUOTE] = ACTIONS(2385),
    [anon_sym_UR_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2385),
    [anon_sym_co_await] = ACTIONS(2383),
    [anon_sym_new] = ACTIONS(2383),
    [anon_sym_requires] = ACTIONS(2383),
    [sym_this] = ACTIONS(2383),
    [anon_sym___launch_bounds__] = ACTIONS(2383),
  },
  [STATE(612)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4940),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7731),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7928),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2958),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(613)] = {
    [sym_identifier] = ACTIONS(2415),
    [aux_sym_preproc_include_token1] = ACTIONS(2415),
    [aux_sym_preproc_def_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2415),
    [sym_preproc_directive] = ACTIONS(2415),
    [anon_sym_LPAREN2] = ACTIONS(2417),
    [anon_sym_BANG] = ACTIONS(2417),
    [anon_sym_TILDE] = ACTIONS(2417),
    [anon_sym_DASH] = ACTIONS(2415),
    [anon_sym_PLUS] = ACTIONS(2415),
    [anon_sym_STAR] = ACTIONS(2417),
    [anon_sym_AMP_AMP] = ACTIONS(2417),
    [anon_sym_AMP] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(2417),
    [anon_sym___extension__] = ACTIONS(2415),
    [anon_sym_typedef] = ACTIONS(2415),
    [anon_sym___device__] = ACTIONS(2415),
    [anon_sym___host__] = ACTIONS(2415),
    [anon_sym___global__] = ACTIONS(2415),
    [anon_sym___forceinline__] = ACTIONS(2415),
    [anon_sym___noinline__] = ACTIONS(2415),
    [anon_sym_virtual] = ACTIONS(2415),
    [anon_sym_extern] = ACTIONS(2415),
    [anon_sym___attribute__] = ACTIONS(2415),
    [anon_sym___attribute] = ACTIONS(2415),
    [anon_sym_COLON_COLON] = ACTIONS(2417),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2417),
    [anon_sym___declspec] = ACTIONS(2415),
    [anon_sym___based] = ACTIONS(2415),
    [anon_sym___cdecl] = ACTIONS(2415),
    [anon_sym___clrcall] = ACTIONS(2415),
    [anon_sym___stdcall] = ACTIONS(2415),
    [anon_sym___fastcall] = ACTIONS(2415),
    [anon_sym___thiscall] = ACTIONS(2415),
    [anon_sym___vectorcall] = ACTIONS(2415),
    [anon_sym_LBRACE] = ACTIONS(2417),
    [anon_sym_RBRACE] = ACTIONS(2417),
    [anon_sym_signed] = ACTIONS(2415),
    [anon_sym_unsigned] = ACTIONS(2415),
    [anon_sym_long] = ACTIONS(2415),
    [anon_sym_short] = ACTIONS(2415),
    [anon_sym_LBRACK] = ACTIONS(2415),
    [anon_sym_static] = ACTIONS(2415),
    [anon_sym_register] = ACTIONS(2415),
    [anon_sym_inline] = ACTIONS(2415),
    [anon_sym___inline] = ACTIONS(2415),
    [anon_sym___inline__] = ACTIONS(2415),
    [anon_sym___forceinline] = ACTIONS(2415),
    [anon_sym_thread_local] = ACTIONS(2415),
    [anon_sym___thread] = ACTIONS(2415),
    [anon_sym_const] = ACTIONS(2415),
    [anon_sym_constexpr] = ACTIONS(2415),
    [anon_sym_volatile] = ACTIONS(2415),
    [anon_sym_restrict] = ACTIONS(2415),
    [anon_sym___restrict__] = ACTIONS(2415),
    [anon_sym__Atomic] = ACTIONS(2415),
    [anon_sym__Noreturn] = ACTIONS(2415),
    [anon_sym_noreturn] = ACTIONS(2415),
    [anon_sym__Nonnull] = ACTIONS(2415),
    [anon_sym_mutable] = ACTIONS(2415),
    [anon_sym_constinit] = ACTIONS(2415),
    [anon_sym_consteval] = ACTIONS(2415),
    [anon_sym___shared__] = ACTIONS(2415),
    [anon_sym___local__] = ACTIONS(2415),
    [anon_sym___constant__] = ACTIONS(2415),
    [anon_sym___managed__] = ACTIONS(2415),
    [anon_sym___grid_constant__] = ACTIONS(2415),
    [anon_sym_alignas] = ACTIONS(2415),
    [anon_sym__Alignas] = ACTIONS(2415),
    [sym_primitive_type] = ACTIONS(2415),
    [anon_sym_enum] = ACTIONS(2415),
    [anon_sym_class] = ACTIONS(2415),
    [anon_sym_struct] = ACTIONS(2415),
    [anon_sym_union] = ACTIONS(2415),
    [anon_sym_if] = ACTIONS(2415),
    [anon_sym_switch] = ACTIONS(2415),
    [anon_sym_case] = ACTIONS(2415),
    [anon_sym_default] = ACTIONS(2415),
    [anon_sym_while] = ACTIONS(2415),
    [anon_sym_do] = ACTIONS(2415),
    [anon_sym_for] = ACTIONS(2415),
    [anon_sym_return] = ACTIONS(2415),
    [anon_sym_break] = ACTIONS(2415),
    [anon_sym_continue] = ACTIONS(2415),
    [anon_sym_goto] = ACTIONS(2415),
    [anon_sym___try] = ACTIONS(2415),
    [anon_sym___leave] = ACTIONS(2415),
    [anon_sym_not] = ACTIONS(2415),
    [anon_sym_compl] = ACTIONS(2415),
    [anon_sym_DASH_DASH] = ACTIONS(2417),
    [anon_sym_PLUS_PLUS] = ACTIONS(2417),
    [anon_sym_sizeof] = ACTIONS(2415),
    [anon_sym___alignof__] = ACTIONS(2415),
    [anon_sym___alignof] = ACTIONS(2415),
    [anon_sym__alignof] = ACTIONS(2415),
    [anon_sym_alignof] = ACTIONS(2415),
    [anon_sym__Alignof] = ACTIONS(2415),
    [anon_sym_offsetof] = ACTIONS(2415),
    [anon_sym__Generic] = ACTIONS(2415),
    [anon_sym_asm] = ACTIONS(2415),
    [anon_sym___asm__] = ACTIONS(2415),
    [anon_sym___asm] = ACTIONS(2415),
    [sym_number_literal] = ACTIONS(2417),
    [anon_sym_L_SQUOTE] = ACTIONS(2417),
    [anon_sym_u_SQUOTE] = ACTIONS(2417),
    [anon_sym_U_SQUOTE] = ACTIONS(2417),
    [anon_sym_u8_SQUOTE] = ACTIONS(2417),
    [anon_sym_SQUOTE] = ACTIONS(2417),
    [anon_sym_L_DQUOTE] = ACTIONS(2417),
    [anon_sym_u_DQUOTE] = ACTIONS(2417),
    [anon_sym_U_DQUOTE] = ACTIONS(2417),
    [anon_sym_u8_DQUOTE] = ACTIONS(2417),
    [anon_sym_DQUOTE] = ACTIONS(2417),
    [sym_true] = ACTIONS(2415),
    [sym_false] = ACTIONS(2415),
    [anon_sym_NULL] = ACTIONS(2415),
    [anon_sym_nullptr] = ACTIONS(2415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2415),
    [anon_sym_decltype] = ACTIONS(2415),
    [anon_sym_explicit] = ACTIONS(2415),
    [anon_sym_typename] = ACTIONS(2415),
    [anon_sym_template] = ACTIONS(2415),
    [anon_sym_operator] = ACTIONS(2415),
    [anon_sym_try] = ACTIONS(2415),
    [anon_sym_delete] = ACTIONS(2415),
    [anon_sym_throw] = ACTIONS(2415),
    [anon_sym_namespace] = ACTIONS(2415),
    [anon_sym_using] = ACTIONS(2415),
    [anon_sym_static_assert] = ACTIONS(2415),
    [anon_sym_concept] = ACTIONS(2415),
    [anon_sym_co_return] = ACTIONS(2415),
    [anon_sym_co_yield] = ACTIONS(2415),
    [anon_sym_R_DQUOTE] = ACTIONS(2417),
    [anon_sym_LR_DQUOTE] = ACTIONS(2417),
    [anon_sym_uR_DQUOTE] = ACTIONS(2417),
    [anon_sym_UR_DQUOTE] = ACTIONS(2417),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2417),
    [anon_sym_co_await] = ACTIONS(2415),
    [anon_sym_new] = ACTIONS(2415),
    [anon_sym_requires] = ACTIONS(2415),
    [sym_this] = ACTIONS(2415),
    [anon_sym___launch_bounds__] = ACTIONS(2415),
  },
  [STATE(614)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4943),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7748),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(7968),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2960),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(615)] = {
    [sym_identifier] = ACTIONS(2409),
    [aux_sym_preproc_include_token1] = ACTIONS(2409),
    [aux_sym_preproc_def_token1] = ACTIONS(2409),
    [aux_sym_preproc_if_token1] = ACTIONS(2409),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2409),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2409),
    [sym_preproc_directive] = ACTIONS(2409),
    [anon_sym_LPAREN2] = ACTIONS(2412),
    [anon_sym_BANG] = ACTIONS(2412),
    [anon_sym_TILDE] = ACTIONS(2412),
    [anon_sym_DASH] = ACTIONS(2409),
    [anon_sym_PLUS] = ACTIONS(2409),
    [anon_sym_STAR] = ACTIONS(2412),
    [anon_sym_AMP_AMP] = ACTIONS(2412),
    [anon_sym_AMP] = ACTIONS(2409),
    [anon_sym_SEMI] = ACTIONS(2412),
    [anon_sym___extension__] = ACTIONS(2409),
    [anon_sym_typedef] = ACTIONS(2409),
    [anon_sym___device__] = ACTIONS(2409),
    [anon_sym___host__] = ACTIONS(2409),
    [anon_sym___global__] = ACTIONS(2409),
    [anon_sym___forceinline__] = ACTIONS(2409),
    [anon_sym___noinline__] = ACTIONS(2409),
    [anon_sym_virtual] = ACTIONS(2409),
    [anon_sym_extern] = ACTIONS(2409),
    [anon_sym___attribute__] = ACTIONS(2409),
    [anon_sym___attribute] = ACTIONS(2409),
    [anon_sym_COLON_COLON] = ACTIONS(2412),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2412),
    [anon_sym___declspec] = ACTIONS(2409),
    [anon_sym___based] = ACTIONS(2409),
    [anon_sym___cdecl] = ACTIONS(2409),
    [anon_sym___clrcall] = ACTIONS(2409),
    [anon_sym___stdcall] = ACTIONS(2409),
    [anon_sym___fastcall] = ACTIONS(2409),
    [anon_sym___thiscall] = ACTIONS(2409),
    [anon_sym___vectorcall] = ACTIONS(2409),
    [anon_sym_LBRACE] = ACTIONS(2412),
    [anon_sym_RBRACE] = ACTIONS(2412),
    [anon_sym_signed] = ACTIONS(2409),
    [anon_sym_unsigned] = ACTIONS(2409),
    [anon_sym_long] = ACTIONS(2409),
    [anon_sym_short] = ACTIONS(2409),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_static] = ACTIONS(2409),
    [anon_sym_register] = ACTIONS(2409),
    [anon_sym_inline] = ACTIONS(2409),
    [anon_sym___inline] = ACTIONS(2409),
    [anon_sym___inline__] = ACTIONS(2409),
    [anon_sym___forceinline] = ACTIONS(2409),
    [anon_sym_thread_local] = ACTIONS(2409),
    [anon_sym___thread] = ACTIONS(2409),
    [anon_sym_const] = ACTIONS(2409),
    [anon_sym_constexpr] = ACTIONS(2409),
    [anon_sym_volatile] = ACTIONS(2409),
    [anon_sym_restrict] = ACTIONS(2409),
    [anon_sym___restrict__] = ACTIONS(2409),
    [anon_sym__Atomic] = ACTIONS(2409),
    [anon_sym__Noreturn] = ACTIONS(2409),
    [anon_sym_noreturn] = ACTIONS(2409),
    [anon_sym__Nonnull] = ACTIONS(2409),
    [anon_sym_mutable] = ACTIONS(2409),
    [anon_sym_constinit] = ACTIONS(2409),
    [anon_sym_consteval] = ACTIONS(2409),
    [anon_sym___shared__] = ACTIONS(2409),
    [anon_sym___local__] = ACTIONS(2409),
    [anon_sym___constant__] = ACTIONS(2409),
    [anon_sym___managed__] = ACTIONS(2409),
    [anon_sym___grid_constant__] = ACTIONS(2409),
    [anon_sym_alignas] = ACTIONS(2409),
    [anon_sym__Alignas] = ACTIONS(2409),
    [sym_primitive_type] = ACTIONS(2409),
    [anon_sym_enum] = ACTIONS(2409),
    [anon_sym_class] = ACTIONS(2409),
    [anon_sym_struct] = ACTIONS(2409),
    [anon_sym_union] = ACTIONS(2409),
    [anon_sym_if] = ACTIONS(2409),
    [anon_sym_switch] = ACTIONS(2409),
    [anon_sym_case] = ACTIONS(2409),
    [anon_sym_default] = ACTIONS(2409),
    [anon_sym_while] = ACTIONS(2409),
    [anon_sym_do] = ACTIONS(2409),
    [anon_sym_for] = ACTIONS(2409),
    [anon_sym_return] = ACTIONS(2409),
    [anon_sym_break] = ACTIONS(2409),
    [anon_sym_continue] = ACTIONS(2409),
    [anon_sym_goto] = ACTIONS(2409),
    [anon_sym___try] = ACTIONS(2409),
    [anon_sym___leave] = ACTIONS(2409),
    [anon_sym_not] = ACTIONS(2409),
    [anon_sym_compl] = ACTIONS(2409),
    [anon_sym_DASH_DASH] = ACTIONS(2412),
    [anon_sym_PLUS_PLUS] = ACTIONS(2412),
    [anon_sym_sizeof] = ACTIONS(2409),
    [anon_sym___alignof__] = ACTIONS(2409),
    [anon_sym___alignof] = ACTIONS(2409),
    [anon_sym__alignof] = ACTIONS(2409),
    [anon_sym_alignof] = ACTIONS(2409),
    [anon_sym__Alignof] = ACTIONS(2409),
    [anon_sym_offsetof] = ACTIONS(2409),
    [anon_sym__Generic] = ACTIONS(2409),
    [anon_sym_asm] = ACTIONS(2409),
    [anon_sym___asm__] = ACTIONS(2409),
    [anon_sym___asm] = ACTIONS(2409),
    [sym_number_literal] = ACTIONS(2412),
    [anon_sym_L_SQUOTE] = ACTIONS(2412),
    [anon_sym_u_SQUOTE] = ACTIONS(2412),
    [anon_sym_U_SQUOTE] = ACTIONS(2412),
    [anon_sym_u8_SQUOTE] = ACTIONS(2412),
    [anon_sym_SQUOTE] = ACTIONS(2412),
    [anon_sym_L_DQUOTE] = ACTIONS(2412),
    [anon_sym_u_DQUOTE] = ACTIONS(2412),
    [anon_sym_U_DQUOTE] = ACTIONS(2412),
    [anon_sym_u8_DQUOTE] = ACTIONS(2412),
    [anon_sym_DQUOTE] = ACTIONS(2412),
    [sym_true] = ACTIONS(2409),
    [sym_false] = ACTIONS(2409),
    [anon_sym_NULL] = ACTIONS(2409),
    [anon_sym_nullptr] = ACTIONS(2409),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2409),
    [anon_sym_decltype] = ACTIONS(2409),
    [anon_sym_explicit] = ACTIONS(2409),
    [anon_sym_typename] = ACTIONS(2409),
    [anon_sym_template] = ACTIONS(2409),
    [anon_sym_operator] = ACTIONS(2409),
    [anon_sym_try] = ACTIONS(2409),
    [anon_sym_delete] = ACTIONS(2409),
    [anon_sym_throw] = ACTIONS(2409),
    [anon_sym_namespace] = ACTIONS(2409),
    [anon_sym_using] = ACTIONS(2409),
    [anon_sym_static_assert] = ACTIONS(2409),
    [anon_sym_concept] = ACTIONS(2409),
    [anon_sym_co_return] = ACTIONS(2409),
    [anon_sym_co_yield] = ACTIONS(2409),
    [anon_sym_R_DQUOTE] = ACTIONS(2412),
    [anon_sym_LR_DQUOTE] = ACTIONS(2412),
    [anon_sym_uR_DQUOTE] = ACTIONS(2412),
    [anon_sym_UR_DQUOTE] = ACTIONS(2412),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2412),
    [anon_sym_co_await] = ACTIONS(2409),
    [anon_sym_new] = ACTIONS(2409),
    [anon_sym_requires] = ACTIONS(2409),
    [sym_this] = ACTIONS(2409),
    [anon_sym___launch_bounds__] = ACTIONS(2409),
  },
  [STATE(616)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4953),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7760),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8002),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2962),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(617)] = {
    [sym_identifier] = ACTIONS(2409),
    [aux_sym_preproc_include_token1] = ACTIONS(2409),
    [aux_sym_preproc_def_token1] = ACTIONS(2409),
    [aux_sym_preproc_if_token1] = ACTIONS(2409),
    [aux_sym_preproc_if_token2] = ACTIONS(2409),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2409),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2409),
    [sym_preproc_directive] = ACTIONS(2409),
    [anon_sym_LPAREN2] = ACTIONS(2412),
    [anon_sym_BANG] = ACTIONS(2412),
    [anon_sym_TILDE] = ACTIONS(2412),
    [anon_sym_DASH] = ACTIONS(2409),
    [anon_sym_PLUS] = ACTIONS(2409),
    [anon_sym_STAR] = ACTIONS(2412),
    [anon_sym_AMP_AMP] = ACTIONS(2412),
    [anon_sym_AMP] = ACTIONS(2409),
    [anon_sym_SEMI] = ACTIONS(2412),
    [anon_sym___extension__] = ACTIONS(2409),
    [anon_sym_typedef] = ACTIONS(2409),
    [anon_sym___device__] = ACTIONS(2409),
    [anon_sym___host__] = ACTIONS(2409),
    [anon_sym___global__] = ACTIONS(2409),
    [anon_sym___forceinline__] = ACTIONS(2409),
    [anon_sym___noinline__] = ACTIONS(2409),
    [anon_sym_virtual] = ACTIONS(2409),
    [anon_sym_extern] = ACTIONS(2409),
    [anon_sym___attribute__] = ACTIONS(2409),
    [anon_sym___attribute] = ACTIONS(2409),
    [anon_sym_COLON_COLON] = ACTIONS(2412),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2412),
    [anon_sym___declspec] = ACTIONS(2409),
    [anon_sym___based] = ACTIONS(2409),
    [anon_sym___cdecl] = ACTIONS(2409),
    [anon_sym___clrcall] = ACTIONS(2409),
    [anon_sym___stdcall] = ACTIONS(2409),
    [anon_sym___fastcall] = ACTIONS(2409),
    [anon_sym___thiscall] = ACTIONS(2409),
    [anon_sym___vectorcall] = ACTIONS(2409),
    [anon_sym_LBRACE] = ACTIONS(2412),
    [anon_sym_signed] = ACTIONS(2409),
    [anon_sym_unsigned] = ACTIONS(2409),
    [anon_sym_long] = ACTIONS(2409),
    [anon_sym_short] = ACTIONS(2409),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_static] = ACTIONS(2409),
    [anon_sym_register] = ACTIONS(2409),
    [anon_sym_inline] = ACTIONS(2409),
    [anon_sym___inline] = ACTIONS(2409),
    [anon_sym___inline__] = ACTIONS(2409),
    [anon_sym___forceinline] = ACTIONS(2409),
    [anon_sym_thread_local] = ACTIONS(2409),
    [anon_sym___thread] = ACTIONS(2409),
    [anon_sym_const] = ACTIONS(2409),
    [anon_sym_constexpr] = ACTIONS(2409),
    [anon_sym_volatile] = ACTIONS(2409),
    [anon_sym_restrict] = ACTIONS(2409),
    [anon_sym___restrict__] = ACTIONS(2409),
    [anon_sym__Atomic] = ACTIONS(2409),
    [anon_sym__Noreturn] = ACTIONS(2409),
    [anon_sym_noreturn] = ACTIONS(2409),
    [anon_sym__Nonnull] = ACTIONS(2409),
    [anon_sym_mutable] = ACTIONS(2409),
    [anon_sym_constinit] = ACTIONS(2409),
    [anon_sym_consteval] = ACTIONS(2409),
    [anon_sym___shared__] = ACTIONS(2409),
    [anon_sym___local__] = ACTIONS(2409),
    [anon_sym___constant__] = ACTIONS(2409),
    [anon_sym___managed__] = ACTIONS(2409),
    [anon_sym___grid_constant__] = ACTIONS(2409),
    [anon_sym_alignas] = ACTIONS(2409),
    [anon_sym__Alignas] = ACTIONS(2409),
    [sym_primitive_type] = ACTIONS(2409),
    [anon_sym_enum] = ACTIONS(2409),
    [anon_sym_class] = ACTIONS(2409),
    [anon_sym_struct] = ACTIONS(2409),
    [anon_sym_union] = ACTIONS(2409),
    [anon_sym_if] = ACTIONS(2409),
    [anon_sym_switch] = ACTIONS(2409),
    [anon_sym_case] = ACTIONS(2409),
    [anon_sym_default] = ACTIONS(2409),
    [anon_sym_while] = ACTIONS(2409),
    [anon_sym_do] = ACTIONS(2409),
    [anon_sym_for] = ACTIONS(2409),
    [anon_sym_return] = ACTIONS(2409),
    [anon_sym_break] = ACTIONS(2409),
    [anon_sym_continue] = ACTIONS(2409),
    [anon_sym_goto] = ACTIONS(2409),
    [anon_sym___try] = ACTIONS(2409),
    [anon_sym___leave] = ACTIONS(2409),
    [anon_sym_not] = ACTIONS(2409),
    [anon_sym_compl] = ACTIONS(2409),
    [anon_sym_DASH_DASH] = ACTIONS(2412),
    [anon_sym_PLUS_PLUS] = ACTIONS(2412),
    [anon_sym_sizeof] = ACTIONS(2409),
    [anon_sym___alignof__] = ACTIONS(2409),
    [anon_sym___alignof] = ACTIONS(2409),
    [anon_sym__alignof] = ACTIONS(2409),
    [anon_sym_alignof] = ACTIONS(2409),
    [anon_sym__Alignof] = ACTIONS(2409),
    [anon_sym_offsetof] = ACTIONS(2409),
    [anon_sym__Generic] = ACTIONS(2409),
    [anon_sym_asm] = ACTIONS(2409),
    [anon_sym___asm__] = ACTIONS(2409),
    [anon_sym___asm] = ACTIONS(2409),
    [sym_number_literal] = ACTIONS(2412),
    [anon_sym_L_SQUOTE] = ACTIONS(2412),
    [anon_sym_u_SQUOTE] = ACTIONS(2412),
    [anon_sym_U_SQUOTE] = ACTIONS(2412),
    [anon_sym_u8_SQUOTE] = ACTIONS(2412),
    [anon_sym_SQUOTE] = ACTIONS(2412),
    [anon_sym_L_DQUOTE] = ACTIONS(2412),
    [anon_sym_u_DQUOTE] = ACTIONS(2412),
    [anon_sym_U_DQUOTE] = ACTIONS(2412),
    [anon_sym_u8_DQUOTE] = ACTIONS(2412),
    [anon_sym_DQUOTE] = ACTIONS(2412),
    [sym_true] = ACTIONS(2409),
    [sym_false] = ACTIONS(2409),
    [anon_sym_NULL] = ACTIONS(2409),
    [anon_sym_nullptr] = ACTIONS(2409),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2409),
    [anon_sym_decltype] = ACTIONS(2409),
    [anon_sym_explicit] = ACTIONS(2409),
    [anon_sym_typename] = ACTIONS(2409),
    [anon_sym_template] = ACTIONS(2409),
    [anon_sym_operator] = ACTIONS(2409),
    [anon_sym_try] = ACTIONS(2409),
    [anon_sym_delete] = ACTIONS(2409),
    [anon_sym_throw] = ACTIONS(2409),
    [anon_sym_namespace] = ACTIONS(2409),
    [anon_sym_using] = ACTIONS(2409),
    [anon_sym_static_assert] = ACTIONS(2409),
    [anon_sym_concept] = ACTIONS(2409),
    [anon_sym_co_return] = ACTIONS(2409),
    [anon_sym_co_yield] = ACTIONS(2409),
    [anon_sym_R_DQUOTE] = ACTIONS(2412),
    [anon_sym_LR_DQUOTE] = ACTIONS(2412),
    [anon_sym_uR_DQUOTE] = ACTIONS(2412),
    [anon_sym_UR_DQUOTE] = ACTIONS(2412),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2412),
    [anon_sym_co_await] = ACTIONS(2409),
    [anon_sym_new] = ACTIONS(2409),
    [anon_sym_requires] = ACTIONS(2409),
    [sym_this] = ACTIONS(2409),
    [anon_sym___launch_bounds__] = ACTIONS(2409),
  },
  [STATE(618)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4956),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7698),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8018),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2964),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(619)] = {
    [sym_identifier] = ACTIONS(2377),
    [aux_sym_preproc_include_token1] = ACTIONS(2377),
    [aux_sym_preproc_def_token1] = ACTIONS(2377),
    [aux_sym_preproc_if_token1] = ACTIONS(2377),
    [aux_sym_preproc_if_token2] = ACTIONS(2377),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2377),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2377),
    [sym_preproc_directive] = ACTIONS(2377),
    [anon_sym_LPAREN2] = ACTIONS(2379),
    [anon_sym_BANG] = ACTIONS(2379),
    [anon_sym_TILDE] = ACTIONS(2379),
    [anon_sym_DASH] = ACTIONS(2377),
    [anon_sym_PLUS] = ACTIONS(2377),
    [anon_sym_STAR] = ACTIONS(2379),
    [anon_sym_AMP_AMP] = ACTIONS(2379),
    [anon_sym_AMP] = ACTIONS(2377),
    [anon_sym_SEMI] = ACTIONS(2379),
    [anon_sym___extension__] = ACTIONS(2377),
    [anon_sym_typedef] = ACTIONS(2377),
    [anon_sym___device__] = ACTIONS(2377),
    [anon_sym___host__] = ACTIONS(2377),
    [anon_sym___global__] = ACTIONS(2377),
    [anon_sym___forceinline__] = ACTIONS(2377),
    [anon_sym___noinline__] = ACTIONS(2377),
    [anon_sym_virtual] = ACTIONS(2377),
    [anon_sym_extern] = ACTIONS(2377),
    [anon_sym___attribute__] = ACTIONS(2377),
    [anon_sym___attribute] = ACTIONS(2377),
    [anon_sym_COLON_COLON] = ACTIONS(2379),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2379),
    [anon_sym___declspec] = ACTIONS(2377),
    [anon_sym___based] = ACTIONS(2377),
    [anon_sym___cdecl] = ACTIONS(2377),
    [anon_sym___clrcall] = ACTIONS(2377),
    [anon_sym___stdcall] = ACTIONS(2377),
    [anon_sym___fastcall] = ACTIONS(2377),
    [anon_sym___thiscall] = ACTIONS(2377),
    [anon_sym___vectorcall] = ACTIONS(2377),
    [anon_sym_LBRACE] = ACTIONS(2379),
    [anon_sym_signed] = ACTIONS(2377),
    [anon_sym_unsigned] = ACTIONS(2377),
    [anon_sym_long] = ACTIONS(2377),
    [anon_sym_short] = ACTIONS(2377),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_static] = ACTIONS(2377),
    [anon_sym_register] = ACTIONS(2377),
    [anon_sym_inline] = ACTIONS(2377),
    [anon_sym___inline] = ACTIONS(2377),
    [anon_sym___inline__] = ACTIONS(2377),
    [anon_sym___forceinline] = ACTIONS(2377),
    [anon_sym_thread_local] = ACTIONS(2377),
    [anon_sym___thread] = ACTIONS(2377),
    [anon_sym_const] = ACTIONS(2377),
    [anon_sym_constexpr] = ACTIONS(2377),
    [anon_sym_volatile] = ACTIONS(2377),
    [anon_sym_restrict] = ACTIONS(2377),
    [anon_sym___restrict__] = ACTIONS(2377),
    [anon_sym__Atomic] = ACTIONS(2377),
    [anon_sym__Noreturn] = ACTIONS(2377),
    [anon_sym_noreturn] = ACTIONS(2377),
    [anon_sym__Nonnull] = ACTIONS(2377),
    [anon_sym_mutable] = ACTIONS(2377),
    [anon_sym_constinit] = ACTIONS(2377),
    [anon_sym_consteval] = ACTIONS(2377),
    [anon_sym___shared__] = ACTIONS(2377),
    [anon_sym___local__] = ACTIONS(2377),
    [anon_sym___constant__] = ACTIONS(2377),
    [anon_sym___managed__] = ACTIONS(2377),
    [anon_sym___grid_constant__] = ACTIONS(2377),
    [anon_sym_alignas] = ACTIONS(2377),
    [anon_sym__Alignas] = ACTIONS(2377),
    [sym_primitive_type] = ACTIONS(2377),
    [anon_sym_enum] = ACTIONS(2377),
    [anon_sym_class] = ACTIONS(2377),
    [anon_sym_struct] = ACTIONS(2377),
    [anon_sym_union] = ACTIONS(2377),
    [anon_sym_if] = ACTIONS(2377),
    [anon_sym_switch] = ACTIONS(2377),
    [anon_sym_case] = ACTIONS(2377),
    [anon_sym_default] = ACTIONS(2377),
    [anon_sym_while] = ACTIONS(2377),
    [anon_sym_do] = ACTIONS(2377),
    [anon_sym_for] = ACTIONS(2377),
    [anon_sym_return] = ACTIONS(2377),
    [anon_sym_break] = ACTIONS(2377),
    [anon_sym_continue] = ACTIONS(2377),
    [anon_sym_goto] = ACTIONS(2377),
    [anon_sym___try] = ACTIONS(2377),
    [anon_sym___leave] = ACTIONS(2377),
    [anon_sym_not] = ACTIONS(2377),
    [anon_sym_compl] = ACTIONS(2377),
    [anon_sym_DASH_DASH] = ACTIONS(2379),
    [anon_sym_PLUS_PLUS] = ACTIONS(2379),
    [anon_sym_sizeof] = ACTIONS(2377),
    [anon_sym___alignof__] = ACTIONS(2377),
    [anon_sym___alignof] = ACTIONS(2377),
    [anon_sym__alignof] = ACTIONS(2377),
    [anon_sym_alignof] = ACTIONS(2377),
    [anon_sym__Alignof] = ACTIONS(2377),
    [anon_sym_offsetof] = ACTIONS(2377),
    [anon_sym__Generic] = ACTIONS(2377),
    [anon_sym_asm] = ACTIONS(2377),
    [anon_sym___asm__] = ACTIONS(2377),
    [anon_sym___asm] = ACTIONS(2377),
    [sym_number_literal] = ACTIONS(2379),
    [anon_sym_L_SQUOTE] = ACTIONS(2379),
    [anon_sym_u_SQUOTE] = ACTIONS(2379),
    [anon_sym_U_SQUOTE] = ACTIONS(2379),
    [anon_sym_u8_SQUOTE] = ACTIONS(2379),
    [anon_sym_SQUOTE] = ACTIONS(2379),
    [anon_sym_L_DQUOTE] = ACTIONS(2379),
    [anon_sym_u_DQUOTE] = ACTIONS(2379),
    [anon_sym_U_DQUOTE] = ACTIONS(2379),
    [anon_sym_u8_DQUOTE] = ACTIONS(2379),
    [anon_sym_DQUOTE] = ACTIONS(2379),
    [sym_true] = ACTIONS(2377),
    [sym_false] = ACTIONS(2377),
    [anon_sym_NULL] = ACTIONS(2377),
    [anon_sym_nullptr] = ACTIONS(2377),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2377),
    [anon_sym_decltype] = ACTIONS(2377),
    [anon_sym_explicit] = ACTIONS(2377),
    [anon_sym_typename] = ACTIONS(2377),
    [anon_sym_template] = ACTIONS(2377),
    [anon_sym_operator] = ACTIONS(2377),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_delete] = ACTIONS(2377),
    [anon_sym_throw] = ACTIONS(2377),
    [anon_sym_namespace] = ACTIONS(2377),
    [anon_sym_using] = ACTIONS(2377),
    [anon_sym_static_assert] = ACTIONS(2377),
    [anon_sym_concept] = ACTIONS(2377),
    [anon_sym_co_return] = ACTIONS(2377),
    [anon_sym_co_yield] = ACTIONS(2377),
    [anon_sym_R_DQUOTE] = ACTIONS(2379),
    [anon_sym_LR_DQUOTE] = ACTIONS(2379),
    [anon_sym_uR_DQUOTE] = ACTIONS(2379),
    [anon_sym_UR_DQUOTE] = ACTIONS(2379),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2379),
    [anon_sym_co_await] = ACTIONS(2377),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_requires] = ACTIONS(2377),
    [sym_this] = ACTIONS(2377),
    [anon_sym___launch_bounds__] = ACTIONS(2377),
  },
  [STATE(620)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(5007),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7663),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8045),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2966),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(621)] = {
    [sym_identifier] = ACTIONS(2423),
    [aux_sym_preproc_include_token1] = ACTIONS(2423),
    [aux_sym_preproc_def_token1] = ACTIONS(2423),
    [aux_sym_preproc_if_token1] = ACTIONS(2423),
    [aux_sym_preproc_if_token2] = ACTIONS(2423),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2423),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2423),
    [sym_preproc_directive] = ACTIONS(2423),
    [anon_sym_LPAREN2] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(2425),
    [anon_sym_TILDE] = ACTIONS(2425),
    [anon_sym_DASH] = ACTIONS(2423),
    [anon_sym_PLUS] = ACTIONS(2423),
    [anon_sym_STAR] = ACTIONS(2425),
    [anon_sym_AMP_AMP] = ACTIONS(2425),
    [anon_sym_AMP] = ACTIONS(2423),
    [anon_sym_SEMI] = ACTIONS(2425),
    [anon_sym___extension__] = ACTIONS(2423),
    [anon_sym_typedef] = ACTIONS(2423),
    [anon_sym___device__] = ACTIONS(2423),
    [anon_sym___host__] = ACTIONS(2423),
    [anon_sym___global__] = ACTIONS(2423),
    [anon_sym___forceinline__] = ACTIONS(2423),
    [anon_sym___noinline__] = ACTIONS(2423),
    [anon_sym_virtual] = ACTIONS(2423),
    [anon_sym_extern] = ACTIONS(2423),
    [anon_sym___attribute__] = ACTIONS(2423),
    [anon_sym___attribute] = ACTIONS(2423),
    [anon_sym_COLON_COLON] = ACTIONS(2425),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2425),
    [anon_sym___declspec] = ACTIONS(2423),
    [anon_sym___based] = ACTIONS(2423),
    [anon_sym___cdecl] = ACTIONS(2423),
    [anon_sym___clrcall] = ACTIONS(2423),
    [anon_sym___stdcall] = ACTIONS(2423),
    [anon_sym___fastcall] = ACTIONS(2423),
    [anon_sym___thiscall] = ACTIONS(2423),
    [anon_sym___vectorcall] = ACTIONS(2423),
    [anon_sym_LBRACE] = ACTIONS(2425),
    [anon_sym_signed] = ACTIONS(2423),
    [anon_sym_unsigned] = ACTIONS(2423),
    [anon_sym_long] = ACTIONS(2423),
    [anon_sym_short] = ACTIONS(2423),
    [anon_sym_LBRACK] = ACTIONS(2423),
    [anon_sym_static] = ACTIONS(2423),
    [anon_sym_register] = ACTIONS(2423),
    [anon_sym_inline] = ACTIONS(2423),
    [anon_sym___inline] = ACTIONS(2423),
    [anon_sym___inline__] = ACTIONS(2423),
    [anon_sym___forceinline] = ACTIONS(2423),
    [anon_sym_thread_local] = ACTIONS(2423),
    [anon_sym___thread] = ACTIONS(2423),
    [anon_sym_const] = ACTIONS(2423),
    [anon_sym_constexpr] = ACTIONS(2423),
    [anon_sym_volatile] = ACTIONS(2423),
    [anon_sym_restrict] = ACTIONS(2423),
    [anon_sym___restrict__] = ACTIONS(2423),
    [anon_sym__Atomic] = ACTIONS(2423),
    [anon_sym__Noreturn] = ACTIONS(2423),
    [anon_sym_noreturn] = ACTIONS(2423),
    [anon_sym__Nonnull] = ACTIONS(2423),
    [anon_sym_mutable] = ACTIONS(2423),
    [anon_sym_constinit] = ACTIONS(2423),
    [anon_sym_consteval] = ACTIONS(2423),
    [anon_sym___shared__] = ACTIONS(2423),
    [anon_sym___local__] = ACTIONS(2423),
    [anon_sym___constant__] = ACTIONS(2423),
    [anon_sym___managed__] = ACTIONS(2423),
    [anon_sym___grid_constant__] = ACTIONS(2423),
    [anon_sym_alignas] = ACTIONS(2423),
    [anon_sym__Alignas] = ACTIONS(2423),
    [sym_primitive_type] = ACTIONS(2423),
    [anon_sym_enum] = ACTIONS(2423),
    [anon_sym_class] = ACTIONS(2423),
    [anon_sym_struct] = ACTIONS(2423),
    [anon_sym_union] = ACTIONS(2423),
    [anon_sym_if] = ACTIONS(2423),
    [anon_sym_switch] = ACTIONS(2423),
    [anon_sym_case] = ACTIONS(2423),
    [anon_sym_default] = ACTIONS(2423),
    [anon_sym_while] = ACTIONS(2423),
    [anon_sym_do] = ACTIONS(2423),
    [anon_sym_for] = ACTIONS(2423),
    [anon_sym_return] = ACTIONS(2423),
    [anon_sym_break] = ACTIONS(2423),
    [anon_sym_continue] = ACTIONS(2423),
    [anon_sym_goto] = ACTIONS(2423),
    [anon_sym___try] = ACTIONS(2423),
    [anon_sym___leave] = ACTIONS(2423),
    [anon_sym_not] = ACTIONS(2423),
    [anon_sym_compl] = ACTIONS(2423),
    [anon_sym_DASH_DASH] = ACTIONS(2425),
    [anon_sym_PLUS_PLUS] = ACTIONS(2425),
    [anon_sym_sizeof] = ACTIONS(2423),
    [anon_sym___alignof__] = ACTIONS(2423),
    [anon_sym___alignof] = ACTIONS(2423),
    [anon_sym__alignof] = ACTIONS(2423),
    [anon_sym_alignof] = ACTIONS(2423),
    [anon_sym__Alignof] = ACTIONS(2423),
    [anon_sym_offsetof] = ACTIONS(2423),
    [anon_sym__Generic] = ACTIONS(2423),
    [anon_sym_asm] = ACTIONS(2423),
    [anon_sym___asm__] = ACTIONS(2423),
    [anon_sym___asm] = ACTIONS(2423),
    [sym_number_literal] = ACTIONS(2425),
    [anon_sym_L_SQUOTE] = ACTIONS(2425),
    [anon_sym_u_SQUOTE] = ACTIONS(2425),
    [anon_sym_U_SQUOTE] = ACTIONS(2425),
    [anon_sym_u8_SQUOTE] = ACTIONS(2425),
    [anon_sym_SQUOTE] = ACTIONS(2425),
    [anon_sym_L_DQUOTE] = ACTIONS(2425),
    [anon_sym_u_DQUOTE] = ACTIONS(2425),
    [anon_sym_U_DQUOTE] = ACTIONS(2425),
    [anon_sym_u8_DQUOTE] = ACTIONS(2425),
    [anon_sym_DQUOTE] = ACTIONS(2425),
    [sym_true] = ACTIONS(2423),
    [sym_false] = ACTIONS(2423),
    [anon_sym_NULL] = ACTIONS(2423),
    [anon_sym_nullptr] = ACTIONS(2423),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2423),
    [anon_sym_decltype] = ACTIONS(2423),
    [anon_sym_explicit] = ACTIONS(2423),
    [anon_sym_typename] = ACTIONS(2423),
    [anon_sym_template] = ACTIONS(2423),
    [anon_sym_operator] = ACTIONS(2423),
    [anon_sym_try] = ACTIONS(2423),
    [anon_sym_delete] = ACTIONS(2423),
    [anon_sym_throw] = ACTIONS(2423),
    [anon_sym_namespace] = ACTIONS(2423),
    [anon_sym_using] = ACTIONS(2423),
    [anon_sym_static_assert] = ACTIONS(2423),
    [anon_sym_concept] = ACTIONS(2423),
    [anon_sym_co_return] = ACTIONS(2423),
    [anon_sym_co_yield] = ACTIONS(2423),
    [anon_sym_R_DQUOTE] = ACTIONS(2425),
    [anon_sym_LR_DQUOTE] = ACTIONS(2425),
    [anon_sym_uR_DQUOTE] = ACTIONS(2425),
    [anon_sym_UR_DQUOTE] = ACTIONS(2425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2425),
    [anon_sym_co_await] = ACTIONS(2423),
    [anon_sym_new] = ACTIONS(2423),
    [anon_sym_requires] = ACTIONS(2423),
    [sym_this] = ACTIONS(2423),
    [anon_sym___launch_bounds__] = ACTIONS(2423),
  },
  [STATE(622)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4965),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7527),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8063),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2968),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(623)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(4972),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7542),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8092),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2970),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(624)] = {
    [sym_identifier] = ACTIONS(2467),
    [aux_sym_preproc_include_token1] = ACTIONS(2467),
    [aux_sym_preproc_def_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2467),
    [sym_preproc_directive] = ACTIONS(2467),
    [anon_sym_LPAREN2] = ACTIONS(2469),
    [anon_sym_BANG] = ACTIONS(2469),
    [anon_sym_TILDE] = ACTIONS(2469),
    [anon_sym_DASH] = ACTIONS(2467),
    [anon_sym_PLUS] = ACTIONS(2467),
    [anon_sym_STAR] = ACTIONS(2469),
    [anon_sym_AMP_AMP] = ACTIONS(2469),
    [anon_sym_AMP] = ACTIONS(2467),
    [anon_sym_SEMI] = ACTIONS(2469),
    [anon_sym___extension__] = ACTIONS(2467),
    [anon_sym_typedef] = ACTIONS(2467),
    [anon_sym___device__] = ACTIONS(2467),
    [anon_sym___host__] = ACTIONS(2467),
    [anon_sym___global__] = ACTIONS(2467),
    [anon_sym___forceinline__] = ACTIONS(2467),
    [anon_sym___noinline__] = ACTIONS(2467),
    [anon_sym_virtual] = ACTIONS(2467),
    [anon_sym_extern] = ACTIONS(2467),
    [anon_sym___attribute__] = ACTIONS(2467),
    [anon_sym___attribute] = ACTIONS(2467),
    [anon_sym_COLON_COLON] = ACTIONS(2469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2469),
    [anon_sym___declspec] = ACTIONS(2467),
    [anon_sym___based] = ACTIONS(2467),
    [anon_sym___cdecl] = ACTIONS(2467),
    [anon_sym___clrcall] = ACTIONS(2467),
    [anon_sym___stdcall] = ACTIONS(2467),
    [anon_sym___fastcall] = ACTIONS(2467),
    [anon_sym___thiscall] = ACTIONS(2467),
    [anon_sym___vectorcall] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2469),
    [anon_sym_RBRACE] = ACTIONS(2469),
    [anon_sym_signed] = ACTIONS(2467),
    [anon_sym_unsigned] = ACTIONS(2467),
    [anon_sym_long] = ACTIONS(2467),
    [anon_sym_short] = ACTIONS(2467),
    [anon_sym_LBRACK] = ACTIONS(2467),
    [anon_sym_static] = ACTIONS(2467),
    [anon_sym_register] = ACTIONS(2467),
    [anon_sym_inline] = ACTIONS(2467),
    [anon_sym___inline] = ACTIONS(2467),
    [anon_sym___inline__] = ACTIONS(2467),
    [anon_sym___forceinline] = ACTIONS(2467),
    [anon_sym_thread_local] = ACTIONS(2467),
    [anon_sym___thread] = ACTIONS(2467),
    [anon_sym_const] = ACTIONS(2467),
    [anon_sym_constexpr] = ACTIONS(2467),
    [anon_sym_volatile] = ACTIONS(2467),
    [anon_sym_restrict] = ACTIONS(2467),
    [anon_sym___restrict__] = ACTIONS(2467),
    [anon_sym__Atomic] = ACTIONS(2467),
    [anon_sym__Noreturn] = ACTIONS(2467),
    [anon_sym_noreturn] = ACTIONS(2467),
    [anon_sym__Nonnull] = ACTIONS(2467),
    [anon_sym_mutable] = ACTIONS(2467),
    [anon_sym_constinit] = ACTIONS(2467),
    [anon_sym_consteval] = ACTIONS(2467),
    [anon_sym___shared__] = ACTIONS(2467),
    [anon_sym___local__] = ACTIONS(2467),
    [anon_sym___constant__] = ACTIONS(2467),
    [anon_sym___managed__] = ACTIONS(2467),
    [anon_sym___grid_constant__] = ACTIONS(2467),
    [anon_sym_alignas] = ACTIONS(2467),
    [anon_sym__Alignas] = ACTIONS(2467),
    [sym_primitive_type] = ACTIONS(2467),
    [anon_sym_enum] = ACTIONS(2467),
    [anon_sym_class] = ACTIONS(2467),
    [anon_sym_struct] = ACTIONS(2467),
    [anon_sym_union] = ACTIONS(2467),
    [anon_sym_if] = ACTIONS(2467),
    [anon_sym_switch] = ACTIONS(2467),
    [anon_sym_case] = ACTIONS(2467),
    [anon_sym_default] = ACTIONS(2467),
    [anon_sym_while] = ACTIONS(2467),
    [anon_sym_do] = ACTIONS(2467),
    [anon_sym_for] = ACTIONS(2467),
    [anon_sym_return] = ACTIONS(2467),
    [anon_sym_break] = ACTIONS(2467),
    [anon_sym_continue] = ACTIONS(2467),
    [anon_sym_goto] = ACTIONS(2467),
    [anon_sym___try] = ACTIONS(2467),
    [anon_sym___leave] = ACTIONS(2467),
    [anon_sym_not] = ACTIONS(2467),
    [anon_sym_compl] = ACTIONS(2467),
    [anon_sym_DASH_DASH] = ACTIONS(2469),
    [anon_sym_PLUS_PLUS] = ACTIONS(2469),
    [anon_sym_sizeof] = ACTIONS(2467),
    [anon_sym___alignof__] = ACTIONS(2467),
    [anon_sym___alignof] = ACTIONS(2467),
    [anon_sym__alignof] = ACTIONS(2467),
    [anon_sym_alignof] = ACTIONS(2467),
    [anon_sym__Alignof] = ACTIONS(2467),
    [anon_sym_offsetof] = ACTIONS(2467),
    [anon_sym__Generic] = ACTIONS(2467),
    [anon_sym_asm] = ACTIONS(2467),
    [anon_sym___asm__] = ACTIONS(2467),
    [anon_sym___asm] = ACTIONS(2467),
    [sym_number_literal] = ACTIONS(2469),
    [anon_sym_L_SQUOTE] = ACTIONS(2469),
    [anon_sym_u_SQUOTE] = ACTIONS(2469),
    [anon_sym_U_SQUOTE] = ACTIONS(2469),
    [anon_sym_u8_SQUOTE] = ACTIONS(2469),
    [anon_sym_SQUOTE] = ACTIONS(2469),
    [anon_sym_L_DQUOTE] = ACTIONS(2469),
    [anon_sym_u_DQUOTE] = ACTIONS(2469),
    [anon_sym_U_DQUOTE] = ACTIONS(2469),
    [anon_sym_u8_DQUOTE] = ACTIONS(2469),
    [anon_sym_DQUOTE] = ACTIONS(2469),
    [sym_true] = ACTIONS(2467),
    [sym_false] = ACTIONS(2467),
    [anon_sym_NULL] = ACTIONS(2467),
    [anon_sym_nullptr] = ACTIONS(2467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2467),
    [anon_sym_decltype] = ACTIONS(2467),
    [anon_sym_explicit] = ACTIONS(2467),
    [anon_sym_typename] = ACTIONS(2467),
    [anon_sym_template] = ACTIONS(2467),
    [anon_sym_operator] = ACTIONS(2467),
    [anon_sym_try] = ACTIONS(2467),
    [anon_sym_delete] = ACTIONS(2467),
    [anon_sym_throw] = ACTIONS(2467),
    [anon_sym_namespace] = ACTIONS(2467),
    [anon_sym_using] = ACTIONS(2467),
    [anon_sym_static_assert] = ACTIONS(2467),
    [anon_sym_concept] = ACTIONS(2467),
    [anon_sym_co_return] = ACTIONS(2467),
    [anon_sym_co_yield] = ACTIONS(2467),
    [anon_sym_R_DQUOTE] = ACTIONS(2469),
    [anon_sym_LR_DQUOTE] = ACTIONS(2469),
    [anon_sym_uR_DQUOTE] = ACTIONS(2469),
    [anon_sym_UR_DQUOTE] = ACTIONS(2469),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2469),
    [anon_sym_co_await] = ACTIONS(2467),
    [anon_sym_new] = ACTIONS(2467),
    [anon_sym_requires] = ACTIONS(2467),
    [sym_this] = ACTIONS(2467),
    [anon_sym___launch_bounds__] = ACTIONS(2467),
  },
  [STATE(625)] = {
    [ts_builtin_sym_end] = ACTIONS(1930),
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_include_token1] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [anon_sym_RPAREN] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_case] = ACTIONS(1932),
    [anon_sym_default] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_namespace] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(626)] = {
    [sym_identifier] = ACTIONS(2505),
    [aux_sym_preproc_include_token1] = ACTIONS(2505),
    [aux_sym_preproc_def_token1] = ACTIONS(2505),
    [aux_sym_preproc_if_token1] = ACTIONS(2505),
    [aux_sym_preproc_if_token2] = ACTIONS(2505),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2505),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2505),
    [sym_preproc_directive] = ACTIONS(2505),
    [anon_sym_LPAREN2] = ACTIONS(2507),
    [anon_sym_BANG] = ACTIONS(2507),
    [anon_sym_TILDE] = ACTIONS(2507),
    [anon_sym_DASH] = ACTIONS(2505),
    [anon_sym_PLUS] = ACTIONS(2505),
    [anon_sym_STAR] = ACTIONS(2507),
    [anon_sym_AMP_AMP] = ACTIONS(2507),
    [anon_sym_AMP] = ACTIONS(2505),
    [anon_sym_SEMI] = ACTIONS(2507),
    [anon_sym___extension__] = ACTIONS(2505),
    [anon_sym_typedef] = ACTIONS(2505),
    [anon_sym___device__] = ACTIONS(2505),
    [anon_sym___host__] = ACTIONS(2505),
    [anon_sym___global__] = ACTIONS(2505),
    [anon_sym___forceinline__] = ACTIONS(2505),
    [anon_sym___noinline__] = ACTIONS(2505),
    [anon_sym_virtual] = ACTIONS(2505),
    [anon_sym_extern] = ACTIONS(2505),
    [anon_sym___attribute__] = ACTIONS(2505),
    [anon_sym___attribute] = ACTIONS(2505),
    [anon_sym_COLON_COLON] = ACTIONS(2507),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2507),
    [anon_sym___declspec] = ACTIONS(2505),
    [anon_sym___based] = ACTIONS(2505),
    [anon_sym___cdecl] = ACTIONS(2505),
    [anon_sym___clrcall] = ACTIONS(2505),
    [anon_sym___stdcall] = ACTIONS(2505),
    [anon_sym___fastcall] = ACTIONS(2505),
    [anon_sym___thiscall] = ACTIONS(2505),
    [anon_sym___vectorcall] = ACTIONS(2505),
    [anon_sym_LBRACE] = ACTIONS(2507),
    [anon_sym_signed] = ACTIONS(2505),
    [anon_sym_unsigned] = ACTIONS(2505),
    [anon_sym_long] = ACTIONS(2505),
    [anon_sym_short] = ACTIONS(2505),
    [anon_sym_LBRACK] = ACTIONS(2505),
    [anon_sym_static] = ACTIONS(2505),
    [anon_sym_register] = ACTIONS(2505),
    [anon_sym_inline] = ACTIONS(2505),
    [anon_sym___inline] = ACTIONS(2505),
    [anon_sym___inline__] = ACTIONS(2505),
    [anon_sym___forceinline] = ACTIONS(2505),
    [anon_sym_thread_local] = ACTIONS(2505),
    [anon_sym___thread] = ACTIONS(2505),
    [anon_sym_const] = ACTIONS(2505),
    [anon_sym_constexpr] = ACTIONS(2505),
    [anon_sym_volatile] = ACTIONS(2505),
    [anon_sym_restrict] = ACTIONS(2505),
    [anon_sym___restrict__] = ACTIONS(2505),
    [anon_sym__Atomic] = ACTIONS(2505),
    [anon_sym__Noreturn] = ACTIONS(2505),
    [anon_sym_noreturn] = ACTIONS(2505),
    [anon_sym__Nonnull] = ACTIONS(2505),
    [anon_sym_mutable] = ACTIONS(2505),
    [anon_sym_constinit] = ACTIONS(2505),
    [anon_sym_consteval] = ACTIONS(2505),
    [anon_sym___shared__] = ACTIONS(2505),
    [anon_sym___local__] = ACTIONS(2505),
    [anon_sym___constant__] = ACTIONS(2505),
    [anon_sym___managed__] = ACTIONS(2505),
    [anon_sym___grid_constant__] = ACTIONS(2505),
    [anon_sym_alignas] = ACTIONS(2505),
    [anon_sym__Alignas] = ACTIONS(2505),
    [sym_primitive_type] = ACTIONS(2505),
    [anon_sym_enum] = ACTIONS(2505),
    [anon_sym_class] = ACTIONS(2505),
    [anon_sym_struct] = ACTIONS(2505),
    [anon_sym_union] = ACTIONS(2505),
    [anon_sym_if] = ACTIONS(2505),
    [anon_sym_switch] = ACTIONS(2505),
    [anon_sym_case] = ACTIONS(2505),
    [anon_sym_default] = ACTIONS(2505),
    [anon_sym_while] = ACTIONS(2505),
    [anon_sym_do] = ACTIONS(2505),
    [anon_sym_for] = ACTIONS(2505),
    [anon_sym_return] = ACTIONS(2505),
    [anon_sym_break] = ACTIONS(2505),
    [anon_sym_continue] = ACTIONS(2505),
    [anon_sym_goto] = ACTIONS(2505),
    [anon_sym___try] = ACTIONS(2505),
    [anon_sym___leave] = ACTIONS(2505),
    [anon_sym_not] = ACTIONS(2505),
    [anon_sym_compl] = ACTIONS(2505),
    [anon_sym_DASH_DASH] = ACTIONS(2507),
    [anon_sym_PLUS_PLUS] = ACTIONS(2507),
    [anon_sym_sizeof] = ACTIONS(2505),
    [anon_sym___alignof__] = ACTIONS(2505),
    [anon_sym___alignof] = ACTIONS(2505),
    [anon_sym__alignof] = ACTIONS(2505),
    [anon_sym_alignof] = ACTIONS(2505),
    [anon_sym__Alignof] = ACTIONS(2505),
    [anon_sym_offsetof] = ACTIONS(2505),
    [anon_sym__Generic] = ACTIONS(2505),
    [anon_sym_asm] = ACTIONS(2505),
    [anon_sym___asm__] = ACTIONS(2505),
    [anon_sym___asm] = ACTIONS(2505),
    [sym_number_literal] = ACTIONS(2507),
    [anon_sym_L_SQUOTE] = ACTIONS(2507),
    [anon_sym_u_SQUOTE] = ACTIONS(2507),
    [anon_sym_U_SQUOTE] = ACTIONS(2507),
    [anon_sym_u8_SQUOTE] = ACTIONS(2507),
    [anon_sym_SQUOTE] = ACTIONS(2507),
    [anon_sym_L_DQUOTE] = ACTIONS(2507),
    [anon_sym_u_DQUOTE] = ACTIONS(2507),
    [anon_sym_U_DQUOTE] = ACTIONS(2507),
    [anon_sym_u8_DQUOTE] = ACTIONS(2507),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_true] = ACTIONS(2505),
    [sym_false] = ACTIONS(2505),
    [anon_sym_NULL] = ACTIONS(2505),
    [anon_sym_nullptr] = ACTIONS(2505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2505),
    [anon_sym_decltype] = ACTIONS(2505),
    [anon_sym_explicit] = ACTIONS(2505),
    [anon_sym_typename] = ACTIONS(2505),
    [anon_sym_template] = ACTIONS(2505),
    [anon_sym_operator] = ACTIONS(2505),
    [anon_sym_try] = ACTIONS(2505),
    [anon_sym_delete] = ACTIONS(2505),
    [anon_sym_throw] = ACTIONS(2505),
    [anon_sym_namespace] = ACTIONS(2505),
    [anon_sym_using] = ACTIONS(2505),
    [anon_sym_static_assert] = ACTIONS(2505),
    [anon_sym_concept] = ACTIONS(2505),
    [anon_sym_co_return] = ACTIONS(2505),
    [anon_sym_co_yield] = ACTIONS(2505),
    [anon_sym_R_DQUOTE] = ACTIONS(2507),
    [anon_sym_LR_DQUOTE] = ACTIONS(2507),
    [anon_sym_uR_DQUOTE] = ACTIONS(2507),
    [anon_sym_UR_DQUOTE] = ACTIONS(2507),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2507),
    [anon_sym_co_await] = ACTIONS(2505),
    [anon_sym_new] = ACTIONS(2505),
    [anon_sym_requires] = ACTIONS(2505),
    [sym_this] = ACTIONS(2505),
    [anon_sym___launch_bounds__] = ACTIONS(2505),
  },
  [STATE(627)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(7836),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(628)] = {
    [sym_attribute_declaration] = STATE(628),
    [sym_compound_statement] = STATE(201),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(207),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(628),
    [sym_identifier] = ACTIONS(2978),
    [anon_sym_LPAREN2] = ACTIONS(2981),
    [anon_sym_BANG] = ACTIONS(2984),
    [anon_sym_TILDE] = ACTIONS(2984),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2990),
    [anon_sym_AMP] = ACTIONS(2990),
    [anon_sym_SEMI] = ACTIONS(2993),
    [anon_sym___extension__] = ACTIONS(2996),
    [anon_sym_COLON_COLON] = ACTIONS(2999),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3002),
    [anon_sym_LBRACE] = ACTIONS(3005),
    [anon_sym_LBRACK] = ACTIONS(3008),
    [sym_primitive_type] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3014),
    [anon_sym_switch] = ACTIONS(3017),
    [anon_sym_case] = ACTIONS(3020),
    [anon_sym_default] = ACTIONS(3023),
    [anon_sym_while] = ACTIONS(3026),
    [anon_sym_do] = ACTIONS(3029),
    [anon_sym_for] = ACTIONS(3032),
    [anon_sym_return] = ACTIONS(3035),
    [anon_sym_break] = ACTIONS(3038),
    [anon_sym_continue] = ACTIONS(3041),
    [anon_sym_goto] = ACTIONS(3044),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(3050),
    [anon_sym_not] = ACTIONS(2987),
    [anon_sym_compl] = ACTIONS(2987),
    [anon_sym_DASH_DASH] = ACTIONS(3053),
    [anon_sym_PLUS_PLUS] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3056),
    [anon_sym___alignof__] = ACTIONS(3059),
    [anon_sym___alignof] = ACTIONS(3059),
    [anon_sym__alignof] = ACTIONS(3059),
    [anon_sym_alignof] = ACTIONS(3059),
    [anon_sym__Alignof] = ACTIONS(3059),
    [anon_sym_offsetof] = ACTIONS(3062),
    [anon_sym__Generic] = ACTIONS(3065),
    [anon_sym_asm] = ACTIONS(3068),
    [anon_sym___asm__] = ACTIONS(3068),
    [anon_sym___asm] = ACTIONS(3068),
    [sym_number_literal] = ACTIONS(3071),
    [anon_sym_L_SQUOTE] = ACTIONS(3074),
    [anon_sym_u_SQUOTE] = ACTIONS(3074),
    [anon_sym_U_SQUOTE] = ACTIONS(3074),
    [anon_sym_u8_SQUOTE] = ACTIONS(3074),
    [anon_sym_SQUOTE] = ACTIONS(3074),
    [anon_sym_L_DQUOTE] = ACTIONS(3077),
    [anon_sym_u_DQUOTE] = ACTIONS(3077),
    [anon_sym_U_DQUOTE] = ACTIONS(3077),
    [anon_sym_u8_DQUOTE] = ACTIONS(3077),
    [anon_sym_DQUOTE] = ACTIONS(3077),
    [sym_true] = ACTIONS(3080),
    [sym_false] = ACTIONS(3080),
    [anon_sym_NULL] = ACTIONS(3083),
    [anon_sym_nullptr] = ACTIONS(3083),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3086),
    [anon_sym_template] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3092),
    [anon_sym_delete] = ACTIONS(3095),
    [anon_sym_throw] = ACTIONS(3098),
    [anon_sym_co_return] = ACTIONS(3101),
    [anon_sym_co_yield] = ACTIONS(3104),
    [anon_sym_R_DQUOTE] = ACTIONS(3107),
    [anon_sym_LR_DQUOTE] = ACTIONS(3107),
    [anon_sym_uR_DQUOTE] = ACTIONS(3107),
    [anon_sym_UR_DQUOTE] = ACTIONS(3107),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3107),
    [anon_sym_co_await] = ACTIONS(3110),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_requires] = ACTIONS(3116),
    [sym_this] = ACTIONS(3080),
  },
  [STATE(629)] = {
    [sym_attribute_declaration] = STATE(637),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(408),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [sym_identifier] = ACTIONS(3119),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(630)] = {
    [sym_attribute_declaration] = STATE(670),
    [sym_compound_statement] = STATE(368),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(357),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [sym_identifier] = ACTIONS(3121),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(631)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(2923),
    [sym__declarator] = STATE(7042),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_type_qualifier] = STATE(3776),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_expression] = STATE(3334),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3726),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6227),
    [sym_qualified_identifier] = STATE(3729),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [aux_sym__type_definition_type_repeat1] = STATE(3776),
    [aux_sym_pointer_declarator_repeat1] = STATE(2923),
    [sym_identifier] = ACTIONS(3123),
    [anon_sym_LPAREN2] = ACTIONS(1854),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1858),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1862),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(1864),
    [anon_sym___extension__] = ACTIONS(3125),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(1874),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(632)] = {
    [sym_attribute_declaration] = STATE(632),
    [sym_compound_statement] = STATE(375),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(381),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(632),
    [sym_identifier] = ACTIONS(3135),
    [anon_sym_LPAREN2] = ACTIONS(2981),
    [anon_sym_BANG] = ACTIONS(2984),
    [anon_sym_TILDE] = ACTIONS(2984),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2990),
    [anon_sym_AMP] = ACTIONS(2990),
    [anon_sym_SEMI] = ACTIONS(3138),
    [anon_sym___extension__] = ACTIONS(2996),
    [anon_sym_COLON_COLON] = ACTIONS(2999),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3002),
    [anon_sym_LBRACE] = ACTIONS(3141),
    [anon_sym_LBRACK] = ACTIONS(3008),
    [sym_primitive_type] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3144),
    [anon_sym_switch] = ACTIONS(3147),
    [anon_sym_case] = ACTIONS(3150),
    [anon_sym_default] = ACTIONS(3153),
    [anon_sym_while] = ACTIONS(3156),
    [anon_sym_do] = ACTIONS(3159),
    [anon_sym_for] = ACTIONS(3162),
    [anon_sym_return] = ACTIONS(3165),
    [anon_sym_break] = ACTIONS(3168),
    [anon_sym_continue] = ACTIONS(3171),
    [anon_sym_goto] = ACTIONS(3174),
    [anon_sym___try] = ACTIONS(3177),
    [anon_sym___leave] = ACTIONS(3180),
    [anon_sym_not] = ACTIONS(2987),
    [anon_sym_compl] = ACTIONS(2987),
    [anon_sym_DASH_DASH] = ACTIONS(3053),
    [anon_sym_PLUS_PLUS] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3056),
    [anon_sym___alignof__] = ACTIONS(3059),
    [anon_sym___alignof] = ACTIONS(3059),
    [anon_sym__alignof] = ACTIONS(3059),
    [anon_sym_alignof] = ACTIONS(3059),
    [anon_sym__Alignof] = ACTIONS(3059),
    [anon_sym_offsetof] = ACTIONS(3062),
    [anon_sym__Generic] = ACTIONS(3065),
    [anon_sym_asm] = ACTIONS(3068),
    [anon_sym___asm__] = ACTIONS(3068),
    [anon_sym___asm] = ACTIONS(3068),
    [sym_number_literal] = ACTIONS(3071),
    [anon_sym_L_SQUOTE] = ACTIONS(3074),
    [anon_sym_u_SQUOTE] = ACTIONS(3074),
    [anon_sym_U_SQUOTE] = ACTIONS(3074),
    [anon_sym_u8_SQUOTE] = ACTIONS(3074),
    [anon_sym_SQUOTE] = ACTIONS(3074),
    [anon_sym_L_DQUOTE] = ACTIONS(3077),
    [anon_sym_u_DQUOTE] = ACTIONS(3077),
    [anon_sym_U_DQUOTE] = ACTIONS(3077),
    [anon_sym_u8_DQUOTE] = ACTIONS(3077),
    [anon_sym_DQUOTE] = ACTIONS(3077),
    [sym_true] = ACTIONS(3080),
    [sym_false] = ACTIONS(3080),
    [anon_sym_NULL] = ACTIONS(3083),
    [anon_sym_nullptr] = ACTIONS(3083),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3086),
    [anon_sym_template] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3183),
    [anon_sym_delete] = ACTIONS(3095),
    [anon_sym_throw] = ACTIONS(3186),
    [anon_sym_co_return] = ACTIONS(3189),
    [anon_sym_co_yield] = ACTIONS(3192),
    [anon_sym_R_DQUOTE] = ACTIONS(3107),
    [anon_sym_LR_DQUOTE] = ACTIONS(3107),
    [anon_sym_uR_DQUOTE] = ACTIONS(3107),
    [anon_sym_UR_DQUOTE] = ACTIONS(3107),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3107),
    [anon_sym_co_await] = ACTIONS(3110),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_requires] = ACTIONS(3116),
    [sym_this] = ACTIONS(3080),
  },
  [STATE(633)] = {
    [sym_attribute_declaration] = STATE(645),
    [sym_compound_statement] = STATE(201),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(165),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [sym_identifier] = ACTIONS(3195),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(634)] = {
    [sym_attribute_declaration] = STATE(666),
    [sym_compound_statement] = STATE(375),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(338),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [sym_identifier] = ACTIONS(3197),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(635)] = {
    [sym_type_qualifier] = STATE(3485),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4810),
    [sym_sized_type_specifier] = STATE(2611),
    [sym_enum_specifier] = STATE(2611),
    [sym_struct_specifier] = STATE(2611),
    [sym_union_specifier] = STATE(2611),
    [sym_expression] = STATE(5104),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_type_descriptor] = STATE(7989),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_placeholder_type_specifier] = STATE(2611),
    [sym_decltype_auto] = STATE(2610),
    [sym_decltype] = STATE(2446),
    [sym_class_specifier] = STATE(2611),
    [sym__class_name] = STATE(8513),
    [sym_dependent_type] = STATE(2611),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_type_parameter_pack_expansion] = STATE(8435),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6274),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [aux_sym__type_definition_type_repeat1] = STATE(3485),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4515),
    [sym_identifier] = ACTIONS(2862),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(2872),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_signed] = ACTIONS(2876),
    [anon_sym_unsigned] = ACTIONS(2876),
    [anon_sym_long] = ACTIONS(2876),
    [anon_sym_short] = ACTIONS(2876),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2878),
    [anon_sym_enum] = ACTIONS(2880),
    [anon_sym_class] = ACTIONS(2882),
    [anon_sym_struct] = ACTIONS(2884),
    [anon_sym_union] = ACTIONS(2886),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2910),
    [anon_sym_decltype] = ACTIONS(2912),
    [anon_sym_typename] = ACTIONS(2914),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(636)] = {
    [sym_attribute_declaration] = STATE(637),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(445),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [sym_identifier] = ACTIONS(3119),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(637)] = {
    [sym_attribute_declaration] = STATE(642),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(391),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(642),
    [sym_identifier] = ACTIONS(3119),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(638)] = {
    [sym_attribute_declaration] = STATE(666),
    [sym_compound_statement] = STATE(375),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(398),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [sym_identifier] = ACTIONS(3197),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(639)] = {
    [sym_attribute_declaration] = STATE(666),
    [sym_compound_statement] = STATE(375),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(400),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [sym_identifier] = ACTIONS(3197),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(640)] = {
    [sym_attribute_declaration] = STATE(666),
    [sym_compound_statement] = STATE(375),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(401),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [sym_identifier] = ACTIONS(3197),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(641)] = {
    [sym_expression] = STATE(3559),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_initializer_list] = STATE(4125),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(3201),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2633),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2633),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2633),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACE] = ACTIONS(3209),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_EQ] = ACTIONS(2633),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_STAR_EQ] = ACTIONS(2635),
    [anon_sym_SLASH_EQ] = ACTIONS(2635),
    [anon_sym_PERCENT_EQ] = ACTIONS(2635),
    [anon_sym_PLUS_EQ] = ACTIONS(2635),
    [anon_sym_DASH_EQ] = ACTIONS(2635),
    [anon_sym_LT_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT_GT_EQ] = ACTIONS(2633),
    [anon_sym_AMP_EQ] = ACTIONS(2635),
    [anon_sym_CARET_EQ] = ACTIONS(2635),
    [anon_sym_PIPE_EQ] = ACTIONS(2635),
    [anon_sym_and_eq] = ACTIONS(2633),
    [anon_sym_or_eq] = ACTIONS(2633),
    [anon_sym_xor_eq] = ACTIONS(2633),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2635),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(642)] = {
    [sym_attribute_declaration] = STATE(642),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(391),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(642),
    [sym_identifier] = ACTIONS(3243),
    [anon_sym_LPAREN2] = ACTIONS(2981),
    [anon_sym_BANG] = ACTIONS(2984),
    [anon_sym_TILDE] = ACTIONS(2984),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2990),
    [anon_sym_AMP] = ACTIONS(2990),
    [anon_sym_SEMI] = ACTIONS(3246),
    [anon_sym___extension__] = ACTIONS(2996),
    [anon_sym_COLON_COLON] = ACTIONS(2999),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3002),
    [anon_sym_LBRACE] = ACTIONS(3249),
    [anon_sym_LBRACK] = ACTIONS(3008),
    [sym_primitive_type] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3252),
    [anon_sym_switch] = ACTIONS(3255),
    [anon_sym_case] = ACTIONS(3258),
    [anon_sym_default] = ACTIONS(3261),
    [anon_sym_while] = ACTIONS(3264),
    [anon_sym_do] = ACTIONS(3267),
    [anon_sym_for] = ACTIONS(3270),
    [anon_sym_return] = ACTIONS(3273),
    [anon_sym_break] = ACTIONS(3276),
    [anon_sym_continue] = ACTIONS(3279),
    [anon_sym_goto] = ACTIONS(3282),
    [anon_sym___try] = ACTIONS(3285),
    [anon_sym___leave] = ACTIONS(3288),
    [anon_sym_not] = ACTIONS(2987),
    [anon_sym_compl] = ACTIONS(2987),
    [anon_sym_DASH_DASH] = ACTIONS(3053),
    [anon_sym_PLUS_PLUS] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3056),
    [anon_sym___alignof__] = ACTIONS(3059),
    [anon_sym___alignof] = ACTIONS(3059),
    [anon_sym__alignof] = ACTIONS(3059),
    [anon_sym_alignof] = ACTIONS(3059),
    [anon_sym__Alignof] = ACTIONS(3059),
    [anon_sym_offsetof] = ACTIONS(3062),
    [anon_sym__Generic] = ACTIONS(3065),
    [anon_sym_asm] = ACTIONS(3068),
    [anon_sym___asm__] = ACTIONS(3068),
    [anon_sym___asm] = ACTIONS(3068),
    [sym_number_literal] = ACTIONS(3071),
    [anon_sym_L_SQUOTE] = ACTIONS(3074),
    [anon_sym_u_SQUOTE] = ACTIONS(3074),
    [anon_sym_U_SQUOTE] = ACTIONS(3074),
    [anon_sym_u8_SQUOTE] = ACTIONS(3074),
    [anon_sym_SQUOTE] = ACTIONS(3074),
    [anon_sym_L_DQUOTE] = ACTIONS(3077),
    [anon_sym_u_DQUOTE] = ACTIONS(3077),
    [anon_sym_U_DQUOTE] = ACTIONS(3077),
    [anon_sym_u8_DQUOTE] = ACTIONS(3077),
    [anon_sym_DQUOTE] = ACTIONS(3077),
    [sym_true] = ACTIONS(3080),
    [sym_false] = ACTIONS(3080),
    [anon_sym_NULL] = ACTIONS(3083),
    [anon_sym_nullptr] = ACTIONS(3083),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3086),
    [anon_sym_template] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3291),
    [anon_sym_delete] = ACTIONS(3095),
    [anon_sym_throw] = ACTIONS(3294),
    [anon_sym_co_return] = ACTIONS(3297),
    [anon_sym_co_yield] = ACTIONS(3300),
    [anon_sym_R_DQUOTE] = ACTIONS(3107),
    [anon_sym_LR_DQUOTE] = ACTIONS(3107),
    [anon_sym_uR_DQUOTE] = ACTIONS(3107),
    [anon_sym_UR_DQUOTE] = ACTIONS(3107),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3107),
    [anon_sym_co_await] = ACTIONS(3110),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_requires] = ACTIONS(3116),
    [sym_this] = ACTIONS(3080),
  },
  [STATE(643)] = {
    [sym_attribute_declaration] = STATE(637),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(447),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [sym_identifier] = ACTIONS(3119),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(644)] = {
    [sym_attribute_declaration] = STATE(637),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(448),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [sym_identifier] = ACTIONS(3119),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(645)] = {
    [sym_attribute_declaration] = STATE(628),
    [sym_compound_statement] = STATE(201),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(207),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(628),
    [sym_identifier] = ACTIONS(3195),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(646)] = {
    [sym_attribute_declaration] = STATE(645),
    [sym_compound_statement] = STATE(201),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(209),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [sym_identifier] = ACTIONS(3195),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(647)] = {
    [sym_attribute_declaration] = STATE(645),
    [sym_compound_statement] = STATE(201),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(217),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [sym_identifier] = ACTIONS(3195),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(648)] = {
    [sym_attribute_declaration] = STATE(645),
    [sym_compound_statement] = STATE(201),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(221),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [sym_identifier] = ACTIONS(3195),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(649)] = {
    [sym_attribute_declaration] = STATE(674),
    [sym_compound_statement] = STATE(885),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(857),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [sym_identifier] = ACTIONS(3303),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(650)] = {
    [sym_attribute_declaration] = STATE(674),
    [sym_compound_statement] = STATE(885),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(894),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [sym_identifier] = ACTIONS(3303),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(651)] = {
    [sym_attribute_declaration] = STATE(637),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(333),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [sym_identifier] = ACTIONS(3119),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(652)] = {
    [sym_attribute_declaration] = STATE(670),
    [sym_compound_statement] = STATE(368),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(343),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [sym_identifier] = ACTIONS(3121),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(653)] = {
    [sym_attribute_declaration] = STATE(645),
    [sym_compound_statement] = STATE(201),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(168),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [sym_identifier] = ACTIONS(3195),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(654)] = {
    [sym_attribute_declaration] = STATE(666),
    [sym_compound_statement] = STATE(375),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(384),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [sym_identifier] = ACTIONS(3197),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(655)] = {
    [sym_attribute_declaration] = STATE(670),
    [sym_compound_statement] = STATE(368),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(331),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [sym_identifier] = ACTIONS(3121),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(656)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(405),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(657)] = {
    [sym_attribute_declaration] = STATE(645),
    [sym_compound_statement] = STATE(201),
    [sym_attributed_statement] = STATE(201),
    [sym_statement] = STATE(184),
    [sym_labeled_statement] = STATE(201),
    [sym_expression_statement] = STATE(201),
    [sym_if_statement] = STATE(201),
    [sym_switch_statement] = STATE(201),
    [sym_case_statement] = STATE(201),
    [sym_while_statement] = STATE(201),
    [sym_do_statement] = STATE(201),
    [sym_for_statement] = STATE(201),
    [sym_return_statement] = STATE(201),
    [sym_break_statement] = STATE(201),
    [sym_continue_statement] = STATE(201),
    [sym_goto_statement] = STATE(201),
    [sym_seh_try_statement] = STATE(201),
    [sym_seh_leave_statement] = STATE(201),
    [sym_expression] = STATE(5042),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9545),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(201),
    [sym_co_return_statement] = STATE(201),
    [sym_co_yield_statement] = STATE(201),
    [sym_throw_statement] = STATE(201),
    [sym_try_statement] = STATE(201),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(645),
    [sym_identifier] = ACTIONS(3195),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(283),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(295),
    [anon_sym_switch] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(299),
    [anon_sym_default] = ACTIONS(301),
    [anon_sym_while] = ACTIONS(303),
    [anon_sym_do] = ACTIONS(305),
    [anon_sym_for] = ACTIONS(307),
    [anon_sym_return] = ACTIONS(309),
    [anon_sym_break] = ACTIONS(311),
    [anon_sym_continue] = ACTIONS(313),
    [anon_sym_goto] = ACTIONS(315),
    [anon_sym___try] = ACTIONS(317),
    [anon_sym___leave] = ACTIONS(319),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(325),
    [anon_sym_co_return] = ACTIONS(335),
    [anon_sym_co_yield] = ACTIONS(337),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(658)] = {
    [sym_attribute_declaration] = STATE(658),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(346),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(658),
    [sym_identifier] = ACTIONS(3305),
    [anon_sym_LPAREN2] = ACTIONS(2981),
    [anon_sym_BANG] = ACTIONS(2984),
    [anon_sym_TILDE] = ACTIONS(2984),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2990),
    [anon_sym_AMP] = ACTIONS(2990),
    [anon_sym_SEMI] = ACTIONS(3246),
    [anon_sym___extension__] = ACTIONS(2996),
    [anon_sym_COLON_COLON] = ACTIONS(2999),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3002),
    [anon_sym_LBRACE] = ACTIONS(3308),
    [anon_sym_LBRACK] = ACTIONS(3008),
    [sym_primitive_type] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3311),
    [anon_sym_switch] = ACTIONS(3314),
    [anon_sym_case] = ACTIONS(3317),
    [anon_sym_default] = ACTIONS(3320),
    [anon_sym_while] = ACTIONS(3323),
    [anon_sym_do] = ACTIONS(3326),
    [anon_sym_for] = ACTIONS(3329),
    [anon_sym_return] = ACTIONS(3332),
    [anon_sym_break] = ACTIONS(3335),
    [anon_sym_continue] = ACTIONS(3338),
    [anon_sym_goto] = ACTIONS(3341),
    [anon_sym___try] = ACTIONS(3344),
    [anon_sym___leave] = ACTIONS(3288),
    [anon_sym_not] = ACTIONS(2987),
    [anon_sym_compl] = ACTIONS(2987),
    [anon_sym_DASH_DASH] = ACTIONS(3053),
    [anon_sym_PLUS_PLUS] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3056),
    [anon_sym___alignof__] = ACTIONS(3059),
    [anon_sym___alignof] = ACTIONS(3059),
    [anon_sym__alignof] = ACTIONS(3059),
    [anon_sym_alignof] = ACTIONS(3059),
    [anon_sym__Alignof] = ACTIONS(3059),
    [anon_sym_offsetof] = ACTIONS(3062),
    [anon_sym__Generic] = ACTIONS(3065),
    [anon_sym_asm] = ACTIONS(3068),
    [anon_sym___asm__] = ACTIONS(3068),
    [anon_sym___asm] = ACTIONS(3068),
    [sym_number_literal] = ACTIONS(3071),
    [anon_sym_L_SQUOTE] = ACTIONS(3074),
    [anon_sym_u_SQUOTE] = ACTIONS(3074),
    [anon_sym_U_SQUOTE] = ACTIONS(3074),
    [anon_sym_u8_SQUOTE] = ACTIONS(3074),
    [anon_sym_SQUOTE] = ACTIONS(3074),
    [anon_sym_L_DQUOTE] = ACTIONS(3077),
    [anon_sym_u_DQUOTE] = ACTIONS(3077),
    [anon_sym_U_DQUOTE] = ACTIONS(3077),
    [anon_sym_u8_DQUOTE] = ACTIONS(3077),
    [anon_sym_DQUOTE] = ACTIONS(3077),
    [sym_true] = ACTIONS(3080),
    [sym_false] = ACTIONS(3080),
    [anon_sym_NULL] = ACTIONS(3083),
    [anon_sym_nullptr] = ACTIONS(3083),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3086),
    [anon_sym_template] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3347),
    [anon_sym_delete] = ACTIONS(3095),
    [anon_sym_throw] = ACTIONS(3350),
    [anon_sym_co_return] = ACTIONS(3353),
    [anon_sym_co_yield] = ACTIONS(3356),
    [anon_sym_R_DQUOTE] = ACTIONS(3107),
    [anon_sym_LR_DQUOTE] = ACTIONS(3107),
    [anon_sym_uR_DQUOTE] = ACTIONS(3107),
    [anon_sym_UR_DQUOTE] = ACTIONS(3107),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3107),
    [anon_sym_co_await] = ACTIONS(3110),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_requires] = ACTIONS(3116),
    [sym_this] = ACTIONS(3080),
  },
  [STATE(659)] = {
    [sym_attribute_declaration] = STATE(674),
    [sym_compound_statement] = STATE(885),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(860),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [sym_identifier] = ACTIONS(3303),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(660)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(7948),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(661)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(356),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(662)] = {
    [sym_attribute_declaration] = STATE(674),
    [sym_compound_statement] = STATE(885),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(873),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [sym_identifier] = ACTIONS(3303),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(663)] = {
    [sym_attribute_declaration] = STATE(674),
    [sym_compound_statement] = STATE(885),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(875),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [sym_identifier] = ACTIONS(3303),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(664)] = {
    [sym_attribute_declaration] = STATE(674),
    [sym_compound_statement] = STATE(885),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(880),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(674),
    [sym_identifier] = ACTIONS(3303),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(665)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(357),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(666)] = {
    [sym_attribute_declaration] = STATE(632),
    [sym_compound_statement] = STATE(375),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(381),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(632),
    [sym_identifier] = ACTIONS(3197),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(667)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(358),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(668)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(9181),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(669)] = {
    [sym_attribute_declaration] = STATE(658),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(346),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(658),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(670)] = {
    [sym_attribute_declaration] = STATE(679),
    [sym_compound_statement] = STATE(368),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(346),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(679),
    [sym_identifier] = ACTIONS(3121),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(671)] = {
    [sym_attribute_declaration] = STATE(637),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(335),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(637),
    [sym_identifier] = ACTIONS(3119),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(621),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_switch] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(197),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_do] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_return] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_goto] = ACTIONS(213),
    [anon_sym___try] = ACTIONS(215),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(227),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(229),
    [anon_sym_co_return] = ACTIONS(239),
    [anon_sym_co_yield] = ACTIONS(241),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(672)] = {
    [sym_attribute_declaration] = STATE(670),
    [sym_compound_statement] = STATE(368),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(405),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [sym_identifier] = ACTIONS(3121),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(673)] = {
    [sym_expression] = STATE(3661),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_initializer_list] = STATE(4246),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(3361),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2633),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2633),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACE] = ACTIONS(3369),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_EQ] = ACTIONS(2633),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_STAR_EQ] = ACTIONS(2635),
    [anon_sym_SLASH_EQ] = ACTIONS(2635),
    [anon_sym_PERCENT_EQ] = ACTIONS(2635),
    [anon_sym_PLUS_EQ] = ACTIONS(2635),
    [anon_sym_DASH_EQ] = ACTIONS(2635),
    [anon_sym_LT_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT_GT_EQ] = ACTIONS(2635),
    [anon_sym_AMP_EQ] = ACTIONS(2635),
    [anon_sym_CARET_EQ] = ACTIONS(2635),
    [anon_sym_PIPE_EQ] = ACTIONS(2635),
    [anon_sym_and_eq] = ACTIONS(2633),
    [anon_sym_or_eq] = ACTIONS(2633),
    [anon_sym_xor_eq] = ACTIONS(2633),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(2635),
  },
  [STATE(674)] = {
    [sym_attribute_declaration] = STATE(685),
    [sym_compound_statement] = STATE(885),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(891),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(685),
    [sym_identifier] = ACTIONS(3303),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1654),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(1660),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1662),
    [anon_sym_switch] = ACTIONS(1664),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1666),
    [anon_sym_do] = ACTIONS(1668),
    [anon_sym_for] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1672),
    [anon_sym_break] = ACTIONS(1674),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_goto] = ACTIONS(1678),
    [anon_sym___try] = ACTIONS(1680),
    [anon_sym___leave] = ACTIONS(1682),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(1684),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(1686),
    [anon_sym_co_return] = ACTIONS(1688),
    [anon_sym_co_yield] = ACTIONS(1690),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(675)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(9271),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(676)] = {
    [sym_expression] = STATE(3633),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_initializer_list] = STATE(2799),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(3403),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2633),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2633),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_EQ] = ACTIONS(2633),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_COLON] = ACTIONS(2633),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_STAR_EQ] = ACTIONS(2635),
    [anon_sym_SLASH_EQ] = ACTIONS(2635),
    [anon_sym_PERCENT_EQ] = ACTIONS(2635),
    [anon_sym_PLUS_EQ] = ACTIONS(2635),
    [anon_sym_DASH_EQ] = ACTIONS(2635),
    [anon_sym_LT_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT_GT_EQ] = ACTIONS(2635),
    [anon_sym_AMP_EQ] = ACTIONS(2635),
    [anon_sym_CARET_EQ] = ACTIONS(2635),
    [anon_sym_PIPE_EQ] = ACTIONS(2635),
    [anon_sym_and_eq] = ACTIONS(2633),
    [anon_sym_or_eq] = ACTIONS(2633),
    [anon_sym_xor_eq] = ACTIONS(2633),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(677)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(2923),
    [sym__declarator] = STATE(7042),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_type_qualifier] = STATE(3776),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3695),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6305),
    [sym_qualified_identifier] = STATE(3696),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [aux_sym__type_definition_type_repeat1] = STATE(3776),
    [aux_sym_pointer_declarator_repeat1] = STATE(2923),
    [sym_identifier] = ACTIONS(3417),
    [anon_sym_LPAREN2] = ACTIONS(3419),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(3421),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym___extension__] = ACTIONS(3423),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(1874),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(678)] = {
    [sym_attribute_declaration] = STATE(666),
    [sym_compound_statement] = STATE(375),
    [sym_attributed_statement] = STATE(375),
    [sym_statement] = STATE(342),
    [sym_labeled_statement] = STATE(375),
    [sym_expression_statement] = STATE(375),
    [sym_if_statement] = STATE(375),
    [sym_switch_statement] = STATE(375),
    [sym_case_statement] = STATE(375),
    [sym_while_statement] = STATE(375),
    [sym_do_statement] = STATE(375),
    [sym_for_statement] = STATE(375),
    [sym_return_statement] = STATE(375),
    [sym_break_statement] = STATE(375),
    [sym_continue_statement] = STATE(375),
    [sym_goto_statement] = STATE(375),
    [sym_seh_try_statement] = STATE(375),
    [sym_seh_leave_statement] = STATE(375),
    [sym_expression] = STATE(5041),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8603),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(375),
    [sym_co_return_statement] = STATE(375),
    [sym_co_yield_statement] = STATE(375),
    [sym_throw_statement] = STATE(375),
    [sym_try_statement] = STATE(375),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(666),
    [sym_identifier] = ACTIONS(3197),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_case] = ACTIONS(903),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(915),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_goto] = ACTIONS(919),
    [anon_sym___try] = ACTIONS(921),
    [anon_sym___leave] = ACTIONS(923),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(927),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_co_return] = ACTIONS(939),
    [anon_sym_co_yield] = ACTIONS(941),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(679)] = {
    [sym_attribute_declaration] = STATE(679),
    [sym_compound_statement] = STATE(368),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(346),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(679),
    [sym_identifier] = ACTIONS(3427),
    [anon_sym_LPAREN2] = ACTIONS(2981),
    [anon_sym_BANG] = ACTIONS(2984),
    [anon_sym_TILDE] = ACTIONS(2984),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2990),
    [anon_sym_AMP] = ACTIONS(2990),
    [anon_sym_SEMI] = ACTIONS(3430),
    [anon_sym___extension__] = ACTIONS(2996),
    [anon_sym_COLON_COLON] = ACTIONS(2999),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3002),
    [anon_sym_LBRACE] = ACTIONS(3308),
    [anon_sym_LBRACK] = ACTIONS(3008),
    [sym_primitive_type] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3433),
    [anon_sym_switch] = ACTIONS(3314),
    [anon_sym_case] = ACTIONS(3436),
    [anon_sym_default] = ACTIONS(3439),
    [anon_sym_while] = ACTIONS(3442),
    [anon_sym_do] = ACTIONS(3326),
    [anon_sym_for] = ACTIONS(3445),
    [anon_sym_return] = ACTIONS(3332),
    [anon_sym_break] = ACTIONS(3335),
    [anon_sym_continue] = ACTIONS(3338),
    [anon_sym_goto] = ACTIONS(3341),
    [anon_sym___try] = ACTIONS(3448),
    [anon_sym___leave] = ACTIONS(3451),
    [anon_sym_not] = ACTIONS(2987),
    [anon_sym_compl] = ACTIONS(2987),
    [anon_sym_DASH_DASH] = ACTIONS(3053),
    [anon_sym_PLUS_PLUS] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3056),
    [anon_sym___alignof__] = ACTIONS(3059),
    [anon_sym___alignof] = ACTIONS(3059),
    [anon_sym__alignof] = ACTIONS(3059),
    [anon_sym_alignof] = ACTIONS(3059),
    [anon_sym__Alignof] = ACTIONS(3059),
    [anon_sym_offsetof] = ACTIONS(3062),
    [anon_sym__Generic] = ACTIONS(3065),
    [anon_sym_asm] = ACTIONS(3068),
    [anon_sym___asm__] = ACTIONS(3068),
    [anon_sym___asm] = ACTIONS(3068),
    [sym_number_literal] = ACTIONS(3071),
    [anon_sym_L_SQUOTE] = ACTIONS(3074),
    [anon_sym_u_SQUOTE] = ACTIONS(3074),
    [anon_sym_U_SQUOTE] = ACTIONS(3074),
    [anon_sym_u8_SQUOTE] = ACTIONS(3074),
    [anon_sym_SQUOTE] = ACTIONS(3074),
    [anon_sym_L_DQUOTE] = ACTIONS(3077),
    [anon_sym_u_DQUOTE] = ACTIONS(3077),
    [anon_sym_U_DQUOTE] = ACTIONS(3077),
    [anon_sym_u8_DQUOTE] = ACTIONS(3077),
    [anon_sym_DQUOTE] = ACTIONS(3077),
    [sym_true] = ACTIONS(3080),
    [sym_false] = ACTIONS(3080),
    [anon_sym_NULL] = ACTIONS(3083),
    [anon_sym_nullptr] = ACTIONS(3083),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3086),
    [anon_sym_template] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3347),
    [anon_sym_delete] = ACTIONS(3095),
    [anon_sym_throw] = ACTIONS(3350),
    [anon_sym_co_return] = ACTIONS(3353),
    [anon_sym_co_yield] = ACTIONS(3356),
    [anon_sym_R_DQUOTE] = ACTIONS(3107),
    [anon_sym_LR_DQUOTE] = ACTIONS(3107),
    [anon_sym_uR_DQUOTE] = ACTIONS(3107),
    [anon_sym_UR_DQUOTE] = ACTIONS(3107),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3107),
    [anon_sym_co_await] = ACTIONS(3110),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_requires] = ACTIONS(3116),
    [sym_this] = ACTIONS(3080),
  },
  [STATE(680)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(9006),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(681)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(9219),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(682)] = {
    [sym_attribute_declaration] = STATE(670),
    [sym_compound_statement] = STATE(368),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(356),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [sym_identifier] = ACTIONS(3121),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(683)] = {
    [sym_attribute_declaration] = STATE(669),
    [sym_compound_statement] = STATE(423),
    [sym_attributed_statement] = STATE(423),
    [sym_statement] = STATE(9249),
    [sym_labeled_statement] = STATE(423),
    [sym_expression_statement] = STATE(423),
    [sym_if_statement] = STATE(423),
    [sym_switch_statement] = STATE(423),
    [sym_case_statement] = STATE(423),
    [sym_while_statement] = STATE(423),
    [sym_do_statement] = STATE(423),
    [sym_for_statement] = STATE(423),
    [sym_return_statement] = STATE(423),
    [sym_break_statement] = STATE(423),
    [sym_continue_statement] = STATE(423),
    [sym_goto_statement] = STATE(423),
    [sym_seh_try_statement] = STATE(423),
    [sym_seh_leave_statement] = STATE(423),
    [sym_expression] = STATE(5129),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9107),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(423),
    [sym_co_return_statement] = STATE(423),
    [sym_co_yield_statement] = STATE(423),
    [sym_throw_statement] = STATE(423),
    [sym_try_statement] = STATE(423),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(669),
    [sym_identifier] = ACTIONS(2972),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(1754),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1758),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(1762),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1764),
    [anon_sym___leave] = ACTIONS(217),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(684)] = {
    [sym_attribute_declaration] = STATE(670),
    [sym_compound_statement] = STATE(368),
    [sym_attributed_statement] = STATE(368),
    [sym_statement] = STATE(358),
    [sym_labeled_statement] = STATE(368),
    [sym_expression_statement] = STATE(368),
    [sym_if_statement] = STATE(368),
    [sym_switch_statement] = STATE(368),
    [sym_case_statement] = STATE(368),
    [sym_while_statement] = STATE(368),
    [sym_do_statement] = STATE(368),
    [sym_for_statement] = STATE(368),
    [sym_return_statement] = STATE(368),
    [sym_break_statement] = STATE(368),
    [sym_continue_statement] = STATE(368),
    [sym_goto_statement] = STATE(368),
    [sym_seh_try_statement] = STATE(368),
    [sym_seh_leave_statement] = STATE(368),
    [sym_expression] = STATE(5162),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9341),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(368),
    [sym_co_return_statement] = STATE(368),
    [sym_co_yield_statement] = STATE(368),
    [sym_throw_statement] = STATE(368),
    [sym_try_statement] = STATE(368),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(670),
    [sym_identifier] = ACTIONS(3121),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(1458),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1247),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1249),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_switch] = ACTIONS(81),
    [anon_sym_case] = ACTIONS(83),
    [anon_sym_default] = ACTIONS(85),
    [anon_sym_while] = ACTIONS(87),
    [anon_sym_do] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(95),
    [anon_sym_continue] = ACTIONS(97),
    [anon_sym_goto] = ACTIONS(99),
    [anon_sym___try] = ACTIONS(1462),
    [anon_sym___leave] = ACTIONS(1464),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_try] = ACTIONS(135),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_throw] = ACTIONS(139),
    [anon_sym_co_return] = ACTIONS(149),
    [anon_sym_co_yield] = ACTIONS(151),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(685)] = {
    [sym_attribute_declaration] = STATE(685),
    [sym_compound_statement] = STATE(885),
    [sym_attributed_statement] = STATE(885),
    [sym_statement] = STATE(891),
    [sym_labeled_statement] = STATE(885),
    [sym_expression_statement] = STATE(885),
    [sym_if_statement] = STATE(885),
    [sym_switch_statement] = STATE(885),
    [sym_case_statement] = STATE(885),
    [sym_while_statement] = STATE(885),
    [sym_do_statement] = STATE(885),
    [sym_for_statement] = STATE(885),
    [sym_return_statement] = STATE(885),
    [sym_break_statement] = STATE(885),
    [sym_continue_statement] = STATE(885),
    [sym_goto_statement] = STATE(885),
    [sym_seh_try_statement] = STATE(885),
    [sym_seh_leave_statement] = STATE(885),
    [sym_expression] = STATE(5091),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9064),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_for_range_loop] = STATE(885),
    [sym_co_return_statement] = STATE(885),
    [sym_co_yield_statement] = STATE(885),
    [sym_throw_statement] = STATE(885),
    [sym_try_statement] = STATE(885),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_attributed_declarator_repeat1] = STATE(685),
    [sym_identifier] = ACTIONS(3454),
    [anon_sym_LPAREN2] = ACTIONS(2981),
    [anon_sym_BANG] = ACTIONS(2984),
    [anon_sym_TILDE] = ACTIONS(2984),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2990),
    [anon_sym_AMP] = ACTIONS(2990),
    [anon_sym_SEMI] = ACTIONS(3457),
    [anon_sym___extension__] = ACTIONS(2996),
    [anon_sym_COLON_COLON] = ACTIONS(2999),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3002),
    [anon_sym_LBRACE] = ACTIONS(3460),
    [anon_sym_LBRACK] = ACTIONS(3008),
    [sym_primitive_type] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3463),
    [anon_sym_switch] = ACTIONS(3466),
    [anon_sym_case] = ACTIONS(3317),
    [anon_sym_default] = ACTIONS(3320),
    [anon_sym_while] = ACTIONS(3469),
    [anon_sym_do] = ACTIONS(3472),
    [anon_sym_for] = ACTIONS(3475),
    [anon_sym_return] = ACTIONS(3478),
    [anon_sym_break] = ACTIONS(3481),
    [anon_sym_continue] = ACTIONS(3484),
    [anon_sym_goto] = ACTIONS(3487),
    [anon_sym___try] = ACTIONS(3490),
    [anon_sym___leave] = ACTIONS(3493),
    [anon_sym_not] = ACTIONS(2987),
    [anon_sym_compl] = ACTIONS(2987),
    [anon_sym_DASH_DASH] = ACTIONS(3053),
    [anon_sym_PLUS_PLUS] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3056),
    [anon_sym___alignof__] = ACTIONS(3059),
    [anon_sym___alignof] = ACTIONS(3059),
    [anon_sym__alignof] = ACTIONS(3059),
    [anon_sym_alignof] = ACTIONS(3059),
    [anon_sym__Alignof] = ACTIONS(3059),
    [anon_sym_offsetof] = ACTIONS(3062),
    [anon_sym__Generic] = ACTIONS(3065),
    [anon_sym_asm] = ACTIONS(3068),
    [anon_sym___asm__] = ACTIONS(3068),
    [anon_sym___asm] = ACTIONS(3068),
    [sym_number_literal] = ACTIONS(3071),
    [anon_sym_L_SQUOTE] = ACTIONS(3074),
    [anon_sym_u_SQUOTE] = ACTIONS(3074),
    [anon_sym_U_SQUOTE] = ACTIONS(3074),
    [anon_sym_u8_SQUOTE] = ACTIONS(3074),
    [anon_sym_SQUOTE] = ACTIONS(3074),
    [anon_sym_L_DQUOTE] = ACTIONS(3077),
    [anon_sym_u_DQUOTE] = ACTIONS(3077),
    [anon_sym_U_DQUOTE] = ACTIONS(3077),
    [anon_sym_u8_DQUOTE] = ACTIONS(3077),
    [anon_sym_DQUOTE] = ACTIONS(3077),
    [sym_true] = ACTIONS(3080),
    [sym_false] = ACTIONS(3080),
    [anon_sym_NULL] = ACTIONS(3083),
    [anon_sym_nullptr] = ACTIONS(3083),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3086),
    [anon_sym_template] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3496),
    [anon_sym_delete] = ACTIONS(3095),
    [anon_sym_throw] = ACTIONS(3499),
    [anon_sym_co_return] = ACTIONS(3502),
    [anon_sym_co_yield] = ACTIONS(3505),
    [anon_sym_R_DQUOTE] = ACTIONS(3107),
    [anon_sym_LR_DQUOTE] = ACTIONS(3107),
    [anon_sym_uR_DQUOTE] = ACTIONS(3107),
    [anon_sym_UR_DQUOTE] = ACTIONS(3107),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3107),
    [anon_sym_co_await] = ACTIONS(3110),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_requires] = ACTIONS(3116),
    [sym_this] = ACTIONS(3080),
  },
  [STATE(686)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5270),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(9153),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(687)] = {
    [ts_builtin_sym_end] = ACTIONS(2575),
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [anon_sym___asm] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(688)] = {
    [ts_builtin_sym_end] = ACTIONS(2330),
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_include_token1] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_BANG] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_DASH] = ACTIONS(2328),
    [anon_sym_PLUS] = ACTIONS(2328),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym___device__] = ACTIONS(2328),
    [anon_sym___host__] = ACTIONS(2328),
    [anon_sym___global__] = ACTIONS(2328),
    [anon_sym___forceinline__] = ACTIONS(2328),
    [anon_sym___noinline__] = ACTIONS(2328),
    [anon_sym_virtual] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym___attribute] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym___cdecl] = ACTIONS(2328),
    [anon_sym___clrcall] = ACTIONS(2328),
    [anon_sym___stdcall] = ACTIONS(2328),
    [anon_sym___fastcall] = ACTIONS(2328),
    [anon_sym___thiscall] = ACTIONS(2328),
    [anon_sym___vectorcall] = ACTIONS(2328),
    [anon_sym_LBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym__Nonnull] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym___shared__] = ACTIONS(2328),
    [anon_sym___local__] = ACTIONS(2328),
    [anon_sym___constant__] = ACTIONS(2328),
    [anon_sym___managed__] = ACTIONS(2328),
    [anon_sym___grid_constant__] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2328),
    [anon_sym_switch] = ACTIONS(2328),
    [anon_sym_case] = ACTIONS(2328),
    [anon_sym_default] = ACTIONS(2328),
    [anon_sym_while] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2328),
    [anon_sym_for] = ACTIONS(2328),
    [anon_sym_return] = ACTIONS(2328),
    [anon_sym_break] = ACTIONS(2328),
    [anon_sym_continue] = ACTIONS(2328),
    [anon_sym_goto] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2328),
    [anon_sym_compl] = ACTIONS(2328),
    [anon_sym_DASH_DASH] = ACTIONS(2330),
    [anon_sym_PLUS_PLUS] = ACTIONS(2330),
    [anon_sym_sizeof] = ACTIONS(2328),
    [anon_sym___alignof__] = ACTIONS(2328),
    [anon_sym___alignof] = ACTIONS(2328),
    [anon_sym__alignof] = ACTIONS(2328),
    [anon_sym_alignof] = ACTIONS(2328),
    [anon_sym__Alignof] = ACTIONS(2328),
    [anon_sym_offsetof] = ACTIONS(2328),
    [anon_sym__Generic] = ACTIONS(2328),
    [anon_sym_asm] = ACTIONS(2328),
    [anon_sym___asm__] = ACTIONS(2328),
    [anon_sym___asm] = ACTIONS(2328),
    [sym_number_literal] = ACTIONS(2330),
    [anon_sym_L_SQUOTE] = ACTIONS(2330),
    [anon_sym_u_SQUOTE] = ACTIONS(2330),
    [anon_sym_U_SQUOTE] = ACTIONS(2330),
    [anon_sym_u8_SQUOTE] = ACTIONS(2330),
    [anon_sym_SQUOTE] = ACTIONS(2330),
    [anon_sym_L_DQUOTE] = ACTIONS(2330),
    [anon_sym_u_DQUOTE] = ACTIONS(2330),
    [anon_sym_U_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8_DQUOTE] = ACTIONS(2330),
    [anon_sym_DQUOTE] = ACTIONS(2330),
    [sym_true] = ACTIONS(2328),
    [sym_false] = ACTIONS(2328),
    [anon_sym_NULL] = ACTIONS(2328),
    [anon_sym_nullptr] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_delete] = ACTIONS(2328),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_namespace] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_concept] = ACTIONS(2328),
    [anon_sym_co_return] = ACTIONS(2328),
    [anon_sym_co_yield] = ACTIONS(2328),
    [anon_sym_R_DQUOTE] = ACTIONS(2330),
    [anon_sym_LR_DQUOTE] = ACTIONS(2330),
    [anon_sym_uR_DQUOTE] = ACTIONS(2330),
    [anon_sym_UR_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2330),
    [anon_sym_co_await] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(2328),
    [anon_sym_requires] = ACTIONS(2328),
    [sym_this] = ACTIONS(2328),
    [anon_sym___launch_bounds__] = ACTIONS(2328),
  },
  [STATE(689)] = {
    [ts_builtin_sym_end] = ACTIONS(2232),
    [sym_identifier] = ACTIONS(2230),
    [aux_sym_preproc_include_token1] = ACTIONS(2230),
    [aux_sym_preproc_def_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2230),
    [sym_preproc_directive] = ACTIONS(2230),
    [anon_sym_LPAREN2] = ACTIONS(2232),
    [anon_sym_BANG] = ACTIONS(2232),
    [anon_sym_TILDE] = ACTIONS(2232),
    [anon_sym_DASH] = ACTIONS(2230),
    [anon_sym_PLUS] = ACTIONS(2230),
    [anon_sym_STAR] = ACTIONS(2232),
    [anon_sym_AMP_AMP] = ACTIONS(2232),
    [anon_sym_AMP] = ACTIONS(2230),
    [anon_sym_SEMI] = ACTIONS(2232),
    [anon_sym___extension__] = ACTIONS(2230),
    [anon_sym_typedef] = ACTIONS(2230),
    [anon_sym___device__] = ACTIONS(2230),
    [anon_sym___host__] = ACTIONS(2230),
    [anon_sym___global__] = ACTIONS(2230),
    [anon_sym___forceinline__] = ACTIONS(2230),
    [anon_sym___noinline__] = ACTIONS(2230),
    [anon_sym_virtual] = ACTIONS(2230),
    [anon_sym_extern] = ACTIONS(2230),
    [anon_sym___attribute__] = ACTIONS(2230),
    [anon_sym___attribute] = ACTIONS(2230),
    [anon_sym_COLON_COLON] = ACTIONS(2232),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2232),
    [anon_sym___declspec] = ACTIONS(2230),
    [anon_sym___based] = ACTIONS(2230),
    [anon_sym___cdecl] = ACTIONS(2230),
    [anon_sym___clrcall] = ACTIONS(2230),
    [anon_sym___stdcall] = ACTIONS(2230),
    [anon_sym___fastcall] = ACTIONS(2230),
    [anon_sym___thiscall] = ACTIONS(2230),
    [anon_sym___vectorcall] = ACTIONS(2230),
    [anon_sym_LBRACE] = ACTIONS(2232),
    [anon_sym_signed] = ACTIONS(2230),
    [anon_sym_unsigned] = ACTIONS(2230),
    [anon_sym_long] = ACTIONS(2230),
    [anon_sym_short] = ACTIONS(2230),
    [anon_sym_LBRACK] = ACTIONS(2230),
    [anon_sym_static] = ACTIONS(2230),
    [anon_sym_register] = ACTIONS(2230),
    [anon_sym_inline] = ACTIONS(2230),
    [anon_sym___inline] = ACTIONS(2230),
    [anon_sym___inline__] = ACTIONS(2230),
    [anon_sym___forceinline] = ACTIONS(2230),
    [anon_sym_thread_local] = ACTIONS(2230),
    [anon_sym___thread] = ACTIONS(2230),
    [anon_sym_const] = ACTIONS(2230),
    [anon_sym_constexpr] = ACTIONS(2230),
    [anon_sym_volatile] = ACTIONS(2230),
    [anon_sym_restrict] = ACTIONS(2230),
    [anon_sym___restrict__] = ACTIONS(2230),
    [anon_sym__Atomic] = ACTIONS(2230),
    [anon_sym__Noreturn] = ACTIONS(2230),
    [anon_sym_noreturn] = ACTIONS(2230),
    [anon_sym__Nonnull] = ACTIONS(2230),
    [anon_sym_mutable] = ACTIONS(2230),
    [anon_sym_constinit] = ACTIONS(2230),
    [anon_sym_consteval] = ACTIONS(2230),
    [anon_sym___shared__] = ACTIONS(2230),
    [anon_sym___local__] = ACTIONS(2230),
    [anon_sym___constant__] = ACTIONS(2230),
    [anon_sym___managed__] = ACTIONS(2230),
    [anon_sym___grid_constant__] = ACTIONS(2230),
    [anon_sym_alignas] = ACTIONS(2230),
    [anon_sym__Alignas] = ACTIONS(2230),
    [sym_primitive_type] = ACTIONS(2230),
    [anon_sym_enum] = ACTIONS(2230),
    [anon_sym_class] = ACTIONS(2230),
    [anon_sym_struct] = ACTIONS(2230),
    [anon_sym_union] = ACTIONS(2230),
    [anon_sym_if] = ACTIONS(2230),
    [anon_sym_switch] = ACTIONS(2230),
    [anon_sym_case] = ACTIONS(2230),
    [anon_sym_default] = ACTIONS(2230),
    [anon_sym_while] = ACTIONS(2230),
    [anon_sym_do] = ACTIONS(2230),
    [anon_sym_for] = ACTIONS(2230),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_break] = ACTIONS(2230),
    [anon_sym_continue] = ACTIONS(2230),
    [anon_sym_goto] = ACTIONS(2230),
    [anon_sym_not] = ACTIONS(2230),
    [anon_sym_compl] = ACTIONS(2230),
    [anon_sym_DASH_DASH] = ACTIONS(2232),
    [anon_sym_PLUS_PLUS] = ACTIONS(2232),
    [anon_sym_sizeof] = ACTIONS(2230),
    [anon_sym___alignof__] = ACTIONS(2230),
    [anon_sym___alignof] = ACTIONS(2230),
    [anon_sym__alignof] = ACTIONS(2230),
    [anon_sym_alignof] = ACTIONS(2230),
    [anon_sym__Alignof] = ACTIONS(2230),
    [anon_sym_offsetof] = ACTIONS(2230),
    [anon_sym__Generic] = ACTIONS(2230),
    [anon_sym_asm] = ACTIONS(2230),
    [anon_sym___asm__] = ACTIONS(2230),
    [anon_sym___asm] = ACTIONS(2230),
    [sym_number_literal] = ACTIONS(2232),
    [anon_sym_L_SQUOTE] = ACTIONS(2232),
    [anon_sym_u_SQUOTE] = ACTIONS(2232),
    [anon_sym_U_SQUOTE] = ACTIONS(2232),
    [anon_sym_u8_SQUOTE] = ACTIONS(2232),
    [anon_sym_SQUOTE] = ACTIONS(2232),
    [anon_sym_L_DQUOTE] = ACTIONS(2232),
    [anon_sym_u_DQUOTE] = ACTIONS(2232),
    [anon_sym_U_DQUOTE] = ACTIONS(2232),
    [anon_sym_u8_DQUOTE] = ACTIONS(2232),
    [anon_sym_DQUOTE] = ACTIONS(2232),
    [sym_true] = ACTIONS(2230),
    [sym_false] = ACTIONS(2230),
    [anon_sym_NULL] = ACTIONS(2230),
    [anon_sym_nullptr] = ACTIONS(2230),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2230),
    [anon_sym_decltype] = ACTIONS(2230),
    [anon_sym_explicit] = ACTIONS(2230),
    [anon_sym_typename] = ACTIONS(2230),
    [anon_sym_template] = ACTIONS(2230),
    [anon_sym_operator] = ACTIONS(2230),
    [anon_sym_try] = ACTIONS(2230),
    [anon_sym_delete] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2230),
    [anon_sym_namespace] = ACTIONS(2230),
    [anon_sym_using] = ACTIONS(2230),
    [anon_sym_static_assert] = ACTIONS(2230),
    [anon_sym_concept] = ACTIONS(2230),
    [anon_sym_co_return] = ACTIONS(2230),
    [anon_sym_co_yield] = ACTIONS(2230),
    [anon_sym_R_DQUOTE] = ACTIONS(2232),
    [anon_sym_LR_DQUOTE] = ACTIONS(2232),
    [anon_sym_uR_DQUOTE] = ACTIONS(2232),
    [anon_sym_UR_DQUOTE] = ACTIONS(2232),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2232),
    [anon_sym_co_await] = ACTIONS(2230),
    [anon_sym_new] = ACTIONS(2230),
    [anon_sym_requires] = ACTIONS(2230),
    [sym_this] = ACTIONS(2230),
    [anon_sym___launch_bounds__] = ACTIONS(2230),
  },
  [STATE(690)] = {
    [ts_builtin_sym_end] = ACTIONS(2318),
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_include_token1] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_BANG] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym___device__] = ACTIONS(2316),
    [anon_sym___host__] = ACTIONS(2316),
    [anon_sym___global__] = ACTIONS(2316),
    [anon_sym___forceinline__] = ACTIONS(2316),
    [anon_sym___noinline__] = ACTIONS(2316),
    [anon_sym_virtual] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym___attribute] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym___cdecl] = ACTIONS(2316),
    [anon_sym___clrcall] = ACTIONS(2316),
    [anon_sym___stdcall] = ACTIONS(2316),
    [anon_sym___fastcall] = ACTIONS(2316),
    [anon_sym___thiscall] = ACTIONS(2316),
    [anon_sym___vectorcall] = ACTIONS(2316),
    [anon_sym_LBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym__Nonnull] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym___shared__] = ACTIONS(2316),
    [anon_sym___local__] = ACTIONS(2316),
    [anon_sym___constant__] = ACTIONS(2316),
    [anon_sym___managed__] = ACTIONS(2316),
    [anon_sym___grid_constant__] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_switch] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_default] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_return] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_goto] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_compl] = ACTIONS(2316),
    [anon_sym_DASH_DASH] = ACTIONS(2318),
    [anon_sym_PLUS_PLUS] = ACTIONS(2318),
    [anon_sym_sizeof] = ACTIONS(2316),
    [anon_sym___alignof__] = ACTIONS(2316),
    [anon_sym___alignof] = ACTIONS(2316),
    [anon_sym__alignof] = ACTIONS(2316),
    [anon_sym_alignof] = ACTIONS(2316),
    [anon_sym__Alignof] = ACTIONS(2316),
    [anon_sym_offsetof] = ACTIONS(2316),
    [anon_sym__Generic] = ACTIONS(2316),
    [anon_sym_asm] = ACTIONS(2316),
    [anon_sym___asm__] = ACTIONS(2316),
    [anon_sym___asm] = ACTIONS(2316),
    [sym_number_literal] = ACTIONS(2318),
    [anon_sym_L_SQUOTE] = ACTIONS(2318),
    [anon_sym_u_SQUOTE] = ACTIONS(2318),
    [anon_sym_U_SQUOTE] = ACTIONS(2318),
    [anon_sym_u8_SQUOTE] = ACTIONS(2318),
    [anon_sym_SQUOTE] = ACTIONS(2318),
    [anon_sym_L_DQUOTE] = ACTIONS(2318),
    [anon_sym_u_DQUOTE] = ACTIONS(2318),
    [anon_sym_U_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8_DQUOTE] = ACTIONS(2318),
    [anon_sym_DQUOTE] = ACTIONS(2318),
    [sym_true] = ACTIONS(2316),
    [sym_false] = ACTIONS(2316),
    [anon_sym_NULL] = ACTIONS(2316),
    [anon_sym_nullptr] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_try] = ACTIONS(2316),
    [anon_sym_delete] = ACTIONS(2316),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_namespace] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_concept] = ACTIONS(2316),
    [anon_sym_co_return] = ACTIONS(2316),
    [anon_sym_co_yield] = ACTIONS(2316),
    [anon_sym_R_DQUOTE] = ACTIONS(2318),
    [anon_sym_LR_DQUOTE] = ACTIONS(2318),
    [anon_sym_uR_DQUOTE] = ACTIONS(2318),
    [anon_sym_UR_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2318),
    [anon_sym_co_await] = ACTIONS(2316),
    [anon_sym_new] = ACTIONS(2316),
    [anon_sym_requires] = ACTIONS(2316),
    [sym_this] = ACTIONS(2316),
    [anon_sym___launch_bounds__] = ACTIONS(2316),
  },
  [STATE(691)] = {
    [ts_builtin_sym_end] = ACTIONS(2579),
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_include_token1] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_BANG] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym___device__] = ACTIONS(2577),
    [anon_sym___host__] = ACTIONS(2577),
    [anon_sym___global__] = ACTIONS(2577),
    [anon_sym___forceinline__] = ACTIONS(2577),
    [anon_sym___noinline__] = ACTIONS(2577),
    [anon_sym_virtual] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym___attribute] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym___cdecl] = ACTIONS(2577),
    [anon_sym___clrcall] = ACTIONS(2577),
    [anon_sym___stdcall] = ACTIONS(2577),
    [anon_sym___fastcall] = ACTIONS(2577),
    [anon_sym___thiscall] = ACTIONS(2577),
    [anon_sym___vectorcall] = ACTIONS(2577),
    [anon_sym_LBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym__Nonnull] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym___shared__] = ACTIONS(2577),
    [anon_sym___local__] = ACTIONS(2577),
    [anon_sym___constant__] = ACTIONS(2577),
    [anon_sym___managed__] = ACTIONS(2577),
    [anon_sym___grid_constant__] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_switch] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_default] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_do] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_return] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_goto] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_compl] = ACTIONS(2577),
    [anon_sym_DASH_DASH] = ACTIONS(2579),
    [anon_sym_PLUS_PLUS] = ACTIONS(2579),
    [anon_sym_sizeof] = ACTIONS(2577),
    [anon_sym___alignof__] = ACTIONS(2577),
    [anon_sym___alignof] = ACTIONS(2577),
    [anon_sym__alignof] = ACTIONS(2577),
    [anon_sym_alignof] = ACTIONS(2577),
    [anon_sym__Alignof] = ACTIONS(2577),
    [anon_sym_offsetof] = ACTIONS(2577),
    [anon_sym__Generic] = ACTIONS(2577),
    [anon_sym_asm] = ACTIONS(2577),
    [anon_sym___asm__] = ACTIONS(2577),
    [anon_sym___asm] = ACTIONS(2577),
    [sym_number_literal] = ACTIONS(2579),
    [anon_sym_L_SQUOTE] = ACTIONS(2579),
    [anon_sym_u_SQUOTE] = ACTIONS(2579),
    [anon_sym_U_SQUOTE] = ACTIONS(2579),
    [anon_sym_u8_SQUOTE] = ACTIONS(2579),
    [anon_sym_SQUOTE] = ACTIONS(2579),
    [anon_sym_L_DQUOTE] = ACTIONS(2579),
    [anon_sym_u_DQUOTE] = ACTIONS(2579),
    [anon_sym_U_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8_DQUOTE] = ACTIONS(2579),
    [anon_sym_DQUOTE] = ACTIONS(2579),
    [sym_true] = ACTIONS(2577),
    [sym_false] = ACTIONS(2577),
    [anon_sym_NULL] = ACTIONS(2577),
    [anon_sym_nullptr] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_try] = ACTIONS(2577),
    [anon_sym_delete] = ACTIONS(2577),
    [anon_sym_throw] = ACTIONS(2577),
    [anon_sym_namespace] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_concept] = ACTIONS(2577),
    [anon_sym_co_return] = ACTIONS(2577),
    [anon_sym_co_yield] = ACTIONS(2577),
    [anon_sym_R_DQUOTE] = ACTIONS(2579),
    [anon_sym_LR_DQUOTE] = ACTIONS(2579),
    [anon_sym_uR_DQUOTE] = ACTIONS(2579),
    [anon_sym_UR_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2579),
    [anon_sym_co_await] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(2577),
    [anon_sym_requires] = ACTIONS(2577),
    [sym_this] = ACTIONS(2577),
    [anon_sym___launch_bounds__] = ACTIONS(2577),
  },
  [STATE(692)] = {
    [ts_builtin_sym_end] = ACTIONS(2228),
    [sym_identifier] = ACTIONS(2226),
    [aux_sym_preproc_include_token1] = ACTIONS(2226),
    [aux_sym_preproc_def_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2226),
    [sym_preproc_directive] = ACTIONS(2226),
    [anon_sym_LPAREN2] = ACTIONS(2228),
    [anon_sym_BANG] = ACTIONS(2228),
    [anon_sym_TILDE] = ACTIONS(2228),
    [anon_sym_DASH] = ACTIONS(2226),
    [anon_sym_PLUS] = ACTIONS(2226),
    [anon_sym_STAR] = ACTIONS(2228),
    [anon_sym_AMP_AMP] = ACTIONS(2228),
    [anon_sym_AMP] = ACTIONS(2226),
    [anon_sym_SEMI] = ACTIONS(2228),
    [anon_sym___extension__] = ACTIONS(2226),
    [anon_sym_typedef] = ACTIONS(2226),
    [anon_sym___device__] = ACTIONS(2226),
    [anon_sym___host__] = ACTIONS(2226),
    [anon_sym___global__] = ACTIONS(2226),
    [anon_sym___forceinline__] = ACTIONS(2226),
    [anon_sym___noinline__] = ACTIONS(2226),
    [anon_sym_virtual] = ACTIONS(2226),
    [anon_sym_extern] = ACTIONS(2226),
    [anon_sym___attribute__] = ACTIONS(2226),
    [anon_sym___attribute] = ACTIONS(2226),
    [anon_sym_COLON_COLON] = ACTIONS(2228),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2228),
    [anon_sym___declspec] = ACTIONS(2226),
    [anon_sym___based] = ACTIONS(2226),
    [anon_sym___cdecl] = ACTIONS(2226),
    [anon_sym___clrcall] = ACTIONS(2226),
    [anon_sym___stdcall] = ACTIONS(2226),
    [anon_sym___fastcall] = ACTIONS(2226),
    [anon_sym___thiscall] = ACTIONS(2226),
    [anon_sym___vectorcall] = ACTIONS(2226),
    [anon_sym_LBRACE] = ACTIONS(2228),
    [anon_sym_signed] = ACTIONS(2226),
    [anon_sym_unsigned] = ACTIONS(2226),
    [anon_sym_long] = ACTIONS(2226),
    [anon_sym_short] = ACTIONS(2226),
    [anon_sym_LBRACK] = ACTIONS(2226),
    [anon_sym_static] = ACTIONS(2226),
    [anon_sym_register] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(2226),
    [anon_sym___inline] = ACTIONS(2226),
    [anon_sym___inline__] = ACTIONS(2226),
    [anon_sym___forceinline] = ACTIONS(2226),
    [anon_sym_thread_local] = ACTIONS(2226),
    [anon_sym___thread] = ACTIONS(2226),
    [anon_sym_const] = ACTIONS(2226),
    [anon_sym_constexpr] = ACTIONS(2226),
    [anon_sym_volatile] = ACTIONS(2226),
    [anon_sym_restrict] = ACTIONS(2226),
    [anon_sym___restrict__] = ACTIONS(2226),
    [anon_sym__Atomic] = ACTIONS(2226),
    [anon_sym__Noreturn] = ACTIONS(2226),
    [anon_sym_noreturn] = ACTIONS(2226),
    [anon_sym__Nonnull] = ACTIONS(2226),
    [anon_sym_mutable] = ACTIONS(2226),
    [anon_sym_constinit] = ACTIONS(2226),
    [anon_sym_consteval] = ACTIONS(2226),
    [anon_sym___shared__] = ACTIONS(2226),
    [anon_sym___local__] = ACTIONS(2226),
    [anon_sym___constant__] = ACTIONS(2226),
    [anon_sym___managed__] = ACTIONS(2226),
    [anon_sym___grid_constant__] = ACTIONS(2226),
    [anon_sym_alignas] = ACTIONS(2226),
    [anon_sym__Alignas] = ACTIONS(2226),
    [sym_primitive_type] = ACTIONS(2226),
    [anon_sym_enum] = ACTIONS(2226),
    [anon_sym_class] = ACTIONS(2226),
    [anon_sym_struct] = ACTIONS(2226),
    [anon_sym_union] = ACTIONS(2226),
    [anon_sym_if] = ACTIONS(2226),
    [anon_sym_switch] = ACTIONS(2226),
    [anon_sym_case] = ACTIONS(2226),
    [anon_sym_default] = ACTIONS(2226),
    [anon_sym_while] = ACTIONS(2226),
    [anon_sym_do] = ACTIONS(2226),
    [anon_sym_for] = ACTIONS(2226),
    [anon_sym_return] = ACTIONS(2226),
    [anon_sym_break] = ACTIONS(2226),
    [anon_sym_continue] = ACTIONS(2226),
    [anon_sym_goto] = ACTIONS(2226),
    [anon_sym_not] = ACTIONS(2226),
    [anon_sym_compl] = ACTIONS(2226),
    [anon_sym_DASH_DASH] = ACTIONS(2228),
    [anon_sym_PLUS_PLUS] = ACTIONS(2228),
    [anon_sym_sizeof] = ACTIONS(2226),
    [anon_sym___alignof__] = ACTIONS(2226),
    [anon_sym___alignof] = ACTIONS(2226),
    [anon_sym__alignof] = ACTIONS(2226),
    [anon_sym_alignof] = ACTIONS(2226),
    [anon_sym__Alignof] = ACTIONS(2226),
    [anon_sym_offsetof] = ACTIONS(2226),
    [anon_sym__Generic] = ACTIONS(2226),
    [anon_sym_asm] = ACTIONS(2226),
    [anon_sym___asm__] = ACTIONS(2226),
    [anon_sym___asm] = ACTIONS(2226),
    [sym_number_literal] = ACTIONS(2228),
    [anon_sym_L_SQUOTE] = ACTIONS(2228),
    [anon_sym_u_SQUOTE] = ACTIONS(2228),
    [anon_sym_U_SQUOTE] = ACTIONS(2228),
    [anon_sym_u8_SQUOTE] = ACTIONS(2228),
    [anon_sym_SQUOTE] = ACTIONS(2228),
    [anon_sym_L_DQUOTE] = ACTIONS(2228),
    [anon_sym_u_DQUOTE] = ACTIONS(2228),
    [anon_sym_U_DQUOTE] = ACTIONS(2228),
    [anon_sym_u8_DQUOTE] = ACTIONS(2228),
    [anon_sym_DQUOTE] = ACTIONS(2228),
    [sym_true] = ACTIONS(2226),
    [sym_false] = ACTIONS(2226),
    [anon_sym_NULL] = ACTIONS(2226),
    [anon_sym_nullptr] = ACTIONS(2226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2226),
    [anon_sym_decltype] = ACTIONS(2226),
    [anon_sym_explicit] = ACTIONS(2226),
    [anon_sym_typename] = ACTIONS(2226),
    [anon_sym_template] = ACTIONS(2226),
    [anon_sym_operator] = ACTIONS(2226),
    [anon_sym_try] = ACTIONS(2226),
    [anon_sym_delete] = ACTIONS(2226),
    [anon_sym_throw] = ACTIONS(2226),
    [anon_sym_namespace] = ACTIONS(2226),
    [anon_sym_using] = ACTIONS(2226),
    [anon_sym_static_assert] = ACTIONS(2226),
    [anon_sym_concept] = ACTIONS(2226),
    [anon_sym_co_return] = ACTIONS(2226),
    [anon_sym_co_yield] = ACTIONS(2226),
    [anon_sym_R_DQUOTE] = ACTIONS(2228),
    [anon_sym_LR_DQUOTE] = ACTIONS(2228),
    [anon_sym_uR_DQUOTE] = ACTIONS(2228),
    [anon_sym_UR_DQUOTE] = ACTIONS(2228),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2228),
    [anon_sym_co_await] = ACTIONS(2226),
    [anon_sym_new] = ACTIONS(2226),
    [anon_sym_requires] = ACTIONS(2226),
    [sym_this] = ACTIONS(2226),
    [anon_sym___launch_bounds__] = ACTIONS(2226),
  },
  [STATE(693)] = {
    [ts_builtin_sym_end] = ACTIONS(2433),
    [sym_identifier] = ACTIONS(2431),
    [aux_sym_preproc_include_token1] = ACTIONS(2431),
    [aux_sym_preproc_def_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2431),
    [sym_preproc_directive] = ACTIONS(2431),
    [anon_sym_LPAREN2] = ACTIONS(2433),
    [anon_sym_BANG] = ACTIONS(2433),
    [anon_sym_TILDE] = ACTIONS(2433),
    [anon_sym_DASH] = ACTIONS(2431),
    [anon_sym_PLUS] = ACTIONS(2431),
    [anon_sym_STAR] = ACTIONS(2433),
    [anon_sym_AMP_AMP] = ACTIONS(2433),
    [anon_sym_AMP] = ACTIONS(2431),
    [anon_sym_SEMI] = ACTIONS(2433),
    [anon_sym___extension__] = ACTIONS(2431),
    [anon_sym_typedef] = ACTIONS(2431),
    [anon_sym___device__] = ACTIONS(2431),
    [anon_sym___host__] = ACTIONS(2431),
    [anon_sym___global__] = ACTIONS(2431),
    [anon_sym___forceinline__] = ACTIONS(2431),
    [anon_sym___noinline__] = ACTIONS(2431),
    [anon_sym_virtual] = ACTIONS(2431),
    [anon_sym_extern] = ACTIONS(2431),
    [anon_sym___attribute__] = ACTIONS(2431),
    [anon_sym___attribute] = ACTIONS(2431),
    [anon_sym_COLON_COLON] = ACTIONS(2433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2433),
    [anon_sym___declspec] = ACTIONS(2431),
    [anon_sym___based] = ACTIONS(2431),
    [anon_sym___cdecl] = ACTIONS(2431),
    [anon_sym___clrcall] = ACTIONS(2431),
    [anon_sym___stdcall] = ACTIONS(2431),
    [anon_sym___fastcall] = ACTIONS(2431),
    [anon_sym___thiscall] = ACTIONS(2431),
    [anon_sym___vectorcall] = ACTIONS(2431),
    [anon_sym_LBRACE] = ACTIONS(2433),
    [anon_sym_signed] = ACTIONS(2431),
    [anon_sym_unsigned] = ACTIONS(2431),
    [anon_sym_long] = ACTIONS(2431),
    [anon_sym_short] = ACTIONS(2431),
    [anon_sym_LBRACK] = ACTIONS(2431),
    [anon_sym_static] = ACTIONS(2431),
    [anon_sym_register] = ACTIONS(2431),
    [anon_sym_inline] = ACTIONS(2431),
    [anon_sym___inline] = ACTIONS(2431),
    [anon_sym___inline__] = ACTIONS(2431),
    [anon_sym___forceinline] = ACTIONS(2431),
    [anon_sym_thread_local] = ACTIONS(2431),
    [anon_sym___thread] = ACTIONS(2431),
    [anon_sym_const] = ACTIONS(2431),
    [anon_sym_constexpr] = ACTIONS(2431),
    [anon_sym_volatile] = ACTIONS(2431),
    [anon_sym_restrict] = ACTIONS(2431),
    [anon_sym___restrict__] = ACTIONS(2431),
    [anon_sym__Atomic] = ACTIONS(2431),
    [anon_sym__Noreturn] = ACTIONS(2431),
    [anon_sym_noreturn] = ACTIONS(2431),
    [anon_sym__Nonnull] = ACTIONS(2431),
    [anon_sym_mutable] = ACTIONS(2431),
    [anon_sym_constinit] = ACTIONS(2431),
    [anon_sym_consteval] = ACTIONS(2431),
    [anon_sym___shared__] = ACTIONS(2431),
    [anon_sym___local__] = ACTIONS(2431),
    [anon_sym___constant__] = ACTIONS(2431),
    [anon_sym___managed__] = ACTIONS(2431),
    [anon_sym___grid_constant__] = ACTIONS(2431),
    [anon_sym_alignas] = ACTIONS(2431),
    [anon_sym__Alignas] = ACTIONS(2431),
    [sym_primitive_type] = ACTIONS(2431),
    [anon_sym_enum] = ACTIONS(2431),
    [anon_sym_class] = ACTIONS(2431),
    [anon_sym_struct] = ACTIONS(2431),
    [anon_sym_union] = ACTIONS(2431),
    [anon_sym_if] = ACTIONS(2431),
    [anon_sym_switch] = ACTIONS(2431),
    [anon_sym_case] = ACTIONS(2431),
    [anon_sym_default] = ACTIONS(2431),
    [anon_sym_while] = ACTIONS(2431),
    [anon_sym_do] = ACTIONS(2431),
    [anon_sym_for] = ACTIONS(2431),
    [anon_sym_return] = ACTIONS(2431),
    [anon_sym_break] = ACTIONS(2431),
    [anon_sym_continue] = ACTIONS(2431),
    [anon_sym_goto] = ACTIONS(2431),
    [anon_sym_not] = ACTIONS(2431),
    [anon_sym_compl] = ACTIONS(2431),
    [anon_sym_DASH_DASH] = ACTIONS(2433),
    [anon_sym_PLUS_PLUS] = ACTIONS(2433),
    [anon_sym_sizeof] = ACTIONS(2431),
    [anon_sym___alignof__] = ACTIONS(2431),
    [anon_sym___alignof] = ACTIONS(2431),
    [anon_sym__alignof] = ACTIONS(2431),
    [anon_sym_alignof] = ACTIONS(2431),
    [anon_sym__Alignof] = ACTIONS(2431),
    [anon_sym_offsetof] = ACTIONS(2431),
    [anon_sym__Generic] = ACTIONS(2431),
    [anon_sym_asm] = ACTIONS(2431),
    [anon_sym___asm__] = ACTIONS(2431),
    [anon_sym___asm] = ACTIONS(2431),
    [sym_number_literal] = ACTIONS(2433),
    [anon_sym_L_SQUOTE] = ACTIONS(2433),
    [anon_sym_u_SQUOTE] = ACTIONS(2433),
    [anon_sym_U_SQUOTE] = ACTIONS(2433),
    [anon_sym_u8_SQUOTE] = ACTIONS(2433),
    [anon_sym_SQUOTE] = ACTIONS(2433),
    [anon_sym_L_DQUOTE] = ACTIONS(2433),
    [anon_sym_u_DQUOTE] = ACTIONS(2433),
    [anon_sym_U_DQUOTE] = ACTIONS(2433),
    [anon_sym_u8_DQUOTE] = ACTIONS(2433),
    [anon_sym_DQUOTE] = ACTIONS(2433),
    [sym_true] = ACTIONS(2431),
    [sym_false] = ACTIONS(2431),
    [anon_sym_NULL] = ACTIONS(2431),
    [anon_sym_nullptr] = ACTIONS(2431),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2431),
    [anon_sym_decltype] = ACTIONS(2431),
    [anon_sym_explicit] = ACTIONS(2431),
    [anon_sym_typename] = ACTIONS(2431),
    [anon_sym_template] = ACTIONS(2431),
    [anon_sym_operator] = ACTIONS(2431),
    [anon_sym_try] = ACTIONS(2431),
    [anon_sym_delete] = ACTIONS(2431),
    [anon_sym_throw] = ACTIONS(2431),
    [anon_sym_namespace] = ACTIONS(2431),
    [anon_sym_using] = ACTIONS(2431),
    [anon_sym_static_assert] = ACTIONS(2431),
    [anon_sym_concept] = ACTIONS(2431),
    [anon_sym_co_return] = ACTIONS(2431),
    [anon_sym_co_yield] = ACTIONS(2431),
    [anon_sym_R_DQUOTE] = ACTIONS(2433),
    [anon_sym_LR_DQUOTE] = ACTIONS(2433),
    [anon_sym_uR_DQUOTE] = ACTIONS(2433),
    [anon_sym_UR_DQUOTE] = ACTIONS(2433),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2433),
    [anon_sym_co_await] = ACTIONS(2431),
    [anon_sym_new] = ACTIONS(2431),
    [anon_sym_requires] = ACTIONS(2431),
    [sym_this] = ACTIONS(2431),
    [anon_sym___launch_bounds__] = ACTIONS(2431),
  },
  [STATE(694)] = {
    [ts_builtin_sym_end] = ACTIONS(2571),
    [sym_identifier] = ACTIONS(2569),
    [aux_sym_preproc_include_token1] = ACTIONS(2569),
    [aux_sym_preproc_def_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2569),
    [sym_preproc_directive] = ACTIONS(2569),
    [anon_sym_LPAREN2] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2571),
    [anon_sym_TILDE] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2571),
    [anon_sym_AMP_AMP] = ACTIONS(2571),
    [anon_sym_AMP] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym___extension__] = ACTIONS(2569),
    [anon_sym_typedef] = ACTIONS(2569),
    [anon_sym___device__] = ACTIONS(2569),
    [anon_sym___host__] = ACTIONS(2569),
    [anon_sym___global__] = ACTIONS(2569),
    [anon_sym___forceinline__] = ACTIONS(2569),
    [anon_sym___noinline__] = ACTIONS(2569),
    [anon_sym_virtual] = ACTIONS(2569),
    [anon_sym_extern] = ACTIONS(2569),
    [anon_sym___attribute__] = ACTIONS(2569),
    [anon_sym___attribute] = ACTIONS(2569),
    [anon_sym_COLON_COLON] = ACTIONS(2571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2571),
    [anon_sym___declspec] = ACTIONS(2569),
    [anon_sym___based] = ACTIONS(2569),
    [anon_sym___cdecl] = ACTIONS(2569),
    [anon_sym___clrcall] = ACTIONS(2569),
    [anon_sym___stdcall] = ACTIONS(2569),
    [anon_sym___fastcall] = ACTIONS(2569),
    [anon_sym___thiscall] = ACTIONS(2569),
    [anon_sym___vectorcall] = ACTIONS(2569),
    [anon_sym_LBRACE] = ACTIONS(2571),
    [anon_sym_signed] = ACTIONS(2569),
    [anon_sym_unsigned] = ACTIONS(2569),
    [anon_sym_long] = ACTIONS(2569),
    [anon_sym_short] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2569),
    [anon_sym_register] = ACTIONS(2569),
    [anon_sym_inline] = ACTIONS(2569),
    [anon_sym___inline] = ACTIONS(2569),
    [anon_sym___inline__] = ACTIONS(2569),
    [anon_sym___forceinline] = ACTIONS(2569),
    [anon_sym_thread_local] = ACTIONS(2569),
    [anon_sym___thread] = ACTIONS(2569),
    [anon_sym_const] = ACTIONS(2569),
    [anon_sym_constexpr] = ACTIONS(2569),
    [anon_sym_volatile] = ACTIONS(2569),
    [anon_sym_restrict] = ACTIONS(2569),
    [anon_sym___restrict__] = ACTIONS(2569),
    [anon_sym__Atomic] = ACTIONS(2569),
    [anon_sym__Noreturn] = ACTIONS(2569),
    [anon_sym_noreturn] = ACTIONS(2569),
    [anon_sym__Nonnull] = ACTIONS(2569),
    [anon_sym_mutable] = ACTIONS(2569),
    [anon_sym_constinit] = ACTIONS(2569),
    [anon_sym_consteval] = ACTIONS(2569),
    [anon_sym___shared__] = ACTIONS(2569),
    [anon_sym___local__] = ACTIONS(2569),
    [anon_sym___constant__] = ACTIONS(2569),
    [anon_sym___managed__] = ACTIONS(2569),
    [anon_sym___grid_constant__] = ACTIONS(2569),
    [anon_sym_alignas] = ACTIONS(2569),
    [anon_sym__Alignas] = ACTIONS(2569),
    [sym_primitive_type] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2569),
    [anon_sym_struct] = ACTIONS(2569),
    [anon_sym_union] = ACTIONS(2569),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_switch] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_default] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_do] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_return] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_goto] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_compl] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2571),
    [anon_sym_sizeof] = ACTIONS(2569),
    [anon_sym___alignof__] = ACTIONS(2569),
    [anon_sym___alignof] = ACTIONS(2569),
    [anon_sym__alignof] = ACTIONS(2569),
    [anon_sym_alignof] = ACTIONS(2569),
    [anon_sym__Alignof] = ACTIONS(2569),
    [anon_sym_offsetof] = ACTIONS(2569),
    [anon_sym__Generic] = ACTIONS(2569),
    [anon_sym_asm] = ACTIONS(2569),
    [anon_sym___asm__] = ACTIONS(2569),
    [anon_sym___asm] = ACTIONS(2569),
    [sym_number_literal] = ACTIONS(2571),
    [anon_sym_L_SQUOTE] = ACTIONS(2571),
    [anon_sym_u_SQUOTE] = ACTIONS(2571),
    [anon_sym_U_SQUOTE] = ACTIONS(2571),
    [anon_sym_u8_SQUOTE] = ACTIONS(2571),
    [anon_sym_SQUOTE] = ACTIONS(2571),
    [anon_sym_L_DQUOTE] = ACTIONS(2571),
    [anon_sym_u_DQUOTE] = ACTIONS(2571),
    [anon_sym_U_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8_DQUOTE] = ACTIONS(2571),
    [anon_sym_DQUOTE] = ACTIONS(2571),
    [sym_true] = ACTIONS(2569),
    [sym_false] = ACTIONS(2569),
    [anon_sym_NULL] = ACTIONS(2569),
    [anon_sym_nullptr] = ACTIONS(2569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2569),
    [anon_sym_decltype] = ACTIONS(2569),
    [anon_sym_explicit] = ACTIONS(2569),
    [anon_sym_typename] = ACTIONS(2569),
    [anon_sym_template] = ACTIONS(2569),
    [anon_sym_operator] = ACTIONS(2569),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_delete] = ACTIONS(2569),
    [anon_sym_throw] = ACTIONS(2569),
    [anon_sym_namespace] = ACTIONS(2569),
    [anon_sym_using] = ACTIONS(2569),
    [anon_sym_static_assert] = ACTIONS(2569),
    [anon_sym_concept] = ACTIONS(2569),
    [anon_sym_co_return] = ACTIONS(2569),
    [anon_sym_co_yield] = ACTIONS(2569),
    [anon_sym_R_DQUOTE] = ACTIONS(2571),
    [anon_sym_LR_DQUOTE] = ACTIONS(2571),
    [anon_sym_uR_DQUOTE] = ACTIONS(2571),
    [anon_sym_UR_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2571),
    [anon_sym_co_await] = ACTIONS(2569),
    [anon_sym_new] = ACTIONS(2569),
    [anon_sym_requires] = ACTIONS(2569),
    [sym_this] = ACTIONS(2569),
    [anon_sym___launch_bounds__] = ACTIONS(2569),
  },
  [STATE(695)] = {
    [ts_builtin_sym_end] = ACTIONS(2583),
    [sym_identifier] = ACTIONS(2581),
    [aux_sym_preproc_include_token1] = ACTIONS(2581),
    [aux_sym_preproc_def_token1] = ACTIONS(2581),
    [aux_sym_preproc_if_token1] = ACTIONS(2581),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2581),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2581),
    [sym_preproc_directive] = ACTIONS(2581),
    [anon_sym_LPAREN2] = ACTIONS(2583),
    [anon_sym_BANG] = ACTIONS(2583),
    [anon_sym_TILDE] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2581),
    [anon_sym_PLUS] = ACTIONS(2581),
    [anon_sym_STAR] = ACTIONS(2583),
    [anon_sym_AMP_AMP] = ACTIONS(2583),
    [anon_sym_AMP] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2583),
    [anon_sym___extension__] = ACTIONS(2581),
    [anon_sym_typedef] = ACTIONS(2581),
    [anon_sym___device__] = ACTIONS(2581),
    [anon_sym___host__] = ACTIONS(2581),
    [anon_sym___global__] = ACTIONS(2581),
    [anon_sym___forceinline__] = ACTIONS(2581),
    [anon_sym___noinline__] = ACTIONS(2581),
    [anon_sym_virtual] = ACTIONS(2581),
    [anon_sym_extern] = ACTIONS(2581),
    [anon_sym___attribute__] = ACTIONS(2581),
    [anon_sym___attribute] = ACTIONS(2581),
    [anon_sym_COLON_COLON] = ACTIONS(2583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2583),
    [anon_sym___declspec] = ACTIONS(2581),
    [anon_sym___based] = ACTIONS(2581),
    [anon_sym___cdecl] = ACTIONS(2581),
    [anon_sym___clrcall] = ACTIONS(2581),
    [anon_sym___stdcall] = ACTIONS(2581),
    [anon_sym___fastcall] = ACTIONS(2581),
    [anon_sym___thiscall] = ACTIONS(2581),
    [anon_sym___vectorcall] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_signed] = ACTIONS(2581),
    [anon_sym_unsigned] = ACTIONS(2581),
    [anon_sym_long] = ACTIONS(2581),
    [anon_sym_short] = ACTIONS(2581),
    [anon_sym_LBRACK] = ACTIONS(2581),
    [anon_sym_static] = ACTIONS(2581),
    [anon_sym_register] = ACTIONS(2581),
    [anon_sym_inline] = ACTIONS(2581),
    [anon_sym___inline] = ACTIONS(2581),
    [anon_sym___inline__] = ACTIONS(2581),
    [anon_sym___forceinline] = ACTIONS(2581),
    [anon_sym_thread_local] = ACTIONS(2581),
    [anon_sym___thread] = ACTIONS(2581),
    [anon_sym_const] = ACTIONS(2581),
    [anon_sym_constexpr] = ACTIONS(2581),
    [anon_sym_volatile] = ACTIONS(2581),
    [anon_sym_restrict] = ACTIONS(2581),
    [anon_sym___restrict__] = ACTIONS(2581),
    [anon_sym__Atomic] = ACTIONS(2581),
    [anon_sym__Noreturn] = ACTIONS(2581),
    [anon_sym_noreturn] = ACTIONS(2581),
    [anon_sym__Nonnull] = ACTIONS(2581),
    [anon_sym_mutable] = ACTIONS(2581),
    [anon_sym_constinit] = ACTIONS(2581),
    [anon_sym_consteval] = ACTIONS(2581),
    [anon_sym___shared__] = ACTIONS(2581),
    [anon_sym___local__] = ACTIONS(2581),
    [anon_sym___constant__] = ACTIONS(2581),
    [anon_sym___managed__] = ACTIONS(2581),
    [anon_sym___grid_constant__] = ACTIONS(2581),
    [anon_sym_alignas] = ACTIONS(2581),
    [anon_sym__Alignas] = ACTIONS(2581),
    [sym_primitive_type] = ACTIONS(2581),
    [anon_sym_enum] = ACTIONS(2581),
    [anon_sym_class] = ACTIONS(2581),
    [anon_sym_struct] = ACTIONS(2581),
    [anon_sym_union] = ACTIONS(2581),
    [anon_sym_if] = ACTIONS(2581),
    [anon_sym_switch] = ACTIONS(2581),
    [anon_sym_case] = ACTIONS(2581),
    [anon_sym_default] = ACTIONS(2581),
    [anon_sym_while] = ACTIONS(2581),
    [anon_sym_do] = ACTIONS(2581),
    [anon_sym_for] = ACTIONS(2581),
    [anon_sym_return] = ACTIONS(2581),
    [anon_sym_break] = ACTIONS(2581),
    [anon_sym_continue] = ACTIONS(2581),
    [anon_sym_goto] = ACTIONS(2581),
    [anon_sym_not] = ACTIONS(2581),
    [anon_sym_compl] = ACTIONS(2581),
    [anon_sym_DASH_DASH] = ACTIONS(2583),
    [anon_sym_PLUS_PLUS] = ACTIONS(2583),
    [anon_sym_sizeof] = ACTIONS(2581),
    [anon_sym___alignof__] = ACTIONS(2581),
    [anon_sym___alignof] = ACTIONS(2581),
    [anon_sym__alignof] = ACTIONS(2581),
    [anon_sym_alignof] = ACTIONS(2581),
    [anon_sym__Alignof] = ACTIONS(2581),
    [anon_sym_offsetof] = ACTIONS(2581),
    [anon_sym__Generic] = ACTIONS(2581),
    [anon_sym_asm] = ACTIONS(2581),
    [anon_sym___asm__] = ACTIONS(2581),
    [anon_sym___asm] = ACTIONS(2581),
    [sym_number_literal] = ACTIONS(2583),
    [anon_sym_L_SQUOTE] = ACTIONS(2583),
    [anon_sym_u_SQUOTE] = ACTIONS(2583),
    [anon_sym_U_SQUOTE] = ACTIONS(2583),
    [anon_sym_u8_SQUOTE] = ACTIONS(2583),
    [anon_sym_SQUOTE] = ACTIONS(2583),
    [anon_sym_L_DQUOTE] = ACTIONS(2583),
    [anon_sym_u_DQUOTE] = ACTIONS(2583),
    [anon_sym_U_DQUOTE] = ACTIONS(2583),
    [anon_sym_u8_DQUOTE] = ACTIONS(2583),
    [anon_sym_DQUOTE] = ACTIONS(2583),
    [sym_true] = ACTIONS(2581),
    [sym_false] = ACTIONS(2581),
    [anon_sym_NULL] = ACTIONS(2581),
    [anon_sym_nullptr] = ACTIONS(2581),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2581),
    [anon_sym_decltype] = ACTIONS(2581),
    [anon_sym_explicit] = ACTIONS(2581),
    [anon_sym_typename] = ACTIONS(2581),
    [anon_sym_template] = ACTIONS(2581),
    [anon_sym_operator] = ACTIONS(2581),
    [anon_sym_try] = ACTIONS(2581),
    [anon_sym_delete] = ACTIONS(2581),
    [anon_sym_throw] = ACTIONS(2581),
    [anon_sym_namespace] = ACTIONS(2581),
    [anon_sym_using] = ACTIONS(2581),
    [anon_sym_static_assert] = ACTIONS(2581),
    [anon_sym_concept] = ACTIONS(2581),
    [anon_sym_co_return] = ACTIONS(2581),
    [anon_sym_co_yield] = ACTIONS(2581),
    [anon_sym_R_DQUOTE] = ACTIONS(2583),
    [anon_sym_LR_DQUOTE] = ACTIONS(2583),
    [anon_sym_uR_DQUOTE] = ACTIONS(2583),
    [anon_sym_UR_DQUOTE] = ACTIONS(2583),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2583),
    [anon_sym_co_await] = ACTIONS(2581),
    [anon_sym_new] = ACTIONS(2581),
    [anon_sym_requires] = ACTIONS(2581),
    [sym_this] = ACTIONS(2581),
    [anon_sym___launch_bounds__] = ACTIONS(2581),
  },
  [STATE(696)] = {
    [ts_builtin_sym_end] = ACTIONS(2597),
    [sym_identifier] = ACTIONS(2595),
    [aux_sym_preproc_include_token1] = ACTIONS(2595),
    [aux_sym_preproc_def_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2595),
    [sym_preproc_directive] = ACTIONS(2595),
    [anon_sym_LPAREN2] = ACTIONS(2597),
    [anon_sym_BANG] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_DASH] = ACTIONS(2595),
    [anon_sym_PLUS] = ACTIONS(2595),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_AMP_AMP] = ACTIONS(2597),
    [anon_sym_AMP] = ACTIONS(2595),
    [anon_sym_SEMI] = ACTIONS(2597),
    [anon_sym___extension__] = ACTIONS(2595),
    [anon_sym_typedef] = ACTIONS(2595),
    [anon_sym___device__] = ACTIONS(2595),
    [anon_sym___host__] = ACTIONS(2595),
    [anon_sym___global__] = ACTIONS(2595),
    [anon_sym___forceinline__] = ACTIONS(2595),
    [anon_sym___noinline__] = ACTIONS(2595),
    [anon_sym_virtual] = ACTIONS(2595),
    [anon_sym_extern] = ACTIONS(2595),
    [anon_sym___attribute__] = ACTIONS(2595),
    [anon_sym___attribute] = ACTIONS(2595),
    [anon_sym_COLON_COLON] = ACTIONS(2597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2597),
    [anon_sym___declspec] = ACTIONS(2595),
    [anon_sym___based] = ACTIONS(2595),
    [anon_sym___cdecl] = ACTIONS(2595),
    [anon_sym___clrcall] = ACTIONS(2595),
    [anon_sym___stdcall] = ACTIONS(2595),
    [anon_sym___fastcall] = ACTIONS(2595),
    [anon_sym___thiscall] = ACTIONS(2595),
    [anon_sym___vectorcall] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_signed] = ACTIONS(2595),
    [anon_sym_unsigned] = ACTIONS(2595),
    [anon_sym_long] = ACTIONS(2595),
    [anon_sym_short] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_register] = ACTIONS(2595),
    [anon_sym_inline] = ACTIONS(2595),
    [anon_sym___inline] = ACTIONS(2595),
    [anon_sym___inline__] = ACTIONS(2595),
    [anon_sym___forceinline] = ACTIONS(2595),
    [anon_sym_thread_local] = ACTIONS(2595),
    [anon_sym___thread] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_constexpr] = ACTIONS(2595),
    [anon_sym_volatile] = ACTIONS(2595),
    [anon_sym_restrict] = ACTIONS(2595),
    [anon_sym___restrict__] = ACTIONS(2595),
    [anon_sym__Atomic] = ACTIONS(2595),
    [anon_sym__Noreturn] = ACTIONS(2595),
    [anon_sym_noreturn] = ACTIONS(2595),
    [anon_sym__Nonnull] = ACTIONS(2595),
    [anon_sym_mutable] = ACTIONS(2595),
    [anon_sym_constinit] = ACTIONS(2595),
    [anon_sym_consteval] = ACTIONS(2595),
    [anon_sym___shared__] = ACTIONS(2595),
    [anon_sym___local__] = ACTIONS(2595),
    [anon_sym___constant__] = ACTIONS(2595),
    [anon_sym___managed__] = ACTIONS(2595),
    [anon_sym___grid_constant__] = ACTIONS(2595),
    [anon_sym_alignas] = ACTIONS(2595),
    [anon_sym__Alignas] = ACTIONS(2595),
    [sym_primitive_type] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_struct] = ACTIONS(2595),
    [anon_sym_union] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2595),
    [anon_sym_switch] = ACTIONS(2595),
    [anon_sym_case] = ACTIONS(2595),
    [anon_sym_default] = ACTIONS(2595),
    [anon_sym_while] = ACTIONS(2595),
    [anon_sym_do] = ACTIONS(2595),
    [anon_sym_for] = ACTIONS(2595),
    [anon_sym_return] = ACTIONS(2595),
    [anon_sym_break] = ACTIONS(2595),
    [anon_sym_continue] = ACTIONS(2595),
    [anon_sym_goto] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2595),
    [anon_sym_compl] = ACTIONS(2595),
    [anon_sym_DASH_DASH] = ACTIONS(2597),
    [anon_sym_PLUS_PLUS] = ACTIONS(2597),
    [anon_sym_sizeof] = ACTIONS(2595),
    [anon_sym___alignof__] = ACTIONS(2595),
    [anon_sym___alignof] = ACTIONS(2595),
    [anon_sym__alignof] = ACTIONS(2595),
    [anon_sym_alignof] = ACTIONS(2595),
    [anon_sym__Alignof] = ACTIONS(2595),
    [anon_sym_offsetof] = ACTIONS(2595),
    [anon_sym__Generic] = ACTIONS(2595),
    [anon_sym_asm] = ACTIONS(2595),
    [anon_sym___asm__] = ACTIONS(2595),
    [anon_sym___asm] = ACTIONS(2595),
    [sym_number_literal] = ACTIONS(2597),
    [anon_sym_L_SQUOTE] = ACTIONS(2597),
    [anon_sym_u_SQUOTE] = ACTIONS(2597),
    [anon_sym_U_SQUOTE] = ACTIONS(2597),
    [anon_sym_u8_SQUOTE] = ACTIONS(2597),
    [anon_sym_SQUOTE] = ACTIONS(2597),
    [anon_sym_L_DQUOTE] = ACTIONS(2597),
    [anon_sym_u_DQUOTE] = ACTIONS(2597),
    [anon_sym_U_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8_DQUOTE] = ACTIONS(2597),
    [anon_sym_DQUOTE] = ACTIONS(2597),
    [sym_true] = ACTIONS(2595),
    [sym_false] = ACTIONS(2595),
    [anon_sym_NULL] = ACTIONS(2595),
    [anon_sym_nullptr] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2595),
    [anon_sym_decltype] = ACTIONS(2595),
    [anon_sym_explicit] = ACTIONS(2595),
    [anon_sym_typename] = ACTIONS(2595),
    [anon_sym_template] = ACTIONS(2595),
    [anon_sym_operator] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2595),
    [anon_sym_delete] = ACTIONS(2595),
    [anon_sym_throw] = ACTIONS(2595),
    [anon_sym_namespace] = ACTIONS(2595),
    [anon_sym_using] = ACTIONS(2595),
    [anon_sym_static_assert] = ACTIONS(2595),
    [anon_sym_concept] = ACTIONS(2595),
    [anon_sym_co_return] = ACTIONS(2595),
    [anon_sym_co_yield] = ACTIONS(2595),
    [anon_sym_R_DQUOTE] = ACTIONS(2597),
    [anon_sym_LR_DQUOTE] = ACTIONS(2597),
    [anon_sym_uR_DQUOTE] = ACTIONS(2597),
    [anon_sym_UR_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2597),
    [anon_sym_co_await] = ACTIONS(2595),
    [anon_sym_new] = ACTIONS(2595),
    [anon_sym_requires] = ACTIONS(2595),
    [sym_this] = ACTIONS(2595),
    [anon_sym___launch_bounds__] = ACTIONS(2595),
  },
  [STATE(697)] = {
    [ts_builtin_sym_end] = ACTIONS(2607),
    [sym_identifier] = ACTIONS(2605),
    [aux_sym_preproc_include_token1] = ACTIONS(2605),
    [aux_sym_preproc_def_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2605),
    [sym_preproc_directive] = ACTIONS(2605),
    [anon_sym_LPAREN2] = ACTIONS(2607),
    [anon_sym_BANG] = ACTIONS(2607),
    [anon_sym_TILDE] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2605),
    [anon_sym_PLUS] = ACTIONS(2605),
    [anon_sym_STAR] = ACTIONS(2607),
    [anon_sym_AMP_AMP] = ACTIONS(2607),
    [anon_sym_AMP] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2605),
    [anon_sym_typedef] = ACTIONS(2605),
    [anon_sym___device__] = ACTIONS(2605),
    [anon_sym___host__] = ACTIONS(2605),
    [anon_sym___global__] = ACTIONS(2605),
    [anon_sym___forceinline__] = ACTIONS(2605),
    [anon_sym___noinline__] = ACTIONS(2605),
    [anon_sym_virtual] = ACTIONS(2605),
    [anon_sym_extern] = ACTIONS(2605),
    [anon_sym___attribute__] = ACTIONS(2605),
    [anon_sym___attribute] = ACTIONS(2605),
    [anon_sym_COLON_COLON] = ACTIONS(2607),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2607),
    [anon_sym___declspec] = ACTIONS(2605),
    [anon_sym___based] = ACTIONS(2605),
    [anon_sym___cdecl] = ACTIONS(2605),
    [anon_sym___clrcall] = ACTIONS(2605),
    [anon_sym___stdcall] = ACTIONS(2605),
    [anon_sym___fastcall] = ACTIONS(2605),
    [anon_sym___thiscall] = ACTIONS(2605),
    [anon_sym___vectorcall] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(2607),
    [anon_sym_signed] = ACTIONS(2605),
    [anon_sym_unsigned] = ACTIONS(2605),
    [anon_sym_long] = ACTIONS(2605),
    [anon_sym_short] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2605),
    [anon_sym_static] = ACTIONS(2605),
    [anon_sym_register] = ACTIONS(2605),
    [anon_sym_inline] = ACTIONS(2605),
    [anon_sym___inline] = ACTIONS(2605),
    [anon_sym___inline__] = ACTIONS(2605),
    [anon_sym___forceinline] = ACTIONS(2605),
    [anon_sym_thread_local] = ACTIONS(2605),
    [anon_sym___thread] = ACTIONS(2605),
    [anon_sym_const] = ACTIONS(2605),
    [anon_sym_constexpr] = ACTIONS(2605),
    [anon_sym_volatile] = ACTIONS(2605),
    [anon_sym_restrict] = ACTIONS(2605),
    [anon_sym___restrict__] = ACTIONS(2605),
    [anon_sym__Atomic] = ACTIONS(2605),
    [anon_sym__Noreturn] = ACTIONS(2605),
    [anon_sym_noreturn] = ACTIONS(2605),
    [anon_sym__Nonnull] = ACTIONS(2605),
    [anon_sym_mutable] = ACTIONS(2605),
    [anon_sym_constinit] = ACTIONS(2605),
    [anon_sym_consteval] = ACTIONS(2605),
    [anon_sym___shared__] = ACTIONS(2605),
    [anon_sym___local__] = ACTIONS(2605),
    [anon_sym___constant__] = ACTIONS(2605),
    [anon_sym___managed__] = ACTIONS(2605),
    [anon_sym___grid_constant__] = ACTIONS(2605),
    [anon_sym_alignas] = ACTIONS(2605),
    [anon_sym__Alignas] = ACTIONS(2605),
    [sym_primitive_type] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_class] = ACTIONS(2605),
    [anon_sym_struct] = ACTIONS(2605),
    [anon_sym_union] = ACTIONS(2605),
    [anon_sym_if] = ACTIONS(2605),
    [anon_sym_switch] = ACTIONS(2605),
    [anon_sym_case] = ACTIONS(2605),
    [anon_sym_default] = ACTIONS(2605),
    [anon_sym_while] = ACTIONS(2605),
    [anon_sym_do] = ACTIONS(2605),
    [anon_sym_for] = ACTIONS(2605),
    [anon_sym_return] = ACTIONS(2605),
    [anon_sym_break] = ACTIONS(2605),
    [anon_sym_continue] = ACTIONS(2605),
    [anon_sym_goto] = ACTIONS(2605),
    [anon_sym_not] = ACTIONS(2605),
    [anon_sym_compl] = ACTIONS(2605),
    [anon_sym_DASH_DASH] = ACTIONS(2607),
    [anon_sym_PLUS_PLUS] = ACTIONS(2607),
    [anon_sym_sizeof] = ACTIONS(2605),
    [anon_sym___alignof__] = ACTIONS(2605),
    [anon_sym___alignof] = ACTIONS(2605),
    [anon_sym__alignof] = ACTIONS(2605),
    [anon_sym_alignof] = ACTIONS(2605),
    [anon_sym__Alignof] = ACTIONS(2605),
    [anon_sym_offsetof] = ACTIONS(2605),
    [anon_sym__Generic] = ACTIONS(2605),
    [anon_sym_asm] = ACTIONS(2605),
    [anon_sym___asm__] = ACTIONS(2605),
    [anon_sym___asm] = ACTIONS(2605),
    [sym_number_literal] = ACTIONS(2607),
    [anon_sym_L_SQUOTE] = ACTIONS(2607),
    [anon_sym_u_SQUOTE] = ACTIONS(2607),
    [anon_sym_U_SQUOTE] = ACTIONS(2607),
    [anon_sym_u8_SQUOTE] = ACTIONS(2607),
    [anon_sym_SQUOTE] = ACTIONS(2607),
    [anon_sym_L_DQUOTE] = ACTIONS(2607),
    [anon_sym_u_DQUOTE] = ACTIONS(2607),
    [anon_sym_U_DQUOTE] = ACTIONS(2607),
    [anon_sym_u8_DQUOTE] = ACTIONS(2607),
    [anon_sym_DQUOTE] = ACTIONS(2607),
    [sym_true] = ACTIONS(2605),
    [sym_false] = ACTIONS(2605),
    [anon_sym_NULL] = ACTIONS(2605),
    [anon_sym_nullptr] = ACTIONS(2605),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2605),
    [anon_sym_decltype] = ACTIONS(2605),
    [anon_sym_explicit] = ACTIONS(2605),
    [anon_sym_typename] = ACTIONS(2605),
    [anon_sym_template] = ACTIONS(2605),
    [anon_sym_operator] = ACTIONS(2605),
    [anon_sym_try] = ACTIONS(2605),
    [anon_sym_delete] = ACTIONS(2605),
    [anon_sym_throw] = ACTIONS(2605),
    [anon_sym_namespace] = ACTIONS(2605),
    [anon_sym_using] = ACTIONS(2605),
    [anon_sym_static_assert] = ACTIONS(2605),
    [anon_sym_concept] = ACTIONS(2605),
    [anon_sym_co_return] = ACTIONS(2605),
    [anon_sym_co_yield] = ACTIONS(2605),
    [anon_sym_R_DQUOTE] = ACTIONS(2607),
    [anon_sym_LR_DQUOTE] = ACTIONS(2607),
    [anon_sym_uR_DQUOTE] = ACTIONS(2607),
    [anon_sym_UR_DQUOTE] = ACTIONS(2607),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2607),
    [anon_sym_co_await] = ACTIONS(2605),
    [anon_sym_new] = ACTIONS(2605),
    [anon_sym_requires] = ACTIONS(2605),
    [sym_this] = ACTIONS(2605),
    [anon_sym___launch_bounds__] = ACTIONS(2605),
  },
  [STATE(698)] = {
    [ts_builtin_sym_end] = ACTIONS(2615),
    [sym_identifier] = ACTIONS(2613),
    [aux_sym_preproc_include_token1] = ACTIONS(2613),
    [aux_sym_preproc_def_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2613),
    [sym_preproc_directive] = ACTIONS(2613),
    [anon_sym_LPAREN2] = ACTIONS(2615),
    [anon_sym_BANG] = ACTIONS(2615),
    [anon_sym_TILDE] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2613),
    [anon_sym_PLUS] = ACTIONS(2613),
    [anon_sym_STAR] = ACTIONS(2615),
    [anon_sym_AMP_AMP] = ACTIONS(2615),
    [anon_sym_AMP] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym___extension__] = ACTIONS(2613),
    [anon_sym_typedef] = ACTIONS(2613),
    [anon_sym___device__] = ACTIONS(2613),
    [anon_sym___host__] = ACTIONS(2613),
    [anon_sym___global__] = ACTIONS(2613),
    [anon_sym___forceinline__] = ACTIONS(2613),
    [anon_sym___noinline__] = ACTIONS(2613),
    [anon_sym_virtual] = ACTIONS(2613),
    [anon_sym_extern] = ACTIONS(2613),
    [anon_sym___attribute__] = ACTIONS(2613),
    [anon_sym___attribute] = ACTIONS(2613),
    [anon_sym_COLON_COLON] = ACTIONS(2615),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2615),
    [anon_sym___declspec] = ACTIONS(2613),
    [anon_sym___based] = ACTIONS(2613),
    [anon_sym___cdecl] = ACTIONS(2613),
    [anon_sym___clrcall] = ACTIONS(2613),
    [anon_sym___stdcall] = ACTIONS(2613),
    [anon_sym___fastcall] = ACTIONS(2613),
    [anon_sym___thiscall] = ACTIONS(2613),
    [anon_sym___vectorcall] = ACTIONS(2613),
    [anon_sym_LBRACE] = ACTIONS(2615),
    [anon_sym_signed] = ACTIONS(2613),
    [anon_sym_unsigned] = ACTIONS(2613),
    [anon_sym_long] = ACTIONS(2613),
    [anon_sym_short] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2613),
    [anon_sym_static] = ACTIONS(2613),
    [anon_sym_register] = ACTIONS(2613),
    [anon_sym_inline] = ACTIONS(2613),
    [anon_sym___inline] = ACTIONS(2613),
    [anon_sym___inline__] = ACTIONS(2613),
    [anon_sym___forceinline] = ACTIONS(2613),
    [anon_sym_thread_local] = ACTIONS(2613),
    [anon_sym___thread] = ACTIONS(2613),
    [anon_sym_const] = ACTIONS(2613),
    [anon_sym_constexpr] = ACTIONS(2613),
    [anon_sym_volatile] = ACTIONS(2613),
    [anon_sym_restrict] = ACTIONS(2613),
    [anon_sym___restrict__] = ACTIONS(2613),
    [anon_sym__Atomic] = ACTIONS(2613),
    [anon_sym__Noreturn] = ACTIONS(2613),
    [anon_sym_noreturn] = ACTIONS(2613),
    [anon_sym__Nonnull] = ACTIONS(2613),
    [anon_sym_mutable] = ACTIONS(2613),
    [anon_sym_constinit] = ACTIONS(2613),
    [anon_sym_consteval] = ACTIONS(2613),
    [anon_sym___shared__] = ACTIONS(2613),
    [anon_sym___local__] = ACTIONS(2613),
    [anon_sym___constant__] = ACTIONS(2613),
    [anon_sym___managed__] = ACTIONS(2613),
    [anon_sym___grid_constant__] = ACTIONS(2613),
    [anon_sym_alignas] = ACTIONS(2613),
    [anon_sym__Alignas] = ACTIONS(2613),
    [sym_primitive_type] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_class] = ACTIONS(2613),
    [anon_sym_struct] = ACTIONS(2613),
    [anon_sym_union] = ACTIONS(2613),
    [anon_sym_if] = ACTIONS(2613),
    [anon_sym_switch] = ACTIONS(2613),
    [anon_sym_case] = ACTIONS(2613),
    [anon_sym_default] = ACTIONS(2613),
    [anon_sym_while] = ACTIONS(2613),
    [anon_sym_do] = ACTIONS(2613),
    [anon_sym_for] = ACTIONS(2613),
    [anon_sym_return] = ACTIONS(2613),
    [anon_sym_break] = ACTIONS(2613),
    [anon_sym_continue] = ACTIONS(2613),
    [anon_sym_goto] = ACTIONS(2613),
    [anon_sym_not] = ACTIONS(2613),
    [anon_sym_compl] = ACTIONS(2613),
    [anon_sym_DASH_DASH] = ACTIONS(2615),
    [anon_sym_PLUS_PLUS] = ACTIONS(2615),
    [anon_sym_sizeof] = ACTIONS(2613),
    [anon_sym___alignof__] = ACTIONS(2613),
    [anon_sym___alignof] = ACTIONS(2613),
    [anon_sym__alignof] = ACTIONS(2613),
    [anon_sym_alignof] = ACTIONS(2613),
    [anon_sym__Alignof] = ACTIONS(2613),
    [anon_sym_offsetof] = ACTIONS(2613),
    [anon_sym__Generic] = ACTIONS(2613),
    [anon_sym_asm] = ACTIONS(2613),
    [anon_sym___asm__] = ACTIONS(2613),
    [anon_sym___asm] = ACTIONS(2613),
    [sym_number_literal] = ACTIONS(2615),
    [anon_sym_L_SQUOTE] = ACTIONS(2615),
    [anon_sym_u_SQUOTE] = ACTIONS(2615),
    [anon_sym_U_SQUOTE] = ACTIONS(2615),
    [anon_sym_u8_SQUOTE] = ACTIONS(2615),
    [anon_sym_SQUOTE] = ACTIONS(2615),
    [anon_sym_L_DQUOTE] = ACTIONS(2615),
    [anon_sym_u_DQUOTE] = ACTIONS(2615),
    [anon_sym_U_DQUOTE] = ACTIONS(2615),
    [anon_sym_u8_DQUOTE] = ACTIONS(2615),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_true] = ACTIONS(2613),
    [sym_false] = ACTIONS(2613),
    [anon_sym_NULL] = ACTIONS(2613),
    [anon_sym_nullptr] = ACTIONS(2613),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2613),
    [anon_sym_decltype] = ACTIONS(2613),
    [anon_sym_explicit] = ACTIONS(2613),
    [anon_sym_typename] = ACTIONS(2613),
    [anon_sym_template] = ACTIONS(2613),
    [anon_sym_operator] = ACTIONS(2613),
    [anon_sym_try] = ACTIONS(2613),
    [anon_sym_delete] = ACTIONS(2613),
    [anon_sym_throw] = ACTIONS(2613),
    [anon_sym_namespace] = ACTIONS(2613),
    [anon_sym_using] = ACTIONS(2613),
    [anon_sym_static_assert] = ACTIONS(2613),
    [anon_sym_concept] = ACTIONS(2613),
    [anon_sym_co_return] = ACTIONS(2613),
    [anon_sym_co_yield] = ACTIONS(2613),
    [anon_sym_R_DQUOTE] = ACTIONS(2615),
    [anon_sym_LR_DQUOTE] = ACTIONS(2615),
    [anon_sym_uR_DQUOTE] = ACTIONS(2615),
    [anon_sym_UR_DQUOTE] = ACTIONS(2615),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2615),
    [anon_sym_co_await] = ACTIONS(2613),
    [anon_sym_new] = ACTIONS(2613),
    [anon_sym_requires] = ACTIONS(2613),
    [sym_this] = ACTIONS(2613),
    [anon_sym___launch_bounds__] = ACTIONS(2613),
  },
  [STATE(699)] = {
    [ts_builtin_sym_end] = ACTIONS(2437),
    [sym_identifier] = ACTIONS(2435),
    [aux_sym_preproc_include_token1] = ACTIONS(2435),
    [aux_sym_preproc_def_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2435),
    [sym_preproc_directive] = ACTIONS(2435),
    [anon_sym_LPAREN2] = ACTIONS(2437),
    [anon_sym_BANG] = ACTIONS(2437),
    [anon_sym_TILDE] = ACTIONS(2437),
    [anon_sym_DASH] = ACTIONS(2435),
    [anon_sym_PLUS] = ACTIONS(2435),
    [anon_sym_STAR] = ACTIONS(2437),
    [anon_sym_AMP_AMP] = ACTIONS(2437),
    [anon_sym_AMP] = ACTIONS(2435),
    [anon_sym_SEMI] = ACTIONS(2437),
    [anon_sym___extension__] = ACTIONS(2435),
    [anon_sym_typedef] = ACTIONS(2435),
    [anon_sym___device__] = ACTIONS(2435),
    [anon_sym___host__] = ACTIONS(2435),
    [anon_sym___global__] = ACTIONS(2435),
    [anon_sym___forceinline__] = ACTIONS(2435),
    [anon_sym___noinline__] = ACTIONS(2435),
    [anon_sym_virtual] = ACTIONS(2435),
    [anon_sym_extern] = ACTIONS(2435),
    [anon_sym___attribute__] = ACTIONS(2435),
    [anon_sym___attribute] = ACTIONS(2435),
    [anon_sym_COLON_COLON] = ACTIONS(2437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2437),
    [anon_sym___declspec] = ACTIONS(2435),
    [anon_sym___based] = ACTIONS(2435),
    [anon_sym___cdecl] = ACTIONS(2435),
    [anon_sym___clrcall] = ACTIONS(2435),
    [anon_sym___stdcall] = ACTIONS(2435),
    [anon_sym___fastcall] = ACTIONS(2435),
    [anon_sym___thiscall] = ACTIONS(2435),
    [anon_sym___vectorcall] = ACTIONS(2435),
    [anon_sym_LBRACE] = ACTIONS(2437),
    [anon_sym_signed] = ACTIONS(2435),
    [anon_sym_unsigned] = ACTIONS(2435),
    [anon_sym_long] = ACTIONS(2435),
    [anon_sym_short] = ACTIONS(2435),
    [anon_sym_LBRACK] = ACTIONS(2435),
    [anon_sym_static] = ACTIONS(2435),
    [anon_sym_register] = ACTIONS(2435),
    [anon_sym_inline] = ACTIONS(2435),
    [anon_sym___inline] = ACTIONS(2435),
    [anon_sym___inline__] = ACTIONS(2435),
    [anon_sym___forceinline] = ACTIONS(2435),
    [anon_sym_thread_local] = ACTIONS(2435),
    [anon_sym___thread] = ACTIONS(2435),
    [anon_sym_const] = ACTIONS(2435),
    [anon_sym_constexpr] = ACTIONS(2435),
    [anon_sym_volatile] = ACTIONS(2435),
    [anon_sym_restrict] = ACTIONS(2435),
    [anon_sym___restrict__] = ACTIONS(2435),
    [anon_sym__Atomic] = ACTIONS(2435),
    [anon_sym__Noreturn] = ACTIONS(2435),
    [anon_sym_noreturn] = ACTIONS(2435),
    [anon_sym__Nonnull] = ACTIONS(2435),
    [anon_sym_mutable] = ACTIONS(2435),
    [anon_sym_constinit] = ACTIONS(2435),
    [anon_sym_consteval] = ACTIONS(2435),
    [anon_sym___shared__] = ACTIONS(2435),
    [anon_sym___local__] = ACTIONS(2435),
    [anon_sym___constant__] = ACTIONS(2435),
    [anon_sym___managed__] = ACTIONS(2435),
    [anon_sym___grid_constant__] = ACTIONS(2435),
    [anon_sym_alignas] = ACTIONS(2435),
    [anon_sym__Alignas] = ACTIONS(2435),
    [sym_primitive_type] = ACTIONS(2435),
    [anon_sym_enum] = ACTIONS(2435),
    [anon_sym_class] = ACTIONS(2435),
    [anon_sym_struct] = ACTIONS(2435),
    [anon_sym_union] = ACTIONS(2435),
    [anon_sym_if] = ACTIONS(2435),
    [anon_sym_switch] = ACTIONS(2435),
    [anon_sym_case] = ACTIONS(2435),
    [anon_sym_default] = ACTIONS(2435),
    [anon_sym_while] = ACTIONS(2435),
    [anon_sym_do] = ACTIONS(2435),
    [anon_sym_for] = ACTIONS(2435),
    [anon_sym_return] = ACTIONS(2435),
    [anon_sym_break] = ACTIONS(2435),
    [anon_sym_continue] = ACTIONS(2435),
    [anon_sym_goto] = ACTIONS(2435),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_compl] = ACTIONS(2435),
    [anon_sym_DASH_DASH] = ACTIONS(2437),
    [anon_sym_PLUS_PLUS] = ACTIONS(2437),
    [anon_sym_sizeof] = ACTIONS(2435),
    [anon_sym___alignof__] = ACTIONS(2435),
    [anon_sym___alignof] = ACTIONS(2435),
    [anon_sym__alignof] = ACTIONS(2435),
    [anon_sym_alignof] = ACTIONS(2435),
    [anon_sym__Alignof] = ACTIONS(2435),
    [anon_sym_offsetof] = ACTIONS(2435),
    [anon_sym__Generic] = ACTIONS(2435),
    [anon_sym_asm] = ACTIONS(2435),
    [anon_sym___asm__] = ACTIONS(2435),
    [anon_sym___asm] = ACTIONS(2435),
    [sym_number_literal] = ACTIONS(2437),
    [anon_sym_L_SQUOTE] = ACTIONS(2437),
    [anon_sym_u_SQUOTE] = ACTIONS(2437),
    [anon_sym_U_SQUOTE] = ACTIONS(2437),
    [anon_sym_u8_SQUOTE] = ACTIONS(2437),
    [anon_sym_SQUOTE] = ACTIONS(2437),
    [anon_sym_L_DQUOTE] = ACTIONS(2437),
    [anon_sym_u_DQUOTE] = ACTIONS(2437),
    [anon_sym_U_DQUOTE] = ACTIONS(2437),
    [anon_sym_u8_DQUOTE] = ACTIONS(2437),
    [anon_sym_DQUOTE] = ACTIONS(2437),
    [sym_true] = ACTIONS(2435),
    [sym_false] = ACTIONS(2435),
    [anon_sym_NULL] = ACTIONS(2435),
    [anon_sym_nullptr] = ACTIONS(2435),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2435),
    [anon_sym_decltype] = ACTIONS(2435),
    [anon_sym_explicit] = ACTIONS(2435),
    [anon_sym_typename] = ACTIONS(2435),
    [anon_sym_template] = ACTIONS(2435),
    [anon_sym_operator] = ACTIONS(2435),
    [anon_sym_try] = ACTIONS(2435),
    [anon_sym_delete] = ACTIONS(2435),
    [anon_sym_throw] = ACTIONS(2435),
    [anon_sym_namespace] = ACTIONS(2435),
    [anon_sym_using] = ACTIONS(2435),
    [anon_sym_static_assert] = ACTIONS(2435),
    [anon_sym_concept] = ACTIONS(2435),
    [anon_sym_co_return] = ACTIONS(2435),
    [anon_sym_co_yield] = ACTIONS(2435),
    [anon_sym_R_DQUOTE] = ACTIONS(2437),
    [anon_sym_LR_DQUOTE] = ACTIONS(2437),
    [anon_sym_uR_DQUOTE] = ACTIONS(2437),
    [anon_sym_UR_DQUOTE] = ACTIONS(2437),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2437),
    [anon_sym_co_await] = ACTIONS(2435),
    [anon_sym_new] = ACTIONS(2435),
    [anon_sym_requires] = ACTIONS(2435),
    [sym_this] = ACTIONS(2435),
    [anon_sym___launch_bounds__] = ACTIONS(2435),
  },
  [STATE(700)] = {
    [ts_builtin_sym_end] = ACTIONS(2236),
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_include_token1] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_BANG] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_DASH] = ACTIONS(2234),
    [anon_sym_PLUS] = ACTIONS(2234),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym___cdecl] = ACTIONS(2234),
    [anon_sym___clrcall] = ACTIONS(2234),
    [anon_sym___stdcall] = ACTIONS(2234),
    [anon_sym___fastcall] = ACTIONS(2234),
    [anon_sym___thiscall] = ACTIONS(2234),
    [anon_sym___vectorcall] = ACTIONS(2234),
    [anon_sym_LBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [anon_sym_if] = ACTIONS(2234),
    [anon_sym_switch] = ACTIONS(2234),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym_default] = ACTIONS(2234),
    [anon_sym_while] = ACTIONS(2234),
    [anon_sym_do] = ACTIONS(2234),
    [anon_sym_for] = ACTIONS(2234),
    [anon_sym_return] = ACTIONS(2234),
    [anon_sym_break] = ACTIONS(2234),
    [anon_sym_continue] = ACTIONS(2234),
    [anon_sym_goto] = ACTIONS(2234),
    [anon_sym_not] = ACTIONS(2234),
    [anon_sym_compl] = ACTIONS(2234),
    [anon_sym_DASH_DASH] = ACTIONS(2236),
    [anon_sym_PLUS_PLUS] = ACTIONS(2236),
    [anon_sym_sizeof] = ACTIONS(2234),
    [anon_sym___alignof__] = ACTIONS(2234),
    [anon_sym___alignof] = ACTIONS(2234),
    [anon_sym__alignof] = ACTIONS(2234),
    [anon_sym_alignof] = ACTIONS(2234),
    [anon_sym__Alignof] = ACTIONS(2234),
    [anon_sym_offsetof] = ACTIONS(2234),
    [anon_sym__Generic] = ACTIONS(2234),
    [anon_sym_asm] = ACTIONS(2234),
    [anon_sym___asm__] = ACTIONS(2234),
    [anon_sym___asm] = ACTIONS(2234),
    [sym_number_literal] = ACTIONS(2236),
    [anon_sym_L_SQUOTE] = ACTIONS(2236),
    [anon_sym_u_SQUOTE] = ACTIONS(2236),
    [anon_sym_U_SQUOTE] = ACTIONS(2236),
    [anon_sym_u8_SQUOTE] = ACTIONS(2236),
    [anon_sym_SQUOTE] = ACTIONS(2236),
    [anon_sym_L_DQUOTE] = ACTIONS(2236),
    [anon_sym_u_DQUOTE] = ACTIONS(2236),
    [anon_sym_U_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8_DQUOTE] = ACTIONS(2236),
    [anon_sym_DQUOTE] = ACTIONS(2236),
    [sym_true] = ACTIONS(2234),
    [sym_false] = ACTIONS(2234),
    [anon_sym_NULL] = ACTIONS(2234),
    [anon_sym_nullptr] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_try] = ACTIONS(2234),
    [anon_sym_delete] = ACTIONS(2234),
    [anon_sym_throw] = ACTIONS(2234),
    [anon_sym_namespace] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym_concept] = ACTIONS(2234),
    [anon_sym_co_return] = ACTIONS(2234),
    [anon_sym_co_yield] = ACTIONS(2234),
    [anon_sym_R_DQUOTE] = ACTIONS(2236),
    [anon_sym_LR_DQUOTE] = ACTIONS(2236),
    [anon_sym_uR_DQUOTE] = ACTIONS(2236),
    [anon_sym_UR_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2236),
    [anon_sym_co_await] = ACTIONS(2234),
    [anon_sym_new] = ACTIONS(2234),
    [anon_sym_requires] = ACTIONS(2234),
    [sym_this] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(701)] = {
    [ts_builtin_sym_end] = ACTIONS(2236),
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_include_token1] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_BANG] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_DASH] = ACTIONS(2234),
    [anon_sym_PLUS] = ACTIONS(2234),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym___cdecl] = ACTIONS(2234),
    [anon_sym___clrcall] = ACTIONS(2234),
    [anon_sym___stdcall] = ACTIONS(2234),
    [anon_sym___fastcall] = ACTIONS(2234),
    [anon_sym___thiscall] = ACTIONS(2234),
    [anon_sym___vectorcall] = ACTIONS(2234),
    [anon_sym_LBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [anon_sym_if] = ACTIONS(2234),
    [anon_sym_switch] = ACTIONS(2234),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym_default] = ACTIONS(2234),
    [anon_sym_while] = ACTIONS(2234),
    [anon_sym_do] = ACTIONS(2234),
    [anon_sym_for] = ACTIONS(2234),
    [anon_sym_return] = ACTIONS(2234),
    [anon_sym_break] = ACTIONS(2234),
    [anon_sym_continue] = ACTIONS(2234),
    [anon_sym_goto] = ACTIONS(2234),
    [anon_sym_not] = ACTIONS(2234),
    [anon_sym_compl] = ACTIONS(2234),
    [anon_sym_DASH_DASH] = ACTIONS(2236),
    [anon_sym_PLUS_PLUS] = ACTIONS(2236),
    [anon_sym_sizeof] = ACTIONS(2234),
    [anon_sym___alignof__] = ACTIONS(2234),
    [anon_sym___alignof] = ACTIONS(2234),
    [anon_sym__alignof] = ACTIONS(2234),
    [anon_sym_alignof] = ACTIONS(2234),
    [anon_sym__Alignof] = ACTIONS(2234),
    [anon_sym_offsetof] = ACTIONS(2234),
    [anon_sym__Generic] = ACTIONS(2234),
    [anon_sym_asm] = ACTIONS(2234),
    [anon_sym___asm__] = ACTIONS(2234),
    [anon_sym___asm] = ACTIONS(2234),
    [sym_number_literal] = ACTIONS(2236),
    [anon_sym_L_SQUOTE] = ACTIONS(2236),
    [anon_sym_u_SQUOTE] = ACTIONS(2236),
    [anon_sym_U_SQUOTE] = ACTIONS(2236),
    [anon_sym_u8_SQUOTE] = ACTIONS(2236),
    [anon_sym_SQUOTE] = ACTIONS(2236),
    [anon_sym_L_DQUOTE] = ACTIONS(2236),
    [anon_sym_u_DQUOTE] = ACTIONS(2236),
    [anon_sym_U_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8_DQUOTE] = ACTIONS(2236),
    [anon_sym_DQUOTE] = ACTIONS(2236),
    [sym_true] = ACTIONS(2234),
    [sym_false] = ACTIONS(2234),
    [anon_sym_NULL] = ACTIONS(2234),
    [anon_sym_nullptr] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_try] = ACTIONS(2234),
    [anon_sym_delete] = ACTIONS(2234),
    [anon_sym_throw] = ACTIONS(2234),
    [anon_sym_namespace] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym_concept] = ACTIONS(2234),
    [anon_sym_co_return] = ACTIONS(2234),
    [anon_sym_co_yield] = ACTIONS(2234),
    [anon_sym_R_DQUOTE] = ACTIONS(2236),
    [anon_sym_LR_DQUOTE] = ACTIONS(2236),
    [anon_sym_uR_DQUOTE] = ACTIONS(2236),
    [anon_sym_UR_DQUOTE] = ACTIONS(2236),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2236),
    [anon_sym_co_await] = ACTIONS(2234),
    [anon_sym_new] = ACTIONS(2234),
    [anon_sym_requires] = ACTIONS(2234),
    [sym_this] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(702)] = {
    [ts_builtin_sym_end] = ACTIONS(2449),
    [sym_identifier] = ACTIONS(2447),
    [aux_sym_preproc_include_token1] = ACTIONS(2447),
    [aux_sym_preproc_def_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2447),
    [sym_preproc_directive] = ACTIONS(2447),
    [anon_sym_LPAREN2] = ACTIONS(2449),
    [anon_sym_BANG] = ACTIONS(2449),
    [anon_sym_TILDE] = ACTIONS(2449),
    [anon_sym_DASH] = ACTIONS(2447),
    [anon_sym_PLUS] = ACTIONS(2447),
    [anon_sym_STAR] = ACTIONS(2449),
    [anon_sym_AMP_AMP] = ACTIONS(2449),
    [anon_sym_AMP] = ACTIONS(2447),
    [anon_sym_SEMI] = ACTIONS(2449),
    [anon_sym___extension__] = ACTIONS(2447),
    [anon_sym_typedef] = ACTIONS(2447),
    [anon_sym___device__] = ACTIONS(2447),
    [anon_sym___host__] = ACTIONS(2447),
    [anon_sym___global__] = ACTIONS(2447),
    [anon_sym___forceinline__] = ACTIONS(2447),
    [anon_sym___noinline__] = ACTIONS(2447),
    [anon_sym_virtual] = ACTIONS(2447),
    [anon_sym_extern] = ACTIONS(2447),
    [anon_sym___attribute__] = ACTIONS(2447),
    [anon_sym___attribute] = ACTIONS(2447),
    [anon_sym_COLON_COLON] = ACTIONS(2449),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2449),
    [anon_sym___declspec] = ACTIONS(2447),
    [anon_sym___based] = ACTIONS(2447),
    [anon_sym___cdecl] = ACTIONS(2447),
    [anon_sym___clrcall] = ACTIONS(2447),
    [anon_sym___stdcall] = ACTIONS(2447),
    [anon_sym___fastcall] = ACTIONS(2447),
    [anon_sym___thiscall] = ACTIONS(2447),
    [anon_sym___vectorcall] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2449),
    [anon_sym_signed] = ACTIONS(2447),
    [anon_sym_unsigned] = ACTIONS(2447),
    [anon_sym_long] = ACTIONS(2447),
    [anon_sym_short] = ACTIONS(2447),
    [anon_sym_LBRACK] = ACTIONS(2447),
    [anon_sym_static] = ACTIONS(2447),
    [anon_sym_register] = ACTIONS(2447),
    [anon_sym_inline] = ACTIONS(2447),
    [anon_sym___inline] = ACTIONS(2447),
    [anon_sym___inline__] = ACTIONS(2447),
    [anon_sym___forceinline] = ACTIONS(2447),
    [anon_sym_thread_local] = ACTIONS(2447),
    [anon_sym___thread] = ACTIONS(2447),
    [anon_sym_const] = ACTIONS(2447),
    [anon_sym_constexpr] = ACTIONS(2447),
    [anon_sym_volatile] = ACTIONS(2447),
    [anon_sym_restrict] = ACTIONS(2447),
    [anon_sym___restrict__] = ACTIONS(2447),
    [anon_sym__Atomic] = ACTIONS(2447),
    [anon_sym__Noreturn] = ACTIONS(2447),
    [anon_sym_noreturn] = ACTIONS(2447),
    [anon_sym__Nonnull] = ACTIONS(2447),
    [anon_sym_mutable] = ACTIONS(2447),
    [anon_sym_constinit] = ACTIONS(2447),
    [anon_sym_consteval] = ACTIONS(2447),
    [anon_sym___shared__] = ACTIONS(2447),
    [anon_sym___local__] = ACTIONS(2447),
    [anon_sym___constant__] = ACTIONS(2447),
    [anon_sym___managed__] = ACTIONS(2447),
    [anon_sym___grid_constant__] = ACTIONS(2447),
    [anon_sym_alignas] = ACTIONS(2447),
    [anon_sym__Alignas] = ACTIONS(2447),
    [sym_primitive_type] = ACTIONS(2447),
    [anon_sym_enum] = ACTIONS(2447),
    [anon_sym_class] = ACTIONS(2447),
    [anon_sym_struct] = ACTIONS(2447),
    [anon_sym_union] = ACTIONS(2447),
    [anon_sym_if] = ACTIONS(2447),
    [anon_sym_switch] = ACTIONS(2447),
    [anon_sym_case] = ACTIONS(2447),
    [anon_sym_default] = ACTIONS(2447),
    [anon_sym_while] = ACTIONS(2447),
    [anon_sym_do] = ACTIONS(2447),
    [anon_sym_for] = ACTIONS(2447),
    [anon_sym_return] = ACTIONS(2447),
    [anon_sym_break] = ACTIONS(2447),
    [anon_sym_continue] = ACTIONS(2447),
    [anon_sym_goto] = ACTIONS(2447),
    [anon_sym_not] = ACTIONS(2447),
    [anon_sym_compl] = ACTIONS(2447),
    [anon_sym_DASH_DASH] = ACTIONS(2449),
    [anon_sym_PLUS_PLUS] = ACTIONS(2449),
    [anon_sym_sizeof] = ACTIONS(2447),
    [anon_sym___alignof__] = ACTIONS(2447),
    [anon_sym___alignof] = ACTIONS(2447),
    [anon_sym__alignof] = ACTIONS(2447),
    [anon_sym_alignof] = ACTIONS(2447),
    [anon_sym__Alignof] = ACTIONS(2447),
    [anon_sym_offsetof] = ACTIONS(2447),
    [anon_sym__Generic] = ACTIONS(2447),
    [anon_sym_asm] = ACTIONS(2447),
    [anon_sym___asm__] = ACTIONS(2447),
    [anon_sym___asm] = ACTIONS(2447),
    [sym_number_literal] = ACTIONS(2449),
    [anon_sym_L_SQUOTE] = ACTIONS(2449),
    [anon_sym_u_SQUOTE] = ACTIONS(2449),
    [anon_sym_U_SQUOTE] = ACTIONS(2449),
    [anon_sym_u8_SQUOTE] = ACTIONS(2449),
    [anon_sym_SQUOTE] = ACTIONS(2449),
    [anon_sym_L_DQUOTE] = ACTIONS(2449),
    [anon_sym_u_DQUOTE] = ACTIONS(2449),
    [anon_sym_U_DQUOTE] = ACTIONS(2449),
    [anon_sym_u8_DQUOTE] = ACTIONS(2449),
    [anon_sym_DQUOTE] = ACTIONS(2449),
    [sym_true] = ACTIONS(2447),
    [sym_false] = ACTIONS(2447),
    [anon_sym_NULL] = ACTIONS(2447),
    [anon_sym_nullptr] = ACTIONS(2447),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2447),
    [anon_sym_decltype] = ACTIONS(2447),
    [anon_sym_explicit] = ACTIONS(2447),
    [anon_sym_typename] = ACTIONS(2447),
    [anon_sym_template] = ACTIONS(2447),
    [anon_sym_operator] = ACTIONS(2447),
    [anon_sym_try] = ACTIONS(2447),
    [anon_sym_delete] = ACTIONS(2447),
    [anon_sym_throw] = ACTIONS(2447),
    [anon_sym_namespace] = ACTIONS(2447),
    [anon_sym_using] = ACTIONS(2447),
    [anon_sym_static_assert] = ACTIONS(2447),
    [anon_sym_concept] = ACTIONS(2447),
    [anon_sym_co_return] = ACTIONS(2447),
    [anon_sym_co_yield] = ACTIONS(2447),
    [anon_sym_R_DQUOTE] = ACTIONS(2449),
    [anon_sym_LR_DQUOTE] = ACTIONS(2449),
    [anon_sym_uR_DQUOTE] = ACTIONS(2449),
    [anon_sym_UR_DQUOTE] = ACTIONS(2449),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2449),
    [anon_sym_co_await] = ACTIONS(2447),
    [anon_sym_new] = ACTIONS(2447),
    [anon_sym_requires] = ACTIONS(2447),
    [sym_this] = ACTIONS(2447),
    [anon_sym___launch_bounds__] = ACTIONS(2447),
  },
  [STATE(703)] = {
    [ts_builtin_sym_end] = ACTIONS(2499),
    [sym_identifier] = ACTIONS(2497),
    [aux_sym_preproc_include_token1] = ACTIONS(2497),
    [aux_sym_preproc_def_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2497),
    [sym_preproc_directive] = ACTIONS(2497),
    [anon_sym_LPAREN2] = ACTIONS(2499),
    [anon_sym_BANG] = ACTIONS(2499),
    [anon_sym_TILDE] = ACTIONS(2499),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_STAR] = ACTIONS(2499),
    [anon_sym_AMP_AMP] = ACTIONS(2499),
    [anon_sym_AMP] = ACTIONS(2497),
    [anon_sym_SEMI] = ACTIONS(2499),
    [anon_sym___extension__] = ACTIONS(2497),
    [anon_sym_typedef] = ACTIONS(2497),
    [anon_sym___device__] = ACTIONS(2497),
    [anon_sym___host__] = ACTIONS(2497),
    [anon_sym___global__] = ACTIONS(2497),
    [anon_sym___forceinline__] = ACTIONS(2497),
    [anon_sym___noinline__] = ACTIONS(2497),
    [anon_sym_virtual] = ACTIONS(2497),
    [anon_sym_extern] = ACTIONS(2497),
    [anon_sym___attribute__] = ACTIONS(2497),
    [anon_sym___attribute] = ACTIONS(2497),
    [anon_sym_COLON_COLON] = ACTIONS(2499),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2499),
    [anon_sym___declspec] = ACTIONS(2497),
    [anon_sym___based] = ACTIONS(2497),
    [anon_sym___cdecl] = ACTIONS(2497),
    [anon_sym___clrcall] = ACTIONS(2497),
    [anon_sym___stdcall] = ACTIONS(2497),
    [anon_sym___fastcall] = ACTIONS(2497),
    [anon_sym___thiscall] = ACTIONS(2497),
    [anon_sym___vectorcall] = ACTIONS(2497),
    [anon_sym_LBRACE] = ACTIONS(2499),
    [anon_sym_signed] = ACTIONS(2497),
    [anon_sym_unsigned] = ACTIONS(2497),
    [anon_sym_long] = ACTIONS(2497),
    [anon_sym_short] = ACTIONS(2497),
    [anon_sym_LBRACK] = ACTIONS(2497),
    [anon_sym_static] = ACTIONS(2497),
    [anon_sym_register] = ACTIONS(2497),
    [anon_sym_inline] = ACTIONS(2497),
    [anon_sym___inline] = ACTIONS(2497),
    [anon_sym___inline__] = ACTIONS(2497),
    [anon_sym___forceinline] = ACTIONS(2497),
    [anon_sym_thread_local] = ACTIONS(2497),
    [anon_sym___thread] = ACTIONS(2497),
    [anon_sym_const] = ACTIONS(2497),
    [anon_sym_constexpr] = ACTIONS(2497),
    [anon_sym_volatile] = ACTIONS(2497),
    [anon_sym_restrict] = ACTIONS(2497),
    [anon_sym___restrict__] = ACTIONS(2497),
    [anon_sym__Atomic] = ACTIONS(2497),
    [anon_sym__Noreturn] = ACTIONS(2497),
    [anon_sym_noreturn] = ACTIONS(2497),
    [anon_sym__Nonnull] = ACTIONS(2497),
    [anon_sym_mutable] = ACTIONS(2497),
    [anon_sym_constinit] = ACTIONS(2497),
    [anon_sym_consteval] = ACTIONS(2497),
    [anon_sym___shared__] = ACTIONS(2497),
    [anon_sym___local__] = ACTIONS(2497),
    [anon_sym___constant__] = ACTIONS(2497),
    [anon_sym___managed__] = ACTIONS(2497),
    [anon_sym___grid_constant__] = ACTIONS(2497),
    [anon_sym_alignas] = ACTIONS(2497),
    [anon_sym__Alignas] = ACTIONS(2497),
    [sym_primitive_type] = ACTIONS(2497),
    [anon_sym_enum] = ACTIONS(2497),
    [anon_sym_class] = ACTIONS(2497),
    [anon_sym_struct] = ACTIONS(2497),
    [anon_sym_union] = ACTIONS(2497),
    [anon_sym_if] = ACTIONS(2497),
    [anon_sym_switch] = ACTIONS(2497),
    [anon_sym_case] = ACTIONS(2497),
    [anon_sym_default] = ACTIONS(2497),
    [anon_sym_while] = ACTIONS(2497),
    [anon_sym_do] = ACTIONS(2497),
    [anon_sym_for] = ACTIONS(2497),
    [anon_sym_return] = ACTIONS(2497),
    [anon_sym_break] = ACTIONS(2497),
    [anon_sym_continue] = ACTIONS(2497),
    [anon_sym_goto] = ACTIONS(2497),
    [anon_sym_not] = ACTIONS(2497),
    [anon_sym_compl] = ACTIONS(2497),
    [anon_sym_DASH_DASH] = ACTIONS(2499),
    [anon_sym_PLUS_PLUS] = ACTIONS(2499),
    [anon_sym_sizeof] = ACTIONS(2497),
    [anon_sym___alignof__] = ACTIONS(2497),
    [anon_sym___alignof] = ACTIONS(2497),
    [anon_sym__alignof] = ACTIONS(2497),
    [anon_sym_alignof] = ACTIONS(2497),
    [anon_sym__Alignof] = ACTIONS(2497),
    [anon_sym_offsetof] = ACTIONS(2497),
    [anon_sym__Generic] = ACTIONS(2497),
    [anon_sym_asm] = ACTIONS(2497),
    [anon_sym___asm__] = ACTIONS(2497),
    [anon_sym___asm] = ACTIONS(2497),
    [sym_number_literal] = ACTIONS(2499),
    [anon_sym_L_SQUOTE] = ACTIONS(2499),
    [anon_sym_u_SQUOTE] = ACTIONS(2499),
    [anon_sym_U_SQUOTE] = ACTIONS(2499),
    [anon_sym_u8_SQUOTE] = ACTIONS(2499),
    [anon_sym_SQUOTE] = ACTIONS(2499),
    [anon_sym_L_DQUOTE] = ACTIONS(2499),
    [anon_sym_u_DQUOTE] = ACTIONS(2499),
    [anon_sym_U_DQUOTE] = ACTIONS(2499),
    [anon_sym_u8_DQUOTE] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(2499),
    [sym_true] = ACTIONS(2497),
    [sym_false] = ACTIONS(2497),
    [anon_sym_NULL] = ACTIONS(2497),
    [anon_sym_nullptr] = ACTIONS(2497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2497),
    [anon_sym_decltype] = ACTIONS(2497),
    [anon_sym_explicit] = ACTIONS(2497),
    [anon_sym_typename] = ACTIONS(2497),
    [anon_sym_template] = ACTIONS(2497),
    [anon_sym_operator] = ACTIONS(2497),
    [anon_sym_try] = ACTIONS(2497),
    [anon_sym_delete] = ACTIONS(2497),
    [anon_sym_throw] = ACTIONS(2497),
    [anon_sym_namespace] = ACTIONS(2497),
    [anon_sym_using] = ACTIONS(2497),
    [anon_sym_static_assert] = ACTIONS(2497),
    [anon_sym_concept] = ACTIONS(2497),
    [anon_sym_co_return] = ACTIONS(2497),
    [anon_sym_co_yield] = ACTIONS(2497),
    [anon_sym_R_DQUOTE] = ACTIONS(2499),
    [anon_sym_LR_DQUOTE] = ACTIONS(2499),
    [anon_sym_uR_DQUOTE] = ACTIONS(2499),
    [anon_sym_UR_DQUOTE] = ACTIONS(2499),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2499),
    [anon_sym_co_await] = ACTIONS(2497),
    [anon_sym_new] = ACTIONS(2497),
    [anon_sym_requires] = ACTIONS(2497),
    [sym_this] = ACTIONS(2497),
    [anon_sym___launch_bounds__] = ACTIONS(2497),
  },
  [STATE(704)] = {
    [ts_builtin_sym_end] = ACTIONS(2322),
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_include_token1] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_BANG] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym___device__] = ACTIONS(2320),
    [anon_sym___host__] = ACTIONS(2320),
    [anon_sym___global__] = ACTIONS(2320),
    [anon_sym___forceinline__] = ACTIONS(2320),
    [anon_sym___noinline__] = ACTIONS(2320),
    [anon_sym_virtual] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym___attribute] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym___cdecl] = ACTIONS(2320),
    [anon_sym___clrcall] = ACTIONS(2320),
    [anon_sym___stdcall] = ACTIONS(2320),
    [anon_sym___fastcall] = ACTIONS(2320),
    [anon_sym___thiscall] = ACTIONS(2320),
    [anon_sym___vectorcall] = ACTIONS(2320),
    [anon_sym_LBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym__Nonnull] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym___shared__] = ACTIONS(2320),
    [anon_sym___local__] = ACTIONS(2320),
    [anon_sym___constant__] = ACTIONS(2320),
    [anon_sym___managed__] = ACTIONS(2320),
    [anon_sym___grid_constant__] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_switch] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_default] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_do] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_return] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_goto] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_compl] = ACTIONS(2320),
    [anon_sym_DASH_DASH] = ACTIONS(2322),
    [anon_sym_PLUS_PLUS] = ACTIONS(2322),
    [anon_sym_sizeof] = ACTIONS(2320),
    [anon_sym___alignof__] = ACTIONS(2320),
    [anon_sym___alignof] = ACTIONS(2320),
    [anon_sym__alignof] = ACTIONS(2320),
    [anon_sym_alignof] = ACTIONS(2320),
    [anon_sym__Alignof] = ACTIONS(2320),
    [anon_sym_offsetof] = ACTIONS(2320),
    [anon_sym__Generic] = ACTIONS(2320),
    [anon_sym_asm] = ACTIONS(2320),
    [anon_sym___asm__] = ACTIONS(2320),
    [anon_sym___asm] = ACTIONS(2320),
    [sym_number_literal] = ACTIONS(2322),
    [anon_sym_L_SQUOTE] = ACTIONS(2322),
    [anon_sym_u_SQUOTE] = ACTIONS(2322),
    [anon_sym_U_SQUOTE] = ACTIONS(2322),
    [anon_sym_u8_SQUOTE] = ACTIONS(2322),
    [anon_sym_SQUOTE] = ACTIONS(2322),
    [anon_sym_L_DQUOTE] = ACTIONS(2322),
    [anon_sym_u_DQUOTE] = ACTIONS(2322),
    [anon_sym_U_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8_DQUOTE] = ACTIONS(2322),
    [anon_sym_DQUOTE] = ACTIONS(2322),
    [sym_true] = ACTIONS(2320),
    [sym_false] = ACTIONS(2320),
    [anon_sym_NULL] = ACTIONS(2320),
    [anon_sym_nullptr] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_delete] = ACTIONS(2320),
    [anon_sym_throw] = ACTIONS(2320),
    [anon_sym_namespace] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_concept] = ACTIONS(2320),
    [anon_sym_co_return] = ACTIONS(2320),
    [anon_sym_co_yield] = ACTIONS(2320),
    [anon_sym_R_DQUOTE] = ACTIONS(2322),
    [anon_sym_LR_DQUOTE] = ACTIONS(2322),
    [anon_sym_uR_DQUOTE] = ACTIONS(2322),
    [anon_sym_UR_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2322),
    [anon_sym_co_await] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(2320),
    [anon_sym_requires] = ACTIONS(2320),
    [sym_this] = ACTIONS(2320),
    [anon_sym___launch_bounds__] = ACTIONS(2320),
  },
  [STATE(705)] = {
    [ts_builtin_sym_end] = ACTIONS(2326),
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym___device__] = ACTIONS(2324),
    [anon_sym___host__] = ACTIONS(2324),
    [anon_sym___global__] = ACTIONS(2324),
    [anon_sym___forceinline__] = ACTIONS(2324),
    [anon_sym___noinline__] = ACTIONS(2324),
    [anon_sym_virtual] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym___attribute] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym__Nonnull] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym___shared__] = ACTIONS(2324),
    [anon_sym___local__] = ACTIONS(2324),
    [anon_sym___constant__] = ACTIONS(2324),
    [anon_sym___managed__] = ACTIONS(2324),
    [anon_sym___grid_constant__] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [anon_sym___asm] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym___launch_bounds__] = ACTIONS(2324),
  },
  [STATE(706)] = {
    [ts_builtin_sym_end] = ACTIONS(2503),
    [sym_identifier] = ACTIONS(2501),
    [aux_sym_preproc_include_token1] = ACTIONS(2501),
    [aux_sym_preproc_def_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2501),
    [sym_preproc_directive] = ACTIONS(2501),
    [anon_sym_LPAREN2] = ACTIONS(2503),
    [anon_sym_BANG] = ACTIONS(2503),
    [anon_sym_TILDE] = ACTIONS(2503),
    [anon_sym_DASH] = ACTIONS(2501),
    [anon_sym_PLUS] = ACTIONS(2501),
    [anon_sym_STAR] = ACTIONS(2503),
    [anon_sym_AMP_AMP] = ACTIONS(2503),
    [anon_sym_AMP] = ACTIONS(2501),
    [anon_sym_SEMI] = ACTIONS(2503),
    [anon_sym___extension__] = ACTIONS(2501),
    [anon_sym_typedef] = ACTIONS(2501),
    [anon_sym___device__] = ACTIONS(2501),
    [anon_sym___host__] = ACTIONS(2501),
    [anon_sym___global__] = ACTIONS(2501),
    [anon_sym___forceinline__] = ACTIONS(2501),
    [anon_sym___noinline__] = ACTIONS(2501),
    [anon_sym_virtual] = ACTIONS(2501),
    [anon_sym_extern] = ACTIONS(2501),
    [anon_sym___attribute__] = ACTIONS(2501),
    [anon_sym___attribute] = ACTIONS(2501),
    [anon_sym_COLON_COLON] = ACTIONS(2503),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2503),
    [anon_sym___declspec] = ACTIONS(2501),
    [anon_sym___based] = ACTIONS(2501),
    [anon_sym___cdecl] = ACTIONS(2501),
    [anon_sym___clrcall] = ACTIONS(2501),
    [anon_sym___stdcall] = ACTIONS(2501),
    [anon_sym___fastcall] = ACTIONS(2501),
    [anon_sym___thiscall] = ACTIONS(2501),
    [anon_sym___vectorcall] = ACTIONS(2501),
    [anon_sym_LBRACE] = ACTIONS(2503),
    [anon_sym_signed] = ACTIONS(2501),
    [anon_sym_unsigned] = ACTIONS(2501),
    [anon_sym_long] = ACTIONS(2501),
    [anon_sym_short] = ACTIONS(2501),
    [anon_sym_LBRACK] = ACTIONS(2501),
    [anon_sym_static] = ACTIONS(2501),
    [anon_sym_register] = ACTIONS(2501),
    [anon_sym_inline] = ACTIONS(2501),
    [anon_sym___inline] = ACTIONS(2501),
    [anon_sym___inline__] = ACTIONS(2501),
    [anon_sym___forceinline] = ACTIONS(2501),
    [anon_sym_thread_local] = ACTIONS(2501),
    [anon_sym___thread] = ACTIONS(2501),
    [anon_sym_const] = ACTIONS(2501),
    [anon_sym_constexpr] = ACTIONS(2501),
    [anon_sym_volatile] = ACTIONS(2501),
    [anon_sym_restrict] = ACTIONS(2501),
    [anon_sym___restrict__] = ACTIONS(2501),
    [anon_sym__Atomic] = ACTIONS(2501),
    [anon_sym__Noreturn] = ACTIONS(2501),
    [anon_sym_noreturn] = ACTIONS(2501),
    [anon_sym__Nonnull] = ACTIONS(2501),
    [anon_sym_mutable] = ACTIONS(2501),
    [anon_sym_constinit] = ACTIONS(2501),
    [anon_sym_consteval] = ACTIONS(2501),
    [anon_sym___shared__] = ACTIONS(2501),
    [anon_sym___local__] = ACTIONS(2501),
    [anon_sym___constant__] = ACTIONS(2501),
    [anon_sym___managed__] = ACTIONS(2501),
    [anon_sym___grid_constant__] = ACTIONS(2501),
    [anon_sym_alignas] = ACTIONS(2501),
    [anon_sym__Alignas] = ACTIONS(2501),
    [sym_primitive_type] = ACTIONS(2501),
    [anon_sym_enum] = ACTIONS(2501),
    [anon_sym_class] = ACTIONS(2501),
    [anon_sym_struct] = ACTIONS(2501),
    [anon_sym_union] = ACTIONS(2501),
    [anon_sym_if] = ACTIONS(2501),
    [anon_sym_switch] = ACTIONS(2501),
    [anon_sym_case] = ACTIONS(2501),
    [anon_sym_default] = ACTIONS(2501),
    [anon_sym_while] = ACTIONS(2501),
    [anon_sym_do] = ACTIONS(2501),
    [anon_sym_for] = ACTIONS(2501),
    [anon_sym_return] = ACTIONS(2501),
    [anon_sym_break] = ACTIONS(2501),
    [anon_sym_continue] = ACTIONS(2501),
    [anon_sym_goto] = ACTIONS(2501),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_compl] = ACTIONS(2501),
    [anon_sym_DASH_DASH] = ACTIONS(2503),
    [anon_sym_PLUS_PLUS] = ACTIONS(2503),
    [anon_sym_sizeof] = ACTIONS(2501),
    [anon_sym___alignof__] = ACTIONS(2501),
    [anon_sym___alignof] = ACTIONS(2501),
    [anon_sym__alignof] = ACTIONS(2501),
    [anon_sym_alignof] = ACTIONS(2501),
    [anon_sym__Alignof] = ACTIONS(2501),
    [anon_sym_offsetof] = ACTIONS(2501),
    [anon_sym__Generic] = ACTIONS(2501),
    [anon_sym_asm] = ACTIONS(2501),
    [anon_sym___asm__] = ACTIONS(2501),
    [anon_sym___asm] = ACTIONS(2501),
    [sym_number_literal] = ACTIONS(2503),
    [anon_sym_L_SQUOTE] = ACTIONS(2503),
    [anon_sym_u_SQUOTE] = ACTIONS(2503),
    [anon_sym_U_SQUOTE] = ACTIONS(2503),
    [anon_sym_u8_SQUOTE] = ACTIONS(2503),
    [anon_sym_SQUOTE] = ACTIONS(2503),
    [anon_sym_L_DQUOTE] = ACTIONS(2503),
    [anon_sym_u_DQUOTE] = ACTIONS(2503),
    [anon_sym_U_DQUOTE] = ACTIONS(2503),
    [anon_sym_u8_DQUOTE] = ACTIONS(2503),
    [anon_sym_DQUOTE] = ACTIONS(2503),
    [sym_true] = ACTIONS(2501),
    [sym_false] = ACTIONS(2501),
    [anon_sym_NULL] = ACTIONS(2501),
    [anon_sym_nullptr] = ACTIONS(2501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2501),
    [anon_sym_decltype] = ACTIONS(2501),
    [anon_sym_explicit] = ACTIONS(2501),
    [anon_sym_typename] = ACTIONS(2501),
    [anon_sym_template] = ACTIONS(2501),
    [anon_sym_operator] = ACTIONS(2501),
    [anon_sym_try] = ACTIONS(2501),
    [anon_sym_delete] = ACTIONS(2501),
    [anon_sym_throw] = ACTIONS(2501),
    [anon_sym_namespace] = ACTIONS(2501),
    [anon_sym_using] = ACTIONS(2501),
    [anon_sym_static_assert] = ACTIONS(2501),
    [anon_sym_concept] = ACTIONS(2501),
    [anon_sym_co_return] = ACTIONS(2501),
    [anon_sym_co_yield] = ACTIONS(2501),
    [anon_sym_R_DQUOTE] = ACTIONS(2503),
    [anon_sym_LR_DQUOTE] = ACTIONS(2503),
    [anon_sym_uR_DQUOTE] = ACTIONS(2503),
    [anon_sym_UR_DQUOTE] = ACTIONS(2503),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2503),
    [anon_sym_co_await] = ACTIONS(2501),
    [anon_sym_new] = ACTIONS(2501),
    [anon_sym_requires] = ACTIONS(2501),
    [sym_this] = ACTIONS(2501),
    [anon_sym___launch_bounds__] = ACTIONS(2501),
  },
  [STATE(707)] = {
    [ts_builtin_sym_end] = ACTIONS(2619),
    [sym_identifier] = ACTIONS(2617),
    [aux_sym_preproc_include_token1] = ACTIONS(2617),
    [aux_sym_preproc_def_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2617),
    [sym_preproc_directive] = ACTIONS(2617),
    [anon_sym_LPAREN2] = ACTIONS(2619),
    [anon_sym_BANG] = ACTIONS(2619),
    [anon_sym_TILDE] = ACTIONS(2619),
    [anon_sym_DASH] = ACTIONS(2617),
    [anon_sym_PLUS] = ACTIONS(2617),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_AMP_AMP] = ACTIONS(2619),
    [anon_sym_AMP] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2619),
    [anon_sym___extension__] = ACTIONS(2617),
    [anon_sym_typedef] = ACTIONS(2617),
    [anon_sym___device__] = ACTIONS(2617),
    [anon_sym___host__] = ACTIONS(2617),
    [anon_sym___global__] = ACTIONS(2617),
    [anon_sym___forceinline__] = ACTIONS(2617),
    [anon_sym___noinline__] = ACTIONS(2617),
    [anon_sym_virtual] = ACTIONS(2617),
    [anon_sym_extern] = ACTIONS(2617),
    [anon_sym___attribute__] = ACTIONS(2617),
    [anon_sym___attribute] = ACTIONS(2617),
    [anon_sym_COLON_COLON] = ACTIONS(2619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2619),
    [anon_sym___declspec] = ACTIONS(2617),
    [anon_sym___based] = ACTIONS(2617),
    [anon_sym___cdecl] = ACTIONS(2617),
    [anon_sym___clrcall] = ACTIONS(2617),
    [anon_sym___stdcall] = ACTIONS(2617),
    [anon_sym___fastcall] = ACTIONS(2617),
    [anon_sym___thiscall] = ACTIONS(2617),
    [anon_sym___vectorcall] = ACTIONS(2617),
    [anon_sym_LBRACE] = ACTIONS(2619),
    [anon_sym_signed] = ACTIONS(2617),
    [anon_sym_unsigned] = ACTIONS(2617),
    [anon_sym_long] = ACTIONS(2617),
    [anon_sym_short] = ACTIONS(2617),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2617),
    [anon_sym_register] = ACTIONS(2617),
    [anon_sym_inline] = ACTIONS(2617),
    [anon_sym___inline] = ACTIONS(2617),
    [anon_sym___inline__] = ACTIONS(2617),
    [anon_sym___forceinline] = ACTIONS(2617),
    [anon_sym_thread_local] = ACTIONS(2617),
    [anon_sym___thread] = ACTIONS(2617),
    [anon_sym_const] = ACTIONS(2617),
    [anon_sym_constexpr] = ACTIONS(2617),
    [anon_sym_volatile] = ACTIONS(2617),
    [anon_sym_restrict] = ACTIONS(2617),
    [anon_sym___restrict__] = ACTIONS(2617),
    [anon_sym__Atomic] = ACTIONS(2617),
    [anon_sym__Noreturn] = ACTIONS(2617),
    [anon_sym_noreturn] = ACTIONS(2617),
    [anon_sym__Nonnull] = ACTIONS(2617),
    [anon_sym_mutable] = ACTIONS(2617),
    [anon_sym_constinit] = ACTIONS(2617),
    [anon_sym_consteval] = ACTIONS(2617),
    [anon_sym___shared__] = ACTIONS(2617),
    [anon_sym___local__] = ACTIONS(2617),
    [anon_sym___constant__] = ACTIONS(2617),
    [anon_sym___managed__] = ACTIONS(2617),
    [anon_sym___grid_constant__] = ACTIONS(2617),
    [anon_sym_alignas] = ACTIONS(2617),
    [anon_sym__Alignas] = ACTIONS(2617),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2617),
    [anon_sym_struct] = ACTIONS(2617),
    [anon_sym_union] = ACTIONS(2617),
    [anon_sym_if] = ACTIONS(2617),
    [anon_sym_switch] = ACTIONS(2617),
    [anon_sym_case] = ACTIONS(2617),
    [anon_sym_default] = ACTIONS(2617),
    [anon_sym_while] = ACTIONS(2617),
    [anon_sym_do] = ACTIONS(2617),
    [anon_sym_for] = ACTIONS(2617),
    [anon_sym_return] = ACTIONS(2617),
    [anon_sym_break] = ACTIONS(2617),
    [anon_sym_continue] = ACTIONS(2617),
    [anon_sym_goto] = ACTIONS(2617),
    [anon_sym_not] = ACTIONS(2617),
    [anon_sym_compl] = ACTIONS(2617),
    [anon_sym_DASH_DASH] = ACTIONS(2619),
    [anon_sym_PLUS_PLUS] = ACTIONS(2619),
    [anon_sym_sizeof] = ACTIONS(2617),
    [anon_sym___alignof__] = ACTIONS(2617),
    [anon_sym___alignof] = ACTIONS(2617),
    [anon_sym__alignof] = ACTIONS(2617),
    [anon_sym_alignof] = ACTIONS(2617),
    [anon_sym__Alignof] = ACTIONS(2617),
    [anon_sym_offsetof] = ACTIONS(2617),
    [anon_sym__Generic] = ACTIONS(2617),
    [anon_sym_asm] = ACTIONS(2617),
    [anon_sym___asm__] = ACTIONS(2617),
    [anon_sym___asm] = ACTIONS(2617),
    [sym_number_literal] = ACTIONS(2619),
    [anon_sym_L_SQUOTE] = ACTIONS(2619),
    [anon_sym_u_SQUOTE] = ACTIONS(2619),
    [anon_sym_U_SQUOTE] = ACTIONS(2619),
    [anon_sym_u8_SQUOTE] = ACTIONS(2619),
    [anon_sym_SQUOTE] = ACTIONS(2619),
    [anon_sym_L_DQUOTE] = ACTIONS(2619),
    [anon_sym_u_DQUOTE] = ACTIONS(2619),
    [anon_sym_U_DQUOTE] = ACTIONS(2619),
    [anon_sym_u8_DQUOTE] = ACTIONS(2619),
    [anon_sym_DQUOTE] = ACTIONS(2619),
    [sym_true] = ACTIONS(2617),
    [sym_false] = ACTIONS(2617),
    [anon_sym_NULL] = ACTIONS(2617),
    [anon_sym_nullptr] = ACTIONS(2617),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2617),
    [anon_sym_decltype] = ACTIONS(2617),
    [anon_sym_explicit] = ACTIONS(2617),
    [anon_sym_typename] = ACTIONS(2617),
    [anon_sym_template] = ACTIONS(2617),
    [anon_sym_operator] = ACTIONS(2617),
    [anon_sym_try] = ACTIONS(2617),
    [anon_sym_delete] = ACTIONS(2617),
    [anon_sym_throw] = ACTIONS(2617),
    [anon_sym_namespace] = ACTIONS(2617),
    [anon_sym_using] = ACTIONS(2617),
    [anon_sym_static_assert] = ACTIONS(2617),
    [anon_sym_concept] = ACTIONS(2617),
    [anon_sym_co_return] = ACTIONS(2617),
    [anon_sym_co_yield] = ACTIONS(2617),
    [anon_sym_R_DQUOTE] = ACTIONS(2619),
    [anon_sym_LR_DQUOTE] = ACTIONS(2619),
    [anon_sym_uR_DQUOTE] = ACTIONS(2619),
    [anon_sym_UR_DQUOTE] = ACTIONS(2619),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2619),
    [anon_sym_co_await] = ACTIONS(2617),
    [anon_sym_new] = ACTIONS(2617),
    [anon_sym_requires] = ACTIONS(2617),
    [sym_this] = ACTIONS(2617),
    [anon_sym___launch_bounds__] = ACTIONS(2617),
  },
  [STATE(708)] = {
    [ts_builtin_sym_end] = ACTIONS(2535),
    [sym_identifier] = ACTIONS(2533),
    [aux_sym_preproc_include_token1] = ACTIONS(2533),
    [aux_sym_preproc_def_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2533),
    [sym_preproc_directive] = ACTIONS(2533),
    [anon_sym_LPAREN2] = ACTIONS(2535),
    [anon_sym_BANG] = ACTIONS(2535),
    [anon_sym_TILDE] = ACTIONS(2535),
    [anon_sym_DASH] = ACTIONS(2533),
    [anon_sym_PLUS] = ACTIONS(2533),
    [anon_sym_STAR] = ACTIONS(2535),
    [anon_sym_AMP_AMP] = ACTIONS(2535),
    [anon_sym_AMP] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym___extension__] = ACTIONS(2533),
    [anon_sym_typedef] = ACTIONS(2533),
    [anon_sym___device__] = ACTIONS(2533),
    [anon_sym___host__] = ACTIONS(2533),
    [anon_sym___global__] = ACTIONS(2533),
    [anon_sym___forceinline__] = ACTIONS(2533),
    [anon_sym___noinline__] = ACTIONS(2533),
    [anon_sym_virtual] = ACTIONS(2533),
    [anon_sym_extern] = ACTIONS(2533),
    [anon_sym___attribute__] = ACTIONS(2533),
    [anon_sym___attribute] = ACTIONS(2533),
    [anon_sym_COLON_COLON] = ACTIONS(2535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2535),
    [anon_sym___declspec] = ACTIONS(2533),
    [anon_sym___based] = ACTIONS(2533),
    [anon_sym___cdecl] = ACTIONS(2533),
    [anon_sym___clrcall] = ACTIONS(2533),
    [anon_sym___stdcall] = ACTIONS(2533),
    [anon_sym___fastcall] = ACTIONS(2533),
    [anon_sym___thiscall] = ACTIONS(2533),
    [anon_sym___vectorcall] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2535),
    [anon_sym_signed] = ACTIONS(2533),
    [anon_sym_unsigned] = ACTIONS(2533),
    [anon_sym_long] = ACTIONS(2533),
    [anon_sym_short] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2533),
    [anon_sym_static] = ACTIONS(2533),
    [anon_sym_register] = ACTIONS(2533),
    [anon_sym_inline] = ACTIONS(2533),
    [anon_sym___inline] = ACTIONS(2533),
    [anon_sym___inline__] = ACTIONS(2533),
    [anon_sym___forceinline] = ACTIONS(2533),
    [anon_sym_thread_local] = ACTIONS(2533),
    [anon_sym___thread] = ACTIONS(2533),
    [anon_sym_const] = ACTIONS(2533),
    [anon_sym_constexpr] = ACTIONS(2533),
    [anon_sym_volatile] = ACTIONS(2533),
    [anon_sym_restrict] = ACTIONS(2533),
    [anon_sym___restrict__] = ACTIONS(2533),
    [anon_sym__Atomic] = ACTIONS(2533),
    [anon_sym__Noreturn] = ACTIONS(2533),
    [anon_sym_noreturn] = ACTIONS(2533),
    [anon_sym__Nonnull] = ACTIONS(2533),
    [anon_sym_mutable] = ACTIONS(2533),
    [anon_sym_constinit] = ACTIONS(2533),
    [anon_sym_consteval] = ACTIONS(2533),
    [anon_sym___shared__] = ACTIONS(2533),
    [anon_sym___local__] = ACTIONS(2533),
    [anon_sym___constant__] = ACTIONS(2533),
    [anon_sym___managed__] = ACTIONS(2533),
    [anon_sym___grid_constant__] = ACTIONS(2533),
    [anon_sym_alignas] = ACTIONS(2533),
    [anon_sym__Alignas] = ACTIONS(2533),
    [sym_primitive_type] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_class] = ACTIONS(2533),
    [anon_sym_struct] = ACTIONS(2533),
    [anon_sym_union] = ACTIONS(2533),
    [anon_sym_if] = ACTIONS(2533),
    [anon_sym_switch] = ACTIONS(2533),
    [anon_sym_case] = ACTIONS(2533),
    [anon_sym_default] = ACTIONS(2533),
    [anon_sym_while] = ACTIONS(2533),
    [anon_sym_do] = ACTIONS(2533),
    [anon_sym_for] = ACTIONS(2533),
    [anon_sym_return] = ACTIONS(2533),
    [anon_sym_break] = ACTIONS(2533),
    [anon_sym_continue] = ACTIONS(2533),
    [anon_sym_goto] = ACTIONS(2533),
    [anon_sym_not] = ACTIONS(2533),
    [anon_sym_compl] = ACTIONS(2533),
    [anon_sym_DASH_DASH] = ACTIONS(2535),
    [anon_sym_PLUS_PLUS] = ACTIONS(2535),
    [anon_sym_sizeof] = ACTIONS(2533),
    [anon_sym___alignof__] = ACTIONS(2533),
    [anon_sym___alignof] = ACTIONS(2533),
    [anon_sym__alignof] = ACTIONS(2533),
    [anon_sym_alignof] = ACTIONS(2533),
    [anon_sym__Alignof] = ACTIONS(2533),
    [anon_sym_offsetof] = ACTIONS(2533),
    [anon_sym__Generic] = ACTIONS(2533),
    [anon_sym_asm] = ACTIONS(2533),
    [anon_sym___asm__] = ACTIONS(2533),
    [anon_sym___asm] = ACTIONS(2533),
    [sym_number_literal] = ACTIONS(2535),
    [anon_sym_L_SQUOTE] = ACTIONS(2535),
    [anon_sym_u_SQUOTE] = ACTIONS(2535),
    [anon_sym_U_SQUOTE] = ACTIONS(2535),
    [anon_sym_u8_SQUOTE] = ACTIONS(2535),
    [anon_sym_SQUOTE] = ACTIONS(2535),
    [anon_sym_L_DQUOTE] = ACTIONS(2535),
    [anon_sym_u_DQUOTE] = ACTIONS(2535),
    [anon_sym_U_DQUOTE] = ACTIONS(2535),
    [anon_sym_u8_DQUOTE] = ACTIONS(2535),
    [anon_sym_DQUOTE] = ACTIONS(2535),
    [sym_true] = ACTIONS(2533),
    [sym_false] = ACTIONS(2533),
    [anon_sym_NULL] = ACTIONS(2533),
    [anon_sym_nullptr] = ACTIONS(2533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2533),
    [anon_sym_decltype] = ACTIONS(2533),
    [anon_sym_explicit] = ACTIONS(2533),
    [anon_sym_typename] = ACTIONS(2533),
    [anon_sym_template] = ACTIONS(2533),
    [anon_sym_operator] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2533),
    [anon_sym_delete] = ACTIONS(2533),
    [anon_sym_throw] = ACTIONS(2533),
    [anon_sym_namespace] = ACTIONS(2533),
    [anon_sym_using] = ACTIONS(2533),
    [anon_sym_static_assert] = ACTIONS(2533),
    [anon_sym_concept] = ACTIONS(2533),
    [anon_sym_co_return] = ACTIONS(2533),
    [anon_sym_co_yield] = ACTIONS(2533),
    [anon_sym_R_DQUOTE] = ACTIONS(2535),
    [anon_sym_LR_DQUOTE] = ACTIONS(2535),
    [anon_sym_uR_DQUOTE] = ACTIONS(2535),
    [anon_sym_UR_DQUOTE] = ACTIONS(2535),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2535),
    [anon_sym_co_await] = ACTIONS(2533),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_requires] = ACTIONS(2533),
    [sym_this] = ACTIONS(2533),
    [anon_sym___launch_bounds__] = ACTIONS(2533),
  },
  [STATE(709)] = {
    [ts_builtin_sym_end] = ACTIONS(2593),
    [sym_identifier] = ACTIONS(2591),
    [aux_sym_preproc_include_token1] = ACTIONS(2591),
    [aux_sym_preproc_def_token1] = ACTIONS(2591),
    [aux_sym_preproc_if_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [sym_preproc_directive] = ACTIONS(2591),
    [anon_sym_LPAREN2] = ACTIONS(2593),
    [anon_sym_BANG] = ACTIONS(2593),
    [anon_sym_TILDE] = ACTIONS(2593),
    [anon_sym_DASH] = ACTIONS(2591),
    [anon_sym_PLUS] = ACTIONS(2591),
    [anon_sym_STAR] = ACTIONS(2593),
    [anon_sym_AMP_AMP] = ACTIONS(2593),
    [anon_sym_AMP] = ACTIONS(2591),
    [anon_sym_SEMI] = ACTIONS(2593),
    [anon_sym___extension__] = ACTIONS(2591),
    [anon_sym_typedef] = ACTIONS(2591),
    [anon_sym___device__] = ACTIONS(2591),
    [anon_sym___host__] = ACTIONS(2591),
    [anon_sym___global__] = ACTIONS(2591),
    [anon_sym___forceinline__] = ACTIONS(2591),
    [anon_sym___noinline__] = ACTIONS(2591),
    [anon_sym_virtual] = ACTIONS(2591),
    [anon_sym_extern] = ACTIONS(2591),
    [anon_sym___attribute__] = ACTIONS(2591),
    [anon_sym___attribute] = ACTIONS(2591),
    [anon_sym_COLON_COLON] = ACTIONS(2593),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2593),
    [anon_sym___declspec] = ACTIONS(2591),
    [anon_sym___based] = ACTIONS(2591),
    [anon_sym___cdecl] = ACTIONS(2591),
    [anon_sym___clrcall] = ACTIONS(2591),
    [anon_sym___stdcall] = ACTIONS(2591),
    [anon_sym___fastcall] = ACTIONS(2591),
    [anon_sym___thiscall] = ACTIONS(2591),
    [anon_sym___vectorcall] = ACTIONS(2591),
    [anon_sym_LBRACE] = ACTIONS(2593),
    [anon_sym_signed] = ACTIONS(2591),
    [anon_sym_unsigned] = ACTIONS(2591),
    [anon_sym_long] = ACTIONS(2591),
    [anon_sym_short] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2591),
    [anon_sym_static] = ACTIONS(2591),
    [anon_sym_register] = ACTIONS(2591),
    [anon_sym_inline] = ACTIONS(2591),
    [anon_sym___inline] = ACTIONS(2591),
    [anon_sym___inline__] = ACTIONS(2591),
    [anon_sym___forceinline] = ACTIONS(2591),
    [anon_sym_thread_local] = ACTIONS(2591),
    [anon_sym___thread] = ACTIONS(2591),
    [anon_sym_const] = ACTIONS(2591),
    [anon_sym_constexpr] = ACTIONS(2591),
    [anon_sym_volatile] = ACTIONS(2591),
    [anon_sym_restrict] = ACTIONS(2591),
    [anon_sym___restrict__] = ACTIONS(2591),
    [anon_sym__Atomic] = ACTIONS(2591),
    [anon_sym__Noreturn] = ACTIONS(2591),
    [anon_sym_noreturn] = ACTIONS(2591),
    [anon_sym__Nonnull] = ACTIONS(2591),
    [anon_sym_mutable] = ACTIONS(2591),
    [anon_sym_constinit] = ACTIONS(2591),
    [anon_sym_consteval] = ACTIONS(2591),
    [anon_sym___shared__] = ACTIONS(2591),
    [anon_sym___local__] = ACTIONS(2591),
    [anon_sym___constant__] = ACTIONS(2591),
    [anon_sym___managed__] = ACTIONS(2591),
    [anon_sym___grid_constant__] = ACTIONS(2591),
    [anon_sym_alignas] = ACTIONS(2591),
    [anon_sym__Alignas] = ACTIONS(2591),
    [sym_primitive_type] = ACTIONS(2591),
    [anon_sym_enum] = ACTIONS(2591),
    [anon_sym_class] = ACTIONS(2591),
    [anon_sym_struct] = ACTIONS(2591),
    [anon_sym_union] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_switch] = ACTIONS(2591),
    [anon_sym_case] = ACTIONS(2591),
    [anon_sym_default] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(2591),
    [anon_sym_do] = ACTIONS(2591),
    [anon_sym_for] = ACTIONS(2591),
    [anon_sym_return] = ACTIONS(2591),
    [anon_sym_break] = ACTIONS(2591),
    [anon_sym_continue] = ACTIONS(2591),
    [anon_sym_goto] = ACTIONS(2591),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_compl] = ACTIONS(2591),
    [anon_sym_DASH_DASH] = ACTIONS(2593),
    [anon_sym_PLUS_PLUS] = ACTIONS(2593),
    [anon_sym_sizeof] = ACTIONS(2591),
    [anon_sym___alignof__] = ACTIONS(2591),
    [anon_sym___alignof] = ACTIONS(2591),
    [anon_sym__alignof] = ACTIONS(2591),
    [anon_sym_alignof] = ACTIONS(2591),
    [anon_sym__Alignof] = ACTIONS(2591),
    [anon_sym_offsetof] = ACTIONS(2591),
    [anon_sym__Generic] = ACTIONS(2591),
    [anon_sym_asm] = ACTIONS(2591),
    [anon_sym___asm__] = ACTIONS(2591),
    [anon_sym___asm] = ACTIONS(2591),
    [sym_number_literal] = ACTIONS(2593),
    [anon_sym_L_SQUOTE] = ACTIONS(2593),
    [anon_sym_u_SQUOTE] = ACTIONS(2593),
    [anon_sym_U_SQUOTE] = ACTIONS(2593),
    [anon_sym_u8_SQUOTE] = ACTIONS(2593),
    [anon_sym_SQUOTE] = ACTIONS(2593),
    [anon_sym_L_DQUOTE] = ACTIONS(2593),
    [anon_sym_u_DQUOTE] = ACTIONS(2593),
    [anon_sym_U_DQUOTE] = ACTIONS(2593),
    [anon_sym_u8_DQUOTE] = ACTIONS(2593),
    [anon_sym_DQUOTE] = ACTIONS(2593),
    [sym_true] = ACTIONS(2591),
    [sym_false] = ACTIONS(2591),
    [anon_sym_NULL] = ACTIONS(2591),
    [anon_sym_nullptr] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2591),
    [anon_sym_decltype] = ACTIONS(2591),
    [anon_sym_explicit] = ACTIONS(2591),
    [anon_sym_typename] = ACTIONS(2591),
    [anon_sym_template] = ACTIONS(2591),
    [anon_sym_operator] = ACTIONS(2591),
    [anon_sym_try] = ACTIONS(2591),
    [anon_sym_delete] = ACTIONS(2591),
    [anon_sym_throw] = ACTIONS(2591),
    [anon_sym_namespace] = ACTIONS(2591),
    [anon_sym_using] = ACTIONS(2591),
    [anon_sym_static_assert] = ACTIONS(2591),
    [anon_sym_concept] = ACTIONS(2591),
    [anon_sym_co_return] = ACTIONS(2591),
    [anon_sym_co_yield] = ACTIONS(2591),
    [anon_sym_R_DQUOTE] = ACTIONS(2593),
    [anon_sym_LR_DQUOTE] = ACTIONS(2593),
    [anon_sym_uR_DQUOTE] = ACTIONS(2593),
    [anon_sym_UR_DQUOTE] = ACTIONS(2593),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2593),
    [anon_sym_co_await] = ACTIONS(2591),
    [anon_sym_new] = ACTIONS(2591),
    [anon_sym_requires] = ACTIONS(2591),
    [sym_this] = ACTIONS(2591),
    [anon_sym___launch_bounds__] = ACTIONS(2591),
  },
  [STATE(710)] = {
    [ts_builtin_sym_end] = ACTIONS(2469),
    [sym_identifier] = ACTIONS(2467),
    [aux_sym_preproc_include_token1] = ACTIONS(2467),
    [aux_sym_preproc_def_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2467),
    [sym_preproc_directive] = ACTIONS(2467),
    [anon_sym_LPAREN2] = ACTIONS(2469),
    [anon_sym_BANG] = ACTIONS(2469),
    [anon_sym_TILDE] = ACTIONS(2469),
    [anon_sym_DASH] = ACTIONS(2467),
    [anon_sym_PLUS] = ACTIONS(2467),
    [anon_sym_STAR] = ACTIONS(2469),
    [anon_sym_AMP_AMP] = ACTIONS(2469),
    [anon_sym_AMP] = ACTIONS(2467),
    [anon_sym_SEMI] = ACTIONS(2469),
    [anon_sym___extension__] = ACTIONS(2467),
    [anon_sym_typedef] = ACTIONS(2467),
    [anon_sym___device__] = ACTIONS(2467),
    [anon_sym___host__] = ACTIONS(2467),
    [anon_sym___global__] = ACTIONS(2467),
    [anon_sym___forceinline__] = ACTIONS(2467),
    [anon_sym___noinline__] = ACTIONS(2467),
    [anon_sym_virtual] = ACTIONS(2467),
    [anon_sym_extern] = ACTIONS(2467),
    [anon_sym___attribute__] = ACTIONS(2467),
    [anon_sym___attribute] = ACTIONS(2467),
    [anon_sym_COLON_COLON] = ACTIONS(2469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2469),
    [anon_sym___declspec] = ACTIONS(2467),
    [anon_sym___based] = ACTIONS(2467),
    [anon_sym___cdecl] = ACTIONS(2467),
    [anon_sym___clrcall] = ACTIONS(2467),
    [anon_sym___stdcall] = ACTIONS(2467),
    [anon_sym___fastcall] = ACTIONS(2467),
    [anon_sym___thiscall] = ACTIONS(2467),
    [anon_sym___vectorcall] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2469),
    [anon_sym_signed] = ACTIONS(2467),
    [anon_sym_unsigned] = ACTIONS(2467),
    [anon_sym_long] = ACTIONS(2467),
    [anon_sym_short] = ACTIONS(2467),
    [anon_sym_LBRACK] = ACTIONS(2467),
    [anon_sym_static] = ACTIONS(2467),
    [anon_sym_register] = ACTIONS(2467),
    [anon_sym_inline] = ACTIONS(2467),
    [anon_sym___inline] = ACTIONS(2467),
    [anon_sym___inline__] = ACTIONS(2467),
    [anon_sym___forceinline] = ACTIONS(2467),
    [anon_sym_thread_local] = ACTIONS(2467),
    [anon_sym___thread] = ACTIONS(2467),
    [anon_sym_const] = ACTIONS(2467),
    [anon_sym_constexpr] = ACTIONS(2467),
    [anon_sym_volatile] = ACTIONS(2467),
    [anon_sym_restrict] = ACTIONS(2467),
    [anon_sym___restrict__] = ACTIONS(2467),
    [anon_sym__Atomic] = ACTIONS(2467),
    [anon_sym__Noreturn] = ACTIONS(2467),
    [anon_sym_noreturn] = ACTIONS(2467),
    [anon_sym__Nonnull] = ACTIONS(2467),
    [anon_sym_mutable] = ACTIONS(2467),
    [anon_sym_constinit] = ACTIONS(2467),
    [anon_sym_consteval] = ACTIONS(2467),
    [anon_sym___shared__] = ACTIONS(2467),
    [anon_sym___local__] = ACTIONS(2467),
    [anon_sym___constant__] = ACTIONS(2467),
    [anon_sym___managed__] = ACTIONS(2467),
    [anon_sym___grid_constant__] = ACTIONS(2467),
    [anon_sym_alignas] = ACTIONS(2467),
    [anon_sym__Alignas] = ACTIONS(2467),
    [sym_primitive_type] = ACTIONS(2467),
    [anon_sym_enum] = ACTIONS(2467),
    [anon_sym_class] = ACTIONS(2467),
    [anon_sym_struct] = ACTIONS(2467),
    [anon_sym_union] = ACTIONS(2467),
    [anon_sym_if] = ACTIONS(2467),
    [anon_sym_switch] = ACTIONS(2467),
    [anon_sym_case] = ACTIONS(2467),
    [anon_sym_default] = ACTIONS(2467),
    [anon_sym_while] = ACTIONS(2467),
    [anon_sym_do] = ACTIONS(2467),
    [anon_sym_for] = ACTIONS(2467),
    [anon_sym_return] = ACTIONS(2467),
    [anon_sym_break] = ACTIONS(2467),
    [anon_sym_continue] = ACTIONS(2467),
    [anon_sym_goto] = ACTIONS(2467),
    [anon_sym_not] = ACTIONS(2467),
    [anon_sym_compl] = ACTIONS(2467),
    [anon_sym_DASH_DASH] = ACTIONS(2469),
    [anon_sym_PLUS_PLUS] = ACTIONS(2469),
    [anon_sym_sizeof] = ACTIONS(2467),
    [anon_sym___alignof__] = ACTIONS(2467),
    [anon_sym___alignof] = ACTIONS(2467),
    [anon_sym__alignof] = ACTIONS(2467),
    [anon_sym_alignof] = ACTIONS(2467),
    [anon_sym__Alignof] = ACTIONS(2467),
    [anon_sym_offsetof] = ACTIONS(2467),
    [anon_sym__Generic] = ACTIONS(2467),
    [anon_sym_asm] = ACTIONS(2467),
    [anon_sym___asm__] = ACTIONS(2467),
    [anon_sym___asm] = ACTIONS(2467),
    [sym_number_literal] = ACTIONS(2469),
    [anon_sym_L_SQUOTE] = ACTIONS(2469),
    [anon_sym_u_SQUOTE] = ACTIONS(2469),
    [anon_sym_U_SQUOTE] = ACTIONS(2469),
    [anon_sym_u8_SQUOTE] = ACTIONS(2469),
    [anon_sym_SQUOTE] = ACTIONS(2469),
    [anon_sym_L_DQUOTE] = ACTIONS(2469),
    [anon_sym_u_DQUOTE] = ACTIONS(2469),
    [anon_sym_U_DQUOTE] = ACTIONS(2469),
    [anon_sym_u8_DQUOTE] = ACTIONS(2469),
    [anon_sym_DQUOTE] = ACTIONS(2469),
    [sym_true] = ACTIONS(2467),
    [sym_false] = ACTIONS(2467),
    [anon_sym_NULL] = ACTIONS(2467),
    [anon_sym_nullptr] = ACTIONS(2467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2467),
    [anon_sym_decltype] = ACTIONS(2467),
    [anon_sym_explicit] = ACTIONS(2467),
    [anon_sym_typename] = ACTIONS(2467),
    [anon_sym_template] = ACTIONS(2467),
    [anon_sym_operator] = ACTIONS(2467),
    [anon_sym_try] = ACTIONS(2467),
    [anon_sym_delete] = ACTIONS(2467),
    [anon_sym_throw] = ACTIONS(2467),
    [anon_sym_namespace] = ACTIONS(2467),
    [anon_sym_using] = ACTIONS(2467),
    [anon_sym_static_assert] = ACTIONS(2467),
    [anon_sym_concept] = ACTIONS(2467),
    [anon_sym_co_return] = ACTIONS(2467),
    [anon_sym_co_yield] = ACTIONS(2467),
    [anon_sym_R_DQUOTE] = ACTIONS(2469),
    [anon_sym_LR_DQUOTE] = ACTIONS(2469),
    [anon_sym_uR_DQUOTE] = ACTIONS(2469),
    [anon_sym_UR_DQUOTE] = ACTIONS(2469),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2469),
    [anon_sym_co_await] = ACTIONS(2467),
    [anon_sym_new] = ACTIONS(2467),
    [anon_sym_requires] = ACTIONS(2467),
    [sym_this] = ACTIONS(2467),
    [anon_sym___launch_bounds__] = ACTIONS(2467),
  },
  [STATE(711)] = {
    [ts_builtin_sym_end] = ACTIONS(2459),
    [sym_identifier] = ACTIONS(2457),
    [aux_sym_preproc_include_token1] = ACTIONS(2457),
    [aux_sym_preproc_def_token1] = ACTIONS(2457),
    [aux_sym_preproc_if_token1] = ACTIONS(2457),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2457),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2457),
    [sym_preproc_directive] = ACTIONS(2457),
    [anon_sym_LPAREN2] = ACTIONS(2459),
    [anon_sym_BANG] = ACTIONS(2459),
    [anon_sym_TILDE] = ACTIONS(2459),
    [anon_sym_DASH] = ACTIONS(2457),
    [anon_sym_PLUS] = ACTIONS(2457),
    [anon_sym_STAR] = ACTIONS(2459),
    [anon_sym_AMP_AMP] = ACTIONS(2459),
    [anon_sym_AMP] = ACTIONS(2457),
    [anon_sym_SEMI] = ACTIONS(2459),
    [anon_sym___extension__] = ACTIONS(2457),
    [anon_sym_typedef] = ACTIONS(2457),
    [anon_sym___device__] = ACTIONS(2457),
    [anon_sym___host__] = ACTIONS(2457),
    [anon_sym___global__] = ACTIONS(2457),
    [anon_sym___forceinline__] = ACTIONS(2457),
    [anon_sym___noinline__] = ACTIONS(2457),
    [anon_sym_virtual] = ACTIONS(2457),
    [anon_sym_extern] = ACTIONS(2457),
    [anon_sym___attribute__] = ACTIONS(2457),
    [anon_sym___attribute] = ACTIONS(2457),
    [anon_sym_COLON_COLON] = ACTIONS(2459),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2459),
    [anon_sym___declspec] = ACTIONS(2457),
    [anon_sym___based] = ACTIONS(2457),
    [anon_sym___cdecl] = ACTIONS(2457),
    [anon_sym___clrcall] = ACTIONS(2457),
    [anon_sym___stdcall] = ACTIONS(2457),
    [anon_sym___fastcall] = ACTIONS(2457),
    [anon_sym___thiscall] = ACTIONS(2457),
    [anon_sym___vectorcall] = ACTIONS(2457),
    [anon_sym_LBRACE] = ACTIONS(2459),
    [anon_sym_signed] = ACTIONS(2457),
    [anon_sym_unsigned] = ACTIONS(2457),
    [anon_sym_long] = ACTIONS(2457),
    [anon_sym_short] = ACTIONS(2457),
    [anon_sym_LBRACK] = ACTIONS(2457),
    [anon_sym_static] = ACTIONS(2457),
    [anon_sym_register] = ACTIONS(2457),
    [anon_sym_inline] = ACTIONS(2457),
    [anon_sym___inline] = ACTIONS(2457),
    [anon_sym___inline__] = ACTIONS(2457),
    [anon_sym___forceinline] = ACTIONS(2457),
    [anon_sym_thread_local] = ACTIONS(2457),
    [anon_sym___thread] = ACTIONS(2457),
    [anon_sym_const] = ACTIONS(2457),
    [anon_sym_constexpr] = ACTIONS(2457),
    [anon_sym_volatile] = ACTIONS(2457),
    [anon_sym_restrict] = ACTIONS(2457),
    [anon_sym___restrict__] = ACTIONS(2457),
    [anon_sym__Atomic] = ACTIONS(2457),
    [anon_sym__Noreturn] = ACTIONS(2457),
    [anon_sym_noreturn] = ACTIONS(2457),
    [anon_sym__Nonnull] = ACTIONS(2457),
    [anon_sym_mutable] = ACTIONS(2457),
    [anon_sym_constinit] = ACTIONS(2457),
    [anon_sym_consteval] = ACTIONS(2457),
    [anon_sym___shared__] = ACTIONS(2457),
    [anon_sym___local__] = ACTIONS(2457),
    [anon_sym___constant__] = ACTIONS(2457),
    [anon_sym___managed__] = ACTIONS(2457),
    [anon_sym___grid_constant__] = ACTIONS(2457),
    [anon_sym_alignas] = ACTIONS(2457),
    [anon_sym__Alignas] = ACTIONS(2457),
    [sym_primitive_type] = ACTIONS(2457),
    [anon_sym_enum] = ACTIONS(2457),
    [anon_sym_class] = ACTIONS(2457),
    [anon_sym_struct] = ACTIONS(2457),
    [anon_sym_union] = ACTIONS(2457),
    [anon_sym_if] = ACTIONS(2457),
    [anon_sym_switch] = ACTIONS(2457),
    [anon_sym_case] = ACTIONS(2457),
    [anon_sym_default] = ACTIONS(2457),
    [anon_sym_while] = ACTIONS(2457),
    [anon_sym_do] = ACTIONS(2457),
    [anon_sym_for] = ACTIONS(2457),
    [anon_sym_return] = ACTIONS(2457),
    [anon_sym_break] = ACTIONS(2457),
    [anon_sym_continue] = ACTIONS(2457),
    [anon_sym_goto] = ACTIONS(2457),
    [anon_sym_not] = ACTIONS(2457),
    [anon_sym_compl] = ACTIONS(2457),
    [anon_sym_DASH_DASH] = ACTIONS(2459),
    [anon_sym_PLUS_PLUS] = ACTIONS(2459),
    [anon_sym_sizeof] = ACTIONS(2457),
    [anon_sym___alignof__] = ACTIONS(2457),
    [anon_sym___alignof] = ACTIONS(2457),
    [anon_sym__alignof] = ACTIONS(2457),
    [anon_sym_alignof] = ACTIONS(2457),
    [anon_sym__Alignof] = ACTIONS(2457),
    [anon_sym_offsetof] = ACTIONS(2457),
    [anon_sym__Generic] = ACTIONS(2457),
    [anon_sym_asm] = ACTIONS(2457),
    [anon_sym___asm__] = ACTIONS(2457),
    [anon_sym___asm] = ACTIONS(2457),
    [sym_number_literal] = ACTIONS(2459),
    [anon_sym_L_SQUOTE] = ACTIONS(2459),
    [anon_sym_u_SQUOTE] = ACTIONS(2459),
    [anon_sym_U_SQUOTE] = ACTIONS(2459),
    [anon_sym_u8_SQUOTE] = ACTIONS(2459),
    [anon_sym_SQUOTE] = ACTIONS(2459),
    [anon_sym_L_DQUOTE] = ACTIONS(2459),
    [anon_sym_u_DQUOTE] = ACTIONS(2459),
    [anon_sym_U_DQUOTE] = ACTIONS(2459),
    [anon_sym_u8_DQUOTE] = ACTIONS(2459),
    [anon_sym_DQUOTE] = ACTIONS(2459),
    [sym_true] = ACTIONS(2457),
    [sym_false] = ACTIONS(2457),
    [anon_sym_NULL] = ACTIONS(2457),
    [anon_sym_nullptr] = ACTIONS(2457),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2457),
    [anon_sym_decltype] = ACTIONS(2457),
    [anon_sym_explicit] = ACTIONS(2457),
    [anon_sym_typename] = ACTIONS(2457),
    [anon_sym_template] = ACTIONS(2457),
    [anon_sym_operator] = ACTIONS(2457),
    [anon_sym_try] = ACTIONS(2457),
    [anon_sym_delete] = ACTIONS(2457),
    [anon_sym_throw] = ACTIONS(2457),
    [anon_sym_namespace] = ACTIONS(2457),
    [anon_sym_using] = ACTIONS(2457),
    [anon_sym_static_assert] = ACTIONS(2457),
    [anon_sym_concept] = ACTIONS(2457),
    [anon_sym_co_return] = ACTIONS(2457),
    [anon_sym_co_yield] = ACTIONS(2457),
    [anon_sym_R_DQUOTE] = ACTIONS(2459),
    [anon_sym_LR_DQUOTE] = ACTIONS(2459),
    [anon_sym_uR_DQUOTE] = ACTIONS(2459),
    [anon_sym_UR_DQUOTE] = ACTIONS(2459),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2459),
    [anon_sym_co_await] = ACTIONS(2457),
    [anon_sym_new] = ACTIONS(2457),
    [anon_sym_requires] = ACTIONS(2457),
    [sym_this] = ACTIONS(2457),
    [anon_sym___launch_bounds__] = ACTIONS(2457),
  },
  [STATE(712)] = {
    [ts_builtin_sym_end] = ACTIONS(2601),
    [sym_identifier] = ACTIONS(2599),
    [aux_sym_preproc_include_token1] = ACTIONS(2599),
    [aux_sym_preproc_def_token1] = ACTIONS(2599),
    [aux_sym_preproc_if_token1] = ACTIONS(2599),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2599),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2599),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_BANG] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2601),
    [anon_sym_DASH] = ACTIONS(2599),
    [anon_sym_PLUS] = ACTIONS(2599),
    [anon_sym_STAR] = ACTIONS(2601),
    [anon_sym_AMP_AMP] = ACTIONS(2601),
    [anon_sym_AMP] = ACTIONS(2599),
    [anon_sym_SEMI] = ACTIONS(2601),
    [anon_sym___extension__] = ACTIONS(2599),
    [anon_sym_typedef] = ACTIONS(2599),
    [anon_sym___device__] = ACTIONS(2599),
    [anon_sym___host__] = ACTIONS(2599),
    [anon_sym___global__] = ACTIONS(2599),
    [anon_sym___forceinline__] = ACTIONS(2599),
    [anon_sym___noinline__] = ACTIONS(2599),
    [anon_sym_virtual] = ACTIONS(2599),
    [anon_sym_extern] = ACTIONS(2599),
    [anon_sym___attribute__] = ACTIONS(2599),
    [anon_sym___attribute] = ACTIONS(2599),
    [anon_sym_COLON_COLON] = ACTIONS(2601),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2601),
    [anon_sym___declspec] = ACTIONS(2599),
    [anon_sym___based] = ACTIONS(2599),
    [anon_sym___cdecl] = ACTIONS(2599),
    [anon_sym___clrcall] = ACTIONS(2599),
    [anon_sym___stdcall] = ACTIONS(2599),
    [anon_sym___fastcall] = ACTIONS(2599),
    [anon_sym___thiscall] = ACTIONS(2599),
    [anon_sym___vectorcall] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(2601),
    [anon_sym_signed] = ACTIONS(2599),
    [anon_sym_unsigned] = ACTIONS(2599),
    [anon_sym_long] = ACTIONS(2599),
    [anon_sym_short] = ACTIONS(2599),
    [anon_sym_LBRACK] = ACTIONS(2599),
    [anon_sym_static] = ACTIONS(2599),
    [anon_sym_register] = ACTIONS(2599),
    [anon_sym_inline] = ACTIONS(2599),
    [anon_sym___inline] = ACTIONS(2599),
    [anon_sym___inline__] = ACTIONS(2599),
    [anon_sym___forceinline] = ACTIONS(2599),
    [anon_sym_thread_local] = ACTIONS(2599),
    [anon_sym___thread] = ACTIONS(2599),
    [anon_sym_const] = ACTIONS(2599),
    [anon_sym_constexpr] = ACTIONS(2599),
    [anon_sym_volatile] = ACTIONS(2599),
    [anon_sym_restrict] = ACTIONS(2599),
    [anon_sym___restrict__] = ACTIONS(2599),
    [anon_sym__Atomic] = ACTIONS(2599),
    [anon_sym__Noreturn] = ACTIONS(2599),
    [anon_sym_noreturn] = ACTIONS(2599),
    [anon_sym__Nonnull] = ACTIONS(2599),
    [anon_sym_mutable] = ACTIONS(2599),
    [anon_sym_constinit] = ACTIONS(2599),
    [anon_sym_consteval] = ACTIONS(2599),
    [anon_sym___shared__] = ACTIONS(2599),
    [anon_sym___local__] = ACTIONS(2599),
    [anon_sym___constant__] = ACTIONS(2599),
    [anon_sym___managed__] = ACTIONS(2599),
    [anon_sym___grid_constant__] = ACTIONS(2599),
    [anon_sym_alignas] = ACTIONS(2599),
    [anon_sym__Alignas] = ACTIONS(2599),
    [sym_primitive_type] = ACTIONS(2599),
    [anon_sym_enum] = ACTIONS(2599),
    [anon_sym_class] = ACTIONS(2599),
    [anon_sym_struct] = ACTIONS(2599),
    [anon_sym_union] = ACTIONS(2599),
    [anon_sym_if] = ACTIONS(2599),
    [anon_sym_switch] = ACTIONS(2599),
    [anon_sym_case] = ACTIONS(2599),
    [anon_sym_default] = ACTIONS(2599),
    [anon_sym_while] = ACTIONS(2599),
    [anon_sym_do] = ACTIONS(2599),
    [anon_sym_for] = ACTIONS(2599),
    [anon_sym_return] = ACTIONS(2599),
    [anon_sym_break] = ACTIONS(2599),
    [anon_sym_continue] = ACTIONS(2599),
    [anon_sym_goto] = ACTIONS(2599),
    [anon_sym_not] = ACTIONS(2599),
    [anon_sym_compl] = ACTIONS(2599),
    [anon_sym_DASH_DASH] = ACTIONS(2601),
    [anon_sym_PLUS_PLUS] = ACTIONS(2601),
    [anon_sym_sizeof] = ACTIONS(2599),
    [anon_sym___alignof__] = ACTIONS(2599),
    [anon_sym___alignof] = ACTIONS(2599),
    [anon_sym__alignof] = ACTIONS(2599),
    [anon_sym_alignof] = ACTIONS(2599),
    [anon_sym__Alignof] = ACTIONS(2599),
    [anon_sym_offsetof] = ACTIONS(2599),
    [anon_sym__Generic] = ACTIONS(2599),
    [anon_sym_asm] = ACTIONS(2599),
    [anon_sym___asm__] = ACTIONS(2599),
    [anon_sym___asm] = ACTIONS(2599),
    [sym_number_literal] = ACTIONS(2601),
    [anon_sym_L_SQUOTE] = ACTIONS(2601),
    [anon_sym_u_SQUOTE] = ACTIONS(2601),
    [anon_sym_U_SQUOTE] = ACTIONS(2601),
    [anon_sym_u8_SQUOTE] = ACTIONS(2601),
    [anon_sym_SQUOTE] = ACTIONS(2601),
    [anon_sym_L_DQUOTE] = ACTIONS(2601),
    [anon_sym_u_DQUOTE] = ACTIONS(2601),
    [anon_sym_U_DQUOTE] = ACTIONS(2601),
    [anon_sym_u8_DQUOTE] = ACTIONS(2601),
    [anon_sym_DQUOTE] = ACTIONS(2601),
    [sym_true] = ACTIONS(2599),
    [sym_false] = ACTIONS(2599),
    [anon_sym_NULL] = ACTIONS(2599),
    [anon_sym_nullptr] = ACTIONS(2599),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2599),
    [anon_sym_decltype] = ACTIONS(2599),
    [anon_sym_explicit] = ACTIONS(2599),
    [anon_sym_typename] = ACTIONS(2599),
    [anon_sym_template] = ACTIONS(2599),
    [anon_sym_operator] = ACTIONS(2599),
    [anon_sym_try] = ACTIONS(2599),
    [anon_sym_delete] = ACTIONS(2599),
    [anon_sym_throw] = ACTIONS(2599),
    [anon_sym_namespace] = ACTIONS(2599),
    [anon_sym_using] = ACTIONS(2599),
    [anon_sym_static_assert] = ACTIONS(2599),
    [anon_sym_concept] = ACTIONS(2599),
    [anon_sym_co_return] = ACTIONS(2599),
    [anon_sym_co_yield] = ACTIONS(2599),
    [anon_sym_R_DQUOTE] = ACTIONS(2601),
    [anon_sym_LR_DQUOTE] = ACTIONS(2601),
    [anon_sym_uR_DQUOTE] = ACTIONS(2601),
    [anon_sym_UR_DQUOTE] = ACTIONS(2601),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2601),
    [anon_sym_co_await] = ACTIONS(2599),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_requires] = ACTIONS(2599),
    [sym_this] = ACTIONS(2599),
    [anon_sym___launch_bounds__] = ACTIONS(2599),
  },
  [STATE(713)] = {
    [ts_builtin_sym_end] = ACTIONS(3514),
    [sym_identifier] = ACTIONS(3516),
    [aux_sym_preproc_include_token1] = ACTIONS(3516),
    [aux_sym_preproc_def_token1] = ACTIONS(3516),
    [aux_sym_preproc_if_token1] = ACTIONS(3516),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3516),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3516),
    [sym_preproc_directive] = ACTIONS(3516),
    [anon_sym_LPAREN2] = ACTIONS(3514),
    [anon_sym_BANG] = ACTIONS(3514),
    [anon_sym_TILDE] = ACTIONS(3514),
    [anon_sym_DASH] = ACTIONS(3516),
    [anon_sym_PLUS] = ACTIONS(3516),
    [anon_sym_STAR] = ACTIONS(3514),
    [anon_sym_AMP_AMP] = ACTIONS(3514),
    [anon_sym_AMP] = ACTIONS(3516),
    [anon_sym_SEMI] = ACTIONS(3514),
    [anon_sym___extension__] = ACTIONS(3516),
    [anon_sym_typedef] = ACTIONS(3516),
    [anon_sym___device__] = ACTIONS(3516),
    [anon_sym___host__] = ACTIONS(3516),
    [anon_sym___global__] = ACTIONS(3516),
    [anon_sym___forceinline__] = ACTIONS(3516),
    [anon_sym___noinline__] = ACTIONS(3516),
    [anon_sym_virtual] = ACTIONS(3516),
    [anon_sym_extern] = ACTIONS(3516),
    [anon_sym___attribute__] = ACTIONS(3516),
    [anon_sym___attribute] = ACTIONS(3516),
    [anon_sym_COLON_COLON] = ACTIONS(3514),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3514),
    [anon_sym___declspec] = ACTIONS(3516),
    [anon_sym___based] = ACTIONS(3516),
    [anon_sym___cdecl] = ACTIONS(3516),
    [anon_sym___clrcall] = ACTIONS(3516),
    [anon_sym___stdcall] = ACTIONS(3516),
    [anon_sym___fastcall] = ACTIONS(3516),
    [anon_sym___thiscall] = ACTIONS(3516),
    [anon_sym___vectorcall] = ACTIONS(3516),
    [anon_sym_LBRACE] = ACTIONS(3514),
    [anon_sym_signed] = ACTIONS(3516),
    [anon_sym_unsigned] = ACTIONS(3516),
    [anon_sym_long] = ACTIONS(3516),
    [anon_sym_short] = ACTIONS(3516),
    [anon_sym_LBRACK] = ACTIONS(3516),
    [anon_sym_static] = ACTIONS(3516),
    [anon_sym_register] = ACTIONS(3516),
    [anon_sym_inline] = ACTIONS(3516),
    [anon_sym___inline] = ACTIONS(3516),
    [anon_sym___inline__] = ACTIONS(3516),
    [anon_sym___forceinline] = ACTIONS(3516),
    [anon_sym_thread_local] = ACTIONS(3516),
    [anon_sym___thread] = ACTIONS(3516),
    [anon_sym_const] = ACTIONS(3516),
    [anon_sym_constexpr] = ACTIONS(3516),
    [anon_sym_volatile] = ACTIONS(3516),
    [anon_sym_restrict] = ACTIONS(3516),
    [anon_sym___restrict__] = ACTIONS(3516),
    [anon_sym__Atomic] = ACTIONS(3516),
    [anon_sym__Noreturn] = ACTIONS(3516),
    [anon_sym_noreturn] = ACTIONS(3516),
    [anon_sym__Nonnull] = ACTIONS(3516),
    [anon_sym_mutable] = ACTIONS(3516),
    [anon_sym_constinit] = ACTIONS(3516),
    [anon_sym_consteval] = ACTIONS(3516),
    [anon_sym___shared__] = ACTIONS(3516),
    [anon_sym___local__] = ACTIONS(3516),
    [anon_sym___constant__] = ACTIONS(3516),
    [anon_sym___managed__] = ACTIONS(3516),
    [anon_sym___grid_constant__] = ACTIONS(3516),
    [anon_sym_alignas] = ACTIONS(3516),
    [anon_sym__Alignas] = ACTIONS(3516),
    [sym_primitive_type] = ACTIONS(3516),
    [anon_sym_enum] = ACTIONS(3516),
    [anon_sym_class] = ACTIONS(3516),
    [anon_sym_struct] = ACTIONS(3516),
    [anon_sym_union] = ACTIONS(3516),
    [anon_sym_if] = ACTIONS(3516),
    [anon_sym_switch] = ACTIONS(3516),
    [anon_sym_case] = ACTIONS(3516),
    [anon_sym_default] = ACTIONS(3516),
    [anon_sym_while] = ACTIONS(3516),
    [anon_sym_do] = ACTIONS(3516),
    [anon_sym_for] = ACTIONS(3516),
    [anon_sym_return] = ACTIONS(3516),
    [anon_sym_break] = ACTIONS(3516),
    [anon_sym_continue] = ACTIONS(3516),
    [anon_sym_goto] = ACTIONS(3516),
    [anon_sym_not] = ACTIONS(3516),
    [anon_sym_compl] = ACTIONS(3516),
    [anon_sym_DASH_DASH] = ACTIONS(3514),
    [anon_sym_PLUS_PLUS] = ACTIONS(3514),
    [anon_sym_sizeof] = ACTIONS(3516),
    [anon_sym___alignof__] = ACTIONS(3516),
    [anon_sym___alignof] = ACTIONS(3516),
    [anon_sym__alignof] = ACTIONS(3516),
    [anon_sym_alignof] = ACTIONS(3516),
    [anon_sym__Alignof] = ACTIONS(3516),
    [anon_sym_offsetof] = ACTIONS(3516),
    [anon_sym__Generic] = ACTIONS(3516),
    [anon_sym_asm] = ACTIONS(3516),
    [anon_sym___asm__] = ACTIONS(3516),
    [anon_sym___asm] = ACTIONS(3516),
    [sym_number_literal] = ACTIONS(3514),
    [anon_sym_L_SQUOTE] = ACTIONS(3514),
    [anon_sym_u_SQUOTE] = ACTIONS(3514),
    [anon_sym_U_SQUOTE] = ACTIONS(3514),
    [anon_sym_u8_SQUOTE] = ACTIONS(3514),
    [anon_sym_SQUOTE] = ACTIONS(3514),
    [anon_sym_L_DQUOTE] = ACTIONS(3514),
    [anon_sym_u_DQUOTE] = ACTIONS(3514),
    [anon_sym_U_DQUOTE] = ACTIONS(3514),
    [anon_sym_u8_DQUOTE] = ACTIONS(3514),
    [anon_sym_DQUOTE] = ACTIONS(3514),
    [sym_true] = ACTIONS(3516),
    [sym_false] = ACTIONS(3516),
    [anon_sym_NULL] = ACTIONS(3516),
    [anon_sym_nullptr] = ACTIONS(3516),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3516),
    [anon_sym_decltype] = ACTIONS(3516),
    [anon_sym_explicit] = ACTIONS(3516),
    [anon_sym_typename] = ACTIONS(3516),
    [anon_sym_template] = ACTIONS(3516),
    [anon_sym_operator] = ACTIONS(3516),
    [anon_sym_try] = ACTIONS(3516),
    [anon_sym_delete] = ACTIONS(3516),
    [anon_sym_throw] = ACTIONS(3516),
    [anon_sym_namespace] = ACTIONS(3516),
    [anon_sym_using] = ACTIONS(3516),
    [anon_sym_static_assert] = ACTIONS(3516),
    [anon_sym_concept] = ACTIONS(3516),
    [anon_sym_co_return] = ACTIONS(3516),
    [anon_sym_co_yield] = ACTIONS(3516),
    [anon_sym_R_DQUOTE] = ACTIONS(3514),
    [anon_sym_LR_DQUOTE] = ACTIONS(3514),
    [anon_sym_uR_DQUOTE] = ACTIONS(3514),
    [anon_sym_UR_DQUOTE] = ACTIONS(3514),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3514),
    [anon_sym_co_await] = ACTIONS(3516),
    [anon_sym_new] = ACTIONS(3516),
    [anon_sym_requires] = ACTIONS(3516),
    [sym_this] = ACTIONS(3516),
    [anon_sym___launch_bounds__] = ACTIONS(3516),
  },
  [STATE(714)] = {
    [ts_builtin_sym_end] = ACTIONS(2587),
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_include_token1] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym___cdecl] = ACTIONS(2585),
    [anon_sym___clrcall] = ACTIONS(2585),
    [anon_sym___stdcall] = ACTIONS(2585),
    [anon_sym___fastcall] = ACTIONS(2585),
    [anon_sym___thiscall] = ACTIONS(2585),
    [anon_sym___vectorcall] = ACTIONS(2585),
    [anon_sym_LBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_switch] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_default] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_do] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_return] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_goto] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_compl] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2587),
    [anon_sym_sizeof] = ACTIONS(2585),
    [anon_sym___alignof__] = ACTIONS(2585),
    [anon_sym___alignof] = ACTIONS(2585),
    [anon_sym__alignof] = ACTIONS(2585),
    [anon_sym_alignof] = ACTIONS(2585),
    [anon_sym__Alignof] = ACTIONS(2585),
    [anon_sym_offsetof] = ACTIONS(2585),
    [anon_sym__Generic] = ACTIONS(2585),
    [anon_sym_asm] = ACTIONS(2585),
    [anon_sym___asm__] = ACTIONS(2585),
    [anon_sym___asm] = ACTIONS(2585),
    [sym_number_literal] = ACTIONS(2587),
    [anon_sym_L_SQUOTE] = ACTIONS(2587),
    [anon_sym_u_SQUOTE] = ACTIONS(2587),
    [anon_sym_U_SQUOTE] = ACTIONS(2587),
    [anon_sym_u8_SQUOTE] = ACTIONS(2587),
    [anon_sym_SQUOTE] = ACTIONS(2587),
    [anon_sym_L_DQUOTE] = ACTIONS(2587),
    [anon_sym_u_DQUOTE] = ACTIONS(2587),
    [anon_sym_U_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8_DQUOTE] = ACTIONS(2587),
    [anon_sym_DQUOTE] = ACTIONS(2587),
    [sym_true] = ACTIONS(2585),
    [sym_false] = ACTIONS(2585),
    [anon_sym_NULL] = ACTIONS(2585),
    [anon_sym_nullptr] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_try] = ACTIONS(2585),
    [anon_sym_delete] = ACTIONS(2585),
    [anon_sym_throw] = ACTIONS(2585),
    [anon_sym_namespace] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym_concept] = ACTIONS(2585),
    [anon_sym_co_return] = ACTIONS(2585),
    [anon_sym_co_yield] = ACTIONS(2585),
    [anon_sym_R_DQUOTE] = ACTIONS(2587),
    [anon_sym_LR_DQUOTE] = ACTIONS(2587),
    [anon_sym_uR_DQUOTE] = ACTIONS(2587),
    [anon_sym_UR_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2587),
    [anon_sym_co_await] = ACTIONS(2585),
    [anon_sym_new] = ACTIONS(2585),
    [anon_sym_requires] = ACTIONS(2585),
    [sym_this] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(715)] = {
    [ts_builtin_sym_end] = ACTIONS(2611),
    [sym_identifier] = ACTIONS(2609),
    [aux_sym_preproc_include_token1] = ACTIONS(2609),
    [aux_sym_preproc_def_token1] = ACTIONS(2609),
    [aux_sym_preproc_if_token1] = ACTIONS(2609),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2609),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2609),
    [sym_preproc_directive] = ACTIONS(2609),
    [anon_sym_LPAREN2] = ACTIONS(2611),
    [anon_sym_BANG] = ACTIONS(2611),
    [anon_sym_TILDE] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2609),
    [anon_sym_PLUS] = ACTIONS(2609),
    [anon_sym_STAR] = ACTIONS(2611),
    [anon_sym_AMP_AMP] = ACTIONS(2611),
    [anon_sym_AMP] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2611),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2609),
    [anon_sym___device__] = ACTIONS(2609),
    [anon_sym___host__] = ACTIONS(2609),
    [anon_sym___global__] = ACTIONS(2609),
    [anon_sym___forceinline__] = ACTIONS(2609),
    [anon_sym___noinline__] = ACTIONS(2609),
    [anon_sym_virtual] = ACTIONS(2609),
    [anon_sym_extern] = ACTIONS(2609),
    [anon_sym___attribute__] = ACTIONS(2609),
    [anon_sym___attribute] = ACTIONS(2609),
    [anon_sym_COLON_COLON] = ACTIONS(2611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2611),
    [anon_sym___declspec] = ACTIONS(2609),
    [anon_sym___based] = ACTIONS(2609),
    [anon_sym___cdecl] = ACTIONS(2609),
    [anon_sym___clrcall] = ACTIONS(2609),
    [anon_sym___stdcall] = ACTIONS(2609),
    [anon_sym___fastcall] = ACTIONS(2609),
    [anon_sym___thiscall] = ACTIONS(2609),
    [anon_sym___vectorcall] = ACTIONS(2609),
    [anon_sym_LBRACE] = ACTIONS(2611),
    [anon_sym_signed] = ACTIONS(2609),
    [anon_sym_unsigned] = ACTIONS(2609),
    [anon_sym_long] = ACTIONS(2609),
    [anon_sym_short] = ACTIONS(2609),
    [anon_sym_LBRACK] = ACTIONS(2609),
    [anon_sym_static] = ACTIONS(2609),
    [anon_sym_register] = ACTIONS(2609),
    [anon_sym_inline] = ACTIONS(2609),
    [anon_sym___inline] = ACTIONS(2609),
    [anon_sym___inline__] = ACTIONS(2609),
    [anon_sym___forceinline] = ACTIONS(2609),
    [anon_sym_thread_local] = ACTIONS(2609),
    [anon_sym___thread] = ACTIONS(2609),
    [anon_sym_const] = ACTIONS(2609),
    [anon_sym_constexpr] = ACTIONS(2609),
    [anon_sym_volatile] = ACTIONS(2609),
    [anon_sym_restrict] = ACTIONS(2609),
    [anon_sym___restrict__] = ACTIONS(2609),
    [anon_sym__Atomic] = ACTIONS(2609),
    [anon_sym__Noreturn] = ACTIONS(2609),
    [anon_sym_noreturn] = ACTIONS(2609),
    [anon_sym__Nonnull] = ACTIONS(2609),
    [anon_sym_mutable] = ACTIONS(2609),
    [anon_sym_constinit] = ACTIONS(2609),
    [anon_sym_consteval] = ACTIONS(2609),
    [anon_sym___shared__] = ACTIONS(2609),
    [anon_sym___local__] = ACTIONS(2609),
    [anon_sym___constant__] = ACTIONS(2609),
    [anon_sym___managed__] = ACTIONS(2609),
    [anon_sym___grid_constant__] = ACTIONS(2609),
    [anon_sym_alignas] = ACTIONS(2609),
    [anon_sym__Alignas] = ACTIONS(2609),
    [sym_primitive_type] = ACTIONS(2609),
    [anon_sym_enum] = ACTIONS(2609),
    [anon_sym_class] = ACTIONS(2609),
    [anon_sym_struct] = ACTIONS(2609),
    [anon_sym_union] = ACTIONS(2609),
    [anon_sym_if] = ACTIONS(2609),
    [anon_sym_switch] = ACTIONS(2609),
    [anon_sym_case] = ACTIONS(2609),
    [anon_sym_default] = ACTIONS(2609),
    [anon_sym_while] = ACTIONS(2609),
    [anon_sym_do] = ACTIONS(2609),
    [anon_sym_for] = ACTIONS(2609),
    [anon_sym_return] = ACTIONS(2609),
    [anon_sym_break] = ACTIONS(2609),
    [anon_sym_continue] = ACTIONS(2609),
    [anon_sym_goto] = ACTIONS(2609),
    [anon_sym_not] = ACTIONS(2609),
    [anon_sym_compl] = ACTIONS(2609),
    [anon_sym_DASH_DASH] = ACTIONS(2611),
    [anon_sym_PLUS_PLUS] = ACTIONS(2611),
    [anon_sym_sizeof] = ACTIONS(2609),
    [anon_sym___alignof__] = ACTIONS(2609),
    [anon_sym___alignof] = ACTIONS(2609),
    [anon_sym__alignof] = ACTIONS(2609),
    [anon_sym_alignof] = ACTIONS(2609),
    [anon_sym__Alignof] = ACTIONS(2609),
    [anon_sym_offsetof] = ACTIONS(2609),
    [anon_sym__Generic] = ACTIONS(2609),
    [anon_sym_asm] = ACTIONS(2609),
    [anon_sym___asm__] = ACTIONS(2609),
    [anon_sym___asm] = ACTIONS(2609),
    [sym_number_literal] = ACTIONS(2611),
    [anon_sym_L_SQUOTE] = ACTIONS(2611),
    [anon_sym_u_SQUOTE] = ACTIONS(2611),
    [anon_sym_U_SQUOTE] = ACTIONS(2611),
    [anon_sym_u8_SQUOTE] = ACTIONS(2611),
    [anon_sym_SQUOTE] = ACTIONS(2611),
    [anon_sym_L_DQUOTE] = ACTIONS(2611),
    [anon_sym_u_DQUOTE] = ACTIONS(2611),
    [anon_sym_U_DQUOTE] = ACTIONS(2611),
    [anon_sym_u8_DQUOTE] = ACTIONS(2611),
    [anon_sym_DQUOTE] = ACTIONS(2611),
    [sym_true] = ACTIONS(2609),
    [sym_false] = ACTIONS(2609),
    [anon_sym_NULL] = ACTIONS(2609),
    [anon_sym_nullptr] = ACTIONS(2609),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2609),
    [anon_sym_decltype] = ACTIONS(2609),
    [anon_sym_explicit] = ACTIONS(2609),
    [anon_sym_typename] = ACTIONS(2609),
    [anon_sym_template] = ACTIONS(2609),
    [anon_sym_operator] = ACTIONS(2609),
    [anon_sym_try] = ACTIONS(2609),
    [anon_sym_delete] = ACTIONS(2609),
    [anon_sym_throw] = ACTIONS(2609),
    [anon_sym_namespace] = ACTIONS(2609),
    [anon_sym_using] = ACTIONS(2609),
    [anon_sym_static_assert] = ACTIONS(2609),
    [anon_sym_concept] = ACTIONS(2609),
    [anon_sym_co_return] = ACTIONS(2609),
    [anon_sym_co_yield] = ACTIONS(2609),
    [anon_sym_R_DQUOTE] = ACTIONS(2611),
    [anon_sym_LR_DQUOTE] = ACTIONS(2611),
    [anon_sym_uR_DQUOTE] = ACTIONS(2611),
    [anon_sym_UR_DQUOTE] = ACTIONS(2611),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2611),
    [anon_sym_co_await] = ACTIONS(2609),
    [anon_sym_new] = ACTIONS(2609),
    [anon_sym_requires] = ACTIONS(2609),
    [sym_this] = ACTIONS(2609),
    [anon_sym___launch_bounds__] = ACTIONS(2609),
  },
  [STATE(716)] = {
    [ts_builtin_sym_end] = ACTIONS(2587),
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_include_token1] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2585),
    [anon_sym_PLUS] = ACTIONS(2585),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym___cdecl] = ACTIONS(2585),
    [anon_sym___clrcall] = ACTIONS(2585),
    [anon_sym___stdcall] = ACTIONS(2585),
    [anon_sym___fastcall] = ACTIONS(2585),
    [anon_sym___thiscall] = ACTIONS(2585),
    [anon_sym___vectorcall] = ACTIONS(2585),
    [anon_sym_LBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [anon_sym_if] = ACTIONS(2585),
    [anon_sym_switch] = ACTIONS(2585),
    [anon_sym_case] = ACTIONS(2585),
    [anon_sym_default] = ACTIONS(2585),
    [anon_sym_while] = ACTIONS(2585),
    [anon_sym_do] = ACTIONS(2585),
    [anon_sym_for] = ACTIONS(2585),
    [anon_sym_return] = ACTIONS(2585),
    [anon_sym_break] = ACTIONS(2585),
    [anon_sym_continue] = ACTIONS(2585),
    [anon_sym_goto] = ACTIONS(2585),
    [anon_sym_not] = ACTIONS(2585),
    [anon_sym_compl] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2587),
    [anon_sym_sizeof] = ACTIONS(2585),
    [anon_sym___alignof__] = ACTIONS(2585),
    [anon_sym___alignof] = ACTIONS(2585),
    [anon_sym__alignof] = ACTIONS(2585),
    [anon_sym_alignof] = ACTIONS(2585),
    [anon_sym__Alignof] = ACTIONS(2585),
    [anon_sym_offsetof] = ACTIONS(2585),
    [anon_sym__Generic] = ACTIONS(2585),
    [anon_sym_asm] = ACTIONS(2585),
    [anon_sym___asm__] = ACTIONS(2585),
    [anon_sym___asm] = ACTIONS(2585),
    [sym_number_literal] = ACTIONS(2587),
    [anon_sym_L_SQUOTE] = ACTIONS(2587),
    [anon_sym_u_SQUOTE] = ACTIONS(2587),
    [anon_sym_U_SQUOTE] = ACTIONS(2587),
    [anon_sym_u8_SQUOTE] = ACTIONS(2587),
    [anon_sym_SQUOTE] = ACTIONS(2587),
    [anon_sym_L_DQUOTE] = ACTIONS(2587),
    [anon_sym_u_DQUOTE] = ACTIONS(2587),
    [anon_sym_U_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8_DQUOTE] = ACTIONS(2587),
    [anon_sym_DQUOTE] = ACTIONS(2587),
    [sym_true] = ACTIONS(2585),
    [sym_false] = ACTIONS(2585),
    [anon_sym_NULL] = ACTIONS(2585),
    [anon_sym_nullptr] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_try] = ACTIONS(2585),
    [anon_sym_delete] = ACTIONS(2585),
    [anon_sym_throw] = ACTIONS(2585),
    [anon_sym_namespace] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym_concept] = ACTIONS(2585),
    [anon_sym_co_return] = ACTIONS(2585),
    [anon_sym_co_yield] = ACTIONS(2585),
    [anon_sym_R_DQUOTE] = ACTIONS(2587),
    [anon_sym_LR_DQUOTE] = ACTIONS(2587),
    [anon_sym_uR_DQUOTE] = ACTIONS(2587),
    [anon_sym_UR_DQUOTE] = ACTIONS(2587),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2587),
    [anon_sym_co_await] = ACTIONS(2585),
    [anon_sym_new] = ACTIONS(2585),
    [anon_sym_requires] = ACTIONS(2585),
    [sym_this] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(717)] = {
    [ts_builtin_sym_end] = ACTIONS(2465),
    [sym_identifier] = ACTIONS(2463),
    [aux_sym_preproc_include_token1] = ACTIONS(2463),
    [aux_sym_preproc_def_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2463),
    [sym_preproc_directive] = ACTIONS(2463),
    [anon_sym_LPAREN2] = ACTIONS(2465),
    [anon_sym_BANG] = ACTIONS(2465),
    [anon_sym_TILDE] = ACTIONS(2465),
    [anon_sym_DASH] = ACTIONS(2463),
    [anon_sym_PLUS] = ACTIONS(2463),
    [anon_sym_STAR] = ACTIONS(2465),
    [anon_sym_AMP_AMP] = ACTIONS(2465),
    [anon_sym_AMP] = ACTIONS(2463),
    [anon_sym_SEMI] = ACTIONS(2465),
    [anon_sym___extension__] = ACTIONS(2463),
    [anon_sym_typedef] = ACTIONS(2463),
    [anon_sym___device__] = ACTIONS(2463),
    [anon_sym___host__] = ACTIONS(2463),
    [anon_sym___global__] = ACTIONS(2463),
    [anon_sym___forceinline__] = ACTIONS(2463),
    [anon_sym___noinline__] = ACTIONS(2463),
    [anon_sym_virtual] = ACTIONS(2463),
    [anon_sym_extern] = ACTIONS(2463),
    [anon_sym___attribute__] = ACTIONS(2463),
    [anon_sym___attribute] = ACTIONS(2463),
    [anon_sym_COLON_COLON] = ACTIONS(2465),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2465),
    [anon_sym___declspec] = ACTIONS(2463),
    [anon_sym___based] = ACTIONS(2463),
    [anon_sym___cdecl] = ACTIONS(2463),
    [anon_sym___clrcall] = ACTIONS(2463),
    [anon_sym___stdcall] = ACTIONS(2463),
    [anon_sym___fastcall] = ACTIONS(2463),
    [anon_sym___thiscall] = ACTIONS(2463),
    [anon_sym___vectorcall] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_signed] = ACTIONS(2463),
    [anon_sym_unsigned] = ACTIONS(2463),
    [anon_sym_long] = ACTIONS(2463),
    [anon_sym_short] = ACTIONS(2463),
    [anon_sym_LBRACK] = ACTIONS(2463),
    [anon_sym_static] = ACTIONS(2463),
    [anon_sym_register] = ACTIONS(2463),
    [anon_sym_inline] = ACTIONS(2463),
    [anon_sym___inline] = ACTIONS(2463),
    [anon_sym___inline__] = ACTIONS(2463),
    [anon_sym___forceinline] = ACTIONS(2463),
    [anon_sym_thread_local] = ACTIONS(2463),
    [anon_sym___thread] = ACTIONS(2463),
    [anon_sym_const] = ACTIONS(2463),
    [anon_sym_constexpr] = ACTIONS(2463),
    [anon_sym_volatile] = ACTIONS(2463),
    [anon_sym_restrict] = ACTIONS(2463),
    [anon_sym___restrict__] = ACTIONS(2463),
    [anon_sym__Atomic] = ACTIONS(2463),
    [anon_sym__Noreturn] = ACTIONS(2463),
    [anon_sym_noreturn] = ACTIONS(2463),
    [anon_sym__Nonnull] = ACTIONS(2463),
    [anon_sym_mutable] = ACTIONS(2463),
    [anon_sym_constinit] = ACTIONS(2463),
    [anon_sym_consteval] = ACTIONS(2463),
    [anon_sym___shared__] = ACTIONS(2463),
    [anon_sym___local__] = ACTIONS(2463),
    [anon_sym___constant__] = ACTIONS(2463),
    [anon_sym___managed__] = ACTIONS(2463),
    [anon_sym___grid_constant__] = ACTIONS(2463),
    [anon_sym_alignas] = ACTIONS(2463),
    [anon_sym__Alignas] = ACTIONS(2463),
    [sym_primitive_type] = ACTIONS(2463),
    [anon_sym_enum] = ACTIONS(2463),
    [anon_sym_class] = ACTIONS(2463),
    [anon_sym_struct] = ACTIONS(2463),
    [anon_sym_union] = ACTIONS(2463),
    [anon_sym_if] = ACTIONS(2463),
    [anon_sym_switch] = ACTIONS(2463),
    [anon_sym_case] = ACTIONS(2463),
    [anon_sym_default] = ACTIONS(2463),
    [anon_sym_while] = ACTIONS(2463),
    [anon_sym_do] = ACTIONS(2463),
    [anon_sym_for] = ACTIONS(2463),
    [anon_sym_return] = ACTIONS(2463),
    [anon_sym_break] = ACTIONS(2463),
    [anon_sym_continue] = ACTIONS(2463),
    [anon_sym_goto] = ACTIONS(2463),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_compl] = ACTIONS(2463),
    [anon_sym_DASH_DASH] = ACTIONS(2465),
    [anon_sym_PLUS_PLUS] = ACTIONS(2465),
    [anon_sym_sizeof] = ACTIONS(2463),
    [anon_sym___alignof__] = ACTIONS(2463),
    [anon_sym___alignof] = ACTIONS(2463),
    [anon_sym__alignof] = ACTIONS(2463),
    [anon_sym_alignof] = ACTIONS(2463),
    [anon_sym__Alignof] = ACTIONS(2463),
    [anon_sym_offsetof] = ACTIONS(2463),
    [anon_sym__Generic] = ACTIONS(2463),
    [anon_sym_asm] = ACTIONS(2463),
    [anon_sym___asm__] = ACTIONS(2463),
    [anon_sym___asm] = ACTIONS(2463),
    [sym_number_literal] = ACTIONS(2465),
    [anon_sym_L_SQUOTE] = ACTIONS(2465),
    [anon_sym_u_SQUOTE] = ACTIONS(2465),
    [anon_sym_U_SQUOTE] = ACTIONS(2465),
    [anon_sym_u8_SQUOTE] = ACTIONS(2465),
    [anon_sym_SQUOTE] = ACTIONS(2465),
    [anon_sym_L_DQUOTE] = ACTIONS(2465),
    [anon_sym_u_DQUOTE] = ACTIONS(2465),
    [anon_sym_U_DQUOTE] = ACTIONS(2465),
    [anon_sym_u8_DQUOTE] = ACTIONS(2465),
    [anon_sym_DQUOTE] = ACTIONS(2465),
    [sym_true] = ACTIONS(2463),
    [sym_false] = ACTIONS(2463),
    [anon_sym_NULL] = ACTIONS(2463),
    [anon_sym_nullptr] = ACTIONS(2463),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2463),
    [anon_sym_decltype] = ACTIONS(2463),
    [anon_sym_explicit] = ACTIONS(2463),
    [anon_sym_typename] = ACTIONS(2463),
    [anon_sym_template] = ACTIONS(2463),
    [anon_sym_operator] = ACTIONS(2463),
    [anon_sym_try] = ACTIONS(2463),
    [anon_sym_delete] = ACTIONS(2463),
    [anon_sym_throw] = ACTIONS(2463),
    [anon_sym_namespace] = ACTIONS(2463),
    [anon_sym_using] = ACTIONS(2463),
    [anon_sym_static_assert] = ACTIONS(2463),
    [anon_sym_concept] = ACTIONS(2463),
    [anon_sym_co_return] = ACTIONS(2463),
    [anon_sym_co_yield] = ACTIONS(2463),
    [anon_sym_R_DQUOTE] = ACTIONS(2465),
    [anon_sym_LR_DQUOTE] = ACTIONS(2465),
    [anon_sym_uR_DQUOTE] = ACTIONS(2465),
    [anon_sym_UR_DQUOTE] = ACTIONS(2465),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2465),
    [anon_sym_co_await] = ACTIONS(2463),
    [anon_sym_new] = ACTIONS(2463),
    [anon_sym_requires] = ACTIONS(2463),
    [sym_this] = ACTIONS(2463),
    [anon_sym___launch_bounds__] = ACTIONS(2463),
  },
  [STATE(718)] = {
    [ts_builtin_sym_end] = ACTIONS(2473),
    [sym_identifier] = ACTIONS(2471),
    [aux_sym_preproc_include_token1] = ACTIONS(2471),
    [aux_sym_preproc_def_token1] = ACTIONS(2471),
    [aux_sym_preproc_if_token1] = ACTIONS(2471),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2471),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2471),
    [sym_preproc_directive] = ACTIONS(2471),
    [anon_sym_LPAREN2] = ACTIONS(2473),
    [anon_sym_BANG] = ACTIONS(2473),
    [anon_sym_TILDE] = ACTIONS(2473),
    [anon_sym_DASH] = ACTIONS(2471),
    [anon_sym_PLUS] = ACTIONS(2471),
    [anon_sym_STAR] = ACTIONS(2473),
    [anon_sym_AMP_AMP] = ACTIONS(2473),
    [anon_sym_AMP] = ACTIONS(2471),
    [anon_sym_SEMI] = ACTIONS(2473),
    [anon_sym___extension__] = ACTIONS(2471),
    [anon_sym_typedef] = ACTIONS(2471),
    [anon_sym___device__] = ACTIONS(2471),
    [anon_sym___host__] = ACTIONS(2471),
    [anon_sym___global__] = ACTIONS(2471),
    [anon_sym___forceinline__] = ACTIONS(2471),
    [anon_sym___noinline__] = ACTIONS(2471),
    [anon_sym_virtual] = ACTIONS(2471),
    [anon_sym_extern] = ACTIONS(2471),
    [anon_sym___attribute__] = ACTIONS(2471),
    [anon_sym___attribute] = ACTIONS(2471),
    [anon_sym_COLON_COLON] = ACTIONS(2473),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2473),
    [anon_sym___declspec] = ACTIONS(2471),
    [anon_sym___based] = ACTIONS(2471),
    [anon_sym___cdecl] = ACTIONS(2471),
    [anon_sym___clrcall] = ACTIONS(2471),
    [anon_sym___stdcall] = ACTIONS(2471),
    [anon_sym___fastcall] = ACTIONS(2471),
    [anon_sym___thiscall] = ACTIONS(2471),
    [anon_sym___vectorcall] = ACTIONS(2471),
    [anon_sym_LBRACE] = ACTIONS(2473),
    [anon_sym_signed] = ACTIONS(2471),
    [anon_sym_unsigned] = ACTIONS(2471),
    [anon_sym_long] = ACTIONS(2471),
    [anon_sym_short] = ACTIONS(2471),
    [anon_sym_LBRACK] = ACTIONS(2471),
    [anon_sym_static] = ACTIONS(2471),
    [anon_sym_register] = ACTIONS(2471),
    [anon_sym_inline] = ACTIONS(2471),
    [anon_sym___inline] = ACTIONS(2471),
    [anon_sym___inline__] = ACTIONS(2471),
    [anon_sym___forceinline] = ACTIONS(2471),
    [anon_sym_thread_local] = ACTIONS(2471),
    [anon_sym___thread] = ACTIONS(2471),
    [anon_sym_const] = ACTIONS(2471),
    [anon_sym_constexpr] = ACTIONS(2471),
    [anon_sym_volatile] = ACTIONS(2471),
    [anon_sym_restrict] = ACTIONS(2471),
    [anon_sym___restrict__] = ACTIONS(2471),
    [anon_sym__Atomic] = ACTIONS(2471),
    [anon_sym__Noreturn] = ACTIONS(2471),
    [anon_sym_noreturn] = ACTIONS(2471),
    [anon_sym__Nonnull] = ACTIONS(2471),
    [anon_sym_mutable] = ACTIONS(2471),
    [anon_sym_constinit] = ACTIONS(2471),
    [anon_sym_consteval] = ACTIONS(2471),
    [anon_sym___shared__] = ACTIONS(2471),
    [anon_sym___local__] = ACTIONS(2471),
    [anon_sym___constant__] = ACTIONS(2471),
    [anon_sym___managed__] = ACTIONS(2471),
    [anon_sym___grid_constant__] = ACTIONS(2471),
    [anon_sym_alignas] = ACTIONS(2471),
    [anon_sym__Alignas] = ACTIONS(2471),
    [sym_primitive_type] = ACTIONS(2471),
    [anon_sym_enum] = ACTIONS(2471),
    [anon_sym_class] = ACTIONS(2471),
    [anon_sym_struct] = ACTIONS(2471),
    [anon_sym_union] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2471),
    [anon_sym_switch] = ACTIONS(2471),
    [anon_sym_case] = ACTIONS(2471),
    [anon_sym_default] = ACTIONS(2471),
    [anon_sym_while] = ACTIONS(2471),
    [anon_sym_do] = ACTIONS(2471),
    [anon_sym_for] = ACTIONS(2471),
    [anon_sym_return] = ACTIONS(2471),
    [anon_sym_break] = ACTIONS(2471),
    [anon_sym_continue] = ACTIONS(2471),
    [anon_sym_goto] = ACTIONS(2471),
    [anon_sym_not] = ACTIONS(2471),
    [anon_sym_compl] = ACTIONS(2471),
    [anon_sym_DASH_DASH] = ACTIONS(2473),
    [anon_sym_PLUS_PLUS] = ACTIONS(2473),
    [anon_sym_sizeof] = ACTIONS(2471),
    [anon_sym___alignof__] = ACTIONS(2471),
    [anon_sym___alignof] = ACTIONS(2471),
    [anon_sym__alignof] = ACTIONS(2471),
    [anon_sym_alignof] = ACTIONS(2471),
    [anon_sym__Alignof] = ACTIONS(2471),
    [anon_sym_offsetof] = ACTIONS(2471),
    [anon_sym__Generic] = ACTIONS(2471),
    [anon_sym_asm] = ACTIONS(2471),
    [anon_sym___asm__] = ACTIONS(2471),
    [anon_sym___asm] = ACTIONS(2471),
    [sym_number_literal] = ACTIONS(2473),
    [anon_sym_L_SQUOTE] = ACTIONS(2473),
    [anon_sym_u_SQUOTE] = ACTIONS(2473),
    [anon_sym_U_SQUOTE] = ACTIONS(2473),
    [anon_sym_u8_SQUOTE] = ACTIONS(2473),
    [anon_sym_SQUOTE] = ACTIONS(2473),
    [anon_sym_L_DQUOTE] = ACTIONS(2473),
    [anon_sym_u_DQUOTE] = ACTIONS(2473),
    [anon_sym_U_DQUOTE] = ACTIONS(2473),
    [anon_sym_u8_DQUOTE] = ACTIONS(2473),
    [anon_sym_DQUOTE] = ACTIONS(2473),
    [sym_true] = ACTIONS(2471),
    [sym_false] = ACTIONS(2471),
    [anon_sym_NULL] = ACTIONS(2471),
    [anon_sym_nullptr] = ACTIONS(2471),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2471),
    [anon_sym_decltype] = ACTIONS(2471),
    [anon_sym_explicit] = ACTIONS(2471),
    [anon_sym_typename] = ACTIONS(2471),
    [anon_sym_template] = ACTIONS(2471),
    [anon_sym_operator] = ACTIONS(2471),
    [anon_sym_try] = ACTIONS(2471),
    [anon_sym_delete] = ACTIONS(2471),
    [anon_sym_throw] = ACTIONS(2471),
    [anon_sym_namespace] = ACTIONS(2471),
    [anon_sym_using] = ACTIONS(2471),
    [anon_sym_static_assert] = ACTIONS(2471),
    [anon_sym_concept] = ACTIONS(2471),
    [anon_sym_co_return] = ACTIONS(2471),
    [anon_sym_co_yield] = ACTIONS(2471),
    [anon_sym_R_DQUOTE] = ACTIONS(2473),
    [anon_sym_LR_DQUOTE] = ACTIONS(2473),
    [anon_sym_uR_DQUOTE] = ACTIONS(2473),
    [anon_sym_UR_DQUOTE] = ACTIONS(2473),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2473),
    [anon_sym_co_await] = ACTIONS(2471),
    [anon_sym_new] = ACTIONS(2471),
    [anon_sym_requires] = ACTIONS(2471),
    [sym_this] = ACTIONS(2471),
    [anon_sym___launch_bounds__] = ACTIONS(2471),
  },
  [STATE(719)] = {
    [ts_builtin_sym_end] = ACTIONS(2539),
    [sym_identifier] = ACTIONS(2537),
    [aux_sym_preproc_include_token1] = ACTIONS(2537),
    [aux_sym_preproc_def_token1] = ACTIONS(2537),
    [aux_sym_preproc_if_token1] = ACTIONS(2537),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2537),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2537),
    [sym_preproc_directive] = ACTIONS(2537),
    [anon_sym_LPAREN2] = ACTIONS(2539),
    [anon_sym_BANG] = ACTIONS(2539),
    [anon_sym_TILDE] = ACTIONS(2539),
    [anon_sym_DASH] = ACTIONS(2537),
    [anon_sym_PLUS] = ACTIONS(2537),
    [anon_sym_STAR] = ACTIONS(2539),
    [anon_sym_AMP_AMP] = ACTIONS(2539),
    [anon_sym_AMP] = ACTIONS(2537),
    [anon_sym_SEMI] = ACTIONS(2539),
    [anon_sym___extension__] = ACTIONS(2537),
    [anon_sym_typedef] = ACTIONS(2537),
    [anon_sym___device__] = ACTIONS(2537),
    [anon_sym___host__] = ACTIONS(2537),
    [anon_sym___global__] = ACTIONS(2537),
    [anon_sym___forceinline__] = ACTIONS(2537),
    [anon_sym___noinline__] = ACTIONS(2537),
    [anon_sym_virtual] = ACTIONS(2537),
    [anon_sym_extern] = ACTIONS(2537),
    [anon_sym___attribute__] = ACTIONS(2537),
    [anon_sym___attribute] = ACTIONS(2537),
    [anon_sym_COLON_COLON] = ACTIONS(2539),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2539),
    [anon_sym___declspec] = ACTIONS(2537),
    [anon_sym___based] = ACTIONS(2537),
    [anon_sym___cdecl] = ACTIONS(2537),
    [anon_sym___clrcall] = ACTIONS(2537),
    [anon_sym___stdcall] = ACTIONS(2537),
    [anon_sym___fastcall] = ACTIONS(2537),
    [anon_sym___thiscall] = ACTIONS(2537),
    [anon_sym___vectorcall] = ACTIONS(2537),
    [anon_sym_LBRACE] = ACTIONS(2539),
    [anon_sym_signed] = ACTIONS(2537),
    [anon_sym_unsigned] = ACTIONS(2537),
    [anon_sym_long] = ACTIONS(2537),
    [anon_sym_short] = ACTIONS(2537),
    [anon_sym_LBRACK] = ACTIONS(2537),
    [anon_sym_static] = ACTIONS(2537),
    [anon_sym_register] = ACTIONS(2537),
    [anon_sym_inline] = ACTIONS(2537),
    [anon_sym___inline] = ACTIONS(2537),
    [anon_sym___inline__] = ACTIONS(2537),
    [anon_sym___forceinline] = ACTIONS(2537),
    [anon_sym_thread_local] = ACTIONS(2537),
    [anon_sym___thread] = ACTIONS(2537),
    [anon_sym_const] = ACTIONS(2537),
    [anon_sym_constexpr] = ACTIONS(2537),
    [anon_sym_volatile] = ACTIONS(2537),
    [anon_sym_restrict] = ACTIONS(2537),
    [anon_sym___restrict__] = ACTIONS(2537),
    [anon_sym__Atomic] = ACTIONS(2537),
    [anon_sym__Noreturn] = ACTIONS(2537),
    [anon_sym_noreturn] = ACTIONS(2537),
    [anon_sym__Nonnull] = ACTIONS(2537),
    [anon_sym_mutable] = ACTIONS(2537),
    [anon_sym_constinit] = ACTIONS(2537),
    [anon_sym_consteval] = ACTIONS(2537),
    [anon_sym___shared__] = ACTIONS(2537),
    [anon_sym___local__] = ACTIONS(2537),
    [anon_sym___constant__] = ACTIONS(2537),
    [anon_sym___managed__] = ACTIONS(2537),
    [anon_sym___grid_constant__] = ACTIONS(2537),
    [anon_sym_alignas] = ACTIONS(2537),
    [anon_sym__Alignas] = ACTIONS(2537),
    [sym_primitive_type] = ACTIONS(2537),
    [anon_sym_enum] = ACTIONS(2537),
    [anon_sym_class] = ACTIONS(2537),
    [anon_sym_struct] = ACTIONS(2537),
    [anon_sym_union] = ACTIONS(2537),
    [anon_sym_if] = ACTIONS(2537),
    [anon_sym_switch] = ACTIONS(2537),
    [anon_sym_case] = ACTIONS(2537),
    [anon_sym_default] = ACTIONS(2537),
    [anon_sym_while] = ACTIONS(2537),
    [anon_sym_do] = ACTIONS(2537),
    [anon_sym_for] = ACTIONS(2537),
    [anon_sym_return] = ACTIONS(2537),
    [anon_sym_break] = ACTIONS(2537),
    [anon_sym_continue] = ACTIONS(2537),
    [anon_sym_goto] = ACTIONS(2537),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_compl] = ACTIONS(2537),
    [anon_sym_DASH_DASH] = ACTIONS(2539),
    [anon_sym_PLUS_PLUS] = ACTIONS(2539),
    [anon_sym_sizeof] = ACTIONS(2537),
    [anon_sym___alignof__] = ACTIONS(2537),
    [anon_sym___alignof] = ACTIONS(2537),
    [anon_sym__alignof] = ACTIONS(2537),
    [anon_sym_alignof] = ACTIONS(2537),
    [anon_sym__Alignof] = ACTIONS(2537),
    [anon_sym_offsetof] = ACTIONS(2537),
    [anon_sym__Generic] = ACTIONS(2537),
    [anon_sym_asm] = ACTIONS(2537),
    [anon_sym___asm__] = ACTIONS(2537),
    [anon_sym___asm] = ACTIONS(2537),
    [sym_number_literal] = ACTIONS(2539),
    [anon_sym_L_SQUOTE] = ACTIONS(2539),
    [anon_sym_u_SQUOTE] = ACTIONS(2539),
    [anon_sym_U_SQUOTE] = ACTIONS(2539),
    [anon_sym_u8_SQUOTE] = ACTIONS(2539),
    [anon_sym_SQUOTE] = ACTIONS(2539),
    [anon_sym_L_DQUOTE] = ACTIONS(2539),
    [anon_sym_u_DQUOTE] = ACTIONS(2539),
    [anon_sym_U_DQUOTE] = ACTIONS(2539),
    [anon_sym_u8_DQUOTE] = ACTIONS(2539),
    [anon_sym_DQUOTE] = ACTIONS(2539),
    [sym_true] = ACTIONS(2537),
    [sym_false] = ACTIONS(2537),
    [anon_sym_NULL] = ACTIONS(2537),
    [anon_sym_nullptr] = ACTIONS(2537),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2537),
    [anon_sym_decltype] = ACTIONS(2537),
    [anon_sym_explicit] = ACTIONS(2537),
    [anon_sym_typename] = ACTIONS(2537),
    [anon_sym_template] = ACTIONS(2537),
    [anon_sym_operator] = ACTIONS(2537),
    [anon_sym_try] = ACTIONS(2537),
    [anon_sym_delete] = ACTIONS(2537),
    [anon_sym_throw] = ACTIONS(2537),
    [anon_sym_namespace] = ACTIONS(2537),
    [anon_sym_using] = ACTIONS(2537),
    [anon_sym_static_assert] = ACTIONS(2537),
    [anon_sym_concept] = ACTIONS(2537),
    [anon_sym_co_return] = ACTIONS(2537),
    [anon_sym_co_yield] = ACTIONS(2537),
    [anon_sym_R_DQUOTE] = ACTIONS(2539),
    [anon_sym_LR_DQUOTE] = ACTIONS(2539),
    [anon_sym_uR_DQUOTE] = ACTIONS(2539),
    [anon_sym_UR_DQUOTE] = ACTIONS(2539),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2539),
    [anon_sym_co_await] = ACTIONS(2537),
    [anon_sym_new] = ACTIONS(2537),
    [anon_sym_requires] = ACTIONS(2537),
    [sym_this] = ACTIONS(2537),
    [anon_sym___launch_bounds__] = ACTIONS(2537),
  },
  [STATE(720)] = {
    [ts_builtin_sym_end] = ACTIONS(2555),
    [sym_identifier] = ACTIONS(2553),
    [aux_sym_preproc_include_token1] = ACTIONS(2553),
    [aux_sym_preproc_def_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2553),
    [sym_preproc_directive] = ACTIONS(2553),
    [anon_sym_LPAREN2] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2555),
    [anon_sym_TILDE] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2553),
    [anon_sym_PLUS] = ACTIONS(2553),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_AMP_AMP] = ACTIONS(2555),
    [anon_sym_AMP] = ACTIONS(2553),
    [anon_sym_SEMI] = ACTIONS(2555),
    [anon_sym___extension__] = ACTIONS(2553),
    [anon_sym_typedef] = ACTIONS(2553),
    [anon_sym___device__] = ACTIONS(2553),
    [anon_sym___host__] = ACTIONS(2553),
    [anon_sym___global__] = ACTIONS(2553),
    [anon_sym___forceinline__] = ACTIONS(2553),
    [anon_sym___noinline__] = ACTIONS(2553),
    [anon_sym_virtual] = ACTIONS(2553),
    [anon_sym_extern] = ACTIONS(2553),
    [anon_sym___attribute__] = ACTIONS(2553),
    [anon_sym___attribute] = ACTIONS(2553),
    [anon_sym_COLON_COLON] = ACTIONS(2555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2555),
    [anon_sym___declspec] = ACTIONS(2553),
    [anon_sym___based] = ACTIONS(2553),
    [anon_sym___cdecl] = ACTIONS(2553),
    [anon_sym___clrcall] = ACTIONS(2553),
    [anon_sym___stdcall] = ACTIONS(2553),
    [anon_sym___fastcall] = ACTIONS(2553),
    [anon_sym___thiscall] = ACTIONS(2553),
    [anon_sym___vectorcall] = ACTIONS(2553),
    [anon_sym_LBRACE] = ACTIONS(2555),
    [anon_sym_signed] = ACTIONS(2553),
    [anon_sym_unsigned] = ACTIONS(2553),
    [anon_sym_long] = ACTIONS(2553),
    [anon_sym_short] = ACTIONS(2553),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2553),
    [anon_sym_register] = ACTIONS(2553),
    [anon_sym_inline] = ACTIONS(2553),
    [anon_sym___inline] = ACTIONS(2553),
    [anon_sym___inline__] = ACTIONS(2553),
    [anon_sym___forceinline] = ACTIONS(2553),
    [anon_sym_thread_local] = ACTIONS(2553),
    [anon_sym___thread] = ACTIONS(2553),
    [anon_sym_const] = ACTIONS(2553),
    [anon_sym_constexpr] = ACTIONS(2553),
    [anon_sym_volatile] = ACTIONS(2553),
    [anon_sym_restrict] = ACTIONS(2553),
    [anon_sym___restrict__] = ACTIONS(2553),
    [anon_sym__Atomic] = ACTIONS(2553),
    [anon_sym__Noreturn] = ACTIONS(2553),
    [anon_sym_noreturn] = ACTIONS(2553),
    [anon_sym__Nonnull] = ACTIONS(2553),
    [anon_sym_mutable] = ACTIONS(2553),
    [anon_sym_constinit] = ACTIONS(2553),
    [anon_sym_consteval] = ACTIONS(2553),
    [anon_sym___shared__] = ACTIONS(2553),
    [anon_sym___local__] = ACTIONS(2553),
    [anon_sym___constant__] = ACTIONS(2553),
    [anon_sym___managed__] = ACTIONS(2553),
    [anon_sym___grid_constant__] = ACTIONS(2553),
    [anon_sym_alignas] = ACTIONS(2553),
    [anon_sym__Alignas] = ACTIONS(2553),
    [sym_primitive_type] = ACTIONS(2553),
    [anon_sym_enum] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2553),
    [anon_sym_struct] = ACTIONS(2553),
    [anon_sym_union] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2553),
    [anon_sym_switch] = ACTIONS(2553),
    [anon_sym_case] = ACTIONS(2553),
    [anon_sym_default] = ACTIONS(2553),
    [anon_sym_while] = ACTIONS(2553),
    [anon_sym_do] = ACTIONS(2553),
    [anon_sym_for] = ACTIONS(2553),
    [anon_sym_return] = ACTIONS(2553),
    [anon_sym_break] = ACTIONS(2553),
    [anon_sym_continue] = ACTIONS(2553),
    [anon_sym_goto] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2553),
    [anon_sym_compl] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2555),
    [anon_sym_sizeof] = ACTIONS(2553),
    [anon_sym___alignof__] = ACTIONS(2553),
    [anon_sym___alignof] = ACTIONS(2553),
    [anon_sym__alignof] = ACTIONS(2553),
    [anon_sym_alignof] = ACTIONS(2553),
    [anon_sym__Alignof] = ACTIONS(2553),
    [anon_sym_offsetof] = ACTIONS(2553),
    [anon_sym__Generic] = ACTIONS(2553),
    [anon_sym_asm] = ACTIONS(2553),
    [anon_sym___asm__] = ACTIONS(2553),
    [anon_sym___asm] = ACTIONS(2553),
    [sym_number_literal] = ACTIONS(2555),
    [anon_sym_L_SQUOTE] = ACTIONS(2555),
    [anon_sym_u_SQUOTE] = ACTIONS(2555),
    [anon_sym_U_SQUOTE] = ACTIONS(2555),
    [anon_sym_u8_SQUOTE] = ACTIONS(2555),
    [anon_sym_SQUOTE] = ACTIONS(2555),
    [anon_sym_L_DQUOTE] = ACTIONS(2555),
    [anon_sym_u_DQUOTE] = ACTIONS(2555),
    [anon_sym_U_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8_DQUOTE] = ACTIONS(2555),
    [anon_sym_DQUOTE] = ACTIONS(2555),
    [sym_true] = ACTIONS(2553),
    [sym_false] = ACTIONS(2553),
    [anon_sym_NULL] = ACTIONS(2553),
    [anon_sym_nullptr] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2553),
    [anon_sym_decltype] = ACTIONS(2553),
    [anon_sym_explicit] = ACTIONS(2553),
    [anon_sym_typename] = ACTIONS(2553),
    [anon_sym_template] = ACTIONS(2553),
    [anon_sym_operator] = ACTIONS(2553),
    [anon_sym_try] = ACTIONS(2553),
    [anon_sym_delete] = ACTIONS(2553),
    [anon_sym_throw] = ACTIONS(2553),
    [anon_sym_namespace] = ACTIONS(2553),
    [anon_sym_using] = ACTIONS(2553),
    [anon_sym_static_assert] = ACTIONS(2553),
    [anon_sym_concept] = ACTIONS(2553),
    [anon_sym_co_return] = ACTIONS(2553),
    [anon_sym_co_yield] = ACTIONS(2553),
    [anon_sym_R_DQUOTE] = ACTIONS(2555),
    [anon_sym_LR_DQUOTE] = ACTIONS(2555),
    [anon_sym_uR_DQUOTE] = ACTIONS(2555),
    [anon_sym_UR_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2555),
    [anon_sym_co_await] = ACTIONS(2553),
    [anon_sym_new] = ACTIONS(2553),
    [anon_sym_requires] = ACTIONS(2553),
    [sym_this] = ACTIONS(2553),
    [anon_sym___launch_bounds__] = ACTIONS(2553),
  },
  [STATE(721)] = {
    [ts_builtin_sym_end] = ACTIONS(2507),
    [sym_identifier] = ACTIONS(2505),
    [aux_sym_preproc_include_token1] = ACTIONS(2505),
    [aux_sym_preproc_def_token1] = ACTIONS(2505),
    [aux_sym_preproc_if_token1] = ACTIONS(2505),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2505),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2505),
    [sym_preproc_directive] = ACTIONS(2505),
    [anon_sym_LPAREN2] = ACTIONS(2507),
    [anon_sym_BANG] = ACTIONS(2507),
    [anon_sym_TILDE] = ACTIONS(2507),
    [anon_sym_DASH] = ACTIONS(2505),
    [anon_sym_PLUS] = ACTIONS(2505),
    [anon_sym_STAR] = ACTIONS(2507),
    [anon_sym_AMP_AMP] = ACTIONS(2507),
    [anon_sym_AMP] = ACTIONS(2505),
    [anon_sym_SEMI] = ACTIONS(2507),
    [anon_sym___extension__] = ACTIONS(2505),
    [anon_sym_typedef] = ACTIONS(2505),
    [anon_sym___device__] = ACTIONS(2505),
    [anon_sym___host__] = ACTIONS(2505),
    [anon_sym___global__] = ACTIONS(2505),
    [anon_sym___forceinline__] = ACTIONS(2505),
    [anon_sym___noinline__] = ACTIONS(2505),
    [anon_sym_virtual] = ACTIONS(2505),
    [anon_sym_extern] = ACTIONS(2505),
    [anon_sym___attribute__] = ACTIONS(2505),
    [anon_sym___attribute] = ACTIONS(2505),
    [anon_sym_COLON_COLON] = ACTIONS(2507),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2507),
    [anon_sym___declspec] = ACTIONS(2505),
    [anon_sym___based] = ACTIONS(2505),
    [anon_sym___cdecl] = ACTIONS(2505),
    [anon_sym___clrcall] = ACTIONS(2505),
    [anon_sym___stdcall] = ACTIONS(2505),
    [anon_sym___fastcall] = ACTIONS(2505),
    [anon_sym___thiscall] = ACTIONS(2505),
    [anon_sym___vectorcall] = ACTIONS(2505),
    [anon_sym_LBRACE] = ACTIONS(2507),
    [anon_sym_signed] = ACTIONS(2505),
    [anon_sym_unsigned] = ACTIONS(2505),
    [anon_sym_long] = ACTIONS(2505),
    [anon_sym_short] = ACTIONS(2505),
    [anon_sym_LBRACK] = ACTIONS(2505),
    [anon_sym_static] = ACTIONS(2505),
    [anon_sym_register] = ACTIONS(2505),
    [anon_sym_inline] = ACTIONS(2505),
    [anon_sym___inline] = ACTIONS(2505),
    [anon_sym___inline__] = ACTIONS(2505),
    [anon_sym___forceinline] = ACTIONS(2505),
    [anon_sym_thread_local] = ACTIONS(2505),
    [anon_sym___thread] = ACTIONS(2505),
    [anon_sym_const] = ACTIONS(2505),
    [anon_sym_constexpr] = ACTIONS(2505),
    [anon_sym_volatile] = ACTIONS(2505),
    [anon_sym_restrict] = ACTIONS(2505),
    [anon_sym___restrict__] = ACTIONS(2505),
    [anon_sym__Atomic] = ACTIONS(2505),
    [anon_sym__Noreturn] = ACTIONS(2505),
    [anon_sym_noreturn] = ACTIONS(2505),
    [anon_sym__Nonnull] = ACTIONS(2505),
    [anon_sym_mutable] = ACTIONS(2505),
    [anon_sym_constinit] = ACTIONS(2505),
    [anon_sym_consteval] = ACTIONS(2505),
    [anon_sym___shared__] = ACTIONS(2505),
    [anon_sym___local__] = ACTIONS(2505),
    [anon_sym___constant__] = ACTIONS(2505),
    [anon_sym___managed__] = ACTIONS(2505),
    [anon_sym___grid_constant__] = ACTIONS(2505),
    [anon_sym_alignas] = ACTIONS(2505),
    [anon_sym__Alignas] = ACTIONS(2505),
    [sym_primitive_type] = ACTIONS(2505),
    [anon_sym_enum] = ACTIONS(2505),
    [anon_sym_class] = ACTIONS(2505),
    [anon_sym_struct] = ACTIONS(2505),
    [anon_sym_union] = ACTIONS(2505),
    [anon_sym_if] = ACTIONS(2505),
    [anon_sym_switch] = ACTIONS(2505),
    [anon_sym_case] = ACTIONS(2505),
    [anon_sym_default] = ACTIONS(2505),
    [anon_sym_while] = ACTIONS(2505),
    [anon_sym_do] = ACTIONS(2505),
    [anon_sym_for] = ACTIONS(2505),
    [anon_sym_return] = ACTIONS(2505),
    [anon_sym_break] = ACTIONS(2505),
    [anon_sym_continue] = ACTIONS(2505),
    [anon_sym_goto] = ACTIONS(2505),
    [anon_sym_not] = ACTIONS(2505),
    [anon_sym_compl] = ACTIONS(2505),
    [anon_sym_DASH_DASH] = ACTIONS(2507),
    [anon_sym_PLUS_PLUS] = ACTIONS(2507),
    [anon_sym_sizeof] = ACTIONS(2505),
    [anon_sym___alignof__] = ACTIONS(2505),
    [anon_sym___alignof] = ACTIONS(2505),
    [anon_sym__alignof] = ACTIONS(2505),
    [anon_sym_alignof] = ACTIONS(2505),
    [anon_sym__Alignof] = ACTIONS(2505),
    [anon_sym_offsetof] = ACTIONS(2505),
    [anon_sym__Generic] = ACTIONS(2505),
    [anon_sym_asm] = ACTIONS(2505),
    [anon_sym___asm__] = ACTIONS(2505),
    [anon_sym___asm] = ACTIONS(2505),
    [sym_number_literal] = ACTIONS(2507),
    [anon_sym_L_SQUOTE] = ACTIONS(2507),
    [anon_sym_u_SQUOTE] = ACTIONS(2507),
    [anon_sym_U_SQUOTE] = ACTIONS(2507),
    [anon_sym_u8_SQUOTE] = ACTIONS(2507),
    [anon_sym_SQUOTE] = ACTIONS(2507),
    [anon_sym_L_DQUOTE] = ACTIONS(2507),
    [anon_sym_u_DQUOTE] = ACTIONS(2507),
    [anon_sym_U_DQUOTE] = ACTIONS(2507),
    [anon_sym_u8_DQUOTE] = ACTIONS(2507),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [sym_true] = ACTIONS(2505),
    [sym_false] = ACTIONS(2505),
    [anon_sym_NULL] = ACTIONS(2505),
    [anon_sym_nullptr] = ACTIONS(2505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2505),
    [anon_sym_decltype] = ACTIONS(2505),
    [anon_sym_explicit] = ACTIONS(2505),
    [anon_sym_typename] = ACTIONS(2505),
    [anon_sym_template] = ACTIONS(2505),
    [anon_sym_operator] = ACTIONS(2505),
    [anon_sym_try] = ACTIONS(2505),
    [anon_sym_delete] = ACTIONS(2505),
    [anon_sym_throw] = ACTIONS(2505),
    [anon_sym_namespace] = ACTIONS(2505),
    [anon_sym_using] = ACTIONS(2505),
    [anon_sym_static_assert] = ACTIONS(2505),
    [anon_sym_concept] = ACTIONS(2505),
    [anon_sym_co_return] = ACTIONS(2505),
    [anon_sym_co_yield] = ACTIONS(2505),
    [anon_sym_R_DQUOTE] = ACTIONS(2507),
    [anon_sym_LR_DQUOTE] = ACTIONS(2507),
    [anon_sym_uR_DQUOTE] = ACTIONS(2507),
    [anon_sym_UR_DQUOTE] = ACTIONS(2507),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2507),
    [anon_sym_co_await] = ACTIONS(2505),
    [anon_sym_new] = ACTIONS(2505),
    [anon_sym_requires] = ACTIONS(2505),
    [sym_this] = ACTIONS(2505),
    [anon_sym___launch_bounds__] = ACTIONS(2505),
  },
  [STATE(722)] = {
    [ts_builtin_sym_end] = ACTIONS(2543),
    [sym_identifier] = ACTIONS(2541),
    [aux_sym_preproc_include_token1] = ACTIONS(2541),
    [aux_sym_preproc_def_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2541),
    [sym_preproc_directive] = ACTIONS(2541),
    [anon_sym_LPAREN2] = ACTIONS(2543),
    [anon_sym_BANG] = ACTIONS(2543),
    [anon_sym_TILDE] = ACTIONS(2543),
    [anon_sym_DASH] = ACTIONS(2541),
    [anon_sym_PLUS] = ACTIONS(2541),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_AMP_AMP] = ACTIONS(2543),
    [anon_sym_AMP] = ACTIONS(2541),
    [anon_sym_SEMI] = ACTIONS(2543),
    [anon_sym___extension__] = ACTIONS(2541),
    [anon_sym_typedef] = ACTIONS(2541),
    [anon_sym___device__] = ACTIONS(2541),
    [anon_sym___host__] = ACTIONS(2541),
    [anon_sym___global__] = ACTIONS(2541),
    [anon_sym___forceinline__] = ACTIONS(2541),
    [anon_sym___noinline__] = ACTIONS(2541),
    [anon_sym_virtual] = ACTIONS(2541),
    [anon_sym_extern] = ACTIONS(2541),
    [anon_sym___attribute__] = ACTIONS(2541),
    [anon_sym___attribute] = ACTIONS(2541),
    [anon_sym_COLON_COLON] = ACTIONS(2543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2543),
    [anon_sym___declspec] = ACTIONS(2541),
    [anon_sym___based] = ACTIONS(2541),
    [anon_sym___cdecl] = ACTIONS(2541),
    [anon_sym___clrcall] = ACTIONS(2541),
    [anon_sym___stdcall] = ACTIONS(2541),
    [anon_sym___fastcall] = ACTIONS(2541),
    [anon_sym___thiscall] = ACTIONS(2541),
    [anon_sym___vectorcall] = ACTIONS(2541),
    [anon_sym_LBRACE] = ACTIONS(2543),
    [anon_sym_signed] = ACTIONS(2541),
    [anon_sym_unsigned] = ACTIONS(2541),
    [anon_sym_long] = ACTIONS(2541),
    [anon_sym_short] = ACTIONS(2541),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [anon_sym_static] = ACTIONS(2541),
    [anon_sym_register] = ACTIONS(2541),
    [anon_sym_inline] = ACTIONS(2541),
    [anon_sym___inline] = ACTIONS(2541),
    [anon_sym___inline__] = ACTIONS(2541),
    [anon_sym___forceinline] = ACTIONS(2541),
    [anon_sym_thread_local] = ACTIONS(2541),
    [anon_sym___thread] = ACTIONS(2541),
    [anon_sym_const] = ACTIONS(2541),
    [anon_sym_constexpr] = ACTIONS(2541),
    [anon_sym_volatile] = ACTIONS(2541),
    [anon_sym_restrict] = ACTIONS(2541),
    [anon_sym___restrict__] = ACTIONS(2541),
    [anon_sym__Atomic] = ACTIONS(2541),
    [anon_sym__Noreturn] = ACTIONS(2541),
    [anon_sym_noreturn] = ACTIONS(2541),
    [anon_sym__Nonnull] = ACTIONS(2541),
    [anon_sym_mutable] = ACTIONS(2541),
    [anon_sym_constinit] = ACTIONS(2541),
    [anon_sym_consteval] = ACTIONS(2541),
    [anon_sym___shared__] = ACTIONS(2541),
    [anon_sym___local__] = ACTIONS(2541),
    [anon_sym___constant__] = ACTIONS(2541),
    [anon_sym___managed__] = ACTIONS(2541),
    [anon_sym___grid_constant__] = ACTIONS(2541),
    [anon_sym_alignas] = ACTIONS(2541),
    [anon_sym__Alignas] = ACTIONS(2541),
    [sym_primitive_type] = ACTIONS(2541),
    [anon_sym_enum] = ACTIONS(2541),
    [anon_sym_class] = ACTIONS(2541),
    [anon_sym_struct] = ACTIONS(2541),
    [anon_sym_union] = ACTIONS(2541),
    [anon_sym_if] = ACTIONS(2541),
    [anon_sym_switch] = ACTIONS(2541),
    [anon_sym_case] = ACTIONS(2541),
    [anon_sym_default] = ACTIONS(2541),
    [anon_sym_while] = ACTIONS(2541),
    [anon_sym_do] = ACTIONS(2541),
    [anon_sym_for] = ACTIONS(2541),
    [anon_sym_return] = ACTIONS(2541),
    [anon_sym_break] = ACTIONS(2541),
    [anon_sym_continue] = ACTIONS(2541),
    [anon_sym_goto] = ACTIONS(2541),
    [anon_sym_not] = ACTIONS(2541),
    [anon_sym_compl] = ACTIONS(2541),
    [anon_sym_DASH_DASH] = ACTIONS(2543),
    [anon_sym_PLUS_PLUS] = ACTIONS(2543),
    [anon_sym_sizeof] = ACTIONS(2541),
    [anon_sym___alignof__] = ACTIONS(2541),
    [anon_sym___alignof] = ACTIONS(2541),
    [anon_sym__alignof] = ACTIONS(2541),
    [anon_sym_alignof] = ACTIONS(2541),
    [anon_sym__Alignof] = ACTIONS(2541),
    [anon_sym_offsetof] = ACTIONS(2541),
    [anon_sym__Generic] = ACTIONS(2541),
    [anon_sym_asm] = ACTIONS(2541),
    [anon_sym___asm__] = ACTIONS(2541),
    [anon_sym___asm] = ACTIONS(2541),
    [sym_number_literal] = ACTIONS(2543),
    [anon_sym_L_SQUOTE] = ACTIONS(2543),
    [anon_sym_u_SQUOTE] = ACTIONS(2543),
    [anon_sym_U_SQUOTE] = ACTIONS(2543),
    [anon_sym_u8_SQUOTE] = ACTIONS(2543),
    [anon_sym_SQUOTE] = ACTIONS(2543),
    [anon_sym_L_DQUOTE] = ACTIONS(2543),
    [anon_sym_u_DQUOTE] = ACTIONS(2543),
    [anon_sym_U_DQUOTE] = ACTIONS(2543),
    [anon_sym_u8_DQUOTE] = ACTIONS(2543),
    [anon_sym_DQUOTE] = ACTIONS(2543),
    [sym_true] = ACTIONS(2541),
    [sym_false] = ACTIONS(2541),
    [anon_sym_NULL] = ACTIONS(2541),
    [anon_sym_nullptr] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2541),
    [anon_sym_decltype] = ACTIONS(2541),
    [anon_sym_explicit] = ACTIONS(2541),
    [anon_sym_typename] = ACTIONS(2541),
    [anon_sym_template] = ACTIONS(2541),
    [anon_sym_operator] = ACTIONS(2541),
    [anon_sym_try] = ACTIONS(2541),
    [anon_sym_delete] = ACTIONS(2541),
    [anon_sym_throw] = ACTIONS(2541),
    [anon_sym_namespace] = ACTIONS(2541),
    [anon_sym_using] = ACTIONS(2541),
    [anon_sym_static_assert] = ACTIONS(2541),
    [anon_sym_concept] = ACTIONS(2541),
    [anon_sym_co_return] = ACTIONS(2541),
    [anon_sym_co_yield] = ACTIONS(2541),
    [anon_sym_R_DQUOTE] = ACTIONS(2543),
    [anon_sym_LR_DQUOTE] = ACTIONS(2543),
    [anon_sym_uR_DQUOTE] = ACTIONS(2543),
    [anon_sym_UR_DQUOTE] = ACTIONS(2543),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2543),
    [anon_sym_co_await] = ACTIONS(2541),
    [anon_sym_new] = ACTIONS(2541),
    [anon_sym_requires] = ACTIONS(2541),
    [sym_this] = ACTIONS(2541),
    [anon_sym___launch_bounds__] = ACTIONS(2541),
  },
  [STATE(723)] = {
    [ts_builtin_sym_end] = ACTIONS(2385),
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_include_token1] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2385),
    [anon_sym_BANG] = ACTIONS(2385),
    [anon_sym_TILDE] = ACTIONS(2385),
    [anon_sym_DASH] = ACTIONS(2383),
    [anon_sym_PLUS] = ACTIONS(2383),
    [anon_sym_STAR] = ACTIONS(2385),
    [anon_sym_AMP_AMP] = ACTIONS(2385),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym___device__] = ACTIONS(2383),
    [anon_sym___host__] = ACTIONS(2383),
    [anon_sym___global__] = ACTIONS(2383),
    [anon_sym___forceinline__] = ACTIONS(2383),
    [anon_sym___noinline__] = ACTIONS(2383),
    [anon_sym_virtual] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym___attribute] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2385),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2385),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym___cdecl] = ACTIONS(2383),
    [anon_sym___clrcall] = ACTIONS(2383),
    [anon_sym___stdcall] = ACTIONS(2383),
    [anon_sym___fastcall] = ACTIONS(2383),
    [anon_sym___thiscall] = ACTIONS(2383),
    [anon_sym___vectorcall] = ACTIONS(2383),
    [anon_sym_LBRACE] = ACTIONS(2385),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym__Nonnull] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym___shared__] = ACTIONS(2383),
    [anon_sym___local__] = ACTIONS(2383),
    [anon_sym___constant__] = ACTIONS(2383),
    [anon_sym___managed__] = ACTIONS(2383),
    [anon_sym___grid_constant__] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [anon_sym_if] = ACTIONS(2383),
    [anon_sym_switch] = ACTIONS(2383),
    [anon_sym_case] = ACTIONS(2383),
    [anon_sym_default] = ACTIONS(2383),
    [anon_sym_while] = ACTIONS(2383),
    [anon_sym_do] = ACTIONS(2383),
    [anon_sym_for] = ACTIONS(2383),
    [anon_sym_return] = ACTIONS(2383),
    [anon_sym_break] = ACTIONS(2383),
    [anon_sym_continue] = ACTIONS(2383),
    [anon_sym_goto] = ACTIONS(2383),
    [anon_sym_not] = ACTIONS(2383),
    [anon_sym_compl] = ACTIONS(2383),
    [anon_sym_DASH_DASH] = ACTIONS(2385),
    [anon_sym_PLUS_PLUS] = ACTIONS(2385),
    [anon_sym_sizeof] = ACTIONS(2383),
    [anon_sym___alignof__] = ACTIONS(2383),
    [anon_sym___alignof] = ACTIONS(2383),
    [anon_sym__alignof] = ACTIONS(2383),
    [anon_sym_alignof] = ACTIONS(2383),
    [anon_sym__Alignof] = ACTIONS(2383),
    [anon_sym_offsetof] = ACTIONS(2383),
    [anon_sym__Generic] = ACTIONS(2383),
    [anon_sym_asm] = ACTIONS(2383),
    [anon_sym___asm__] = ACTIONS(2383),
    [anon_sym___asm] = ACTIONS(2383),
    [sym_number_literal] = ACTIONS(2385),
    [anon_sym_L_SQUOTE] = ACTIONS(2385),
    [anon_sym_u_SQUOTE] = ACTIONS(2385),
    [anon_sym_U_SQUOTE] = ACTIONS(2385),
    [anon_sym_u8_SQUOTE] = ACTIONS(2385),
    [anon_sym_SQUOTE] = ACTIONS(2385),
    [anon_sym_L_DQUOTE] = ACTIONS(2385),
    [anon_sym_u_DQUOTE] = ACTIONS(2385),
    [anon_sym_U_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8_DQUOTE] = ACTIONS(2385),
    [anon_sym_DQUOTE] = ACTIONS(2385),
    [sym_true] = ACTIONS(2383),
    [sym_false] = ACTIONS(2383),
    [anon_sym_NULL] = ACTIONS(2383),
    [anon_sym_nullptr] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_try] = ACTIONS(2383),
    [anon_sym_delete] = ACTIONS(2383),
    [anon_sym_throw] = ACTIONS(2383),
    [anon_sym_namespace] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym_concept] = ACTIONS(2383),
    [anon_sym_co_return] = ACTIONS(2383),
    [anon_sym_co_yield] = ACTIONS(2383),
    [anon_sym_R_DQUOTE] = ACTIONS(2385),
    [anon_sym_LR_DQUOTE] = ACTIONS(2385),
    [anon_sym_uR_DQUOTE] = ACTIONS(2385),
    [anon_sym_UR_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2385),
    [anon_sym_co_await] = ACTIONS(2383),
    [anon_sym_new] = ACTIONS(2383),
    [anon_sym_requires] = ACTIONS(2383),
    [sym_this] = ACTIONS(2383),
    [anon_sym___launch_bounds__] = ACTIONS(2383),
  },
  [STATE(724)] = {
    [ts_builtin_sym_end] = ACTIONS(2314),
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [anon_sym___asm] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(725)] = {
    [ts_builtin_sym_end] = ACTIONS(2477),
    [sym_identifier] = ACTIONS(2475),
    [aux_sym_preproc_include_token1] = ACTIONS(2475),
    [aux_sym_preproc_def_token1] = ACTIONS(2475),
    [aux_sym_preproc_if_token1] = ACTIONS(2475),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2475),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2475),
    [sym_preproc_directive] = ACTIONS(2475),
    [anon_sym_LPAREN2] = ACTIONS(2477),
    [anon_sym_BANG] = ACTIONS(2477),
    [anon_sym_TILDE] = ACTIONS(2477),
    [anon_sym_DASH] = ACTIONS(2475),
    [anon_sym_PLUS] = ACTIONS(2475),
    [anon_sym_STAR] = ACTIONS(2477),
    [anon_sym_AMP_AMP] = ACTIONS(2477),
    [anon_sym_AMP] = ACTIONS(2475),
    [anon_sym_SEMI] = ACTIONS(2477),
    [anon_sym___extension__] = ACTIONS(2475),
    [anon_sym_typedef] = ACTIONS(2475),
    [anon_sym___device__] = ACTIONS(2475),
    [anon_sym___host__] = ACTIONS(2475),
    [anon_sym___global__] = ACTIONS(2475),
    [anon_sym___forceinline__] = ACTIONS(2475),
    [anon_sym___noinline__] = ACTIONS(2475),
    [anon_sym_virtual] = ACTIONS(2475),
    [anon_sym_extern] = ACTIONS(2475),
    [anon_sym___attribute__] = ACTIONS(2475),
    [anon_sym___attribute] = ACTIONS(2475),
    [anon_sym_COLON_COLON] = ACTIONS(2477),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2477),
    [anon_sym___declspec] = ACTIONS(2475),
    [anon_sym___based] = ACTIONS(2475),
    [anon_sym___cdecl] = ACTIONS(2475),
    [anon_sym___clrcall] = ACTIONS(2475),
    [anon_sym___stdcall] = ACTIONS(2475),
    [anon_sym___fastcall] = ACTIONS(2475),
    [anon_sym___thiscall] = ACTIONS(2475),
    [anon_sym___vectorcall] = ACTIONS(2475),
    [anon_sym_LBRACE] = ACTIONS(2477),
    [anon_sym_signed] = ACTIONS(2475),
    [anon_sym_unsigned] = ACTIONS(2475),
    [anon_sym_long] = ACTIONS(2475),
    [anon_sym_short] = ACTIONS(2475),
    [anon_sym_LBRACK] = ACTIONS(2475),
    [anon_sym_static] = ACTIONS(2475),
    [anon_sym_register] = ACTIONS(2475),
    [anon_sym_inline] = ACTIONS(2475),
    [anon_sym___inline] = ACTIONS(2475),
    [anon_sym___inline__] = ACTIONS(2475),
    [anon_sym___forceinline] = ACTIONS(2475),
    [anon_sym_thread_local] = ACTIONS(2475),
    [anon_sym___thread] = ACTIONS(2475),
    [anon_sym_const] = ACTIONS(2475),
    [anon_sym_constexpr] = ACTIONS(2475),
    [anon_sym_volatile] = ACTIONS(2475),
    [anon_sym_restrict] = ACTIONS(2475),
    [anon_sym___restrict__] = ACTIONS(2475),
    [anon_sym__Atomic] = ACTIONS(2475),
    [anon_sym__Noreturn] = ACTIONS(2475),
    [anon_sym_noreturn] = ACTIONS(2475),
    [anon_sym__Nonnull] = ACTIONS(2475),
    [anon_sym_mutable] = ACTIONS(2475),
    [anon_sym_constinit] = ACTIONS(2475),
    [anon_sym_consteval] = ACTIONS(2475),
    [anon_sym___shared__] = ACTIONS(2475),
    [anon_sym___local__] = ACTIONS(2475),
    [anon_sym___constant__] = ACTIONS(2475),
    [anon_sym___managed__] = ACTIONS(2475),
    [anon_sym___grid_constant__] = ACTIONS(2475),
    [anon_sym_alignas] = ACTIONS(2475),
    [anon_sym__Alignas] = ACTIONS(2475),
    [sym_primitive_type] = ACTIONS(2475),
    [anon_sym_enum] = ACTIONS(2475),
    [anon_sym_class] = ACTIONS(2475),
    [anon_sym_struct] = ACTIONS(2475),
    [anon_sym_union] = ACTIONS(2475),
    [anon_sym_if] = ACTIONS(2475),
    [anon_sym_switch] = ACTIONS(2475),
    [anon_sym_case] = ACTIONS(2475),
    [anon_sym_default] = ACTIONS(2475),
    [anon_sym_while] = ACTIONS(2475),
    [anon_sym_do] = ACTIONS(2475),
    [anon_sym_for] = ACTIONS(2475),
    [anon_sym_return] = ACTIONS(2475),
    [anon_sym_break] = ACTIONS(2475),
    [anon_sym_continue] = ACTIONS(2475),
    [anon_sym_goto] = ACTIONS(2475),
    [anon_sym_not] = ACTIONS(2475),
    [anon_sym_compl] = ACTIONS(2475),
    [anon_sym_DASH_DASH] = ACTIONS(2477),
    [anon_sym_PLUS_PLUS] = ACTIONS(2477),
    [anon_sym_sizeof] = ACTIONS(2475),
    [anon_sym___alignof__] = ACTIONS(2475),
    [anon_sym___alignof] = ACTIONS(2475),
    [anon_sym__alignof] = ACTIONS(2475),
    [anon_sym_alignof] = ACTIONS(2475),
    [anon_sym__Alignof] = ACTIONS(2475),
    [anon_sym_offsetof] = ACTIONS(2475),
    [anon_sym__Generic] = ACTIONS(2475),
    [anon_sym_asm] = ACTIONS(2475),
    [anon_sym___asm__] = ACTIONS(2475),
    [anon_sym___asm] = ACTIONS(2475),
    [sym_number_literal] = ACTIONS(2477),
    [anon_sym_L_SQUOTE] = ACTIONS(2477),
    [anon_sym_u_SQUOTE] = ACTIONS(2477),
    [anon_sym_U_SQUOTE] = ACTIONS(2477),
    [anon_sym_u8_SQUOTE] = ACTIONS(2477),
    [anon_sym_SQUOTE] = ACTIONS(2477),
    [anon_sym_L_DQUOTE] = ACTIONS(2477),
    [anon_sym_u_DQUOTE] = ACTIONS(2477),
    [anon_sym_U_DQUOTE] = ACTIONS(2477),
    [anon_sym_u8_DQUOTE] = ACTIONS(2477),
    [anon_sym_DQUOTE] = ACTIONS(2477),
    [sym_true] = ACTIONS(2475),
    [sym_false] = ACTIONS(2475),
    [anon_sym_NULL] = ACTIONS(2475),
    [anon_sym_nullptr] = ACTIONS(2475),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2475),
    [anon_sym_decltype] = ACTIONS(2475),
    [anon_sym_explicit] = ACTIONS(2475),
    [anon_sym_typename] = ACTIONS(2475),
    [anon_sym_template] = ACTIONS(2475),
    [anon_sym_operator] = ACTIONS(2475),
    [anon_sym_try] = ACTIONS(2475),
    [anon_sym_delete] = ACTIONS(2475),
    [anon_sym_throw] = ACTIONS(2475),
    [anon_sym_namespace] = ACTIONS(2475),
    [anon_sym_using] = ACTIONS(2475),
    [anon_sym_static_assert] = ACTIONS(2475),
    [anon_sym_concept] = ACTIONS(2475),
    [anon_sym_co_return] = ACTIONS(2475),
    [anon_sym_co_yield] = ACTIONS(2475),
    [anon_sym_R_DQUOTE] = ACTIONS(2477),
    [anon_sym_LR_DQUOTE] = ACTIONS(2477),
    [anon_sym_uR_DQUOTE] = ACTIONS(2477),
    [anon_sym_UR_DQUOTE] = ACTIONS(2477),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2477),
    [anon_sym_co_await] = ACTIONS(2475),
    [anon_sym_new] = ACTIONS(2475),
    [anon_sym_requires] = ACTIONS(2475),
    [sym_this] = ACTIONS(2475),
    [anon_sym___launch_bounds__] = ACTIONS(2475),
  },
  [STATE(726)] = {
    [ts_builtin_sym_end] = ACTIONS(2314),
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [anon_sym___asm] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(727)] = {
    [ts_builtin_sym_end] = ACTIONS(2559),
    [sym_identifier] = ACTIONS(2557),
    [aux_sym_preproc_include_token1] = ACTIONS(2557),
    [aux_sym_preproc_def_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2557),
    [sym_preproc_directive] = ACTIONS(2557),
    [anon_sym_LPAREN2] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2557),
    [anon_sym_PLUS] = ACTIONS(2557),
    [anon_sym_STAR] = ACTIONS(2559),
    [anon_sym_AMP_AMP] = ACTIONS(2559),
    [anon_sym_AMP] = ACTIONS(2557),
    [anon_sym_SEMI] = ACTIONS(2559),
    [anon_sym___extension__] = ACTIONS(2557),
    [anon_sym_typedef] = ACTIONS(2557),
    [anon_sym___device__] = ACTIONS(2557),
    [anon_sym___host__] = ACTIONS(2557),
    [anon_sym___global__] = ACTIONS(2557),
    [anon_sym___forceinline__] = ACTIONS(2557),
    [anon_sym___noinline__] = ACTIONS(2557),
    [anon_sym_virtual] = ACTIONS(2557),
    [anon_sym_extern] = ACTIONS(2557),
    [anon_sym___attribute__] = ACTIONS(2557),
    [anon_sym___attribute] = ACTIONS(2557),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2559),
    [anon_sym___declspec] = ACTIONS(2557),
    [anon_sym___based] = ACTIONS(2557),
    [anon_sym___cdecl] = ACTIONS(2557),
    [anon_sym___clrcall] = ACTIONS(2557),
    [anon_sym___stdcall] = ACTIONS(2557),
    [anon_sym___fastcall] = ACTIONS(2557),
    [anon_sym___thiscall] = ACTIONS(2557),
    [anon_sym___vectorcall] = ACTIONS(2557),
    [anon_sym_LBRACE] = ACTIONS(2559),
    [anon_sym_signed] = ACTIONS(2557),
    [anon_sym_unsigned] = ACTIONS(2557),
    [anon_sym_long] = ACTIONS(2557),
    [anon_sym_short] = ACTIONS(2557),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2557),
    [anon_sym_register] = ACTIONS(2557),
    [anon_sym_inline] = ACTIONS(2557),
    [anon_sym___inline] = ACTIONS(2557),
    [anon_sym___inline__] = ACTIONS(2557),
    [anon_sym___forceinline] = ACTIONS(2557),
    [anon_sym_thread_local] = ACTIONS(2557),
    [anon_sym___thread] = ACTIONS(2557),
    [anon_sym_const] = ACTIONS(2557),
    [anon_sym_constexpr] = ACTIONS(2557),
    [anon_sym_volatile] = ACTIONS(2557),
    [anon_sym_restrict] = ACTIONS(2557),
    [anon_sym___restrict__] = ACTIONS(2557),
    [anon_sym__Atomic] = ACTIONS(2557),
    [anon_sym__Noreturn] = ACTIONS(2557),
    [anon_sym_noreturn] = ACTIONS(2557),
    [anon_sym__Nonnull] = ACTIONS(2557),
    [anon_sym_mutable] = ACTIONS(2557),
    [anon_sym_constinit] = ACTIONS(2557),
    [anon_sym_consteval] = ACTIONS(2557),
    [anon_sym___shared__] = ACTIONS(2557),
    [anon_sym___local__] = ACTIONS(2557),
    [anon_sym___constant__] = ACTIONS(2557),
    [anon_sym___managed__] = ACTIONS(2557),
    [anon_sym___grid_constant__] = ACTIONS(2557),
    [anon_sym_alignas] = ACTIONS(2557),
    [anon_sym__Alignas] = ACTIONS(2557),
    [sym_primitive_type] = ACTIONS(2557),
    [anon_sym_enum] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2557),
    [anon_sym_struct] = ACTIONS(2557),
    [anon_sym_union] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2557),
    [anon_sym_switch] = ACTIONS(2557),
    [anon_sym_case] = ACTIONS(2557),
    [anon_sym_default] = ACTIONS(2557),
    [anon_sym_while] = ACTIONS(2557),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_for] = ACTIONS(2557),
    [anon_sym_return] = ACTIONS(2557),
    [anon_sym_break] = ACTIONS(2557),
    [anon_sym_continue] = ACTIONS(2557),
    [anon_sym_goto] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2557),
    [anon_sym_compl] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2559),
    [anon_sym_sizeof] = ACTIONS(2557),
    [anon_sym___alignof__] = ACTIONS(2557),
    [anon_sym___alignof] = ACTIONS(2557),
    [anon_sym__alignof] = ACTIONS(2557),
    [anon_sym_alignof] = ACTIONS(2557),
    [anon_sym__Alignof] = ACTIONS(2557),
    [anon_sym_offsetof] = ACTIONS(2557),
    [anon_sym__Generic] = ACTIONS(2557),
    [anon_sym_asm] = ACTIONS(2557),
    [anon_sym___asm__] = ACTIONS(2557),
    [anon_sym___asm] = ACTIONS(2557),
    [sym_number_literal] = ACTIONS(2559),
    [anon_sym_L_SQUOTE] = ACTIONS(2559),
    [anon_sym_u_SQUOTE] = ACTIONS(2559),
    [anon_sym_U_SQUOTE] = ACTIONS(2559),
    [anon_sym_u8_SQUOTE] = ACTIONS(2559),
    [anon_sym_SQUOTE] = ACTIONS(2559),
    [anon_sym_L_DQUOTE] = ACTIONS(2559),
    [anon_sym_u_DQUOTE] = ACTIONS(2559),
    [anon_sym_U_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8_DQUOTE] = ACTIONS(2559),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_true] = ACTIONS(2557),
    [sym_false] = ACTIONS(2557),
    [anon_sym_NULL] = ACTIONS(2557),
    [anon_sym_nullptr] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2557),
    [anon_sym_decltype] = ACTIONS(2557),
    [anon_sym_explicit] = ACTIONS(2557),
    [anon_sym_typename] = ACTIONS(2557),
    [anon_sym_template] = ACTIONS(2557),
    [anon_sym_operator] = ACTIONS(2557),
    [anon_sym_try] = ACTIONS(2557),
    [anon_sym_delete] = ACTIONS(2557),
    [anon_sym_throw] = ACTIONS(2557),
    [anon_sym_namespace] = ACTIONS(2557),
    [anon_sym_using] = ACTIONS(2557),
    [anon_sym_static_assert] = ACTIONS(2557),
    [anon_sym_concept] = ACTIONS(2557),
    [anon_sym_co_return] = ACTIONS(2557),
    [anon_sym_co_yield] = ACTIONS(2557),
    [anon_sym_R_DQUOTE] = ACTIONS(2559),
    [anon_sym_LR_DQUOTE] = ACTIONS(2559),
    [anon_sym_uR_DQUOTE] = ACTIONS(2559),
    [anon_sym_UR_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2559),
    [anon_sym_co_await] = ACTIONS(2557),
    [anon_sym_new] = ACTIONS(2557),
    [anon_sym_requires] = ACTIONS(2557),
    [sym_this] = ACTIONS(2557),
    [anon_sym___launch_bounds__] = ACTIONS(2557),
  },
  [STATE(728)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5339),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(8815),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(729)] = {
    [ts_builtin_sym_end] = ACTIONS(2417),
    [sym_identifier] = ACTIONS(2415),
    [aux_sym_preproc_include_token1] = ACTIONS(2415),
    [aux_sym_preproc_def_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2415),
    [sym_preproc_directive] = ACTIONS(2415),
    [anon_sym_LPAREN2] = ACTIONS(2417),
    [anon_sym_BANG] = ACTIONS(2417),
    [anon_sym_TILDE] = ACTIONS(2417),
    [anon_sym_DASH] = ACTIONS(2415),
    [anon_sym_PLUS] = ACTIONS(2415),
    [anon_sym_STAR] = ACTIONS(2417),
    [anon_sym_AMP_AMP] = ACTIONS(2417),
    [anon_sym_AMP] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(2417),
    [anon_sym___extension__] = ACTIONS(2415),
    [anon_sym_typedef] = ACTIONS(2415),
    [anon_sym___device__] = ACTIONS(2415),
    [anon_sym___host__] = ACTIONS(2415),
    [anon_sym___global__] = ACTIONS(2415),
    [anon_sym___forceinline__] = ACTIONS(2415),
    [anon_sym___noinline__] = ACTIONS(2415),
    [anon_sym_virtual] = ACTIONS(2415),
    [anon_sym_extern] = ACTIONS(2415),
    [anon_sym___attribute__] = ACTIONS(2415),
    [anon_sym___attribute] = ACTIONS(2415),
    [anon_sym_COLON_COLON] = ACTIONS(2417),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2417),
    [anon_sym___declspec] = ACTIONS(2415),
    [anon_sym___based] = ACTIONS(2415),
    [anon_sym___cdecl] = ACTIONS(2415),
    [anon_sym___clrcall] = ACTIONS(2415),
    [anon_sym___stdcall] = ACTIONS(2415),
    [anon_sym___fastcall] = ACTIONS(2415),
    [anon_sym___thiscall] = ACTIONS(2415),
    [anon_sym___vectorcall] = ACTIONS(2415),
    [anon_sym_LBRACE] = ACTIONS(2417),
    [anon_sym_signed] = ACTIONS(2415),
    [anon_sym_unsigned] = ACTIONS(2415),
    [anon_sym_long] = ACTIONS(2415),
    [anon_sym_short] = ACTIONS(2415),
    [anon_sym_LBRACK] = ACTIONS(2415),
    [anon_sym_static] = ACTIONS(2415),
    [anon_sym_register] = ACTIONS(2415),
    [anon_sym_inline] = ACTIONS(2415),
    [anon_sym___inline] = ACTIONS(2415),
    [anon_sym___inline__] = ACTIONS(2415),
    [anon_sym___forceinline] = ACTIONS(2415),
    [anon_sym_thread_local] = ACTIONS(2415),
    [anon_sym___thread] = ACTIONS(2415),
    [anon_sym_const] = ACTIONS(2415),
    [anon_sym_constexpr] = ACTIONS(2415),
    [anon_sym_volatile] = ACTIONS(2415),
    [anon_sym_restrict] = ACTIONS(2415),
    [anon_sym___restrict__] = ACTIONS(2415),
    [anon_sym__Atomic] = ACTIONS(2415),
    [anon_sym__Noreturn] = ACTIONS(2415),
    [anon_sym_noreturn] = ACTIONS(2415),
    [anon_sym__Nonnull] = ACTIONS(2415),
    [anon_sym_mutable] = ACTIONS(2415),
    [anon_sym_constinit] = ACTIONS(2415),
    [anon_sym_consteval] = ACTIONS(2415),
    [anon_sym___shared__] = ACTIONS(2415),
    [anon_sym___local__] = ACTIONS(2415),
    [anon_sym___constant__] = ACTIONS(2415),
    [anon_sym___managed__] = ACTIONS(2415),
    [anon_sym___grid_constant__] = ACTIONS(2415),
    [anon_sym_alignas] = ACTIONS(2415),
    [anon_sym__Alignas] = ACTIONS(2415),
    [sym_primitive_type] = ACTIONS(2415),
    [anon_sym_enum] = ACTIONS(2415),
    [anon_sym_class] = ACTIONS(2415),
    [anon_sym_struct] = ACTIONS(2415),
    [anon_sym_union] = ACTIONS(2415),
    [anon_sym_if] = ACTIONS(2415),
    [anon_sym_switch] = ACTIONS(2415),
    [anon_sym_case] = ACTIONS(2415),
    [anon_sym_default] = ACTIONS(2415),
    [anon_sym_while] = ACTIONS(2415),
    [anon_sym_do] = ACTIONS(2415),
    [anon_sym_for] = ACTIONS(2415),
    [anon_sym_return] = ACTIONS(2415),
    [anon_sym_break] = ACTIONS(2415),
    [anon_sym_continue] = ACTIONS(2415),
    [anon_sym_goto] = ACTIONS(2415),
    [anon_sym_not] = ACTIONS(2415),
    [anon_sym_compl] = ACTIONS(2415),
    [anon_sym_DASH_DASH] = ACTIONS(2417),
    [anon_sym_PLUS_PLUS] = ACTIONS(2417),
    [anon_sym_sizeof] = ACTIONS(2415),
    [anon_sym___alignof__] = ACTIONS(2415),
    [anon_sym___alignof] = ACTIONS(2415),
    [anon_sym__alignof] = ACTIONS(2415),
    [anon_sym_alignof] = ACTIONS(2415),
    [anon_sym__Alignof] = ACTIONS(2415),
    [anon_sym_offsetof] = ACTIONS(2415),
    [anon_sym__Generic] = ACTIONS(2415),
    [anon_sym_asm] = ACTIONS(2415),
    [anon_sym___asm__] = ACTIONS(2415),
    [anon_sym___asm] = ACTIONS(2415),
    [sym_number_literal] = ACTIONS(2417),
    [anon_sym_L_SQUOTE] = ACTIONS(2417),
    [anon_sym_u_SQUOTE] = ACTIONS(2417),
    [anon_sym_U_SQUOTE] = ACTIONS(2417),
    [anon_sym_u8_SQUOTE] = ACTIONS(2417),
    [anon_sym_SQUOTE] = ACTIONS(2417),
    [anon_sym_L_DQUOTE] = ACTIONS(2417),
    [anon_sym_u_DQUOTE] = ACTIONS(2417),
    [anon_sym_U_DQUOTE] = ACTIONS(2417),
    [anon_sym_u8_DQUOTE] = ACTIONS(2417),
    [anon_sym_DQUOTE] = ACTIONS(2417),
    [sym_true] = ACTIONS(2415),
    [sym_false] = ACTIONS(2415),
    [anon_sym_NULL] = ACTIONS(2415),
    [anon_sym_nullptr] = ACTIONS(2415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2415),
    [anon_sym_decltype] = ACTIONS(2415),
    [anon_sym_explicit] = ACTIONS(2415),
    [anon_sym_typename] = ACTIONS(2415),
    [anon_sym_template] = ACTIONS(2415),
    [anon_sym_operator] = ACTIONS(2415),
    [anon_sym_try] = ACTIONS(2415),
    [anon_sym_delete] = ACTIONS(2415),
    [anon_sym_throw] = ACTIONS(2415),
    [anon_sym_namespace] = ACTIONS(2415),
    [anon_sym_using] = ACTIONS(2415),
    [anon_sym_static_assert] = ACTIONS(2415),
    [anon_sym_concept] = ACTIONS(2415),
    [anon_sym_co_return] = ACTIONS(2415),
    [anon_sym_co_yield] = ACTIONS(2415),
    [anon_sym_R_DQUOTE] = ACTIONS(2417),
    [anon_sym_LR_DQUOTE] = ACTIONS(2417),
    [anon_sym_uR_DQUOTE] = ACTIONS(2417),
    [anon_sym_UR_DQUOTE] = ACTIONS(2417),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2417),
    [anon_sym_co_await] = ACTIONS(2415),
    [anon_sym_new] = ACTIONS(2415),
    [anon_sym_requires] = ACTIONS(2415),
    [sym_this] = ACTIONS(2415),
    [anon_sym___launch_bounds__] = ACTIONS(2415),
  },
  [STATE(730)] = {
    [ts_builtin_sym_end] = ACTIONS(2531),
    [sym_identifier] = ACTIONS(2529),
    [aux_sym_preproc_include_token1] = ACTIONS(2529),
    [aux_sym_preproc_def_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2529),
    [sym_preproc_directive] = ACTIONS(2529),
    [anon_sym_LPAREN2] = ACTIONS(2531),
    [anon_sym_BANG] = ACTIONS(2531),
    [anon_sym_TILDE] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2529),
    [anon_sym_PLUS] = ACTIONS(2529),
    [anon_sym_STAR] = ACTIONS(2531),
    [anon_sym_AMP_AMP] = ACTIONS(2531),
    [anon_sym_AMP] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym___extension__] = ACTIONS(2529),
    [anon_sym_typedef] = ACTIONS(2529),
    [anon_sym___device__] = ACTIONS(2529),
    [anon_sym___host__] = ACTIONS(2529),
    [anon_sym___global__] = ACTIONS(2529),
    [anon_sym___forceinline__] = ACTIONS(2529),
    [anon_sym___noinline__] = ACTIONS(2529),
    [anon_sym_virtual] = ACTIONS(2529),
    [anon_sym_extern] = ACTIONS(2529),
    [anon_sym___attribute__] = ACTIONS(2529),
    [anon_sym___attribute] = ACTIONS(2529),
    [anon_sym_COLON_COLON] = ACTIONS(2531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2531),
    [anon_sym___declspec] = ACTIONS(2529),
    [anon_sym___based] = ACTIONS(2529),
    [anon_sym___cdecl] = ACTIONS(2529),
    [anon_sym___clrcall] = ACTIONS(2529),
    [anon_sym___stdcall] = ACTIONS(2529),
    [anon_sym___fastcall] = ACTIONS(2529),
    [anon_sym___thiscall] = ACTIONS(2529),
    [anon_sym___vectorcall] = ACTIONS(2529),
    [anon_sym_LBRACE] = ACTIONS(2531),
    [anon_sym_signed] = ACTIONS(2529),
    [anon_sym_unsigned] = ACTIONS(2529),
    [anon_sym_long] = ACTIONS(2529),
    [anon_sym_short] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2529),
    [anon_sym_register] = ACTIONS(2529),
    [anon_sym_inline] = ACTIONS(2529),
    [anon_sym___inline] = ACTIONS(2529),
    [anon_sym___inline__] = ACTIONS(2529),
    [anon_sym___forceinline] = ACTIONS(2529),
    [anon_sym_thread_local] = ACTIONS(2529),
    [anon_sym___thread] = ACTIONS(2529),
    [anon_sym_const] = ACTIONS(2529),
    [anon_sym_constexpr] = ACTIONS(2529),
    [anon_sym_volatile] = ACTIONS(2529),
    [anon_sym_restrict] = ACTIONS(2529),
    [anon_sym___restrict__] = ACTIONS(2529),
    [anon_sym__Atomic] = ACTIONS(2529),
    [anon_sym__Noreturn] = ACTIONS(2529),
    [anon_sym_noreturn] = ACTIONS(2529),
    [anon_sym__Nonnull] = ACTIONS(2529),
    [anon_sym_mutable] = ACTIONS(2529),
    [anon_sym_constinit] = ACTIONS(2529),
    [anon_sym_consteval] = ACTIONS(2529),
    [anon_sym___shared__] = ACTIONS(2529),
    [anon_sym___local__] = ACTIONS(2529),
    [anon_sym___constant__] = ACTIONS(2529),
    [anon_sym___managed__] = ACTIONS(2529),
    [anon_sym___grid_constant__] = ACTIONS(2529),
    [anon_sym_alignas] = ACTIONS(2529),
    [anon_sym__Alignas] = ACTIONS(2529),
    [sym_primitive_type] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2529),
    [anon_sym_struct] = ACTIONS(2529),
    [anon_sym_union] = ACTIONS(2529),
    [anon_sym_if] = ACTIONS(2529),
    [anon_sym_switch] = ACTIONS(2529),
    [anon_sym_case] = ACTIONS(2529),
    [anon_sym_default] = ACTIONS(2529),
    [anon_sym_while] = ACTIONS(2529),
    [anon_sym_do] = ACTIONS(2529),
    [anon_sym_for] = ACTIONS(2529),
    [anon_sym_return] = ACTIONS(2529),
    [anon_sym_break] = ACTIONS(2529),
    [anon_sym_continue] = ACTIONS(2529),
    [anon_sym_goto] = ACTIONS(2529),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_compl] = ACTIONS(2529),
    [anon_sym_DASH_DASH] = ACTIONS(2531),
    [anon_sym_PLUS_PLUS] = ACTIONS(2531),
    [anon_sym_sizeof] = ACTIONS(2529),
    [anon_sym___alignof__] = ACTIONS(2529),
    [anon_sym___alignof] = ACTIONS(2529),
    [anon_sym__alignof] = ACTIONS(2529),
    [anon_sym_alignof] = ACTIONS(2529),
    [anon_sym__Alignof] = ACTIONS(2529),
    [anon_sym_offsetof] = ACTIONS(2529),
    [anon_sym__Generic] = ACTIONS(2529),
    [anon_sym_asm] = ACTIONS(2529),
    [anon_sym___asm__] = ACTIONS(2529),
    [anon_sym___asm] = ACTIONS(2529),
    [sym_number_literal] = ACTIONS(2531),
    [anon_sym_L_SQUOTE] = ACTIONS(2531),
    [anon_sym_u_SQUOTE] = ACTIONS(2531),
    [anon_sym_U_SQUOTE] = ACTIONS(2531),
    [anon_sym_u8_SQUOTE] = ACTIONS(2531),
    [anon_sym_SQUOTE] = ACTIONS(2531),
    [anon_sym_L_DQUOTE] = ACTIONS(2531),
    [anon_sym_u_DQUOTE] = ACTIONS(2531),
    [anon_sym_U_DQUOTE] = ACTIONS(2531),
    [anon_sym_u8_DQUOTE] = ACTIONS(2531),
    [anon_sym_DQUOTE] = ACTIONS(2531),
    [sym_true] = ACTIONS(2529),
    [sym_false] = ACTIONS(2529),
    [anon_sym_NULL] = ACTIONS(2529),
    [anon_sym_nullptr] = ACTIONS(2529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2529),
    [anon_sym_decltype] = ACTIONS(2529),
    [anon_sym_explicit] = ACTIONS(2529),
    [anon_sym_typename] = ACTIONS(2529),
    [anon_sym_template] = ACTIONS(2529),
    [anon_sym_operator] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2529),
    [anon_sym_delete] = ACTIONS(2529),
    [anon_sym_throw] = ACTIONS(2529),
    [anon_sym_namespace] = ACTIONS(2529),
    [anon_sym_using] = ACTIONS(2529),
    [anon_sym_static_assert] = ACTIONS(2529),
    [anon_sym_concept] = ACTIONS(2529),
    [anon_sym_co_return] = ACTIONS(2529),
    [anon_sym_co_yield] = ACTIONS(2529),
    [anon_sym_R_DQUOTE] = ACTIONS(2531),
    [anon_sym_LR_DQUOTE] = ACTIONS(2531),
    [anon_sym_uR_DQUOTE] = ACTIONS(2531),
    [anon_sym_UR_DQUOTE] = ACTIONS(2531),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2531),
    [anon_sym_co_await] = ACTIONS(2529),
    [anon_sym_new] = ACTIONS(2529),
    [anon_sym_requires] = ACTIONS(2529),
    [sym_this] = ACTIONS(2529),
    [anon_sym___launch_bounds__] = ACTIONS(2529),
  },
  [STATE(731)] = {
    [ts_builtin_sym_end] = ACTIONS(2341),
    [sym_identifier] = ACTIONS(2339),
    [aux_sym_preproc_include_token1] = ACTIONS(2339),
    [aux_sym_preproc_def_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2339),
    [sym_preproc_directive] = ACTIONS(2339),
    [anon_sym_LPAREN2] = ACTIONS(2341),
    [anon_sym_BANG] = ACTIONS(2341),
    [anon_sym_TILDE] = ACTIONS(2341),
    [anon_sym_DASH] = ACTIONS(2339),
    [anon_sym_PLUS] = ACTIONS(2339),
    [anon_sym_STAR] = ACTIONS(2341),
    [anon_sym_AMP_AMP] = ACTIONS(2341),
    [anon_sym_AMP] = ACTIONS(2339),
    [anon_sym_SEMI] = ACTIONS(2341),
    [anon_sym___extension__] = ACTIONS(2339),
    [anon_sym_typedef] = ACTIONS(2339),
    [anon_sym___device__] = ACTIONS(2339),
    [anon_sym___host__] = ACTIONS(2339),
    [anon_sym___global__] = ACTIONS(2339),
    [anon_sym___forceinline__] = ACTIONS(2339),
    [anon_sym___noinline__] = ACTIONS(2339),
    [anon_sym_virtual] = ACTIONS(2339),
    [anon_sym_extern] = ACTIONS(2339),
    [anon_sym___attribute__] = ACTIONS(2339),
    [anon_sym___attribute] = ACTIONS(2339),
    [anon_sym_COLON_COLON] = ACTIONS(2341),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2341),
    [anon_sym___declspec] = ACTIONS(2339),
    [anon_sym___based] = ACTIONS(2339),
    [anon_sym___cdecl] = ACTIONS(2339),
    [anon_sym___clrcall] = ACTIONS(2339),
    [anon_sym___stdcall] = ACTIONS(2339),
    [anon_sym___fastcall] = ACTIONS(2339),
    [anon_sym___thiscall] = ACTIONS(2339),
    [anon_sym___vectorcall] = ACTIONS(2339),
    [anon_sym_LBRACE] = ACTIONS(2341),
    [anon_sym_signed] = ACTIONS(2339),
    [anon_sym_unsigned] = ACTIONS(2339),
    [anon_sym_long] = ACTIONS(2339),
    [anon_sym_short] = ACTIONS(2339),
    [anon_sym_LBRACK] = ACTIONS(2339),
    [anon_sym_static] = ACTIONS(2339),
    [anon_sym_register] = ACTIONS(2339),
    [anon_sym_inline] = ACTIONS(2339),
    [anon_sym___inline] = ACTIONS(2339),
    [anon_sym___inline__] = ACTIONS(2339),
    [anon_sym___forceinline] = ACTIONS(2339),
    [anon_sym_thread_local] = ACTIONS(2339),
    [anon_sym___thread] = ACTIONS(2339),
    [anon_sym_const] = ACTIONS(2339),
    [anon_sym_constexpr] = ACTIONS(2339),
    [anon_sym_volatile] = ACTIONS(2339),
    [anon_sym_restrict] = ACTIONS(2339),
    [anon_sym___restrict__] = ACTIONS(2339),
    [anon_sym__Atomic] = ACTIONS(2339),
    [anon_sym__Noreturn] = ACTIONS(2339),
    [anon_sym_noreturn] = ACTIONS(2339),
    [anon_sym__Nonnull] = ACTIONS(2339),
    [anon_sym_mutable] = ACTIONS(2339),
    [anon_sym_constinit] = ACTIONS(2339),
    [anon_sym_consteval] = ACTIONS(2339),
    [anon_sym___shared__] = ACTIONS(2339),
    [anon_sym___local__] = ACTIONS(2339),
    [anon_sym___constant__] = ACTIONS(2339),
    [anon_sym___managed__] = ACTIONS(2339),
    [anon_sym___grid_constant__] = ACTIONS(2339),
    [anon_sym_alignas] = ACTIONS(2339),
    [anon_sym__Alignas] = ACTIONS(2339),
    [sym_primitive_type] = ACTIONS(2339),
    [anon_sym_enum] = ACTIONS(2339),
    [anon_sym_class] = ACTIONS(2339),
    [anon_sym_struct] = ACTIONS(2339),
    [anon_sym_union] = ACTIONS(2339),
    [anon_sym_if] = ACTIONS(2339),
    [anon_sym_switch] = ACTIONS(2339),
    [anon_sym_case] = ACTIONS(2339),
    [anon_sym_default] = ACTIONS(2339),
    [anon_sym_while] = ACTIONS(2339),
    [anon_sym_do] = ACTIONS(2339),
    [anon_sym_for] = ACTIONS(2339),
    [anon_sym_return] = ACTIONS(2339),
    [anon_sym_break] = ACTIONS(2339),
    [anon_sym_continue] = ACTIONS(2339),
    [anon_sym_goto] = ACTIONS(2339),
    [anon_sym_not] = ACTIONS(2339),
    [anon_sym_compl] = ACTIONS(2339),
    [anon_sym_DASH_DASH] = ACTIONS(2341),
    [anon_sym_PLUS_PLUS] = ACTIONS(2341),
    [anon_sym_sizeof] = ACTIONS(2339),
    [anon_sym___alignof__] = ACTIONS(2339),
    [anon_sym___alignof] = ACTIONS(2339),
    [anon_sym__alignof] = ACTIONS(2339),
    [anon_sym_alignof] = ACTIONS(2339),
    [anon_sym__Alignof] = ACTIONS(2339),
    [anon_sym_offsetof] = ACTIONS(2339),
    [anon_sym__Generic] = ACTIONS(2339),
    [anon_sym_asm] = ACTIONS(2339),
    [anon_sym___asm__] = ACTIONS(2339),
    [anon_sym___asm] = ACTIONS(2339),
    [sym_number_literal] = ACTIONS(2341),
    [anon_sym_L_SQUOTE] = ACTIONS(2341),
    [anon_sym_u_SQUOTE] = ACTIONS(2341),
    [anon_sym_U_SQUOTE] = ACTIONS(2341),
    [anon_sym_u8_SQUOTE] = ACTIONS(2341),
    [anon_sym_SQUOTE] = ACTIONS(2341),
    [anon_sym_L_DQUOTE] = ACTIONS(2341),
    [anon_sym_u_DQUOTE] = ACTIONS(2341),
    [anon_sym_U_DQUOTE] = ACTIONS(2341),
    [anon_sym_u8_DQUOTE] = ACTIONS(2341),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_true] = ACTIONS(2339),
    [sym_false] = ACTIONS(2339),
    [anon_sym_NULL] = ACTIONS(2339),
    [anon_sym_nullptr] = ACTIONS(2339),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2339),
    [anon_sym_decltype] = ACTIONS(2339),
    [anon_sym_explicit] = ACTIONS(2339),
    [anon_sym_typename] = ACTIONS(2339),
    [anon_sym_template] = ACTIONS(2339),
    [anon_sym_operator] = ACTIONS(2339),
    [anon_sym_try] = ACTIONS(2339),
    [anon_sym_delete] = ACTIONS(2339),
    [anon_sym_throw] = ACTIONS(2339),
    [anon_sym_namespace] = ACTIONS(2339),
    [anon_sym_using] = ACTIONS(2339),
    [anon_sym_static_assert] = ACTIONS(2339),
    [anon_sym_concept] = ACTIONS(2339),
    [anon_sym_co_return] = ACTIONS(2339),
    [anon_sym_co_yield] = ACTIONS(2339),
    [anon_sym_R_DQUOTE] = ACTIONS(2341),
    [anon_sym_LR_DQUOTE] = ACTIONS(2341),
    [anon_sym_uR_DQUOTE] = ACTIONS(2341),
    [anon_sym_UR_DQUOTE] = ACTIONS(2341),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2341),
    [anon_sym_co_await] = ACTIONS(2339),
    [anon_sym_new] = ACTIONS(2339),
    [anon_sym_requires] = ACTIONS(2339),
    [sym_this] = ACTIONS(2339),
    [anon_sym___launch_bounds__] = ACTIONS(2339),
  },
  [STATE(732)] = {
    [ts_builtin_sym_end] = ACTIONS(2345),
    [sym_identifier] = ACTIONS(2343),
    [aux_sym_preproc_include_token1] = ACTIONS(2343),
    [aux_sym_preproc_def_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2343),
    [sym_preproc_directive] = ACTIONS(2343),
    [anon_sym_LPAREN2] = ACTIONS(2345),
    [anon_sym_BANG] = ACTIONS(2345),
    [anon_sym_TILDE] = ACTIONS(2345),
    [anon_sym_DASH] = ACTIONS(2343),
    [anon_sym_PLUS] = ACTIONS(2343),
    [anon_sym_STAR] = ACTIONS(2345),
    [anon_sym_AMP_AMP] = ACTIONS(2345),
    [anon_sym_AMP] = ACTIONS(2343),
    [anon_sym_SEMI] = ACTIONS(2345),
    [anon_sym___extension__] = ACTIONS(2343),
    [anon_sym_typedef] = ACTIONS(2343),
    [anon_sym___device__] = ACTIONS(2343),
    [anon_sym___host__] = ACTIONS(2343),
    [anon_sym___global__] = ACTIONS(2343),
    [anon_sym___forceinline__] = ACTIONS(2343),
    [anon_sym___noinline__] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2343),
    [anon_sym_extern] = ACTIONS(2343),
    [anon_sym___attribute__] = ACTIONS(2343),
    [anon_sym___attribute] = ACTIONS(2343),
    [anon_sym_COLON_COLON] = ACTIONS(2345),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2345),
    [anon_sym___declspec] = ACTIONS(2343),
    [anon_sym___based] = ACTIONS(2343),
    [anon_sym___cdecl] = ACTIONS(2343),
    [anon_sym___clrcall] = ACTIONS(2343),
    [anon_sym___stdcall] = ACTIONS(2343),
    [anon_sym___fastcall] = ACTIONS(2343),
    [anon_sym___thiscall] = ACTIONS(2343),
    [anon_sym___vectorcall] = ACTIONS(2343),
    [anon_sym_LBRACE] = ACTIONS(2345),
    [anon_sym_signed] = ACTIONS(2343),
    [anon_sym_unsigned] = ACTIONS(2343),
    [anon_sym_long] = ACTIONS(2343),
    [anon_sym_short] = ACTIONS(2343),
    [anon_sym_LBRACK] = ACTIONS(2343),
    [anon_sym_static] = ACTIONS(2343),
    [anon_sym_register] = ACTIONS(2343),
    [anon_sym_inline] = ACTIONS(2343),
    [anon_sym___inline] = ACTIONS(2343),
    [anon_sym___inline__] = ACTIONS(2343),
    [anon_sym___forceinline] = ACTIONS(2343),
    [anon_sym_thread_local] = ACTIONS(2343),
    [anon_sym___thread] = ACTIONS(2343),
    [anon_sym_const] = ACTIONS(2343),
    [anon_sym_constexpr] = ACTIONS(2343),
    [anon_sym_volatile] = ACTIONS(2343),
    [anon_sym_restrict] = ACTIONS(2343),
    [anon_sym___restrict__] = ACTIONS(2343),
    [anon_sym__Atomic] = ACTIONS(2343),
    [anon_sym__Noreturn] = ACTIONS(2343),
    [anon_sym_noreturn] = ACTIONS(2343),
    [anon_sym__Nonnull] = ACTIONS(2343),
    [anon_sym_mutable] = ACTIONS(2343),
    [anon_sym_constinit] = ACTIONS(2343),
    [anon_sym_consteval] = ACTIONS(2343),
    [anon_sym___shared__] = ACTIONS(2343),
    [anon_sym___local__] = ACTIONS(2343),
    [anon_sym___constant__] = ACTIONS(2343),
    [anon_sym___managed__] = ACTIONS(2343),
    [anon_sym___grid_constant__] = ACTIONS(2343),
    [anon_sym_alignas] = ACTIONS(2343),
    [anon_sym__Alignas] = ACTIONS(2343),
    [sym_primitive_type] = ACTIONS(2343),
    [anon_sym_enum] = ACTIONS(2343),
    [anon_sym_class] = ACTIONS(2343),
    [anon_sym_struct] = ACTIONS(2343),
    [anon_sym_union] = ACTIONS(2343),
    [anon_sym_if] = ACTIONS(2343),
    [anon_sym_switch] = ACTIONS(2343),
    [anon_sym_case] = ACTIONS(2343),
    [anon_sym_default] = ACTIONS(2343),
    [anon_sym_while] = ACTIONS(2343),
    [anon_sym_do] = ACTIONS(2343),
    [anon_sym_for] = ACTIONS(2343),
    [anon_sym_return] = ACTIONS(2343),
    [anon_sym_break] = ACTIONS(2343),
    [anon_sym_continue] = ACTIONS(2343),
    [anon_sym_goto] = ACTIONS(2343),
    [anon_sym_not] = ACTIONS(2343),
    [anon_sym_compl] = ACTIONS(2343),
    [anon_sym_DASH_DASH] = ACTIONS(2345),
    [anon_sym_PLUS_PLUS] = ACTIONS(2345),
    [anon_sym_sizeof] = ACTIONS(2343),
    [anon_sym___alignof__] = ACTIONS(2343),
    [anon_sym___alignof] = ACTIONS(2343),
    [anon_sym__alignof] = ACTIONS(2343),
    [anon_sym_alignof] = ACTIONS(2343),
    [anon_sym__Alignof] = ACTIONS(2343),
    [anon_sym_offsetof] = ACTIONS(2343),
    [anon_sym__Generic] = ACTIONS(2343),
    [anon_sym_asm] = ACTIONS(2343),
    [anon_sym___asm__] = ACTIONS(2343),
    [anon_sym___asm] = ACTIONS(2343),
    [sym_number_literal] = ACTIONS(2345),
    [anon_sym_L_SQUOTE] = ACTIONS(2345),
    [anon_sym_u_SQUOTE] = ACTIONS(2345),
    [anon_sym_U_SQUOTE] = ACTIONS(2345),
    [anon_sym_u8_SQUOTE] = ACTIONS(2345),
    [anon_sym_SQUOTE] = ACTIONS(2345),
    [anon_sym_L_DQUOTE] = ACTIONS(2345),
    [anon_sym_u_DQUOTE] = ACTIONS(2345),
    [anon_sym_U_DQUOTE] = ACTIONS(2345),
    [anon_sym_u8_DQUOTE] = ACTIONS(2345),
    [anon_sym_DQUOTE] = ACTIONS(2345),
    [sym_true] = ACTIONS(2343),
    [sym_false] = ACTIONS(2343),
    [anon_sym_NULL] = ACTIONS(2343),
    [anon_sym_nullptr] = ACTIONS(2343),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2343),
    [anon_sym_decltype] = ACTIONS(2343),
    [anon_sym_explicit] = ACTIONS(2343),
    [anon_sym_typename] = ACTIONS(2343),
    [anon_sym_template] = ACTIONS(2343),
    [anon_sym_operator] = ACTIONS(2343),
    [anon_sym_try] = ACTIONS(2343),
    [anon_sym_delete] = ACTIONS(2343),
    [anon_sym_throw] = ACTIONS(2343),
    [anon_sym_namespace] = ACTIONS(2343),
    [anon_sym_using] = ACTIONS(2343),
    [anon_sym_static_assert] = ACTIONS(2343),
    [anon_sym_concept] = ACTIONS(2343),
    [anon_sym_co_return] = ACTIONS(2343),
    [anon_sym_co_yield] = ACTIONS(2343),
    [anon_sym_R_DQUOTE] = ACTIONS(2345),
    [anon_sym_LR_DQUOTE] = ACTIONS(2345),
    [anon_sym_uR_DQUOTE] = ACTIONS(2345),
    [anon_sym_UR_DQUOTE] = ACTIONS(2345),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2345),
    [anon_sym_co_await] = ACTIONS(2343),
    [anon_sym_new] = ACTIONS(2343),
    [anon_sym_requires] = ACTIONS(2343),
    [sym_this] = ACTIONS(2343),
    [anon_sym___launch_bounds__] = ACTIONS(2343),
  },
  [STATE(733)] = {
    [ts_builtin_sym_end] = ACTIONS(2349),
    [sym_identifier] = ACTIONS(2347),
    [aux_sym_preproc_include_token1] = ACTIONS(2347),
    [aux_sym_preproc_def_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2347),
    [sym_preproc_directive] = ACTIONS(2347),
    [anon_sym_LPAREN2] = ACTIONS(2349),
    [anon_sym_BANG] = ACTIONS(2349),
    [anon_sym_TILDE] = ACTIONS(2349),
    [anon_sym_DASH] = ACTIONS(2347),
    [anon_sym_PLUS] = ACTIONS(2347),
    [anon_sym_STAR] = ACTIONS(2349),
    [anon_sym_AMP_AMP] = ACTIONS(2349),
    [anon_sym_AMP] = ACTIONS(2347),
    [anon_sym_SEMI] = ACTIONS(2349),
    [anon_sym___extension__] = ACTIONS(2347),
    [anon_sym_typedef] = ACTIONS(2347),
    [anon_sym___device__] = ACTIONS(2347),
    [anon_sym___host__] = ACTIONS(2347),
    [anon_sym___global__] = ACTIONS(2347),
    [anon_sym___forceinline__] = ACTIONS(2347),
    [anon_sym___noinline__] = ACTIONS(2347),
    [anon_sym_virtual] = ACTIONS(2347),
    [anon_sym_extern] = ACTIONS(2347),
    [anon_sym___attribute__] = ACTIONS(2347),
    [anon_sym___attribute] = ACTIONS(2347),
    [anon_sym_COLON_COLON] = ACTIONS(2349),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2349),
    [anon_sym___declspec] = ACTIONS(2347),
    [anon_sym___based] = ACTIONS(2347),
    [anon_sym___cdecl] = ACTIONS(2347),
    [anon_sym___clrcall] = ACTIONS(2347),
    [anon_sym___stdcall] = ACTIONS(2347),
    [anon_sym___fastcall] = ACTIONS(2347),
    [anon_sym___thiscall] = ACTIONS(2347),
    [anon_sym___vectorcall] = ACTIONS(2347),
    [anon_sym_LBRACE] = ACTIONS(2349),
    [anon_sym_signed] = ACTIONS(2347),
    [anon_sym_unsigned] = ACTIONS(2347),
    [anon_sym_long] = ACTIONS(2347),
    [anon_sym_short] = ACTIONS(2347),
    [anon_sym_LBRACK] = ACTIONS(2347),
    [anon_sym_static] = ACTIONS(2347),
    [anon_sym_register] = ACTIONS(2347),
    [anon_sym_inline] = ACTIONS(2347),
    [anon_sym___inline] = ACTIONS(2347),
    [anon_sym___inline__] = ACTIONS(2347),
    [anon_sym___forceinline] = ACTIONS(2347),
    [anon_sym_thread_local] = ACTIONS(2347),
    [anon_sym___thread] = ACTIONS(2347),
    [anon_sym_const] = ACTIONS(2347),
    [anon_sym_constexpr] = ACTIONS(2347),
    [anon_sym_volatile] = ACTIONS(2347),
    [anon_sym_restrict] = ACTIONS(2347),
    [anon_sym___restrict__] = ACTIONS(2347),
    [anon_sym__Atomic] = ACTIONS(2347),
    [anon_sym__Noreturn] = ACTIONS(2347),
    [anon_sym_noreturn] = ACTIONS(2347),
    [anon_sym__Nonnull] = ACTIONS(2347),
    [anon_sym_mutable] = ACTIONS(2347),
    [anon_sym_constinit] = ACTIONS(2347),
    [anon_sym_consteval] = ACTIONS(2347),
    [anon_sym___shared__] = ACTIONS(2347),
    [anon_sym___local__] = ACTIONS(2347),
    [anon_sym___constant__] = ACTIONS(2347),
    [anon_sym___managed__] = ACTIONS(2347),
    [anon_sym___grid_constant__] = ACTIONS(2347),
    [anon_sym_alignas] = ACTIONS(2347),
    [anon_sym__Alignas] = ACTIONS(2347),
    [sym_primitive_type] = ACTIONS(2347),
    [anon_sym_enum] = ACTIONS(2347),
    [anon_sym_class] = ACTIONS(2347),
    [anon_sym_struct] = ACTIONS(2347),
    [anon_sym_union] = ACTIONS(2347),
    [anon_sym_if] = ACTIONS(2347),
    [anon_sym_switch] = ACTIONS(2347),
    [anon_sym_case] = ACTIONS(2347),
    [anon_sym_default] = ACTIONS(2347),
    [anon_sym_while] = ACTIONS(2347),
    [anon_sym_do] = ACTIONS(2347),
    [anon_sym_for] = ACTIONS(2347),
    [anon_sym_return] = ACTIONS(2347),
    [anon_sym_break] = ACTIONS(2347),
    [anon_sym_continue] = ACTIONS(2347),
    [anon_sym_goto] = ACTIONS(2347),
    [anon_sym_not] = ACTIONS(2347),
    [anon_sym_compl] = ACTIONS(2347),
    [anon_sym_DASH_DASH] = ACTIONS(2349),
    [anon_sym_PLUS_PLUS] = ACTIONS(2349),
    [anon_sym_sizeof] = ACTIONS(2347),
    [anon_sym___alignof__] = ACTIONS(2347),
    [anon_sym___alignof] = ACTIONS(2347),
    [anon_sym__alignof] = ACTIONS(2347),
    [anon_sym_alignof] = ACTIONS(2347),
    [anon_sym__Alignof] = ACTIONS(2347),
    [anon_sym_offsetof] = ACTIONS(2347),
    [anon_sym__Generic] = ACTIONS(2347),
    [anon_sym_asm] = ACTIONS(2347),
    [anon_sym___asm__] = ACTIONS(2347),
    [anon_sym___asm] = ACTIONS(2347),
    [sym_number_literal] = ACTIONS(2349),
    [anon_sym_L_SQUOTE] = ACTIONS(2349),
    [anon_sym_u_SQUOTE] = ACTIONS(2349),
    [anon_sym_U_SQUOTE] = ACTIONS(2349),
    [anon_sym_u8_SQUOTE] = ACTIONS(2349),
    [anon_sym_SQUOTE] = ACTIONS(2349),
    [anon_sym_L_DQUOTE] = ACTIONS(2349),
    [anon_sym_u_DQUOTE] = ACTIONS(2349),
    [anon_sym_U_DQUOTE] = ACTIONS(2349),
    [anon_sym_u8_DQUOTE] = ACTIONS(2349),
    [anon_sym_DQUOTE] = ACTIONS(2349),
    [sym_true] = ACTIONS(2347),
    [sym_false] = ACTIONS(2347),
    [anon_sym_NULL] = ACTIONS(2347),
    [anon_sym_nullptr] = ACTIONS(2347),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2347),
    [anon_sym_decltype] = ACTIONS(2347),
    [anon_sym_explicit] = ACTIONS(2347),
    [anon_sym_typename] = ACTIONS(2347),
    [anon_sym_template] = ACTIONS(2347),
    [anon_sym_operator] = ACTIONS(2347),
    [anon_sym_try] = ACTIONS(2347),
    [anon_sym_delete] = ACTIONS(2347),
    [anon_sym_throw] = ACTIONS(2347),
    [anon_sym_namespace] = ACTIONS(2347),
    [anon_sym_using] = ACTIONS(2347),
    [anon_sym_static_assert] = ACTIONS(2347),
    [anon_sym_concept] = ACTIONS(2347),
    [anon_sym_co_return] = ACTIONS(2347),
    [anon_sym_co_yield] = ACTIONS(2347),
    [anon_sym_R_DQUOTE] = ACTIONS(2349),
    [anon_sym_LR_DQUOTE] = ACTIONS(2349),
    [anon_sym_uR_DQUOTE] = ACTIONS(2349),
    [anon_sym_UR_DQUOTE] = ACTIONS(2349),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2349),
    [anon_sym_co_await] = ACTIONS(2347),
    [anon_sym_new] = ACTIONS(2347),
    [anon_sym_requires] = ACTIONS(2347),
    [sym_this] = ACTIONS(2347),
    [anon_sym___launch_bounds__] = ACTIONS(2347),
  },
  [STATE(734)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5258),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(9556),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(735)] = {
    [ts_builtin_sym_end] = ACTIONS(2353),
    [sym_identifier] = ACTIONS(2351),
    [aux_sym_preproc_include_token1] = ACTIONS(2351),
    [aux_sym_preproc_def_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2351),
    [sym_preproc_directive] = ACTIONS(2351),
    [anon_sym_LPAREN2] = ACTIONS(2353),
    [anon_sym_BANG] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(2353),
    [anon_sym_DASH] = ACTIONS(2351),
    [anon_sym_PLUS] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2353),
    [anon_sym_AMP_AMP] = ACTIONS(2353),
    [anon_sym_AMP] = ACTIONS(2351),
    [anon_sym_SEMI] = ACTIONS(2353),
    [anon_sym___extension__] = ACTIONS(2351),
    [anon_sym_typedef] = ACTIONS(2351),
    [anon_sym___device__] = ACTIONS(2351),
    [anon_sym___host__] = ACTIONS(2351),
    [anon_sym___global__] = ACTIONS(2351),
    [anon_sym___forceinline__] = ACTIONS(2351),
    [anon_sym___noinline__] = ACTIONS(2351),
    [anon_sym_virtual] = ACTIONS(2351),
    [anon_sym_extern] = ACTIONS(2351),
    [anon_sym___attribute__] = ACTIONS(2351),
    [anon_sym___attribute] = ACTIONS(2351),
    [anon_sym_COLON_COLON] = ACTIONS(2353),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2353),
    [anon_sym___declspec] = ACTIONS(2351),
    [anon_sym___based] = ACTIONS(2351),
    [anon_sym___cdecl] = ACTIONS(2351),
    [anon_sym___clrcall] = ACTIONS(2351),
    [anon_sym___stdcall] = ACTIONS(2351),
    [anon_sym___fastcall] = ACTIONS(2351),
    [anon_sym___thiscall] = ACTIONS(2351),
    [anon_sym___vectorcall] = ACTIONS(2351),
    [anon_sym_LBRACE] = ACTIONS(2353),
    [anon_sym_signed] = ACTIONS(2351),
    [anon_sym_unsigned] = ACTIONS(2351),
    [anon_sym_long] = ACTIONS(2351),
    [anon_sym_short] = ACTIONS(2351),
    [anon_sym_LBRACK] = ACTIONS(2351),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_register] = ACTIONS(2351),
    [anon_sym_inline] = ACTIONS(2351),
    [anon_sym___inline] = ACTIONS(2351),
    [anon_sym___inline__] = ACTIONS(2351),
    [anon_sym___forceinline] = ACTIONS(2351),
    [anon_sym_thread_local] = ACTIONS(2351),
    [anon_sym___thread] = ACTIONS(2351),
    [anon_sym_const] = ACTIONS(2351),
    [anon_sym_constexpr] = ACTIONS(2351),
    [anon_sym_volatile] = ACTIONS(2351),
    [anon_sym_restrict] = ACTIONS(2351),
    [anon_sym___restrict__] = ACTIONS(2351),
    [anon_sym__Atomic] = ACTIONS(2351),
    [anon_sym__Noreturn] = ACTIONS(2351),
    [anon_sym_noreturn] = ACTIONS(2351),
    [anon_sym__Nonnull] = ACTIONS(2351),
    [anon_sym_mutable] = ACTIONS(2351),
    [anon_sym_constinit] = ACTIONS(2351),
    [anon_sym_consteval] = ACTIONS(2351),
    [anon_sym___shared__] = ACTIONS(2351),
    [anon_sym___local__] = ACTIONS(2351),
    [anon_sym___constant__] = ACTIONS(2351),
    [anon_sym___managed__] = ACTIONS(2351),
    [anon_sym___grid_constant__] = ACTIONS(2351),
    [anon_sym_alignas] = ACTIONS(2351),
    [anon_sym__Alignas] = ACTIONS(2351),
    [sym_primitive_type] = ACTIONS(2351),
    [anon_sym_enum] = ACTIONS(2351),
    [anon_sym_class] = ACTIONS(2351),
    [anon_sym_struct] = ACTIONS(2351),
    [anon_sym_union] = ACTIONS(2351),
    [anon_sym_if] = ACTIONS(2351),
    [anon_sym_switch] = ACTIONS(2351),
    [anon_sym_case] = ACTIONS(2351),
    [anon_sym_default] = ACTIONS(2351),
    [anon_sym_while] = ACTIONS(2351),
    [anon_sym_do] = ACTIONS(2351),
    [anon_sym_for] = ACTIONS(2351),
    [anon_sym_return] = ACTIONS(2351),
    [anon_sym_break] = ACTIONS(2351),
    [anon_sym_continue] = ACTIONS(2351),
    [anon_sym_goto] = ACTIONS(2351),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_compl] = ACTIONS(2351),
    [anon_sym_DASH_DASH] = ACTIONS(2353),
    [anon_sym_PLUS_PLUS] = ACTIONS(2353),
    [anon_sym_sizeof] = ACTIONS(2351),
    [anon_sym___alignof__] = ACTIONS(2351),
    [anon_sym___alignof] = ACTIONS(2351),
    [anon_sym__alignof] = ACTIONS(2351),
    [anon_sym_alignof] = ACTIONS(2351),
    [anon_sym__Alignof] = ACTIONS(2351),
    [anon_sym_offsetof] = ACTIONS(2351),
    [anon_sym__Generic] = ACTIONS(2351),
    [anon_sym_asm] = ACTIONS(2351),
    [anon_sym___asm__] = ACTIONS(2351),
    [anon_sym___asm] = ACTIONS(2351),
    [sym_number_literal] = ACTIONS(2353),
    [anon_sym_L_SQUOTE] = ACTIONS(2353),
    [anon_sym_u_SQUOTE] = ACTIONS(2353),
    [anon_sym_U_SQUOTE] = ACTIONS(2353),
    [anon_sym_u8_SQUOTE] = ACTIONS(2353),
    [anon_sym_SQUOTE] = ACTIONS(2353),
    [anon_sym_L_DQUOTE] = ACTIONS(2353),
    [anon_sym_u_DQUOTE] = ACTIONS(2353),
    [anon_sym_U_DQUOTE] = ACTIONS(2353),
    [anon_sym_u8_DQUOTE] = ACTIONS(2353),
    [anon_sym_DQUOTE] = ACTIONS(2353),
    [sym_true] = ACTIONS(2351),
    [sym_false] = ACTIONS(2351),
    [anon_sym_NULL] = ACTIONS(2351),
    [anon_sym_nullptr] = ACTIONS(2351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2351),
    [anon_sym_decltype] = ACTIONS(2351),
    [anon_sym_explicit] = ACTIONS(2351),
    [anon_sym_typename] = ACTIONS(2351),
    [anon_sym_template] = ACTIONS(2351),
    [anon_sym_operator] = ACTIONS(2351),
    [anon_sym_try] = ACTIONS(2351),
    [anon_sym_delete] = ACTIONS(2351),
    [anon_sym_throw] = ACTIONS(2351),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_using] = ACTIONS(2351),
    [anon_sym_static_assert] = ACTIONS(2351),
    [anon_sym_concept] = ACTIONS(2351),
    [anon_sym_co_return] = ACTIONS(2351),
    [anon_sym_co_yield] = ACTIONS(2351),
    [anon_sym_R_DQUOTE] = ACTIONS(2353),
    [anon_sym_LR_DQUOTE] = ACTIONS(2353),
    [anon_sym_uR_DQUOTE] = ACTIONS(2353),
    [anon_sym_UR_DQUOTE] = ACTIONS(2353),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2353),
    [anon_sym_co_await] = ACTIONS(2351),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_requires] = ACTIONS(2351),
    [sym_this] = ACTIONS(2351),
    [anon_sym___launch_bounds__] = ACTIONS(2351),
  },
  [STATE(736)] = {
    [ts_builtin_sym_end] = ACTIONS(2375),
    [sym_identifier] = ACTIONS(2373),
    [aux_sym_preproc_include_token1] = ACTIONS(2373),
    [aux_sym_preproc_def_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2373),
    [sym_preproc_directive] = ACTIONS(2373),
    [anon_sym_LPAREN2] = ACTIONS(2375),
    [anon_sym_BANG] = ACTIONS(2375),
    [anon_sym_TILDE] = ACTIONS(2375),
    [anon_sym_DASH] = ACTIONS(2373),
    [anon_sym_PLUS] = ACTIONS(2373),
    [anon_sym_STAR] = ACTIONS(2375),
    [anon_sym_AMP_AMP] = ACTIONS(2375),
    [anon_sym_AMP] = ACTIONS(2373),
    [anon_sym_SEMI] = ACTIONS(2375),
    [anon_sym___extension__] = ACTIONS(2373),
    [anon_sym_typedef] = ACTIONS(2373),
    [anon_sym___device__] = ACTIONS(2373),
    [anon_sym___host__] = ACTIONS(2373),
    [anon_sym___global__] = ACTIONS(2373),
    [anon_sym___forceinline__] = ACTIONS(2373),
    [anon_sym___noinline__] = ACTIONS(2373),
    [anon_sym_virtual] = ACTIONS(2373),
    [anon_sym_extern] = ACTIONS(2373),
    [anon_sym___attribute__] = ACTIONS(2373),
    [anon_sym___attribute] = ACTIONS(2373),
    [anon_sym_COLON_COLON] = ACTIONS(2375),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2375),
    [anon_sym___declspec] = ACTIONS(2373),
    [anon_sym___based] = ACTIONS(2373),
    [anon_sym___cdecl] = ACTIONS(2373),
    [anon_sym___clrcall] = ACTIONS(2373),
    [anon_sym___stdcall] = ACTIONS(2373),
    [anon_sym___fastcall] = ACTIONS(2373),
    [anon_sym___thiscall] = ACTIONS(2373),
    [anon_sym___vectorcall] = ACTIONS(2373),
    [anon_sym_LBRACE] = ACTIONS(2375),
    [anon_sym_signed] = ACTIONS(2373),
    [anon_sym_unsigned] = ACTIONS(2373),
    [anon_sym_long] = ACTIONS(2373),
    [anon_sym_short] = ACTIONS(2373),
    [anon_sym_LBRACK] = ACTIONS(2373),
    [anon_sym_static] = ACTIONS(2373),
    [anon_sym_register] = ACTIONS(2373),
    [anon_sym_inline] = ACTIONS(2373),
    [anon_sym___inline] = ACTIONS(2373),
    [anon_sym___inline__] = ACTIONS(2373),
    [anon_sym___forceinline] = ACTIONS(2373),
    [anon_sym_thread_local] = ACTIONS(2373),
    [anon_sym___thread] = ACTIONS(2373),
    [anon_sym_const] = ACTIONS(2373),
    [anon_sym_constexpr] = ACTIONS(2373),
    [anon_sym_volatile] = ACTIONS(2373),
    [anon_sym_restrict] = ACTIONS(2373),
    [anon_sym___restrict__] = ACTIONS(2373),
    [anon_sym__Atomic] = ACTIONS(2373),
    [anon_sym__Noreturn] = ACTIONS(2373),
    [anon_sym_noreturn] = ACTIONS(2373),
    [anon_sym__Nonnull] = ACTIONS(2373),
    [anon_sym_mutable] = ACTIONS(2373),
    [anon_sym_constinit] = ACTIONS(2373),
    [anon_sym_consteval] = ACTIONS(2373),
    [anon_sym___shared__] = ACTIONS(2373),
    [anon_sym___local__] = ACTIONS(2373),
    [anon_sym___constant__] = ACTIONS(2373),
    [anon_sym___managed__] = ACTIONS(2373),
    [anon_sym___grid_constant__] = ACTIONS(2373),
    [anon_sym_alignas] = ACTIONS(2373),
    [anon_sym__Alignas] = ACTIONS(2373),
    [sym_primitive_type] = ACTIONS(2373),
    [anon_sym_enum] = ACTIONS(2373),
    [anon_sym_class] = ACTIONS(2373),
    [anon_sym_struct] = ACTIONS(2373),
    [anon_sym_union] = ACTIONS(2373),
    [anon_sym_if] = ACTIONS(2373),
    [anon_sym_switch] = ACTIONS(2373),
    [anon_sym_case] = ACTIONS(2373),
    [anon_sym_default] = ACTIONS(2373),
    [anon_sym_while] = ACTIONS(2373),
    [anon_sym_do] = ACTIONS(2373),
    [anon_sym_for] = ACTIONS(2373),
    [anon_sym_return] = ACTIONS(2373),
    [anon_sym_break] = ACTIONS(2373),
    [anon_sym_continue] = ACTIONS(2373),
    [anon_sym_goto] = ACTIONS(2373),
    [anon_sym_not] = ACTIONS(2373),
    [anon_sym_compl] = ACTIONS(2373),
    [anon_sym_DASH_DASH] = ACTIONS(2375),
    [anon_sym_PLUS_PLUS] = ACTIONS(2375),
    [anon_sym_sizeof] = ACTIONS(2373),
    [anon_sym___alignof__] = ACTIONS(2373),
    [anon_sym___alignof] = ACTIONS(2373),
    [anon_sym__alignof] = ACTIONS(2373),
    [anon_sym_alignof] = ACTIONS(2373),
    [anon_sym__Alignof] = ACTIONS(2373),
    [anon_sym_offsetof] = ACTIONS(2373),
    [anon_sym__Generic] = ACTIONS(2373),
    [anon_sym_asm] = ACTIONS(2373),
    [anon_sym___asm__] = ACTIONS(2373),
    [anon_sym___asm] = ACTIONS(2373),
    [sym_number_literal] = ACTIONS(2375),
    [anon_sym_L_SQUOTE] = ACTIONS(2375),
    [anon_sym_u_SQUOTE] = ACTIONS(2375),
    [anon_sym_U_SQUOTE] = ACTIONS(2375),
    [anon_sym_u8_SQUOTE] = ACTIONS(2375),
    [anon_sym_SQUOTE] = ACTIONS(2375),
    [anon_sym_L_DQUOTE] = ACTIONS(2375),
    [anon_sym_u_DQUOTE] = ACTIONS(2375),
    [anon_sym_U_DQUOTE] = ACTIONS(2375),
    [anon_sym_u8_DQUOTE] = ACTIONS(2375),
    [anon_sym_DQUOTE] = ACTIONS(2375),
    [sym_true] = ACTIONS(2373),
    [sym_false] = ACTIONS(2373),
    [anon_sym_NULL] = ACTIONS(2373),
    [anon_sym_nullptr] = ACTIONS(2373),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2373),
    [anon_sym_decltype] = ACTIONS(2373),
    [anon_sym_explicit] = ACTIONS(2373),
    [anon_sym_typename] = ACTIONS(2373),
    [anon_sym_template] = ACTIONS(2373),
    [anon_sym_operator] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2373),
    [anon_sym_delete] = ACTIONS(2373),
    [anon_sym_throw] = ACTIONS(2373),
    [anon_sym_namespace] = ACTIONS(2373),
    [anon_sym_using] = ACTIONS(2373),
    [anon_sym_static_assert] = ACTIONS(2373),
    [anon_sym_concept] = ACTIONS(2373),
    [anon_sym_co_return] = ACTIONS(2373),
    [anon_sym_co_yield] = ACTIONS(2373),
    [anon_sym_R_DQUOTE] = ACTIONS(2375),
    [anon_sym_LR_DQUOTE] = ACTIONS(2375),
    [anon_sym_uR_DQUOTE] = ACTIONS(2375),
    [anon_sym_UR_DQUOTE] = ACTIONS(2375),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2375),
    [anon_sym_co_await] = ACTIONS(2373),
    [anon_sym_new] = ACTIONS(2373),
    [anon_sym_requires] = ACTIONS(2373),
    [sym_this] = ACTIONS(2373),
    [anon_sym___launch_bounds__] = ACTIONS(2373),
  },
  [STATE(737)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5263),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(9076),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(738)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5257),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(9109),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(739)] = {
    [ts_builtin_sym_end] = ACTIONS(3518),
    [sym_identifier] = ACTIONS(3520),
    [aux_sym_preproc_include_token1] = ACTIONS(3520),
    [aux_sym_preproc_def_token1] = ACTIONS(3520),
    [aux_sym_preproc_if_token1] = ACTIONS(3520),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3520),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3520),
    [sym_preproc_directive] = ACTIONS(3520),
    [anon_sym_LPAREN2] = ACTIONS(3518),
    [anon_sym_BANG] = ACTIONS(3518),
    [anon_sym_TILDE] = ACTIONS(3518),
    [anon_sym_DASH] = ACTIONS(3520),
    [anon_sym_PLUS] = ACTIONS(3520),
    [anon_sym_STAR] = ACTIONS(3518),
    [anon_sym_AMP_AMP] = ACTIONS(3518),
    [anon_sym_AMP] = ACTIONS(3520),
    [anon_sym_SEMI] = ACTIONS(3518),
    [anon_sym___extension__] = ACTIONS(3520),
    [anon_sym_typedef] = ACTIONS(3520),
    [anon_sym___device__] = ACTIONS(3520),
    [anon_sym___host__] = ACTIONS(3520),
    [anon_sym___global__] = ACTIONS(3520),
    [anon_sym___forceinline__] = ACTIONS(3520),
    [anon_sym___noinline__] = ACTIONS(3520),
    [anon_sym_virtual] = ACTIONS(3520),
    [anon_sym_extern] = ACTIONS(3520),
    [anon_sym___attribute__] = ACTIONS(3520),
    [anon_sym___attribute] = ACTIONS(3520),
    [anon_sym_COLON_COLON] = ACTIONS(3518),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3518),
    [anon_sym___declspec] = ACTIONS(3520),
    [anon_sym___based] = ACTIONS(3520),
    [anon_sym___cdecl] = ACTIONS(3520),
    [anon_sym___clrcall] = ACTIONS(3520),
    [anon_sym___stdcall] = ACTIONS(3520),
    [anon_sym___fastcall] = ACTIONS(3520),
    [anon_sym___thiscall] = ACTIONS(3520),
    [anon_sym___vectorcall] = ACTIONS(3520),
    [anon_sym_LBRACE] = ACTIONS(3518),
    [anon_sym_signed] = ACTIONS(3520),
    [anon_sym_unsigned] = ACTIONS(3520),
    [anon_sym_long] = ACTIONS(3520),
    [anon_sym_short] = ACTIONS(3520),
    [anon_sym_LBRACK] = ACTIONS(3520),
    [anon_sym_static] = ACTIONS(3520),
    [anon_sym_register] = ACTIONS(3520),
    [anon_sym_inline] = ACTIONS(3520),
    [anon_sym___inline] = ACTIONS(3520),
    [anon_sym___inline__] = ACTIONS(3520),
    [anon_sym___forceinline] = ACTIONS(3520),
    [anon_sym_thread_local] = ACTIONS(3520),
    [anon_sym___thread] = ACTIONS(3520),
    [anon_sym_const] = ACTIONS(3520),
    [anon_sym_constexpr] = ACTIONS(3520),
    [anon_sym_volatile] = ACTIONS(3520),
    [anon_sym_restrict] = ACTIONS(3520),
    [anon_sym___restrict__] = ACTIONS(3520),
    [anon_sym__Atomic] = ACTIONS(3520),
    [anon_sym__Noreturn] = ACTIONS(3520),
    [anon_sym_noreturn] = ACTIONS(3520),
    [anon_sym__Nonnull] = ACTIONS(3520),
    [anon_sym_mutable] = ACTIONS(3520),
    [anon_sym_constinit] = ACTIONS(3520),
    [anon_sym_consteval] = ACTIONS(3520),
    [anon_sym___shared__] = ACTIONS(3520),
    [anon_sym___local__] = ACTIONS(3520),
    [anon_sym___constant__] = ACTIONS(3520),
    [anon_sym___managed__] = ACTIONS(3520),
    [anon_sym___grid_constant__] = ACTIONS(3520),
    [anon_sym_alignas] = ACTIONS(3520),
    [anon_sym__Alignas] = ACTIONS(3520),
    [sym_primitive_type] = ACTIONS(3520),
    [anon_sym_enum] = ACTIONS(3520),
    [anon_sym_class] = ACTIONS(3520),
    [anon_sym_struct] = ACTIONS(3520),
    [anon_sym_union] = ACTIONS(3520),
    [anon_sym_if] = ACTIONS(3520),
    [anon_sym_switch] = ACTIONS(3520),
    [anon_sym_case] = ACTIONS(3520),
    [anon_sym_default] = ACTIONS(3520),
    [anon_sym_while] = ACTIONS(3520),
    [anon_sym_do] = ACTIONS(3520),
    [anon_sym_for] = ACTIONS(3520),
    [anon_sym_return] = ACTIONS(3520),
    [anon_sym_break] = ACTIONS(3520),
    [anon_sym_continue] = ACTIONS(3520),
    [anon_sym_goto] = ACTIONS(3520),
    [anon_sym_not] = ACTIONS(3520),
    [anon_sym_compl] = ACTIONS(3520),
    [anon_sym_DASH_DASH] = ACTIONS(3518),
    [anon_sym_PLUS_PLUS] = ACTIONS(3518),
    [anon_sym_sizeof] = ACTIONS(3520),
    [anon_sym___alignof__] = ACTIONS(3520),
    [anon_sym___alignof] = ACTIONS(3520),
    [anon_sym__alignof] = ACTIONS(3520),
    [anon_sym_alignof] = ACTIONS(3520),
    [anon_sym__Alignof] = ACTIONS(3520),
    [anon_sym_offsetof] = ACTIONS(3520),
    [anon_sym__Generic] = ACTIONS(3520),
    [anon_sym_asm] = ACTIONS(3520),
    [anon_sym___asm__] = ACTIONS(3520),
    [anon_sym___asm] = ACTIONS(3520),
    [sym_number_literal] = ACTIONS(3518),
    [anon_sym_L_SQUOTE] = ACTIONS(3518),
    [anon_sym_u_SQUOTE] = ACTIONS(3518),
    [anon_sym_U_SQUOTE] = ACTIONS(3518),
    [anon_sym_u8_SQUOTE] = ACTIONS(3518),
    [anon_sym_SQUOTE] = ACTIONS(3518),
    [anon_sym_L_DQUOTE] = ACTIONS(3518),
    [anon_sym_u_DQUOTE] = ACTIONS(3518),
    [anon_sym_U_DQUOTE] = ACTIONS(3518),
    [anon_sym_u8_DQUOTE] = ACTIONS(3518),
    [anon_sym_DQUOTE] = ACTIONS(3518),
    [sym_true] = ACTIONS(3520),
    [sym_false] = ACTIONS(3520),
    [anon_sym_NULL] = ACTIONS(3520),
    [anon_sym_nullptr] = ACTIONS(3520),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3520),
    [anon_sym_decltype] = ACTIONS(3520),
    [anon_sym_explicit] = ACTIONS(3520),
    [anon_sym_typename] = ACTIONS(3520),
    [anon_sym_template] = ACTIONS(3520),
    [anon_sym_operator] = ACTIONS(3520),
    [anon_sym_try] = ACTIONS(3520),
    [anon_sym_delete] = ACTIONS(3520),
    [anon_sym_throw] = ACTIONS(3520),
    [anon_sym_namespace] = ACTIONS(3520),
    [anon_sym_using] = ACTIONS(3520),
    [anon_sym_static_assert] = ACTIONS(3520),
    [anon_sym_concept] = ACTIONS(3520),
    [anon_sym_co_return] = ACTIONS(3520),
    [anon_sym_co_yield] = ACTIONS(3520),
    [anon_sym_R_DQUOTE] = ACTIONS(3518),
    [anon_sym_LR_DQUOTE] = ACTIONS(3518),
    [anon_sym_uR_DQUOTE] = ACTIONS(3518),
    [anon_sym_UR_DQUOTE] = ACTIONS(3518),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3518),
    [anon_sym_co_await] = ACTIONS(3520),
    [anon_sym_new] = ACTIONS(3520),
    [anon_sym_requires] = ACTIONS(3520),
    [sym_this] = ACTIONS(3520),
    [anon_sym___launch_bounds__] = ACTIONS(3520),
  },
  [STATE(740)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5359),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(8950),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(741)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5323),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(9437),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(742)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5357),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(9135),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(743)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5302),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(8624),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(744)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5345),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(9382),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(745)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5280),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(8677),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(746)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5314),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(8769),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(747)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5331),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(8826),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(748)] = {
    [ts_builtin_sym_end] = ACTIONS(2389),
    [sym_identifier] = ACTIONS(2387),
    [aux_sym_preproc_include_token1] = ACTIONS(2387),
    [aux_sym_preproc_def_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2387),
    [sym_preproc_directive] = ACTIONS(2387),
    [anon_sym_LPAREN2] = ACTIONS(2389),
    [anon_sym_BANG] = ACTIONS(2389),
    [anon_sym_TILDE] = ACTIONS(2389),
    [anon_sym_DASH] = ACTIONS(2387),
    [anon_sym_PLUS] = ACTIONS(2387),
    [anon_sym_STAR] = ACTIONS(2389),
    [anon_sym_AMP_AMP] = ACTIONS(2389),
    [anon_sym_AMP] = ACTIONS(2387),
    [anon_sym_SEMI] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2387),
    [anon_sym_typedef] = ACTIONS(2387),
    [anon_sym___device__] = ACTIONS(2387),
    [anon_sym___host__] = ACTIONS(2387),
    [anon_sym___global__] = ACTIONS(2387),
    [anon_sym___forceinline__] = ACTIONS(2387),
    [anon_sym___noinline__] = ACTIONS(2387),
    [anon_sym_virtual] = ACTIONS(2387),
    [anon_sym_extern] = ACTIONS(2387),
    [anon_sym___attribute__] = ACTIONS(2387),
    [anon_sym___attribute] = ACTIONS(2387),
    [anon_sym_COLON_COLON] = ACTIONS(2389),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2389),
    [anon_sym___declspec] = ACTIONS(2387),
    [anon_sym___based] = ACTIONS(2387),
    [anon_sym___cdecl] = ACTIONS(2387),
    [anon_sym___clrcall] = ACTIONS(2387),
    [anon_sym___stdcall] = ACTIONS(2387),
    [anon_sym___fastcall] = ACTIONS(2387),
    [anon_sym___thiscall] = ACTIONS(2387),
    [anon_sym___vectorcall] = ACTIONS(2387),
    [anon_sym_LBRACE] = ACTIONS(2389),
    [anon_sym_signed] = ACTIONS(2387),
    [anon_sym_unsigned] = ACTIONS(2387),
    [anon_sym_long] = ACTIONS(2387),
    [anon_sym_short] = ACTIONS(2387),
    [anon_sym_LBRACK] = ACTIONS(2387),
    [anon_sym_static] = ACTIONS(2387),
    [anon_sym_register] = ACTIONS(2387),
    [anon_sym_inline] = ACTIONS(2387),
    [anon_sym___inline] = ACTIONS(2387),
    [anon_sym___inline__] = ACTIONS(2387),
    [anon_sym___forceinline] = ACTIONS(2387),
    [anon_sym_thread_local] = ACTIONS(2387),
    [anon_sym___thread] = ACTIONS(2387),
    [anon_sym_const] = ACTIONS(2387),
    [anon_sym_constexpr] = ACTIONS(2387),
    [anon_sym_volatile] = ACTIONS(2387),
    [anon_sym_restrict] = ACTIONS(2387),
    [anon_sym___restrict__] = ACTIONS(2387),
    [anon_sym__Atomic] = ACTIONS(2387),
    [anon_sym__Noreturn] = ACTIONS(2387),
    [anon_sym_noreturn] = ACTIONS(2387),
    [anon_sym__Nonnull] = ACTIONS(2387),
    [anon_sym_mutable] = ACTIONS(2387),
    [anon_sym_constinit] = ACTIONS(2387),
    [anon_sym_consteval] = ACTIONS(2387),
    [anon_sym___shared__] = ACTIONS(2387),
    [anon_sym___local__] = ACTIONS(2387),
    [anon_sym___constant__] = ACTIONS(2387),
    [anon_sym___managed__] = ACTIONS(2387),
    [anon_sym___grid_constant__] = ACTIONS(2387),
    [anon_sym_alignas] = ACTIONS(2387),
    [anon_sym__Alignas] = ACTIONS(2387),
    [sym_primitive_type] = ACTIONS(2387),
    [anon_sym_enum] = ACTIONS(2387),
    [anon_sym_class] = ACTIONS(2387),
    [anon_sym_struct] = ACTIONS(2387),
    [anon_sym_union] = ACTIONS(2387),
    [anon_sym_if] = ACTIONS(2387),
    [anon_sym_switch] = ACTIONS(2387),
    [anon_sym_case] = ACTIONS(2387),
    [anon_sym_default] = ACTIONS(2387),
    [anon_sym_while] = ACTIONS(2387),
    [anon_sym_do] = ACTIONS(2387),
    [anon_sym_for] = ACTIONS(2387),
    [anon_sym_return] = ACTIONS(2387),
    [anon_sym_break] = ACTIONS(2387),
    [anon_sym_continue] = ACTIONS(2387),
    [anon_sym_goto] = ACTIONS(2387),
    [anon_sym_not] = ACTIONS(2387),
    [anon_sym_compl] = ACTIONS(2387),
    [anon_sym_DASH_DASH] = ACTIONS(2389),
    [anon_sym_PLUS_PLUS] = ACTIONS(2389),
    [anon_sym_sizeof] = ACTIONS(2387),
    [anon_sym___alignof__] = ACTIONS(2387),
    [anon_sym___alignof] = ACTIONS(2387),
    [anon_sym__alignof] = ACTIONS(2387),
    [anon_sym_alignof] = ACTIONS(2387),
    [anon_sym__Alignof] = ACTIONS(2387),
    [anon_sym_offsetof] = ACTIONS(2387),
    [anon_sym__Generic] = ACTIONS(2387),
    [anon_sym_asm] = ACTIONS(2387),
    [anon_sym___asm__] = ACTIONS(2387),
    [anon_sym___asm] = ACTIONS(2387),
    [sym_number_literal] = ACTIONS(2389),
    [anon_sym_L_SQUOTE] = ACTIONS(2389),
    [anon_sym_u_SQUOTE] = ACTIONS(2389),
    [anon_sym_U_SQUOTE] = ACTIONS(2389),
    [anon_sym_u8_SQUOTE] = ACTIONS(2389),
    [anon_sym_SQUOTE] = ACTIONS(2389),
    [anon_sym_L_DQUOTE] = ACTIONS(2389),
    [anon_sym_u_DQUOTE] = ACTIONS(2389),
    [anon_sym_U_DQUOTE] = ACTIONS(2389),
    [anon_sym_u8_DQUOTE] = ACTIONS(2389),
    [anon_sym_DQUOTE] = ACTIONS(2389),
    [sym_true] = ACTIONS(2387),
    [sym_false] = ACTIONS(2387),
    [anon_sym_NULL] = ACTIONS(2387),
    [anon_sym_nullptr] = ACTIONS(2387),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2387),
    [anon_sym_decltype] = ACTIONS(2387),
    [anon_sym_explicit] = ACTIONS(2387),
    [anon_sym_typename] = ACTIONS(2387),
    [anon_sym_template] = ACTIONS(2387),
    [anon_sym_operator] = ACTIONS(2387),
    [anon_sym_try] = ACTIONS(2387),
    [anon_sym_delete] = ACTIONS(2387),
    [anon_sym_throw] = ACTIONS(2387),
    [anon_sym_namespace] = ACTIONS(2387),
    [anon_sym_using] = ACTIONS(2387),
    [anon_sym_static_assert] = ACTIONS(2387),
    [anon_sym_concept] = ACTIONS(2387),
    [anon_sym_co_return] = ACTIONS(2387),
    [anon_sym_co_yield] = ACTIONS(2387),
    [anon_sym_R_DQUOTE] = ACTIONS(2389),
    [anon_sym_LR_DQUOTE] = ACTIONS(2389),
    [anon_sym_uR_DQUOTE] = ACTIONS(2389),
    [anon_sym_UR_DQUOTE] = ACTIONS(2389),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2389),
    [anon_sym_co_await] = ACTIONS(2387),
    [anon_sym_new] = ACTIONS(2387),
    [anon_sym_requires] = ACTIONS(2387),
    [sym_this] = ACTIONS(2387),
    [anon_sym___launch_bounds__] = ACTIONS(2387),
  },
  [STATE(749)] = {
    [ts_builtin_sym_end] = ACTIONS(2397),
    [sym_identifier] = ACTIONS(2395),
    [aux_sym_preproc_include_token1] = ACTIONS(2395),
    [aux_sym_preproc_def_token1] = ACTIONS(2395),
    [aux_sym_preproc_if_token1] = ACTIONS(2395),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2395),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2395),
    [sym_preproc_directive] = ACTIONS(2395),
    [anon_sym_LPAREN2] = ACTIONS(2397),
    [anon_sym_BANG] = ACTIONS(2397),
    [anon_sym_TILDE] = ACTIONS(2397),
    [anon_sym_DASH] = ACTIONS(2395),
    [anon_sym_PLUS] = ACTIONS(2395),
    [anon_sym_STAR] = ACTIONS(2397),
    [anon_sym_AMP_AMP] = ACTIONS(2397),
    [anon_sym_AMP] = ACTIONS(2395),
    [anon_sym_SEMI] = ACTIONS(2397),
    [anon_sym___extension__] = ACTIONS(2395),
    [anon_sym_typedef] = ACTIONS(2395),
    [anon_sym___device__] = ACTIONS(2395),
    [anon_sym___host__] = ACTIONS(2395),
    [anon_sym___global__] = ACTIONS(2395),
    [anon_sym___forceinline__] = ACTIONS(2395),
    [anon_sym___noinline__] = ACTIONS(2395),
    [anon_sym_virtual] = ACTIONS(2395),
    [anon_sym_extern] = ACTIONS(2395),
    [anon_sym___attribute__] = ACTIONS(2395),
    [anon_sym___attribute] = ACTIONS(2395),
    [anon_sym_COLON_COLON] = ACTIONS(2397),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2397),
    [anon_sym___declspec] = ACTIONS(2395),
    [anon_sym___based] = ACTIONS(2395),
    [anon_sym___cdecl] = ACTIONS(2395),
    [anon_sym___clrcall] = ACTIONS(2395),
    [anon_sym___stdcall] = ACTIONS(2395),
    [anon_sym___fastcall] = ACTIONS(2395),
    [anon_sym___thiscall] = ACTIONS(2395),
    [anon_sym___vectorcall] = ACTIONS(2395),
    [anon_sym_LBRACE] = ACTIONS(2397),
    [anon_sym_signed] = ACTIONS(2395),
    [anon_sym_unsigned] = ACTIONS(2395),
    [anon_sym_long] = ACTIONS(2395),
    [anon_sym_short] = ACTIONS(2395),
    [anon_sym_LBRACK] = ACTIONS(2395),
    [anon_sym_static] = ACTIONS(2395),
    [anon_sym_register] = ACTIONS(2395),
    [anon_sym_inline] = ACTIONS(2395),
    [anon_sym___inline] = ACTIONS(2395),
    [anon_sym___inline__] = ACTIONS(2395),
    [anon_sym___forceinline] = ACTIONS(2395),
    [anon_sym_thread_local] = ACTIONS(2395),
    [anon_sym___thread] = ACTIONS(2395),
    [anon_sym_const] = ACTIONS(2395),
    [anon_sym_constexpr] = ACTIONS(2395),
    [anon_sym_volatile] = ACTIONS(2395),
    [anon_sym_restrict] = ACTIONS(2395),
    [anon_sym___restrict__] = ACTIONS(2395),
    [anon_sym__Atomic] = ACTIONS(2395),
    [anon_sym__Noreturn] = ACTIONS(2395),
    [anon_sym_noreturn] = ACTIONS(2395),
    [anon_sym__Nonnull] = ACTIONS(2395),
    [anon_sym_mutable] = ACTIONS(2395),
    [anon_sym_constinit] = ACTIONS(2395),
    [anon_sym_consteval] = ACTIONS(2395),
    [anon_sym___shared__] = ACTIONS(2395),
    [anon_sym___local__] = ACTIONS(2395),
    [anon_sym___constant__] = ACTIONS(2395),
    [anon_sym___managed__] = ACTIONS(2395),
    [anon_sym___grid_constant__] = ACTIONS(2395),
    [anon_sym_alignas] = ACTIONS(2395),
    [anon_sym__Alignas] = ACTIONS(2395),
    [sym_primitive_type] = ACTIONS(2395),
    [anon_sym_enum] = ACTIONS(2395),
    [anon_sym_class] = ACTIONS(2395),
    [anon_sym_struct] = ACTIONS(2395),
    [anon_sym_union] = ACTIONS(2395),
    [anon_sym_if] = ACTIONS(2395),
    [anon_sym_switch] = ACTIONS(2395),
    [anon_sym_case] = ACTIONS(2395),
    [anon_sym_default] = ACTIONS(2395),
    [anon_sym_while] = ACTIONS(2395),
    [anon_sym_do] = ACTIONS(2395),
    [anon_sym_for] = ACTIONS(2395),
    [anon_sym_return] = ACTIONS(2395),
    [anon_sym_break] = ACTIONS(2395),
    [anon_sym_continue] = ACTIONS(2395),
    [anon_sym_goto] = ACTIONS(2395),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_compl] = ACTIONS(2395),
    [anon_sym_DASH_DASH] = ACTIONS(2397),
    [anon_sym_PLUS_PLUS] = ACTIONS(2397),
    [anon_sym_sizeof] = ACTIONS(2395),
    [anon_sym___alignof__] = ACTIONS(2395),
    [anon_sym___alignof] = ACTIONS(2395),
    [anon_sym__alignof] = ACTIONS(2395),
    [anon_sym_alignof] = ACTIONS(2395),
    [anon_sym__Alignof] = ACTIONS(2395),
    [anon_sym_offsetof] = ACTIONS(2395),
    [anon_sym__Generic] = ACTIONS(2395),
    [anon_sym_asm] = ACTIONS(2395),
    [anon_sym___asm__] = ACTIONS(2395),
    [anon_sym___asm] = ACTIONS(2395),
    [sym_number_literal] = ACTIONS(2397),
    [anon_sym_L_SQUOTE] = ACTIONS(2397),
    [anon_sym_u_SQUOTE] = ACTIONS(2397),
    [anon_sym_U_SQUOTE] = ACTIONS(2397),
    [anon_sym_u8_SQUOTE] = ACTIONS(2397),
    [anon_sym_SQUOTE] = ACTIONS(2397),
    [anon_sym_L_DQUOTE] = ACTIONS(2397),
    [anon_sym_u_DQUOTE] = ACTIONS(2397),
    [anon_sym_U_DQUOTE] = ACTIONS(2397),
    [anon_sym_u8_DQUOTE] = ACTIONS(2397),
    [anon_sym_DQUOTE] = ACTIONS(2397),
    [sym_true] = ACTIONS(2395),
    [sym_false] = ACTIONS(2395),
    [anon_sym_NULL] = ACTIONS(2395),
    [anon_sym_nullptr] = ACTIONS(2395),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2395),
    [anon_sym_decltype] = ACTIONS(2395),
    [anon_sym_explicit] = ACTIONS(2395),
    [anon_sym_typename] = ACTIONS(2395),
    [anon_sym_template] = ACTIONS(2395),
    [anon_sym_operator] = ACTIONS(2395),
    [anon_sym_try] = ACTIONS(2395),
    [anon_sym_delete] = ACTIONS(2395),
    [anon_sym_throw] = ACTIONS(2395),
    [anon_sym_namespace] = ACTIONS(2395),
    [anon_sym_using] = ACTIONS(2395),
    [anon_sym_static_assert] = ACTIONS(2395),
    [anon_sym_concept] = ACTIONS(2395),
    [anon_sym_co_return] = ACTIONS(2395),
    [anon_sym_co_yield] = ACTIONS(2395),
    [anon_sym_R_DQUOTE] = ACTIONS(2397),
    [anon_sym_LR_DQUOTE] = ACTIONS(2397),
    [anon_sym_uR_DQUOTE] = ACTIONS(2397),
    [anon_sym_UR_DQUOTE] = ACTIONS(2397),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2397),
    [anon_sym_co_await] = ACTIONS(2395),
    [anon_sym_new] = ACTIONS(2395),
    [anon_sym_requires] = ACTIONS(2395),
    [sym_this] = ACTIONS(2395),
    [anon_sym___launch_bounds__] = ACTIONS(2395),
  },
  [STATE(750)] = {
    [ts_builtin_sym_end] = ACTIONS(3522),
    [sym_identifier] = ACTIONS(3525),
    [aux_sym_preproc_include_token1] = ACTIONS(3525),
    [aux_sym_preproc_def_token1] = ACTIONS(3525),
    [aux_sym_preproc_if_token1] = ACTIONS(3525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3525),
    [sym_preproc_directive] = ACTIONS(3525),
    [anon_sym_LPAREN2] = ACTIONS(3522),
    [anon_sym_BANG] = ACTIONS(3522),
    [anon_sym_TILDE] = ACTIONS(3522),
    [anon_sym_DASH] = ACTIONS(3525),
    [anon_sym_PLUS] = ACTIONS(3525),
    [anon_sym_STAR] = ACTIONS(3522),
    [anon_sym_AMP_AMP] = ACTIONS(3522),
    [anon_sym_AMP] = ACTIONS(3525),
    [anon_sym_SEMI] = ACTIONS(3522),
    [anon_sym___extension__] = ACTIONS(3525),
    [anon_sym_typedef] = ACTIONS(3525),
    [anon_sym___device__] = ACTIONS(3525),
    [anon_sym___host__] = ACTIONS(3525),
    [anon_sym___global__] = ACTIONS(3525),
    [anon_sym___forceinline__] = ACTIONS(3525),
    [anon_sym___noinline__] = ACTIONS(3525),
    [anon_sym_virtual] = ACTIONS(3525),
    [anon_sym_extern] = ACTIONS(3525),
    [anon_sym___attribute__] = ACTIONS(3525),
    [anon_sym___attribute] = ACTIONS(3525),
    [anon_sym_COLON_COLON] = ACTIONS(3522),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3522),
    [anon_sym___declspec] = ACTIONS(3525),
    [anon_sym___based] = ACTIONS(3525),
    [anon_sym___cdecl] = ACTIONS(3525),
    [anon_sym___clrcall] = ACTIONS(3525),
    [anon_sym___stdcall] = ACTIONS(3525),
    [anon_sym___fastcall] = ACTIONS(3525),
    [anon_sym___thiscall] = ACTIONS(3525),
    [anon_sym___vectorcall] = ACTIONS(3525),
    [anon_sym_LBRACE] = ACTIONS(3522),
    [anon_sym_signed] = ACTIONS(3525),
    [anon_sym_unsigned] = ACTIONS(3525),
    [anon_sym_long] = ACTIONS(3525),
    [anon_sym_short] = ACTIONS(3525),
    [anon_sym_LBRACK] = ACTIONS(3525),
    [anon_sym_static] = ACTIONS(3525),
    [anon_sym_register] = ACTIONS(3525),
    [anon_sym_inline] = ACTIONS(3525),
    [anon_sym___inline] = ACTIONS(3525),
    [anon_sym___inline__] = ACTIONS(3525),
    [anon_sym___forceinline] = ACTIONS(3525),
    [anon_sym_thread_local] = ACTIONS(3525),
    [anon_sym___thread] = ACTIONS(3525),
    [anon_sym_const] = ACTIONS(3525),
    [anon_sym_constexpr] = ACTIONS(3525),
    [anon_sym_volatile] = ACTIONS(3525),
    [anon_sym_restrict] = ACTIONS(3525),
    [anon_sym___restrict__] = ACTIONS(3525),
    [anon_sym__Atomic] = ACTIONS(3525),
    [anon_sym__Noreturn] = ACTIONS(3525),
    [anon_sym_noreturn] = ACTIONS(3525),
    [anon_sym__Nonnull] = ACTIONS(3525),
    [anon_sym_mutable] = ACTIONS(3525),
    [anon_sym_constinit] = ACTIONS(3525),
    [anon_sym_consteval] = ACTIONS(3525),
    [anon_sym___shared__] = ACTIONS(3525),
    [anon_sym___local__] = ACTIONS(3525),
    [anon_sym___constant__] = ACTIONS(3525),
    [anon_sym___managed__] = ACTIONS(3525),
    [anon_sym___grid_constant__] = ACTIONS(3525),
    [anon_sym_alignas] = ACTIONS(3525),
    [anon_sym__Alignas] = ACTIONS(3525),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_enum] = ACTIONS(3525),
    [anon_sym_class] = ACTIONS(3525),
    [anon_sym_struct] = ACTIONS(3525),
    [anon_sym_union] = ACTIONS(3525),
    [anon_sym_if] = ACTIONS(3525),
    [anon_sym_switch] = ACTIONS(3525),
    [anon_sym_case] = ACTIONS(3525),
    [anon_sym_default] = ACTIONS(3525),
    [anon_sym_while] = ACTIONS(3525),
    [anon_sym_do] = ACTIONS(3525),
    [anon_sym_for] = ACTIONS(3525),
    [anon_sym_return] = ACTIONS(3525),
    [anon_sym_break] = ACTIONS(3525),
    [anon_sym_continue] = ACTIONS(3525),
    [anon_sym_goto] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3525),
    [anon_sym_compl] = ACTIONS(3525),
    [anon_sym_DASH_DASH] = ACTIONS(3522),
    [anon_sym_PLUS_PLUS] = ACTIONS(3522),
    [anon_sym_sizeof] = ACTIONS(3525),
    [anon_sym___alignof__] = ACTIONS(3525),
    [anon_sym___alignof] = ACTIONS(3525),
    [anon_sym__alignof] = ACTIONS(3525),
    [anon_sym_alignof] = ACTIONS(3525),
    [anon_sym__Alignof] = ACTIONS(3525),
    [anon_sym_offsetof] = ACTIONS(3525),
    [anon_sym__Generic] = ACTIONS(3525),
    [anon_sym_asm] = ACTIONS(3525),
    [anon_sym___asm__] = ACTIONS(3525),
    [anon_sym___asm] = ACTIONS(3525),
    [sym_number_literal] = ACTIONS(3522),
    [anon_sym_L_SQUOTE] = ACTIONS(3522),
    [anon_sym_u_SQUOTE] = ACTIONS(3522),
    [anon_sym_U_SQUOTE] = ACTIONS(3522),
    [anon_sym_u8_SQUOTE] = ACTIONS(3522),
    [anon_sym_SQUOTE] = ACTIONS(3522),
    [anon_sym_L_DQUOTE] = ACTIONS(3522),
    [anon_sym_u_DQUOTE] = ACTIONS(3522),
    [anon_sym_U_DQUOTE] = ACTIONS(3522),
    [anon_sym_u8_DQUOTE] = ACTIONS(3522),
    [anon_sym_DQUOTE] = ACTIONS(3522),
    [sym_true] = ACTIONS(3525),
    [sym_false] = ACTIONS(3525),
    [anon_sym_NULL] = ACTIONS(3525),
    [anon_sym_nullptr] = ACTIONS(3525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3525),
    [anon_sym_decltype] = ACTIONS(3525),
    [anon_sym_explicit] = ACTIONS(3525),
    [anon_sym_typename] = ACTIONS(3525),
    [anon_sym_template] = ACTIONS(3525),
    [anon_sym_operator] = ACTIONS(3525),
    [anon_sym_try] = ACTIONS(3525),
    [anon_sym_delete] = ACTIONS(3525),
    [anon_sym_throw] = ACTIONS(3525),
    [anon_sym_namespace] = ACTIONS(3525),
    [anon_sym_using] = ACTIONS(3525),
    [anon_sym_static_assert] = ACTIONS(3525),
    [anon_sym_concept] = ACTIONS(3525),
    [anon_sym_co_return] = ACTIONS(3525),
    [anon_sym_co_yield] = ACTIONS(3525),
    [anon_sym_R_DQUOTE] = ACTIONS(3522),
    [anon_sym_LR_DQUOTE] = ACTIONS(3522),
    [anon_sym_uR_DQUOTE] = ACTIONS(3522),
    [anon_sym_UR_DQUOTE] = ACTIONS(3522),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3522),
    [anon_sym_co_await] = ACTIONS(3525),
    [anon_sym_new] = ACTIONS(3525),
    [anon_sym_requires] = ACTIONS(3525),
    [sym_this] = ACTIONS(3525),
    [anon_sym___launch_bounds__] = ACTIONS(3525),
  },
  [STATE(751)] = {
    [ts_builtin_sym_end] = ACTIONS(2515),
    [sym_identifier] = ACTIONS(2513),
    [aux_sym_preproc_include_token1] = ACTIONS(2513),
    [aux_sym_preproc_def_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2513),
    [sym_preproc_directive] = ACTIONS(2513),
    [anon_sym_LPAREN2] = ACTIONS(2515),
    [anon_sym_BANG] = ACTIONS(2515),
    [anon_sym_TILDE] = ACTIONS(2515),
    [anon_sym_DASH] = ACTIONS(2513),
    [anon_sym_PLUS] = ACTIONS(2513),
    [anon_sym_STAR] = ACTIONS(2515),
    [anon_sym_AMP_AMP] = ACTIONS(2515),
    [anon_sym_AMP] = ACTIONS(2513),
    [anon_sym_SEMI] = ACTIONS(2515),
    [anon_sym___extension__] = ACTIONS(2513),
    [anon_sym_typedef] = ACTIONS(2513),
    [anon_sym___device__] = ACTIONS(2513),
    [anon_sym___host__] = ACTIONS(2513),
    [anon_sym___global__] = ACTIONS(2513),
    [anon_sym___forceinline__] = ACTIONS(2513),
    [anon_sym___noinline__] = ACTIONS(2513),
    [anon_sym_virtual] = ACTIONS(2513),
    [anon_sym_extern] = ACTIONS(2513),
    [anon_sym___attribute__] = ACTIONS(2513),
    [anon_sym___attribute] = ACTIONS(2513),
    [anon_sym_COLON_COLON] = ACTIONS(2515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2515),
    [anon_sym___declspec] = ACTIONS(2513),
    [anon_sym___based] = ACTIONS(2513),
    [anon_sym___cdecl] = ACTIONS(2513),
    [anon_sym___clrcall] = ACTIONS(2513),
    [anon_sym___stdcall] = ACTIONS(2513),
    [anon_sym___fastcall] = ACTIONS(2513),
    [anon_sym___thiscall] = ACTIONS(2513),
    [anon_sym___vectorcall] = ACTIONS(2513),
    [anon_sym_LBRACE] = ACTIONS(2515),
    [anon_sym_signed] = ACTIONS(2513),
    [anon_sym_unsigned] = ACTIONS(2513),
    [anon_sym_long] = ACTIONS(2513),
    [anon_sym_short] = ACTIONS(2513),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_static] = ACTIONS(2513),
    [anon_sym_register] = ACTIONS(2513),
    [anon_sym_inline] = ACTIONS(2513),
    [anon_sym___inline] = ACTIONS(2513),
    [anon_sym___inline__] = ACTIONS(2513),
    [anon_sym___forceinline] = ACTIONS(2513),
    [anon_sym_thread_local] = ACTIONS(2513),
    [anon_sym___thread] = ACTIONS(2513),
    [anon_sym_const] = ACTIONS(2513),
    [anon_sym_constexpr] = ACTIONS(2513),
    [anon_sym_volatile] = ACTIONS(2513),
    [anon_sym_restrict] = ACTIONS(2513),
    [anon_sym___restrict__] = ACTIONS(2513),
    [anon_sym__Atomic] = ACTIONS(2513),
    [anon_sym__Noreturn] = ACTIONS(2513),
    [anon_sym_noreturn] = ACTIONS(2513),
    [anon_sym__Nonnull] = ACTIONS(2513),
    [anon_sym_mutable] = ACTIONS(2513),
    [anon_sym_constinit] = ACTIONS(2513),
    [anon_sym_consteval] = ACTIONS(2513),
    [anon_sym___shared__] = ACTIONS(2513),
    [anon_sym___local__] = ACTIONS(2513),
    [anon_sym___constant__] = ACTIONS(2513),
    [anon_sym___managed__] = ACTIONS(2513),
    [anon_sym___grid_constant__] = ACTIONS(2513),
    [anon_sym_alignas] = ACTIONS(2513),
    [anon_sym__Alignas] = ACTIONS(2513),
    [sym_primitive_type] = ACTIONS(2513),
    [anon_sym_enum] = ACTIONS(2513),
    [anon_sym_class] = ACTIONS(2513),
    [anon_sym_struct] = ACTIONS(2513),
    [anon_sym_union] = ACTIONS(2513),
    [anon_sym_if] = ACTIONS(2513),
    [anon_sym_switch] = ACTIONS(2513),
    [anon_sym_case] = ACTIONS(2513),
    [anon_sym_default] = ACTIONS(2513),
    [anon_sym_while] = ACTIONS(2513),
    [anon_sym_do] = ACTIONS(2513),
    [anon_sym_for] = ACTIONS(2513),
    [anon_sym_return] = ACTIONS(2513),
    [anon_sym_break] = ACTIONS(2513),
    [anon_sym_continue] = ACTIONS(2513),
    [anon_sym_goto] = ACTIONS(2513),
    [anon_sym_not] = ACTIONS(2513),
    [anon_sym_compl] = ACTIONS(2513),
    [anon_sym_DASH_DASH] = ACTIONS(2515),
    [anon_sym_PLUS_PLUS] = ACTIONS(2515),
    [anon_sym_sizeof] = ACTIONS(2513),
    [anon_sym___alignof__] = ACTIONS(2513),
    [anon_sym___alignof] = ACTIONS(2513),
    [anon_sym__alignof] = ACTIONS(2513),
    [anon_sym_alignof] = ACTIONS(2513),
    [anon_sym__Alignof] = ACTIONS(2513),
    [anon_sym_offsetof] = ACTIONS(2513),
    [anon_sym__Generic] = ACTIONS(2513),
    [anon_sym_asm] = ACTIONS(2513),
    [anon_sym___asm__] = ACTIONS(2513),
    [anon_sym___asm] = ACTIONS(2513),
    [sym_number_literal] = ACTIONS(2515),
    [anon_sym_L_SQUOTE] = ACTIONS(2515),
    [anon_sym_u_SQUOTE] = ACTIONS(2515),
    [anon_sym_U_SQUOTE] = ACTIONS(2515),
    [anon_sym_u8_SQUOTE] = ACTIONS(2515),
    [anon_sym_SQUOTE] = ACTIONS(2515),
    [anon_sym_L_DQUOTE] = ACTIONS(2515),
    [anon_sym_u_DQUOTE] = ACTIONS(2515),
    [anon_sym_U_DQUOTE] = ACTIONS(2515),
    [anon_sym_u8_DQUOTE] = ACTIONS(2515),
    [anon_sym_DQUOTE] = ACTIONS(2515),
    [sym_true] = ACTIONS(2513),
    [sym_false] = ACTIONS(2513),
    [anon_sym_NULL] = ACTIONS(2513),
    [anon_sym_nullptr] = ACTIONS(2513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2513),
    [anon_sym_decltype] = ACTIONS(2513),
    [anon_sym_explicit] = ACTIONS(2513),
    [anon_sym_typename] = ACTIONS(2513),
    [anon_sym_template] = ACTIONS(2513),
    [anon_sym_operator] = ACTIONS(2513),
    [anon_sym_try] = ACTIONS(2513),
    [anon_sym_delete] = ACTIONS(2513),
    [anon_sym_throw] = ACTIONS(2513),
    [anon_sym_namespace] = ACTIONS(2513),
    [anon_sym_using] = ACTIONS(2513),
    [anon_sym_static_assert] = ACTIONS(2513),
    [anon_sym_concept] = ACTIONS(2513),
    [anon_sym_co_return] = ACTIONS(2513),
    [anon_sym_co_yield] = ACTIONS(2513),
    [anon_sym_R_DQUOTE] = ACTIONS(2515),
    [anon_sym_LR_DQUOTE] = ACTIONS(2515),
    [anon_sym_uR_DQUOTE] = ACTIONS(2515),
    [anon_sym_UR_DQUOTE] = ACTIONS(2515),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2515),
    [anon_sym_co_await] = ACTIONS(2513),
    [anon_sym_new] = ACTIONS(2513),
    [anon_sym_requires] = ACTIONS(2513),
    [sym_this] = ACTIONS(2513),
    [anon_sym___launch_bounds__] = ACTIONS(2513),
  },
  [STATE(752)] = {
    [ts_builtin_sym_end] = ACTIONS(2567),
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_include_token1] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym___device__] = ACTIONS(2565),
    [anon_sym___host__] = ACTIONS(2565),
    [anon_sym___global__] = ACTIONS(2565),
    [anon_sym___forceinline__] = ACTIONS(2565),
    [anon_sym___noinline__] = ACTIONS(2565),
    [anon_sym_virtual] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym___attribute] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym___cdecl] = ACTIONS(2565),
    [anon_sym___clrcall] = ACTIONS(2565),
    [anon_sym___stdcall] = ACTIONS(2565),
    [anon_sym___fastcall] = ACTIONS(2565),
    [anon_sym___thiscall] = ACTIONS(2565),
    [anon_sym___vectorcall] = ACTIONS(2565),
    [anon_sym_LBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym__Nonnull] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym___shared__] = ACTIONS(2565),
    [anon_sym___local__] = ACTIONS(2565),
    [anon_sym___constant__] = ACTIONS(2565),
    [anon_sym___managed__] = ACTIONS(2565),
    [anon_sym___grid_constant__] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_switch] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_default] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_do] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_return] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_goto] = ACTIONS(2565),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_compl] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2567),
    [anon_sym_sizeof] = ACTIONS(2565),
    [anon_sym___alignof__] = ACTIONS(2565),
    [anon_sym___alignof] = ACTIONS(2565),
    [anon_sym__alignof] = ACTIONS(2565),
    [anon_sym_alignof] = ACTIONS(2565),
    [anon_sym__Alignof] = ACTIONS(2565),
    [anon_sym_offsetof] = ACTIONS(2565),
    [anon_sym__Generic] = ACTIONS(2565),
    [anon_sym_asm] = ACTIONS(2565),
    [anon_sym___asm__] = ACTIONS(2565),
    [anon_sym___asm] = ACTIONS(2565),
    [sym_number_literal] = ACTIONS(2567),
    [anon_sym_L_SQUOTE] = ACTIONS(2567),
    [anon_sym_u_SQUOTE] = ACTIONS(2567),
    [anon_sym_U_SQUOTE] = ACTIONS(2567),
    [anon_sym_u8_SQUOTE] = ACTIONS(2567),
    [anon_sym_SQUOTE] = ACTIONS(2567),
    [anon_sym_L_DQUOTE] = ACTIONS(2567),
    [anon_sym_u_DQUOTE] = ACTIONS(2567),
    [anon_sym_U_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8_DQUOTE] = ACTIONS(2567),
    [anon_sym_DQUOTE] = ACTIONS(2567),
    [sym_true] = ACTIONS(2565),
    [sym_false] = ACTIONS(2565),
    [anon_sym_NULL] = ACTIONS(2565),
    [anon_sym_nullptr] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_try] = ACTIONS(2565),
    [anon_sym_delete] = ACTIONS(2565),
    [anon_sym_throw] = ACTIONS(2565),
    [anon_sym_namespace] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_concept] = ACTIONS(2565),
    [anon_sym_co_return] = ACTIONS(2565),
    [anon_sym_co_yield] = ACTIONS(2565),
    [anon_sym_R_DQUOTE] = ACTIONS(2567),
    [anon_sym_LR_DQUOTE] = ACTIONS(2567),
    [anon_sym_uR_DQUOTE] = ACTIONS(2567),
    [anon_sym_UR_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2567),
    [anon_sym_co_await] = ACTIONS(2565),
    [anon_sym_new] = ACTIONS(2565),
    [anon_sym_requires] = ACTIONS(2565),
    [sym_this] = ACTIONS(2565),
    [anon_sym___launch_bounds__] = ACTIONS(2565),
  },
  [STATE(753)] = {
    [ts_builtin_sym_end] = ACTIONS(2519),
    [sym_identifier] = ACTIONS(2517),
    [aux_sym_preproc_include_token1] = ACTIONS(2517),
    [aux_sym_preproc_def_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2517),
    [sym_preproc_directive] = ACTIONS(2517),
    [anon_sym_LPAREN2] = ACTIONS(2519),
    [anon_sym_BANG] = ACTIONS(2519),
    [anon_sym_TILDE] = ACTIONS(2519),
    [anon_sym_DASH] = ACTIONS(2517),
    [anon_sym_PLUS] = ACTIONS(2517),
    [anon_sym_STAR] = ACTIONS(2519),
    [anon_sym_AMP_AMP] = ACTIONS(2519),
    [anon_sym_AMP] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym___extension__] = ACTIONS(2517),
    [anon_sym_typedef] = ACTIONS(2517),
    [anon_sym___device__] = ACTIONS(2517),
    [anon_sym___host__] = ACTIONS(2517),
    [anon_sym___global__] = ACTIONS(2517),
    [anon_sym___forceinline__] = ACTIONS(2517),
    [anon_sym___noinline__] = ACTIONS(2517),
    [anon_sym_virtual] = ACTIONS(2517),
    [anon_sym_extern] = ACTIONS(2517),
    [anon_sym___attribute__] = ACTIONS(2517),
    [anon_sym___attribute] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2519),
    [anon_sym___declspec] = ACTIONS(2517),
    [anon_sym___based] = ACTIONS(2517),
    [anon_sym___cdecl] = ACTIONS(2517),
    [anon_sym___clrcall] = ACTIONS(2517),
    [anon_sym___stdcall] = ACTIONS(2517),
    [anon_sym___fastcall] = ACTIONS(2517),
    [anon_sym___thiscall] = ACTIONS(2517),
    [anon_sym___vectorcall] = ACTIONS(2517),
    [anon_sym_LBRACE] = ACTIONS(2519),
    [anon_sym_signed] = ACTIONS(2517),
    [anon_sym_unsigned] = ACTIONS(2517),
    [anon_sym_long] = ACTIONS(2517),
    [anon_sym_short] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2517),
    [anon_sym_static] = ACTIONS(2517),
    [anon_sym_register] = ACTIONS(2517),
    [anon_sym_inline] = ACTIONS(2517),
    [anon_sym___inline] = ACTIONS(2517),
    [anon_sym___inline__] = ACTIONS(2517),
    [anon_sym___forceinline] = ACTIONS(2517),
    [anon_sym_thread_local] = ACTIONS(2517),
    [anon_sym___thread] = ACTIONS(2517),
    [anon_sym_const] = ACTIONS(2517),
    [anon_sym_constexpr] = ACTIONS(2517),
    [anon_sym_volatile] = ACTIONS(2517),
    [anon_sym_restrict] = ACTIONS(2517),
    [anon_sym___restrict__] = ACTIONS(2517),
    [anon_sym__Atomic] = ACTIONS(2517),
    [anon_sym__Noreturn] = ACTIONS(2517),
    [anon_sym_noreturn] = ACTIONS(2517),
    [anon_sym__Nonnull] = ACTIONS(2517),
    [anon_sym_mutable] = ACTIONS(2517),
    [anon_sym_constinit] = ACTIONS(2517),
    [anon_sym_consteval] = ACTIONS(2517),
    [anon_sym___shared__] = ACTIONS(2517),
    [anon_sym___local__] = ACTIONS(2517),
    [anon_sym___constant__] = ACTIONS(2517),
    [anon_sym___managed__] = ACTIONS(2517),
    [anon_sym___grid_constant__] = ACTIONS(2517),
    [anon_sym_alignas] = ACTIONS(2517),
    [anon_sym__Alignas] = ACTIONS(2517),
    [sym_primitive_type] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_class] = ACTIONS(2517),
    [anon_sym_struct] = ACTIONS(2517),
    [anon_sym_union] = ACTIONS(2517),
    [anon_sym_if] = ACTIONS(2517),
    [anon_sym_switch] = ACTIONS(2517),
    [anon_sym_case] = ACTIONS(2517),
    [anon_sym_default] = ACTIONS(2517),
    [anon_sym_while] = ACTIONS(2517),
    [anon_sym_do] = ACTIONS(2517),
    [anon_sym_for] = ACTIONS(2517),
    [anon_sym_return] = ACTIONS(2517),
    [anon_sym_break] = ACTIONS(2517),
    [anon_sym_continue] = ACTIONS(2517),
    [anon_sym_goto] = ACTIONS(2517),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_compl] = ACTIONS(2517),
    [anon_sym_DASH_DASH] = ACTIONS(2519),
    [anon_sym_PLUS_PLUS] = ACTIONS(2519),
    [anon_sym_sizeof] = ACTIONS(2517),
    [anon_sym___alignof__] = ACTIONS(2517),
    [anon_sym___alignof] = ACTIONS(2517),
    [anon_sym__alignof] = ACTIONS(2517),
    [anon_sym_alignof] = ACTIONS(2517),
    [anon_sym__Alignof] = ACTIONS(2517),
    [anon_sym_offsetof] = ACTIONS(2517),
    [anon_sym__Generic] = ACTIONS(2517),
    [anon_sym_asm] = ACTIONS(2517),
    [anon_sym___asm__] = ACTIONS(2517),
    [anon_sym___asm] = ACTIONS(2517),
    [sym_number_literal] = ACTIONS(2519),
    [anon_sym_L_SQUOTE] = ACTIONS(2519),
    [anon_sym_u_SQUOTE] = ACTIONS(2519),
    [anon_sym_U_SQUOTE] = ACTIONS(2519),
    [anon_sym_u8_SQUOTE] = ACTIONS(2519),
    [anon_sym_SQUOTE] = ACTIONS(2519),
    [anon_sym_L_DQUOTE] = ACTIONS(2519),
    [anon_sym_u_DQUOTE] = ACTIONS(2519),
    [anon_sym_U_DQUOTE] = ACTIONS(2519),
    [anon_sym_u8_DQUOTE] = ACTIONS(2519),
    [anon_sym_DQUOTE] = ACTIONS(2519),
    [sym_true] = ACTIONS(2517),
    [sym_false] = ACTIONS(2517),
    [anon_sym_NULL] = ACTIONS(2517),
    [anon_sym_nullptr] = ACTIONS(2517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2517),
    [anon_sym_decltype] = ACTIONS(2517),
    [anon_sym_explicit] = ACTIONS(2517),
    [anon_sym_typename] = ACTIONS(2517),
    [anon_sym_template] = ACTIONS(2517),
    [anon_sym_operator] = ACTIONS(2517),
    [anon_sym_try] = ACTIONS(2517),
    [anon_sym_delete] = ACTIONS(2517),
    [anon_sym_throw] = ACTIONS(2517),
    [anon_sym_namespace] = ACTIONS(2517),
    [anon_sym_using] = ACTIONS(2517),
    [anon_sym_static_assert] = ACTIONS(2517),
    [anon_sym_concept] = ACTIONS(2517),
    [anon_sym_co_return] = ACTIONS(2517),
    [anon_sym_co_yield] = ACTIONS(2517),
    [anon_sym_R_DQUOTE] = ACTIONS(2519),
    [anon_sym_LR_DQUOTE] = ACTIONS(2519),
    [anon_sym_uR_DQUOTE] = ACTIONS(2519),
    [anon_sym_UR_DQUOTE] = ACTIONS(2519),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2519),
    [anon_sym_co_await] = ACTIONS(2517),
    [anon_sym_new] = ACTIONS(2517),
    [anon_sym_requires] = ACTIONS(2517),
    [sym_this] = ACTIONS(2517),
    [anon_sym___launch_bounds__] = ACTIONS(2517),
  },
  [STATE(754)] = {
    [ts_builtin_sym_end] = ACTIONS(2421),
    [sym_identifier] = ACTIONS(2419),
    [aux_sym_preproc_include_token1] = ACTIONS(2419),
    [aux_sym_preproc_def_token1] = ACTIONS(2419),
    [aux_sym_preproc_if_token1] = ACTIONS(2419),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2419),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2419),
    [sym_preproc_directive] = ACTIONS(2419),
    [anon_sym_LPAREN2] = ACTIONS(2421),
    [anon_sym_BANG] = ACTIONS(2421),
    [anon_sym_TILDE] = ACTIONS(2421),
    [anon_sym_DASH] = ACTIONS(2419),
    [anon_sym_PLUS] = ACTIONS(2419),
    [anon_sym_STAR] = ACTIONS(2421),
    [anon_sym_AMP_AMP] = ACTIONS(2421),
    [anon_sym_AMP] = ACTIONS(2419),
    [anon_sym_SEMI] = ACTIONS(2421),
    [anon_sym___extension__] = ACTIONS(2419),
    [anon_sym_typedef] = ACTIONS(2419),
    [anon_sym___device__] = ACTIONS(2419),
    [anon_sym___host__] = ACTIONS(2419),
    [anon_sym___global__] = ACTIONS(2419),
    [anon_sym___forceinline__] = ACTIONS(2419),
    [anon_sym___noinline__] = ACTIONS(2419),
    [anon_sym_virtual] = ACTIONS(2419),
    [anon_sym_extern] = ACTIONS(2419),
    [anon_sym___attribute__] = ACTIONS(2419),
    [anon_sym___attribute] = ACTIONS(2419),
    [anon_sym_COLON_COLON] = ACTIONS(2421),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2421),
    [anon_sym___declspec] = ACTIONS(2419),
    [anon_sym___based] = ACTIONS(2419),
    [anon_sym___cdecl] = ACTIONS(2419),
    [anon_sym___clrcall] = ACTIONS(2419),
    [anon_sym___stdcall] = ACTIONS(2419),
    [anon_sym___fastcall] = ACTIONS(2419),
    [anon_sym___thiscall] = ACTIONS(2419),
    [anon_sym___vectorcall] = ACTIONS(2419),
    [anon_sym_LBRACE] = ACTIONS(2421),
    [anon_sym_signed] = ACTIONS(2419),
    [anon_sym_unsigned] = ACTIONS(2419),
    [anon_sym_long] = ACTIONS(2419),
    [anon_sym_short] = ACTIONS(2419),
    [anon_sym_LBRACK] = ACTIONS(2419),
    [anon_sym_static] = ACTIONS(2419),
    [anon_sym_register] = ACTIONS(2419),
    [anon_sym_inline] = ACTIONS(2419),
    [anon_sym___inline] = ACTIONS(2419),
    [anon_sym___inline__] = ACTIONS(2419),
    [anon_sym___forceinline] = ACTIONS(2419),
    [anon_sym_thread_local] = ACTIONS(2419),
    [anon_sym___thread] = ACTIONS(2419),
    [anon_sym_const] = ACTIONS(2419),
    [anon_sym_constexpr] = ACTIONS(2419),
    [anon_sym_volatile] = ACTIONS(2419),
    [anon_sym_restrict] = ACTIONS(2419),
    [anon_sym___restrict__] = ACTIONS(2419),
    [anon_sym__Atomic] = ACTIONS(2419),
    [anon_sym__Noreturn] = ACTIONS(2419),
    [anon_sym_noreturn] = ACTIONS(2419),
    [anon_sym__Nonnull] = ACTIONS(2419),
    [anon_sym_mutable] = ACTIONS(2419),
    [anon_sym_constinit] = ACTIONS(2419),
    [anon_sym_consteval] = ACTIONS(2419),
    [anon_sym___shared__] = ACTIONS(2419),
    [anon_sym___local__] = ACTIONS(2419),
    [anon_sym___constant__] = ACTIONS(2419),
    [anon_sym___managed__] = ACTIONS(2419),
    [anon_sym___grid_constant__] = ACTIONS(2419),
    [anon_sym_alignas] = ACTIONS(2419),
    [anon_sym__Alignas] = ACTIONS(2419),
    [sym_primitive_type] = ACTIONS(2419),
    [anon_sym_enum] = ACTIONS(2419),
    [anon_sym_class] = ACTIONS(2419),
    [anon_sym_struct] = ACTIONS(2419),
    [anon_sym_union] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2419),
    [anon_sym_switch] = ACTIONS(2419),
    [anon_sym_case] = ACTIONS(2419),
    [anon_sym_default] = ACTIONS(2419),
    [anon_sym_while] = ACTIONS(2419),
    [anon_sym_do] = ACTIONS(2419),
    [anon_sym_for] = ACTIONS(2419),
    [anon_sym_return] = ACTIONS(2419),
    [anon_sym_break] = ACTIONS(2419),
    [anon_sym_continue] = ACTIONS(2419),
    [anon_sym_goto] = ACTIONS(2419),
    [anon_sym_not] = ACTIONS(2419),
    [anon_sym_compl] = ACTIONS(2419),
    [anon_sym_DASH_DASH] = ACTIONS(2421),
    [anon_sym_PLUS_PLUS] = ACTIONS(2421),
    [anon_sym_sizeof] = ACTIONS(2419),
    [anon_sym___alignof__] = ACTIONS(2419),
    [anon_sym___alignof] = ACTIONS(2419),
    [anon_sym__alignof] = ACTIONS(2419),
    [anon_sym_alignof] = ACTIONS(2419),
    [anon_sym__Alignof] = ACTIONS(2419),
    [anon_sym_offsetof] = ACTIONS(2419),
    [anon_sym__Generic] = ACTIONS(2419),
    [anon_sym_asm] = ACTIONS(2419),
    [anon_sym___asm__] = ACTIONS(2419),
    [anon_sym___asm] = ACTIONS(2419),
    [sym_number_literal] = ACTIONS(2421),
    [anon_sym_L_SQUOTE] = ACTIONS(2421),
    [anon_sym_u_SQUOTE] = ACTIONS(2421),
    [anon_sym_U_SQUOTE] = ACTIONS(2421),
    [anon_sym_u8_SQUOTE] = ACTIONS(2421),
    [anon_sym_SQUOTE] = ACTIONS(2421),
    [anon_sym_L_DQUOTE] = ACTIONS(2421),
    [anon_sym_u_DQUOTE] = ACTIONS(2421),
    [anon_sym_U_DQUOTE] = ACTIONS(2421),
    [anon_sym_u8_DQUOTE] = ACTIONS(2421),
    [anon_sym_DQUOTE] = ACTIONS(2421),
    [sym_true] = ACTIONS(2419),
    [sym_false] = ACTIONS(2419),
    [anon_sym_NULL] = ACTIONS(2419),
    [anon_sym_nullptr] = ACTIONS(2419),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2419),
    [anon_sym_decltype] = ACTIONS(2419),
    [anon_sym_explicit] = ACTIONS(2419),
    [anon_sym_typename] = ACTIONS(2419),
    [anon_sym_template] = ACTIONS(2419),
    [anon_sym_operator] = ACTIONS(2419),
    [anon_sym_try] = ACTIONS(2419),
    [anon_sym_delete] = ACTIONS(2419),
    [anon_sym_throw] = ACTIONS(2419),
    [anon_sym_namespace] = ACTIONS(2419),
    [anon_sym_using] = ACTIONS(2419),
    [anon_sym_static_assert] = ACTIONS(2419),
    [anon_sym_concept] = ACTIONS(2419),
    [anon_sym_co_return] = ACTIONS(2419),
    [anon_sym_co_yield] = ACTIONS(2419),
    [anon_sym_R_DQUOTE] = ACTIONS(2421),
    [anon_sym_LR_DQUOTE] = ACTIONS(2421),
    [anon_sym_uR_DQUOTE] = ACTIONS(2421),
    [anon_sym_UR_DQUOTE] = ACTIONS(2421),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2421),
    [anon_sym_co_await] = ACTIONS(2419),
    [anon_sym_new] = ACTIONS(2419),
    [anon_sym_requires] = ACTIONS(2419),
    [sym_this] = ACTIONS(2419),
    [anon_sym___launch_bounds__] = ACTIONS(2419),
  },
  [STATE(755)] = {
    [ts_builtin_sym_end] = ACTIONS(2429),
    [sym_identifier] = ACTIONS(2427),
    [aux_sym_preproc_include_token1] = ACTIONS(2427),
    [aux_sym_preproc_def_token1] = ACTIONS(2427),
    [aux_sym_preproc_if_token1] = ACTIONS(2427),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2427),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2427),
    [sym_preproc_directive] = ACTIONS(2427),
    [anon_sym_LPAREN2] = ACTIONS(2429),
    [anon_sym_BANG] = ACTIONS(2429),
    [anon_sym_TILDE] = ACTIONS(2429),
    [anon_sym_DASH] = ACTIONS(2427),
    [anon_sym_PLUS] = ACTIONS(2427),
    [anon_sym_STAR] = ACTIONS(2429),
    [anon_sym_AMP_AMP] = ACTIONS(2429),
    [anon_sym_AMP] = ACTIONS(2427),
    [anon_sym_SEMI] = ACTIONS(2429),
    [anon_sym___extension__] = ACTIONS(2427),
    [anon_sym_typedef] = ACTIONS(2427),
    [anon_sym___device__] = ACTIONS(2427),
    [anon_sym___host__] = ACTIONS(2427),
    [anon_sym___global__] = ACTIONS(2427),
    [anon_sym___forceinline__] = ACTIONS(2427),
    [anon_sym___noinline__] = ACTIONS(2427),
    [anon_sym_virtual] = ACTIONS(2427),
    [anon_sym_extern] = ACTIONS(2427),
    [anon_sym___attribute__] = ACTIONS(2427),
    [anon_sym___attribute] = ACTIONS(2427),
    [anon_sym_COLON_COLON] = ACTIONS(2429),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2429),
    [anon_sym___declspec] = ACTIONS(2427),
    [anon_sym___based] = ACTIONS(2427),
    [anon_sym___cdecl] = ACTIONS(2427),
    [anon_sym___clrcall] = ACTIONS(2427),
    [anon_sym___stdcall] = ACTIONS(2427),
    [anon_sym___fastcall] = ACTIONS(2427),
    [anon_sym___thiscall] = ACTIONS(2427),
    [anon_sym___vectorcall] = ACTIONS(2427),
    [anon_sym_LBRACE] = ACTIONS(2429),
    [anon_sym_signed] = ACTIONS(2427),
    [anon_sym_unsigned] = ACTIONS(2427),
    [anon_sym_long] = ACTIONS(2427),
    [anon_sym_short] = ACTIONS(2427),
    [anon_sym_LBRACK] = ACTIONS(2427),
    [anon_sym_static] = ACTIONS(2427),
    [anon_sym_register] = ACTIONS(2427),
    [anon_sym_inline] = ACTIONS(2427),
    [anon_sym___inline] = ACTIONS(2427),
    [anon_sym___inline__] = ACTIONS(2427),
    [anon_sym___forceinline] = ACTIONS(2427),
    [anon_sym_thread_local] = ACTIONS(2427),
    [anon_sym___thread] = ACTIONS(2427),
    [anon_sym_const] = ACTIONS(2427),
    [anon_sym_constexpr] = ACTIONS(2427),
    [anon_sym_volatile] = ACTIONS(2427),
    [anon_sym_restrict] = ACTIONS(2427),
    [anon_sym___restrict__] = ACTIONS(2427),
    [anon_sym__Atomic] = ACTIONS(2427),
    [anon_sym__Noreturn] = ACTIONS(2427),
    [anon_sym_noreturn] = ACTIONS(2427),
    [anon_sym__Nonnull] = ACTIONS(2427),
    [anon_sym_mutable] = ACTIONS(2427),
    [anon_sym_constinit] = ACTIONS(2427),
    [anon_sym_consteval] = ACTIONS(2427),
    [anon_sym___shared__] = ACTIONS(2427),
    [anon_sym___local__] = ACTIONS(2427),
    [anon_sym___constant__] = ACTIONS(2427),
    [anon_sym___managed__] = ACTIONS(2427),
    [anon_sym___grid_constant__] = ACTIONS(2427),
    [anon_sym_alignas] = ACTIONS(2427),
    [anon_sym__Alignas] = ACTIONS(2427),
    [sym_primitive_type] = ACTIONS(2427),
    [anon_sym_enum] = ACTIONS(2427),
    [anon_sym_class] = ACTIONS(2427),
    [anon_sym_struct] = ACTIONS(2427),
    [anon_sym_union] = ACTIONS(2427),
    [anon_sym_if] = ACTIONS(2427),
    [anon_sym_switch] = ACTIONS(2427),
    [anon_sym_case] = ACTIONS(2427),
    [anon_sym_default] = ACTIONS(2427),
    [anon_sym_while] = ACTIONS(2427),
    [anon_sym_do] = ACTIONS(2427),
    [anon_sym_for] = ACTIONS(2427),
    [anon_sym_return] = ACTIONS(2427),
    [anon_sym_break] = ACTIONS(2427),
    [anon_sym_continue] = ACTIONS(2427),
    [anon_sym_goto] = ACTIONS(2427),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_compl] = ACTIONS(2427),
    [anon_sym_DASH_DASH] = ACTIONS(2429),
    [anon_sym_PLUS_PLUS] = ACTIONS(2429),
    [anon_sym_sizeof] = ACTIONS(2427),
    [anon_sym___alignof__] = ACTIONS(2427),
    [anon_sym___alignof] = ACTIONS(2427),
    [anon_sym__alignof] = ACTIONS(2427),
    [anon_sym_alignof] = ACTIONS(2427),
    [anon_sym__Alignof] = ACTIONS(2427),
    [anon_sym_offsetof] = ACTIONS(2427),
    [anon_sym__Generic] = ACTIONS(2427),
    [anon_sym_asm] = ACTIONS(2427),
    [anon_sym___asm__] = ACTIONS(2427),
    [anon_sym___asm] = ACTIONS(2427),
    [sym_number_literal] = ACTIONS(2429),
    [anon_sym_L_SQUOTE] = ACTIONS(2429),
    [anon_sym_u_SQUOTE] = ACTIONS(2429),
    [anon_sym_U_SQUOTE] = ACTIONS(2429),
    [anon_sym_u8_SQUOTE] = ACTIONS(2429),
    [anon_sym_SQUOTE] = ACTIONS(2429),
    [anon_sym_L_DQUOTE] = ACTIONS(2429),
    [anon_sym_u_DQUOTE] = ACTIONS(2429),
    [anon_sym_U_DQUOTE] = ACTIONS(2429),
    [anon_sym_u8_DQUOTE] = ACTIONS(2429),
    [anon_sym_DQUOTE] = ACTIONS(2429),
    [sym_true] = ACTIONS(2427),
    [sym_false] = ACTIONS(2427),
    [anon_sym_NULL] = ACTIONS(2427),
    [anon_sym_nullptr] = ACTIONS(2427),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2427),
    [anon_sym_decltype] = ACTIONS(2427),
    [anon_sym_explicit] = ACTIONS(2427),
    [anon_sym_typename] = ACTIONS(2427),
    [anon_sym_template] = ACTIONS(2427),
    [anon_sym_operator] = ACTIONS(2427),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_delete] = ACTIONS(2427),
    [anon_sym_throw] = ACTIONS(2427),
    [anon_sym_namespace] = ACTIONS(2427),
    [anon_sym_using] = ACTIONS(2427),
    [anon_sym_static_assert] = ACTIONS(2427),
    [anon_sym_concept] = ACTIONS(2427),
    [anon_sym_co_return] = ACTIONS(2427),
    [anon_sym_co_yield] = ACTIONS(2427),
    [anon_sym_R_DQUOTE] = ACTIONS(2429),
    [anon_sym_LR_DQUOTE] = ACTIONS(2429),
    [anon_sym_uR_DQUOTE] = ACTIONS(2429),
    [anon_sym_UR_DQUOTE] = ACTIONS(2429),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2429),
    [anon_sym_co_await] = ACTIONS(2427),
    [anon_sym_new] = ACTIONS(2427),
    [anon_sym_requires] = ACTIONS(2427),
    [sym_this] = ACTIONS(2427),
    [anon_sym___launch_bounds__] = ACTIONS(2427),
  },
  [STATE(756)] = {
    [ts_builtin_sym_end] = ACTIONS(2487),
    [sym_identifier] = ACTIONS(2485),
    [aux_sym_preproc_include_token1] = ACTIONS(2485),
    [aux_sym_preproc_def_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2485),
    [sym_preproc_directive] = ACTIONS(2485),
    [anon_sym_LPAREN2] = ACTIONS(2487),
    [anon_sym_BANG] = ACTIONS(2487),
    [anon_sym_TILDE] = ACTIONS(2487),
    [anon_sym_DASH] = ACTIONS(2485),
    [anon_sym_PLUS] = ACTIONS(2485),
    [anon_sym_STAR] = ACTIONS(2487),
    [anon_sym_AMP_AMP] = ACTIONS(2487),
    [anon_sym_AMP] = ACTIONS(2485),
    [anon_sym_SEMI] = ACTIONS(2487),
    [anon_sym___extension__] = ACTIONS(2485),
    [anon_sym_typedef] = ACTIONS(2485),
    [anon_sym___device__] = ACTIONS(2485),
    [anon_sym___host__] = ACTIONS(2485),
    [anon_sym___global__] = ACTIONS(2485),
    [anon_sym___forceinline__] = ACTIONS(2485),
    [anon_sym___noinline__] = ACTIONS(2485),
    [anon_sym_virtual] = ACTIONS(2485),
    [anon_sym_extern] = ACTIONS(2485),
    [anon_sym___attribute__] = ACTIONS(2485),
    [anon_sym___attribute] = ACTIONS(2485),
    [anon_sym_COLON_COLON] = ACTIONS(2487),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2487),
    [anon_sym___declspec] = ACTIONS(2485),
    [anon_sym___based] = ACTIONS(2485),
    [anon_sym___cdecl] = ACTIONS(2485),
    [anon_sym___clrcall] = ACTIONS(2485),
    [anon_sym___stdcall] = ACTIONS(2485),
    [anon_sym___fastcall] = ACTIONS(2485),
    [anon_sym___thiscall] = ACTIONS(2485),
    [anon_sym___vectorcall] = ACTIONS(2485),
    [anon_sym_LBRACE] = ACTIONS(2487),
    [anon_sym_signed] = ACTIONS(2485),
    [anon_sym_unsigned] = ACTIONS(2485),
    [anon_sym_long] = ACTIONS(2485),
    [anon_sym_short] = ACTIONS(2485),
    [anon_sym_LBRACK] = ACTIONS(2485),
    [anon_sym_static] = ACTIONS(2485),
    [anon_sym_register] = ACTIONS(2485),
    [anon_sym_inline] = ACTIONS(2485),
    [anon_sym___inline] = ACTIONS(2485),
    [anon_sym___inline__] = ACTIONS(2485),
    [anon_sym___forceinline] = ACTIONS(2485),
    [anon_sym_thread_local] = ACTIONS(2485),
    [anon_sym___thread] = ACTIONS(2485),
    [anon_sym_const] = ACTIONS(2485),
    [anon_sym_constexpr] = ACTIONS(2485),
    [anon_sym_volatile] = ACTIONS(2485),
    [anon_sym_restrict] = ACTIONS(2485),
    [anon_sym___restrict__] = ACTIONS(2485),
    [anon_sym__Atomic] = ACTIONS(2485),
    [anon_sym__Noreturn] = ACTIONS(2485),
    [anon_sym_noreturn] = ACTIONS(2485),
    [anon_sym__Nonnull] = ACTIONS(2485),
    [anon_sym_mutable] = ACTIONS(2485),
    [anon_sym_constinit] = ACTIONS(2485),
    [anon_sym_consteval] = ACTIONS(2485),
    [anon_sym___shared__] = ACTIONS(2485),
    [anon_sym___local__] = ACTIONS(2485),
    [anon_sym___constant__] = ACTIONS(2485),
    [anon_sym___managed__] = ACTIONS(2485),
    [anon_sym___grid_constant__] = ACTIONS(2485),
    [anon_sym_alignas] = ACTIONS(2485),
    [anon_sym__Alignas] = ACTIONS(2485),
    [sym_primitive_type] = ACTIONS(2485),
    [anon_sym_enum] = ACTIONS(2485),
    [anon_sym_class] = ACTIONS(2485),
    [anon_sym_struct] = ACTIONS(2485),
    [anon_sym_union] = ACTIONS(2485),
    [anon_sym_if] = ACTIONS(2485),
    [anon_sym_switch] = ACTIONS(2485),
    [anon_sym_case] = ACTIONS(2485),
    [anon_sym_default] = ACTIONS(2485),
    [anon_sym_while] = ACTIONS(2485),
    [anon_sym_do] = ACTIONS(2485),
    [anon_sym_for] = ACTIONS(2485),
    [anon_sym_return] = ACTIONS(2485),
    [anon_sym_break] = ACTIONS(2485),
    [anon_sym_continue] = ACTIONS(2485),
    [anon_sym_goto] = ACTIONS(2485),
    [anon_sym_not] = ACTIONS(2485),
    [anon_sym_compl] = ACTIONS(2485),
    [anon_sym_DASH_DASH] = ACTIONS(2487),
    [anon_sym_PLUS_PLUS] = ACTIONS(2487),
    [anon_sym_sizeof] = ACTIONS(2485),
    [anon_sym___alignof__] = ACTIONS(2485),
    [anon_sym___alignof] = ACTIONS(2485),
    [anon_sym__alignof] = ACTIONS(2485),
    [anon_sym_alignof] = ACTIONS(2485),
    [anon_sym__Alignof] = ACTIONS(2485),
    [anon_sym_offsetof] = ACTIONS(2485),
    [anon_sym__Generic] = ACTIONS(2485),
    [anon_sym_asm] = ACTIONS(2485),
    [anon_sym___asm__] = ACTIONS(2485),
    [anon_sym___asm] = ACTIONS(2485),
    [sym_number_literal] = ACTIONS(2487),
    [anon_sym_L_SQUOTE] = ACTIONS(2487),
    [anon_sym_u_SQUOTE] = ACTIONS(2487),
    [anon_sym_U_SQUOTE] = ACTIONS(2487),
    [anon_sym_u8_SQUOTE] = ACTIONS(2487),
    [anon_sym_SQUOTE] = ACTIONS(2487),
    [anon_sym_L_DQUOTE] = ACTIONS(2487),
    [anon_sym_u_DQUOTE] = ACTIONS(2487),
    [anon_sym_U_DQUOTE] = ACTIONS(2487),
    [anon_sym_u8_DQUOTE] = ACTIONS(2487),
    [anon_sym_DQUOTE] = ACTIONS(2487),
    [sym_true] = ACTIONS(2485),
    [sym_false] = ACTIONS(2485),
    [anon_sym_NULL] = ACTIONS(2485),
    [anon_sym_nullptr] = ACTIONS(2485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2485),
    [anon_sym_decltype] = ACTIONS(2485),
    [anon_sym_explicit] = ACTIONS(2485),
    [anon_sym_typename] = ACTIONS(2485),
    [anon_sym_template] = ACTIONS(2485),
    [anon_sym_operator] = ACTIONS(2485),
    [anon_sym_try] = ACTIONS(2485),
    [anon_sym_delete] = ACTIONS(2485),
    [anon_sym_throw] = ACTIONS(2485),
    [anon_sym_namespace] = ACTIONS(2485),
    [anon_sym_using] = ACTIONS(2485),
    [anon_sym_static_assert] = ACTIONS(2485),
    [anon_sym_concept] = ACTIONS(2485),
    [anon_sym_co_return] = ACTIONS(2485),
    [anon_sym_co_yield] = ACTIONS(2485),
    [anon_sym_R_DQUOTE] = ACTIONS(2487),
    [anon_sym_LR_DQUOTE] = ACTIONS(2487),
    [anon_sym_uR_DQUOTE] = ACTIONS(2487),
    [anon_sym_UR_DQUOTE] = ACTIONS(2487),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2487),
    [anon_sym_co_await] = ACTIONS(2485),
    [anon_sym_new] = ACTIONS(2485),
    [anon_sym_requires] = ACTIONS(2485),
    [sym_this] = ACTIONS(2485),
    [anon_sym___launch_bounds__] = ACTIONS(2485),
  },
  [STATE(757)] = {
    [ts_builtin_sym_end] = ACTIONS(2495),
    [sym_identifier] = ACTIONS(2493),
    [aux_sym_preproc_include_token1] = ACTIONS(2493),
    [aux_sym_preproc_def_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2493),
    [sym_preproc_directive] = ACTIONS(2493),
    [anon_sym_LPAREN2] = ACTIONS(2495),
    [anon_sym_BANG] = ACTIONS(2495),
    [anon_sym_TILDE] = ACTIONS(2495),
    [anon_sym_DASH] = ACTIONS(2493),
    [anon_sym_PLUS] = ACTIONS(2493),
    [anon_sym_STAR] = ACTIONS(2495),
    [anon_sym_AMP_AMP] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(2493),
    [anon_sym_SEMI] = ACTIONS(2495),
    [anon_sym___extension__] = ACTIONS(2493),
    [anon_sym_typedef] = ACTIONS(2493),
    [anon_sym___device__] = ACTIONS(2493),
    [anon_sym___host__] = ACTIONS(2493),
    [anon_sym___global__] = ACTIONS(2493),
    [anon_sym___forceinline__] = ACTIONS(2493),
    [anon_sym___noinline__] = ACTIONS(2493),
    [anon_sym_virtual] = ACTIONS(2493),
    [anon_sym_extern] = ACTIONS(2493),
    [anon_sym___attribute__] = ACTIONS(2493),
    [anon_sym___attribute] = ACTIONS(2493),
    [anon_sym_COLON_COLON] = ACTIONS(2495),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2495),
    [anon_sym___declspec] = ACTIONS(2493),
    [anon_sym___based] = ACTIONS(2493),
    [anon_sym___cdecl] = ACTIONS(2493),
    [anon_sym___clrcall] = ACTIONS(2493),
    [anon_sym___stdcall] = ACTIONS(2493),
    [anon_sym___fastcall] = ACTIONS(2493),
    [anon_sym___thiscall] = ACTIONS(2493),
    [anon_sym___vectorcall] = ACTIONS(2493),
    [anon_sym_LBRACE] = ACTIONS(2495),
    [anon_sym_signed] = ACTIONS(2493),
    [anon_sym_unsigned] = ACTIONS(2493),
    [anon_sym_long] = ACTIONS(2493),
    [anon_sym_short] = ACTIONS(2493),
    [anon_sym_LBRACK] = ACTIONS(2493),
    [anon_sym_static] = ACTIONS(2493),
    [anon_sym_register] = ACTIONS(2493),
    [anon_sym_inline] = ACTIONS(2493),
    [anon_sym___inline] = ACTIONS(2493),
    [anon_sym___inline__] = ACTIONS(2493),
    [anon_sym___forceinline] = ACTIONS(2493),
    [anon_sym_thread_local] = ACTIONS(2493),
    [anon_sym___thread] = ACTIONS(2493),
    [anon_sym_const] = ACTIONS(2493),
    [anon_sym_constexpr] = ACTIONS(2493),
    [anon_sym_volatile] = ACTIONS(2493),
    [anon_sym_restrict] = ACTIONS(2493),
    [anon_sym___restrict__] = ACTIONS(2493),
    [anon_sym__Atomic] = ACTIONS(2493),
    [anon_sym__Noreturn] = ACTIONS(2493),
    [anon_sym_noreturn] = ACTIONS(2493),
    [anon_sym__Nonnull] = ACTIONS(2493),
    [anon_sym_mutable] = ACTIONS(2493),
    [anon_sym_constinit] = ACTIONS(2493),
    [anon_sym_consteval] = ACTIONS(2493),
    [anon_sym___shared__] = ACTIONS(2493),
    [anon_sym___local__] = ACTIONS(2493),
    [anon_sym___constant__] = ACTIONS(2493),
    [anon_sym___managed__] = ACTIONS(2493),
    [anon_sym___grid_constant__] = ACTIONS(2493),
    [anon_sym_alignas] = ACTIONS(2493),
    [anon_sym__Alignas] = ACTIONS(2493),
    [sym_primitive_type] = ACTIONS(2493),
    [anon_sym_enum] = ACTIONS(2493),
    [anon_sym_class] = ACTIONS(2493),
    [anon_sym_struct] = ACTIONS(2493),
    [anon_sym_union] = ACTIONS(2493),
    [anon_sym_if] = ACTIONS(2493),
    [anon_sym_switch] = ACTIONS(2493),
    [anon_sym_case] = ACTIONS(2493),
    [anon_sym_default] = ACTIONS(2493),
    [anon_sym_while] = ACTIONS(2493),
    [anon_sym_do] = ACTIONS(2493),
    [anon_sym_for] = ACTIONS(2493),
    [anon_sym_return] = ACTIONS(2493),
    [anon_sym_break] = ACTIONS(2493),
    [anon_sym_continue] = ACTIONS(2493),
    [anon_sym_goto] = ACTIONS(2493),
    [anon_sym_not] = ACTIONS(2493),
    [anon_sym_compl] = ACTIONS(2493),
    [anon_sym_DASH_DASH] = ACTIONS(2495),
    [anon_sym_PLUS_PLUS] = ACTIONS(2495),
    [anon_sym_sizeof] = ACTIONS(2493),
    [anon_sym___alignof__] = ACTIONS(2493),
    [anon_sym___alignof] = ACTIONS(2493),
    [anon_sym__alignof] = ACTIONS(2493),
    [anon_sym_alignof] = ACTIONS(2493),
    [anon_sym__Alignof] = ACTIONS(2493),
    [anon_sym_offsetof] = ACTIONS(2493),
    [anon_sym__Generic] = ACTIONS(2493),
    [anon_sym_asm] = ACTIONS(2493),
    [anon_sym___asm__] = ACTIONS(2493),
    [anon_sym___asm] = ACTIONS(2493),
    [sym_number_literal] = ACTIONS(2495),
    [anon_sym_L_SQUOTE] = ACTIONS(2495),
    [anon_sym_u_SQUOTE] = ACTIONS(2495),
    [anon_sym_U_SQUOTE] = ACTIONS(2495),
    [anon_sym_u8_SQUOTE] = ACTIONS(2495),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_L_DQUOTE] = ACTIONS(2495),
    [anon_sym_u_DQUOTE] = ACTIONS(2495),
    [anon_sym_U_DQUOTE] = ACTIONS(2495),
    [anon_sym_u8_DQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2495),
    [sym_true] = ACTIONS(2493),
    [sym_false] = ACTIONS(2493),
    [anon_sym_NULL] = ACTIONS(2493),
    [anon_sym_nullptr] = ACTIONS(2493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2493),
    [anon_sym_decltype] = ACTIONS(2493),
    [anon_sym_explicit] = ACTIONS(2493),
    [anon_sym_typename] = ACTIONS(2493),
    [anon_sym_template] = ACTIONS(2493),
    [anon_sym_operator] = ACTIONS(2493),
    [anon_sym_try] = ACTIONS(2493),
    [anon_sym_delete] = ACTIONS(2493),
    [anon_sym_throw] = ACTIONS(2493),
    [anon_sym_namespace] = ACTIONS(2493),
    [anon_sym_using] = ACTIONS(2493),
    [anon_sym_static_assert] = ACTIONS(2493),
    [anon_sym_concept] = ACTIONS(2493),
    [anon_sym_co_return] = ACTIONS(2493),
    [anon_sym_co_yield] = ACTIONS(2493),
    [anon_sym_R_DQUOTE] = ACTIONS(2495),
    [anon_sym_LR_DQUOTE] = ACTIONS(2495),
    [anon_sym_uR_DQUOTE] = ACTIONS(2495),
    [anon_sym_UR_DQUOTE] = ACTIONS(2495),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2495),
    [anon_sym_co_await] = ACTIONS(2493),
    [anon_sym_new] = ACTIONS(2493),
    [anon_sym_requires] = ACTIONS(2493),
    [sym_this] = ACTIONS(2493),
    [anon_sym___launch_bounds__] = ACTIONS(2493),
  },
  [STATE(758)] = {
    [sym_type_qualifier] = STATE(3563),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(4837),
    [sym_sized_type_specifier] = STATE(2127),
    [sym_enum_specifier] = STATE(2127),
    [sym_struct_specifier] = STATE(2127),
    [sym_union_specifier] = STATE(2127),
    [sym_expression] = STATE(5319),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_type_descriptor] = STATE(8896),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_placeholder_type_specifier] = STATE(2127),
    [sym_decltype_auto] = STATE(2123),
    [sym_decltype] = STATE(2072),
    [sym_class_specifier] = STATE(2127),
    [sym__class_name] = STATE(8212),
    [sym_dependent_type] = STATE(2127),
    [sym_template_type] = STATE(5576),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6260),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(5601),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym__type_definition_type_repeat1] = STATE(3563),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4448),
    [sym_identifier] = ACTIONS(3508),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3510),
    [anon_sym___global__] = ACTIONS(65),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_signed] = ACTIONS(1872),
    [anon_sym_unsigned] = ACTIONS(1872),
    [anon_sym_long] = ACTIONS(1872),
    [anon_sym_short] = ACTIONS(1872),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3512),
    [anon_sym_enum] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_struct] = ACTIONS(1882),
    [anon_sym_union] = ACTIONS(1884),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1908),
    [anon_sym_decltype] = ACTIONS(1910),
    [anon_sym_typename] = ACTIONS(1912),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(759)] = {
    [ts_builtin_sym_end] = ACTIONS(2575),
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [anon_sym___asm] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(760)] = {
    [ts_builtin_sym_end] = ACTIONS(2441),
    [sym_identifier] = ACTIONS(2439),
    [aux_sym_preproc_include_token1] = ACTIONS(2439),
    [aux_sym_preproc_def_token1] = ACTIONS(2439),
    [aux_sym_preproc_if_token1] = ACTIONS(2439),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2439),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2439),
    [sym_preproc_directive] = ACTIONS(2439),
    [anon_sym_LPAREN2] = ACTIONS(2441),
    [anon_sym_BANG] = ACTIONS(2441),
    [anon_sym_TILDE] = ACTIONS(2441),
    [anon_sym_DASH] = ACTIONS(2439),
    [anon_sym_PLUS] = ACTIONS(2439),
    [anon_sym_STAR] = ACTIONS(2441),
    [anon_sym_AMP_AMP] = ACTIONS(2441),
    [anon_sym_AMP] = ACTIONS(2439),
    [anon_sym_SEMI] = ACTIONS(2441),
    [anon_sym___extension__] = ACTIONS(2439),
    [anon_sym_typedef] = ACTIONS(2439),
    [anon_sym___device__] = ACTIONS(2439),
    [anon_sym___host__] = ACTIONS(2439),
    [anon_sym___global__] = ACTIONS(2439),
    [anon_sym___forceinline__] = ACTIONS(2439),
    [anon_sym___noinline__] = ACTIONS(2439),
    [anon_sym_virtual] = ACTIONS(2439),
    [anon_sym_extern] = ACTIONS(2439),
    [anon_sym___attribute__] = ACTIONS(2439),
    [anon_sym___attribute] = ACTIONS(2439),
    [anon_sym_COLON_COLON] = ACTIONS(2441),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2441),
    [anon_sym___declspec] = ACTIONS(2439),
    [anon_sym___based] = ACTIONS(2439),
    [anon_sym___cdecl] = ACTIONS(2439),
    [anon_sym___clrcall] = ACTIONS(2439),
    [anon_sym___stdcall] = ACTIONS(2439),
    [anon_sym___fastcall] = ACTIONS(2439),
    [anon_sym___thiscall] = ACTIONS(2439),
    [anon_sym___vectorcall] = ACTIONS(2439),
    [anon_sym_LBRACE] = ACTIONS(2441),
    [anon_sym_signed] = ACTIONS(2439),
    [anon_sym_unsigned] = ACTIONS(2439),
    [anon_sym_long] = ACTIONS(2439),
    [anon_sym_short] = ACTIONS(2439),
    [anon_sym_LBRACK] = ACTIONS(2439),
    [anon_sym_static] = ACTIONS(2439),
    [anon_sym_register] = ACTIONS(2439),
    [anon_sym_inline] = ACTIONS(2439),
    [anon_sym___inline] = ACTIONS(2439),
    [anon_sym___inline__] = ACTIONS(2439),
    [anon_sym___forceinline] = ACTIONS(2439),
    [anon_sym_thread_local] = ACTIONS(2439),
    [anon_sym___thread] = ACTIONS(2439),
    [anon_sym_const] = ACTIONS(2439),
    [anon_sym_constexpr] = ACTIONS(2439),
    [anon_sym_volatile] = ACTIONS(2439),
    [anon_sym_restrict] = ACTIONS(2439),
    [anon_sym___restrict__] = ACTIONS(2439),
    [anon_sym__Atomic] = ACTIONS(2439),
    [anon_sym__Noreturn] = ACTIONS(2439),
    [anon_sym_noreturn] = ACTIONS(2439),
    [anon_sym__Nonnull] = ACTIONS(2439),
    [anon_sym_mutable] = ACTIONS(2439),
    [anon_sym_constinit] = ACTIONS(2439),
    [anon_sym_consteval] = ACTIONS(2439),
    [anon_sym___shared__] = ACTIONS(2439),
    [anon_sym___local__] = ACTIONS(2439),
    [anon_sym___constant__] = ACTIONS(2439),
    [anon_sym___managed__] = ACTIONS(2439),
    [anon_sym___grid_constant__] = ACTIONS(2439),
    [anon_sym_alignas] = ACTIONS(2439),
    [anon_sym__Alignas] = ACTIONS(2439),
    [sym_primitive_type] = ACTIONS(2439),
    [anon_sym_enum] = ACTIONS(2439),
    [anon_sym_class] = ACTIONS(2439),
    [anon_sym_struct] = ACTIONS(2439),
    [anon_sym_union] = ACTIONS(2439),
    [anon_sym_if] = ACTIONS(2439),
    [anon_sym_switch] = ACTIONS(2439),
    [anon_sym_case] = ACTIONS(2439),
    [anon_sym_default] = ACTIONS(2439),
    [anon_sym_while] = ACTIONS(2439),
    [anon_sym_do] = ACTIONS(2439),
    [anon_sym_for] = ACTIONS(2439),
    [anon_sym_return] = ACTIONS(2439),
    [anon_sym_break] = ACTIONS(2439),
    [anon_sym_continue] = ACTIONS(2439),
    [anon_sym_goto] = ACTIONS(2439),
    [anon_sym_not] = ACTIONS(2439),
    [anon_sym_compl] = ACTIONS(2439),
    [anon_sym_DASH_DASH] = ACTIONS(2441),
    [anon_sym_PLUS_PLUS] = ACTIONS(2441),
    [anon_sym_sizeof] = ACTIONS(2439),
    [anon_sym___alignof__] = ACTIONS(2439),
    [anon_sym___alignof] = ACTIONS(2439),
    [anon_sym__alignof] = ACTIONS(2439),
    [anon_sym_alignof] = ACTIONS(2439),
    [anon_sym__Alignof] = ACTIONS(2439),
    [anon_sym_offsetof] = ACTIONS(2439),
    [anon_sym__Generic] = ACTIONS(2439),
    [anon_sym_asm] = ACTIONS(2439),
    [anon_sym___asm__] = ACTIONS(2439),
    [anon_sym___asm] = ACTIONS(2439),
    [sym_number_literal] = ACTIONS(2441),
    [anon_sym_L_SQUOTE] = ACTIONS(2441),
    [anon_sym_u_SQUOTE] = ACTIONS(2441),
    [anon_sym_U_SQUOTE] = ACTIONS(2441),
    [anon_sym_u8_SQUOTE] = ACTIONS(2441),
    [anon_sym_SQUOTE] = ACTIONS(2441),
    [anon_sym_L_DQUOTE] = ACTIONS(2441),
    [anon_sym_u_DQUOTE] = ACTIONS(2441),
    [anon_sym_U_DQUOTE] = ACTIONS(2441),
    [anon_sym_u8_DQUOTE] = ACTIONS(2441),
    [anon_sym_DQUOTE] = ACTIONS(2441),
    [sym_true] = ACTIONS(2439),
    [sym_false] = ACTIONS(2439),
    [anon_sym_NULL] = ACTIONS(2439),
    [anon_sym_nullptr] = ACTIONS(2439),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2439),
    [anon_sym_decltype] = ACTIONS(2439),
    [anon_sym_explicit] = ACTIONS(2439),
    [anon_sym_typename] = ACTIONS(2439),
    [anon_sym_template] = ACTIONS(2439),
    [anon_sym_operator] = ACTIONS(2439),
    [anon_sym_try] = ACTIONS(2439),
    [anon_sym_delete] = ACTIONS(2439),
    [anon_sym_throw] = ACTIONS(2439),
    [anon_sym_namespace] = ACTIONS(2439),
    [anon_sym_using] = ACTIONS(2439),
    [anon_sym_static_assert] = ACTIONS(2439),
    [anon_sym_concept] = ACTIONS(2439),
    [anon_sym_co_return] = ACTIONS(2439),
    [anon_sym_co_yield] = ACTIONS(2439),
    [anon_sym_R_DQUOTE] = ACTIONS(2441),
    [anon_sym_LR_DQUOTE] = ACTIONS(2441),
    [anon_sym_uR_DQUOTE] = ACTIONS(2441),
    [anon_sym_UR_DQUOTE] = ACTIONS(2441),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2441),
    [anon_sym_co_await] = ACTIONS(2439),
    [anon_sym_new] = ACTIONS(2439),
    [anon_sym_requires] = ACTIONS(2439),
    [sym_this] = ACTIONS(2439),
    [anon_sym___launch_bounds__] = ACTIONS(2439),
  },
  [STATE(761)] = {
    [ts_builtin_sym_end] = ACTIONS(2445),
    [sym_identifier] = ACTIONS(2443),
    [aux_sym_preproc_include_token1] = ACTIONS(2443),
    [aux_sym_preproc_def_token1] = ACTIONS(2443),
    [aux_sym_preproc_if_token1] = ACTIONS(2443),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2443),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2443),
    [sym_preproc_directive] = ACTIONS(2443),
    [anon_sym_LPAREN2] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(2445),
    [anon_sym_TILDE] = ACTIONS(2445),
    [anon_sym_DASH] = ACTIONS(2443),
    [anon_sym_PLUS] = ACTIONS(2443),
    [anon_sym_STAR] = ACTIONS(2445),
    [anon_sym_AMP_AMP] = ACTIONS(2445),
    [anon_sym_AMP] = ACTIONS(2443),
    [anon_sym_SEMI] = ACTIONS(2445),
    [anon_sym___extension__] = ACTIONS(2443),
    [anon_sym_typedef] = ACTIONS(2443),
    [anon_sym___device__] = ACTIONS(2443),
    [anon_sym___host__] = ACTIONS(2443),
    [anon_sym___global__] = ACTIONS(2443),
    [anon_sym___forceinline__] = ACTIONS(2443),
    [anon_sym___noinline__] = ACTIONS(2443),
    [anon_sym_virtual] = ACTIONS(2443),
    [anon_sym_extern] = ACTIONS(2443),
    [anon_sym___attribute__] = ACTIONS(2443),
    [anon_sym___attribute] = ACTIONS(2443),
    [anon_sym_COLON_COLON] = ACTIONS(2445),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2445),
    [anon_sym___declspec] = ACTIONS(2443),
    [anon_sym___based] = ACTIONS(2443),
    [anon_sym___cdecl] = ACTIONS(2443),
    [anon_sym___clrcall] = ACTIONS(2443),
    [anon_sym___stdcall] = ACTIONS(2443),
    [anon_sym___fastcall] = ACTIONS(2443),
    [anon_sym___thiscall] = ACTIONS(2443),
    [anon_sym___vectorcall] = ACTIONS(2443),
    [anon_sym_LBRACE] = ACTIONS(2445),
    [anon_sym_signed] = ACTIONS(2443),
    [anon_sym_unsigned] = ACTIONS(2443),
    [anon_sym_long] = ACTIONS(2443),
    [anon_sym_short] = ACTIONS(2443),
    [anon_sym_LBRACK] = ACTIONS(2443),
    [anon_sym_static] = ACTIONS(2443),
    [anon_sym_register] = ACTIONS(2443),
    [anon_sym_inline] = ACTIONS(2443),
    [anon_sym___inline] = ACTIONS(2443),
    [anon_sym___inline__] = ACTIONS(2443),
    [anon_sym___forceinline] = ACTIONS(2443),
    [anon_sym_thread_local] = ACTIONS(2443),
    [anon_sym___thread] = ACTIONS(2443),
    [anon_sym_const] = ACTIONS(2443),
    [anon_sym_constexpr] = ACTIONS(2443),
    [anon_sym_volatile] = ACTIONS(2443),
    [anon_sym_restrict] = ACTIONS(2443),
    [anon_sym___restrict__] = ACTIONS(2443),
    [anon_sym__Atomic] = ACTIONS(2443),
    [anon_sym__Noreturn] = ACTIONS(2443),
    [anon_sym_noreturn] = ACTIONS(2443),
    [anon_sym__Nonnull] = ACTIONS(2443),
    [anon_sym_mutable] = ACTIONS(2443),
    [anon_sym_constinit] = ACTIONS(2443),
    [anon_sym_consteval] = ACTIONS(2443),
    [anon_sym___shared__] = ACTIONS(2443),
    [anon_sym___local__] = ACTIONS(2443),
    [anon_sym___constant__] = ACTIONS(2443),
    [anon_sym___managed__] = ACTIONS(2443),
    [anon_sym___grid_constant__] = ACTIONS(2443),
    [anon_sym_alignas] = ACTIONS(2443),
    [anon_sym__Alignas] = ACTIONS(2443),
    [sym_primitive_type] = ACTIONS(2443),
    [anon_sym_enum] = ACTIONS(2443),
    [anon_sym_class] = ACTIONS(2443),
    [anon_sym_struct] = ACTIONS(2443),
    [anon_sym_union] = ACTIONS(2443),
    [anon_sym_if] = ACTIONS(2443),
    [anon_sym_switch] = ACTIONS(2443),
    [anon_sym_case] = ACTIONS(2443),
    [anon_sym_default] = ACTIONS(2443),
    [anon_sym_while] = ACTIONS(2443),
    [anon_sym_do] = ACTIONS(2443),
    [anon_sym_for] = ACTIONS(2443),
    [anon_sym_return] = ACTIONS(2443),
    [anon_sym_break] = ACTIONS(2443),
    [anon_sym_continue] = ACTIONS(2443),
    [anon_sym_goto] = ACTIONS(2443),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_compl] = ACTIONS(2443),
    [anon_sym_DASH_DASH] = ACTIONS(2445),
    [anon_sym_PLUS_PLUS] = ACTIONS(2445),
    [anon_sym_sizeof] = ACTIONS(2443),
    [anon_sym___alignof__] = ACTIONS(2443),
    [anon_sym___alignof] = ACTIONS(2443),
    [anon_sym__alignof] = ACTIONS(2443),
    [anon_sym_alignof] = ACTIONS(2443),
    [anon_sym__Alignof] = ACTIONS(2443),
    [anon_sym_offsetof] = ACTIONS(2443),
    [anon_sym__Generic] = ACTIONS(2443),
    [anon_sym_asm] = ACTIONS(2443),
    [anon_sym___asm__] = ACTIONS(2443),
    [anon_sym___asm] = ACTIONS(2443),
    [sym_number_literal] = ACTIONS(2445),
    [anon_sym_L_SQUOTE] = ACTIONS(2445),
    [anon_sym_u_SQUOTE] = ACTIONS(2445),
    [anon_sym_U_SQUOTE] = ACTIONS(2445),
    [anon_sym_u8_SQUOTE] = ACTIONS(2445),
    [anon_sym_SQUOTE] = ACTIONS(2445),
    [anon_sym_L_DQUOTE] = ACTIONS(2445),
    [anon_sym_u_DQUOTE] = ACTIONS(2445),
    [anon_sym_U_DQUOTE] = ACTIONS(2445),
    [anon_sym_u8_DQUOTE] = ACTIONS(2445),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_true] = ACTIONS(2443),
    [sym_false] = ACTIONS(2443),
    [anon_sym_NULL] = ACTIONS(2443),
    [anon_sym_nullptr] = ACTIONS(2443),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2443),
    [anon_sym_decltype] = ACTIONS(2443),
    [anon_sym_explicit] = ACTIONS(2443),
    [anon_sym_typename] = ACTIONS(2443),
    [anon_sym_template] = ACTIONS(2443),
    [anon_sym_operator] = ACTIONS(2443),
    [anon_sym_try] = ACTIONS(2443),
    [anon_sym_delete] = ACTIONS(2443),
    [anon_sym_throw] = ACTIONS(2443),
    [anon_sym_namespace] = ACTIONS(2443),
    [anon_sym_using] = ACTIONS(2443),
    [anon_sym_static_assert] = ACTIONS(2443),
    [anon_sym_concept] = ACTIONS(2443),
    [anon_sym_co_return] = ACTIONS(2443),
    [anon_sym_co_yield] = ACTIONS(2443),
    [anon_sym_R_DQUOTE] = ACTIONS(2445),
    [anon_sym_LR_DQUOTE] = ACTIONS(2445),
    [anon_sym_uR_DQUOTE] = ACTIONS(2445),
    [anon_sym_UR_DQUOTE] = ACTIONS(2445),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2445),
    [anon_sym_co_await] = ACTIONS(2443),
    [anon_sym_new] = ACTIONS(2443),
    [anon_sym_requires] = ACTIONS(2443),
    [sym_this] = ACTIONS(2443),
    [anon_sym___launch_bounds__] = ACTIONS(2443),
  },
  [STATE(762)] = {
    [ts_builtin_sym_end] = ACTIONS(2453),
    [sym_identifier] = ACTIONS(2451),
    [aux_sym_preproc_include_token1] = ACTIONS(2451),
    [aux_sym_preproc_def_token1] = ACTIONS(2451),
    [aux_sym_preproc_if_token1] = ACTIONS(2451),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2451),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2451),
    [sym_preproc_directive] = ACTIONS(2451),
    [anon_sym_LPAREN2] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(2453),
    [anon_sym_TILDE] = ACTIONS(2453),
    [anon_sym_DASH] = ACTIONS(2451),
    [anon_sym_PLUS] = ACTIONS(2451),
    [anon_sym_STAR] = ACTIONS(2453),
    [anon_sym_AMP_AMP] = ACTIONS(2453),
    [anon_sym_AMP] = ACTIONS(2451),
    [anon_sym_SEMI] = ACTIONS(2453),
    [anon_sym___extension__] = ACTIONS(2451),
    [anon_sym_typedef] = ACTIONS(2451),
    [anon_sym___device__] = ACTIONS(2451),
    [anon_sym___host__] = ACTIONS(2451),
    [anon_sym___global__] = ACTIONS(2451),
    [anon_sym___forceinline__] = ACTIONS(2451),
    [anon_sym___noinline__] = ACTIONS(2451),
    [anon_sym_virtual] = ACTIONS(2451),
    [anon_sym_extern] = ACTIONS(2451),
    [anon_sym___attribute__] = ACTIONS(2451),
    [anon_sym___attribute] = ACTIONS(2451),
    [anon_sym_COLON_COLON] = ACTIONS(2453),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2453),
    [anon_sym___declspec] = ACTIONS(2451),
    [anon_sym___based] = ACTIONS(2451),
    [anon_sym___cdecl] = ACTIONS(2451),
    [anon_sym___clrcall] = ACTIONS(2451),
    [anon_sym___stdcall] = ACTIONS(2451),
    [anon_sym___fastcall] = ACTIONS(2451),
    [anon_sym___thiscall] = ACTIONS(2451),
    [anon_sym___vectorcall] = ACTIONS(2451),
    [anon_sym_LBRACE] = ACTIONS(2453),
    [anon_sym_signed] = ACTIONS(2451),
    [anon_sym_unsigned] = ACTIONS(2451),
    [anon_sym_long] = ACTIONS(2451),
    [anon_sym_short] = ACTIONS(2451),
    [anon_sym_LBRACK] = ACTIONS(2451),
    [anon_sym_static] = ACTIONS(2451),
    [anon_sym_register] = ACTIONS(2451),
    [anon_sym_inline] = ACTIONS(2451),
    [anon_sym___inline] = ACTIONS(2451),
    [anon_sym___inline__] = ACTIONS(2451),
    [anon_sym___forceinline] = ACTIONS(2451),
    [anon_sym_thread_local] = ACTIONS(2451),
    [anon_sym___thread] = ACTIONS(2451),
    [anon_sym_const] = ACTIONS(2451),
    [anon_sym_constexpr] = ACTIONS(2451),
    [anon_sym_volatile] = ACTIONS(2451),
    [anon_sym_restrict] = ACTIONS(2451),
    [anon_sym___restrict__] = ACTIONS(2451),
    [anon_sym__Atomic] = ACTIONS(2451),
    [anon_sym__Noreturn] = ACTIONS(2451),
    [anon_sym_noreturn] = ACTIONS(2451),
    [anon_sym__Nonnull] = ACTIONS(2451),
    [anon_sym_mutable] = ACTIONS(2451),
    [anon_sym_constinit] = ACTIONS(2451),
    [anon_sym_consteval] = ACTIONS(2451),
    [anon_sym___shared__] = ACTIONS(2451),
    [anon_sym___local__] = ACTIONS(2451),
    [anon_sym___constant__] = ACTIONS(2451),
    [anon_sym___managed__] = ACTIONS(2451),
    [anon_sym___grid_constant__] = ACTIONS(2451),
    [anon_sym_alignas] = ACTIONS(2451),
    [anon_sym__Alignas] = ACTIONS(2451),
    [sym_primitive_type] = ACTIONS(2451),
    [anon_sym_enum] = ACTIONS(2451),
    [anon_sym_class] = ACTIONS(2451),
    [anon_sym_struct] = ACTIONS(2451),
    [anon_sym_union] = ACTIONS(2451),
    [anon_sym_if] = ACTIONS(2451),
    [anon_sym_switch] = ACTIONS(2451),
    [anon_sym_case] = ACTIONS(2451),
    [anon_sym_default] = ACTIONS(2451),
    [anon_sym_while] = ACTIONS(2451),
    [anon_sym_do] = ACTIONS(2451),
    [anon_sym_for] = ACTIONS(2451),
    [anon_sym_return] = ACTIONS(2451),
    [anon_sym_break] = ACTIONS(2451),
    [anon_sym_continue] = ACTIONS(2451),
    [anon_sym_goto] = ACTIONS(2451),
    [anon_sym_not] = ACTIONS(2451),
    [anon_sym_compl] = ACTIONS(2451),
    [anon_sym_DASH_DASH] = ACTIONS(2453),
    [anon_sym_PLUS_PLUS] = ACTIONS(2453),
    [anon_sym_sizeof] = ACTIONS(2451),
    [anon_sym___alignof__] = ACTIONS(2451),
    [anon_sym___alignof] = ACTIONS(2451),
    [anon_sym__alignof] = ACTIONS(2451),
    [anon_sym_alignof] = ACTIONS(2451),
    [anon_sym__Alignof] = ACTIONS(2451),
    [anon_sym_offsetof] = ACTIONS(2451),
    [anon_sym__Generic] = ACTIONS(2451),
    [anon_sym_asm] = ACTIONS(2451),
    [anon_sym___asm__] = ACTIONS(2451),
    [anon_sym___asm] = ACTIONS(2451),
    [sym_number_literal] = ACTIONS(2453),
    [anon_sym_L_SQUOTE] = ACTIONS(2453),
    [anon_sym_u_SQUOTE] = ACTIONS(2453),
    [anon_sym_U_SQUOTE] = ACTIONS(2453),
    [anon_sym_u8_SQUOTE] = ACTIONS(2453),
    [anon_sym_SQUOTE] = ACTIONS(2453),
    [anon_sym_L_DQUOTE] = ACTIONS(2453),
    [anon_sym_u_DQUOTE] = ACTIONS(2453),
    [anon_sym_U_DQUOTE] = ACTIONS(2453),
    [anon_sym_u8_DQUOTE] = ACTIONS(2453),
    [anon_sym_DQUOTE] = ACTIONS(2453),
    [sym_true] = ACTIONS(2451),
    [sym_false] = ACTIONS(2451),
    [anon_sym_NULL] = ACTIONS(2451),
    [anon_sym_nullptr] = ACTIONS(2451),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2451),
    [anon_sym_decltype] = ACTIONS(2451),
    [anon_sym_explicit] = ACTIONS(2451),
    [anon_sym_typename] = ACTIONS(2451),
    [anon_sym_template] = ACTIONS(2451),
    [anon_sym_operator] = ACTIONS(2451),
    [anon_sym_try] = ACTIONS(2451),
    [anon_sym_delete] = ACTIONS(2451),
    [anon_sym_throw] = ACTIONS(2451),
    [anon_sym_namespace] = ACTIONS(2451),
    [anon_sym_using] = ACTIONS(2451),
    [anon_sym_static_assert] = ACTIONS(2451),
    [anon_sym_concept] = ACTIONS(2451),
    [anon_sym_co_return] = ACTIONS(2451),
    [anon_sym_co_yield] = ACTIONS(2451),
    [anon_sym_R_DQUOTE] = ACTIONS(2453),
    [anon_sym_LR_DQUOTE] = ACTIONS(2453),
    [anon_sym_uR_DQUOTE] = ACTIONS(2453),
    [anon_sym_UR_DQUOTE] = ACTIONS(2453),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2453),
    [anon_sym_co_await] = ACTIONS(2451),
    [anon_sym_new] = ACTIONS(2451),
    [anon_sym_requires] = ACTIONS(2451),
    [sym_this] = ACTIONS(2451),
    [anon_sym___launch_bounds__] = ACTIONS(2451),
  },
  [STATE(763)] = {
    [ts_builtin_sym_end] = ACTIONS(2523),
    [sym_identifier] = ACTIONS(2521),
    [aux_sym_preproc_include_token1] = ACTIONS(2521),
    [aux_sym_preproc_def_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2521),
    [sym_preproc_directive] = ACTIONS(2521),
    [anon_sym_LPAREN2] = ACTIONS(2523),
    [anon_sym_BANG] = ACTIONS(2523),
    [anon_sym_TILDE] = ACTIONS(2523),
    [anon_sym_DASH] = ACTIONS(2521),
    [anon_sym_PLUS] = ACTIONS(2521),
    [anon_sym_STAR] = ACTIONS(2523),
    [anon_sym_AMP_AMP] = ACTIONS(2523),
    [anon_sym_AMP] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym___extension__] = ACTIONS(2521),
    [anon_sym_typedef] = ACTIONS(2521),
    [anon_sym___device__] = ACTIONS(2521),
    [anon_sym___host__] = ACTIONS(2521),
    [anon_sym___global__] = ACTIONS(2521),
    [anon_sym___forceinline__] = ACTIONS(2521),
    [anon_sym___noinline__] = ACTIONS(2521),
    [anon_sym_virtual] = ACTIONS(2521),
    [anon_sym_extern] = ACTIONS(2521),
    [anon_sym___attribute__] = ACTIONS(2521),
    [anon_sym___attribute] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2523),
    [anon_sym___declspec] = ACTIONS(2521),
    [anon_sym___based] = ACTIONS(2521),
    [anon_sym___cdecl] = ACTIONS(2521),
    [anon_sym___clrcall] = ACTIONS(2521),
    [anon_sym___stdcall] = ACTIONS(2521),
    [anon_sym___fastcall] = ACTIONS(2521),
    [anon_sym___thiscall] = ACTIONS(2521),
    [anon_sym___vectorcall] = ACTIONS(2521),
    [anon_sym_LBRACE] = ACTIONS(2523),
    [anon_sym_signed] = ACTIONS(2521),
    [anon_sym_unsigned] = ACTIONS(2521),
    [anon_sym_long] = ACTIONS(2521),
    [anon_sym_short] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2521),
    [anon_sym_static] = ACTIONS(2521),
    [anon_sym_register] = ACTIONS(2521),
    [anon_sym_inline] = ACTIONS(2521),
    [anon_sym___inline] = ACTIONS(2521),
    [anon_sym___inline__] = ACTIONS(2521),
    [anon_sym___forceinline] = ACTIONS(2521),
    [anon_sym_thread_local] = ACTIONS(2521),
    [anon_sym___thread] = ACTIONS(2521),
    [anon_sym_const] = ACTIONS(2521),
    [anon_sym_constexpr] = ACTIONS(2521),
    [anon_sym_volatile] = ACTIONS(2521),
    [anon_sym_restrict] = ACTIONS(2521),
    [anon_sym___restrict__] = ACTIONS(2521),
    [anon_sym__Atomic] = ACTIONS(2521),
    [anon_sym__Noreturn] = ACTIONS(2521),
    [anon_sym_noreturn] = ACTIONS(2521),
    [anon_sym__Nonnull] = ACTIONS(2521),
    [anon_sym_mutable] = ACTIONS(2521),
    [anon_sym_constinit] = ACTIONS(2521),
    [anon_sym_consteval] = ACTIONS(2521),
    [anon_sym___shared__] = ACTIONS(2521),
    [anon_sym___local__] = ACTIONS(2521),
    [anon_sym___constant__] = ACTIONS(2521),
    [anon_sym___managed__] = ACTIONS(2521),
    [anon_sym___grid_constant__] = ACTIONS(2521),
    [anon_sym_alignas] = ACTIONS(2521),
    [anon_sym__Alignas] = ACTIONS(2521),
    [sym_primitive_type] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_class] = ACTIONS(2521),
    [anon_sym_struct] = ACTIONS(2521),
    [anon_sym_union] = ACTIONS(2521),
    [anon_sym_if] = ACTIONS(2521),
    [anon_sym_switch] = ACTIONS(2521),
    [anon_sym_case] = ACTIONS(2521),
    [anon_sym_default] = ACTIONS(2521),
    [anon_sym_while] = ACTIONS(2521),
    [anon_sym_do] = ACTIONS(2521),
    [anon_sym_for] = ACTIONS(2521),
    [anon_sym_return] = ACTIONS(2521),
    [anon_sym_break] = ACTIONS(2521),
    [anon_sym_continue] = ACTIONS(2521),
    [anon_sym_goto] = ACTIONS(2521),
    [anon_sym_not] = ACTIONS(2521),
    [anon_sym_compl] = ACTIONS(2521),
    [anon_sym_DASH_DASH] = ACTIONS(2523),
    [anon_sym_PLUS_PLUS] = ACTIONS(2523),
    [anon_sym_sizeof] = ACTIONS(2521),
    [anon_sym___alignof__] = ACTIONS(2521),
    [anon_sym___alignof] = ACTIONS(2521),
    [anon_sym__alignof] = ACTIONS(2521),
    [anon_sym_alignof] = ACTIONS(2521),
    [anon_sym__Alignof] = ACTIONS(2521),
    [anon_sym_offsetof] = ACTIONS(2521),
    [anon_sym__Generic] = ACTIONS(2521),
    [anon_sym_asm] = ACTIONS(2521),
    [anon_sym___asm__] = ACTIONS(2521),
    [anon_sym___asm] = ACTIONS(2521),
    [sym_number_literal] = ACTIONS(2523),
    [anon_sym_L_SQUOTE] = ACTIONS(2523),
    [anon_sym_u_SQUOTE] = ACTIONS(2523),
    [anon_sym_U_SQUOTE] = ACTIONS(2523),
    [anon_sym_u8_SQUOTE] = ACTIONS(2523),
    [anon_sym_SQUOTE] = ACTIONS(2523),
    [anon_sym_L_DQUOTE] = ACTIONS(2523),
    [anon_sym_u_DQUOTE] = ACTIONS(2523),
    [anon_sym_U_DQUOTE] = ACTIONS(2523),
    [anon_sym_u8_DQUOTE] = ACTIONS(2523),
    [anon_sym_DQUOTE] = ACTIONS(2523),
    [sym_true] = ACTIONS(2521),
    [sym_false] = ACTIONS(2521),
    [anon_sym_NULL] = ACTIONS(2521),
    [anon_sym_nullptr] = ACTIONS(2521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2521),
    [anon_sym_decltype] = ACTIONS(2521),
    [anon_sym_explicit] = ACTIONS(2521),
    [anon_sym_typename] = ACTIONS(2521),
    [anon_sym_template] = ACTIONS(2521),
    [anon_sym_operator] = ACTIONS(2521),
    [anon_sym_try] = ACTIONS(2521),
    [anon_sym_delete] = ACTIONS(2521),
    [anon_sym_throw] = ACTIONS(2521),
    [anon_sym_namespace] = ACTIONS(2521),
    [anon_sym_using] = ACTIONS(2521),
    [anon_sym_static_assert] = ACTIONS(2521),
    [anon_sym_concept] = ACTIONS(2521),
    [anon_sym_co_return] = ACTIONS(2521),
    [anon_sym_co_yield] = ACTIONS(2521),
    [anon_sym_R_DQUOTE] = ACTIONS(2523),
    [anon_sym_LR_DQUOTE] = ACTIONS(2523),
    [anon_sym_uR_DQUOTE] = ACTIONS(2523),
    [anon_sym_UR_DQUOTE] = ACTIONS(2523),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2523),
    [anon_sym_co_await] = ACTIONS(2521),
    [anon_sym_new] = ACTIONS(2521),
    [anon_sym_requires] = ACTIONS(2521),
    [sym_this] = ACTIONS(2521),
    [anon_sym___launch_bounds__] = ACTIONS(2521),
  },
  [STATE(764)] = {
    [ts_builtin_sym_end] = ACTIONS(2379),
    [sym_identifier] = ACTIONS(2377),
    [aux_sym_preproc_include_token1] = ACTIONS(2377),
    [aux_sym_preproc_def_token1] = ACTIONS(2377),
    [aux_sym_preproc_if_token1] = ACTIONS(2377),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2377),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2377),
    [sym_preproc_directive] = ACTIONS(2377),
    [anon_sym_LPAREN2] = ACTIONS(2379),
    [anon_sym_BANG] = ACTIONS(2379),
    [anon_sym_TILDE] = ACTIONS(2379),
    [anon_sym_DASH] = ACTIONS(2377),
    [anon_sym_PLUS] = ACTIONS(2377),
    [anon_sym_STAR] = ACTIONS(2379),
    [anon_sym_AMP_AMP] = ACTIONS(2379),
    [anon_sym_AMP] = ACTIONS(2377),
    [anon_sym_SEMI] = ACTIONS(2379),
    [anon_sym___extension__] = ACTIONS(2377),
    [anon_sym_typedef] = ACTIONS(2377),
    [anon_sym___device__] = ACTIONS(2377),
    [anon_sym___host__] = ACTIONS(2377),
    [anon_sym___global__] = ACTIONS(2377),
    [anon_sym___forceinline__] = ACTIONS(2377),
    [anon_sym___noinline__] = ACTIONS(2377),
    [anon_sym_virtual] = ACTIONS(2377),
    [anon_sym_extern] = ACTIONS(2377),
    [anon_sym___attribute__] = ACTIONS(2377),
    [anon_sym___attribute] = ACTIONS(2377),
    [anon_sym_COLON_COLON] = ACTIONS(2379),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2379),
    [anon_sym___declspec] = ACTIONS(2377),
    [anon_sym___based] = ACTIONS(2377),
    [anon_sym___cdecl] = ACTIONS(2377),
    [anon_sym___clrcall] = ACTIONS(2377),
    [anon_sym___stdcall] = ACTIONS(2377),
    [anon_sym___fastcall] = ACTIONS(2377),
    [anon_sym___thiscall] = ACTIONS(2377),
    [anon_sym___vectorcall] = ACTIONS(2377),
    [anon_sym_LBRACE] = ACTIONS(2379),
    [anon_sym_signed] = ACTIONS(2377),
    [anon_sym_unsigned] = ACTIONS(2377),
    [anon_sym_long] = ACTIONS(2377),
    [anon_sym_short] = ACTIONS(2377),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_static] = ACTIONS(2377),
    [anon_sym_register] = ACTIONS(2377),
    [anon_sym_inline] = ACTIONS(2377),
    [anon_sym___inline] = ACTIONS(2377),
    [anon_sym___inline__] = ACTIONS(2377),
    [anon_sym___forceinline] = ACTIONS(2377),
    [anon_sym_thread_local] = ACTIONS(2377),
    [anon_sym___thread] = ACTIONS(2377),
    [anon_sym_const] = ACTIONS(2377),
    [anon_sym_constexpr] = ACTIONS(2377),
    [anon_sym_volatile] = ACTIONS(2377),
    [anon_sym_restrict] = ACTIONS(2377),
    [anon_sym___restrict__] = ACTIONS(2377),
    [anon_sym__Atomic] = ACTIONS(2377),
    [anon_sym__Noreturn] = ACTIONS(2377),
    [anon_sym_noreturn] = ACTIONS(2377),
    [anon_sym__Nonnull] = ACTIONS(2377),
    [anon_sym_mutable] = ACTIONS(2377),
    [anon_sym_constinit] = ACTIONS(2377),
    [anon_sym_consteval] = ACTIONS(2377),
    [anon_sym___shared__] = ACTIONS(2377),
    [anon_sym___local__] = ACTIONS(2377),
    [anon_sym___constant__] = ACTIONS(2377),
    [anon_sym___managed__] = ACTIONS(2377),
    [anon_sym___grid_constant__] = ACTIONS(2377),
    [anon_sym_alignas] = ACTIONS(2377),
    [anon_sym__Alignas] = ACTIONS(2377),
    [sym_primitive_type] = ACTIONS(2377),
    [anon_sym_enum] = ACTIONS(2377),
    [anon_sym_class] = ACTIONS(2377),
    [anon_sym_struct] = ACTIONS(2377),
    [anon_sym_union] = ACTIONS(2377),
    [anon_sym_if] = ACTIONS(2377),
    [anon_sym_switch] = ACTIONS(2377),
    [anon_sym_case] = ACTIONS(2377),
    [anon_sym_default] = ACTIONS(2377),
    [anon_sym_while] = ACTIONS(2377),
    [anon_sym_do] = ACTIONS(2377),
    [anon_sym_for] = ACTIONS(2377),
    [anon_sym_return] = ACTIONS(2377),
    [anon_sym_break] = ACTIONS(2377),
    [anon_sym_continue] = ACTIONS(2377),
    [anon_sym_goto] = ACTIONS(2377),
    [anon_sym_not] = ACTIONS(2377),
    [anon_sym_compl] = ACTIONS(2377),
    [anon_sym_DASH_DASH] = ACTIONS(2379),
    [anon_sym_PLUS_PLUS] = ACTIONS(2379),
    [anon_sym_sizeof] = ACTIONS(2377),
    [anon_sym___alignof__] = ACTIONS(2377),
    [anon_sym___alignof] = ACTIONS(2377),
    [anon_sym__alignof] = ACTIONS(2377),
    [anon_sym_alignof] = ACTIONS(2377),
    [anon_sym__Alignof] = ACTIONS(2377),
    [anon_sym_offsetof] = ACTIONS(2377),
    [anon_sym__Generic] = ACTIONS(2377),
    [anon_sym_asm] = ACTIONS(2377),
    [anon_sym___asm__] = ACTIONS(2377),
    [anon_sym___asm] = ACTIONS(2377),
    [sym_number_literal] = ACTIONS(2379),
    [anon_sym_L_SQUOTE] = ACTIONS(2379),
    [anon_sym_u_SQUOTE] = ACTIONS(2379),
    [anon_sym_U_SQUOTE] = ACTIONS(2379),
    [anon_sym_u8_SQUOTE] = ACTIONS(2379),
    [anon_sym_SQUOTE] = ACTIONS(2379),
    [anon_sym_L_DQUOTE] = ACTIONS(2379),
    [anon_sym_u_DQUOTE] = ACTIONS(2379),
    [anon_sym_U_DQUOTE] = ACTIONS(2379),
    [anon_sym_u8_DQUOTE] = ACTIONS(2379),
    [anon_sym_DQUOTE] = ACTIONS(2379),
    [sym_true] = ACTIONS(2377),
    [sym_false] = ACTIONS(2377),
    [anon_sym_NULL] = ACTIONS(2377),
    [anon_sym_nullptr] = ACTIONS(2377),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2377),
    [anon_sym_decltype] = ACTIONS(2377),
    [anon_sym_explicit] = ACTIONS(2377),
    [anon_sym_typename] = ACTIONS(2377),
    [anon_sym_template] = ACTIONS(2377),
    [anon_sym_operator] = ACTIONS(2377),
    [anon_sym_try] = ACTIONS(2377),
    [anon_sym_delete] = ACTIONS(2377),
    [anon_sym_throw] = ACTIONS(2377),
    [anon_sym_namespace] = ACTIONS(2377),
    [anon_sym_using] = ACTIONS(2377),
    [anon_sym_static_assert] = ACTIONS(2377),
    [anon_sym_concept] = ACTIONS(2377),
    [anon_sym_co_return] = ACTIONS(2377),
    [anon_sym_co_yield] = ACTIONS(2377),
    [anon_sym_R_DQUOTE] = ACTIONS(2379),
    [anon_sym_LR_DQUOTE] = ACTIONS(2379),
    [anon_sym_uR_DQUOTE] = ACTIONS(2379),
    [anon_sym_UR_DQUOTE] = ACTIONS(2379),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2379),
    [anon_sym_co_await] = ACTIONS(2377),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_requires] = ACTIONS(2377),
    [sym_this] = ACTIONS(2377),
    [anon_sym___launch_bounds__] = ACTIONS(2377),
  },
  [STATE(765)] = {
    [ts_builtin_sym_end] = ACTIONS(2527),
    [sym_identifier] = ACTIONS(2525),
    [aux_sym_preproc_include_token1] = ACTIONS(2525),
    [aux_sym_preproc_def_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2525),
    [sym_preproc_directive] = ACTIONS(2525),
    [anon_sym_LPAREN2] = ACTIONS(2527),
    [anon_sym_BANG] = ACTIONS(2527),
    [anon_sym_TILDE] = ACTIONS(2527),
    [anon_sym_DASH] = ACTIONS(2525),
    [anon_sym_PLUS] = ACTIONS(2525),
    [anon_sym_STAR] = ACTIONS(2527),
    [anon_sym_AMP_AMP] = ACTIONS(2527),
    [anon_sym_AMP] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym___extension__] = ACTIONS(2525),
    [anon_sym_typedef] = ACTIONS(2525),
    [anon_sym___device__] = ACTIONS(2525),
    [anon_sym___host__] = ACTIONS(2525),
    [anon_sym___global__] = ACTIONS(2525),
    [anon_sym___forceinline__] = ACTIONS(2525),
    [anon_sym___noinline__] = ACTIONS(2525),
    [anon_sym_virtual] = ACTIONS(2525),
    [anon_sym_extern] = ACTIONS(2525),
    [anon_sym___attribute__] = ACTIONS(2525),
    [anon_sym___attribute] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2527),
    [anon_sym___declspec] = ACTIONS(2525),
    [anon_sym___based] = ACTIONS(2525),
    [anon_sym___cdecl] = ACTIONS(2525),
    [anon_sym___clrcall] = ACTIONS(2525),
    [anon_sym___stdcall] = ACTIONS(2525),
    [anon_sym___fastcall] = ACTIONS(2525),
    [anon_sym___thiscall] = ACTIONS(2525),
    [anon_sym___vectorcall] = ACTIONS(2525),
    [anon_sym_LBRACE] = ACTIONS(2527),
    [anon_sym_signed] = ACTIONS(2525),
    [anon_sym_unsigned] = ACTIONS(2525),
    [anon_sym_long] = ACTIONS(2525),
    [anon_sym_short] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2525),
    [anon_sym_static] = ACTIONS(2525),
    [anon_sym_register] = ACTIONS(2525),
    [anon_sym_inline] = ACTIONS(2525),
    [anon_sym___inline] = ACTIONS(2525),
    [anon_sym___inline__] = ACTIONS(2525),
    [anon_sym___forceinline] = ACTIONS(2525),
    [anon_sym_thread_local] = ACTIONS(2525),
    [anon_sym___thread] = ACTIONS(2525),
    [anon_sym_const] = ACTIONS(2525),
    [anon_sym_constexpr] = ACTIONS(2525),
    [anon_sym_volatile] = ACTIONS(2525),
    [anon_sym_restrict] = ACTIONS(2525),
    [anon_sym___restrict__] = ACTIONS(2525),
    [anon_sym__Atomic] = ACTIONS(2525),
    [anon_sym__Noreturn] = ACTIONS(2525),
    [anon_sym_noreturn] = ACTIONS(2525),
    [anon_sym__Nonnull] = ACTIONS(2525),
    [anon_sym_mutable] = ACTIONS(2525),
    [anon_sym_constinit] = ACTIONS(2525),
    [anon_sym_consteval] = ACTIONS(2525),
    [anon_sym___shared__] = ACTIONS(2525),
    [anon_sym___local__] = ACTIONS(2525),
    [anon_sym___constant__] = ACTIONS(2525),
    [anon_sym___managed__] = ACTIONS(2525),
    [anon_sym___grid_constant__] = ACTIONS(2525),
    [anon_sym_alignas] = ACTIONS(2525),
    [anon_sym__Alignas] = ACTIONS(2525),
    [sym_primitive_type] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_class] = ACTIONS(2525),
    [anon_sym_struct] = ACTIONS(2525),
    [anon_sym_union] = ACTIONS(2525),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_switch] = ACTIONS(2525),
    [anon_sym_case] = ACTIONS(2525),
    [anon_sym_default] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(2525),
    [anon_sym_do] = ACTIONS(2525),
    [anon_sym_for] = ACTIONS(2525),
    [anon_sym_return] = ACTIONS(2525),
    [anon_sym_break] = ACTIONS(2525),
    [anon_sym_continue] = ACTIONS(2525),
    [anon_sym_goto] = ACTIONS(2525),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_compl] = ACTIONS(2525),
    [anon_sym_DASH_DASH] = ACTIONS(2527),
    [anon_sym_PLUS_PLUS] = ACTIONS(2527),
    [anon_sym_sizeof] = ACTIONS(2525),
    [anon_sym___alignof__] = ACTIONS(2525),
    [anon_sym___alignof] = ACTIONS(2525),
    [anon_sym__alignof] = ACTIONS(2525),
    [anon_sym_alignof] = ACTIONS(2525),
    [anon_sym__Alignof] = ACTIONS(2525),
    [anon_sym_offsetof] = ACTIONS(2525),
    [anon_sym__Generic] = ACTIONS(2525),
    [anon_sym_asm] = ACTIONS(2525),
    [anon_sym___asm__] = ACTIONS(2525),
    [anon_sym___asm] = ACTIONS(2525),
    [sym_number_literal] = ACTIONS(2527),
    [anon_sym_L_SQUOTE] = ACTIONS(2527),
    [anon_sym_u_SQUOTE] = ACTIONS(2527),
    [anon_sym_U_SQUOTE] = ACTIONS(2527),
    [anon_sym_u8_SQUOTE] = ACTIONS(2527),
    [anon_sym_SQUOTE] = ACTIONS(2527),
    [anon_sym_L_DQUOTE] = ACTIONS(2527),
    [anon_sym_u_DQUOTE] = ACTIONS(2527),
    [anon_sym_U_DQUOTE] = ACTIONS(2527),
    [anon_sym_u8_DQUOTE] = ACTIONS(2527),
    [anon_sym_DQUOTE] = ACTIONS(2527),
    [sym_true] = ACTIONS(2525),
    [sym_false] = ACTIONS(2525),
    [anon_sym_NULL] = ACTIONS(2525),
    [anon_sym_nullptr] = ACTIONS(2525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2525),
    [anon_sym_decltype] = ACTIONS(2525),
    [anon_sym_explicit] = ACTIONS(2525),
    [anon_sym_typename] = ACTIONS(2525),
    [anon_sym_template] = ACTIONS(2525),
    [anon_sym_operator] = ACTIONS(2525),
    [anon_sym_try] = ACTIONS(2525),
    [anon_sym_delete] = ACTIONS(2525),
    [anon_sym_throw] = ACTIONS(2525),
    [anon_sym_namespace] = ACTIONS(2525),
    [anon_sym_using] = ACTIONS(2525),
    [anon_sym_static_assert] = ACTIONS(2525),
    [anon_sym_concept] = ACTIONS(2525),
    [anon_sym_co_return] = ACTIONS(2525),
    [anon_sym_co_yield] = ACTIONS(2525),
    [anon_sym_R_DQUOTE] = ACTIONS(2527),
    [anon_sym_LR_DQUOTE] = ACTIONS(2527),
    [anon_sym_uR_DQUOTE] = ACTIONS(2527),
    [anon_sym_UR_DQUOTE] = ACTIONS(2527),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2527),
    [anon_sym_co_await] = ACTIONS(2525),
    [anon_sym_new] = ACTIONS(2525),
    [anon_sym_requires] = ACTIONS(2525),
    [sym_this] = ACTIONS(2525),
    [anon_sym___launch_bounds__] = ACTIONS(2525),
  },
  [STATE(766)] = {
    [ts_builtin_sym_end] = ACTIONS(2563),
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_include_token1] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym___device__] = ACTIONS(2561),
    [anon_sym___host__] = ACTIONS(2561),
    [anon_sym___global__] = ACTIONS(2561),
    [anon_sym___forceinline__] = ACTIONS(2561),
    [anon_sym___noinline__] = ACTIONS(2561),
    [anon_sym_virtual] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym___attribute] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym___cdecl] = ACTIONS(2561),
    [anon_sym___clrcall] = ACTIONS(2561),
    [anon_sym___stdcall] = ACTIONS(2561),
    [anon_sym___fastcall] = ACTIONS(2561),
    [anon_sym___thiscall] = ACTIONS(2561),
    [anon_sym___vectorcall] = ACTIONS(2561),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym__Nonnull] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym___shared__] = ACTIONS(2561),
    [anon_sym___local__] = ACTIONS(2561),
    [anon_sym___constant__] = ACTIONS(2561),
    [anon_sym___managed__] = ACTIONS(2561),
    [anon_sym___grid_constant__] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_switch] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_default] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_do] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_return] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_goto] = ACTIONS(2561),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_compl] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2563),
    [anon_sym_sizeof] = ACTIONS(2561),
    [anon_sym___alignof__] = ACTIONS(2561),
    [anon_sym___alignof] = ACTIONS(2561),
    [anon_sym__alignof] = ACTIONS(2561),
    [anon_sym_alignof] = ACTIONS(2561),
    [anon_sym__Alignof] = ACTIONS(2561),
    [anon_sym_offsetof] = ACTIONS(2561),
    [anon_sym__Generic] = ACTIONS(2561),
    [anon_sym_asm] = ACTIONS(2561),
    [anon_sym___asm__] = ACTIONS(2561),
    [anon_sym___asm] = ACTIONS(2561),
    [sym_number_literal] = ACTIONS(2563),
    [anon_sym_L_SQUOTE] = ACTIONS(2563),
    [anon_sym_u_SQUOTE] = ACTIONS(2563),
    [anon_sym_U_SQUOTE] = ACTIONS(2563),
    [anon_sym_u8_SQUOTE] = ACTIONS(2563),
    [anon_sym_SQUOTE] = ACTIONS(2563),
    [anon_sym_L_DQUOTE] = ACTIONS(2563),
    [anon_sym_u_DQUOTE] = ACTIONS(2563),
    [anon_sym_U_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8_DQUOTE] = ACTIONS(2563),
    [anon_sym_DQUOTE] = ACTIONS(2563),
    [sym_true] = ACTIONS(2561),
    [sym_false] = ACTIONS(2561),
    [anon_sym_NULL] = ACTIONS(2561),
    [anon_sym_nullptr] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_try] = ACTIONS(2561),
    [anon_sym_delete] = ACTIONS(2561),
    [anon_sym_throw] = ACTIONS(2561),
    [anon_sym_namespace] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_concept] = ACTIONS(2561),
    [anon_sym_co_return] = ACTIONS(2561),
    [anon_sym_co_yield] = ACTIONS(2561),
    [anon_sym_R_DQUOTE] = ACTIONS(2563),
    [anon_sym_LR_DQUOTE] = ACTIONS(2563),
    [anon_sym_uR_DQUOTE] = ACTIONS(2563),
    [anon_sym_UR_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2563),
    [anon_sym_co_await] = ACTIONS(2561),
    [anon_sym_new] = ACTIONS(2561),
    [anon_sym_requires] = ACTIONS(2561),
    [sym_this] = ACTIONS(2561),
    [anon_sym___launch_bounds__] = ACTIONS(2561),
  },
  [STATE(767)] = {
    [ts_builtin_sym_end] = ACTIONS(2425),
    [sym_identifier] = ACTIONS(2423),
    [aux_sym_preproc_include_token1] = ACTIONS(2423),
    [aux_sym_preproc_def_token1] = ACTIONS(2423),
    [aux_sym_preproc_if_token1] = ACTIONS(2423),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2423),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2423),
    [sym_preproc_directive] = ACTIONS(2423),
    [anon_sym_LPAREN2] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(2425),
    [anon_sym_TILDE] = ACTIONS(2425),
    [anon_sym_DASH] = ACTIONS(2423),
    [anon_sym_PLUS] = ACTIONS(2423),
    [anon_sym_STAR] = ACTIONS(2425),
    [anon_sym_AMP_AMP] = ACTIONS(2425),
    [anon_sym_AMP] = ACTIONS(2423),
    [anon_sym_SEMI] = ACTIONS(2425),
    [anon_sym___extension__] = ACTIONS(2423),
    [anon_sym_typedef] = ACTIONS(2423),
    [anon_sym___device__] = ACTIONS(2423),
    [anon_sym___host__] = ACTIONS(2423),
    [anon_sym___global__] = ACTIONS(2423),
    [anon_sym___forceinline__] = ACTIONS(2423),
    [anon_sym___noinline__] = ACTIONS(2423),
    [anon_sym_virtual] = ACTIONS(2423),
    [anon_sym_extern] = ACTIONS(2423),
    [anon_sym___attribute__] = ACTIONS(2423),
    [anon_sym___attribute] = ACTIONS(2423),
    [anon_sym_COLON_COLON] = ACTIONS(2425),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2425),
    [anon_sym___declspec] = ACTIONS(2423),
    [anon_sym___based] = ACTIONS(2423),
    [anon_sym___cdecl] = ACTIONS(2423),
    [anon_sym___clrcall] = ACTIONS(2423),
    [anon_sym___stdcall] = ACTIONS(2423),
    [anon_sym___fastcall] = ACTIONS(2423),
    [anon_sym___thiscall] = ACTIONS(2423),
    [anon_sym___vectorcall] = ACTIONS(2423),
    [anon_sym_LBRACE] = ACTIONS(2425),
    [anon_sym_signed] = ACTIONS(2423),
    [anon_sym_unsigned] = ACTIONS(2423),
    [anon_sym_long] = ACTIONS(2423),
    [anon_sym_short] = ACTIONS(2423),
    [anon_sym_LBRACK] = ACTIONS(2423),
    [anon_sym_static] = ACTIONS(2423),
    [anon_sym_register] = ACTIONS(2423),
    [anon_sym_inline] = ACTIONS(2423),
    [anon_sym___inline] = ACTIONS(2423),
    [anon_sym___inline__] = ACTIONS(2423),
    [anon_sym___forceinline] = ACTIONS(2423),
    [anon_sym_thread_local] = ACTIONS(2423),
    [anon_sym___thread] = ACTIONS(2423),
    [anon_sym_const] = ACTIONS(2423),
    [anon_sym_constexpr] = ACTIONS(2423),
    [anon_sym_volatile] = ACTIONS(2423),
    [anon_sym_restrict] = ACTIONS(2423),
    [anon_sym___restrict__] = ACTIONS(2423),
    [anon_sym__Atomic] = ACTIONS(2423),
    [anon_sym__Noreturn] = ACTIONS(2423),
    [anon_sym_noreturn] = ACTIONS(2423),
    [anon_sym__Nonnull] = ACTIONS(2423),
    [anon_sym_mutable] = ACTIONS(2423),
    [anon_sym_constinit] = ACTIONS(2423),
    [anon_sym_consteval] = ACTIONS(2423),
    [anon_sym___shared__] = ACTIONS(2423),
    [anon_sym___local__] = ACTIONS(2423),
    [anon_sym___constant__] = ACTIONS(2423),
    [anon_sym___managed__] = ACTIONS(2423),
    [anon_sym___grid_constant__] = ACTIONS(2423),
    [anon_sym_alignas] = ACTIONS(2423),
    [anon_sym__Alignas] = ACTIONS(2423),
    [sym_primitive_type] = ACTIONS(2423),
    [anon_sym_enum] = ACTIONS(2423),
    [anon_sym_class] = ACTIONS(2423),
    [anon_sym_struct] = ACTIONS(2423),
    [anon_sym_union] = ACTIONS(2423),
    [anon_sym_if] = ACTIONS(2423),
    [anon_sym_switch] = ACTIONS(2423),
    [anon_sym_case] = ACTIONS(2423),
    [anon_sym_default] = ACTIONS(2423),
    [anon_sym_while] = ACTIONS(2423),
    [anon_sym_do] = ACTIONS(2423),
    [anon_sym_for] = ACTIONS(2423),
    [anon_sym_return] = ACTIONS(2423),
    [anon_sym_break] = ACTIONS(2423),
    [anon_sym_continue] = ACTIONS(2423),
    [anon_sym_goto] = ACTIONS(2423),
    [anon_sym_not] = ACTIONS(2423),
    [anon_sym_compl] = ACTIONS(2423),
    [anon_sym_DASH_DASH] = ACTIONS(2425),
    [anon_sym_PLUS_PLUS] = ACTIONS(2425),
    [anon_sym_sizeof] = ACTIONS(2423),
    [anon_sym___alignof__] = ACTIONS(2423),
    [anon_sym___alignof] = ACTIONS(2423),
    [anon_sym__alignof] = ACTIONS(2423),
    [anon_sym_alignof] = ACTIONS(2423),
    [anon_sym__Alignof] = ACTIONS(2423),
    [anon_sym_offsetof] = ACTIONS(2423),
    [anon_sym__Generic] = ACTIONS(2423),
    [anon_sym_asm] = ACTIONS(2423),
    [anon_sym___asm__] = ACTIONS(2423),
    [anon_sym___asm] = ACTIONS(2423),
    [sym_number_literal] = ACTIONS(2425),
    [anon_sym_L_SQUOTE] = ACTIONS(2425),
    [anon_sym_u_SQUOTE] = ACTIONS(2425),
    [anon_sym_U_SQUOTE] = ACTIONS(2425),
    [anon_sym_u8_SQUOTE] = ACTIONS(2425),
    [anon_sym_SQUOTE] = ACTIONS(2425),
    [anon_sym_L_DQUOTE] = ACTIONS(2425),
    [anon_sym_u_DQUOTE] = ACTIONS(2425),
    [anon_sym_U_DQUOTE] = ACTIONS(2425),
    [anon_sym_u8_DQUOTE] = ACTIONS(2425),
    [anon_sym_DQUOTE] = ACTIONS(2425),
    [sym_true] = ACTIONS(2423),
    [sym_false] = ACTIONS(2423),
    [anon_sym_NULL] = ACTIONS(2423),
    [anon_sym_nullptr] = ACTIONS(2423),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2423),
    [anon_sym_decltype] = ACTIONS(2423),
    [anon_sym_explicit] = ACTIONS(2423),
    [anon_sym_typename] = ACTIONS(2423),
    [anon_sym_template] = ACTIONS(2423),
    [anon_sym_operator] = ACTIONS(2423),
    [anon_sym_try] = ACTIONS(2423),
    [anon_sym_delete] = ACTIONS(2423),
    [anon_sym_throw] = ACTIONS(2423),
    [anon_sym_namespace] = ACTIONS(2423),
    [anon_sym_using] = ACTIONS(2423),
    [anon_sym_static_assert] = ACTIONS(2423),
    [anon_sym_concept] = ACTIONS(2423),
    [anon_sym_co_return] = ACTIONS(2423),
    [anon_sym_co_yield] = ACTIONS(2423),
    [anon_sym_R_DQUOTE] = ACTIONS(2425),
    [anon_sym_LR_DQUOTE] = ACTIONS(2425),
    [anon_sym_uR_DQUOTE] = ACTIONS(2425),
    [anon_sym_UR_DQUOTE] = ACTIONS(2425),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2425),
    [anon_sym_co_await] = ACTIONS(2423),
    [anon_sym_new] = ACTIONS(2423),
    [anon_sym_requires] = ACTIONS(2423),
    [sym_this] = ACTIONS(2423),
    [anon_sym___launch_bounds__] = ACTIONS(2423),
  },
  [STATE(768)] = {
    [ts_builtin_sym_end] = ACTIONS(2511),
    [sym_identifier] = ACTIONS(2509),
    [aux_sym_preproc_include_token1] = ACTIONS(2509),
    [aux_sym_preproc_def_token1] = ACTIONS(2509),
    [aux_sym_preproc_if_token1] = ACTIONS(2509),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2509),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2509),
    [sym_preproc_directive] = ACTIONS(2509),
    [anon_sym_LPAREN2] = ACTIONS(2511),
    [anon_sym_BANG] = ACTIONS(2511),
    [anon_sym_TILDE] = ACTIONS(2511),
    [anon_sym_DASH] = ACTIONS(2509),
    [anon_sym_PLUS] = ACTIONS(2509),
    [anon_sym_STAR] = ACTIONS(2511),
    [anon_sym_AMP_AMP] = ACTIONS(2511),
    [anon_sym_AMP] = ACTIONS(2509),
    [anon_sym_SEMI] = ACTIONS(2511),
    [anon_sym___extension__] = ACTIONS(2509),
    [anon_sym_typedef] = ACTIONS(2509),
    [anon_sym___device__] = ACTIONS(2509),
    [anon_sym___host__] = ACTIONS(2509),
    [anon_sym___global__] = ACTIONS(2509),
    [anon_sym___forceinline__] = ACTIONS(2509),
    [anon_sym___noinline__] = ACTIONS(2509),
    [anon_sym_virtual] = ACTIONS(2509),
    [anon_sym_extern] = ACTIONS(2509),
    [anon_sym___attribute__] = ACTIONS(2509),
    [anon_sym___attribute] = ACTIONS(2509),
    [anon_sym_COLON_COLON] = ACTIONS(2511),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2511),
    [anon_sym___declspec] = ACTIONS(2509),
    [anon_sym___based] = ACTIONS(2509),
    [anon_sym___cdecl] = ACTIONS(2509),
    [anon_sym___clrcall] = ACTIONS(2509),
    [anon_sym___stdcall] = ACTIONS(2509),
    [anon_sym___fastcall] = ACTIONS(2509),
    [anon_sym___thiscall] = ACTIONS(2509),
    [anon_sym___vectorcall] = ACTIONS(2509),
    [anon_sym_LBRACE] = ACTIONS(2511),
    [anon_sym_signed] = ACTIONS(2509),
    [anon_sym_unsigned] = ACTIONS(2509),
    [anon_sym_long] = ACTIONS(2509),
    [anon_sym_short] = ACTIONS(2509),
    [anon_sym_LBRACK] = ACTIONS(2509),
    [anon_sym_static] = ACTIONS(2509),
    [anon_sym_register] = ACTIONS(2509),
    [anon_sym_inline] = ACTIONS(2509),
    [anon_sym___inline] = ACTIONS(2509),
    [anon_sym___inline__] = ACTIONS(2509),
    [anon_sym___forceinline] = ACTIONS(2509),
    [anon_sym_thread_local] = ACTIONS(2509),
    [anon_sym___thread] = ACTIONS(2509),
    [anon_sym_const] = ACTIONS(2509),
    [anon_sym_constexpr] = ACTIONS(2509),
    [anon_sym_volatile] = ACTIONS(2509),
    [anon_sym_restrict] = ACTIONS(2509),
    [anon_sym___restrict__] = ACTIONS(2509),
    [anon_sym__Atomic] = ACTIONS(2509),
    [anon_sym__Noreturn] = ACTIONS(2509),
    [anon_sym_noreturn] = ACTIONS(2509),
    [anon_sym__Nonnull] = ACTIONS(2509),
    [anon_sym_mutable] = ACTIONS(2509),
    [anon_sym_constinit] = ACTIONS(2509),
    [anon_sym_consteval] = ACTIONS(2509),
    [anon_sym___shared__] = ACTIONS(2509),
    [anon_sym___local__] = ACTIONS(2509),
    [anon_sym___constant__] = ACTIONS(2509),
    [anon_sym___managed__] = ACTIONS(2509),
    [anon_sym___grid_constant__] = ACTIONS(2509),
    [anon_sym_alignas] = ACTIONS(2509),
    [anon_sym__Alignas] = ACTIONS(2509),
    [sym_primitive_type] = ACTIONS(2509),
    [anon_sym_enum] = ACTIONS(2509),
    [anon_sym_class] = ACTIONS(2509),
    [anon_sym_struct] = ACTIONS(2509),
    [anon_sym_union] = ACTIONS(2509),
    [anon_sym_if] = ACTIONS(2509),
    [anon_sym_switch] = ACTIONS(2509),
    [anon_sym_case] = ACTIONS(2509),
    [anon_sym_default] = ACTIONS(2509),
    [anon_sym_while] = ACTIONS(2509),
    [anon_sym_do] = ACTIONS(2509),
    [anon_sym_for] = ACTIONS(2509),
    [anon_sym_return] = ACTIONS(2509),
    [anon_sym_break] = ACTIONS(2509),
    [anon_sym_continue] = ACTIONS(2509),
    [anon_sym_goto] = ACTIONS(2509),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_compl] = ACTIONS(2509),
    [anon_sym_DASH_DASH] = ACTIONS(2511),
    [anon_sym_PLUS_PLUS] = ACTIONS(2511),
    [anon_sym_sizeof] = ACTIONS(2509),
    [anon_sym___alignof__] = ACTIONS(2509),
    [anon_sym___alignof] = ACTIONS(2509),
    [anon_sym__alignof] = ACTIONS(2509),
    [anon_sym_alignof] = ACTIONS(2509),
    [anon_sym__Alignof] = ACTIONS(2509),
    [anon_sym_offsetof] = ACTIONS(2509),
    [anon_sym__Generic] = ACTIONS(2509),
    [anon_sym_asm] = ACTIONS(2509),
    [anon_sym___asm__] = ACTIONS(2509),
    [anon_sym___asm] = ACTIONS(2509),
    [sym_number_literal] = ACTIONS(2511),
    [anon_sym_L_SQUOTE] = ACTIONS(2511),
    [anon_sym_u_SQUOTE] = ACTIONS(2511),
    [anon_sym_U_SQUOTE] = ACTIONS(2511),
    [anon_sym_u8_SQUOTE] = ACTIONS(2511),
    [anon_sym_SQUOTE] = ACTIONS(2511),
    [anon_sym_L_DQUOTE] = ACTIONS(2511),
    [anon_sym_u_DQUOTE] = ACTIONS(2511),
    [anon_sym_U_DQUOTE] = ACTIONS(2511),
    [anon_sym_u8_DQUOTE] = ACTIONS(2511),
    [anon_sym_DQUOTE] = ACTIONS(2511),
    [sym_true] = ACTIONS(2509),
    [sym_false] = ACTIONS(2509),
    [anon_sym_NULL] = ACTIONS(2509),
    [anon_sym_nullptr] = ACTIONS(2509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2509),
    [anon_sym_decltype] = ACTIONS(2509),
    [anon_sym_explicit] = ACTIONS(2509),
    [anon_sym_typename] = ACTIONS(2509),
    [anon_sym_template] = ACTIONS(2509),
    [anon_sym_operator] = ACTIONS(2509),
    [anon_sym_try] = ACTIONS(2509),
    [anon_sym_delete] = ACTIONS(2509),
    [anon_sym_throw] = ACTIONS(2509),
    [anon_sym_namespace] = ACTIONS(2509),
    [anon_sym_using] = ACTIONS(2509),
    [anon_sym_static_assert] = ACTIONS(2509),
    [anon_sym_concept] = ACTIONS(2509),
    [anon_sym_co_return] = ACTIONS(2509),
    [anon_sym_co_yield] = ACTIONS(2509),
    [anon_sym_R_DQUOTE] = ACTIONS(2511),
    [anon_sym_LR_DQUOTE] = ACTIONS(2511),
    [anon_sym_uR_DQUOTE] = ACTIONS(2511),
    [anon_sym_UR_DQUOTE] = ACTIONS(2511),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2511),
    [anon_sym_co_await] = ACTIONS(2509),
    [anon_sym_new] = ACTIONS(2509),
    [anon_sym_requires] = ACTIONS(2509),
    [sym_this] = ACTIONS(2509),
    [anon_sym___launch_bounds__] = ACTIONS(2509),
  },
  [STATE(769)] = {
    [ts_builtin_sym_end] = ACTIONS(2547),
    [sym_identifier] = ACTIONS(2545),
    [aux_sym_preproc_include_token1] = ACTIONS(2545),
    [aux_sym_preproc_def_token1] = ACTIONS(2545),
    [aux_sym_preproc_if_token1] = ACTIONS(2545),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2545),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2545),
    [sym_preproc_directive] = ACTIONS(2545),
    [anon_sym_LPAREN2] = ACTIONS(2547),
    [anon_sym_BANG] = ACTIONS(2547),
    [anon_sym_TILDE] = ACTIONS(2547),
    [anon_sym_DASH] = ACTIONS(2545),
    [anon_sym_PLUS] = ACTIONS(2545),
    [anon_sym_STAR] = ACTIONS(2547),
    [anon_sym_AMP_AMP] = ACTIONS(2547),
    [anon_sym_AMP] = ACTIONS(2545),
    [anon_sym_SEMI] = ACTIONS(2547),
    [anon_sym___extension__] = ACTIONS(2545),
    [anon_sym_typedef] = ACTIONS(2545),
    [anon_sym___device__] = ACTIONS(2545),
    [anon_sym___host__] = ACTIONS(2545),
    [anon_sym___global__] = ACTIONS(2545),
    [anon_sym___forceinline__] = ACTIONS(2545),
    [anon_sym___noinline__] = ACTIONS(2545),
    [anon_sym_virtual] = ACTIONS(2545),
    [anon_sym_extern] = ACTIONS(2545),
    [anon_sym___attribute__] = ACTIONS(2545),
    [anon_sym___attribute] = ACTIONS(2545),
    [anon_sym_COLON_COLON] = ACTIONS(2547),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2547),
    [anon_sym___declspec] = ACTIONS(2545),
    [anon_sym___based] = ACTIONS(2545),
    [anon_sym___cdecl] = ACTIONS(2545),
    [anon_sym___clrcall] = ACTIONS(2545),
    [anon_sym___stdcall] = ACTIONS(2545),
    [anon_sym___fastcall] = ACTIONS(2545),
    [anon_sym___thiscall] = ACTIONS(2545),
    [anon_sym___vectorcall] = ACTIONS(2545),
    [anon_sym_LBRACE] = ACTIONS(2547),
    [anon_sym_signed] = ACTIONS(2545),
    [anon_sym_unsigned] = ACTIONS(2545),
    [anon_sym_long] = ACTIONS(2545),
    [anon_sym_short] = ACTIONS(2545),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [anon_sym_static] = ACTIONS(2545),
    [anon_sym_register] = ACTIONS(2545),
    [anon_sym_inline] = ACTIONS(2545),
    [anon_sym___inline] = ACTIONS(2545),
    [anon_sym___inline__] = ACTIONS(2545),
    [anon_sym___forceinline] = ACTIONS(2545),
    [anon_sym_thread_local] = ACTIONS(2545),
    [anon_sym___thread] = ACTIONS(2545),
    [anon_sym_const] = ACTIONS(2545),
    [anon_sym_constexpr] = ACTIONS(2545),
    [anon_sym_volatile] = ACTIONS(2545),
    [anon_sym_restrict] = ACTIONS(2545),
    [anon_sym___restrict__] = ACTIONS(2545),
    [anon_sym__Atomic] = ACTIONS(2545),
    [anon_sym__Noreturn] = ACTIONS(2545),
    [anon_sym_noreturn] = ACTIONS(2545),
    [anon_sym__Nonnull] = ACTIONS(2545),
    [anon_sym_mutable] = ACTIONS(2545),
    [anon_sym_constinit] = ACTIONS(2545),
    [anon_sym_consteval] = ACTIONS(2545),
    [anon_sym___shared__] = ACTIONS(2545),
    [anon_sym___local__] = ACTIONS(2545),
    [anon_sym___constant__] = ACTIONS(2545),
    [anon_sym___managed__] = ACTIONS(2545),
    [anon_sym___grid_constant__] = ACTIONS(2545),
    [anon_sym_alignas] = ACTIONS(2545),
    [anon_sym__Alignas] = ACTIONS(2545),
    [sym_primitive_type] = ACTIONS(2545),
    [anon_sym_enum] = ACTIONS(2545),
    [anon_sym_class] = ACTIONS(2545),
    [anon_sym_struct] = ACTIONS(2545),
    [anon_sym_union] = ACTIONS(2545),
    [anon_sym_if] = ACTIONS(2545),
    [anon_sym_switch] = ACTIONS(2545),
    [anon_sym_case] = ACTIONS(2545),
    [anon_sym_default] = ACTIONS(2545),
    [anon_sym_while] = ACTIONS(2545),
    [anon_sym_do] = ACTIONS(2545),
    [anon_sym_for] = ACTIONS(2545),
    [anon_sym_return] = ACTIONS(2545),
    [anon_sym_break] = ACTIONS(2545),
    [anon_sym_continue] = ACTIONS(2545),
    [anon_sym_goto] = ACTIONS(2545),
    [anon_sym_not] = ACTIONS(2545),
    [anon_sym_compl] = ACTIONS(2545),
    [anon_sym_DASH_DASH] = ACTIONS(2547),
    [anon_sym_PLUS_PLUS] = ACTIONS(2547),
    [anon_sym_sizeof] = ACTIONS(2545),
    [anon_sym___alignof__] = ACTIONS(2545),
    [anon_sym___alignof] = ACTIONS(2545),
    [anon_sym__alignof] = ACTIONS(2545),
    [anon_sym_alignof] = ACTIONS(2545),
    [anon_sym__Alignof] = ACTIONS(2545),
    [anon_sym_offsetof] = ACTIONS(2545),
    [anon_sym__Generic] = ACTIONS(2545),
    [anon_sym_asm] = ACTIONS(2545),
    [anon_sym___asm__] = ACTIONS(2545),
    [anon_sym___asm] = ACTIONS(2545),
    [sym_number_literal] = ACTIONS(2547),
    [anon_sym_L_SQUOTE] = ACTIONS(2547),
    [anon_sym_u_SQUOTE] = ACTIONS(2547),
    [anon_sym_U_SQUOTE] = ACTIONS(2547),
    [anon_sym_u8_SQUOTE] = ACTIONS(2547),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_L_DQUOTE] = ACTIONS(2547),
    [anon_sym_u_DQUOTE] = ACTIONS(2547),
    [anon_sym_U_DQUOTE] = ACTIONS(2547),
    [anon_sym_u8_DQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2547),
    [sym_true] = ACTIONS(2545),
    [sym_false] = ACTIONS(2545),
    [anon_sym_NULL] = ACTIONS(2545),
    [anon_sym_nullptr] = ACTIONS(2545),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2545),
    [anon_sym_decltype] = ACTIONS(2545),
    [anon_sym_explicit] = ACTIONS(2545),
    [anon_sym_typename] = ACTIONS(2545),
    [anon_sym_template] = ACTIONS(2545),
    [anon_sym_operator] = ACTIONS(2545),
    [anon_sym_try] = ACTIONS(2545),
    [anon_sym_delete] = ACTIONS(2545),
    [anon_sym_throw] = ACTIONS(2545),
    [anon_sym_namespace] = ACTIONS(2545),
    [anon_sym_using] = ACTIONS(2545),
    [anon_sym_static_assert] = ACTIONS(2545),
    [anon_sym_concept] = ACTIONS(2545),
    [anon_sym_co_return] = ACTIONS(2545),
    [anon_sym_co_yield] = ACTIONS(2545),
    [anon_sym_R_DQUOTE] = ACTIONS(2547),
    [anon_sym_LR_DQUOTE] = ACTIONS(2547),
    [anon_sym_uR_DQUOTE] = ACTIONS(2547),
    [anon_sym_UR_DQUOTE] = ACTIONS(2547),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2547),
    [anon_sym_co_await] = ACTIONS(2545),
    [anon_sym_new] = ACTIONS(2545),
    [anon_sym_requires] = ACTIONS(2545),
    [sym_this] = ACTIONS(2545),
    [anon_sym___launch_bounds__] = ACTIONS(2545),
  },
  [STATE(770)] = {
    [ts_builtin_sym_end] = ACTIONS(2334),
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym___device__] = ACTIONS(2332),
    [anon_sym___host__] = ACTIONS(2332),
    [anon_sym___global__] = ACTIONS(2332),
    [anon_sym___forceinline__] = ACTIONS(2332),
    [anon_sym___noinline__] = ACTIONS(2332),
    [anon_sym_virtual] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym___attribute] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym__Nonnull] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym___shared__] = ACTIONS(2332),
    [anon_sym___local__] = ACTIONS(2332),
    [anon_sym___constant__] = ACTIONS(2332),
    [anon_sym___managed__] = ACTIONS(2332),
    [anon_sym___grid_constant__] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [anon_sym___asm] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym___launch_bounds__] = ACTIONS(2332),
  },
  [STATE(771)] = {
    [sym_preproc_def] = STATE(791),
    [sym_preproc_function_def] = STATE(791),
    [sym_preproc_call] = STATE(791),
    [sym_preproc_if_in_field_declaration_list] = STATE(791),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(791),
    [sym_type_definition] = STATE(791),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(791),
    [sym_field_declaration] = STATE(791),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(791),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(791),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(791),
    [sym_operator_cast_declaration] = STATE(791),
    [sym_constructor_or_destructor_definition] = STATE(791),
    [sym_constructor_or_destructor_declaration] = STATE(791),
    [sym_friend_declaration] = STATE(791),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(791),
    [sym_alias_declaration] = STATE(791),
    [sym_static_assert_declaration] = STATE(791),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(791),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3536),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3542),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(772)] = {
    [sym_expression] = STATE(3935),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_initializer_list] = STATE(4374),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_RPAREN] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(1790),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2633),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2633),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2633),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACE] = ACTIONS(3558),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_EQ] = ACTIONS(2633),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_STAR_EQ] = ACTIONS(2635),
    [anon_sym_SLASH_EQ] = ACTIONS(2635),
    [anon_sym_PERCENT_EQ] = ACTIONS(2635),
    [anon_sym_PLUS_EQ] = ACTIONS(2635),
    [anon_sym_DASH_EQ] = ACTIONS(2635),
    [anon_sym_LT_LT_EQ] = ACTIONS(2635),
    [anon_sym_GT_GT_EQ] = ACTIONS(2635),
    [anon_sym_AMP_EQ] = ACTIONS(2635),
    [anon_sym_CARET_EQ] = ACTIONS(2635),
    [anon_sym_PIPE_EQ] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2633),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [anon_sym_DASH_GT_STAR] = ACTIONS(2635),
    [sym_this] = ACTIONS(1828),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(773)] = {
    [sym_preproc_def] = STATE(773),
    [sym_preproc_function_def] = STATE(773),
    [sym_preproc_call] = STATE(773),
    [sym_preproc_if_in_field_declaration_list] = STATE(773),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(773),
    [sym_type_definition] = STATE(773),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6070),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6872),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(773),
    [sym_field_declaration] = STATE(773),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1760),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(773),
    [sym_operator_cast] = STATE(7436),
    [sym_inline_method_definition] = STATE(773),
    [sym__constructor_specifiers] = STATE(1760),
    [sym_operator_cast_definition] = STATE(773),
    [sym_operator_cast_declaration] = STATE(773),
    [sym_constructor_or_destructor_definition] = STATE(773),
    [sym_constructor_or_destructor_declaration] = STATE(773),
    [sym_friend_declaration] = STATE(773),
    [sym_access_specifier] = STATE(9408),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(773),
    [sym_alias_declaration] = STATE(773),
    [sym_static_assert_declaration] = STATE(773),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7436),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(773),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1760),
    [sym_identifier] = ACTIONS(2737),
    [aux_sym_preproc_def_token1] = ACTIONS(3562),
    [aux_sym_preproc_if_token1] = ACTIONS(3565),
    [aux_sym_preproc_if_token2] = ACTIONS(2746),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3568),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3568),
    [sym_preproc_directive] = ACTIONS(3571),
    [anon_sym_LPAREN2] = ACTIONS(2754),
    [anon_sym_TILDE] = ACTIONS(2757),
    [anon_sym_STAR] = ACTIONS(2760),
    [anon_sym_AMP_AMP] = ACTIONS(2763),
    [anon_sym_AMP] = ACTIONS(2766),
    [anon_sym_SEMI] = ACTIONS(3574),
    [anon_sym___extension__] = ACTIONS(3577),
    [anon_sym_typedef] = ACTIONS(3580),
    [anon_sym___device__] = ACTIONS(2778),
    [anon_sym___host__] = ACTIONS(2778),
    [anon_sym___global__] = ACTIONS(2778),
    [anon_sym___forceinline__] = ACTIONS(2778),
    [anon_sym___noinline__] = ACTIONS(2778),
    [anon_sym_virtual] = ACTIONS(2778),
    [anon_sym_extern] = ACTIONS(2781),
    [anon_sym___attribute__] = ACTIONS(2784),
    [anon_sym___attribute] = ACTIONS(2784),
    [anon_sym_COLON_COLON] = ACTIONS(2787),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2790),
    [anon_sym___declspec] = ACTIONS(2793),
    [anon_sym___based] = ACTIONS(2796),
    [anon_sym_signed] = ACTIONS(2799),
    [anon_sym_unsigned] = ACTIONS(2799),
    [anon_sym_long] = ACTIONS(2799),
    [anon_sym_short] = ACTIONS(2799),
    [anon_sym_LBRACK] = ACTIONS(2802),
    [anon_sym_static] = ACTIONS(2781),
    [anon_sym_register] = ACTIONS(2781),
    [anon_sym_inline] = ACTIONS(2781),
    [anon_sym___inline] = ACTIONS(2781),
    [anon_sym___inline__] = ACTIONS(2781),
    [anon_sym___forceinline] = ACTIONS(2781),
    [anon_sym_thread_local] = ACTIONS(2781),
    [anon_sym___thread] = ACTIONS(2781),
    [anon_sym_const] = ACTIONS(2805),
    [anon_sym_constexpr] = ACTIONS(3583),
    [anon_sym_volatile] = ACTIONS(2805),
    [anon_sym_restrict] = ACTIONS(2805),
    [anon_sym___restrict__] = ACTIONS(2805),
    [anon_sym__Atomic] = ACTIONS(2805),
    [anon_sym__Noreturn] = ACTIONS(2805),
    [anon_sym_noreturn] = ACTIONS(2805),
    [anon_sym__Nonnull] = ACTIONS(2805),
    [anon_sym_mutable] = ACTIONS(2805),
    [anon_sym_constinit] = ACTIONS(2805),
    [anon_sym_consteval] = ACTIONS(2805),
    [anon_sym___shared__] = ACTIONS(2805),
    [anon_sym___local__] = ACTIONS(2805),
    [anon_sym___constant__] = ACTIONS(2805),
    [anon_sym___managed__] = ACTIONS(2805),
    [anon_sym___grid_constant__] = ACTIONS(2805),
    [anon_sym_alignas] = ACTIONS(2811),
    [anon_sym__Alignas] = ACTIONS(2811),
    [sym_primitive_type] = ACTIONS(2814),
    [anon_sym_enum] = ACTIONS(2817),
    [anon_sym_class] = ACTIONS(2820),
    [anon_sym_struct] = ACTIONS(2823),
    [anon_sym_union] = ACTIONS(2826),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2829),
    [anon_sym_decltype] = ACTIONS(2832),
    [anon_sym_explicit] = ACTIONS(2835),
    [anon_sym_typename] = ACTIONS(2838),
    [anon_sym_template] = ACTIONS(3586),
    [anon_sym_operator] = ACTIONS(2844),
    [anon_sym_friend] = ACTIONS(3589),
    [anon_sym_public] = ACTIONS(2850),
    [anon_sym_private] = ACTIONS(2850),
    [anon_sym_protected] = ACTIONS(2850),
    [anon_sym_using] = ACTIONS(3592),
    [anon_sym_static_assert] = ACTIONS(3595),
    [anon_sym___launch_bounds__] = ACTIONS(2859),
  },
  [STATE(774)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3600),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(775)] = {
    [sym_preproc_def] = STATE(776),
    [sym_preproc_function_def] = STATE(776),
    [sym_preproc_call] = STATE(776),
    [sym_preproc_if_in_field_declaration_list] = STATE(776),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(776),
    [sym_type_definition] = STATE(776),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(776),
    [sym_field_declaration] = STATE(776),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(776),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(776),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(776),
    [sym_operator_cast_declaration] = STATE(776),
    [sym_constructor_or_destructor_definition] = STATE(776),
    [sym_constructor_or_destructor_declaration] = STATE(776),
    [sym_friend_declaration] = STATE(776),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(776),
    [sym_alias_declaration] = STATE(776),
    [sym_static_assert_declaration] = STATE(776),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(776),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3602),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3604),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(776)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3606),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(777)] = {
    [sym_preproc_def] = STATE(774),
    [sym_preproc_function_def] = STATE(774),
    [sym_preproc_call] = STATE(774),
    [sym_preproc_if_in_field_declaration_list] = STATE(774),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(774),
    [sym_type_definition] = STATE(774),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(774),
    [sym_field_declaration] = STATE(774),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(774),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(774),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(774),
    [sym_operator_cast_declaration] = STATE(774),
    [sym_constructor_or_destructor_definition] = STATE(774),
    [sym_constructor_or_destructor_declaration] = STATE(774),
    [sym_friend_declaration] = STATE(774),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(774),
    [sym_alias_declaration] = STATE(774),
    [sym_static_assert_declaration] = STATE(774),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(774),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3608),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3610),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(778)] = {
    [sym_preproc_def] = STATE(782),
    [sym_preproc_function_def] = STATE(782),
    [sym_preproc_call] = STATE(782),
    [sym_preproc_if_in_field_declaration_list] = STATE(782),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(782),
    [sym_type_definition] = STATE(782),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6070),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6872),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(782),
    [sym_field_declaration] = STATE(782),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1760),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(782),
    [sym_operator_cast] = STATE(7436),
    [sym_inline_method_definition] = STATE(782),
    [sym__constructor_specifiers] = STATE(1760),
    [sym_operator_cast_definition] = STATE(782),
    [sym_operator_cast_declaration] = STATE(782),
    [sym_constructor_or_destructor_definition] = STATE(782),
    [sym_constructor_or_destructor_declaration] = STATE(782),
    [sym_friend_declaration] = STATE(782),
    [sym_access_specifier] = STATE(9408),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(782),
    [sym_alias_declaration] = STATE(782),
    [sym_static_assert_declaration] = STATE(782),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7436),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(782),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1760),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3612),
    [aux_sym_preproc_if_token1] = ACTIONS(3614),
    [aux_sym_preproc_if_token2] = ACTIONS(3616),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3618),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3618),
    [sym_preproc_directive] = ACTIONS(3620),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3622),
    [anon_sym___extension__] = ACTIONS(3624),
    [anon_sym_typedef] = ACTIONS(3626),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3628),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3630),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3632),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3634),
    [anon_sym_static_assert] = ACTIONS(3636),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(779)] = {
    [sym_preproc_def] = STATE(780),
    [sym_preproc_function_def] = STATE(780),
    [sym_preproc_call] = STATE(780),
    [sym_preproc_if_in_field_declaration_list] = STATE(780),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(780),
    [sym_type_definition] = STATE(780),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(780),
    [sym_field_declaration] = STATE(780),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(780),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(780),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(780),
    [sym_operator_cast_declaration] = STATE(780),
    [sym_constructor_or_destructor_definition] = STATE(780),
    [sym_constructor_or_destructor_declaration] = STATE(780),
    [sym_friend_declaration] = STATE(780),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(780),
    [sym_alias_declaration] = STATE(780),
    [sym_static_assert_declaration] = STATE(780),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(780),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3638),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3640),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(780)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3642),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(781)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3644),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(782)] = {
    [sym_preproc_def] = STATE(773),
    [sym_preproc_function_def] = STATE(773),
    [sym_preproc_call] = STATE(773),
    [sym_preproc_if_in_field_declaration_list] = STATE(773),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(773),
    [sym_type_definition] = STATE(773),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6070),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6872),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(773),
    [sym_field_declaration] = STATE(773),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1760),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(773),
    [sym_operator_cast] = STATE(7436),
    [sym_inline_method_definition] = STATE(773),
    [sym__constructor_specifiers] = STATE(1760),
    [sym_operator_cast_definition] = STATE(773),
    [sym_operator_cast_declaration] = STATE(773),
    [sym_constructor_or_destructor_definition] = STATE(773),
    [sym_constructor_or_destructor_declaration] = STATE(773),
    [sym_friend_declaration] = STATE(773),
    [sym_access_specifier] = STATE(9408),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(773),
    [sym_alias_declaration] = STATE(773),
    [sym_static_assert_declaration] = STATE(773),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7436),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(773),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1760),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3612),
    [aux_sym_preproc_if_token1] = ACTIONS(3614),
    [aux_sym_preproc_if_token2] = ACTIONS(3646),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3618),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3618),
    [sym_preproc_directive] = ACTIONS(3620),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3648),
    [anon_sym___extension__] = ACTIONS(3624),
    [anon_sym_typedef] = ACTIONS(3626),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3628),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3630),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3632),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3634),
    [anon_sym_static_assert] = ACTIONS(3636),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(783)] = {
    [sym_preproc_def] = STATE(784),
    [sym_preproc_function_def] = STATE(784),
    [sym_preproc_call] = STATE(784),
    [sym_preproc_if_in_field_declaration_list] = STATE(784),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(784),
    [sym_type_definition] = STATE(784),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(784),
    [sym_field_declaration] = STATE(784),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(784),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(784),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(784),
    [sym_operator_cast_declaration] = STATE(784),
    [sym_constructor_or_destructor_definition] = STATE(784),
    [sym_constructor_or_destructor_declaration] = STATE(784),
    [sym_friend_declaration] = STATE(784),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(784),
    [sym_alias_declaration] = STATE(784),
    [sym_static_assert_declaration] = STATE(784),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(784),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3650),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3652),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(784)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3654),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(785)] = {
    [sym_preproc_def] = STATE(786),
    [sym_preproc_function_def] = STATE(786),
    [sym_preproc_call] = STATE(786),
    [sym_preproc_if_in_field_declaration_list] = STATE(786),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(786),
    [sym_type_definition] = STATE(786),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(786),
    [sym_field_declaration] = STATE(786),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(786),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(786),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(786),
    [sym_operator_cast_declaration] = STATE(786),
    [sym_constructor_or_destructor_definition] = STATE(786),
    [sym_constructor_or_destructor_declaration] = STATE(786),
    [sym_friend_declaration] = STATE(786),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(786),
    [sym_alias_declaration] = STATE(786),
    [sym_static_assert_declaration] = STATE(786),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(786),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3656),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3658),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(786)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3660),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(787)] = {
    [sym_preproc_def] = STATE(788),
    [sym_preproc_function_def] = STATE(788),
    [sym_preproc_call] = STATE(788),
    [sym_preproc_if_in_field_declaration_list] = STATE(788),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(788),
    [sym_type_definition] = STATE(788),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(788),
    [sym_field_declaration] = STATE(788),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(788),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(788),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(788),
    [sym_operator_cast_declaration] = STATE(788),
    [sym_constructor_or_destructor_definition] = STATE(788),
    [sym_constructor_or_destructor_declaration] = STATE(788),
    [sym_friend_declaration] = STATE(788),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(788),
    [sym_alias_declaration] = STATE(788),
    [sym_static_assert_declaration] = STATE(788),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(788),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3662),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3664),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(788)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3666),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(789)] = {
    [sym_preproc_def] = STATE(790),
    [sym_preproc_function_def] = STATE(790),
    [sym_preproc_call] = STATE(790),
    [sym_preproc_if_in_field_declaration_list] = STATE(790),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(790),
    [sym_type_definition] = STATE(790),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(790),
    [sym_field_declaration] = STATE(790),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(790),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(790),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(790),
    [sym_operator_cast_declaration] = STATE(790),
    [sym_constructor_or_destructor_definition] = STATE(790),
    [sym_constructor_or_destructor_declaration] = STATE(790),
    [sym_friend_declaration] = STATE(790),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(790),
    [sym_alias_declaration] = STATE(790),
    [sym_static_assert_declaration] = STATE(790),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(790),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3668),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3670),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(790)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3672),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(791)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3674),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(792)] = {
    [sym_preproc_def] = STATE(793),
    [sym_preproc_function_def] = STATE(793),
    [sym_preproc_call] = STATE(793),
    [sym_preproc_if_in_field_declaration_list] = STATE(793),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(793),
    [sym_type_definition] = STATE(793),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(793),
    [sym_field_declaration] = STATE(793),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(793),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(793),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(793),
    [sym_operator_cast_declaration] = STATE(793),
    [sym_constructor_or_destructor_definition] = STATE(793),
    [sym_constructor_or_destructor_declaration] = STATE(793),
    [sym_friend_declaration] = STATE(793),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(793),
    [sym_alias_declaration] = STATE(793),
    [sym_static_assert_declaration] = STATE(793),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(793),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3676),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3678),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(793)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3680),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(794)] = {
    [sym_preproc_def] = STATE(795),
    [sym_preproc_function_def] = STATE(795),
    [sym_preproc_call] = STATE(795),
    [sym_preproc_if_in_field_declaration_list] = STATE(795),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(795),
    [sym_type_definition] = STATE(795),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(795),
    [sym_field_declaration] = STATE(795),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(795),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(795),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(795),
    [sym_operator_cast_declaration] = STATE(795),
    [sym_constructor_or_destructor_definition] = STATE(795),
    [sym_constructor_or_destructor_declaration] = STATE(795),
    [sym_friend_declaration] = STATE(795),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(795),
    [sym_alias_declaration] = STATE(795),
    [sym_static_assert_declaration] = STATE(795),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(795),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3682),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3684),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(795)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3686),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(796)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2737),
    [aux_sym_preproc_def_token1] = ACTIONS(3688),
    [aux_sym_preproc_if_token1] = ACTIONS(3691),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3694),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3694),
    [sym_preproc_directive] = ACTIONS(3697),
    [anon_sym_LPAREN2] = ACTIONS(2754),
    [anon_sym_TILDE] = ACTIONS(2757),
    [anon_sym_STAR] = ACTIONS(2760),
    [anon_sym_AMP_AMP] = ACTIONS(2763),
    [anon_sym_AMP] = ACTIONS(2766),
    [anon_sym_SEMI] = ACTIONS(3700),
    [anon_sym___extension__] = ACTIONS(3703),
    [anon_sym_typedef] = ACTIONS(3706),
    [anon_sym___device__] = ACTIONS(2778),
    [anon_sym___host__] = ACTIONS(2778),
    [anon_sym___global__] = ACTIONS(2778),
    [anon_sym___forceinline__] = ACTIONS(2778),
    [anon_sym___noinline__] = ACTIONS(2778),
    [anon_sym_virtual] = ACTIONS(2778),
    [anon_sym_extern] = ACTIONS(2781),
    [anon_sym___attribute__] = ACTIONS(2784),
    [anon_sym___attribute] = ACTIONS(2784),
    [anon_sym_COLON_COLON] = ACTIONS(2787),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2790),
    [anon_sym___declspec] = ACTIONS(2793),
    [anon_sym___based] = ACTIONS(2796),
    [anon_sym_RBRACE] = ACTIONS(3709),
    [anon_sym_signed] = ACTIONS(2799),
    [anon_sym_unsigned] = ACTIONS(2799),
    [anon_sym_long] = ACTIONS(2799),
    [anon_sym_short] = ACTIONS(2799),
    [anon_sym_LBRACK] = ACTIONS(2802),
    [anon_sym_static] = ACTIONS(2781),
    [anon_sym_register] = ACTIONS(2781),
    [anon_sym_inline] = ACTIONS(2781),
    [anon_sym___inline] = ACTIONS(2781),
    [anon_sym___inline__] = ACTIONS(2781),
    [anon_sym___forceinline] = ACTIONS(2781),
    [anon_sym_thread_local] = ACTIONS(2781),
    [anon_sym___thread] = ACTIONS(2781),
    [anon_sym_const] = ACTIONS(2805),
    [anon_sym_constexpr] = ACTIONS(3711),
    [anon_sym_volatile] = ACTIONS(2805),
    [anon_sym_restrict] = ACTIONS(2805),
    [anon_sym___restrict__] = ACTIONS(2805),
    [anon_sym__Atomic] = ACTIONS(2805),
    [anon_sym__Noreturn] = ACTIONS(2805),
    [anon_sym_noreturn] = ACTIONS(2805),
    [anon_sym__Nonnull] = ACTIONS(2805),
    [anon_sym_mutable] = ACTIONS(2805),
    [anon_sym_constinit] = ACTIONS(2805),
    [anon_sym_consteval] = ACTIONS(2805),
    [anon_sym___shared__] = ACTIONS(2805),
    [anon_sym___local__] = ACTIONS(2805),
    [anon_sym___constant__] = ACTIONS(2805),
    [anon_sym___managed__] = ACTIONS(2805),
    [anon_sym___grid_constant__] = ACTIONS(2805),
    [anon_sym_alignas] = ACTIONS(2811),
    [anon_sym__Alignas] = ACTIONS(2811),
    [sym_primitive_type] = ACTIONS(2814),
    [anon_sym_enum] = ACTIONS(2817),
    [anon_sym_class] = ACTIONS(2820),
    [anon_sym_struct] = ACTIONS(2823),
    [anon_sym_union] = ACTIONS(2826),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2829),
    [anon_sym_decltype] = ACTIONS(2832),
    [anon_sym_explicit] = ACTIONS(2835),
    [anon_sym_typename] = ACTIONS(2838),
    [anon_sym_template] = ACTIONS(3714),
    [anon_sym_operator] = ACTIONS(2844),
    [anon_sym_friend] = ACTIONS(3717),
    [anon_sym_public] = ACTIONS(2850),
    [anon_sym_private] = ACTIONS(2850),
    [anon_sym_protected] = ACTIONS(2850),
    [anon_sym_using] = ACTIONS(3720),
    [anon_sym_static_assert] = ACTIONS(3723),
    [anon_sym___launch_bounds__] = ACTIONS(2859),
  },
  [STATE(797)] = {
    [sym_preproc_def] = STATE(798),
    [sym_preproc_function_def] = STATE(798),
    [sym_preproc_call] = STATE(798),
    [sym_preproc_if_in_field_declaration_list] = STATE(798),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(798),
    [sym_type_definition] = STATE(798),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(798),
    [sym_field_declaration] = STATE(798),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(798),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(798),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(798),
    [sym_operator_cast_declaration] = STATE(798),
    [sym_constructor_or_destructor_definition] = STATE(798),
    [sym_constructor_or_destructor_declaration] = STATE(798),
    [sym_friend_declaration] = STATE(798),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(798),
    [sym_alias_declaration] = STATE(798),
    [sym_static_assert_declaration] = STATE(798),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(798),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3726),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3728),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(798)] = {
    [sym_preproc_def] = STATE(796),
    [sym_preproc_function_def] = STATE(796),
    [sym_preproc_call] = STATE(796),
    [sym_preproc_if_in_field_declaration_list] = STATE(796),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(796),
    [sym_type_definition] = STATE(796),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(796),
    [sym_field_declaration] = STATE(796),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(796),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(796),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(796),
    [sym_operator_cast_declaration] = STATE(796),
    [sym_constructor_or_destructor_definition] = STATE(796),
    [sym_constructor_or_destructor_declaration] = STATE(796),
    [sym_friend_declaration] = STATE(796),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(796),
    [sym_alias_declaration] = STATE(796),
    [sym_static_assert_declaration] = STATE(796),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3598),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3730),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(799)] = {
    [sym_preproc_def] = STATE(781),
    [sym_preproc_function_def] = STATE(781),
    [sym_preproc_call] = STATE(781),
    [sym_preproc_if_in_field_declaration_list] = STATE(781),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(781),
    [sym_type_definition] = STATE(781),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(6087),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__field_declaration_list_item] = STATE(781),
    [sym_field_declaration] = STATE(781),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(781),
    [sym_operator_cast] = STATE(7420),
    [sym_inline_method_definition] = STATE(781),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(781),
    [sym_operator_cast_declaration] = STATE(781),
    [sym_constructor_or_destructor_definition] = STATE(781),
    [sym_constructor_or_destructor_declaration] = STATE(781),
    [sym_friend_declaration] = STATE(781),
    [sym_access_specifier] = STATE(8883),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_using_declaration] = STATE(781),
    [sym_alias_declaration] = STATE(781),
    [sym_static_assert_declaration] = STATE(781),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(5996),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(781),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1903),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(2238),
    [aux_sym_preproc_def_token1] = ACTIONS(3528),
    [aux_sym_preproc_if_token1] = ACTIONS(3530),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(3532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(3532),
    [sym_preproc_directive] = ACTIONS(3534),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(3732),
    [anon_sym___extension__] = ACTIONS(3538),
    [anon_sym_typedef] = ACTIONS(3540),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_RBRACE] = ACTIONS(3734),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_public] = ACTIONS(2292),
    [anon_sym_private] = ACTIONS(2292),
    [anon_sym_protected] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_static_assert] = ACTIONS(3552),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(800)] = {
    [sym__declaration_modifiers] = STATE(1906),
    [sym__declaration_specifiers] = STATE(6963),
    [sym_attribute_specifier] = STATE(1906),
    [sym_attribute_declaration] = STATE(1906),
    [sym_ms_declspec_modifier] = STATE(1906),
    [sym_storage_class_specifier] = STATE(1906),
    [sym_type_qualifier] = STATE(1906),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(3157),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7232),
    [sym_qualified_type_identifier] = STATE(2374),
    [sym_launch_bounds] = STATE(1906),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1906),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2354),
    [sym_identifier] = ACTIONS(3736),
    [anon_sym_COMMA] = ACTIONS(3738),
    [anon_sym_BANG] = ACTIONS(3740),
    [anon_sym_TILDE] = ACTIONS(3738),
    [anon_sym_DASH] = ACTIONS(3740),
    [anon_sym_PLUS] = ACTIONS(3740),
    [anon_sym_STAR] = ACTIONS(3740),
    [anon_sym_SLASH] = ACTIONS(3740),
    [anon_sym_PERCENT] = ACTIONS(3740),
    [anon_sym_PIPE_PIPE] = ACTIONS(3738),
    [anon_sym_AMP_AMP] = ACTIONS(3738),
    [anon_sym_PIPE] = ACTIONS(3740),
    [anon_sym_CARET] = ACTIONS(3740),
    [anon_sym_AMP] = ACTIONS(3740),
    [anon_sym_EQ_EQ] = ACTIONS(3738),
    [anon_sym_BANG_EQ] = ACTIONS(3738),
    [anon_sym_GT] = ACTIONS(3740),
    [anon_sym_GT_EQ] = ACTIONS(3738),
    [anon_sym_LT_EQ] = ACTIONS(3740),
    [anon_sym_LT] = ACTIONS(3740),
    [anon_sym_LT_LT] = ACTIONS(3740),
    [anon_sym_GT_GT] = ACTIONS(3740),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(3742),
    [anon_sym___host__] = ACTIONS(3742),
    [anon_sym___global__] = ACTIONS(3742),
    [anon_sym___forceinline__] = ACTIONS(3742),
    [anon_sym___noinline__] = ACTIONS(3742),
    [anon_sym_virtual] = ACTIONS(3742),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3744),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(3746),
    [anon_sym_unsigned] = ACTIONS(3746),
    [anon_sym_long] = ACTIONS(3746),
    [anon_sym_short] = ACTIONS(3746),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(3740),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3748),
    [anon_sym_enum] = ACTIONS(3750),
    [anon_sym_class] = ACTIONS(3752),
    [anon_sym_struct] = ACTIONS(3754),
    [anon_sym_union] = ACTIONS(3756),
    [anon_sym_STAR_EQ] = ACTIONS(3738),
    [anon_sym_SLASH_EQ] = ACTIONS(3738),
    [anon_sym_PERCENT_EQ] = ACTIONS(3738),
    [anon_sym_PLUS_EQ] = ACTIONS(3738),
    [anon_sym_DASH_EQ] = ACTIONS(3738),
    [anon_sym_LT_LT_EQ] = ACTIONS(3738),
    [anon_sym_GT_GT_EQ] = ACTIONS(3738),
    [anon_sym_AMP_EQ] = ACTIONS(3738),
    [anon_sym_CARET_EQ] = ACTIONS(3738),
    [anon_sym_PIPE_EQ] = ACTIONS(3738),
    [anon_sym_and_eq] = ACTIONS(3740),
    [anon_sym_or_eq] = ACTIONS(3740),
    [anon_sym_xor_eq] = ACTIONS(3740),
    [anon_sym_not] = ACTIONS(3740),
    [anon_sym_compl] = ACTIONS(3740),
    [anon_sym_LT_EQ_GT] = ACTIONS(3738),
    [anon_sym_or] = ACTIONS(3740),
    [anon_sym_and] = ACTIONS(3740),
    [anon_sym_bitor] = ACTIONS(3740),
    [anon_sym_xor] = ACTIONS(3740),
    [anon_sym_bitand] = ACTIONS(3740),
    [anon_sym_not_eq] = ACTIONS(3740),
    [anon_sym_DASH_DASH] = ACTIONS(3738),
    [anon_sym_PLUS_PLUS] = ACTIONS(3738),
    [anon_sym_DASH_GT] = ACTIONS(3740),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(3758),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3760),
    [anon_sym_co_await] = ACTIONS(3740),
    [anon_sym_new] = ACTIONS(3760),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3738),
    [anon_sym_LPAREN_RPAREN] = ACTIONS(3738),
    [anon_sym_LBRACK_RBRACK] = ACTIONS(3738),
    [anon_sym_DQUOTE_DQUOTE] = ACTIONS(3762),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(801)] = {
    [sym__declaration_modifiers] = STATE(1906),
    [sym__declaration_specifiers] = STATE(6963),
    [sym_attribute_specifier] = STATE(1906),
    [sym_attribute_declaration] = STATE(1906),
    [sym_ms_declspec_modifier] = STATE(1906),
    [sym_storage_class_specifier] = STATE(1906),
    [sym_type_qualifier] = STATE(1906),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(3157),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7232),
    [sym_qualified_type_identifier] = STATE(2374),
    [sym_launch_bounds] = STATE(1906),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1906),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2354),
    [sym_identifier] = ACTIONS(3736),
    [anon_sym_COMMA] = ACTIONS(3764),
    [anon_sym_BANG] = ACTIONS(3766),
    [anon_sym_TILDE] = ACTIONS(3764),
    [anon_sym_DASH] = ACTIONS(3766),
    [anon_sym_PLUS] = ACTIONS(3766),
    [anon_sym_STAR] = ACTIONS(3766),
    [anon_sym_SLASH] = ACTIONS(3766),
    [anon_sym_PERCENT] = ACTIONS(3766),
    [anon_sym_PIPE_PIPE] = ACTIONS(3764),
    [anon_sym_AMP_AMP] = ACTIONS(3764),
    [anon_sym_PIPE] = ACTIONS(3766),
    [anon_sym_CARET] = ACTIONS(3766),
    [anon_sym_AMP] = ACTIONS(3766),
    [anon_sym_EQ_EQ] = ACTIONS(3764),
    [anon_sym_BANG_EQ] = ACTIONS(3764),
    [anon_sym_GT] = ACTIONS(3766),
    [anon_sym_GT_EQ] = ACTIONS(3764),
    [anon_sym_LT_EQ] = ACTIONS(3766),
    [anon_sym_LT] = ACTIONS(3766),
    [anon_sym_LT_LT] = ACTIONS(3766),
    [anon_sym_GT_GT] = ACTIONS(3766),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(3742),
    [anon_sym___host__] = ACTIONS(3742),
    [anon_sym___global__] = ACTIONS(3742),
    [anon_sym___forceinline__] = ACTIONS(3742),
    [anon_sym___noinline__] = ACTIONS(3742),
    [anon_sym_virtual] = ACTIONS(3742),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3744),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(3746),
    [anon_sym_unsigned] = ACTIONS(3746),
    [anon_sym_long] = ACTIONS(3746),
    [anon_sym_short] = ACTIONS(3746),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(3766),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3748),
    [anon_sym_enum] = ACTIONS(3750),
    [anon_sym_class] = ACTIONS(3752),
    [anon_sym_struct] = ACTIONS(3754),
    [anon_sym_union] = ACTIONS(3756),
    [anon_sym_STAR_EQ] = ACTIONS(3764),
    [anon_sym_SLASH_EQ] = ACTIONS(3764),
    [anon_sym_PERCENT_EQ] = ACTIONS(3764),
    [anon_sym_PLUS_EQ] = ACTIONS(3764),
    [anon_sym_DASH_EQ] = ACTIONS(3764),
    [anon_sym_LT_LT_EQ] = ACTIONS(3764),
    [anon_sym_GT_GT_EQ] = ACTIONS(3764),
    [anon_sym_AMP_EQ] = ACTIONS(3764),
    [anon_sym_CARET_EQ] = ACTIONS(3764),
    [anon_sym_PIPE_EQ] = ACTIONS(3764),
    [anon_sym_and_eq] = ACTIONS(3766),
    [anon_sym_or_eq] = ACTIONS(3766),
    [anon_sym_xor_eq] = ACTIONS(3766),
    [anon_sym_not] = ACTIONS(3766),
    [anon_sym_compl] = ACTIONS(3766),
    [anon_sym_LT_EQ_GT] = ACTIONS(3764),
    [anon_sym_or] = ACTIONS(3766),
    [anon_sym_and] = ACTIONS(3766),
    [anon_sym_bitor] = ACTIONS(3766),
    [anon_sym_xor] = ACTIONS(3766),
    [anon_sym_bitand] = ACTIONS(3766),
    [anon_sym_not_eq] = ACTIONS(3766),
    [anon_sym_DASH_DASH] = ACTIONS(3764),
    [anon_sym_PLUS_PLUS] = ACTIONS(3764),
    [anon_sym_DASH_GT] = ACTIONS(3766),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(3758),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3768),
    [anon_sym_co_await] = ACTIONS(3766),
    [anon_sym_new] = ACTIONS(3768),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3764),
    [anon_sym_LPAREN_RPAREN] = ACTIONS(3764),
    [anon_sym_LBRACK_RBRACK] = ACTIONS(3764),
    [anon_sym_DQUOTE_DQUOTE] = ACTIONS(3770),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(802)] = {
    [sym_expression] = STATE(4573),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(2633),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [aux_sym_preproc_if_token2] = ACTIONS(2635),
    [aux_sym_preproc_else_token1] = ACTIONS(2635),
    [aux_sym_preproc_elif_token1] = ACTIONS(2633),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2635),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(3772),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2635),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2635),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2635),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2635),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(803)] = {
    [sym_expression] = STATE(4741),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_RPAREN] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2635),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2635),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2635),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2635),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(2635),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(804)] = {
    [sym_expression] = STATE(4741),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(3804),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2635),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2635),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2635),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2635),
    [anon_sym_SEMI] = ACTIONS(2635),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym___attribute__] = ACTIONS(2633),
    [anon_sym___attribute] = ACTIONS(2633),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(805)] = {
    [sym_identifier] = ACTIONS(3826),
    [anon_sym_COMMA] = ACTIONS(3828),
    [anon_sym_RPAREN] = ACTIONS(3828),
    [anon_sym_LPAREN2] = ACTIONS(3828),
    [anon_sym_BANG] = ACTIONS(3828),
    [anon_sym_TILDE] = ACTIONS(3828),
    [anon_sym_DASH] = ACTIONS(3826),
    [anon_sym_PLUS] = ACTIONS(3826),
    [anon_sym_STAR] = ACTIONS(3828),
    [anon_sym_AMP_AMP] = ACTIONS(3828),
    [anon_sym_AMP] = ACTIONS(3826),
    [anon_sym_SEMI] = ACTIONS(3828),
    [anon_sym___extension__] = ACTIONS(3826),
    [anon_sym___device__] = ACTIONS(3826),
    [anon_sym___host__] = ACTIONS(3826),
    [anon_sym___global__] = ACTIONS(3826),
    [anon_sym___forceinline__] = ACTIONS(3826),
    [anon_sym___noinline__] = ACTIONS(3826),
    [anon_sym_virtual] = ACTIONS(3826),
    [anon_sym_extern] = ACTIONS(3826),
    [anon_sym___attribute__] = ACTIONS(3826),
    [anon_sym___attribute] = ACTIONS(3826),
    [anon_sym_COLON_COLON] = ACTIONS(3828),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3828),
    [anon_sym___declspec] = ACTIONS(3826),
    [anon_sym___based] = ACTIONS(3826),
    [anon_sym_LBRACE] = ACTIONS(3828),
    [anon_sym_signed] = ACTIONS(3826),
    [anon_sym_unsigned] = ACTIONS(3826),
    [anon_sym_long] = ACTIONS(3826),
    [anon_sym_short] = ACTIONS(3826),
    [anon_sym_LBRACK] = ACTIONS(3826),
    [anon_sym_static] = ACTIONS(3826),
    [anon_sym_RBRACK] = ACTIONS(3828),
    [anon_sym_EQ] = ACTIONS(3828),
    [anon_sym_register] = ACTIONS(3826),
    [anon_sym_inline] = ACTIONS(3826),
    [anon_sym___inline] = ACTIONS(3826),
    [anon_sym___inline__] = ACTIONS(3826),
    [anon_sym___forceinline] = ACTIONS(3826),
    [anon_sym_thread_local] = ACTIONS(3826),
    [anon_sym___thread] = ACTIONS(3826),
    [anon_sym_const] = ACTIONS(3826),
    [anon_sym_constexpr] = ACTIONS(3826),
    [anon_sym_volatile] = ACTIONS(3826),
    [anon_sym_restrict] = ACTIONS(3826),
    [anon_sym___restrict__] = ACTIONS(3826),
    [anon_sym__Atomic] = ACTIONS(3826),
    [anon_sym__Noreturn] = ACTIONS(3826),
    [anon_sym_noreturn] = ACTIONS(3826),
    [anon_sym__Nonnull] = ACTIONS(3826),
    [anon_sym_mutable] = ACTIONS(3826),
    [anon_sym_constinit] = ACTIONS(3826),
    [anon_sym_consteval] = ACTIONS(3826),
    [anon_sym___shared__] = ACTIONS(3826),
    [anon_sym___local__] = ACTIONS(3826),
    [anon_sym___constant__] = ACTIONS(3826),
    [anon_sym___managed__] = ACTIONS(3826),
    [anon_sym___grid_constant__] = ACTIONS(3826),
    [anon_sym_alignas] = ACTIONS(3826),
    [anon_sym__Alignas] = ACTIONS(3826),
    [sym_primitive_type] = ACTIONS(3826),
    [anon_sym_enum] = ACTIONS(3826),
    [anon_sym_class] = ACTIONS(3826),
    [anon_sym_struct] = ACTIONS(3826),
    [anon_sym_union] = ACTIONS(3826),
    [anon_sym_if] = ACTIONS(3826),
    [anon_sym_switch] = ACTIONS(3826),
    [anon_sym_case] = ACTIONS(3826),
    [anon_sym_default] = ACTIONS(3826),
    [anon_sym_while] = ACTIONS(3826),
    [anon_sym_do] = ACTIONS(3826),
    [anon_sym_for] = ACTIONS(3826),
    [anon_sym_return] = ACTIONS(3826),
    [anon_sym_break] = ACTIONS(3826),
    [anon_sym_continue] = ACTIONS(3826),
    [anon_sym_goto] = ACTIONS(3826),
    [anon_sym___try] = ACTIONS(3826),
    [anon_sym___leave] = ACTIONS(3826),
    [anon_sym_not] = ACTIONS(3826),
    [anon_sym_compl] = ACTIONS(3826),
    [anon_sym_DASH_DASH] = ACTIONS(3828),
    [anon_sym_PLUS_PLUS] = ACTIONS(3828),
    [anon_sym_sizeof] = ACTIONS(3826),
    [anon_sym___alignof__] = ACTIONS(3826),
    [anon_sym___alignof] = ACTIONS(3826),
    [anon_sym__alignof] = ACTIONS(3826),
    [anon_sym_alignof] = ACTIONS(3826),
    [anon_sym__Alignof] = ACTIONS(3826),
    [anon_sym_offsetof] = ACTIONS(3826),
    [anon_sym__Generic] = ACTIONS(3826),
    [anon_sym_asm] = ACTIONS(3826),
    [anon_sym___asm__] = ACTIONS(3826),
    [anon_sym___asm] = ACTIONS(3826),
    [sym_number_literal] = ACTIONS(3828),
    [anon_sym_L_SQUOTE] = ACTIONS(3828),
    [anon_sym_u_SQUOTE] = ACTIONS(3828),
    [anon_sym_U_SQUOTE] = ACTIONS(3828),
    [anon_sym_u8_SQUOTE] = ACTIONS(3828),
    [anon_sym_SQUOTE] = ACTIONS(3828),
    [anon_sym_L_DQUOTE] = ACTIONS(3828),
    [anon_sym_u_DQUOTE] = ACTIONS(3828),
    [anon_sym_U_DQUOTE] = ACTIONS(3828),
    [anon_sym_u8_DQUOTE] = ACTIONS(3828),
    [anon_sym_DQUOTE] = ACTIONS(3828),
    [sym_true] = ACTIONS(3826),
    [sym_false] = ACTIONS(3826),
    [anon_sym_NULL] = ACTIONS(3826),
    [anon_sym_nullptr] = ACTIONS(3826),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3826),
    [anon_sym_decltype] = ACTIONS(3826),
    [anon_sym_explicit] = ACTIONS(3826),
    [anon_sym_typename] = ACTIONS(3826),
    [anon_sym_template] = ACTIONS(3826),
    [anon_sym_GT2] = ACTIONS(3828),
    [anon_sym_operator] = ACTIONS(3826),
    [anon_sym_try] = ACTIONS(3826),
    [anon_sym_delete] = ACTIONS(3826),
    [anon_sym_throw] = ACTIONS(3826),
    [anon_sym_co_return] = ACTIONS(3826),
    [anon_sym_co_yield] = ACTIONS(3826),
    [anon_sym_R_DQUOTE] = ACTIONS(3828),
    [anon_sym_LR_DQUOTE] = ACTIONS(3828),
    [anon_sym_uR_DQUOTE] = ACTIONS(3828),
    [anon_sym_UR_DQUOTE] = ACTIONS(3828),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3828),
    [anon_sym_co_await] = ACTIONS(3826),
    [anon_sym_new] = ACTIONS(3826),
    [anon_sym_requires] = ACTIONS(3826),
    [sym_this] = ACTIONS(3826),
    [anon_sym___launch_bounds__] = ACTIONS(3826),
  },
  [STATE(806)] = {
    [sym_identifier] = ACTIONS(3830),
    [anon_sym_COMMA] = ACTIONS(3832),
    [anon_sym_RPAREN] = ACTIONS(3832),
    [anon_sym_LPAREN2] = ACTIONS(3832),
    [anon_sym_BANG] = ACTIONS(3832),
    [anon_sym_TILDE] = ACTIONS(3832),
    [anon_sym_DASH] = ACTIONS(3830),
    [anon_sym_PLUS] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_AMP_AMP] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3830),
    [anon_sym_SEMI] = ACTIONS(3832),
    [anon_sym___extension__] = ACTIONS(3830),
    [anon_sym___device__] = ACTIONS(3830),
    [anon_sym___host__] = ACTIONS(3830),
    [anon_sym___global__] = ACTIONS(3830),
    [anon_sym___forceinline__] = ACTIONS(3830),
    [anon_sym___noinline__] = ACTIONS(3830),
    [anon_sym_virtual] = ACTIONS(3830),
    [anon_sym_extern] = ACTIONS(3830),
    [anon_sym___attribute__] = ACTIONS(3830),
    [anon_sym___attribute] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(3832),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3832),
    [anon_sym___declspec] = ACTIONS(3830),
    [anon_sym___based] = ACTIONS(3830),
    [anon_sym_LBRACE] = ACTIONS(3832),
    [anon_sym_signed] = ACTIONS(3830),
    [anon_sym_unsigned] = ACTIONS(3830),
    [anon_sym_long] = ACTIONS(3830),
    [anon_sym_short] = ACTIONS(3830),
    [anon_sym_LBRACK] = ACTIONS(3830),
    [anon_sym_static] = ACTIONS(3830),
    [anon_sym_RBRACK] = ACTIONS(3832),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_register] = ACTIONS(3830),
    [anon_sym_inline] = ACTIONS(3830),
    [anon_sym___inline] = ACTIONS(3830),
    [anon_sym___inline__] = ACTIONS(3830),
    [anon_sym___forceinline] = ACTIONS(3830),
    [anon_sym_thread_local] = ACTIONS(3830),
    [anon_sym___thread] = ACTIONS(3830),
    [anon_sym_const] = ACTIONS(3830),
    [anon_sym_constexpr] = ACTIONS(3830),
    [anon_sym_volatile] = ACTIONS(3830),
    [anon_sym_restrict] = ACTIONS(3830),
    [anon_sym___restrict__] = ACTIONS(3830),
    [anon_sym__Atomic] = ACTIONS(3830),
    [anon_sym__Noreturn] = ACTIONS(3830),
    [anon_sym_noreturn] = ACTIONS(3830),
    [anon_sym__Nonnull] = ACTIONS(3830),
    [anon_sym_mutable] = ACTIONS(3830),
    [anon_sym_constinit] = ACTIONS(3830),
    [anon_sym_consteval] = ACTIONS(3830),
    [anon_sym___shared__] = ACTIONS(3830),
    [anon_sym___local__] = ACTIONS(3830),
    [anon_sym___constant__] = ACTIONS(3830),
    [anon_sym___managed__] = ACTIONS(3830),
    [anon_sym___grid_constant__] = ACTIONS(3830),
    [anon_sym_alignas] = ACTIONS(3830),
    [anon_sym__Alignas] = ACTIONS(3830),
    [sym_primitive_type] = ACTIONS(3830),
    [anon_sym_enum] = ACTIONS(3830),
    [anon_sym_class] = ACTIONS(3830),
    [anon_sym_struct] = ACTIONS(3830),
    [anon_sym_union] = ACTIONS(3830),
    [anon_sym_if] = ACTIONS(3830),
    [anon_sym_switch] = ACTIONS(3830),
    [anon_sym_case] = ACTIONS(3830),
    [anon_sym_default] = ACTIONS(3830),
    [anon_sym_while] = ACTIONS(3830),
    [anon_sym_do] = ACTIONS(3830),
    [anon_sym_for] = ACTIONS(3830),
    [anon_sym_return] = ACTIONS(3830),
    [anon_sym_break] = ACTIONS(3830),
    [anon_sym_continue] = ACTIONS(3830),
    [anon_sym_goto] = ACTIONS(3830),
    [anon_sym___try] = ACTIONS(3830),
    [anon_sym___leave] = ACTIONS(3830),
    [anon_sym_not] = ACTIONS(3830),
    [anon_sym_compl] = ACTIONS(3830),
    [anon_sym_DASH_DASH] = ACTIONS(3832),
    [anon_sym_PLUS_PLUS] = ACTIONS(3832),
    [anon_sym_sizeof] = ACTIONS(3830),
    [anon_sym___alignof__] = ACTIONS(3830),
    [anon_sym___alignof] = ACTIONS(3830),
    [anon_sym__alignof] = ACTIONS(3830),
    [anon_sym_alignof] = ACTIONS(3830),
    [anon_sym__Alignof] = ACTIONS(3830),
    [anon_sym_offsetof] = ACTIONS(3830),
    [anon_sym__Generic] = ACTIONS(3830),
    [anon_sym_asm] = ACTIONS(3830),
    [anon_sym___asm__] = ACTIONS(3830),
    [anon_sym___asm] = ACTIONS(3830),
    [sym_number_literal] = ACTIONS(3832),
    [anon_sym_L_SQUOTE] = ACTIONS(3832),
    [anon_sym_u_SQUOTE] = ACTIONS(3832),
    [anon_sym_U_SQUOTE] = ACTIONS(3832),
    [anon_sym_u8_SQUOTE] = ACTIONS(3832),
    [anon_sym_SQUOTE] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(3832),
    [anon_sym_u_DQUOTE] = ACTIONS(3832),
    [anon_sym_U_DQUOTE] = ACTIONS(3832),
    [anon_sym_u8_DQUOTE] = ACTIONS(3832),
    [anon_sym_DQUOTE] = ACTIONS(3832),
    [sym_true] = ACTIONS(3830),
    [sym_false] = ACTIONS(3830),
    [anon_sym_NULL] = ACTIONS(3830),
    [anon_sym_nullptr] = ACTIONS(3830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3830),
    [anon_sym_decltype] = ACTIONS(3830),
    [anon_sym_explicit] = ACTIONS(3830),
    [anon_sym_typename] = ACTIONS(3830),
    [anon_sym_template] = ACTIONS(3830),
    [anon_sym_GT2] = ACTIONS(3832),
    [anon_sym_operator] = ACTIONS(3830),
    [anon_sym_try] = ACTIONS(3830),
    [anon_sym_delete] = ACTIONS(3830),
    [anon_sym_throw] = ACTIONS(3830),
    [anon_sym_co_return] = ACTIONS(3830),
    [anon_sym_co_yield] = ACTIONS(3830),
    [anon_sym_R_DQUOTE] = ACTIONS(3832),
    [anon_sym_LR_DQUOTE] = ACTIONS(3832),
    [anon_sym_uR_DQUOTE] = ACTIONS(3832),
    [anon_sym_UR_DQUOTE] = ACTIONS(3832),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3832),
    [anon_sym_co_await] = ACTIONS(3830),
    [anon_sym_new] = ACTIONS(3830),
    [anon_sym_requires] = ACTIONS(3830),
    [sym_this] = ACTIONS(3830),
    [anon_sym___launch_bounds__] = ACTIONS(3830),
  },
  [STATE(807)] = {
    [sym_function_definition] = STATE(1913),
    [sym_declaration] = STATE(1913),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5463),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1892),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2356),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(1913),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(1913),
    [sym_operator_cast] = STATE(7420),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(1913),
    [sym_operator_cast_declaration] = STATE(1913),
    [sym_constructor_or_destructor_definition] = STATE(1913),
    [sym_constructor_or_destructor_declaration] = STATE(1913),
    [sym_friend_declaration] = STATE(1913),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(1913),
    [sym_concept_definition] = STATE(1913),
    [sym_requires_clause] = STATE(820),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_using] = ACTIONS(3838),
    [anon_sym_concept] = ACTIONS(3840),
    [anon_sym_requires] = ACTIONS(3842),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(808)] = {
    [sym_function_definition] = STATE(296),
    [sym_declaration] = STATE(296),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6826),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(296),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1745),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(296),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1745),
    [sym_operator_cast_definition] = STATE(296),
    [sym_operator_cast_declaration] = STATE(296),
    [sym_constructor_or_destructor_definition] = STATE(296),
    [sym_constructor_or_destructor_declaration] = STATE(296),
    [sym_friend_declaration] = STATE(296),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(296),
    [sym_concept_definition] = STATE(296),
    [sym_requires_clause] = STATE(825),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1745),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3844),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3846),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3848),
    [anon_sym_using] = ACTIONS(3850),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym_requires] = ACTIONS(3842),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(809)] = {
    [sym_function_definition] = STATE(479),
    [sym_declaration] = STATE(479),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5455),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1891),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6827),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2353),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(479),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1758),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(479),
    [sym_operator_cast] = STATE(7422),
    [sym__constructor_specifiers] = STATE(1758),
    [sym_operator_cast_definition] = STATE(479),
    [sym_operator_cast_declaration] = STATE(479),
    [sym_constructor_or_destructor_definition] = STATE(479),
    [sym_constructor_or_destructor_declaration] = STATE(479),
    [sym_friend_declaration] = STATE(479),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(479),
    [sym_concept_definition] = STATE(479),
    [sym_requires_clause] = STATE(822),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7422),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1758),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3852),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3854),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3856),
    [anon_sym_using] = ACTIONS(3858),
    [anon_sym_concept] = ACTIONS(937),
    [anon_sym_requires] = ACTIONS(3842),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(810)] = {
    [sym_function_definition] = STATE(1810),
    [sym_declaration] = STATE(1810),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5466),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1893),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2336),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(1810),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(1810),
    [sym_operator_cast] = STATE(7392),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(1810),
    [sym_operator_cast_declaration] = STATE(1810),
    [sym_constructor_or_destructor_definition] = STATE(1810),
    [sym_constructor_or_destructor_declaration] = STATE(1810),
    [sym_friend_declaration] = STATE(1810),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(1810),
    [sym_concept_definition] = STATE(1810),
    [sym_requires_clause] = STATE(818),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_using] = ACTIONS(3860),
    [anon_sym_concept] = ACTIONS(3862),
    [anon_sym_requires] = ACTIONS(3842),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(811)] = {
    [sym_function_definition] = STATE(708),
    [sym_declaration] = STATE(708),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5483),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1888),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6822),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2335),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(708),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1746),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(708),
    [sym_operator_cast] = STATE(7391),
    [sym__constructor_specifiers] = STATE(1746),
    [sym_operator_cast_definition] = STATE(708),
    [sym_operator_cast_declaration] = STATE(708),
    [sym_constructor_or_destructor_definition] = STATE(708),
    [sym_constructor_or_destructor_declaration] = STATE(708),
    [sym_friend_declaration] = STATE(708),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(708),
    [sym_concept_definition] = STATE(708),
    [sym_requires_clause] = STATE(827),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7391),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1746),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3864),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3866),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3868),
    [anon_sym_using] = ACTIONS(3870),
    [anon_sym_concept] = ACTIONS(147),
    [anon_sym_requires] = ACTIONS(3842),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(812)] = {
    [sym_function_definition] = STATE(2006),
    [sym_declaration] = STATE(2006),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5472),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1894),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6872),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2341),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(2006),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1760),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(2006),
    [sym_operator_cast] = STATE(7436),
    [sym__constructor_specifiers] = STATE(1760),
    [sym_operator_cast_definition] = STATE(2006),
    [sym_operator_cast_declaration] = STATE(2006),
    [sym_constructor_or_destructor_definition] = STATE(2006),
    [sym_constructor_or_destructor_declaration] = STATE(2006),
    [sym_friend_declaration] = STATE(2006),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(2006),
    [sym_concept_definition] = STATE(2006),
    [sym_requires_clause] = STATE(824),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7436),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1760),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3628),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3630),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3632),
    [anon_sym_using] = ACTIONS(3872),
    [anon_sym_concept] = ACTIONS(3874),
    [anon_sym_requires] = ACTIONS(3842),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(813)] = {
    [sym_function_definition] = STATE(516),
    [sym_declaration] = STATE(516),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6825),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(516),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1751),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(516),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1751),
    [sym_operator_cast_definition] = STATE(516),
    [sym_operator_cast_declaration] = STATE(516),
    [sym_constructor_or_destructor_definition] = STATE(516),
    [sym_constructor_or_destructor_declaration] = STATE(516),
    [sym_friend_declaration] = STATE(516),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(516),
    [sym_concept_definition] = STATE(516),
    [sym_requires_clause] = STATE(826),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1751),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3876),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3878),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3880),
    [anon_sym_using] = ACTIONS(3882),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym_requires] = ACTIONS(3842),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(814)] = {
    [sym_expression] = STATE(5087),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(3886),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2635),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2635),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2635),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2635),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(2633),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(815)] = {
    [sym_expression] = STATE(5197),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_initializer_list] = STATE(5515),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(2868),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2635),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2635),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2635),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2633),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACE] = ACTIONS(3906),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(2635),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(816)] = {
    [sym_expression] = STATE(5156),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_initializer_list] = STATE(5465),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(3912),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2635),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2635),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2635),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2633),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACE] = ACTIONS(3920),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(2635),
  },
  [STATE(817)] = {
    [sym_expression] = STATE(4573),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2635),
    [anon_sym_COMMA] = ACTIONS(2635),
    [anon_sym_LPAREN2] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(3956),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(2633),
    [anon_sym_PLUS] = ACTIONS(2633),
    [anon_sym_STAR] = ACTIONS(2635),
    [anon_sym_SLASH] = ACTIONS(2633),
    [anon_sym_PERCENT] = ACTIONS(2635),
    [anon_sym_PIPE_PIPE] = ACTIONS(2635),
    [anon_sym_AMP_AMP] = ACTIONS(2635),
    [anon_sym_PIPE] = ACTIONS(2633),
    [anon_sym_CARET] = ACTIONS(2635),
    [anon_sym_AMP] = ACTIONS(2633),
    [anon_sym_EQ_EQ] = ACTIONS(2635),
    [anon_sym_BANG_EQ] = ACTIONS(2635),
    [anon_sym_GT] = ACTIONS(2633),
    [anon_sym_GT_EQ] = ACTIONS(2635),
    [anon_sym_LT_EQ] = ACTIONS(2633),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_LT_LT] = ACTIONS(2633),
    [anon_sym_GT_GT] = ACTIONS(2635),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2635),
    [anon_sym_RBRACK] = ACTIONS(2635),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_QMARK] = ACTIONS(2635),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_LT_EQ_GT] = ACTIONS(2635),
    [anon_sym_or] = ACTIONS(2633),
    [anon_sym_and] = ACTIONS(2633),
    [anon_sym_bitor] = ACTIONS(2633),
    [anon_sym_xor] = ACTIONS(2633),
    [anon_sym_bitand] = ACTIONS(2633),
    [anon_sym_not_eq] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2635),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(2633),
    [anon_sym_DOT_STAR] = ACTIONS(2635),
    [anon_sym_DASH_GT] = ACTIONS(2635),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(2635),
  },
  [STATE(818)] = {
    [sym_function_definition] = STATE(1824),
    [sym_declaration] = STATE(1824),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5466),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1893),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6860),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2336),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(1824),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1757),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(1824),
    [sym_operator_cast] = STATE(7392),
    [sym__constructor_specifiers] = STATE(1757),
    [sym_operator_cast_definition] = STATE(1824),
    [sym_operator_cast_declaration] = STATE(1824),
    [sym_constructor_or_destructor_definition] = STATE(1824),
    [sym_constructor_or_destructor_declaration] = STATE(1824),
    [sym_friend_declaration] = STATE(1824),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(1824),
    [sym_concept_definition] = STATE(1824),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7392),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(2274),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(2290),
    [anon_sym_using] = ACTIONS(3860),
    [anon_sym_concept] = ACTIONS(3862),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(819)] = {
    [sym_expression] = STATE(3419),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(3970),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3973),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(3976),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(3979),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(820)] = {
    [sym_function_definition] = STATE(2083),
    [sym_declaration] = STATE(2083),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5463),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1892),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6858),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2356),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(2083),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1747),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(2083),
    [sym_operator_cast] = STATE(7420),
    [sym__constructor_specifiers] = STATE(1747),
    [sym_operator_cast_definition] = STATE(2083),
    [sym_operator_cast_declaration] = STATE(2083),
    [sym_constructor_or_destructor_definition] = STATE(2083),
    [sym_constructor_or_destructor_declaration] = STATE(2083),
    [sym_friend_declaration] = STATE(2083),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(2083),
    [sym_concept_definition] = STATE(2083),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7420),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3544),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3546),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3548),
    [anon_sym_using] = ACTIONS(3838),
    [anon_sym_concept] = ACTIONS(3840),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(821)] = {
    [sym_expression] = STATE(5089),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3982),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3985),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(3988),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(3991),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(822)] = {
    [sym_function_definition] = STATE(492),
    [sym_declaration] = STATE(492),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5455),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1891),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6827),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2353),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(492),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1758),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(492),
    [sym_operator_cast] = STATE(7422),
    [sym__constructor_specifiers] = STATE(1758),
    [sym_operator_cast_definition] = STATE(492),
    [sym_operator_cast_declaration] = STATE(492),
    [sym_constructor_or_destructor_definition] = STATE(492),
    [sym_constructor_or_destructor_declaration] = STATE(492),
    [sym_friend_declaration] = STATE(492),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(492),
    [sym_concept_definition] = STATE(492),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7422),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1758),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3852),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3854),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3856),
    [anon_sym_using] = ACTIONS(3858),
    [anon_sym_concept] = ACTIONS(937),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(823)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(1964),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1971),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(824)] = {
    [sym_function_definition] = STATE(2024),
    [sym_declaration] = STATE(2024),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5472),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1894),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6872),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2341),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(2024),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1760),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(2024),
    [sym_operator_cast] = STATE(7436),
    [sym__constructor_specifiers] = STATE(1760),
    [sym_operator_cast_definition] = STATE(2024),
    [sym_operator_cast_declaration] = STATE(2024),
    [sym_constructor_or_destructor_definition] = STATE(2024),
    [sym_constructor_or_destructor_declaration] = STATE(2024),
    [sym_friend_declaration] = STATE(2024),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(2024),
    [sym_concept_definition] = STATE(2024),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7436),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1760),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3628),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3630),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3632),
    [anon_sym_using] = ACTIONS(3872),
    [anon_sym_concept] = ACTIONS(3874),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(825)] = {
    [sym_function_definition] = STATE(304),
    [sym_declaration] = STATE(304),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1890),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6826),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2342),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(304),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1745),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(304),
    [sym_operator_cast] = STATE(7433),
    [sym__constructor_specifiers] = STATE(1745),
    [sym_operator_cast_definition] = STATE(304),
    [sym_operator_cast_declaration] = STATE(304),
    [sym_constructor_or_destructor_definition] = STATE(304),
    [sym_constructor_or_destructor_declaration] = STATE(304),
    [sym_friend_declaration] = STATE(304),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(304),
    [sym_concept_definition] = STATE(304),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7433),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1745),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3844),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3846),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3848),
    [anon_sym_using] = ACTIONS(3850),
    [anon_sym_concept] = ACTIONS(333),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(826)] = {
    [sym_function_definition] = STATE(559),
    [sym_declaration] = STATE(559),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1889),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6825),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2340),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(559),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1751),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(559),
    [sym_operator_cast] = STATE(7435),
    [sym__constructor_specifiers] = STATE(1751),
    [sym_operator_cast_definition] = STATE(559),
    [sym_operator_cast_declaration] = STATE(559),
    [sym_constructor_or_destructor_definition] = STATE(559),
    [sym_constructor_or_destructor_declaration] = STATE(559),
    [sym_friend_declaration] = STATE(559),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(559),
    [sym_concept_definition] = STATE(559),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7435),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1751),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3876),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3878),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3880),
    [anon_sym_using] = ACTIONS(3882),
    [anon_sym_concept] = ACTIONS(237),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(827)] = {
    [sym_function_definition] = STATE(752),
    [sym_declaration] = STATE(752),
    [sym__declaration_modifiers] = STATE(2708),
    [sym__declaration_specifiers] = STATE(5483),
    [sym_attribute_specifier] = STATE(2708),
    [sym_attribute_declaration] = STATE(2708),
    [sym_ms_declspec_modifier] = STATE(2708),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(1888),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6822),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2708),
    [sym_type_qualifier] = STATE(2708),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2335),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym__empty_declaration] = STATE(752),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_explicit_function_specifier] = STATE(1746),
    [sym_dependent_type] = STATE(2264),
    [sym_template_declaration] = STATE(752),
    [sym_operator_cast] = STATE(7391),
    [sym__constructor_specifiers] = STATE(1746),
    [sym_operator_cast_definition] = STATE(752),
    [sym_operator_cast_declaration] = STATE(752),
    [sym_constructor_or_destructor_definition] = STATE(752),
    [sym_constructor_or_destructor_declaration] = STATE(752),
    [sym_friend_declaration] = STATE(752),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_alias_declaration] = STATE(752),
    [sym_concept_definition] = STATE(752),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6006),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_qualified_operator_cast_identifier] = STATE(7391),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2708),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1746),
    [sym_identifier] = ACTIONS(3834),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(39),
    [anon_sym___host__] = ACTIONS(39),
    [anon_sym___global__] = ACTIONS(39),
    [anon_sym___forceinline__] = ACTIONS(39),
    [anon_sym___noinline__] = ACTIONS(39),
    [anon_sym_virtual] = ACTIONS(39),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3836),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(3864),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(3866),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym_friend] = ACTIONS(3868),
    [anon_sym_using] = ACTIONS(3870),
    [anon_sym_concept] = ACTIONS(147),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(828)] = {
    [sym_expression] = STATE(5321),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3994),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3956),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_SLASH] = ACTIONS(3998),
    [anon_sym_PERCENT] = ACTIONS(3994),
    [anon_sym_PIPE_PIPE] = ACTIONS(3994),
    [anon_sym_AMP_AMP] = ACTIONS(3994),
    [anon_sym_PIPE] = ACTIONS(3998),
    [anon_sym_CARET] = ACTIONS(3994),
    [anon_sym_AMP] = ACTIONS(1241),
    [anon_sym_EQ_EQ] = ACTIONS(3994),
    [anon_sym_BANG_EQ] = ACTIONS(3994),
    [anon_sym_GT] = ACTIONS(3998),
    [anon_sym_GT_EQ] = ACTIONS(3994),
    [anon_sym_LT_EQ] = ACTIONS(3998),
    [anon_sym_LT] = ACTIONS(3998),
    [anon_sym_LT_LT] = ACTIONS(3998),
    [anon_sym_GT_GT] = ACTIONS(3994),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(3994),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_QMARK] = ACTIONS(3994),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_LT_EQ_GT] = ACTIONS(3994),
    [anon_sym_or] = ACTIONS(3998),
    [anon_sym_and] = ACTIONS(3998),
    [anon_sym_bitor] = ACTIONS(3998),
    [anon_sym_xor] = ACTIONS(3998),
    [anon_sym_bitand] = ACTIONS(3998),
    [anon_sym_not_eq] = ACTIONS(3998),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(3998),
    [anon_sym_DOT_STAR] = ACTIONS(3994),
    [anon_sym_DASH_GT] = ACTIONS(3994),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(3994),
  },
  [STATE(829)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1653),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4006),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4017),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4025),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym___cdecl] = ACTIONS(4002),
    [anon_sym___clrcall] = ACTIONS(4002),
    [anon_sym___stdcall] = ACTIONS(4002),
    [anon_sym___fastcall] = ACTIONS(4002),
    [anon_sym___thiscall] = ACTIONS(4002),
    [anon_sym___vectorcall] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4004),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4032),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4038),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(830)] = {
    [sym_identifier] = ACTIONS(4042),
    [anon_sym_LPAREN2] = ACTIONS(4045),
    [anon_sym_BANG] = ACTIONS(4048),
    [anon_sym_TILDE] = ACTIONS(4045),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4052),
    [anon_sym_AMP] = ACTIONS(4042),
    [anon_sym_SEMI] = ACTIONS(4048),
    [anon_sym___extension__] = ACTIONS(4042),
    [anon_sym___device__] = ACTIONS(4054),
    [anon_sym___host__] = ACTIONS(4054),
    [anon_sym___global__] = ACTIONS(4054),
    [anon_sym___forceinline__] = ACTIONS(4054),
    [anon_sym___noinline__] = ACTIONS(4054),
    [anon_sym_virtual] = ACTIONS(4054),
    [anon_sym_extern] = ACTIONS(4054),
    [anon_sym___attribute__] = ACTIONS(4054),
    [anon_sym___attribute] = ACTIONS(4054),
    [anon_sym_COLON_COLON] = ACTIONS(4045),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4045),
    [anon_sym___declspec] = ACTIONS(4054),
    [anon_sym___based] = ACTIONS(4054),
    [anon_sym_LBRACE] = ACTIONS(4048),
    [anon_sym_signed] = ACTIONS(4054),
    [anon_sym_unsigned] = ACTIONS(4054),
    [anon_sym_long] = ACTIONS(4054),
    [anon_sym_short] = ACTIONS(4054),
    [anon_sym_LBRACK] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4054),
    [anon_sym_register] = ACTIONS(4054),
    [anon_sym_inline] = ACTIONS(4054),
    [anon_sym___inline] = ACTIONS(4054),
    [anon_sym___inline__] = ACTIONS(4054),
    [anon_sym___forceinline] = ACTIONS(4054),
    [anon_sym_thread_local] = ACTIONS(4054),
    [anon_sym___thread] = ACTIONS(4054),
    [anon_sym_const] = ACTIONS(4054),
    [anon_sym_constexpr] = ACTIONS(4054),
    [anon_sym_volatile] = ACTIONS(4054),
    [anon_sym_restrict] = ACTIONS(4054),
    [anon_sym___restrict__] = ACTIONS(4054),
    [anon_sym__Atomic] = ACTIONS(4054),
    [anon_sym__Noreturn] = ACTIONS(4054),
    [anon_sym_noreturn] = ACTIONS(4054),
    [anon_sym__Nonnull] = ACTIONS(4054),
    [anon_sym_mutable] = ACTIONS(4054),
    [anon_sym_constinit] = ACTIONS(4054),
    [anon_sym_consteval] = ACTIONS(4054),
    [anon_sym___shared__] = ACTIONS(4054),
    [anon_sym___local__] = ACTIONS(4054),
    [anon_sym___constant__] = ACTIONS(4054),
    [anon_sym___managed__] = ACTIONS(4054),
    [anon_sym___grid_constant__] = ACTIONS(4054),
    [anon_sym_alignas] = ACTIONS(4054),
    [anon_sym__Alignas] = ACTIONS(4054),
    [sym_primitive_type] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4054),
    [anon_sym_class] = ACTIONS(4054),
    [anon_sym_struct] = ACTIONS(4054),
    [anon_sym_union] = ACTIONS(4054),
    [anon_sym_if] = ACTIONS(4050),
    [anon_sym_switch] = ACTIONS(4050),
    [anon_sym_case] = ACTIONS(4050),
    [anon_sym_default] = ACTIONS(4050),
    [anon_sym_while] = ACTIONS(4050),
    [anon_sym_do] = ACTIONS(4050),
    [anon_sym_for] = ACTIONS(4050),
    [anon_sym_return] = ACTIONS(4050),
    [anon_sym_break] = ACTIONS(4050),
    [anon_sym_continue] = ACTIONS(4050),
    [anon_sym_goto] = ACTIONS(4050),
    [anon_sym___try] = ACTIONS(4050),
    [anon_sym___leave] = ACTIONS(4050),
    [anon_sym_not] = ACTIONS(4050),
    [anon_sym_compl] = ACTIONS(4050),
    [anon_sym_DASH_DASH] = ACTIONS(4048),
    [anon_sym_PLUS_PLUS] = ACTIONS(4048),
    [anon_sym_sizeof] = ACTIONS(4050),
    [anon_sym___alignof__] = ACTIONS(4050),
    [anon_sym___alignof] = ACTIONS(4050),
    [anon_sym__alignof] = ACTIONS(4050),
    [anon_sym_alignof] = ACTIONS(4050),
    [anon_sym__Alignof] = ACTIONS(4050),
    [anon_sym_offsetof] = ACTIONS(4050),
    [anon_sym__Generic] = ACTIONS(4050),
    [anon_sym_asm] = ACTIONS(4050),
    [anon_sym___asm__] = ACTIONS(4050),
    [anon_sym___asm] = ACTIONS(4050),
    [sym_number_literal] = ACTIONS(4048),
    [anon_sym_L_SQUOTE] = ACTIONS(4048),
    [anon_sym_u_SQUOTE] = ACTIONS(4048),
    [anon_sym_U_SQUOTE] = ACTIONS(4048),
    [anon_sym_u8_SQUOTE] = ACTIONS(4048),
    [anon_sym_SQUOTE] = ACTIONS(4048),
    [anon_sym_L_DQUOTE] = ACTIONS(4048),
    [anon_sym_u_DQUOTE] = ACTIONS(4048),
    [anon_sym_U_DQUOTE] = ACTIONS(4048),
    [anon_sym_u8_DQUOTE] = ACTIONS(4048),
    [anon_sym_DQUOTE] = ACTIONS(4048),
    [sym_true] = ACTIONS(4050),
    [sym_false] = ACTIONS(4050),
    [anon_sym_NULL] = ACTIONS(4050),
    [anon_sym_nullptr] = ACTIONS(4050),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4054),
    [anon_sym_decltype] = ACTIONS(4042),
    [anon_sym_explicit] = ACTIONS(4054),
    [anon_sym_typename] = ACTIONS(4054),
    [anon_sym_template] = ACTIONS(4042),
    [anon_sym_operator] = ACTIONS(4054),
    [anon_sym_try] = ACTIONS(4050),
    [anon_sym_delete] = ACTIONS(4050),
    [anon_sym_throw] = ACTIONS(4050),
    [anon_sym_co_return] = ACTIONS(4050),
    [anon_sym_co_yield] = ACTIONS(4050),
    [anon_sym_R_DQUOTE] = ACTIONS(4048),
    [anon_sym_LR_DQUOTE] = ACTIONS(4048),
    [anon_sym_uR_DQUOTE] = ACTIONS(4048),
    [anon_sym_UR_DQUOTE] = ACTIONS(4048),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4048),
    [anon_sym_co_await] = ACTIONS(4050),
    [anon_sym_new] = ACTIONS(4050),
    [anon_sym_requires] = ACTIONS(4050),
    [sym_this] = ACTIONS(4050),
    [anon_sym___launch_bounds__] = ACTIONS(4054),
  },
  [STATE(831)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1653),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4006),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4017),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4025),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym___cdecl] = ACTIONS(4002),
    [anon_sym___clrcall] = ACTIONS(4002),
    [anon_sym___stdcall] = ACTIONS(4002),
    [anon_sym___fastcall] = ACTIONS(4002),
    [anon_sym___thiscall] = ACTIONS(4002),
    [anon_sym___vectorcall] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4032),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(832)] = {
    [sym_catch_clause] = STATE(834),
    [aux_sym_constructor_try_statement_repeat1] = STATE(834),
    [sym_identifier] = ACTIONS(1934),
    [anon_sym_LPAREN2] = ACTIONS(1936),
    [anon_sym_BANG] = ACTIONS(1936),
    [anon_sym_TILDE] = ACTIONS(1936),
    [anon_sym_DASH] = ACTIONS(1934),
    [anon_sym_PLUS] = ACTIONS(1934),
    [anon_sym_STAR] = ACTIONS(1936),
    [anon_sym_AMP] = ACTIONS(1936),
    [anon_sym_SEMI] = ACTIONS(1936),
    [anon_sym___extension__] = ACTIONS(1934),
    [anon_sym_typedef] = ACTIONS(1934),
    [anon_sym___device__] = ACTIONS(1934),
    [anon_sym___host__] = ACTIONS(1934),
    [anon_sym___global__] = ACTIONS(1934),
    [anon_sym___forceinline__] = ACTIONS(1934),
    [anon_sym___noinline__] = ACTIONS(1934),
    [anon_sym_virtual] = ACTIONS(1934),
    [anon_sym_extern] = ACTIONS(1934),
    [anon_sym___attribute__] = ACTIONS(1934),
    [anon_sym___attribute] = ACTIONS(1934),
    [anon_sym_COLON_COLON] = ACTIONS(1936),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1936),
    [anon_sym___declspec] = ACTIONS(1934),
    [anon_sym_LBRACE] = ACTIONS(1936),
    [anon_sym_signed] = ACTIONS(1934),
    [anon_sym_unsigned] = ACTIONS(1934),
    [anon_sym_long] = ACTIONS(1934),
    [anon_sym_short] = ACTIONS(1934),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [anon_sym_static] = ACTIONS(1934),
    [anon_sym_register] = ACTIONS(1934),
    [anon_sym_inline] = ACTIONS(1934),
    [anon_sym___inline] = ACTIONS(1934),
    [anon_sym___inline__] = ACTIONS(1934),
    [anon_sym___forceinline] = ACTIONS(1934),
    [anon_sym_thread_local] = ACTIONS(1934),
    [anon_sym___thread] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1934),
    [anon_sym_constexpr] = ACTIONS(1934),
    [anon_sym_volatile] = ACTIONS(1934),
    [anon_sym_restrict] = ACTIONS(1934),
    [anon_sym___restrict__] = ACTIONS(1934),
    [anon_sym__Atomic] = ACTIONS(1934),
    [anon_sym__Noreturn] = ACTIONS(1934),
    [anon_sym_noreturn] = ACTIONS(1934),
    [anon_sym__Nonnull] = ACTIONS(1934),
    [anon_sym_mutable] = ACTIONS(1934),
    [anon_sym_constinit] = ACTIONS(1934),
    [anon_sym_consteval] = ACTIONS(1934),
    [anon_sym___shared__] = ACTIONS(1934),
    [anon_sym___local__] = ACTIONS(1934),
    [anon_sym___constant__] = ACTIONS(1934),
    [anon_sym___managed__] = ACTIONS(1934),
    [anon_sym___grid_constant__] = ACTIONS(1934),
    [anon_sym_alignas] = ACTIONS(1934),
    [anon_sym__Alignas] = ACTIONS(1934),
    [sym_primitive_type] = ACTIONS(1934),
    [anon_sym_enum] = ACTIONS(1934),
    [anon_sym_class] = ACTIONS(1934),
    [anon_sym_struct] = ACTIONS(1934),
    [anon_sym_union] = ACTIONS(1934),
    [anon_sym_if] = ACTIONS(1934),
    [anon_sym_else] = ACTIONS(1934),
    [anon_sym_switch] = ACTIONS(1934),
    [anon_sym_while] = ACTIONS(1934),
    [anon_sym_do] = ACTIONS(1934),
    [anon_sym_for] = ACTIONS(1934),
    [anon_sym_return] = ACTIONS(1934),
    [anon_sym_break] = ACTIONS(1934),
    [anon_sym_continue] = ACTIONS(1934),
    [anon_sym_goto] = ACTIONS(1934),
    [anon_sym___try] = ACTIONS(1934),
    [anon_sym___leave] = ACTIONS(1934),
    [anon_sym_not] = ACTIONS(1934),
    [anon_sym_compl] = ACTIONS(1934),
    [anon_sym_DASH_DASH] = ACTIONS(1936),
    [anon_sym_PLUS_PLUS] = ACTIONS(1936),
    [anon_sym_sizeof] = ACTIONS(1934),
    [anon_sym___alignof__] = ACTIONS(1934),
    [anon_sym___alignof] = ACTIONS(1934),
    [anon_sym__alignof] = ACTIONS(1934),
    [anon_sym_alignof] = ACTIONS(1934),
    [anon_sym__Alignof] = ACTIONS(1934),
    [anon_sym_offsetof] = ACTIONS(1934),
    [anon_sym__Generic] = ACTIONS(1934),
    [anon_sym_asm] = ACTIONS(1934),
    [anon_sym___asm__] = ACTIONS(1934),
    [anon_sym___asm] = ACTIONS(1934),
    [sym_number_literal] = ACTIONS(1936),
    [anon_sym_L_SQUOTE] = ACTIONS(1936),
    [anon_sym_u_SQUOTE] = ACTIONS(1936),
    [anon_sym_U_SQUOTE] = ACTIONS(1936),
    [anon_sym_u8_SQUOTE] = ACTIONS(1936),
    [anon_sym_SQUOTE] = ACTIONS(1936),
    [anon_sym_L_DQUOTE] = ACTIONS(1936),
    [anon_sym_u_DQUOTE] = ACTIONS(1936),
    [anon_sym_U_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8_DQUOTE] = ACTIONS(1936),
    [anon_sym_DQUOTE] = ACTIONS(1936),
    [sym_true] = ACTIONS(1934),
    [sym_false] = ACTIONS(1934),
    [anon_sym_NULL] = ACTIONS(1934),
    [anon_sym_nullptr] = ACTIONS(1934),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1934),
    [anon_sym_decltype] = ACTIONS(1934),
    [anon_sym_typename] = ACTIONS(1934),
    [anon_sym_template] = ACTIONS(1934),
    [anon_sym_try] = ACTIONS(1934),
    [anon_sym_delete] = ACTIONS(1934),
    [anon_sym_throw] = ACTIONS(1934),
    [anon_sym_co_return] = ACTIONS(1934),
    [anon_sym_co_yield] = ACTIONS(1934),
    [anon_sym_catch] = ACTIONS(4058),
    [anon_sym_R_DQUOTE] = ACTIONS(1936),
    [anon_sym_LR_DQUOTE] = ACTIONS(1936),
    [anon_sym_uR_DQUOTE] = ACTIONS(1936),
    [anon_sym_UR_DQUOTE] = ACTIONS(1936),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1936),
    [anon_sym_co_await] = ACTIONS(1934),
    [anon_sym_new] = ACTIONS(1934),
    [anon_sym_requires] = ACTIONS(1934),
    [sym_this] = ACTIONS(1934),
    [anon_sym___launch_bounds__] = ACTIONS(1934),
  },
  [STATE(833)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1653),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4006),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4017),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4025),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym___cdecl] = ACTIONS(4002),
    [anon_sym___clrcall] = ACTIONS(4002),
    [anon_sym___stdcall] = ACTIONS(4002),
    [anon_sym___fastcall] = ACTIONS(4002),
    [anon_sym___thiscall] = ACTIONS(4002),
    [anon_sym___vectorcall] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4032),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4060),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(834)] = {
    [sym_catch_clause] = STATE(834),
    [aux_sym_constructor_try_statement_repeat1] = STATE(834),
    [sym_identifier] = ACTIONS(1940),
    [anon_sym_LPAREN2] = ACTIONS(1942),
    [anon_sym_BANG] = ACTIONS(1942),
    [anon_sym_TILDE] = ACTIONS(1942),
    [anon_sym_DASH] = ACTIONS(1940),
    [anon_sym_PLUS] = ACTIONS(1940),
    [anon_sym_STAR] = ACTIONS(1942),
    [anon_sym_AMP] = ACTIONS(1942),
    [anon_sym_SEMI] = ACTIONS(1942),
    [anon_sym___extension__] = ACTIONS(1940),
    [anon_sym_typedef] = ACTIONS(1940),
    [anon_sym___device__] = ACTIONS(1940),
    [anon_sym___host__] = ACTIONS(1940),
    [anon_sym___global__] = ACTIONS(1940),
    [anon_sym___forceinline__] = ACTIONS(1940),
    [anon_sym___noinline__] = ACTIONS(1940),
    [anon_sym_virtual] = ACTIONS(1940),
    [anon_sym_extern] = ACTIONS(1940),
    [anon_sym___attribute__] = ACTIONS(1940),
    [anon_sym___attribute] = ACTIONS(1940),
    [anon_sym_COLON_COLON] = ACTIONS(1942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1942),
    [anon_sym___declspec] = ACTIONS(1940),
    [anon_sym_LBRACE] = ACTIONS(1942),
    [anon_sym_signed] = ACTIONS(1940),
    [anon_sym_unsigned] = ACTIONS(1940),
    [anon_sym_long] = ACTIONS(1940),
    [anon_sym_short] = ACTIONS(1940),
    [anon_sym_LBRACK] = ACTIONS(1940),
    [anon_sym_static] = ACTIONS(1940),
    [anon_sym_register] = ACTIONS(1940),
    [anon_sym_inline] = ACTIONS(1940),
    [anon_sym___inline] = ACTIONS(1940),
    [anon_sym___inline__] = ACTIONS(1940),
    [anon_sym___forceinline] = ACTIONS(1940),
    [anon_sym_thread_local] = ACTIONS(1940),
    [anon_sym___thread] = ACTIONS(1940),
    [anon_sym_const] = ACTIONS(1940),
    [anon_sym_constexpr] = ACTIONS(1940),
    [anon_sym_volatile] = ACTIONS(1940),
    [anon_sym_restrict] = ACTIONS(1940),
    [anon_sym___restrict__] = ACTIONS(1940),
    [anon_sym__Atomic] = ACTIONS(1940),
    [anon_sym__Noreturn] = ACTIONS(1940),
    [anon_sym_noreturn] = ACTIONS(1940),
    [anon_sym__Nonnull] = ACTIONS(1940),
    [anon_sym_mutable] = ACTIONS(1940),
    [anon_sym_constinit] = ACTIONS(1940),
    [anon_sym_consteval] = ACTIONS(1940),
    [anon_sym___shared__] = ACTIONS(1940),
    [anon_sym___local__] = ACTIONS(1940),
    [anon_sym___constant__] = ACTIONS(1940),
    [anon_sym___managed__] = ACTIONS(1940),
    [anon_sym___grid_constant__] = ACTIONS(1940),
    [anon_sym_alignas] = ACTIONS(1940),
    [anon_sym__Alignas] = ACTIONS(1940),
    [sym_primitive_type] = ACTIONS(1940),
    [anon_sym_enum] = ACTIONS(1940),
    [anon_sym_class] = ACTIONS(1940),
    [anon_sym_struct] = ACTIONS(1940),
    [anon_sym_union] = ACTIONS(1940),
    [anon_sym_if] = ACTIONS(1940),
    [anon_sym_else] = ACTIONS(1940),
    [anon_sym_switch] = ACTIONS(1940),
    [anon_sym_while] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_for] = ACTIONS(1940),
    [anon_sym_return] = ACTIONS(1940),
    [anon_sym_break] = ACTIONS(1940),
    [anon_sym_continue] = ACTIONS(1940),
    [anon_sym_goto] = ACTIONS(1940),
    [anon_sym___try] = ACTIONS(1940),
    [anon_sym___leave] = ACTIONS(1940),
    [anon_sym_not] = ACTIONS(1940),
    [anon_sym_compl] = ACTIONS(1940),
    [anon_sym_DASH_DASH] = ACTIONS(1942),
    [anon_sym_PLUS_PLUS] = ACTIONS(1942),
    [anon_sym_sizeof] = ACTIONS(1940),
    [anon_sym___alignof__] = ACTIONS(1940),
    [anon_sym___alignof] = ACTIONS(1940),
    [anon_sym__alignof] = ACTIONS(1940),
    [anon_sym_alignof] = ACTIONS(1940),
    [anon_sym__Alignof] = ACTIONS(1940),
    [anon_sym_offsetof] = ACTIONS(1940),
    [anon_sym__Generic] = ACTIONS(1940),
    [anon_sym_asm] = ACTIONS(1940),
    [anon_sym___asm__] = ACTIONS(1940),
    [anon_sym___asm] = ACTIONS(1940),
    [sym_number_literal] = ACTIONS(1942),
    [anon_sym_L_SQUOTE] = ACTIONS(1942),
    [anon_sym_u_SQUOTE] = ACTIONS(1942),
    [anon_sym_U_SQUOTE] = ACTIONS(1942),
    [anon_sym_u8_SQUOTE] = ACTIONS(1942),
    [anon_sym_SQUOTE] = ACTIONS(1942),
    [anon_sym_L_DQUOTE] = ACTIONS(1942),
    [anon_sym_u_DQUOTE] = ACTIONS(1942),
    [anon_sym_U_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8_DQUOTE] = ACTIONS(1942),
    [anon_sym_DQUOTE] = ACTIONS(1942),
    [sym_true] = ACTIONS(1940),
    [sym_false] = ACTIONS(1940),
    [anon_sym_NULL] = ACTIONS(1940),
    [anon_sym_nullptr] = ACTIONS(1940),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1940),
    [anon_sym_decltype] = ACTIONS(1940),
    [anon_sym_typename] = ACTIONS(1940),
    [anon_sym_template] = ACTIONS(1940),
    [anon_sym_try] = ACTIONS(1940),
    [anon_sym_delete] = ACTIONS(1940),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_co_return] = ACTIONS(1940),
    [anon_sym_co_yield] = ACTIONS(1940),
    [anon_sym_catch] = ACTIONS(4062),
    [anon_sym_R_DQUOTE] = ACTIONS(1942),
    [anon_sym_LR_DQUOTE] = ACTIONS(1942),
    [anon_sym_uR_DQUOTE] = ACTIONS(1942),
    [anon_sym_UR_DQUOTE] = ACTIONS(1942),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1942),
    [anon_sym_co_await] = ACTIONS(1940),
    [anon_sym_new] = ACTIONS(1940),
    [anon_sym_requires] = ACTIONS(1940),
    [sym_this] = ACTIONS(1940),
    [anon_sym___launch_bounds__] = ACTIONS(1940),
  },
  [STATE(835)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1653),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4006),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4017),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4025),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym___cdecl] = ACTIONS(4002),
    [anon_sym___clrcall] = ACTIONS(4002),
    [anon_sym___stdcall] = ACTIONS(4002),
    [anon_sym___fastcall] = ACTIONS(4002),
    [anon_sym___thiscall] = ACTIONS(4002),
    [anon_sym___vectorcall] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4032),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4065),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(836)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1653),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4006),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4067),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4025),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym___cdecl] = ACTIONS(4002),
    [anon_sym___clrcall] = ACTIONS(4002),
    [anon_sym___stdcall] = ACTIONS(4002),
    [anon_sym___fastcall] = ACTIONS(4002),
    [anon_sym___thiscall] = ACTIONS(4002),
    [anon_sym___vectorcall] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4032),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4069),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(837)] = {
    [sym_type_qualifier] = STATE(864),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5309),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(864),
    [sym_identifier] = ACTIONS(4071),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4073),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4079),
    [anon_sym_RBRACK] = ACTIONS(4081),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(838)] = {
    [sym_type_qualifier] = STATE(842),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5354),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(842),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4085),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4087),
    [anon_sym_RBRACK] = ACTIONS(4089),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(839)] = {
    [sym_type_qualifier] = STATE(847),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5365),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(847),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4093),
    [anon_sym_RBRACK] = ACTIONS(4095),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(840)] = {
    [sym_type_qualifier] = STATE(843),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5320),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4097),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4099),
    [anon_sym_RBRACK] = ACTIONS(4101),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(841)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5362),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4103),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4107),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(842)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5328),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4109),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4111),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(843)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5358),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4113),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4115),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(844)] = {
    [sym_type_qualifier] = STATE(855),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5275),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(855),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4117),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4119),
    [anon_sym_RBRACK] = ACTIONS(4121),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(845)] = {
    [sym_type_qualifier] = STATE(863),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5370),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(863),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4123),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4125),
    [anon_sym_RBRACK] = ACTIONS(4127),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(846)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5341),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4129),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4131),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(847)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5386),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4133),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4135),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(848)] = {
    [sym_type_qualifier] = STATE(864),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5309),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(864),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4073),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4079),
    [anon_sym_RBRACK] = ACTIONS(4081),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(849)] = {
    [sym_identifier] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_BANG] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_DASH] = ACTIONS(1932),
    [anon_sym_PLUS] = ACTIONS(1932),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1930),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_if] = ACTIONS(1932),
    [anon_sym_else] = ACTIONS(1932),
    [anon_sym_switch] = ACTIONS(1932),
    [anon_sym_while] = ACTIONS(1932),
    [anon_sym_do] = ACTIONS(1932),
    [anon_sym_for] = ACTIONS(1932),
    [anon_sym_return] = ACTIONS(1932),
    [anon_sym_break] = ACTIONS(1932),
    [anon_sym_continue] = ACTIONS(1932),
    [anon_sym_goto] = ACTIONS(1932),
    [anon_sym___try] = ACTIONS(1932),
    [anon_sym___leave] = ACTIONS(1932),
    [anon_sym_not] = ACTIONS(1932),
    [anon_sym_compl] = ACTIONS(1932),
    [anon_sym_DASH_DASH] = ACTIONS(1930),
    [anon_sym_PLUS_PLUS] = ACTIONS(1930),
    [anon_sym_sizeof] = ACTIONS(1932),
    [anon_sym___alignof__] = ACTIONS(1932),
    [anon_sym___alignof] = ACTIONS(1932),
    [anon_sym__alignof] = ACTIONS(1932),
    [anon_sym_alignof] = ACTIONS(1932),
    [anon_sym__Alignof] = ACTIONS(1932),
    [anon_sym_offsetof] = ACTIONS(1932),
    [anon_sym__Generic] = ACTIONS(1932),
    [anon_sym_asm] = ACTIONS(1932),
    [anon_sym___asm__] = ACTIONS(1932),
    [anon_sym___asm] = ACTIONS(1932),
    [sym_number_literal] = ACTIONS(1930),
    [anon_sym_L_SQUOTE] = ACTIONS(1930),
    [anon_sym_u_SQUOTE] = ACTIONS(1930),
    [anon_sym_U_SQUOTE] = ACTIONS(1930),
    [anon_sym_u8_SQUOTE] = ACTIONS(1930),
    [anon_sym_SQUOTE] = ACTIONS(1930),
    [anon_sym_L_DQUOTE] = ACTIONS(1930),
    [anon_sym_u_DQUOTE] = ACTIONS(1930),
    [anon_sym_U_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8_DQUOTE] = ACTIONS(1930),
    [anon_sym_DQUOTE] = ACTIONS(1930),
    [sym_true] = ACTIONS(1932),
    [sym_false] = ACTIONS(1932),
    [anon_sym_NULL] = ACTIONS(1932),
    [anon_sym_nullptr] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_try] = ACTIONS(1932),
    [anon_sym_delete] = ACTIONS(1932),
    [anon_sym_throw] = ACTIONS(1932),
    [anon_sym_co_return] = ACTIONS(1932),
    [anon_sym_co_yield] = ACTIONS(1932),
    [anon_sym_catch] = ACTIONS(1932),
    [anon_sym_R_DQUOTE] = ACTIONS(1930),
    [anon_sym_LR_DQUOTE] = ACTIONS(1930),
    [anon_sym_uR_DQUOTE] = ACTIONS(1930),
    [anon_sym_UR_DQUOTE] = ACTIONS(1930),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1930),
    [anon_sym_co_await] = ACTIONS(1932),
    [anon_sym_new] = ACTIONS(1932),
    [anon_sym_requires] = ACTIONS(1932),
    [sym_this] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(850)] = {
    [sym_type_qualifier] = STATE(853),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5298),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(853),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4137),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4139),
    [anon_sym_RBRACK] = ACTIONS(4141),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(851)] = {
    [sym_type_qualifier] = STATE(861),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5372),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(861),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4143),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4145),
    [anon_sym_RBRACK] = ACTIONS(4147),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(852)] = {
    [sym_type_qualifier] = STATE(862),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5350),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(862),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4153),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(853)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5306),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4155),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4157),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(854)] = {
    [sym_identifier] = ACTIONS(2006),
    [anon_sym_LPAREN2] = ACTIONS(2008),
    [anon_sym_BANG] = ACTIONS(2008),
    [anon_sym_TILDE] = ACTIONS(2008),
    [anon_sym_DASH] = ACTIONS(2006),
    [anon_sym_PLUS] = ACTIONS(2006),
    [anon_sym_STAR] = ACTIONS(2008),
    [anon_sym_AMP] = ACTIONS(2008),
    [anon_sym_SEMI] = ACTIONS(2008),
    [anon_sym___extension__] = ACTIONS(2006),
    [anon_sym_typedef] = ACTIONS(2006),
    [anon_sym___device__] = ACTIONS(2006),
    [anon_sym___host__] = ACTIONS(2006),
    [anon_sym___global__] = ACTIONS(2006),
    [anon_sym___forceinline__] = ACTIONS(2006),
    [anon_sym___noinline__] = ACTIONS(2006),
    [anon_sym_virtual] = ACTIONS(2006),
    [anon_sym_extern] = ACTIONS(2006),
    [anon_sym___attribute__] = ACTIONS(2006),
    [anon_sym___attribute] = ACTIONS(2006),
    [anon_sym_COLON_COLON] = ACTIONS(2008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2008),
    [anon_sym___declspec] = ACTIONS(2006),
    [anon_sym_LBRACE] = ACTIONS(2008),
    [anon_sym_signed] = ACTIONS(2006),
    [anon_sym_unsigned] = ACTIONS(2006),
    [anon_sym_long] = ACTIONS(2006),
    [anon_sym_short] = ACTIONS(2006),
    [anon_sym_LBRACK] = ACTIONS(2006),
    [anon_sym_static] = ACTIONS(2006),
    [anon_sym_register] = ACTIONS(2006),
    [anon_sym_inline] = ACTIONS(2006),
    [anon_sym___inline] = ACTIONS(2006),
    [anon_sym___inline__] = ACTIONS(2006),
    [anon_sym___forceinline] = ACTIONS(2006),
    [anon_sym_thread_local] = ACTIONS(2006),
    [anon_sym___thread] = ACTIONS(2006),
    [anon_sym_const] = ACTIONS(2006),
    [anon_sym_constexpr] = ACTIONS(2006),
    [anon_sym_volatile] = ACTIONS(2006),
    [anon_sym_restrict] = ACTIONS(2006),
    [anon_sym___restrict__] = ACTIONS(2006),
    [anon_sym__Atomic] = ACTIONS(2006),
    [anon_sym__Noreturn] = ACTIONS(2006),
    [anon_sym_noreturn] = ACTIONS(2006),
    [anon_sym__Nonnull] = ACTIONS(2006),
    [anon_sym_mutable] = ACTIONS(2006),
    [anon_sym_constinit] = ACTIONS(2006),
    [anon_sym_consteval] = ACTIONS(2006),
    [anon_sym___shared__] = ACTIONS(2006),
    [anon_sym___local__] = ACTIONS(2006),
    [anon_sym___constant__] = ACTIONS(2006),
    [anon_sym___managed__] = ACTIONS(2006),
    [anon_sym___grid_constant__] = ACTIONS(2006),
    [anon_sym_alignas] = ACTIONS(2006),
    [anon_sym__Alignas] = ACTIONS(2006),
    [sym_primitive_type] = ACTIONS(2006),
    [anon_sym_enum] = ACTIONS(2006),
    [anon_sym_class] = ACTIONS(2006),
    [anon_sym_struct] = ACTIONS(2006),
    [anon_sym_union] = ACTIONS(2006),
    [anon_sym_if] = ACTIONS(2006),
    [anon_sym_else] = ACTIONS(2006),
    [anon_sym_switch] = ACTIONS(2006),
    [anon_sym_while] = ACTIONS(2006),
    [anon_sym_do] = ACTIONS(2006),
    [anon_sym_for] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2006),
    [anon_sym_break] = ACTIONS(2006),
    [anon_sym_continue] = ACTIONS(2006),
    [anon_sym_goto] = ACTIONS(2006),
    [anon_sym___try] = ACTIONS(2006),
    [anon_sym___leave] = ACTIONS(2006),
    [anon_sym_not] = ACTIONS(2006),
    [anon_sym_compl] = ACTIONS(2006),
    [anon_sym_DASH_DASH] = ACTIONS(2008),
    [anon_sym_PLUS_PLUS] = ACTIONS(2008),
    [anon_sym_sizeof] = ACTIONS(2006),
    [anon_sym___alignof__] = ACTIONS(2006),
    [anon_sym___alignof] = ACTIONS(2006),
    [anon_sym__alignof] = ACTIONS(2006),
    [anon_sym_alignof] = ACTIONS(2006),
    [anon_sym__Alignof] = ACTIONS(2006),
    [anon_sym_offsetof] = ACTIONS(2006),
    [anon_sym__Generic] = ACTIONS(2006),
    [anon_sym_asm] = ACTIONS(2006),
    [anon_sym___asm__] = ACTIONS(2006),
    [anon_sym___asm] = ACTIONS(2006),
    [sym_number_literal] = ACTIONS(2008),
    [anon_sym_L_SQUOTE] = ACTIONS(2008),
    [anon_sym_u_SQUOTE] = ACTIONS(2008),
    [anon_sym_U_SQUOTE] = ACTIONS(2008),
    [anon_sym_u8_SQUOTE] = ACTIONS(2008),
    [anon_sym_SQUOTE] = ACTIONS(2008),
    [anon_sym_L_DQUOTE] = ACTIONS(2008),
    [anon_sym_u_DQUOTE] = ACTIONS(2008),
    [anon_sym_U_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8_DQUOTE] = ACTIONS(2008),
    [anon_sym_DQUOTE] = ACTIONS(2008),
    [sym_true] = ACTIONS(2006),
    [sym_false] = ACTIONS(2006),
    [anon_sym_NULL] = ACTIONS(2006),
    [anon_sym_nullptr] = ACTIONS(2006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2006),
    [anon_sym_decltype] = ACTIONS(2006),
    [anon_sym_typename] = ACTIONS(2006),
    [anon_sym_template] = ACTIONS(2006),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_delete] = ACTIONS(2006),
    [anon_sym_throw] = ACTIONS(2006),
    [anon_sym_co_return] = ACTIONS(2006),
    [anon_sym_co_yield] = ACTIONS(2006),
    [anon_sym_catch] = ACTIONS(2006),
    [anon_sym_R_DQUOTE] = ACTIONS(2008),
    [anon_sym_LR_DQUOTE] = ACTIONS(2008),
    [anon_sym_uR_DQUOTE] = ACTIONS(2008),
    [anon_sym_UR_DQUOTE] = ACTIONS(2008),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2008),
    [anon_sym_co_await] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(2006),
    [anon_sym_requires] = ACTIONS(2006),
    [sym_this] = ACTIONS(2006),
    [anon_sym___launch_bounds__] = ACTIONS(2006),
  },
  [STATE(855)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5307),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4159),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4161),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(856)] = {
    [sym_type_qualifier] = STATE(841),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5261),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(841),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4163),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4165),
    [anon_sym_RBRACK] = ACTIONS(4167),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(857)] = {
    [sym_else_clause] = STATE(882),
    [sym_identifier] = ACTIONS(2016),
    [anon_sym_LPAREN2] = ACTIONS(2018),
    [anon_sym_BANG] = ACTIONS(2018),
    [anon_sym_TILDE] = ACTIONS(2018),
    [anon_sym_DASH] = ACTIONS(2016),
    [anon_sym_PLUS] = ACTIONS(2016),
    [anon_sym_STAR] = ACTIONS(2018),
    [anon_sym_AMP] = ACTIONS(2018),
    [anon_sym_SEMI] = ACTIONS(2018),
    [anon_sym___extension__] = ACTIONS(2016),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym___device__] = ACTIONS(2016),
    [anon_sym___host__] = ACTIONS(2016),
    [anon_sym___global__] = ACTIONS(2016),
    [anon_sym___forceinline__] = ACTIONS(2016),
    [anon_sym___noinline__] = ACTIONS(2016),
    [anon_sym_virtual] = ACTIONS(2016),
    [anon_sym_extern] = ACTIONS(2016),
    [anon_sym___attribute__] = ACTIONS(2016),
    [anon_sym___attribute] = ACTIONS(2016),
    [anon_sym_COLON_COLON] = ACTIONS(2018),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2018),
    [anon_sym___declspec] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2018),
    [anon_sym_signed] = ACTIONS(2016),
    [anon_sym_unsigned] = ACTIONS(2016),
    [anon_sym_long] = ACTIONS(2016),
    [anon_sym_short] = ACTIONS(2016),
    [anon_sym_LBRACK] = ACTIONS(2016),
    [anon_sym_static] = ACTIONS(2016),
    [anon_sym_register] = ACTIONS(2016),
    [anon_sym_inline] = ACTIONS(2016),
    [anon_sym___inline] = ACTIONS(2016),
    [anon_sym___inline__] = ACTIONS(2016),
    [anon_sym___forceinline] = ACTIONS(2016),
    [anon_sym_thread_local] = ACTIONS(2016),
    [anon_sym___thread] = ACTIONS(2016),
    [anon_sym_const] = ACTIONS(2016),
    [anon_sym_constexpr] = ACTIONS(2016),
    [anon_sym_volatile] = ACTIONS(2016),
    [anon_sym_restrict] = ACTIONS(2016),
    [anon_sym___restrict__] = ACTIONS(2016),
    [anon_sym__Atomic] = ACTIONS(2016),
    [anon_sym__Noreturn] = ACTIONS(2016),
    [anon_sym_noreturn] = ACTIONS(2016),
    [anon_sym__Nonnull] = ACTIONS(2016),
    [anon_sym_mutable] = ACTIONS(2016),
    [anon_sym_constinit] = ACTIONS(2016),
    [anon_sym_consteval] = ACTIONS(2016),
    [anon_sym___shared__] = ACTIONS(2016),
    [anon_sym___local__] = ACTIONS(2016),
    [anon_sym___constant__] = ACTIONS(2016),
    [anon_sym___managed__] = ACTIONS(2016),
    [anon_sym___grid_constant__] = ACTIONS(2016),
    [anon_sym_alignas] = ACTIONS(2016),
    [anon_sym__Alignas] = ACTIONS(2016),
    [sym_primitive_type] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2016),
    [anon_sym_class] = ACTIONS(2016),
    [anon_sym_struct] = ACTIONS(2016),
    [anon_sym_union] = ACTIONS(2016),
    [anon_sym_if] = ACTIONS(2016),
    [anon_sym_else] = ACTIONS(4169),
    [anon_sym_switch] = ACTIONS(2016),
    [anon_sym_while] = ACTIONS(2016),
    [anon_sym_do] = ACTIONS(2016),
    [anon_sym_for] = ACTIONS(2016),
    [anon_sym_return] = ACTIONS(2016),
    [anon_sym_break] = ACTIONS(2016),
    [anon_sym_continue] = ACTIONS(2016),
    [anon_sym_goto] = ACTIONS(2016),
    [anon_sym___try] = ACTIONS(2016),
    [anon_sym___leave] = ACTIONS(2016),
    [anon_sym_not] = ACTIONS(2016),
    [anon_sym_compl] = ACTIONS(2016),
    [anon_sym_DASH_DASH] = ACTIONS(2018),
    [anon_sym_PLUS_PLUS] = ACTIONS(2018),
    [anon_sym_sizeof] = ACTIONS(2016),
    [anon_sym___alignof__] = ACTIONS(2016),
    [anon_sym___alignof] = ACTIONS(2016),
    [anon_sym__alignof] = ACTIONS(2016),
    [anon_sym_alignof] = ACTIONS(2016),
    [anon_sym__Alignof] = ACTIONS(2016),
    [anon_sym_offsetof] = ACTIONS(2016),
    [anon_sym__Generic] = ACTIONS(2016),
    [anon_sym_asm] = ACTIONS(2016),
    [anon_sym___asm__] = ACTIONS(2016),
    [anon_sym___asm] = ACTIONS(2016),
    [sym_number_literal] = ACTIONS(2018),
    [anon_sym_L_SQUOTE] = ACTIONS(2018),
    [anon_sym_u_SQUOTE] = ACTIONS(2018),
    [anon_sym_U_SQUOTE] = ACTIONS(2018),
    [anon_sym_u8_SQUOTE] = ACTIONS(2018),
    [anon_sym_SQUOTE] = ACTIONS(2018),
    [anon_sym_L_DQUOTE] = ACTIONS(2018),
    [anon_sym_u_DQUOTE] = ACTIONS(2018),
    [anon_sym_U_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8_DQUOTE] = ACTIONS(2018),
    [anon_sym_DQUOTE] = ACTIONS(2018),
    [sym_true] = ACTIONS(2016),
    [sym_false] = ACTIONS(2016),
    [anon_sym_NULL] = ACTIONS(2016),
    [anon_sym_nullptr] = ACTIONS(2016),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2016),
    [anon_sym_decltype] = ACTIONS(2016),
    [anon_sym_typename] = ACTIONS(2016),
    [anon_sym_template] = ACTIONS(2016),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_delete] = ACTIONS(2016),
    [anon_sym_throw] = ACTIONS(2016),
    [anon_sym_co_return] = ACTIONS(2016),
    [anon_sym_co_yield] = ACTIONS(2016),
    [anon_sym_R_DQUOTE] = ACTIONS(2018),
    [anon_sym_LR_DQUOTE] = ACTIONS(2018),
    [anon_sym_uR_DQUOTE] = ACTIONS(2018),
    [anon_sym_UR_DQUOTE] = ACTIONS(2018),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2018),
    [anon_sym_co_await] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(2016),
    [anon_sym_requires] = ACTIONS(2016),
    [sym_this] = ACTIONS(2016),
    [anon_sym___launch_bounds__] = ACTIONS(2016),
  },
  [STATE(858)] = {
    [sym_identifier] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_BANG] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_DASH] = ACTIONS(1928),
    [anon_sym_PLUS] = ACTIONS(1928),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1926),
    [anon_sym_SEMI] = ACTIONS(1926),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym_typedef] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym_LBRACE] = ACTIONS(1926),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [anon_sym_if] = ACTIONS(1928),
    [anon_sym_else] = ACTIONS(1928),
    [anon_sym_switch] = ACTIONS(1928),
    [anon_sym_while] = ACTIONS(1928),
    [anon_sym_do] = ACTIONS(1928),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_return] = ACTIONS(1928),
    [anon_sym_break] = ACTIONS(1928),
    [anon_sym_continue] = ACTIONS(1928),
    [anon_sym_goto] = ACTIONS(1928),
    [anon_sym___try] = ACTIONS(1928),
    [anon_sym___leave] = ACTIONS(1928),
    [anon_sym_not] = ACTIONS(1928),
    [anon_sym_compl] = ACTIONS(1928),
    [anon_sym_DASH_DASH] = ACTIONS(1926),
    [anon_sym_PLUS_PLUS] = ACTIONS(1926),
    [anon_sym_sizeof] = ACTIONS(1928),
    [anon_sym___alignof__] = ACTIONS(1928),
    [anon_sym___alignof] = ACTIONS(1928),
    [anon_sym__alignof] = ACTIONS(1928),
    [anon_sym_alignof] = ACTIONS(1928),
    [anon_sym__Alignof] = ACTIONS(1928),
    [anon_sym_offsetof] = ACTIONS(1928),
    [anon_sym__Generic] = ACTIONS(1928),
    [anon_sym_asm] = ACTIONS(1928),
    [anon_sym___asm__] = ACTIONS(1928),
    [anon_sym___asm] = ACTIONS(1928),
    [sym_number_literal] = ACTIONS(1926),
    [anon_sym_L_SQUOTE] = ACTIONS(1926),
    [anon_sym_u_SQUOTE] = ACTIONS(1926),
    [anon_sym_U_SQUOTE] = ACTIONS(1926),
    [anon_sym_u8_SQUOTE] = ACTIONS(1926),
    [anon_sym_SQUOTE] = ACTIONS(1926),
    [anon_sym_L_DQUOTE] = ACTIONS(1926),
    [anon_sym_u_DQUOTE] = ACTIONS(1926),
    [anon_sym_U_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8_DQUOTE] = ACTIONS(1926),
    [anon_sym_DQUOTE] = ACTIONS(1926),
    [sym_true] = ACTIONS(1928),
    [sym_false] = ACTIONS(1928),
    [anon_sym_NULL] = ACTIONS(1928),
    [anon_sym_nullptr] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_delete] = ACTIONS(1928),
    [anon_sym_throw] = ACTIONS(1928),
    [anon_sym_co_return] = ACTIONS(1928),
    [anon_sym_co_yield] = ACTIONS(1928),
    [anon_sym_catch] = ACTIONS(1928),
    [anon_sym_R_DQUOTE] = ACTIONS(1926),
    [anon_sym_LR_DQUOTE] = ACTIONS(1926),
    [anon_sym_uR_DQUOTE] = ACTIONS(1926),
    [anon_sym_UR_DQUOTE] = ACTIONS(1926),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1926),
    [anon_sym_co_await] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1928),
    [anon_sym_requires] = ACTIONS(1928),
    [sym_this] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(859)] = {
    [sym_type_qualifier] = STATE(846),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5317),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(846),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4171),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4173),
    [anon_sym_RBRACK] = ACTIONS(4175),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(860)] = {
    [sym_else_clause] = STATE(872),
    [sym_identifier] = ACTIONS(2010),
    [anon_sym_LPAREN2] = ACTIONS(2012),
    [anon_sym_BANG] = ACTIONS(2012),
    [anon_sym_TILDE] = ACTIONS(2012),
    [anon_sym_DASH] = ACTIONS(2010),
    [anon_sym_PLUS] = ACTIONS(2010),
    [anon_sym_STAR] = ACTIONS(2012),
    [anon_sym_AMP] = ACTIONS(2012),
    [anon_sym_SEMI] = ACTIONS(2012),
    [anon_sym___extension__] = ACTIONS(2010),
    [anon_sym_typedef] = ACTIONS(2010),
    [anon_sym___device__] = ACTIONS(2010),
    [anon_sym___host__] = ACTIONS(2010),
    [anon_sym___global__] = ACTIONS(2010),
    [anon_sym___forceinline__] = ACTIONS(2010),
    [anon_sym___noinline__] = ACTIONS(2010),
    [anon_sym_virtual] = ACTIONS(2010),
    [anon_sym_extern] = ACTIONS(2010),
    [anon_sym___attribute__] = ACTIONS(2010),
    [anon_sym___attribute] = ACTIONS(2010),
    [anon_sym_COLON_COLON] = ACTIONS(2012),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2012),
    [anon_sym___declspec] = ACTIONS(2010),
    [anon_sym_LBRACE] = ACTIONS(2012),
    [anon_sym_signed] = ACTIONS(2010),
    [anon_sym_unsigned] = ACTIONS(2010),
    [anon_sym_long] = ACTIONS(2010),
    [anon_sym_short] = ACTIONS(2010),
    [anon_sym_LBRACK] = ACTIONS(2010),
    [anon_sym_static] = ACTIONS(2010),
    [anon_sym_register] = ACTIONS(2010),
    [anon_sym_inline] = ACTIONS(2010),
    [anon_sym___inline] = ACTIONS(2010),
    [anon_sym___inline__] = ACTIONS(2010),
    [anon_sym___forceinline] = ACTIONS(2010),
    [anon_sym_thread_local] = ACTIONS(2010),
    [anon_sym___thread] = ACTIONS(2010),
    [anon_sym_const] = ACTIONS(2010),
    [anon_sym_constexpr] = ACTIONS(2010),
    [anon_sym_volatile] = ACTIONS(2010),
    [anon_sym_restrict] = ACTIONS(2010),
    [anon_sym___restrict__] = ACTIONS(2010),
    [anon_sym__Atomic] = ACTIONS(2010),
    [anon_sym__Noreturn] = ACTIONS(2010),
    [anon_sym_noreturn] = ACTIONS(2010),
    [anon_sym__Nonnull] = ACTIONS(2010),
    [anon_sym_mutable] = ACTIONS(2010),
    [anon_sym_constinit] = ACTIONS(2010),
    [anon_sym_consteval] = ACTIONS(2010),
    [anon_sym___shared__] = ACTIONS(2010),
    [anon_sym___local__] = ACTIONS(2010),
    [anon_sym___constant__] = ACTIONS(2010),
    [anon_sym___managed__] = ACTIONS(2010),
    [anon_sym___grid_constant__] = ACTIONS(2010),
    [anon_sym_alignas] = ACTIONS(2010),
    [anon_sym__Alignas] = ACTIONS(2010),
    [sym_primitive_type] = ACTIONS(2010),
    [anon_sym_enum] = ACTIONS(2010),
    [anon_sym_class] = ACTIONS(2010),
    [anon_sym_struct] = ACTIONS(2010),
    [anon_sym_union] = ACTIONS(2010),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_else] = ACTIONS(4169),
    [anon_sym_switch] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2010),
    [anon_sym_do] = ACTIONS(2010),
    [anon_sym_for] = ACTIONS(2010),
    [anon_sym_return] = ACTIONS(2010),
    [anon_sym_break] = ACTIONS(2010),
    [anon_sym_continue] = ACTIONS(2010),
    [anon_sym_goto] = ACTIONS(2010),
    [anon_sym___try] = ACTIONS(2010),
    [anon_sym___leave] = ACTIONS(2010),
    [anon_sym_not] = ACTIONS(2010),
    [anon_sym_compl] = ACTIONS(2010),
    [anon_sym_DASH_DASH] = ACTIONS(2012),
    [anon_sym_PLUS_PLUS] = ACTIONS(2012),
    [anon_sym_sizeof] = ACTIONS(2010),
    [anon_sym___alignof__] = ACTIONS(2010),
    [anon_sym___alignof] = ACTIONS(2010),
    [anon_sym__alignof] = ACTIONS(2010),
    [anon_sym_alignof] = ACTIONS(2010),
    [anon_sym__Alignof] = ACTIONS(2010),
    [anon_sym_offsetof] = ACTIONS(2010),
    [anon_sym__Generic] = ACTIONS(2010),
    [anon_sym_asm] = ACTIONS(2010),
    [anon_sym___asm__] = ACTIONS(2010),
    [anon_sym___asm] = ACTIONS(2010),
    [sym_number_literal] = ACTIONS(2012),
    [anon_sym_L_SQUOTE] = ACTIONS(2012),
    [anon_sym_u_SQUOTE] = ACTIONS(2012),
    [anon_sym_U_SQUOTE] = ACTIONS(2012),
    [anon_sym_u8_SQUOTE] = ACTIONS(2012),
    [anon_sym_SQUOTE] = ACTIONS(2012),
    [anon_sym_L_DQUOTE] = ACTIONS(2012),
    [anon_sym_u_DQUOTE] = ACTIONS(2012),
    [anon_sym_U_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8_DQUOTE] = ACTIONS(2012),
    [anon_sym_DQUOTE] = ACTIONS(2012),
    [sym_true] = ACTIONS(2010),
    [sym_false] = ACTIONS(2010),
    [anon_sym_NULL] = ACTIONS(2010),
    [anon_sym_nullptr] = ACTIONS(2010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2010),
    [anon_sym_decltype] = ACTIONS(2010),
    [anon_sym_typename] = ACTIONS(2010),
    [anon_sym_template] = ACTIONS(2010),
    [anon_sym_try] = ACTIONS(2010),
    [anon_sym_delete] = ACTIONS(2010),
    [anon_sym_throw] = ACTIONS(2010),
    [anon_sym_co_return] = ACTIONS(2010),
    [anon_sym_co_yield] = ACTIONS(2010),
    [anon_sym_R_DQUOTE] = ACTIONS(2012),
    [anon_sym_LR_DQUOTE] = ACTIONS(2012),
    [anon_sym_uR_DQUOTE] = ACTIONS(2012),
    [anon_sym_UR_DQUOTE] = ACTIONS(2012),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2012),
    [anon_sym_co_await] = ACTIONS(2010),
    [anon_sym_new] = ACTIONS(2010),
    [anon_sym_requires] = ACTIONS(2010),
    [sym_this] = ACTIONS(2010),
    [anon_sym___launch_bounds__] = ACTIONS(2010),
  },
  [STATE(861)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5363),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4177),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4179),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(862)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5264),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4181),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4183),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(863)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5353),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4185),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4187),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(864)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [sym_expression] = STATE(5347),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4189),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(4075),
    [anon_sym___global__] = ACTIONS(4077),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(4105),
    [anon_sym_RBRACK] = ACTIONS(4191),
    [anon_sym_const] = ACTIONS(4077),
    [anon_sym_constexpr] = ACTIONS(4077),
    [anon_sym_volatile] = ACTIONS(4077),
    [anon_sym_restrict] = ACTIONS(4077),
    [anon_sym___restrict__] = ACTIONS(4077),
    [anon_sym__Atomic] = ACTIONS(4077),
    [anon_sym__Noreturn] = ACTIONS(4077),
    [anon_sym_noreturn] = ACTIONS(4077),
    [anon_sym__Nonnull] = ACTIONS(4077),
    [anon_sym_mutable] = ACTIONS(4077),
    [anon_sym_constinit] = ACTIONS(4077),
    [anon_sym_consteval] = ACTIONS(4077),
    [anon_sym___shared__] = ACTIONS(4077),
    [anon_sym___local__] = ACTIONS(4077),
    [anon_sym___constant__] = ACTIONS(4077),
    [anon_sym___managed__] = ACTIONS(4077),
    [anon_sym___grid_constant__] = ACTIONS(4077),
    [anon_sym_alignas] = ACTIONS(4083),
    [anon_sym__Alignas] = ACTIONS(4083),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(865)] = {
    [sym_identifier] = ACTIONS(3826),
    [anon_sym_LPAREN2] = ACTIONS(3828),
    [anon_sym_BANG] = ACTIONS(3828),
    [anon_sym_TILDE] = ACTIONS(3828),
    [anon_sym_DASH] = ACTIONS(3826),
    [anon_sym_PLUS] = ACTIONS(3826),
    [anon_sym_STAR] = ACTIONS(3828),
    [anon_sym_AMP] = ACTIONS(3828),
    [anon_sym_SEMI] = ACTIONS(3828),
    [anon_sym___extension__] = ACTIONS(3826),
    [anon_sym___device__] = ACTIONS(3826),
    [anon_sym___host__] = ACTIONS(3826),
    [anon_sym___global__] = ACTIONS(3826),
    [anon_sym___forceinline__] = ACTIONS(3826),
    [anon_sym___noinline__] = ACTIONS(3826),
    [anon_sym_virtual] = ACTIONS(3826),
    [anon_sym_extern] = ACTIONS(3826),
    [anon_sym___attribute__] = ACTIONS(3826),
    [anon_sym___attribute] = ACTIONS(3826),
    [anon_sym_COLON_COLON] = ACTIONS(3828),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3828),
    [anon_sym___declspec] = ACTIONS(3826),
    [anon_sym_LBRACE] = ACTIONS(3828),
    [anon_sym_signed] = ACTIONS(3826),
    [anon_sym_unsigned] = ACTIONS(3826),
    [anon_sym_long] = ACTIONS(3826),
    [anon_sym_short] = ACTIONS(3826),
    [anon_sym_LBRACK] = ACTIONS(3826),
    [anon_sym_static] = ACTIONS(3826),
    [anon_sym_register] = ACTIONS(3826),
    [anon_sym_inline] = ACTIONS(3826),
    [anon_sym___inline] = ACTIONS(3826),
    [anon_sym___inline__] = ACTIONS(3826),
    [anon_sym___forceinline] = ACTIONS(3826),
    [anon_sym_thread_local] = ACTIONS(3826),
    [anon_sym___thread] = ACTIONS(3826),
    [anon_sym_const] = ACTIONS(3826),
    [anon_sym_constexpr] = ACTIONS(3826),
    [anon_sym_volatile] = ACTIONS(3826),
    [anon_sym_restrict] = ACTIONS(3826),
    [anon_sym___restrict__] = ACTIONS(3826),
    [anon_sym__Atomic] = ACTIONS(3826),
    [anon_sym__Noreturn] = ACTIONS(3826),
    [anon_sym_noreturn] = ACTIONS(3826),
    [anon_sym__Nonnull] = ACTIONS(3826),
    [anon_sym_mutable] = ACTIONS(3826),
    [anon_sym_constinit] = ACTIONS(3826),
    [anon_sym_consteval] = ACTIONS(3826),
    [anon_sym___shared__] = ACTIONS(3826),
    [anon_sym___local__] = ACTIONS(3826),
    [anon_sym___constant__] = ACTIONS(3826),
    [anon_sym___managed__] = ACTIONS(3826),
    [anon_sym___grid_constant__] = ACTIONS(3826),
    [anon_sym_alignas] = ACTIONS(3826),
    [anon_sym__Alignas] = ACTIONS(3826),
    [sym_primitive_type] = ACTIONS(3826),
    [anon_sym_enum] = ACTIONS(3826),
    [anon_sym_class] = ACTIONS(3826),
    [anon_sym_struct] = ACTIONS(3826),
    [anon_sym_union] = ACTIONS(3826),
    [anon_sym_if] = ACTIONS(3826),
    [anon_sym_switch] = ACTIONS(3826),
    [anon_sym_case] = ACTIONS(3826),
    [anon_sym_default] = ACTIONS(3826),
    [anon_sym_while] = ACTIONS(3826),
    [anon_sym_do] = ACTIONS(3826),
    [anon_sym_for] = ACTIONS(3826),
    [anon_sym_return] = ACTIONS(3826),
    [anon_sym_break] = ACTIONS(3826),
    [anon_sym_continue] = ACTIONS(3826),
    [anon_sym_goto] = ACTIONS(3826),
    [anon_sym___try] = ACTIONS(3826),
    [anon_sym___leave] = ACTIONS(3826),
    [anon_sym_not] = ACTIONS(3826),
    [anon_sym_compl] = ACTIONS(3826),
    [anon_sym_DASH_DASH] = ACTIONS(3828),
    [anon_sym_PLUS_PLUS] = ACTIONS(3828),
    [anon_sym_sizeof] = ACTIONS(3826),
    [anon_sym___alignof__] = ACTIONS(3826),
    [anon_sym___alignof] = ACTIONS(3826),
    [anon_sym__alignof] = ACTIONS(3826),
    [anon_sym_alignof] = ACTIONS(3826),
    [anon_sym__Alignof] = ACTIONS(3826),
    [anon_sym_offsetof] = ACTIONS(3826),
    [anon_sym__Generic] = ACTIONS(3826),
    [anon_sym_asm] = ACTIONS(3826),
    [anon_sym___asm__] = ACTIONS(3826),
    [anon_sym___asm] = ACTIONS(3826),
    [sym_number_literal] = ACTIONS(3828),
    [anon_sym_L_SQUOTE] = ACTIONS(3828),
    [anon_sym_u_SQUOTE] = ACTIONS(3828),
    [anon_sym_U_SQUOTE] = ACTIONS(3828),
    [anon_sym_u8_SQUOTE] = ACTIONS(3828),
    [anon_sym_SQUOTE] = ACTIONS(3828),
    [anon_sym_L_DQUOTE] = ACTIONS(3828),
    [anon_sym_u_DQUOTE] = ACTIONS(3828),
    [anon_sym_U_DQUOTE] = ACTIONS(3828),
    [anon_sym_u8_DQUOTE] = ACTIONS(3828),
    [anon_sym_DQUOTE] = ACTIONS(3828),
    [sym_true] = ACTIONS(3826),
    [sym_false] = ACTIONS(3826),
    [anon_sym_NULL] = ACTIONS(3826),
    [anon_sym_nullptr] = ACTIONS(3826),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3826),
    [anon_sym_decltype] = ACTIONS(3826),
    [anon_sym_typename] = ACTIONS(3826),
    [anon_sym_template] = ACTIONS(3826),
    [anon_sym_try] = ACTIONS(3826),
    [anon_sym_delete] = ACTIONS(3826),
    [anon_sym_throw] = ACTIONS(3826),
    [anon_sym_co_return] = ACTIONS(3826),
    [anon_sym_co_yield] = ACTIONS(3826),
    [anon_sym_R_DQUOTE] = ACTIONS(3828),
    [anon_sym_LR_DQUOTE] = ACTIONS(3828),
    [anon_sym_uR_DQUOTE] = ACTIONS(3828),
    [anon_sym_UR_DQUOTE] = ACTIONS(3828),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3828),
    [anon_sym_co_await] = ACTIONS(3826),
    [anon_sym_new] = ACTIONS(3826),
    [anon_sym_requires] = ACTIONS(3826),
    [sym_this] = ACTIONS(3826),
    [anon_sym___launch_bounds__] = ACTIONS(3826),
  },
  [STATE(866)] = {
    [sym_identifier] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2168),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym___device__] = ACTIONS(2166),
    [anon_sym___host__] = ACTIONS(2166),
    [anon_sym___global__] = ACTIONS(2166),
    [anon_sym___forceinline__] = ACTIONS(2166),
    [anon_sym___noinline__] = ACTIONS(2166),
    [anon_sym_virtual] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym___attribute] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym__Nonnull] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym___shared__] = ACTIONS(2166),
    [anon_sym___local__] = ACTIONS(2166),
    [anon_sym___constant__] = ACTIONS(2166),
    [anon_sym___managed__] = ACTIONS(2166),
    [anon_sym___grid_constant__] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [anon_sym___asm] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym___launch_bounds__] = ACTIONS(2166),
  },
  [STATE(867)] = {
    [sym_identifier] = ACTIONS(2218),
    [anon_sym_LPAREN2] = ACTIONS(2220),
    [anon_sym_BANG] = ACTIONS(2220),
    [anon_sym_TILDE] = ACTIONS(2220),
    [anon_sym_DASH] = ACTIONS(2218),
    [anon_sym_PLUS] = ACTIONS(2218),
    [anon_sym_STAR] = ACTIONS(2220),
    [anon_sym_AMP] = ACTIONS(2220),
    [anon_sym_SEMI] = ACTIONS(2220),
    [anon_sym___extension__] = ACTIONS(2218),
    [anon_sym_typedef] = ACTIONS(2218),
    [anon_sym___device__] = ACTIONS(2218),
    [anon_sym___host__] = ACTIONS(2218),
    [anon_sym___global__] = ACTIONS(2218),
    [anon_sym___forceinline__] = ACTIONS(2218),
    [anon_sym___noinline__] = ACTIONS(2218),
    [anon_sym_virtual] = ACTIONS(2218),
    [anon_sym_extern] = ACTIONS(2218),
    [anon_sym___attribute__] = ACTIONS(2218),
    [anon_sym___attribute] = ACTIONS(2218),
    [anon_sym_COLON_COLON] = ACTIONS(2220),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2220),
    [anon_sym___declspec] = ACTIONS(2218),
    [anon_sym_LBRACE] = ACTIONS(2220),
    [anon_sym_signed] = ACTIONS(2218),
    [anon_sym_unsigned] = ACTIONS(2218),
    [anon_sym_long] = ACTIONS(2218),
    [anon_sym_short] = ACTIONS(2218),
    [anon_sym_LBRACK] = ACTIONS(2218),
    [anon_sym_static] = ACTIONS(2218),
    [anon_sym_register] = ACTIONS(2218),
    [anon_sym_inline] = ACTIONS(2218),
    [anon_sym___inline] = ACTIONS(2218),
    [anon_sym___inline__] = ACTIONS(2218),
    [anon_sym___forceinline] = ACTIONS(2218),
    [anon_sym_thread_local] = ACTIONS(2218),
    [anon_sym___thread] = ACTIONS(2218),
    [anon_sym_const] = ACTIONS(2218),
    [anon_sym_constexpr] = ACTIONS(2218),
    [anon_sym_volatile] = ACTIONS(2218),
    [anon_sym_restrict] = ACTIONS(2218),
    [anon_sym___restrict__] = ACTIONS(2218),
    [anon_sym__Atomic] = ACTIONS(2218),
    [anon_sym__Noreturn] = ACTIONS(2218),
    [anon_sym_noreturn] = ACTIONS(2218),
    [anon_sym__Nonnull] = ACTIONS(2218),
    [anon_sym_mutable] = ACTIONS(2218),
    [anon_sym_constinit] = ACTIONS(2218),
    [anon_sym_consteval] = ACTIONS(2218),
    [anon_sym___shared__] = ACTIONS(2218),
    [anon_sym___local__] = ACTIONS(2218),
    [anon_sym___constant__] = ACTIONS(2218),
    [anon_sym___managed__] = ACTIONS(2218),
    [anon_sym___grid_constant__] = ACTIONS(2218),
    [anon_sym_alignas] = ACTIONS(2218),
    [anon_sym__Alignas] = ACTIONS(2218),
    [sym_primitive_type] = ACTIONS(2218),
    [anon_sym_enum] = ACTIONS(2218),
    [anon_sym_class] = ACTIONS(2218),
    [anon_sym_struct] = ACTIONS(2218),
    [anon_sym_union] = ACTIONS(2218),
    [anon_sym_if] = ACTIONS(2218),
    [anon_sym_else] = ACTIONS(2218),
    [anon_sym_switch] = ACTIONS(2218),
    [anon_sym_while] = ACTIONS(2218),
    [anon_sym_do] = ACTIONS(2218),
    [anon_sym_for] = ACTIONS(2218),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_break] = ACTIONS(2218),
    [anon_sym_continue] = ACTIONS(2218),
    [anon_sym_goto] = ACTIONS(2218),
    [anon_sym___try] = ACTIONS(2218),
    [anon_sym___leave] = ACTIONS(2218),
    [anon_sym_not] = ACTIONS(2218),
    [anon_sym_compl] = ACTIONS(2218),
    [anon_sym_DASH_DASH] = ACTIONS(2220),
    [anon_sym_PLUS_PLUS] = ACTIONS(2220),
    [anon_sym_sizeof] = ACTIONS(2218),
    [anon_sym___alignof__] = ACTIONS(2218),
    [anon_sym___alignof] = ACTIONS(2218),
    [anon_sym__alignof] = ACTIONS(2218),
    [anon_sym_alignof] = ACTIONS(2218),
    [anon_sym__Alignof] = ACTIONS(2218),
    [anon_sym_offsetof] = ACTIONS(2218),
    [anon_sym__Generic] = ACTIONS(2218),
    [anon_sym_asm] = ACTIONS(2218),
    [anon_sym___asm__] = ACTIONS(2218),
    [anon_sym___asm] = ACTIONS(2218),
    [sym_number_literal] = ACTIONS(2220),
    [anon_sym_L_SQUOTE] = ACTIONS(2220),
    [anon_sym_u_SQUOTE] = ACTIONS(2220),
    [anon_sym_U_SQUOTE] = ACTIONS(2220),
    [anon_sym_u8_SQUOTE] = ACTIONS(2220),
    [anon_sym_SQUOTE] = ACTIONS(2220),
    [anon_sym_L_DQUOTE] = ACTIONS(2220),
    [anon_sym_u_DQUOTE] = ACTIONS(2220),
    [anon_sym_U_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8_DQUOTE] = ACTIONS(2220),
    [anon_sym_DQUOTE] = ACTIONS(2220),
    [sym_true] = ACTIONS(2218),
    [sym_false] = ACTIONS(2218),
    [anon_sym_NULL] = ACTIONS(2218),
    [anon_sym_nullptr] = ACTIONS(2218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2218),
    [anon_sym_decltype] = ACTIONS(2218),
    [anon_sym_typename] = ACTIONS(2218),
    [anon_sym_template] = ACTIONS(2218),
    [anon_sym_try] = ACTIONS(2218),
    [anon_sym_delete] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2218),
    [anon_sym_co_return] = ACTIONS(2218),
    [anon_sym_co_yield] = ACTIONS(2218),
    [anon_sym_R_DQUOTE] = ACTIONS(2220),
    [anon_sym_LR_DQUOTE] = ACTIONS(2220),
    [anon_sym_uR_DQUOTE] = ACTIONS(2220),
    [anon_sym_UR_DQUOTE] = ACTIONS(2220),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2220),
    [anon_sym_co_await] = ACTIONS(2218),
    [anon_sym_new] = ACTIONS(2218),
    [anon_sym_requires] = ACTIONS(2218),
    [sym_this] = ACTIONS(2218),
    [anon_sym___launch_bounds__] = ACTIONS(2218),
  },
  [STATE(868)] = {
    [sym_identifier] = ACTIONS(2044),
    [anon_sym_LPAREN2] = ACTIONS(2046),
    [anon_sym_BANG] = ACTIONS(2046),
    [anon_sym_TILDE] = ACTIONS(2046),
    [anon_sym_DASH] = ACTIONS(2044),
    [anon_sym_PLUS] = ACTIONS(2044),
    [anon_sym_STAR] = ACTIONS(2046),
    [anon_sym_AMP] = ACTIONS(2046),
    [anon_sym_SEMI] = ACTIONS(2046),
    [anon_sym___extension__] = ACTIONS(2044),
    [anon_sym_typedef] = ACTIONS(2044),
    [anon_sym___device__] = ACTIONS(2044),
    [anon_sym___host__] = ACTIONS(2044),
    [anon_sym___global__] = ACTIONS(2044),
    [anon_sym___forceinline__] = ACTIONS(2044),
    [anon_sym___noinline__] = ACTIONS(2044),
    [anon_sym_virtual] = ACTIONS(2044),
    [anon_sym_extern] = ACTIONS(2044),
    [anon_sym___attribute__] = ACTIONS(2044),
    [anon_sym___attribute] = ACTIONS(2044),
    [anon_sym_COLON_COLON] = ACTIONS(2046),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2046),
    [anon_sym___declspec] = ACTIONS(2044),
    [anon_sym_LBRACE] = ACTIONS(2046),
    [anon_sym_signed] = ACTIONS(2044),
    [anon_sym_unsigned] = ACTIONS(2044),
    [anon_sym_long] = ACTIONS(2044),
    [anon_sym_short] = ACTIONS(2044),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_static] = ACTIONS(2044),
    [anon_sym_register] = ACTIONS(2044),
    [anon_sym_inline] = ACTIONS(2044),
    [anon_sym___inline] = ACTIONS(2044),
    [anon_sym___inline__] = ACTIONS(2044),
    [anon_sym___forceinline] = ACTIONS(2044),
    [anon_sym_thread_local] = ACTIONS(2044),
    [anon_sym___thread] = ACTIONS(2044),
    [anon_sym_const] = ACTIONS(2044),
    [anon_sym_constexpr] = ACTIONS(2044),
    [anon_sym_volatile] = ACTIONS(2044),
    [anon_sym_restrict] = ACTIONS(2044),
    [anon_sym___restrict__] = ACTIONS(2044),
    [anon_sym__Atomic] = ACTIONS(2044),
    [anon_sym__Noreturn] = ACTIONS(2044),
    [anon_sym_noreturn] = ACTIONS(2044),
    [anon_sym__Nonnull] = ACTIONS(2044),
    [anon_sym_mutable] = ACTIONS(2044),
    [anon_sym_constinit] = ACTIONS(2044),
    [anon_sym_consteval] = ACTIONS(2044),
    [anon_sym___shared__] = ACTIONS(2044),
    [anon_sym___local__] = ACTIONS(2044),
    [anon_sym___constant__] = ACTIONS(2044),
    [anon_sym___managed__] = ACTIONS(2044),
    [anon_sym___grid_constant__] = ACTIONS(2044),
    [anon_sym_alignas] = ACTIONS(2044),
    [anon_sym__Alignas] = ACTIONS(2044),
    [sym_primitive_type] = ACTIONS(2044),
    [anon_sym_enum] = ACTIONS(2044),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2044),
    [anon_sym_union] = ACTIONS(2044),
    [anon_sym_if] = ACTIONS(2044),
    [anon_sym_else] = ACTIONS(2044),
    [anon_sym_switch] = ACTIONS(2044),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_do] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2044),
    [anon_sym_return] = ACTIONS(2044),
    [anon_sym_break] = ACTIONS(2044),
    [anon_sym_continue] = ACTIONS(2044),
    [anon_sym_goto] = ACTIONS(2044),
    [anon_sym___try] = ACTIONS(2044),
    [anon_sym___leave] = ACTIONS(2044),
    [anon_sym_not] = ACTIONS(2044),
    [anon_sym_compl] = ACTIONS(2044),
    [anon_sym_DASH_DASH] = ACTIONS(2046),
    [anon_sym_PLUS_PLUS] = ACTIONS(2046),
    [anon_sym_sizeof] = ACTIONS(2044),
    [anon_sym___alignof__] = ACTIONS(2044),
    [anon_sym___alignof] = ACTIONS(2044),
    [anon_sym__alignof] = ACTIONS(2044),
    [anon_sym_alignof] = ACTIONS(2044),
    [anon_sym__Alignof] = ACTIONS(2044),
    [anon_sym_offsetof] = ACTIONS(2044),
    [anon_sym__Generic] = ACTIONS(2044),
    [anon_sym_asm] = ACTIONS(2044),
    [anon_sym___asm__] = ACTIONS(2044),
    [anon_sym___asm] = ACTIONS(2044),
    [sym_number_literal] = ACTIONS(2046),
    [anon_sym_L_SQUOTE] = ACTIONS(2046),
    [anon_sym_u_SQUOTE] = ACTIONS(2046),
    [anon_sym_U_SQUOTE] = ACTIONS(2046),
    [anon_sym_u8_SQUOTE] = ACTIONS(2046),
    [anon_sym_SQUOTE] = ACTIONS(2046),
    [anon_sym_L_DQUOTE] = ACTIONS(2046),
    [anon_sym_u_DQUOTE] = ACTIONS(2046),
    [anon_sym_U_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8_DQUOTE] = ACTIONS(2046),
    [anon_sym_DQUOTE] = ACTIONS(2046),
    [sym_true] = ACTIONS(2044),
    [sym_false] = ACTIONS(2044),
    [anon_sym_NULL] = ACTIONS(2044),
    [anon_sym_nullptr] = ACTIONS(2044),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2044),
    [anon_sym_decltype] = ACTIONS(2044),
    [anon_sym_typename] = ACTIONS(2044),
    [anon_sym_template] = ACTIONS(2044),
    [anon_sym_try] = ACTIONS(2044),
    [anon_sym_delete] = ACTIONS(2044),
    [anon_sym_throw] = ACTIONS(2044),
    [anon_sym_co_return] = ACTIONS(2044),
    [anon_sym_co_yield] = ACTIONS(2044),
    [anon_sym_R_DQUOTE] = ACTIONS(2046),
    [anon_sym_LR_DQUOTE] = ACTIONS(2046),
    [anon_sym_uR_DQUOTE] = ACTIONS(2046),
    [anon_sym_UR_DQUOTE] = ACTIONS(2046),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2046),
    [anon_sym_co_await] = ACTIONS(2044),
    [anon_sym_new] = ACTIONS(2044),
    [anon_sym_requires] = ACTIONS(2044),
    [sym_this] = ACTIONS(2044),
    [anon_sym___launch_bounds__] = ACTIONS(2044),
  },
  [STATE(869)] = {
    [sym_identifier] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2180),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(870)] = {
    [sym_identifier] = ACTIONS(2052),
    [anon_sym_LPAREN2] = ACTIONS(2054),
    [anon_sym_BANG] = ACTIONS(2054),
    [anon_sym_TILDE] = ACTIONS(2054),
    [anon_sym_DASH] = ACTIONS(2052),
    [anon_sym_PLUS] = ACTIONS(2052),
    [anon_sym_STAR] = ACTIONS(2054),
    [anon_sym_AMP] = ACTIONS(2054),
    [anon_sym_SEMI] = ACTIONS(2054),
    [anon_sym___extension__] = ACTIONS(2052),
    [anon_sym_typedef] = ACTIONS(2052),
    [anon_sym___device__] = ACTIONS(2052),
    [anon_sym___host__] = ACTIONS(2052),
    [anon_sym___global__] = ACTIONS(2052),
    [anon_sym___forceinline__] = ACTIONS(2052),
    [anon_sym___noinline__] = ACTIONS(2052),
    [anon_sym_virtual] = ACTIONS(2052),
    [anon_sym_extern] = ACTIONS(2052),
    [anon_sym___attribute__] = ACTIONS(2052),
    [anon_sym___attribute] = ACTIONS(2052),
    [anon_sym_COLON_COLON] = ACTIONS(2054),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2054),
    [anon_sym___declspec] = ACTIONS(2052),
    [anon_sym_LBRACE] = ACTIONS(2054),
    [anon_sym_signed] = ACTIONS(2052),
    [anon_sym_unsigned] = ACTIONS(2052),
    [anon_sym_long] = ACTIONS(2052),
    [anon_sym_short] = ACTIONS(2052),
    [anon_sym_LBRACK] = ACTIONS(2052),
    [anon_sym_static] = ACTIONS(2052),
    [anon_sym_register] = ACTIONS(2052),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym___inline] = ACTIONS(2052),
    [anon_sym___inline__] = ACTIONS(2052),
    [anon_sym___forceinline] = ACTIONS(2052),
    [anon_sym_thread_local] = ACTIONS(2052),
    [anon_sym___thread] = ACTIONS(2052),
    [anon_sym_const] = ACTIONS(2052),
    [anon_sym_constexpr] = ACTIONS(2052),
    [anon_sym_volatile] = ACTIONS(2052),
    [anon_sym_restrict] = ACTIONS(2052),
    [anon_sym___restrict__] = ACTIONS(2052),
    [anon_sym__Atomic] = ACTIONS(2052),
    [anon_sym__Noreturn] = ACTIONS(2052),
    [anon_sym_noreturn] = ACTIONS(2052),
    [anon_sym__Nonnull] = ACTIONS(2052),
    [anon_sym_mutable] = ACTIONS(2052),
    [anon_sym_constinit] = ACTIONS(2052),
    [anon_sym_consteval] = ACTIONS(2052),
    [anon_sym___shared__] = ACTIONS(2052),
    [anon_sym___local__] = ACTIONS(2052),
    [anon_sym___constant__] = ACTIONS(2052),
    [anon_sym___managed__] = ACTIONS(2052),
    [anon_sym___grid_constant__] = ACTIONS(2052),
    [anon_sym_alignas] = ACTIONS(2052),
    [anon_sym__Alignas] = ACTIONS(2052),
    [sym_primitive_type] = ACTIONS(2052),
    [anon_sym_enum] = ACTIONS(2052),
    [anon_sym_class] = ACTIONS(2052),
    [anon_sym_struct] = ACTIONS(2052),
    [anon_sym_union] = ACTIONS(2052),
    [anon_sym_if] = ACTIONS(2052),
    [anon_sym_else] = ACTIONS(2052),
    [anon_sym_switch] = ACTIONS(2052),
    [anon_sym_while] = ACTIONS(2052),
    [anon_sym_do] = ACTIONS(2052),
    [anon_sym_for] = ACTIONS(2052),
    [anon_sym_return] = ACTIONS(2052),
    [anon_sym_break] = ACTIONS(2052),
    [anon_sym_continue] = ACTIONS(2052),
    [anon_sym_goto] = ACTIONS(2052),
    [anon_sym___try] = ACTIONS(2052),
    [anon_sym___leave] = ACTIONS(2052),
    [anon_sym_not] = ACTIONS(2052),
    [anon_sym_compl] = ACTIONS(2052),
    [anon_sym_DASH_DASH] = ACTIONS(2054),
    [anon_sym_PLUS_PLUS] = ACTIONS(2054),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2052),
    [anon_sym___alignof] = ACTIONS(2052),
    [anon_sym__alignof] = ACTIONS(2052),
    [anon_sym_alignof] = ACTIONS(2052),
    [anon_sym__Alignof] = ACTIONS(2052),
    [anon_sym_offsetof] = ACTIONS(2052),
    [anon_sym__Generic] = ACTIONS(2052),
    [anon_sym_asm] = ACTIONS(2052),
    [anon_sym___asm__] = ACTIONS(2052),
    [anon_sym___asm] = ACTIONS(2052),
    [sym_number_literal] = ACTIONS(2054),
    [anon_sym_L_SQUOTE] = ACTIONS(2054),
    [anon_sym_u_SQUOTE] = ACTIONS(2054),
    [anon_sym_U_SQUOTE] = ACTIONS(2054),
    [anon_sym_u8_SQUOTE] = ACTIONS(2054),
    [anon_sym_SQUOTE] = ACTIONS(2054),
    [anon_sym_L_DQUOTE] = ACTIONS(2054),
    [anon_sym_u_DQUOTE] = ACTIONS(2054),
    [anon_sym_U_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8_DQUOTE] = ACTIONS(2054),
    [anon_sym_DQUOTE] = ACTIONS(2054),
    [sym_true] = ACTIONS(2052),
    [sym_false] = ACTIONS(2052),
    [anon_sym_NULL] = ACTIONS(2052),
    [anon_sym_nullptr] = ACTIONS(2052),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2052),
    [anon_sym_decltype] = ACTIONS(2052),
    [anon_sym_typename] = ACTIONS(2052),
    [anon_sym_template] = ACTIONS(2052),
    [anon_sym_try] = ACTIONS(2052),
    [anon_sym_delete] = ACTIONS(2052),
    [anon_sym_throw] = ACTIONS(2052),
    [anon_sym_co_return] = ACTIONS(2052),
    [anon_sym_co_yield] = ACTIONS(2052),
    [anon_sym_R_DQUOTE] = ACTIONS(2054),
    [anon_sym_LR_DQUOTE] = ACTIONS(2054),
    [anon_sym_uR_DQUOTE] = ACTIONS(2054),
    [anon_sym_UR_DQUOTE] = ACTIONS(2054),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2054),
    [anon_sym_co_await] = ACTIONS(2052),
    [anon_sym_new] = ACTIONS(2052),
    [anon_sym_requires] = ACTIONS(2052),
    [sym_this] = ACTIONS(2052),
    [anon_sym___launch_bounds__] = ACTIONS(2052),
  },
  [STATE(871)] = {
    [sym_identifier] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2180),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [anon_sym___asm] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(872)] = {
    [sym_identifier] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2156),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym___device__] = ACTIONS(2154),
    [anon_sym___host__] = ACTIONS(2154),
    [anon_sym___global__] = ACTIONS(2154),
    [anon_sym___forceinline__] = ACTIONS(2154),
    [anon_sym___noinline__] = ACTIONS(2154),
    [anon_sym_virtual] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym___attribute] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym__Nonnull] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym___shared__] = ACTIONS(2154),
    [anon_sym___local__] = ACTIONS(2154),
    [anon_sym___constant__] = ACTIONS(2154),
    [anon_sym___managed__] = ACTIONS(2154),
    [anon_sym___grid_constant__] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [anon_sym___asm] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym___launch_bounds__] = ACTIONS(2154),
  },
  [STATE(873)] = {
    [sym_identifier] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2160),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym___device__] = ACTIONS(2158),
    [anon_sym___host__] = ACTIONS(2158),
    [anon_sym___global__] = ACTIONS(2158),
    [anon_sym___forceinline__] = ACTIONS(2158),
    [anon_sym___noinline__] = ACTIONS(2158),
    [anon_sym_virtual] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym___attribute] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym__Nonnull] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym___shared__] = ACTIONS(2158),
    [anon_sym___local__] = ACTIONS(2158),
    [anon_sym___constant__] = ACTIONS(2158),
    [anon_sym___managed__] = ACTIONS(2158),
    [anon_sym___grid_constant__] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [anon_sym___asm] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym___launch_bounds__] = ACTIONS(2158),
  },
  [STATE(874)] = {
    [sym_identifier] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2164),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym___device__] = ACTIONS(2162),
    [anon_sym___host__] = ACTIONS(2162),
    [anon_sym___global__] = ACTIONS(2162),
    [anon_sym___forceinline__] = ACTIONS(2162),
    [anon_sym___noinline__] = ACTIONS(2162),
    [anon_sym_virtual] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym___attribute] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym__Nonnull] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym___shared__] = ACTIONS(2162),
    [anon_sym___local__] = ACTIONS(2162),
    [anon_sym___constant__] = ACTIONS(2162),
    [anon_sym___managed__] = ACTIONS(2162),
    [anon_sym___grid_constant__] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [anon_sym___asm] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym___launch_bounds__] = ACTIONS(2162),
  },
  [STATE(875)] = {
    [sym_identifier] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2188),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym___device__] = ACTIONS(2186),
    [anon_sym___host__] = ACTIONS(2186),
    [anon_sym___global__] = ACTIONS(2186),
    [anon_sym___forceinline__] = ACTIONS(2186),
    [anon_sym___noinline__] = ACTIONS(2186),
    [anon_sym_virtual] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym___attribute] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym__Nonnull] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym___shared__] = ACTIONS(2186),
    [anon_sym___local__] = ACTIONS(2186),
    [anon_sym___constant__] = ACTIONS(2186),
    [anon_sym___managed__] = ACTIONS(2186),
    [anon_sym___grid_constant__] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [anon_sym___asm] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym___launch_bounds__] = ACTIONS(2186),
  },
  [STATE(876)] = {
    [sym_identifier] = ACTIONS(4042),
    [anon_sym_LPAREN2] = ACTIONS(4048),
    [anon_sym_BANG] = ACTIONS(4048),
    [anon_sym_TILDE] = ACTIONS(4048),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4048),
    [anon_sym_AMP] = ACTIONS(4048),
    [anon_sym_SEMI] = ACTIONS(4048),
    [anon_sym___extension__] = ACTIONS(4042),
    [anon_sym___device__] = ACTIONS(4054),
    [anon_sym___host__] = ACTIONS(4054),
    [anon_sym___global__] = ACTIONS(4054),
    [anon_sym___forceinline__] = ACTIONS(4054),
    [anon_sym___noinline__] = ACTIONS(4054),
    [anon_sym_virtual] = ACTIONS(4054),
    [anon_sym_extern] = ACTIONS(4054),
    [anon_sym___attribute__] = ACTIONS(4054),
    [anon_sym___attribute] = ACTIONS(4054),
    [anon_sym_COLON_COLON] = ACTIONS(4045),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4045),
    [anon_sym___declspec] = ACTIONS(4054),
    [anon_sym_LBRACE] = ACTIONS(4048),
    [anon_sym_signed] = ACTIONS(4054),
    [anon_sym_unsigned] = ACTIONS(4054),
    [anon_sym_long] = ACTIONS(4054),
    [anon_sym_short] = ACTIONS(4054),
    [anon_sym_LBRACK] = ACTIONS(4050),
    [anon_sym_static] = ACTIONS(4054),
    [anon_sym_register] = ACTIONS(4054),
    [anon_sym_inline] = ACTIONS(4054),
    [anon_sym___inline] = ACTIONS(4054),
    [anon_sym___inline__] = ACTIONS(4054),
    [anon_sym___forceinline] = ACTIONS(4054),
    [anon_sym_thread_local] = ACTIONS(4054),
    [anon_sym___thread] = ACTIONS(4054),
    [anon_sym_const] = ACTIONS(4054),
    [anon_sym_constexpr] = ACTIONS(4054),
    [anon_sym_volatile] = ACTIONS(4054),
    [anon_sym_restrict] = ACTIONS(4054),
    [anon_sym___restrict__] = ACTIONS(4054),
    [anon_sym__Atomic] = ACTIONS(4054),
    [anon_sym__Noreturn] = ACTIONS(4054),
    [anon_sym_noreturn] = ACTIONS(4054),
    [anon_sym__Nonnull] = ACTIONS(4054),
    [anon_sym_mutable] = ACTIONS(4054),
    [anon_sym_constinit] = ACTIONS(4054),
    [anon_sym_consteval] = ACTIONS(4054),
    [anon_sym___shared__] = ACTIONS(4054),
    [anon_sym___local__] = ACTIONS(4054),
    [anon_sym___constant__] = ACTIONS(4054),
    [anon_sym___managed__] = ACTIONS(4054),
    [anon_sym___grid_constant__] = ACTIONS(4054),
    [anon_sym_alignas] = ACTIONS(4054),
    [anon_sym__Alignas] = ACTIONS(4054),
    [sym_primitive_type] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4054),
    [anon_sym_class] = ACTIONS(4054),
    [anon_sym_struct] = ACTIONS(4054),
    [anon_sym_union] = ACTIONS(4054),
    [anon_sym_if] = ACTIONS(4050),
    [anon_sym_switch] = ACTIONS(4050),
    [anon_sym_case] = ACTIONS(4050),
    [anon_sym_default] = ACTIONS(4050),
    [anon_sym_while] = ACTIONS(4050),
    [anon_sym_do] = ACTIONS(4050),
    [anon_sym_for] = ACTIONS(4050),
    [anon_sym_return] = ACTIONS(4050),
    [anon_sym_break] = ACTIONS(4050),
    [anon_sym_continue] = ACTIONS(4050),
    [anon_sym_goto] = ACTIONS(4050),
    [anon_sym___try] = ACTIONS(4050),
    [anon_sym___leave] = ACTIONS(4050),
    [anon_sym_not] = ACTIONS(4050),
    [anon_sym_compl] = ACTIONS(4050),
    [anon_sym_DASH_DASH] = ACTIONS(4048),
    [anon_sym_PLUS_PLUS] = ACTIONS(4048),
    [anon_sym_sizeof] = ACTIONS(4050),
    [anon_sym___alignof__] = ACTIONS(4050),
    [anon_sym___alignof] = ACTIONS(4050),
    [anon_sym__alignof] = ACTIONS(4050),
    [anon_sym_alignof] = ACTIONS(4050),
    [anon_sym__Alignof] = ACTIONS(4050),
    [anon_sym_offsetof] = ACTIONS(4050),
    [anon_sym__Generic] = ACTIONS(4050),
    [anon_sym_asm] = ACTIONS(4050),
    [anon_sym___asm__] = ACTIONS(4050),
    [anon_sym___asm] = ACTIONS(4050),
    [sym_number_literal] = ACTIONS(4048),
    [anon_sym_L_SQUOTE] = ACTIONS(4048),
    [anon_sym_u_SQUOTE] = ACTIONS(4048),
    [anon_sym_U_SQUOTE] = ACTIONS(4048),
    [anon_sym_u8_SQUOTE] = ACTIONS(4048),
    [anon_sym_SQUOTE] = ACTIONS(4048),
    [anon_sym_L_DQUOTE] = ACTIONS(4048),
    [anon_sym_u_DQUOTE] = ACTIONS(4048),
    [anon_sym_U_DQUOTE] = ACTIONS(4048),
    [anon_sym_u8_DQUOTE] = ACTIONS(4048),
    [anon_sym_DQUOTE] = ACTIONS(4048),
    [sym_true] = ACTIONS(4050),
    [sym_false] = ACTIONS(4050),
    [anon_sym_NULL] = ACTIONS(4050),
    [anon_sym_nullptr] = ACTIONS(4050),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4054),
    [anon_sym_decltype] = ACTIONS(4042),
    [anon_sym_typename] = ACTIONS(4054),
    [anon_sym_template] = ACTIONS(4042),
    [anon_sym_try] = ACTIONS(4050),
    [anon_sym_delete] = ACTIONS(4050),
    [anon_sym_throw] = ACTIONS(4050),
    [anon_sym_co_return] = ACTIONS(4050),
    [anon_sym_co_yield] = ACTIONS(4050),
    [anon_sym_R_DQUOTE] = ACTIONS(4048),
    [anon_sym_LR_DQUOTE] = ACTIONS(4048),
    [anon_sym_uR_DQUOTE] = ACTIONS(4048),
    [anon_sym_UR_DQUOTE] = ACTIONS(4048),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4048),
    [anon_sym_co_await] = ACTIONS(4050),
    [anon_sym_new] = ACTIONS(4050),
    [anon_sym_requires] = ACTIONS(4050),
    [sym_this] = ACTIONS(4050),
    [anon_sym___launch_bounds__] = ACTIONS(4054),
  },
  [STATE(877)] = {
    [sym_identifier] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2192),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym___device__] = ACTIONS(2190),
    [anon_sym___host__] = ACTIONS(2190),
    [anon_sym___global__] = ACTIONS(2190),
    [anon_sym___forceinline__] = ACTIONS(2190),
    [anon_sym___noinline__] = ACTIONS(2190),
    [anon_sym_virtual] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym___attribute] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym__Nonnull] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym___shared__] = ACTIONS(2190),
    [anon_sym___local__] = ACTIONS(2190),
    [anon_sym___constant__] = ACTIONS(2190),
    [anon_sym___managed__] = ACTIONS(2190),
    [anon_sym___grid_constant__] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [anon_sym___asm] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym___launch_bounds__] = ACTIONS(2190),
  },
  [STATE(878)] = {
    [sym_identifier] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2184),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(879)] = {
    [sym_identifier] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2184),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [anon_sym___asm] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(880)] = {
    [sym_identifier] = ACTIONS(2214),
    [anon_sym_LPAREN2] = ACTIONS(2216),
    [anon_sym_BANG] = ACTIONS(2216),
    [anon_sym_TILDE] = ACTIONS(2216),
    [anon_sym_DASH] = ACTIONS(2214),
    [anon_sym_PLUS] = ACTIONS(2214),
    [anon_sym_STAR] = ACTIONS(2216),
    [anon_sym_AMP] = ACTIONS(2216),
    [anon_sym_SEMI] = ACTIONS(2216),
    [anon_sym___extension__] = ACTIONS(2214),
    [anon_sym_typedef] = ACTIONS(2214),
    [anon_sym___device__] = ACTIONS(2214),
    [anon_sym___host__] = ACTIONS(2214),
    [anon_sym___global__] = ACTIONS(2214),
    [anon_sym___forceinline__] = ACTIONS(2214),
    [anon_sym___noinline__] = ACTIONS(2214),
    [anon_sym_virtual] = ACTIONS(2214),
    [anon_sym_extern] = ACTIONS(2214),
    [anon_sym___attribute__] = ACTIONS(2214),
    [anon_sym___attribute] = ACTIONS(2214),
    [anon_sym_COLON_COLON] = ACTIONS(2216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2216),
    [anon_sym___declspec] = ACTIONS(2214),
    [anon_sym_LBRACE] = ACTIONS(2216),
    [anon_sym_signed] = ACTIONS(2214),
    [anon_sym_unsigned] = ACTIONS(2214),
    [anon_sym_long] = ACTIONS(2214),
    [anon_sym_short] = ACTIONS(2214),
    [anon_sym_LBRACK] = ACTIONS(2214),
    [anon_sym_static] = ACTIONS(2214),
    [anon_sym_register] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(2214),
    [anon_sym___inline] = ACTIONS(2214),
    [anon_sym___inline__] = ACTIONS(2214),
    [anon_sym___forceinline] = ACTIONS(2214),
    [anon_sym_thread_local] = ACTIONS(2214),
    [anon_sym___thread] = ACTIONS(2214),
    [anon_sym_const] = ACTIONS(2214),
    [anon_sym_constexpr] = ACTIONS(2214),
    [anon_sym_volatile] = ACTIONS(2214),
    [anon_sym_restrict] = ACTIONS(2214),
    [anon_sym___restrict__] = ACTIONS(2214),
    [anon_sym__Atomic] = ACTIONS(2214),
    [anon_sym__Noreturn] = ACTIONS(2214),
    [anon_sym_noreturn] = ACTIONS(2214),
    [anon_sym__Nonnull] = ACTIONS(2214),
    [anon_sym_mutable] = ACTIONS(2214),
    [anon_sym_constinit] = ACTIONS(2214),
    [anon_sym_consteval] = ACTIONS(2214),
    [anon_sym___shared__] = ACTIONS(2214),
    [anon_sym___local__] = ACTIONS(2214),
    [anon_sym___constant__] = ACTIONS(2214),
    [anon_sym___managed__] = ACTIONS(2214),
    [anon_sym___grid_constant__] = ACTIONS(2214),
    [anon_sym_alignas] = ACTIONS(2214),
    [anon_sym__Alignas] = ACTIONS(2214),
    [sym_primitive_type] = ACTIONS(2214),
    [anon_sym_enum] = ACTIONS(2214),
    [anon_sym_class] = ACTIONS(2214),
    [anon_sym_struct] = ACTIONS(2214),
    [anon_sym_union] = ACTIONS(2214),
    [anon_sym_if] = ACTIONS(2214),
    [anon_sym_else] = ACTIONS(2214),
    [anon_sym_switch] = ACTIONS(2214),
    [anon_sym_while] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2214),
    [anon_sym_for] = ACTIONS(2214),
    [anon_sym_return] = ACTIONS(2214),
    [anon_sym_break] = ACTIONS(2214),
    [anon_sym_continue] = ACTIONS(2214),
    [anon_sym_goto] = ACTIONS(2214),
    [anon_sym___try] = ACTIONS(2214),
    [anon_sym___leave] = ACTIONS(2214),
    [anon_sym_not] = ACTIONS(2214),
    [anon_sym_compl] = ACTIONS(2214),
    [anon_sym_DASH_DASH] = ACTIONS(2216),
    [anon_sym_PLUS_PLUS] = ACTIONS(2216),
    [anon_sym_sizeof] = ACTIONS(2214),
    [anon_sym___alignof__] = ACTIONS(2214),
    [anon_sym___alignof] = ACTIONS(2214),
    [anon_sym__alignof] = ACTIONS(2214),
    [anon_sym_alignof] = ACTIONS(2214),
    [anon_sym__Alignof] = ACTIONS(2214),
    [anon_sym_offsetof] = ACTIONS(2214),
    [anon_sym__Generic] = ACTIONS(2214),
    [anon_sym_asm] = ACTIONS(2214),
    [anon_sym___asm__] = ACTIONS(2214),
    [anon_sym___asm] = ACTIONS(2214),
    [sym_number_literal] = ACTIONS(2216),
    [anon_sym_L_SQUOTE] = ACTIONS(2216),
    [anon_sym_u_SQUOTE] = ACTIONS(2216),
    [anon_sym_U_SQUOTE] = ACTIONS(2216),
    [anon_sym_u8_SQUOTE] = ACTIONS(2216),
    [anon_sym_SQUOTE] = ACTIONS(2216),
    [anon_sym_L_DQUOTE] = ACTIONS(2216),
    [anon_sym_u_DQUOTE] = ACTIONS(2216),
    [anon_sym_U_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8_DQUOTE] = ACTIONS(2216),
    [anon_sym_DQUOTE] = ACTIONS(2216),
    [sym_true] = ACTIONS(2214),
    [sym_false] = ACTIONS(2214),
    [anon_sym_NULL] = ACTIONS(2214),
    [anon_sym_nullptr] = ACTIONS(2214),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2214),
    [anon_sym_decltype] = ACTIONS(2214),
    [anon_sym_typename] = ACTIONS(2214),
    [anon_sym_template] = ACTIONS(2214),
    [anon_sym_try] = ACTIONS(2214),
    [anon_sym_delete] = ACTIONS(2214),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_co_return] = ACTIONS(2214),
    [anon_sym_co_yield] = ACTIONS(2214),
    [anon_sym_R_DQUOTE] = ACTIONS(2216),
    [anon_sym_LR_DQUOTE] = ACTIONS(2216),
    [anon_sym_uR_DQUOTE] = ACTIONS(2216),
    [anon_sym_UR_DQUOTE] = ACTIONS(2216),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2216),
    [anon_sym_co_await] = ACTIONS(2214),
    [anon_sym_new] = ACTIONS(2214),
    [anon_sym_requires] = ACTIONS(2214),
    [sym_this] = ACTIONS(2214),
    [anon_sym___launch_bounds__] = ACTIONS(2214),
  },
  [STATE(881)] = {
    [sym_identifier] = ACTIONS(2028),
    [anon_sym_LPAREN2] = ACTIONS(2030),
    [anon_sym_BANG] = ACTIONS(2030),
    [anon_sym_TILDE] = ACTIONS(2030),
    [anon_sym_DASH] = ACTIONS(2028),
    [anon_sym_PLUS] = ACTIONS(2028),
    [anon_sym_STAR] = ACTIONS(2030),
    [anon_sym_AMP] = ACTIONS(2030),
    [anon_sym_SEMI] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(2028),
    [anon_sym_typedef] = ACTIONS(2028),
    [anon_sym___device__] = ACTIONS(2028),
    [anon_sym___host__] = ACTIONS(2028),
    [anon_sym___global__] = ACTIONS(2028),
    [anon_sym___forceinline__] = ACTIONS(2028),
    [anon_sym___noinline__] = ACTIONS(2028),
    [anon_sym_virtual] = ACTIONS(2028),
    [anon_sym_extern] = ACTIONS(2028),
    [anon_sym___attribute__] = ACTIONS(2028),
    [anon_sym___attribute] = ACTIONS(2028),
    [anon_sym_COLON_COLON] = ACTIONS(2030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2030),
    [anon_sym___declspec] = ACTIONS(2028),
    [anon_sym_LBRACE] = ACTIONS(2030),
    [anon_sym_signed] = ACTIONS(2028),
    [anon_sym_unsigned] = ACTIONS(2028),
    [anon_sym_long] = ACTIONS(2028),
    [anon_sym_short] = ACTIONS(2028),
    [anon_sym_LBRACK] = ACTIONS(2028),
    [anon_sym_static] = ACTIONS(2028),
    [anon_sym_register] = ACTIONS(2028),
    [anon_sym_inline] = ACTIONS(2028),
    [anon_sym___inline] = ACTIONS(2028),
    [anon_sym___inline__] = ACTIONS(2028),
    [anon_sym___forceinline] = ACTIONS(2028),
    [anon_sym_thread_local] = ACTIONS(2028),
    [anon_sym___thread] = ACTIONS(2028),
    [anon_sym_const] = ACTIONS(2028),
    [anon_sym_constexpr] = ACTIONS(2028),
    [anon_sym_volatile] = ACTIONS(2028),
    [anon_sym_restrict] = ACTIONS(2028),
    [anon_sym___restrict__] = ACTIONS(2028),
    [anon_sym__Atomic] = ACTIONS(2028),
    [anon_sym__Noreturn] = ACTIONS(2028),
    [anon_sym_noreturn] = ACTIONS(2028),
    [anon_sym__Nonnull] = ACTIONS(2028),
    [anon_sym_mutable] = ACTIONS(2028),
    [anon_sym_constinit] = ACTIONS(2028),
    [anon_sym_consteval] = ACTIONS(2028),
    [anon_sym___shared__] = ACTIONS(2028),
    [anon_sym___local__] = ACTIONS(2028),
    [anon_sym___constant__] = ACTIONS(2028),
    [anon_sym___managed__] = ACTIONS(2028),
    [anon_sym___grid_constant__] = ACTIONS(2028),
    [anon_sym_alignas] = ACTIONS(2028),
    [anon_sym__Alignas] = ACTIONS(2028),
    [sym_primitive_type] = ACTIONS(2028),
    [anon_sym_enum] = ACTIONS(2028),
    [anon_sym_class] = ACTIONS(2028),
    [anon_sym_struct] = ACTIONS(2028),
    [anon_sym_union] = ACTIONS(2028),
    [anon_sym_if] = ACTIONS(2028),
    [anon_sym_else] = ACTIONS(2028),
    [anon_sym_switch] = ACTIONS(2028),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_do] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2028),
    [anon_sym_return] = ACTIONS(2028),
    [anon_sym_break] = ACTIONS(2028),
    [anon_sym_continue] = ACTIONS(2028),
    [anon_sym_goto] = ACTIONS(2028),
    [anon_sym___try] = ACTIONS(2028),
    [anon_sym___leave] = ACTIONS(2028),
    [anon_sym_not] = ACTIONS(2028),
    [anon_sym_compl] = ACTIONS(2028),
    [anon_sym_DASH_DASH] = ACTIONS(2030),
    [anon_sym_PLUS_PLUS] = ACTIONS(2030),
    [anon_sym_sizeof] = ACTIONS(2028),
    [anon_sym___alignof__] = ACTIONS(2028),
    [anon_sym___alignof] = ACTIONS(2028),
    [anon_sym__alignof] = ACTIONS(2028),
    [anon_sym_alignof] = ACTIONS(2028),
    [anon_sym__Alignof] = ACTIONS(2028),
    [anon_sym_offsetof] = ACTIONS(2028),
    [anon_sym__Generic] = ACTIONS(2028),
    [anon_sym_asm] = ACTIONS(2028),
    [anon_sym___asm__] = ACTIONS(2028),
    [anon_sym___asm] = ACTIONS(2028),
    [sym_number_literal] = ACTIONS(2030),
    [anon_sym_L_SQUOTE] = ACTIONS(2030),
    [anon_sym_u_SQUOTE] = ACTIONS(2030),
    [anon_sym_U_SQUOTE] = ACTIONS(2030),
    [anon_sym_u8_SQUOTE] = ACTIONS(2030),
    [anon_sym_SQUOTE] = ACTIONS(2030),
    [anon_sym_L_DQUOTE] = ACTIONS(2030),
    [anon_sym_u_DQUOTE] = ACTIONS(2030),
    [anon_sym_U_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8_DQUOTE] = ACTIONS(2030),
    [anon_sym_DQUOTE] = ACTIONS(2030),
    [sym_true] = ACTIONS(2028),
    [sym_false] = ACTIONS(2028),
    [anon_sym_NULL] = ACTIONS(2028),
    [anon_sym_nullptr] = ACTIONS(2028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2028),
    [anon_sym_decltype] = ACTIONS(2028),
    [anon_sym_typename] = ACTIONS(2028),
    [anon_sym_template] = ACTIONS(2028),
    [anon_sym_try] = ACTIONS(2028),
    [anon_sym_delete] = ACTIONS(2028),
    [anon_sym_throw] = ACTIONS(2028),
    [anon_sym_co_return] = ACTIONS(2028),
    [anon_sym_co_yield] = ACTIONS(2028),
    [anon_sym_R_DQUOTE] = ACTIONS(2030),
    [anon_sym_LR_DQUOTE] = ACTIONS(2030),
    [anon_sym_uR_DQUOTE] = ACTIONS(2030),
    [anon_sym_UR_DQUOTE] = ACTIONS(2030),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2030),
    [anon_sym_co_await] = ACTIONS(2028),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_requires] = ACTIONS(2028),
    [sym_this] = ACTIONS(2028),
    [anon_sym___launch_bounds__] = ACTIONS(2028),
  },
  [STATE(882)] = {
    [sym_identifier] = ACTIONS(2062),
    [anon_sym_LPAREN2] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(2064),
    [anon_sym_TILDE] = ACTIONS(2064),
    [anon_sym_DASH] = ACTIONS(2062),
    [anon_sym_PLUS] = ACTIONS(2062),
    [anon_sym_STAR] = ACTIONS(2064),
    [anon_sym_AMP] = ACTIONS(2064),
    [anon_sym_SEMI] = ACTIONS(2064),
    [anon_sym___extension__] = ACTIONS(2062),
    [anon_sym_typedef] = ACTIONS(2062),
    [anon_sym___device__] = ACTIONS(2062),
    [anon_sym___host__] = ACTIONS(2062),
    [anon_sym___global__] = ACTIONS(2062),
    [anon_sym___forceinline__] = ACTIONS(2062),
    [anon_sym___noinline__] = ACTIONS(2062),
    [anon_sym_virtual] = ACTIONS(2062),
    [anon_sym_extern] = ACTIONS(2062),
    [anon_sym___attribute__] = ACTIONS(2062),
    [anon_sym___attribute] = ACTIONS(2062),
    [anon_sym_COLON_COLON] = ACTIONS(2064),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2064),
    [anon_sym___declspec] = ACTIONS(2062),
    [anon_sym_LBRACE] = ACTIONS(2064),
    [anon_sym_signed] = ACTIONS(2062),
    [anon_sym_unsigned] = ACTIONS(2062),
    [anon_sym_long] = ACTIONS(2062),
    [anon_sym_short] = ACTIONS(2062),
    [anon_sym_LBRACK] = ACTIONS(2062),
    [anon_sym_static] = ACTIONS(2062),
    [anon_sym_register] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym___inline] = ACTIONS(2062),
    [anon_sym___inline__] = ACTIONS(2062),
    [anon_sym___forceinline] = ACTIONS(2062),
    [anon_sym_thread_local] = ACTIONS(2062),
    [anon_sym___thread] = ACTIONS(2062),
    [anon_sym_const] = ACTIONS(2062),
    [anon_sym_constexpr] = ACTIONS(2062),
    [anon_sym_volatile] = ACTIONS(2062),
    [anon_sym_restrict] = ACTIONS(2062),
    [anon_sym___restrict__] = ACTIONS(2062),
    [anon_sym__Atomic] = ACTIONS(2062),
    [anon_sym__Noreturn] = ACTIONS(2062),
    [anon_sym_noreturn] = ACTIONS(2062),
    [anon_sym__Nonnull] = ACTIONS(2062),
    [anon_sym_mutable] = ACTIONS(2062),
    [anon_sym_constinit] = ACTIONS(2062),
    [anon_sym_consteval] = ACTIONS(2062),
    [anon_sym___shared__] = ACTIONS(2062),
    [anon_sym___local__] = ACTIONS(2062),
    [anon_sym___constant__] = ACTIONS(2062),
    [anon_sym___managed__] = ACTIONS(2062),
    [anon_sym___grid_constant__] = ACTIONS(2062),
    [anon_sym_alignas] = ACTIONS(2062),
    [anon_sym__Alignas] = ACTIONS(2062),
    [sym_primitive_type] = ACTIONS(2062),
    [anon_sym_enum] = ACTIONS(2062),
    [anon_sym_class] = ACTIONS(2062),
    [anon_sym_struct] = ACTIONS(2062),
    [anon_sym_union] = ACTIONS(2062),
    [anon_sym_if] = ACTIONS(2062),
    [anon_sym_else] = ACTIONS(2062),
    [anon_sym_switch] = ACTIONS(2062),
    [anon_sym_while] = ACTIONS(2062),
    [anon_sym_do] = ACTIONS(2062),
    [anon_sym_for] = ACTIONS(2062),
    [anon_sym_return] = ACTIONS(2062),
    [anon_sym_break] = ACTIONS(2062),
    [anon_sym_continue] = ACTIONS(2062),
    [anon_sym_goto] = ACTIONS(2062),
    [anon_sym___try] = ACTIONS(2062),
    [anon_sym___leave] = ACTIONS(2062),
    [anon_sym_not] = ACTIONS(2062),
    [anon_sym_compl] = ACTIONS(2062),
    [anon_sym_DASH_DASH] = ACTIONS(2064),
    [anon_sym_PLUS_PLUS] = ACTIONS(2064),
    [anon_sym_sizeof] = ACTIONS(2062),
    [anon_sym___alignof__] = ACTIONS(2062),
    [anon_sym___alignof] = ACTIONS(2062),
    [anon_sym__alignof] = ACTIONS(2062),
    [anon_sym_alignof] = ACTIONS(2062),
    [anon_sym__Alignof] = ACTIONS(2062),
    [anon_sym_offsetof] = ACTIONS(2062),
    [anon_sym__Generic] = ACTIONS(2062),
    [anon_sym_asm] = ACTIONS(2062),
    [anon_sym___asm__] = ACTIONS(2062),
    [anon_sym___asm] = ACTIONS(2062),
    [sym_number_literal] = ACTIONS(2064),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2064),
    [anon_sym_u_DQUOTE] = ACTIONS(2064),
    [anon_sym_U_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8_DQUOTE] = ACTIONS(2064),
    [anon_sym_DQUOTE] = ACTIONS(2064),
    [sym_true] = ACTIONS(2062),
    [sym_false] = ACTIONS(2062),
    [anon_sym_NULL] = ACTIONS(2062),
    [anon_sym_nullptr] = ACTIONS(2062),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2062),
    [anon_sym_decltype] = ACTIONS(2062),
    [anon_sym_typename] = ACTIONS(2062),
    [anon_sym_template] = ACTIONS(2062),
    [anon_sym_try] = ACTIONS(2062),
    [anon_sym_delete] = ACTIONS(2062),
    [anon_sym_throw] = ACTIONS(2062),
    [anon_sym_co_return] = ACTIONS(2062),
    [anon_sym_co_yield] = ACTIONS(2062),
    [anon_sym_R_DQUOTE] = ACTIONS(2064),
    [anon_sym_LR_DQUOTE] = ACTIONS(2064),
    [anon_sym_uR_DQUOTE] = ACTIONS(2064),
    [anon_sym_UR_DQUOTE] = ACTIONS(2064),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2064),
    [anon_sym_co_await] = ACTIONS(2062),
    [anon_sym_new] = ACTIONS(2062),
    [anon_sym_requires] = ACTIONS(2062),
    [sym_this] = ACTIONS(2062),
    [anon_sym___launch_bounds__] = ACTIONS(2062),
  },
  [STATE(883)] = {
    [sym_identifier] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2136),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym___device__] = ACTIONS(2134),
    [anon_sym___host__] = ACTIONS(2134),
    [anon_sym___global__] = ACTIONS(2134),
    [anon_sym___forceinline__] = ACTIONS(2134),
    [anon_sym___noinline__] = ACTIONS(2134),
    [anon_sym_virtual] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym___attribute] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym__Nonnull] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym___shared__] = ACTIONS(2134),
    [anon_sym___local__] = ACTIONS(2134),
    [anon_sym___constant__] = ACTIONS(2134),
    [anon_sym___managed__] = ACTIONS(2134),
    [anon_sym___grid_constant__] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [anon_sym___asm] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym___launch_bounds__] = ACTIONS(2134),
  },
  [STATE(884)] = {
    [sym_identifier] = ACTIONS(3830),
    [anon_sym_LPAREN2] = ACTIONS(3832),
    [anon_sym_BANG] = ACTIONS(3832),
    [anon_sym_TILDE] = ACTIONS(3832),
    [anon_sym_DASH] = ACTIONS(3830),
    [anon_sym_PLUS] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3832),
    [anon_sym___extension__] = ACTIONS(3830),
    [anon_sym___device__] = ACTIONS(3830),
    [anon_sym___host__] = ACTIONS(3830),
    [anon_sym___global__] = ACTIONS(3830),
    [anon_sym___forceinline__] = ACTIONS(3830),
    [anon_sym___noinline__] = ACTIONS(3830),
    [anon_sym_virtual] = ACTIONS(3830),
    [anon_sym_extern] = ACTIONS(3830),
    [anon_sym___attribute__] = ACTIONS(3830),
    [anon_sym___attribute] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(3832),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3832),
    [anon_sym___declspec] = ACTIONS(3830),
    [anon_sym_LBRACE] = ACTIONS(3832),
    [anon_sym_signed] = ACTIONS(3830),
    [anon_sym_unsigned] = ACTIONS(3830),
    [anon_sym_long] = ACTIONS(3830),
    [anon_sym_short] = ACTIONS(3830),
    [anon_sym_LBRACK] = ACTIONS(3830),
    [anon_sym_static] = ACTIONS(3830),
    [anon_sym_register] = ACTIONS(3830),
    [anon_sym_inline] = ACTIONS(3830),
    [anon_sym___inline] = ACTIONS(3830),
    [anon_sym___inline__] = ACTIONS(3830),
    [anon_sym___forceinline] = ACTIONS(3830),
    [anon_sym_thread_local] = ACTIONS(3830),
    [anon_sym___thread] = ACTIONS(3830),
    [anon_sym_const] = ACTIONS(3830),
    [anon_sym_constexpr] = ACTIONS(3830),
    [anon_sym_volatile] = ACTIONS(3830),
    [anon_sym_restrict] = ACTIONS(3830),
    [anon_sym___restrict__] = ACTIONS(3830),
    [anon_sym__Atomic] = ACTIONS(3830),
    [anon_sym__Noreturn] = ACTIONS(3830),
    [anon_sym_noreturn] = ACTIONS(3830),
    [anon_sym__Nonnull] = ACTIONS(3830),
    [anon_sym_mutable] = ACTIONS(3830),
    [anon_sym_constinit] = ACTIONS(3830),
    [anon_sym_consteval] = ACTIONS(3830),
    [anon_sym___shared__] = ACTIONS(3830),
    [anon_sym___local__] = ACTIONS(3830),
    [anon_sym___constant__] = ACTIONS(3830),
    [anon_sym___managed__] = ACTIONS(3830),
    [anon_sym___grid_constant__] = ACTIONS(3830),
    [anon_sym_alignas] = ACTIONS(3830),
    [anon_sym__Alignas] = ACTIONS(3830),
    [sym_primitive_type] = ACTIONS(3830),
    [anon_sym_enum] = ACTIONS(3830),
    [anon_sym_class] = ACTIONS(3830),
    [anon_sym_struct] = ACTIONS(3830),
    [anon_sym_union] = ACTIONS(3830),
    [anon_sym_if] = ACTIONS(3830),
    [anon_sym_switch] = ACTIONS(3830),
    [anon_sym_case] = ACTIONS(3830),
    [anon_sym_default] = ACTIONS(3830),
    [anon_sym_while] = ACTIONS(3830),
    [anon_sym_do] = ACTIONS(3830),
    [anon_sym_for] = ACTIONS(3830),
    [anon_sym_return] = ACTIONS(3830),
    [anon_sym_break] = ACTIONS(3830),
    [anon_sym_continue] = ACTIONS(3830),
    [anon_sym_goto] = ACTIONS(3830),
    [anon_sym___try] = ACTIONS(3830),
    [anon_sym___leave] = ACTIONS(3830),
    [anon_sym_not] = ACTIONS(3830),
    [anon_sym_compl] = ACTIONS(3830),
    [anon_sym_DASH_DASH] = ACTIONS(3832),
    [anon_sym_PLUS_PLUS] = ACTIONS(3832),
    [anon_sym_sizeof] = ACTIONS(3830),
    [anon_sym___alignof__] = ACTIONS(3830),
    [anon_sym___alignof] = ACTIONS(3830),
    [anon_sym__alignof] = ACTIONS(3830),
    [anon_sym_alignof] = ACTIONS(3830),
    [anon_sym__Alignof] = ACTIONS(3830),
    [anon_sym_offsetof] = ACTIONS(3830),
    [anon_sym__Generic] = ACTIONS(3830),
    [anon_sym_asm] = ACTIONS(3830),
    [anon_sym___asm__] = ACTIONS(3830),
    [anon_sym___asm] = ACTIONS(3830),
    [sym_number_literal] = ACTIONS(3832),
    [anon_sym_L_SQUOTE] = ACTIONS(3832),
    [anon_sym_u_SQUOTE] = ACTIONS(3832),
    [anon_sym_U_SQUOTE] = ACTIONS(3832),
    [anon_sym_u8_SQUOTE] = ACTIONS(3832),
    [anon_sym_SQUOTE] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(3832),
    [anon_sym_u_DQUOTE] = ACTIONS(3832),
    [anon_sym_U_DQUOTE] = ACTIONS(3832),
    [anon_sym_u8_DQUOTE] = ACTIONS(3832),
    [anon_sym_DQUOTE] = ACTIONS(3832),
    [sym_true] = ACTIONS(3830),
    [sym_false] = ACTIONS(3830),
    [anon_sym_NULL] = ACTIONS(3830),
    [anon_sym_nullptr] = ACTIONS(3830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3830),
    [anon_sym_decltype] = ACTIONS(3830),
    [anon_sym_typename] = ACTIONS(3830),
    [anon_sym_template] = ACTIONS(3830),
    [anon_sym_try] = ACTIONS(3830),
    [anon_sym_delete] = ACTIONS(3830),
    [anon_sym_throw] = ACTIONS(3830),
    [anon_sym_co_return] = ACTIONS(3830),
    [anon_sym_co_yield] = ACTIONS(3830),
    [anon_sym_R_DQUOTE] = ACTIONS(3832),
    [anon_sym_LR_DQUOTE] = ACTIONS(3832),
    [anon_sym_uR_DQUOTE] = ACTIONS(3832),
    [anon_sym_UR_DQUOTE] = ACTIONS(3832),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3832),
    [anon_sym_co_await] = ACTIONS(3830),
    [anon_sym_new] = ACTIONS(3830),
    [anon_sym_requires] = ACTIONS(3830),
    [sym_this] = ACTIONS(3830),
    [anon_sym___launch_bounds__] = ACTIONS(3830),
  },
  [STATE(885)] = {
    [sym_identifier] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2128),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym___device__] = ACTIONS(2126),
    [anon_sym___host__] = ACTIONS(2126),
    [anon_sym___global__] = ACTIONS(2126),
    [anon_sym___forceinline__] = ACTIONS(2126),
    [anon_sym___noinline__] = ACTIONS(2126),
    [anon_sym_virtual] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym___attribute] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym__Nonnull] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym___shared__] = ACTIONS(2126),
    [anon_sym___local__] = ACTIONS(2126),
    [anon_sym___constant__] = ACTIONS(2126),
    [anon_sym___managed__] = ACTIONS(2126),
    [anon_sym___grid_constant__] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [anon_sym___asm] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym___launch_bounds__] = ACTIONS(2126),
  },
  [STATE(886)] = {
    [sym_identifier] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2132),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym___device__] = ACTIONS(2130),
    [anon_sym___host__] = ACTIONS(2130),
    [anon_sym___global__] = ACTIONS(2130),
    [anon_sym___forceinline__] = ACTIONS(2130),
    [anon_sym___noinline__] = ACTIONS(2130),
    [anon_sym_virtual] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym___attribute] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym__Nonnull] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym___shared__] = ACTIONS(2130),
    [anon_sym___local__] = ACTIONS(2130),
    [anon_sym___constant__] = ACTIONS(2130),
    [anon_sym___managed__] = ACTIONS(2130),
    [anon_sym___grid_constant__] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [anon_sym___asm] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym___launch_bounds__] = ACTIONS(2130),
  },
  [STATE(887)] = {
    [sym_identifier] = ACTIONS(2222),
    [anon_sym_LPAREN2] = ACTIONS(2224),
    [anon_sym_BANG] = ACTIONS(2224),
    [anon_sym_TILDE] = ACTIONS(2224),
    [anon_sym_DASH] = ACTIONS(2222),
    [anon_sym_PLUS] = ACTIONS(2222),
    [anon_sym_STAR] = ACTIONS(2224),
    [anon_sym_AMP] = ACTIONS(2224),
    [anon_sym_SEMI] = ACTIONS(2224),
    [anon_sym___extension__] = ACTIONS(2222),
    [anon_sym_typedef] = ACTIONS(2222),
    [anon_sym___device__] = ACTIONS(2222),
    [anon_sym___host__] = ACTIONS(2222),
    [anon_sym___global__] = ACTIONS(2222),
    [anon_sym___forceinline__] = ACTIONS(2222),
    [anon_sym___noinline__] = ACTIONS(2222),
    [anon_sym_virtual] = ACTIONS(2222),
    [anon_sym_extern] = ACTIONS(2222),
    [anon_sym___attribute__] = ACTIONS(2222),
    [anon_sym___attribute] = ACTIONS(2222),
    [anon_sym_COLON_COLON] = ACTIONS(2224),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2224),
    [anon_sym___declspec] = ACTIONS(2222),
    [anon_sym_LBRACE] = ACTIONS(2224),
    [anon_sym_signed] = ACTIONS(2222),
    [anon_sym_unsigned] = ACTIONS(2222),
    [anon_sym_long] = ACTIONS(2222),
    [anon_sym_short] = ACTIONS(2222),
    [anon_sym_LBRACK] = ACTIONS(2222),
    [anon_sym_static] = ACTIONS(2222),
    [anon_sym_register] = ACTIONS(2222),
    [anon_sym_inline] = ACTIONS(2222),
    [anon_sym___inline] = ACTIONS(2222),
    [anon_sym___inline__] = ACTIONS(2222),
    [anon_sym___forceinline] = ACTIONS(2222),
    [anon_sym_thread_local] = ACTIONS(2222),
    [anon_sym___thread] = ACTIONS(2222),
    [anon_sym_const] = ACTIONS(2222),
    [anon_sym_constexpr] = ACTIONS(2222),
    [anon_sym_volatile] = ACTIONS(2222),
    [anon_sym_restrict] = ACTIONS(2222),
    [anon_sym___restrict__] = ACTIONS(2222),
    [anon_sym__Atomic] = ACTIONS(2222),
    [anon_sym__Noreturn] = ACTIONS(2222),
    [anon_sym_noreturn] = ACTIONS(2222),
    [anon_sym__Nonnull] = ACTIONS(2222),
    [anon_sym_mutable] = ACTIONS(2222),
    [anon_sym_constinit] = ACTIONS(2222),
    [anon_sym_consteval] = ACTIONS(2222),
    [anon_sym___shared__] = ACTIONS(2222),
    [anon_sym___local__] = ACTIONS(2222),
    [anon_sym___constant__] = ACTIONS(2222),
    [anon_sym___managed__] = ACTIONS(2222),
    [anon_sym___grid_constant__] = ACTIONS(2222),
    [anon_sym_alignas] = ACTIONS(2222),
    [anon_sym__Alignas] = ACTIONS(2222),
    [sym_primitive_type] = ACTIONS(2222),
    [anon_sym_enum] = ACTIONS(2222),
    [anon_sym_class] = ACTIONS(2222),
    [anon_sym_struct] = ACTIONS(2222),
    [anon_sym_union] = ACTIONS(2222),
    [anon_sym_if] = ACTIONS(2222),
    [anon_sym_else] = ACTIONS(2222),
    [anon_sym_switch] = ACTIONS(2222),
    [anon_sym_while] = ACTIONS(2222),
    [anon_sym_do] = ACTIONS(2222),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_return] = ACTIONS(2222),
    [anon_sym_break] = ACTIONS(2222),
    [anon_sym_continue] = ACTIONS(2222),
    [anon_sym_goto] = ACTIONS(2222),
    [anon_sym___try] = ACTIONS(2222),
    [anon_sym___leave] = ACTIONS(2222),
    [anon_sym_not] = ACTIONS(2222),
    [anon_sym_compl] = ACTIONS(2222),
    [anon_sym_DASH_DASH] = ACTIONS(2224),
    [anon_sym_PLUS_PLUS] = ACTIONS(2224),
    [anon_sym_sizeof] = ACTIONS(2222),
    [anon_sym___alignof__] = ACTIONS(2222),
    [anon_sym___alignof] = ACTIONS(2222),
    [anon_sym__alignof] = ACTIONS(2222),
    [anon_sym_alignof] = ACTIONS(2222),
    [anon_sym__Alignof] = ACTIONS(2222),
    [anon_sym_offsetof] = ACTIONS(2222),
    [anon_sym__Generic] = ACTIONS(2222),
    [anon_sym_asm] = ACTIONS(2222),
    [anon_sym___asm__] = ACTIONS(2222),
    [anon_sym___asm] = ACTIONS(2222),
    [sym_number_literal] = ACTIONS(2224),
    [anon_sym_L_SQUOTE] = ACTIONS(2224),
    [anon_sym_u_SQUOTE] = ACTIONS(2224),
    [anon_sym_U_SQUOTE] = ACTIONS(2224),
    [anon_sym_u8_SQUOTE] = ACTIONS(2224),
    [anon_sym_SQUOTE] = ACTIONS(2224),
    [anon_sym_L_DQUOTE] = ACTIONS(2224),
    [anon_sym_u_DQUOTE] = ACTIONS(2224),
    [anon_sym_U_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8_DQUOTE] = ACTIONS(2224),
    [anon_sym_DQUOTE] = ACTIONS(2224),
    [sym_true] = ACTIONS(2222),
    [sym_false] = ACTIONS(2222),
    [anon_sym_NULL] = ACTIONS(2222),
    [anon_sym_nullptr] = ACTIONS(2222),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2222),
    [anon_sym_decltype] = ACTIONS(2222),
    [anon_sym_typename] = ACTIONS(2222),
    [anon_sym_template] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2222),
    [anon_sym_delete] = ACTIONS(2222),
    [anon_sym_throw] = ACTIONS(2222),
    [anon_sym_co_return] = ACTIONS(2222),
    [anon_sym_co_yield] = ACTIONS(2222),
    [anon_sym_R_DQUOTE] = ACTIONS(2224),
    [anon_sym_LR_DQUOTE] = ACTIONS(2224),
    [anon_sym_uR_DQUOTE] = ACTIONS(2224),
    [anon_sym_UR_DQUOTE] = ACTIONS(2224),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2224),
    [anon_sym_co_await] = ACTIONS(2222),
    [anon_sym_new] = ACTIONS(2222),
    [anon_sym_requires] = ACTIONS(2222),
    [sym_this] = ACTIONS(2222),
    [anon_sym___launch_bounds__] = ACTIONS(2222),
  },
  [STATE(888)] = {
    [sym_identifier] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2140),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym___device__] = ACTIONS(2138),
    [anon_sym___host__] = ACTIONS(2138),
    [anon_sym___global__] = ACTIONS(2138),
    [anon_sym___forceinline__] = ACTIONS(2138),
    [anon_sym___noinline__] = ACTIONS(2138),
    [anon_sym_virtual] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym___attribute] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym__Nonnull] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym___shared__] = ACTIONS(2138),
    [anon_sym___local__] = ACTIONS(2138),
    [anon_sym___constant__] = ACTIONS(2138),
    [anon_sym___managed__] = ACTIONS(2138),
    [anon_sym___grid_constant__] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [anon_sym___asm] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym___launch_bounds__] = ACTIONS(2138),
  },
  [STATE(889)] = {
    [sym_identifier] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2144),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym___device__] = ACTIONS(2142),
    [anon_sym___host__] = ACTIONS(2142),
    [anon_sym___global__] = ACTIONS(2142),
    [anon_sym___forceinline__] = ACTIONS(2142),
    [anon_sym___noinline__] = ACTIONS(2142),
    [anon_sym_virtual] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym___attribute] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym__Nonnull] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym___shared__] = ACTIONS(2142),
    [anon_sym___local__] = ACTIONS(2142),
    [anon_sym___constant__] = ACTIONS(2142),
    [anon_sym___managed__] = ACTIONS(2142),
    [anon_sym___grid_constant__] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [anon_sym___asm] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym___launch_bounds__] = ACTIONS(2142),
  },
  [STATE(890)] = {
    [sym_identifier] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2148),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym___device__] = ACTIONS(2146),
    [anon_sym___host__] = ACTIONS(2146),
    [anon_sym___global__] = ACTIONS(2146),
    [anon_sym___forceinline__] = ACTIONS(2146),
    [anon_sym___noinline__] = ACTIONS(2146),
    [anon_sym_virtual] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym___attribute] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym__Nonnull] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym___shared__] = ACTIONS(2146),
    [anon_sym___local__] = ACTIONS(2146),
    [anon_sym___constant__] = ACTIONS(2146),
    [anon_sym___managed__] = ACTIONS(2146),
    [anon_sym___grid_constant__] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [anon_sym___asm] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym___launch_bounds__] = ACTIONS(2146),
  },
  [STATE(891)] = {
    [sym_identifier] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2152),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym___device__] = ACTIONS(2150),
    [anon_sym___host__] = ACTIONS(2150),
    [anon_sym___global__] = ACTIONS(2150),
    [anon_sym___forceinline__] = ACTIONS(2150),
    [anon_sym___noinline__] = ACTIONS(2150),
    [anon_sym_virtual] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym___attribute] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym__Nonnull] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym___shared__] = ACTIONS(2150),
    [anon_sym___local__] = ACTIONS(2150),
    [anon_sym___constant__] = ACTIONS(2150),
    [anon_sym___managed__] = ACTIONS(2150),
    [anon_sym___grid_constant__] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [anon_sym___asm] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym___launch_bounds__] = ACTIONS(2150),
  },
  [STATE(892)] = {
    [sym_identifier] = ACTIONS(2020),
    [anon_sym_LPAREN2] = ACTIONS(2022),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2020),
    [anon_sym_PLUS] = ACTIONS(2020),
    [anon_sym_STAR] = ACTIONS(2022),
    [anon_sym_AMP] = ACTIONS(2022),
    [anon_sym_SEMI] = ACTIONS(2022),
    [anon_sym___extension__] = ACTIONS(2020),
    [anon_sym_typedef] = ACTIONS(2020),
    [anon_sym___device__] = ACTIONS(2020),
    [anon_sym___host__] = ACTIONS(2020),
    [anon_sym___global__] = ACTIONS(2020),
    [anon_sym___forceinline__] = ACTIONS(2020),
    [anon_sym___noinline__] = ACTIONS(2020),
    [anon_sym_virtual] = ACTIONS(2020),
    [anon_sym_extern] = ACTIONS(2020),
    [anon_sym___attribute__] = ACTIONS(2020),
    [anon_sym___attribute] = ACTIONS(2020),
    [anon_sym_COLON_COLON] = ACTIONS(2022),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2022),
    [anon_sym___declspec] = ACTIONS(2020),
    [anon_sym_LBRACE] = ACTIONS(2022),
    [anon_sym_signed] = ACTIONS(2020),
    [anon_sym_unsigned] = ACTIONS(2020),
    [anon_sym_long] = ACTIONS(2020),
    [anon_sym_short] = ACTIONS(2020),
    [anon_sym_LBRACK] = ACTIONS(2020),
    [anon_sym_static] = ACTIONS(2020),
    [anon_sym_register] = ACTIONS(2020),
    [anon_sym_inline] = ACTIONS(2020),
    [anon_sym___inline] = ACTIONS(2020),
    [anon_sym___inline__] = ACTIONS(2020),
    [anon_sym___forceinline] = ACTIONS(2020),
    [anon_sym_thread_local] = ACTIONS(2020),
    [anon_sym___thread] = ACTIONS(2020),
    [anon_sym_const] = ACTIONS(2020),
    [anon_sym_constexpr] = ACTIONS(2020),
    [anon_sym_volatile] = ACTIONS(2020),
    [anon_sym_restrict] = ACTIONS(2020),
    [anon_sym___restrict__] = ACTIONS(2020),
    [anon_sym__Atomic] = ACTIONS(2020),
    [anon_sym__Noreturn] = ACTIONS(2020),
    [anon_sym_noreturn] = ACTIONS(2020),
    [anon_sym__Nonnull] = ACTIONS(2020),
    [anon_sym_mutable] = ACTIONS(2020),
    [anon_sym_constinit] = ACTIONS(2020),
    [anon_sym_consteval] = ACTIONS(2020),
    [anon_sym___shared__] = ACTIONS(2020),
    [anon_sym___local__] = ACTIONS(2020),
    [anon_sym___constant__] = ACTIONS(2020),
    [anon_sym___managed__] = ACTIONS(2020),
    [anon_sym___grid_constant__] = ACTIONS(2020),
    [anon_sym_alignas] = ACTIONS(2020),
    [anon_sym__Alignas] = ACTIONS(2020),
    [sym_primitive_type] = ACTIONS(2020),
    [anon_sym_enum] = ACTIONS(2020),
    [anon_sym_class] = ACTIONS(2020),
    [anon_sym_struct] = ACTIONS(2020),
    [anon_sym_union] = ACTIONS(2020),
    [anon_sym_if] = ACTIONS(2020),
    [anon_sym_else] = ACTIONS(2020),
    [anon_sym_switch] = ACTIONS(2020),
    [anon_sym_while] = ACTIONS(2020),
    [anon_sym_do] = ACTIONS(2020),
    [anon_sym_for] = ACTIONS(2020),
    [anon_sym_return] = ACTIONS(2020),
    [anon_sym_break] = ACTIONS(2020),
    [anon_sym_continue] = ACTIONS(2020),
    [anon_sym_goto] = ACTIONS(2020),
    [anon_sym___try] = ACTIONS(2020),
    [anon_sym___leave] = ACTIONS(2020),
    [anon_sym_not] = ACTIONS(2020),
    [anon_sym_compl] = ACTIONS(2020),
    [anon_sym_DASH_DASH] = ACTIONS(2022),
    [anon_sym_PLUS_PLUS] = ACTIONS(2022),
    [anon_sym_sizeof] = ACTIONS(2020),
    [anon_sym___alignof__] = ACTIONS(2020),
    [anon_sym___alignof] = ACTIONS(2020),
    [anon_sym__alignof] = ACTIONS(2020),
    [anon_sym_alignof] = ACTIONS(2020),
    [anon_sym__Alignof] = ACTIONS(2020),
    [anon_sym_offsetof] = ACTIONS(2020),
    [anon_sym__Generic] = ACTIONS(2020),
    [anon_sym_asm] = ACTIONS(2020),
    [anon_sym___asm__] = ACTIONS(2020),
    [anon_sym___asm] = ACTIONS(2020),
    [sym_number_literal] = ACTIONS(2022),
    [anon_sym_L_SQUOTE] = ACTIONS(2022),
    [anon_sym_u_SQUOTE] = ACTIONS(2022),
    [anon_sym_U_SQUOTE] = ACTIONS(2022),
    [anon_sym_u8_SQUOTE] = ACTIONS(2022),
    [anon_sym_SQUOTE] = ACTIONS(2022),
    [anon_sym_L_DQUOTE] = ACTIONS(2022),
    [anon_sym_u_DQUOTE] = ACTIONS(2022),
    [anon_sym_U_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8_DQUOTE] = ACTIONS(2022),
    [anon_sym_DQUOTE] = ACTIONS(2022),
    [sym_true] = ACTIONS(2020),
    [sym_false] = ACTIONS(2020),
    [anon_sym_NULL] = ACTIONS(2020),
    [anon_sym_nullptr] = ACTIONS(2020),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2020),
    [anon_sym_decltype] = ACTIONS(2020),
    [anon_sym_typename] = ACTIONS(2020),
    [anon_sym_template] = ACTIONS(2020),
    [anon_sym_try] = ACTIONS(2020),
    [anon_sym_delete] = ACTIONS(2020),
    [anon_sym_throw] = ACTIONS(2020),
    [anon_sym_co_return] = ACTIONS(2020),
    [anon_sym_co_yield] = ACTIONS(2020),
    [anon_sym_R_DQUOTE] = ACTIONS(2022),
    [anon_sym_LR_DQUOTE] = ACTIONS(2022),
    [anon_sym_uR_DQUOTE] = ACTIONS(2022),
    [anon_sym_UR_DQUOTE] = ACTIONS(2022),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2022),
    [anon_sym_co_await] = ACTIONS(2020),
    [anon_sym_new] = ACTIONS(2020),
    [anon_sym_requires] = ACTIONS(2020),
    [sym_this] = ACTIONS(2020),
    [anon_sym___launch_bounds__] = ACTIONS(2020),
  },
  [STATE(893)] = {
    [sym_identifier] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2096),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym___device__] = ACTIONS(2094),
    [anon_sym___host__] = ACTIONS(2094),
    [anon_sym___global__] = ACTIONS(2094),
    [anon_sym___forceinline__] = ACTIONS(2094),
    [anon_sym___noinline__] = ACTIONS(2094),
    [anon_sym_virtual] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym___attribute] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym__Nonnull] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym___shared__] = ACTIONS(2094),
    [anon_sym___local__] = ACTIONS(2094),
    [anon_sym___constant__] = ACTIONS(2094),
    [anon_sym___managed__] = ACTIONS(2094),
    [anon_sym___grid_constant__] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [anon_sym___asm] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym___launch_bounds__] = ACTIONS(2094),
  },
  [STATE(894)] = {
    [sym_identifier] = ACTIONS(2024),
    [anon_sym_LPAREN2] = ACTIONS(2026),
    [anon_sym_BANG] = ACTIONS(2026),
    [anon_sym_TILDE] = ACTIONS(2026),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_STAR] = ACTIONS(2026),
    [anon_sym_AMP] = ACTIONS(2026),
    [anon_sym_SEMI] = ACTIONS(2026),
    [anon_sym___extension__] = ACTIONS(2024),
    [anon_sym_typedef] = ACTIONS(2024),
    [anon_sym___device__] = ACTIONS(2024),
    [anon_sym___host__] = ACTIONS(2024),
    [anon_sym___global__] = ACTIONS(2024),
    [anon_sym___forceinline__] = ACTIONS(2024),
    [anon_sym___noinline__] = ACTIONS(2024),
    [anon_sym_virtual] = ACTIONS(2024),
    [anon_sym_extern] = ACTIONS(2024),
    [anon_sym___attribute__] = ACTIONS(2024),
    [anon_sym___attribute] = ACTIONS(2024),
    [anon_sym_COLON_COLON] = ACTIONS(2026),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2026),
    [anon_sym___declspec] = ACTIONS(2024),
    [anon_sym_LBRACE] = ACTIONS(2026),
    [anon_sym_signed] = ACTIONS(2024),
    [anon_sym_unsigned] = ACTIONS(2024),
    [anon_sym_long] = ACTIONS(2024),
    [anon_sym_short] = ACTIONS(2024),
    [anon_sym_LBRACK] = ACTIONS(2024),
    [anon_sym_static] = ACTIONS(2024),
    [anon_sym_register] = ACTIONS(2024),
    [anon_sym_inline] = ACTIONS(2024),
    [anon_sym___inline] = ACTIONS(2024),
    [anon_sym___inline__] = ACTIONS(2024),
    [anon_sym___forceinline] = ACTIONS(2024),
    [anon_sym_thread_local] = ACTIONS(2024),
    [anon_sym___thread] = ACTIONS(2024),
    [anon_sym_const] = ACTIONS(2024),
    [anon_sym_constexpr] = ACTIONS(2024),
    [anon_sym_volatile] = ACTIONS(2024),
    [anon_sym_restrict] = ACTIONS(2024),
    [anon_sym___restrict__] = ACTIONS(2024),
    [anon_sym__Atomic] = ACTIONS(2024),
    [anon_sym__Noreturn] = ACTIONS(2024),
    [anon_sym_noreturn] = ACTIONS(2024),
    [anon_sym__Nonnull] = ACTIONS(2024),
    [anon_sym_mutable] = ACTIONS(2024),
    [anon_sym_constinit] = ACTIONS(2024),
    [anon_sym_consteval] = ACTIONS(2024),
    [anon_sym___shared__] = ACTIONS(2024),
    [anon_sym___local__] = ACTIONS(2024),
    [anon_sym___constant__] = ACTIONS(2024),
    [anon_sym___managed__] = ACTIONS(2024),
    [anon_sym___grid_constant__] = ACTIONS(2024),
    [anon_sym_alignas] = ACTIONS(2024),
    [anon_sym__Alignas] = ACTIONS(2024),
    [sym_primitive_type] = ACTIONS(2024),
    [anon_sym_enum] = ACTIONS(2024),
    [anon_sym_class] = ACTIONS(2024),
    [anon_sym_struct] = ACTIONS(2024),
    [anon_sym_union] = ACTIONS(2024),
    [anon_sym_if] = ACTIONS(2024),
    [anon_sym_else] = ACTIONS(2024),
    [anon_sym_switch] = ACTIONS(2024),
    [anon_sym_while] = ACTIONS(2024),
    [anon_sym_do] = ACTIONS(2024),
    [anon_sym_for] = ACTIONS(2024),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_break] = ACTIONS(2024),
    [anon_sym_continue] = ACTIONS(2024),
    [anon_sym_goto] = ACTIONS(2024),
    [anon_sym___try] = ACTIONS(2024),
    [anon_sym___leave] = ACTIONS(2024),
    [anon_sym_not] = ACTIONS(2024),
    [anon_sym_compl] = ACTIONS(2024),
    [anon_sym_DASH_DASH] = ACTIONS(2026),
    [anon_sym_PLUS_PLUS] = ACTIONS(2026),
    [anon_sym_sizeof] = ACTIONS(2024),
    [anon_sym___alignof__] = ACTIONS(2024),
    [anon_sym___alignof] = ACTIONS(2024),
    [anon_sym__alignof] = ACTIONS(2024),
    [anon_sym_alignof] = ACTIONS(2024),
    [anon_sym__Alignof] = ACTIONS(2024),
    [anon_sym_offsetof] = ACTIONS(2024),
    [anon_sym__Generic] = ACTIONS(2024),
    [anon_sym_asm] = ACTIONS(2024),
    [anon_sym___asm__] = ACTIONS(2024),
    [anon_sym___asm] = ACTIONS(2024),
    [sym_number_literal] = ACTIONS(2026),
    [anon_sym_L_SQUOTE] = ACTIONS(2026),
    [anon_sym_u_SQUOTE] = ACTIONS(2026),
    [anon_sym_U_SQUOTE] = ACTIONS(2026),
    [anon_sym_u8_SQUOTE] = ACTIONS(2026),
    [anon_sym_SQUOTE] = ACTIONS(2026),
    [anon_sym_L_DQUOTE] = ACTIONS(2026),
    [anon_sym_u_DQUOTE] = ACTIONS(2026),
    [anon_sym_U_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8_DQUOTE] = ACTIONS(2026),
    [anon_sym_DQUOTE] = ACTIONS(2026),
    [sym_true] = ACTIONS(2024),
    [sym_false] = ACTIONS(2024),
    [anon_sym_NULL] = ACTIONS(2024),
    [anon_sym_nullptr] = ACTIONS(2024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2024),
    [anon_sym_decltype] = ACTIONS(2024),
    [anon_sym_typename] = ACTIONS(2024),
    [anon_sym_template] = ACTIONS(2024),
    [anon_sym_try] = ACTIONS(2024),
    [anon_sym_delete] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2024),
    [anon_sym_co_return] = ACTIONS(2024),
    [anon_sym_co_yield] = ACTIONS(2024),
    [anon_sym_R_DQUOTE] = ACTIONS(2026),
    [anon_sym_LR_DQUOTE] = ACTIONS(2026),
    [anon_sym_uR_DQUOTE] = ACTIONS(2026),
    [anon_sym_UR_DQUOTE] = ACTIONS(2026),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2026),
    [anon_sym_co_await] = ACTIONS(2024),
    [anon_sym_new] = ACTIONS(2024),
    [anon_sym_requires] = ACTIONS(2024),
    [sym_this] = ACTIONS(2024),
    [anon_sym___launch_bounds__] = ACTIONS(2024),
  },
  [STATE(895)] = {
    [sym_identifier] = ACTIONS(2048),
    [anon_sym_LPAREN2] = ACTIONS(2050),
    [anon_sym_BANG] = ACTIONS(2050),
    [anon_sym_TILDE] = ACTIONS(2050),
    [anon_sym_DASH] = ACTIONS(2048),
    [anon_sym_PLUS] = ACTIONS(2048),
    [anon_sym_STAR] = ACTIONS(2050),
    [anon_sym_AMP] = ACTIONS(2050),
    [anon_sym_SEMI] = ACTIONS(2050),
    [anon_sym___extension__] = ACTIONS(2048),
    [anon_sym_typedef] = ACTIONS(2048),
    [anon_sym___device__] = ACTIONS(2048),
    [anon_sym___host__] = ACTIONS(2048),
    [anon_sym___global__] = ACTIONS(2048),
    [anon_sym___forceinline__] = ACTIONS(2048),
    [anon_sym___noinline__] = ACTIONS(2048),
    [anon_sym_virtual] = ACTIONS(2048),
    [anon_sym_extern] = ACTIONS(2048),
    [anon_sym___attribute__] = ACTIONS(2048),
    [anon_sym___attribute] = ACTIONS(2048),
    [anon_sym_COLON_COLON] = ACTIONS(2050),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2050),
    [anon_sym___declspec] = ACTIONS(2048),
    [anon_sym_LBRACE] = ACTIONS(2050),
    [anon_sym_signed] = ACTIONS(2048),
    [anon_sym_unsigned] = ACTIONS(2048),
    [anon_sym_long] = ACTIONS(2048),
    [anon_sym_short] = ACTIONS(2048),
    [anon_sym_LBRACK] = ACTIONS(2048),
    [anon_sym_static] = ACTIONS(2048),
    [anon_sym_register] = ACTIONS(2048),
    [anon_sym_inline] = ACTIONS(2048),
    [anon_sym___inline] = ACTIONS(2048),
    [anon_sym___inline__] = ACTIONS(2048),
    [anon_sym___forceinline] = ACTIONS(2048),
    [anon_sym_thread_local] = ACTIONS(2048),
    [anon_sym___thread] = ACTIONS(2048),
    [anon_sym_const] = ACTIONS(2048),
    [anon_sym_constexpr] = ACTIONS(2048),
    [anon_sym_volatile] = ACTIONS(2048),
    [anon_sym_restrict] = ACTIONS(2048),
    [anon_sym___restrict__] = ACTIONS(2048),
    [anon_sym__Atomic] = ACTIONS(2048),
    [anon_sym__Noreturn] = ACTIONS(2048),
    [anon_sym_noreturn] = ACTIONS(2048),
    [anon_sym__Nonnull] = ACTIONS(2048),
    [anon_sym_mutable] = ACTIONS(2048),
    [anon_sym_constinit] = ACTIONS(2048),
    [anon_sym_consteval] = ACTIONS(2048),
    [anon_sym___shared__] = ACTIONS(2048),
    [anon_sym___local__] = ACTIONS(2048),
    [anon_sym___constant__] = ACTIONS(2048),
    [anon_sym___managed__] = ACTIONS(2048),
    [anon_sym___grid_constant__] = ACTIONS(2048),
    [anon_sym_alignas] = ACTIONS(2048),
    [anon_sym__Alignas] = ACTIONS(2048),
    [sym_primitive_type] = ACTIONS(2048),
    [anon_sym_enum] = ACTIONS(2048),
    [anon_sym_class] = ACTIONS(2048),
    [anon_sym_struct] = ACTIONS(2048),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_if] = ACTIONS(2048),
    [anon_sym_else] = ACTIONS(2048),
    [anon_sym_switch] = ACTIONS(2048),
    [anon_sym_while] = ACTIONS(2048),
    [anon_sym_do] = ACTIONS(2048),
    [anon_sym_for] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2048),
    [anon_sym_break] = ACTIONS(2048),
    [anon_sym_continue] = ACTIONS(2048),
    [anon_sym_goto] = ACTIONS(2048),
    [anon_sym___try] = ACTIONS(2048),
    [anon_sym___leave] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2048),
    [anon_sym_compl] = ACTIONS(2048),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2048),
    [anon_sym___alignof__] = ACTIONS(2048),
    [anon_sym___alignof] = ACTIONS(2048),
    [anon_sym__alignof] = ACTIONS(2048),
    [anon_sym_alignof] = ACTIONS(2048),
    [anon_sym__Alignof] = ACTIONS(2048),
    [anon_sym_offsetof] = ACTIONS(2048),
    [anon_sym__Generic] = ACTIONS(2048),
    [anon_sym_asm] = ACTIONS(2048),
    [anon_sym___asm__] = ACTIONS(2048),
    [anon_sym___asm] = ACTIONS(2048),
    [sym_number_literal] = ACTIONS(2050),
    [anon_sym_L_SQUOTE] = ACTIONS(2050),
    [anon_sym_u_SQUOTE] = ACTIONS(2050),
    [anon_sym_U_SQUOTE] = ACTIONS(2050),
    [anon_sym_u8_SQUOTE] = ACTIONS(2050),
    [anon_sym_SQUOTE] = ACTIONS(2050),
    [anon_sym_L_DQUOTE] = ACTIONS(2050),
    [anon_sym_u_DQUOTE] = ACTIONS(2050),
    [anon_sym_U_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8_DQUOTE] = ACTIONS(2050),
    [anon_sym_DQUOTE] = ACTIONS(2050),
    [sym_true] = ACTIONS(2048),
    [sym_false] = ACTIONS(2048),
    [anon_sym_NULL] = ACTIONS(2048),
    [anon_sym_nullptr] = ACTIONS(2048),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2048),
    [anon_sym_decltype] = ACTIONS(2048),
    [anon_sym_typename] = ACTIONS(2048),
    [anon_sym_template] = ACTIONS(2048),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_delete] = ACTIONS(2048),
    [anon_sym_throw] = ACTIONS(2048),
    [anon_sym_co_return] = ACTIONS(2048),
    [anon_sym_co_yield] = ACTIONS(2048),
    [anon_sym_R_DQUOTE] = ACTIONS(2050),
    [anon_sym_LR_DQUOTE] = ACTIONS(2050),
    [anon_sym_uR_DQUOTE] = ACTIONS(2050),
    [anon_sym_UR_DQUOTE] = ACTIONS(2050),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2050),
    [anon_sym_co_await] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(2048),
    [anon_sym_requires] = ACTIONS(2048),
    [sym_this] = ACTIONS(2048),
    [anon_sym___launch_bounds__] = ACTIONS(2048),
  },
  [STATE(896)] = {
    [sym_identifier] = ACTIONS(2056),
    [anon_sym_LPAREN2] = ACTIONS(2058),
    [anon_sym_BANG] = ACTIONS(2058),
    [anon_sym_TILDE] = ACTIONS(2058),
    [anon_sym_DASH] = ACTIONS(2056),
    [anon_sym_PLUS] = ACTIONS(2056),
    [anon_sym_STAR] = ACTIONS(2058),
    [anon_sym_AMP] = ACTIONS(2058),
    [anon_sym_SEMI] = ACTIONS(2058),
    [anon_sym___extension__] = ACTIONS(2056),
    [anon_sym_typedef] = ACTIONS(2056),
    [anon_sym___device__] = ACTIONS(2056),
    [anon_sym___host__] = ACTIONS(2056),
    [anon_sym___global__] = ACTIONS(2056),
    [anon_sym___forceinline__] = ACTIONS(2056),
    [anon_sym___noinline__] = ACTIONS(2056),
    [anon_sym_virtual] = ACTIONS(2056),
    [anon_sym_extern] = ACTIONS(2056),
    [anon_sym___attribute__] = ACTIONS(2056),
    [anon_sym___attribute] = ACTIONS(2056),
    [anon_sym_COLON_COLON] = ACTIONS(2058),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2058),
    [anon_sym___declspec] = ACTIONS(2056),
    [anon_sym_LBRACE] = ACTIONS(2058),
    [anon_sym_signed] = ACTIONS(2056),
    [anon_sym_unsigned] = ACTIONS(2056),
    [anon_sym_long] = ACTIONS(2056),
    [anon_sym_short] = ACTIONS(2056),
    [anon_sym_LBRACK] = ACTIONS(2056),
    [anon_sym_static] = ACTIONS(2056),
    [anon_sym_register] = ACTIONS(2056),
    [anon_sym_inline] = ACTIONS(2056),
    [anon_sym___inline] = ACTIONS(2056),
    [anon_sym___inline__] = ACTIONS(2056),
    [anon_sym___forceinline] = ACTIONS(2056),
    [anon_sym_thread_local] = ACTIONS(2056),
    [anon_sym___thread] = ACTIONS(2056),
    [anon_sym_const] = ACTIONS(2056),
    [anon_sym_constexpr] = ACTIONS(2056),
    [anon_sym_volatile] = ACTIONS(2056),
    [anon_sym_restrict] = ACTIONS(2056),
    [anon_sym___restrict__] = ACTIONS(2056),
    [anon_sym__Atomic] = ACTIONS(2056),
    [anon_sym__Noreturn] = ACTIONS(2056),
    [anon_sym_noreturn] = ACTIONS(2056),
    [anon_sym__Nonnull] = ACTIONS(2056),
    [anon_sym_mutable] = ACTIONS(2056),
    [anon_sym_constinit] = ACTIONS(2056),
    [anon_sym_consteval] = ACTIONS(2056),
    [anon_sym___shared__] = ACTIONS(2056),
    [anon_sym___local__] = ACTIONS(2056),
    [anon_sym___constant__] = ACTIONS(2056),
    [anon_sym___managed__] = ACTIONS(2056),
    [anon_sym___grid_constant__] = ACTIONS(2056),
    [anon_sym_alignas] = ACTIONS(2056),
    [anon_sym__Alignas] = ACTIONS(2056),
    [sym_primitive_type] = ACTIONS(2056),
    [anon_sym_enum] = ACTIONS(2056),
    [anon_sym_class] = ACTIONS(2056),
    [anon_sym_struct] = ACTIONS(2056),
    [anon_sym_union] = ACTIONS(2056),
    [anon_sym_if] = ACTIONS(2056),
    [anon_sym_else] = ACTIONS(2056),
    [anon_sym_switch] = ACTIONS(2056),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_do] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2056),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_break] = ACTIONS(2056),
    [anon_sym_continue] = ACTIONS(2056),
    [anon_sym_goto] = ACTIONS(2056),
    [anon_sym___try] = ACTIONS(2056),
    [anon_sym___leave] = ACTIONS(2056),
    [anon_sym_not] = ACTIONS(2056),
    [anon_sym_compl] = ACTIONS(2056),
    [anon_sym_DASH_DASH] = ACTIONS(2058),
    [anon_sym_PLUS_PLUS] = ACTIONS(2058),
    [anon_sym_sizeof] = ACTIONS(2056),
    [anon_sym___alignof__] = ACTIONS(2056),
    [anon_sym___alignof] = ACTIONS(2056),
    [anon_sym__alignof] = ACTIONS(2056),
    [anon_sym_alignof] = ACTIONS(2056),
    [anon_sym__Alignof] = ACTIONS(2056),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2056),
    [anon_sym_asm] = ACTIONS(2056),
    [anon_sym___asm__] = ACTIONS(2056),
    [anon_sym___asm] = ACTIONS(2056),
    [sym_number_literal] = ACTIONS(2058),
    [anon_sym_L_SQUOTE] = ACTIONS(2058),
    [anon_sym_u_SQUOTE] = ACTIONS(2058),
    [anon_sym_U_SQUOTE] = ACTIONS(2058),
    [anon_sym_u8_SQUOTE] = ACTIONS(2058),
    [anon_sym_SQUOTE] = ACTIONS(2058),
    [anon_sym_L_DQUOTE] = ACTIONS(2058),
    [anon_sym_u_DQUOTE] = ACTIONS(2058),
    [anon_sym_U_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8_DQUOTE] = ACTIONS(2058),
    [anon_sym_DQUOTE] = ACTIONS(2058),
    [sym_true] = ACTIONS(2056),
    [sym_false] = ACTIONS(2056),
    [anon_sym_NULL] = ACTIONS(2056),
    [anon_sym_nullptr] = ACTIONS(2056),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2056),
    [anon_sym_decltype] = ACTIONS(2056),
    [anon_sym_typename] = ACTIONS(2056),
    [anon_sym_template] = ACTIONS(2056),
    [anon_sym_try] = ACTIONS(2056),
    [anon_sym_delete] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2056),
    [anon_sym_co_return] = ACTIONS(2056),
    [anon_sym_co_yield] = ACTIONS(2056),
    [anon_sym_R_DQUOTE] = ACTIONS(2058),
    [anon_sym_LR_DQUOTE] = ACTIONS(2058),
    [anon_sym_uR_DQUOTE] = ACTIONS(2058),
    [anon_sym_UR_DQUOTE] = ACTIONS(2058),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2058),
    [anon_sym_co_await] = ACTIONS(2056),
    [anon_sym_new] = ACTIONS(2056),
    [anon_sym_requires] = ACTIONS(2056),
    [sym_this] = ACTIONS(2056),
    [anon_sym___launch_bounds__] = ACTIONS(2056),
  },
  [STATE(897)] = {
    [sym_identifier] = ACTIONS(2066),
    [anon_sym_LPAREN2] = ACTIONS(2068),
    [anon_sym_BANG] = ACTIONS(2068),
    [anon_sym_TILDE] = ACTIONS(2068),
    [anon_sym_DASH] = ACTIONS(2066),
    [anon_sym_PLUS] = ACTIONS(2066),
    [anon_sym_STAR] = ACTIONS(2068),
    [anon_sym_AMP] = ACTIONS(2068),
    [anon_sym_SEMI] = ACTIONS(2068),
    [anon_sym___extension__] = ACTIONS(2066),
    [anon_sym_typedef] = ACTIONS(2066),
    [anon_sym___device__] = ACTIONS(2066),
    [anon_sym___host__] = ACTIONS(2066),
    [anon_sym___global__] = ACTIONS(2066),
    [anon_sym___forceinline__] = ACTIONS(2066),
    [anon_sym___noinline__] = ACTIONS(2066),
    [anon_sym_virtual] = ACTIONS(2066),
    [anon_sym_extern] = ACTIONS(2066),
    [anon_sym___attribute__] = ACTIONS(2066),
    [anon_sym___attribute] = ACTIONS(2066),
    [anon_sym_COLON_COLON] = ACTIONS(2068),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2068),
    [anon_sym___declspec] = ACTIONS(2066),
    [anon_sym_LBRACE] = ACTIONS(2068),
    [anon_sym_signed] = ACTIONS(2066),
    [anon_sym_unsigned] = ACTIONS(2066),
    [anon_sym_long] = ACTIONS(2066),
    [anon_sym_short] = ACTIONS(2066),
    [anon_sym_LBRACK] = ACTIONS(2066),
    [anon_sym_static] = ACTIONS(2066),
    [anon_sym_register] = ACTIONS(2066),
    [anon_sym_inline] = ACTIONS(2066),
    [anon_sym___inline] = ACTIONS(2066),
    [anon_sym___inline__] = ACTIONS(2066),
    [anon_sym___forceinline] = ACTIONS(2066),
    [anon_sym_thread_local] = ACTIONS(2066),
    [anon_sym___thread] = ACTIONS(2066),
    [anon_sym_const] = ACTIONS(2066),
    [anon_sym_constexpr] = ACTIONS(2066),
    [anon_sym_volatile] = ACTIONS(2066),
    [anon_sym_restrict] = ACTIONS(2066),
    [anon_sym___restrict__] = ACTIONS(2066),
    [anon_sym__Atomic] = ACTIONS(2066),
    [anon_sym__Noreturn] = ACTIONS(2066),
    [anon_sym_noreturn] = ACTIONS(2066),
    [anon_sym__Nonnull] = ACTIONS(2066),
    [anon_sym_mutable] = ACTIONS(2066),
    [anon_sym_constinit] = ACTIONS(2066),
    [anon_sym_consteval] = ACTIONS(2066),
    [anon_sym___shared__] = ACTIONS(2066),
    [anon_sym___local__] = ACTIONS(2066),
    [anon_sym___constant__] = ACTIONS(2066),
    [anon_sym___managed__] = ACTIONS(2066),
    [anon_sym___grid_constant__] = ACTIONS(2066),
    [anon_sym_alignas] = ACTIONS(2066),
    [anon_sym__Alignas] = ACTIONS(2066),
    [sym_primitive_type] = ACTIONS(2066),
    [anon_sym_enum] = ACTIONS(2066),
    [anon_sym_class] = ACTIONS(2066),
    [anon_sym_struct] = ACTIONS(2066),
    [anon_sym_union] = ACTIONS(2066),
    [anon_sym_if] = ACTIONS(2066),
    [anon_sym_else] = ACTIONS(2066),
    [anon_sym_switch] = ACTIONS(2066),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_do] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2066),
    [anon_sym_return] = ACTIONS(2066),
    [anon_sym_break] = ACTIONS(2066),
    [anon_sym_continue] = ACTIONS(2066),
    [anon_sym_goto] = ACTIONS(2066),
    [anon_sym___try] = ACTIONS(2066),
    [anon_sym___leave] = ACTIONS(2066),
    [anon_sym_not] = ACTIONS(2066),
    [anon_sym_compl] = ACTIONS(2066),
    [anon_sym_DASH_DASH] = ACTIONS(2068),
    [anon_sym_PLUS_PLUS] = ACTIONS(2068),
    [anon_sym_sizeof] = ACTIONS(2066),
    [anon_sym___alignof__] = ACTIONS(2066),
    [anon_sym___alignof] = ACTIONS(2066),
    [anon_sym__alignof] = ACTIONS(2066),
    [anon_sym_alignof] = ACTIONS(2066),
    [anon_sym__Alignof] = ACTIONS(2066),
    [anon_sym_offsetof] = ACTIONS(2066),
    [anon_sym__Generic] = ACTIONS(2066),
    [anon_sym_asm] = ACTIONS(2066),
    [anon_sym___asm__] = ACTIONS(2066),
    [anon_sym___asm] = ACTIONS(2066),
    [sym_number_literal] = ACTIONS(2068),
    [anon_sym_L_SQUOTE] = ACTIONS(2068),
    [anon_sym_u_SQUOTE] = ACTIONS(2068),
    [anon_sym_U_SQUOTE] = ACTIONS(2068),
    [anon_sym_u8_SQUOTE] = ACTIONS(2068),
    [anon_sym_SQUOTE] = ACTIONS(2068),
    [anon_sym_L_DQUOTE] = ACTIONS(2068),
    [anon_sym_u_DQUOTE] = ACTIONS(2068),
    [anon_sym_U_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8_DQUOTE] = ACTIONS(2068),
    [anon_sym_DQUOTE] = ACTIONS(2068),
    [sym_true] = ACTIONS(2066),
    [sym_false] = ACTIONS(2066),
    [anon_sym_NULL] = ACTIONS(2066),
    [anon_sym_nullptr] = ACTIONS(2066),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2066),
    [anon_sym_decltype] = ACTIONS(2066),
    [anon_sym_typename] = ACTIONS(2066),
    [anon_sym_template] = ACTIONS(2066),
    [anon_sym_try] = ACTIONS(2066),
    [anon_sym_delete] = ACTIONS(2066),
    [anon_sym_throw] = ACTIONS(2066),
    [anon_sym_co_return] = ACTIONS(2066),
    [anon_sym_co_yield] = ACTIONS(2066),
    [anon_sym_R_DQUOTE] = ACTIONS(2068),
    [anon_sym_LR_DQUOTE] = ACTIONS(2068),
    [anon_sym_uR_DQUOTE] = ACTIONS(2068),
    [anon_sym_UR_DQUOTE] = ACTIONS(2068),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2068),
    [anon_sym_co_await] = ACTIONS(2066),
    [anon_sym_new] = ACTIONS(2066),
    [anon_sym_requires] = ACTIONS(2066),
    [sym_this] = ACTIONS(2066),
    [anon_sym___launch_bounds__] = ACTIONS(2066),
  },
  [STATE(898)] = {
    [sym_identifier] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2100),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym___device__] = ACTIONS(2098),
    [anon_sym___host__] = ACTIONS(2098),
    [anon_sym___global__] = ACTIONS(2098),
    [anon_sym___forceinline__] = ACTIONS(2098),
    [anon_sym___noinline__] = ACTIONS(2098),
    [anon_sym_virtual] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym___attribute] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym__Nonnull] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym___shared__] = ACTIONS(2098),
    [anon_sym___local__] = ACTIONS(2098),
    [anon_sym___constant__] = ACTIONS(2098),
    [anon_sym___managed__] = ACTIONS(2098),
    [anon_sym___grid_constant__] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [anon_sym___asm] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym___launch_bounds__] = ACTIONS(2098),
  },
  [STATE(899)] = {
    [sym_identifier] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2172),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym___device__] = ACTIONS(2170),
    [anon_sym___host__] = ACTIONS(2170),
    [anon_sym___global__] = ACTIONS(2170),
    [anon_sym___forceinline__] = ACTIONS(2170),
    [anon_sym___noinline__] = ACTIONS(2170),
    [anon_sym_virtual] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym___attribute] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym__Nonnull] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym___shared__] = ACTIONS(2170),
    [anon_sym___local__] = ACTIONS(2170),
    [anon_sym___constant__] = ACTIONS(2170),
    [anon_sym___managed__] = ACTIONS(2170),
    [anon_sym___grid_constant__] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [anon_sym___asm] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym___launch_bounds__] = ACTIONS(2170),
  },
  [STATE(900)] = {
    [sym_identifier] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2176),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym___device__] = ACTIONS(2174),
    [anon_sym___host__] = ACTIONS(2174),
    [anon_sym___global__] = ACTIONS(2174),
    [anon_sym___forceinline__] = ACTIONS(2174),
    [anon_sym___noinline__] = ACTIONS(2174),
    [anon_sym_virtual] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym___attribute] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym__Nonnull] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym___shared__] = ACTIONS(2174),
    [anon_sym___local__] = ACTIONS(2174),
    [anon_sym___constant__] = ACTIONS(2174),
    [anon_sym___managed__] = ACTIONS(2174),
    [anon_sym___grid_constant__] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [anon_sym___asm] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym___launch_bounds__] = ACTIONS(2174),
  },
  [STATE(901)] = {
    [sym_identifier] = ACTIONS(2078),
    [anon_sym_LPAREN2] = ACTIONS(2083),
    [anon_sym_BANG] = ACTIONS(2083),
    [anon_sym_TILDE] = ACTIONS(2083),
    [anon_sym_DASH] = ACTIONS(2078),
    [anon_sym_PLUS] = ACTIONS(2078),
    [anon_sym_STAR] = ACTIONS(2083),
    [anon_sym_AMP] = ACTIONS(2083),
    [anon_sym_SEMI] = ACTIONS(2083),
    [anon_sym___extension__] = ACTIONS(2078),
    [anon_sym_typedef] = ACTIONS(2078),
    [anon_sym___device__] = ACTIONS(2078),
    [anon_sym___host__] = ACTIONS(2078),
    [anon_sym___global__] = ACTIONS(2078),
    [anon_sym___forceinline__] = ACTIONS(2078),
    [anon_sym___noinline__] = ACTIONS(2078),
    [anon_sym_virtual] = ACTIONS(2078),
    [anon_sym_extern] = ACTIONS(2078),
    [anon_sym___attribute__] = ACTIONS(2078),
    [anon_sym___attribute] = ACTIONS(2078),
    [anon_sym_COLON_COLON] = ACTIONS(2083),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2083),
    [anon_sym___declspec] = ACTIONS(2078),
    [anon_sym_LBRACE] = ACTIONS(2083),
    [anon_sym_signed] = ACTIONS(2078),
    [anon_sym_unsigned] = ACTIONS(2078),
    [anon_sym_long] = ACTIONS(2078),
    [anon_sym_short] = ACTIONS(2078),
    [anon_sym_LBRACK] = ACTIONS(2078),
    [anon_sym_static] = ACTIONS(2078),
    [anon_sym_register] = ACTIONS(2078),
    [anon_sym_inline] = ACTIONS(2078),
    [anon_sym___inline] = ACTIONS(2078),
    [anon_sym___inline__] = ACTIONS(2078),
    [anon_sym___forceinline] = ACTIONS(2078),
    [anon_sym_thread_local] = ACTIONS(2078),
    [anon_sym___thread] = ACTIONS(2078),
    [anon_sym_const] = ACTIONS(2078),
    [anon_sym_constexpr] = ACTIONS(2078),
    [anon_sym_volatile] = ACTIONS(2078),
    [anon_sym_restrict] = ACTIONS(2078),
    [anon_sym___restrict__] = ACTIONS(2078),
    [anon_sym__Atomic] = ACTIONS(2078),
    [anon_sym__Noreturn] = ACTIONS(2078),
    [anon_sym_noreturn] = ACTIONS(2078),
    [anon_sym__Nonnull] = ACTIONS(2078),
    [anon_sym_mutable] = ACTIONS(2078),
    [anon_sym_constinit] = ACTIONS(2078),
    [anon_sym_consteval] = ACTIONS(2078),
    [anon_sym___shared__] = ACTIONS(2078),
    [anon_sym___local__] = ACTIONS(2078),
    [anon_sym___constant__] = ACTIONS(2078),
    [anon_sym___managed__] = ACTIONS(2078),
    [anon_sym___grid_constant__] = ACTIONS(2078),
    [anon_sym_alignas] = ACTIONS(2078),
    [anon_sym__Alignas] = ACTIONS(2078),
    [sym_primitive_type] = ACTIONS(2078),
    [anon_sym_enum] = ACTIONS(2078),
    [anon_sym_class] = ACTIONS(2078),
    [anon_sym_struct] = ACTIONS(2078),
    [anon_sym_union] = ACTIONS(2078),
    [anon_sym_if] = ACTIONS(2078),
    [anon_sym_else] = ACTIONS(2078),
    [anon_sym_switch] = ACTIONS(2078),
    [anon_sym_while] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(2078),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_return] = ACTIONS(2078),
    [anon_sym_break] = ACTIONS(2078),
    [anon_sym_continue] = ACTIONS(2078),
    [anon_sym_goto] = ACTIONS(2078),
    [anon_sym___try] = ACTIONS(2078),
    [anon_sym___leave] = ACTIONS(2078),
    [anon_sym_not] = ACTIONS(2078),
    [anon_sym_compl] = ACTIONS(2078),
    [anon_sym_DASH_DASH] = ACTIONS(2083),
    [anon_sym_PLUS_PLUS] = ACTIONS(2083),
    [anon_sym_sizeof] = ACTIONS(2078),
    [anon_sym___alignof__] = ACTIONS(2078),
    [anon_sym___alignof] = ACTIONS(2078),
    [anon_sym__alignof] = ACTIONS(2078),
    [anon_sym_alignof] = ACTIONS(2078),
    [anon_sym__Alignof] = ACTIONS(2078),
    [anon_sym_offsetof] = ACTIONS(2078),
    [anon_sym__Generic] = ACTIONS(2078),
    [anon_sym_asm] = ACTIONS(2078),
    [anon_sym___asm__] = ACTIONS(2078),
    [anon_sym___asm] = ACTIONS(2078),
    [sym_number_literal] = ACTIONS(2083),
    [anon_sym_L_SQUOTE] = ACTIONS(2083),
    [anon_sym_u_SQUOTE] = ACTIONS(2083),
    [anon_sym_U_SQUOTE] = ACTIONS(2083),
    [anon_sym_u8_SQUOTE] = ACTIONS(2083),
    [anon_sym_SQUOTE] = ACTIONS(2083),
    [anon_sym_L_DQUOTE] = ACTIONS(2083),
    [anon_sym_u_DQUOTE] = ACTIONS(2083),
    [anon_sym_U_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8_DQUOTE] = ACTIONS(2083),
    [anon_sym_DQUOTE] = ACTIONS(2083),
    [sym_true] = ACTIONS(2078),
    [sym_false] = ACTIONS(2078),
    [anon_sym_NULL] = ACTIONS(2078),
    [anon_sym_nullptr] = ACTIONS(2078),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2078),
    [anon_sym_decltype] = ACTIONS(2078),
    [anon_sym_typename] = ACTIONS(2078),
    [anon_sym_template] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2078),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_co_return] = ACTIONS(2078),
    [anon_sym_co_yield] = ACTIONS(2078),
    [anon_sym_R_DQUOTE] = ACTIONS(2083),
    [anon_sym_LR_DQUOTE] = ACTIONS(2083),
    [anon_sym_uR_DQUOTE] = ACTIONS(2083),
    [anon_sym_UR_DQUOTE] = ACTIONS(2083),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2083),
    [anon_sym_co_await] = ACTIONS(2078),
    [anon_sym_new] = ACTIONS(2078),
    [anon_sym_requires] = ACTIONS(2078),
    [sym_this] = ACTIONS(2078),
    [anon_sym___launch_bounds__] = ACTIONS(2078),
  },
  [STATE(902)] = {
    [sym_identifier] = ACTIONS(2032),
    [anon_sym_LPAREN2] = ACTIONS(2034),
    [anon_sym_BANG] = ACTIONS(2034),
    [anon_sym_TILDE] = ACTIONS(2034),
    [anon_sym_DASH] = ACTIONS(2032),
    [anon_sym_PLUS] = ACTIONS(2032),
    [anon_sym_STAR] = ACTIONS(2034),
    [anon_sym_AMP] = ACTIONS(2034),
    [anon_sym_SEMI] = ACTIONS(2034),
    [anon_sym___extension__] = ACTIONS(2032),
    [anon_sym_typedef] = ACTIONS(2032),
    [anon_sym___device__] = ACTIONS(2032),
    [anon_sym___host__] = ACTIONS(2032),
    [anon_sym___global__] = ACTIONS(2032),
    [anon_sym___forceinline__] = ACTIONS(2032),
    [anon_sym___noinline__] = ACTIONS(2032),
    [anon_sym_virtual] = ACTIONS(2032),
    [anon_sym_extern] = ACTIONS(2032),
    [anon_sym___attribute__] = ACTIONS(2032),
    [anon_sym___attribute] = ACTIONS(2032),
    [anon_sym_COLON_COLON] = ACTIONS(2034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2034),
    [anon_sym___declspec] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2032),
    [anon_sym_unsigned] = ACTIONS(2032),
    [anon_sym_long] = ACTIONS(2032),
    [anon_sym_short] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(2032),
    [anon_sym_static] = ACTIONS(2032),
    [anon_sym_register] = ACTIONS(2032),
    [anon_sym_inline] = ACTIONS(2032),
    [anon_sym___inline] = ACTIONS(2032),
    [anon_sym___inline__] = ACTIONS(2032),
    [anon_sym___forceinline] = ACTIONS(2032),
    [anon_sym_thread_local] = ACTIONS(2032),
    [anon_sym___thread] = ACTIONS(2032),
    [anon_sym_const] = ACTIONS(2032),
    [anon_sym_constexpr] = ACTIONS(2032),
    [anon_sym_volatile] = ACTIONS(2032),
    [anon_sym_restrict] = ACTIONS(2032),
    [anon_sym___restrict__] = ACTIONS(2032),
    [anon_sym__Atomic] = ACTIONS(2032),
    [anon_sym__Noreturn] = ACTIONS(2032),
    [anon_sym_noreturn] = ACTIONS(2032),
    [anon_sym__Nonnull] = ACTIONS(2032),
    [anon_sym_mutable] = ACTIONS(2032),
    [anon_sym_constinit] = ACTIONS(2032),
    [anon_sym_consteval] = ACTIONS(2032),
    [anon_sym___shared__] = ACTIONS(2032),
    [anon_sym___local__] = ACTIONS(2032),
    [anon_sym___constant__] = ACTIONS(2032),
    [anon_sym___managed__] = ACTIONS(2032),
    [anon_sym___grid_constant__] = ACTIONS(2032),
    [anon_sym_alignas] = ACTIONS(2032),
    [anon_sym__Alignas] = ACTIONS(2032),
    [sym_primitive_type] = ACTIONS(2032),
    [anon_sym_enum] = ACTIONS(2032),
    [anon_sym_class] = ACTIONS(2032),
    [anon_sym_struct] = ACTIONS(2032),
    [anon_sym_union] = ACTIONS(2032),
    [anon_sym_if] = ACTIONS(2032),
    [anon_sym_else] = ACTIONS(2032),
    [anon_sym_switch] = ACTIONS(2032),
    [anon_sym_while] = ACTIONS(2032),
    [anon_sym_do] = ACTIONS(2032),
    [anon_sym_for] = ACTIONS(2032),
    [anon_sym_return] = ACTIONS(2032),
    [anon_sym_break] = ACTIONS(2032),
    [anon_sym_continue] = ACTIONS(2032),
    [anon_sym_goto] = ACTIONS(2032),
    [anon_sym___try] = ACTIONS(2032),
    [anon_sym___leave] = ACTIONS(2032),
    [anon_sym_not] = ACTIONS(2032),
    [anon_sym_compl] = ACTIONS(2032),
    [anon_sym_DASH_DASH] = ACTIONS(2034),
    [anon_sym_PLUS_PLUS] = ACTIONS(2034),
    [anon_sym_sizeof] = ACTIONS(2032),
    [anon_sym___alignof__] = ACTIONS(2032),
    [anon_sym___alignof] = ACTIONS(2032),
    [anon_sym__alignof] = ACTIONS(2032),
    [anon_sym_alignof] = ACTIONS(2032),
    [anon_sym__Alignof] = ACTIONS(2032),
    [anon_sym_offsetof] = ACTIONS(2032),
    [anon_sym__Generic] = ACTIONS(2032),
    [anon_sym_asm] = ACTIONS(2032),
    [anon_sym___asm__] = ACTIONS(2032),
    [anon_sym___asm] = ACTIONS(2032),
    [sym_number_literal] = ACTIONS(2034),
    [anon_sym_L_SQUOTE] = ACTIONS(2034),
    [anon_sym_u_SQUOTE] = ACTIONS(2034),
    [anon_sym_U_SQUOTE] = ACTIONS(2034),
    [anon_sym_u8_SQUOTE] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2034),
    [anon_sym_L_DQUOTE] = ACTIONS(2034),
    [anon_sym_u_DQUOTE] = ACTIONS(2034),
    [anon_sym_U_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8_DQUOTE] = ACTIONS(2034),
    [anon_sym_DQUOTE] = ACTIONS(2034),
    [sym_true] = ACTIONS(2032),
    [sym_false] = ACTIONS(2032),
    [anon_sym_NULL] = ACTIONS(2032),
    [anon_sym_nullptr] = ACTIONS(2032),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2032),
    [anon_sym_decltype] = ACTIONS(2032),
    [anon_sym_typename] = ACTIONS(2032),
    [anon_sym_template] = ACTIONS(2032),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_delete] = ACTIONS(2032),
    [anon_sym_throw] = ACTIONS(2032),
    [anon_sym_co_return] = ACTIONS(2032),
    [anon_sym_co_yield] = ACTIONS(2032),
    [anon_sym_R_DQUOTE] = ACTIONS(2034),
    [anon_sym_LR_DQUOTE] = ACTIONS(2034),
    [anon_sym_uR_DQUOTE] = ACTIONS(2034),
    [anon_sym_UR_DQUOTE] = ACTIONS(2034),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2034),
    [anon_sym_co_await] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(2032),
    [anon_sym_requires] = ACTIONS(2032),
    [sym_this] = ACTIONS(2032),
    [anon_sym___launch_bounds__] = ACTIONS(2032),
  },
  [STATE(903)] = {
    [sym_identifier] = ACTIONS(2040),
    [anon_sym_LPAREN2] = ACTIONS(2042),
    [anon_sym_BANG] = ACTIONS(2042),
    [anon_sym_TILDE] = ACTIONS(2042),
    [anon_sym_DASH] = ACTIONS(2040),
    [anon_sym_PLUS] = ACTIONS(2040),
    [anon_sym_STAR] = ACTIONS(2042),
    [anon_sym_AMP] = ACTIONS(2042),
    [anon_sym_SEMI] = ACTIONS(2042),
    [anon_sym___extension__] = ACTIONS(2040),
    [anon_sym_typedef] = ACTIONS(2040),
    [anon_sym___device__] = ACTIONS(2040),
    [anon_sym___host__] = ACTIONS(2040),
    [anon_sym___global__] = ACTIONS(2040),
    [anon_sym___forceinline__] = ACTIONS(2040),
    [anon_sym___noinline__] = ACTIONS(2040),
    [anon_sym_virtual] = ACTIONS(2040),
    [anon_sym_extern] = ACTIONS(2040),
    [anon_sym___attribute__] = ACTIONS(2040),
    [anon_sym___attribute] = ACTIONS(2040),
    [anon_sym_COLON_COLON] = ACTIONS(2042),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2042),
    [anon_sym___declspec] = ACTIONS(2040),
    [anon_sym_LBRACE] = ACTIONS(2042),
    [anon_sym_signed] = ACTIONS(2040),
    [anon_sym_unsigned] = ACTIONS(2040),
    [anon_sym_long] = ACTIONS(2040),
    [anon_sym_short] = ACTIONS(2040),
    [anon_sym_LBRACK] = ACTIONS(2040),
    [anon_sym_static] = ACTIONS(2040),
    [anon_sym_register] = ACTIONS(2040),
    [anon_sym_inline] = ACTIONS(2040),
    [anon_sym___inline] = ACTIONS(2040),
    [anon_sym___inline__] = ACTIONS(2040),
    [anon_sym___forceinline] = ACTIONS(2040),
    [anon_sym_thread_local] = ACTIONS(2040),
    [anon_sym___thread] = ACTIONS(2040),
    [anon_sym_const] = ACTIONS(2040),
    [anon_sym_constexpr] = ACTIONS(2040),
    [anon_sym_volatile] = ACTIONS(2040),
    [anon_sym_restrict] = ACTIONS(2040),
    [anon_sym___restrict__] = ACTIONS(2040),
    [anon_sym__Atomic] = ACTIONS(2040),
    [anon_sym__Noreturn] = ACTIONS(2040),
    [anon_sym_noreturn] = ACTIONS(2040),
    [anon_sym__Nonnull] = ACTIONS(2040),
    [anon_sym_mutable] = ACTIONS(2040),
    [anon_sym_constinit] = ACTIONS(2040),
    [anon_sym_consteval] = ACTIONS(2040),
    [anon_sym___shared__] = ACTIONS(2040),
    [anon_sym___local__] = ACTIONS(2040),
    [anon_sym___constant__] = ACTIONS(2040),
    [anon_sym___managed__] = ACTIONS(2040),
    [anon_sym___grid_constant__] = ACTIONS(2040),
    [anon_sym_alignas] = ACTIONS(2040),
    [anon_sym__Alignas] = ACTIONS(2040),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2040),
    [anon_sym_class] = ACTIONS(2040),
    [anon_sym_struct] = ACTIONS(2040),
    [anon_sym_union] = ACTIONS(2040),
    [anon_sym_if] = ACTIONS(2040),
    [anon_sym_else] = ACTIONS(2040),
    [anon_sym_switch] = ACTIONS(2040),
    [anon_sym_while] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(2040),
    [anon_sym_for] = ACTIONS(2040),
    [anon_sym_return] = ACTIONS(2040),
    [anon_sym_break] = ACTIONS(2040),
    [anon_sym_continue] = ACTIONS(2040),
    [anon_sym_goto] = ACTIONS(2040),
    [anon_sym___try] = ACTIONS(2040),
    [anon_sym___leave] = ACTIONS(2040),
    [anon_sym_not] = ACTIONS(2040),
    [anon_sym_compl] = ACTIONS(2040),
    [anon_sym_DASH_DASH] = ACTIONS(2042),
    [anon_sym_PLUS_PLUS] = ACTIONS(2042),
    [anon_sym_sizeof] = ACTIONS(2040),
    [anon_sym___alignof__] = ACTIONS(2040),
    [anon_sym___alignof] = ACTIONS(2040),
    [anon_sym__alignof] = ACTIONS(2040),
    [anon_sym_alignof] = ACTIONS(2040),
    [anon_sym__Alignof] = ACTIONS(2040),
    [anon_sym_offsetof] = ACTIONS(2040),
    [anon_sym__Generic] = ACTIONS(2040),
    [anon_sym_asm] = ACTIONS(2040),
    [anon_sym___asm__] = ACTIONS(2040),
    [anon_sym___asm] = ACTIONS(2040),
    [sym_number_literal] = ACTIONS(2042),
    [anon_sym_L_SQUOTE] = ACTIONS(2042),
    [anon_sym_u_SQUOTE] = ACTIONS(2042),
    [anon_sym_U_SQUOTE] = ACTIONS(2042),
    [anon_sym_u8_SQUOTE] = ACTIONS(2042),
    [anon_sym_SQUOTE] = ACTIONS(2042),
    [anon_sym_L_DQUOTE] = ACTIONS(2042),
    [anon_sym_u_DQUOTE] = ACTIONS(2042),
    [anon_sym_U_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8_DQUOTE] = ACTIONS(2042),
    [anon_sym_DQUOTE] = ACTIONS(2042),
    [sym_true] = ACTIONS(2040),
    [sym_false] = ACTIONS(2040),
    [anon_sym_NULL] = ACTIONS(2040),
    [anon_sym_nullptr] = ACTIONS(2040),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2040),
    [anon_sym_decltype] = ACTIONS(2040),
    [anon_sym_typename] = ACTIONS(2040),
    [anon_sym_template] = ACTIONS(2040),
    [anon_sym_try] = ACTIONS(2040),
    [anon_sym_delete] = ACTIONS(2040),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_co_return] = ACTIONS(2040),
    [anon_sym_co_yield] = ACTIONS(2040),
    [anon_sym_R_DQUOTE] = ACTIONS(2042),
    [anon_sym_LR_DQUOTE] = ACTIONS(2042),
    [anon_sym_uR_DQUOTE] = ACTIONS(2042),
    [anon_sym_UR_DQUOTE] = ACTIONS(2042),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2042),
    [anon_sym_co_await] = ACTIONS(2040),
    [anon_sym_new] = ACTIONS(2040),
    [anon_sym_requires] = ACTIONS(2040),
    [sym_this] = ACTIONS(2040),
    [anon_sym___launch_bounds__] = ACTIONS(2040),
  },
  [STATE(904)] = {
    [sym_identifier] = ACTIONS(2036),
    [anon_sym_LPAREN2] = ACTIONS(2038),
    [anon_sym_BANG] = ACTIONS(2038),
    [anon_sym_TILDE] = ACTIONS(2038),
    [anon_sym_DASH] = ACTIONS(2036),
    [anon_sym_PLUS] = ACTIONS(2036),
    [anon_sym_STAR] = ACTIONS(2038),
    [anon_sym_AMP] = ACTIONS(2038),
    [anon_sym_SEMI] = ACTIONS(2038),
    [anon_sym___extension__] = ACTIONS(2036),
    [anon_sym_typedef] = ACTIONS(2036),
    [anon_sym___device__] = ACTIONS(2036),
    [anon_sym___host__] = ACTIONS(2036),
    [anon_sym___global__] = ACTIONS(2036),
    [anon_sym___forceinline__] = ACTIONS(2036),
    [anon_sym___noinline__] = ACTIONS(2036),
    [anon_sym_virtual] = ACTIONS(2036),
    [anon_sym_extern] = ACTIONS(2036),
    [anon_sym___attribute__] = ACTIONS(2036),
    [anon_sym___attribute] = ACTIONS(2036),
    [anon_sym_COLON_COLON] = ACTIONS(2038),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2038),
    [anon_sym___declspec] = ACTIONS(2036),
    [anon_sym_LBRACE] = ACTIONS(2038),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(2036),
    [anon_sym_static] = ACTIONS(2036),
    [anon_sym_register] = ACTIONS(2036),
    [anon_sym_inline] = ACTIONS(2036),
    [anon_sym___inline] = ACTIONS(2036),
    [anon_sym___inline__] = ACTIONS(2036),
    [anon_sym___forceinline] = ACTIONS(2036),
    [anon_sym_thread_local] = ACTIONS(2036),
    [anon_sym___thread] = ACTIONS(2036),
    [anon_sym_const] = ACTIONS(2036),
    [anon_sym_constexpr] = ACTIONS(2036),
    [anon_sym_volatile] = ACTIONS(2036),
    [anon_sym_restrict] = ACTIONS(2036),
    [anon_sym___restrict__] = ACTIONS(2036),
    [anon_sym__Atomic] = ACTIONS(2036),
    [anon_sym__Noreturn] = ACTIONS(2036),
    [anon_sym_noreturn] = ACTIONS(2036),
    [anon_sym__Nonnull] = ACTIONS(2036),
    [anon_sym_mutable] = ACTIONS(2036),
    [anon_sym_constinit] = ACTIONS(2036),
    [anon_sym_consteval] = ACTIONS(2036),
    [anon_sym___shared__] = ACTIONS(2036),
    [anon_sym___local__] = ACTIONS(2036),
    [anon_sym___constant__] = ACTIONS(2036),
    [anon_sym___managed__] = ACTIONS(2036),
    [anon_sym___grid_constant__] = ACTIONS(2036),
    [anon_sym_alignas] = ACTIONS(2036),
    [anon_sym__Alignas] = ACTIONS(2036),
    [sym_primitive_type] = ACTIONS(2036),
    [anon_sym_enum] = ACTIONS(2036),
    [anon_sym_class] = ACTIONS(2036),
    [anon_sym_struct] = ACTIONS(2036),
    [anon_sym_union] = ACTIONS(2036),
    [anon_sym_if] = ACTIONS(2036),
    [anon_sym_else] = ACTIONS(2036),
    [anon_sym_switch] = ACTIONS(2036),
    [anon_sym_while] = ACTIONS(2036),
    [anon_sym_do] = ACTIONS(2036),
    [anon_sym_for] = ACTIONS(2036),
    [anon_sym_return] = ACTIONS(2036),
    [anon_sym_break] = ACTIONS(2036),
    [anon_sym_continue] = ACTIONS(2036),
    [anon_sym_goto] = ACTIONS(2036),
    [anon_sym___try] = ACTIONS(2036),
    [anon_sym___leave] = ACTIONS(2036),
    [anon_sym_not] = ACTIONS(2036),
    [anon_sym_compl] = ACTIONS(2036),
    [anon_sym_DASH_DASH] = ACTIONS(2038),
    [anon_sym_PLUS_PLUS] = ACTIONS(2038),
    [anon_sym_sizeof] = ACTIONS(2036),
    [anon_sym___alignof__] = ACTIONS(2036),
    [anon_sym___alignof] = ACTIONS(2036),
    [anon_sym__alignof] = ACTIONS(2036),
    [anon_sym_alignof] = ACTIONS(2036),
    [anon_sym__Alignof] = ACTIONS(2036),
    [anon_sym_offsetof] = ACTIONS(2036),
    [anon_sym__Generic] = ACTIONS(2036),
    [anon_sym_asm] = ACTIONS(2036),
    [anon_sym___asm__] = ACTIONS(2036),
    [anon_sym___asm] = ACTIONS(2036),
    [sym_number_literal] = ACTIONS(2038),
    [anon_sym_L_SQUOTE] = ACTIONS(2038),
    [anon_sym_u_SQUOTE] = ACTIONS(2038),
    [anon_sym_U_SQUOTE] = ACTIONS(2038),
    [anon_sym_u8_SQUOTE] = ACTIONS(2038),
    [anon_sym_SQUOTE] = ACTIONS(2038),
    [anon_sym_L_DQUOTE] = ACTIONS(2038),
    [anon_sym_u_DQUOTE] = ACTIONS(2038),
    [anon_sym_U_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8_DQUOTE] = ACTIONS(2038),
    [anon_sym_DQUOTE] = ACTIONS(2038),
    [sym_true] = ACTIONS(2036),
    [sym_false] = ACTIONS(2036),
    [anon_sym_NULL] = ACTIONS(2036),
    [anon_sym_nullptr] = ACTIONS(2036),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2036),
    [anon_sym_decltype] = ACTIONS(2036),
    [anon_sym_typename] = ACTIONS(2036),
    [anon_sym_template] = ACTIONS(2036),
    [anon_sym_try] = ACTIONS(2036),
    [anon_sym_delete] = ACTIONS(2036),
    [anon_sym_throw] = ACTIONS(2036),
    [anon_sym_co_return] = ACTIONS(2036),
    [anon_sym_co_yield] = ACTIONS(2036),
    [anon_sym_R_DQUOTE] = ACTIONS(2038),
    [anon_sym_LR_DQUOTE] = ACTIONS(2038),
    [anon_sym_uR_DQUOTE] = ACTIONS(2038),
    [anon_sym_UR_DQUOTE] = ACTIONS(2038),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2038),
    [anon_sym_co_await] = ACTIONS(2036),
    [anon_sym_new] = ACTIONS(2036),
    [anon_sym_requires] = ACTIONS(2036),
    [sym_this] = ACTIONS(2036),
    [anon_sym___launch_bounds__] = ACTIONS(2036),
  },
  [STATE(905)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_call_modifier] = STATE(5468),
    [sym__declarator] = STATE(7291),
    [sym__abstract_declarator] = STATE(7441),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_list] = STATE(2996),
    [sym_parameter_declaration] = STATE(8202),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(8202),
    [sym_variadic_parameter_declaration] = STATE(8202),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(2212),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6286),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1846),
    [anon_sym_RPAREN] = ACTIONS(4195),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(4199),
    [anon_sym_AMP_AMP] = ACTIONS(4201),
    [anon_sym_AMP] = ACTIONS(4203),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4205),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym___cdecl] = ACTIONS(1870),
    [anon_sym___clrcall] = ACTIONS(1870),
    [anon_sym___stdcall] = ACTIONS(1870),
    [anon_sym___fastcall] = ACTIONS(1870),
    [anon_sym___thiscall] = ACTIONS(1870),
    [anon_sym___vectorcall] = ACTIONS(1870),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(4207),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(906)] = {
    [sym_expression] = STATE(3419),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(3970),
    [anon_sym_LPAREN2] = ACTIONS(4209),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(4212),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(4215),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(4218),
    [anon_sym___extension__] = ACTIONS(3973),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(3976),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(4221),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(907)] = {
    [sym_expression] = STATE(3175),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(4224),
    [anon_sym_LPAREN2] = ACTIONS(4227),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(4230),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1956),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(4233),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(4236),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(4221),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(908)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1707),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4004),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4060),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(909)] = {
    [sym_expression] = STATE(5196),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4239),
    [anon_sym_LPAREN2] = ACTIONS(4242),
    [anon_sym_BANG] = ACTIONS(4245),
    [anon_sym_TILDE] = ACTIONS(4245),
    [anon_sym_DASH] = ACTIONS(4248),
    [anon_sym_PLUS] = ACTIONS(4248),
    [anon_sym_STAR] = ACTIONS(1956),
    [anon_sym_AMP] = ACTIONS(1956),
    [anon_sym___extension__] = ACTIONS(4251),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(4254),
    [anon_sym_LBRACK] = ACTIONS(4221),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_RBRACK] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1977),
    [anon_sym_not] = ACTIONS(4248),
    [anon_sym_compl] = ACTIONS(4248),
    [anon_sym_DASH_DASH] = ACTIONS(4257),
    [anon_sym_PLUS_PLUS] = ACTIONS(4257),
    [anon_sym_sizeof] = ACTIONS(4260),
    [anon_sym___alignof__] = ACTIONS(4263),
    [anon_sym___alignof] = ACTIONS(4263),
    [anon_sym__alignof] = ACTIONS(4263),
    [anon_sym_alignof] = ACTIONS(4263),
    [anon_sym__Alignof] = ACTIONS(4263),
    [anon_sym_offsetof] = ACTIONS(4266),
    [anon_sym__Generic] = ACTIONS(4269),
    [anon_sym_asm] = ACTIONS(4272),
    [anon_sym___asm__] = ACTIONS(4272),
    [anon_sym___asm] = ACTIONS(4272),
    [sym_number_literal] = ACTIONS(4275),
    [anon_sym_L_SQUOTE] = ACTIONS(4278),
    [anon_sym_u_SQUOTE] = ACTIONS(4278),
    [anon_sym_U_SQUOTE] = ACTIONS(4278),
    [anon_sym_u8_SQUOTE] = ACTIONS(4278),
    [anon_sym_SQUOTE] = ACTIONS(4278),
    [anon_sym_L_DQUOTE] = ACTIONS(4281),
    [anon_sym_u_DQUOTE] = ACTIONS(4281),
    [anon_sym_U_DQUOTE] = ACTIONS(4281),
    [anon_sym_u8_DQUOTE] = ACTIONS(4281),
    [anon_sym_DQUOTE] = ACTIONS(4281),
    [sym_true] = ACTIONS(4284),
    [sym_false] = ACTIONS(4284),
    [anon_sym_NULL] = ACTIONS(4287),
    [anon_sym_nullptr] = ACTIONS(4287),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(1980),
    [anon_sym_template] = ACTIONS(1983),
    [anon_sym_delete] = ACTIONS(4290),
    [anon_sym_R_DQUOTE] = ACTIONS(4293),
    [anon_sym_LR_DQUOTE] = ACTIONS(4293),
    [anon_sym_uR_DQUOTE] = ACTIONS(4293),
    [anon_sym_UR_DQUOTE] = ACTIONS(4293),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4293),
    [anon_sym_co_await] = ACTIONS(4296),
    [anon_sym_new] = ACTIONS(4299),
    [anon_sym_requires] = ACTIONS(4302),
    [sym_this] = ACTIONS(4284),
  },
  [STATE(910)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1707),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4305),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(911)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1707),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4307),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(912)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1707),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(913)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1707),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(914)] = {
    [sym_string_literal] = STATE(2712),
    [sym_template_argument_list] = STATE(1343),
    [sym_raw_string_literal] = STATE(2712),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4017),
    [anon_sym_COMMA] = ACTIONS(4017),
    [anon_sym_RPAREN] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4309),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4014),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4312),
    [anon_sym_or_eq] = ACTIONS(4312),
    [anon_sym_xor_eq] = ACTIONS(4312),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4012),
    [anon_sym_L_DQUOTE] = ACTIONS(4314),
    [anon_sym_u_DQUOTE] = ACTIONS(4314),
    [anon_sym_U_DQUOTE] = ACTIONS(4314),
    [anon_sym_u8_DQUOTE] = ACTIONS(4314),
    [anon_sym_DQUOTE] = ACTIONS(4314),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(4316),
    [anon_sym_LR_DQUOTE] = ACTIONS(4316),
    [anon_sym_uR_DQUOTE] = ACTIONS(4316),
    [anon_sym_UR_DQUOTE] = ACTIONS(4316),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4316),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(915)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1707),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4065),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(916)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1707),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4069),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(917)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(1713),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4017),
    [anon_sym_COMMA] = ACTIONS(4017),
    [anon_sym_RPAREN] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(4020),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4002),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4036),
    [anon_sym_or_eq] = ACTIONS(4036),
    [anon_sym_xor_eq] = ACTIONS(4036),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(918)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7109),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_expression] = STATE(3334),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3726),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6227),
    [sym_qualified_identifier] = STATE(3729),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(3123),
    [anon_sym_LPAREN2] = ACTIONS(1854),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1858),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1862),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(1864),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(1874),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(919)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7109),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3695),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6305),
    [sym_qualified_identifier] = STATE(3696),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_operator_name] = STATE(6660),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(3417),
    [anon_sym_LPAREN2] = ACTIONS(3419),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(3421),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(1874),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(920)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4322),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(921)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(920),
    [sym_compound_requirement] = STATE(920),
    [sym__requirement] = STATE(920),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(920),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4326),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(922)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4328),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(923)] = {
    [sym_identifier] = ACTIONS(4330),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_RPAREN] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_TILDE] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4330),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4330),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4330),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4332),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4330),
    [anon_sym_SEMI] = ACTIONS(4332),
    [anon_sym___extension__] = ACTIONS(4330),
    [anon_sym___device__] = ACTIONS(4330),
    [anon_sym___host__] = ACTIONS(4330),
    [anon_sym___global__] = ACTIONS(4330),
    [anon_sym___forceinline__] = ACTIONS(4330),
    [anon_sym___noinline__] = ACTIONS(4330),
    [anon_sym_virtual] = ACTIONS(4330),
    [anon_sym_extern] = ACTIONS(4330),
    [anon_sym___attribute__] = ACTIONS(4330),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4332),
    [anon_sym___declspec] = ACTIONS(4330),
    [anon_sym___based] = ACTIONS(4330),
    [anon_sym___cdecl] = ACTIONS(4330),
    [anon_sym___clrcall] = ACTIONS(4330),
    [anon_sym___stdcall] = ACTIONS(4330),
    [anon_sym___fastcall] = ACTIONS(4330),
    [anon_sym___thiscall] = ACTIONS(4330),
    [anon_sym___vectorcall] = ACTIONS(4330),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_RBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4330),
    [anon_sym_static] = ACTIONS(4330),
    [anon_sym_EQ] = ACTIONS(4330),
    [anon_sym_register] = ACTIONS(4330),
    [anon_sym_inline] = ACTIONS(4330),
    [anon_sym___inline] = ACTIONS(4330),
    [anon_sym___inline__] = ACTIONS(4330),
    [anon_sym___forceinline] = ACTIONS(4330),
    [anon_sym_thread_local] = ACTIONS(4330),
    [anon_sym___thread] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4330),
    [anon_sym_volatile] = ACTIONS(4330),
    [anon_sym_restrict] = ACTIONS(4330),
    [anon_sym___restrict__] = ACTIONS(4330),
    [anon_sym__Atomic] = ACTIONS(4330),
    [anon_sym__Noreturn] = ACTIONS(4330),
    [anon_sym_noreturn] = ACTIONS(4330),
    [anon_sym__Nonnull] = ACTIONS(4330),
    [anon_sym_mutable] = ACTIONS(4330),
    [anon_sym_constinit] = ACTIONS(4330),
    [anon_sym_consteval] = ACTIONS(4330),
    [anon_sym___shared__] = ACTIONS(4330),
    [anon_sym___local__] = ACTIONS(4330),
    [anon_sym___constant__] = ACTIONS(4330),
    [anon_sym___managed__] = ACTIONS(4330),
    [anon_sym___grid_constant__] = ACTIONS(4330),
    [anon_sym_alignas] = ACTIONS(4330),
    [anon_sym__Alignas] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_STAR_EQ] = ACTIONS(4332),
    [anon_sym_SLASH_EQ] = ACTIONS(4332),
    [anon_sym_PERCENT_EQ] = ACTIONS(4332),
    [anon_sym_PLUS_EQ] = ACTIONS(4332),
    [anon_sym_DASH_EQ] = ACTIONS(4332),
    [anon_sym_LT_LT_EQ] = ACTIONS(4332),
    [anon_sym_GT_GT_EQ] = ACTIONS(4332),
    [anon_sym_AMP_EQ] = ACTIONS(4332),
    [anon_sym_CARET_EQ] = ACTIONS(4332),
    [anon_sym_PIPE_EQ] = ACTIONS(4332),
    [anon_sym_and_eq] = ACTIONS(4330),
    [anon_sym_or_eq] = ACTIONS(4330),
    [anon_sym_xor_eq] = ACTIONS(4330),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_bitor] = ACTIONS(4330),
    [anon_sym_xor] = ACTIONS(4330),
    [anon_sym_bitand] = ACTIONS(4330),
    [anon_sym_not_eq] = ACTIONS(4330),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4330),
    [anon_sym_decltype] = ACTIONS(4330),
    [anon_sym_template] = ACTIONS(4330),
    [anon_sym_operator] = ACTIONS(4330),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
    [anon_sym___launch_bounds__] = ACTIONS(4330),
  },
  [STATE(924)] = {
    [sym_expression] = STATE(4985),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(7802),
    [sym_initializer_pair] = STATE(7802),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_COMMA] = ACTIONS(4336),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4338),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(925)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(926),
    [sym_compound_requirement] = STATE(926),
    [sym__requirement] = STATE(926),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(926),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4342),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(926)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4344),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(927)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(928),
    [sym_compound_requirement] = STATE(928),
    [sym__requirement] = STATE(928),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(928),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4346),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(928)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4348),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(929)] = {
    [sym_identifier] = ACTIONS(4350),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_RPAREN] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_TILDE] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4350),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4350),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4350),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4352),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4350),
    [anon_sym_SEMI] = ACTIONS(4352),
    [anon_sym___extension__] = ACTIONS(4350),
    [anon_sym___device__] = ACTIONS(4350),
    [anon_sym___host__] = ACTIONS(4350),
    [anon_sym___global__] = ACTIONS(4350),
    [anon_sym___forceinline__] = ACTIONS(4350),
    [anon_sym___noinline__] = ACTIONS(4350),
    [anon_sym_virtual] = ACTIONS(4350),
    [anon_sym_extern] = ACTIONS(4350),
    [anon_sym___attribute__] = ACTIONS(4350),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4352),
    [anon_sym___declspec] = ACTIONS(4350),
    [anon_sym___based] = ACTIONS(4350),
    [anon_sym___cdecl] = ACTIONS(4350),
    [anon_sym___clrcall] = ACTIONS(4350),
    [anon_sym___stdcall] = ACTIONS(4350),
    [anon_sym___fastcall] = ACTIONS(4350),
    [anon_sym___thiscall] = ACTIONS(4350),
    [anon_sym___vectorcall] = ACTIONS(4350),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_RBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_static] = ACTIONS(4350),
    [anon_sym_EQ] = ACTIONS(4350),
    [anon_sym_register] = ACTIONS(4350),
    [anon_sym_inline] = ACTIONS(4350),
    [anon_sym___inline] = ACTIONS(4350),
    [anon_sym___inline__] = ACTIONS(4350),
    [anon_sym___forceinline] = ACTIONS(4350),
    [anon_sym_thread_local] = ACTIONS(4350),
    [anon_sym___thread] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4350),
    [anon_sym_volatile] = ACTIONS(4350),
    [anon_sym_restrict] = ACTIONS(4350),
    [anon_sym___restrict__] = ACTIONS(4350),
    [anon_sym__Atomic] = ACTIONS(4350),
    [anon_sym__Noreturn] = ACTIONS(4350),
    [anon_sym_noreturn] = ACTIONS(4350),
    [anon_sym__Nonnull] = ACTIONS(4350),
    [anon_sym_mutable] = ACTIONS(4350),
    [anon_sym_constinit] = ACTIONS(4350),
    [anon_sym_consteval] = ACTIONS(4350),
    [anon_sym___shared__] = ACTIONS(4350),
    [anon_sym___local__] = ACTIONS(4350),
    [anon_sym___constant__] = ACTIONS(4350),
    [anon_sym___managed__] = ACTIONS(4350),
    [anon_sym___grid_constant__] = ACTIONS(4350),
    [anon_sym_alignas] = ACTIONS(4350),
    [anon_sym__Alignas] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_STAR_EQ] = ACTIONS(4352),
    [anon_sym_SLASH_EQ] = ACTIONS(4352),
    [anon_sym_PERCENT_EQ] = ACTIONS(4352),
    [anon_sym_PLUS_EQ] = ACTIONS(4352),
    [anon_sym_DASH_EQ] = ACTIONS(4352),
    [anon_sym_LT_LT_EQ] = ACTIONS(4352),
    [anon_sym_GT_GT_EQ] = ACTIONS(4352),
    [anon_sym_AMP_EQ] = ACTIONS(4352),
    [anon_sym_CARET_EQ] = ACTIONS(4352),
    [anon_sym_PIPE_EQ] = ACTIONS(4352),
    [anon_sym_and_eq] = ACTIONS(4350),
    [anon_sym_or_eq] = ACTIONS(4350),
    [anon_sym_xor_eq] = ACTIONS(4350),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_bitor] = ACTIONS(4350),
    [anon_sym_xor] = ACTIONS(4350),
    [anon_sym_bitand] = ACTIONS(4350),
    [anon_sym_not_eq] = ACTIONS(4350),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4350),
    [anon_sym_decltype] = ACTIONS(4350),
    [anon_sym_template] = ACTIONS(4350),
    [anon_sym_operator] = ACTIONS(4350),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
    [anon_sym___launch_bounds__] = ACTIONS(4350),
  },
  [STATE(930)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(933),
    [sym_compound_requirement] = STATE(933),
    [sym__requirement] = STATE(933),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(933),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4354),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(931)] = {
    [sym_identifier] = ACTIONS(4356),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_RPAREN] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_TILDE] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4356),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4356),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4356),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4358),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4356),
    [anon_sym_SEMI] = ACTIONS(4358),
    [anon_sym___extension__] = ACTIONS(4356),
    [anon_sym___device__] = ACTIONS(4356),
    [anon_sym___host__] = ACTIONS(4356),
    [anon_sym___global__] = ACTIONS(4356),
    [anon_sym___forceinline__] = ACTIONS(4356),
    [anon_sym___noinline__] = ACTIONS(4356),
    [anon_sym_virtual] = ACTIONS(4356),
    [anon_sym_extern] = ACTIONS(4356),
    [anon_sym___attribute__] = ACTIONS(4356),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4358),
    [anon_sym___declspec] = ACTIONS(4356),
    [anon_sym___based] = ACTIONS(4356),
    [anon_sym___cdecl] = ACTIONS(4356),
    [anon_sym___clrcall] = ACTIONS(4356),
    [anon_sym___stdcall] = ACTIONS(4356),
    [anon_sym___fastcall] = ACTIONS(4356),
    [anon_sym___thiscall] = ACTIONS(4356),
    [anon_sym___vectorcall] = ACTIONS(4356),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_RBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_static] = ACTIONS(4356),
    [anon_sym_EQ] = ACTIONS(4356),
    [anon_sym_register] = ACTIONS(4356),
    [anon_sym_inline] = ACTIONS(4356),
    [anon_sym___inline] = ACTIONS(4356),
    [anon_sym___inline__] = ACTIONS(4356),
    [anon_sym___forceinline] = ACTIONS(4356),
    [anon_sym_thread_local] = ACTIONS(4356),
    [anon_sym___thread] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4356),
    [anon_sym_volatile] = ACTIONS(4356),
    [anon_sym_restrict] = ACTIONS(4356),
    [anon_sym___restrict__] = ACTIONS(4356),
    [anon_sym__Atomic] = ACTIONS(4356),
    [anon_sym__Noreturn] = ACTIONS(4356),
    [anon_sym_noreturn] = ACTIONS(4356),
    [anon_sym__Nonnull] = ACTIONS(4356),
    [anon_sym_mutable] = ACTIONS(4356),
    [anon_sym_constinit] = ACTIONS(4356),
    [anon_sym_consteval] = ACTIONS(4356),
    [anon_sym___shared__] = ACTIONS(4356),
    [anon_sym___local__] = ACTIONS(4356),
    [anon_sym___constant__] = ACTIONS(4356),
    [anon_sym___managed__] = ACTIONS(4356),
    [anon_sym___grid_constant__] = ACTIONS(4356),
    [anon_sym_alignas] = ACTIONS(4356),
    [anon_sym__Alignas] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_STAR_EQ] = ACTIONS(4358),
    [anon_sym_SLASH_EQ] = ACTIONS(4358),
    [anon_sym_PERCENT_EQ] = ACTIONS(4358),
    [anon_sym_PLUS_EQ] = ACTIONS(4358),
    [anon_sym_DASH_EQ] = ACTIONS(4358),
    [anon_sym_LT_LT_EQ] = ACTIONS(4358),
    [anon_sym_GT_GT_EQ] = ACTIONS(4358),
    [anon_sym_AMP_EQ] = ACTIONS(4358),
    [anon_sym_CARET_EQ] = ACTIONS(4358),
    [anon_sym_PIPE_EQ] = ACTIONS(4358),
    [anon_sym_and_eq] = ACTIONS(4356),
    [anon_sym_or_eq] = ACTIONS(4356),
    [anon_sym_xor_eq] = ACTIONS(4356),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_bitor] = ACTIONS(4356),
    [anon_sym_xor] = ACTIONS(4356),
    [anon_sym_bitand] = ACTIONS(4356),
    [anon_sym_not_eq] = ACTIONS(4356),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4358),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4356),
    [anon_sym_decltype] = ACTIONS(4356),
    [anon_sym_template] = ACTIONS(4356),
    [anon_sym_operator] = ACTIONS(4356),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
    [anon_sym___launch_bounds__] = ACTIONS(4356),
  },
  [STATE(932)] = {
    [sym_expression] = STATE(4951),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(7849),
    [sym_initializer_pair] = STATE(7849),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_COMMA] = ACTIONS(4360),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4362),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(933)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4364),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(934)] = {
    [sym_identifier] = ACTIONS(4366),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_RPAREN] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_TILDE] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4366),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4366),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4366),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4368),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4366),
    [anon_sym_SEMI] = ACTIONS(4368),
    [anon_sym___extension__] = ACTIONS(4366),
    [anon_sym___device__] = ACTIONS(4366),
    [anon_sym___host__] = ACTIONS(4366),
    [anon_sym___global__] = ACTIONS(4366),
    [anon_sym___forceinline__] = ACTIONS(4366),
    [anon_sym___noinline__] = ACTIONS(4366),
    [anon_sym_virtual] = ACTIONS(4366),
    [anon_sym_extern] = ACTIONS(4366),
    [anon_sym___attribute__] = ACTIONS(4366),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4368),
    [anon_sym___declspec] = ACTIONS(4366),
    [anon_sym___based] = ACTIONS(4366),
    [anon_sym___cdecl] = ACTIONS(4366),
    [anon_sym___clrcall] = ACTIONS(4366),
    [anon_sym___stdcall] = ACTIONS(4366),
    [anon_sym___fastcall] = ACTIONS(4366),
    [anon_sym___thiscall] = ACTIONS(4366),
    [anon_sym___vectorcall] = ACTIONS(4366),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_RBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4366),
    [anon_sym_static] = ACTIONS(4366),
    [anon_sym_EQ] = ACTIONS(4366),
    [anon_sym_register] = ACTIONS(4366),
    [anon_sym_inline] = ACTIONS(4366),
    [anon_sym___inline] = ACTIONS(4366),
    [anon_sym___inline__] = ACTIONS(4366),
    [anon_sym___forceinline] = ACTIONS(4366),
    [anon_sym_thread_local] = ACTIONS(4366),
    [anon_sym___thread] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4366),
    [anon_sym_volatile] = ACTIONS(4366),
    [anon_sym_restrict] = ACTIONS(4366),
    [anon_sym___restrict__] = ACTIONS(4366),
    [anon_sym__Atomic] = ACTIONS(4366),
    [anon_sym__Noreturn] = ACTIONS(4366),
    [anon_sym_noreturn] = ACTIONS(4366),
    [anon_sym__Nonnull] = ACTIONS(4366),
    [anon_sym_mutable] = ACTIONS(4366),
    [anon_sym_constinit] = ACTIONS(4366),
    [anon_sym_consteval] = ACTIONS(4366),
    [anon_sym___shared__] = ACTIONS(4366),
    [anon_sym___local__] = ACTIONS(4366),
    [anon_sym___constant__] = ACTIONS(4366),
    [anon_sym___managed__] = ACTIONS(4366),
    [anon_sym___grid_constant__] = ACTIONS(4366),
    [anon_sym_alignas] = ACTIONS(4366),
    [anon_sym__Alignas] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_STAR_EQ] = ACTIONS(4368),
    [anon_sym_SLASH_EQ] = ACTIONS(4368),
    [anon_sym_PERCENT_EQ] = ACTIONS(4368),
    [anon_sym_PLUS_EQ] = ACTIONS(4368),
    [anon_sym_DASH_EQ] = ACTIONS(4368),
    [anon_sym_LT_LT_EQ] = ACTIONS(4368),
    [anon_sym_GT_GT_EQ] = ACTIONS(4368),
    [anon_sym_AMP_EQ] = ACTIONS(4368),
    [anon_sym_CARET_EQ] = ACTIONS(4368),
    [anon_sym_PIPE_EQ] = ACTIONS(4368),
    [anon_sym_and_eq] = ACTIONS(4366),
    [anon_sym_or_eq] = ACTIONS(4366),
    [anon_sym_xor_eq] = ACTIONS(4366),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_bitor] = ACTIONS(4366),
    [anon_sym_xor] = ACTIONS(4366),
    [anon_sym_bitand] = ACTIONS(4366),
    [anon_sym_not_eq] = ACTIONS(4366),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4366),
    [anon_sym_decltype] = ACTIONS(4366),
    [anon_sym_template] = ACTIONS(4366),
    [anon_sym_operator] = ACTIONS(4366),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
    [anon_sym___launch_bounds__] = ACTIONS(4366),
  },
  [STATE(935)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(938),
    [sym_compound_requirement] = STATE(938),
    [sym__requirement] = STATE(938),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(938),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4370),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(936)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(950),
    [sym_compound_requirement] = STATE(950),
    [sym__requirement] = STATE(950),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(950),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4372),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(937)] = {
    [sym_expression] = STATE(5001),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8027),
    [sym_initializer_pair] = STATE(8027),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_COMMA] = ACTIONS(4374),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4376),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(938)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4378),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(939)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(941),
    [sym_compound_requirement] = STATE(941),
    [sym__requirement] = STATE(941),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(941),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4380),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(940)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4382),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(941)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4384),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(942)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(940),
    [sym_compound_requirement] = STATE(940),
    [sym__requirement] = STATE(940),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(940),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4386),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(943)] = {
    [sym_expression] = STATE(4946),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8112),
    [sym_initializer_pair] = STATE(8112),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_COMMA] = ACTIONS(4388),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4390),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(944)] = {
    [sym_expression] = STATE(4991),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(7817),
    [sym_initializer_pair] = STATE(7817),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_COMMA] = ACTIONS(4392),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4394),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(945)] = {
    [sym_identifier] = ACTIONS(4396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_RPAREN] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_TILDE] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4396),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4396),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4396),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4398),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4396),
    [anon_sym_SEMI] = ACTIONS(4398),
    [anon_sym___extension__] = ACTIONS(4396),
    [anon_sym___device__] = ACTIONS(4396),
    [anon_sym___host__] = ACTIONS(4396),
    [anon_sym___global__] = ACTIONS(4396),
    [anon_sym___forceinline__] = ACTIONS(4396),
    [anon_sym___noinline__] = ACTIONS(4396),
    [anon_sym_virtual] = ACTIONS(4396),
    [anon_sym_extern] = ACTIONS(4396),
    [anon_sym___attribute__] = ACTIONS(4396),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4398),
    [anon_sym___declspec] = ACTIONS(4396),
    [anon_sym___based] = ACTIONS(4396),
    [anon_sym___cdecl] = ACTIONS(4396),
    [anon_sym___clrcall] = ACTIONS(4396),
    [anon_sym___stdcall] = ACTIONS(4396),
    [anon_sym___fastcall] = ACTIONS(4396),
    [anon_sym___thiscall] = ACTIONS(4396),
    [anon_sym___vectorcall] = ACTIONS(4396),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_RBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4396),
    [anon_sym_static] = ACTIONS(4396),
    [anon_sym_EQ] = ACTIONS(4396),
    [anon_sym_register] = ACTIONS(4396),
    [anon_sym_inline] = ACTIONS(4396),
    [anon_sym___inline] = ACTIONS(4396),
    [anon_sym___inline__] = ACTIONS(4396),
    [anon_sym___forceinline] = ACTIONS(4396),
    [anon_sym_thread_local] = ACTIONS(4396),
    [anon_sym___thread] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4396),
    [anon_sym_volatile] = ACTIONS(4396),
    [anon_sym_restrict] = ACTIONS(4396),
    [anon_sym___restrict__] = ACTIONS(4396),
    [anon_sym__Atomic] = ACTIONS(4396),
    [anon_sym__Noreturn] = ACTIONS(4396),
    [anon_sym_noreturn] = ACTIONS(4396),
    [anon_sym__Nonnull] = ACTIONS(4396),
    [anon_sym_mutable] = ACTIONS(4396),
    [anon_sym_constinit] = ACTIONS(4396),
    [anon_sym_consteval] = ACTIONS(4396),
    [anon_sym___shared__] = ACTIONS(4396),
    [anon_sym___local__] = ACTIONS(4396),
    [anon_sym___constant__] = ACTIONS(4396),
    [anon_sym___managed__] = ACTIONS(4396),
    [anon_sym___grid_constant__] = ACTIONS(4396),
    [anon_sym_alignas] = ACTIONS(4396),
    [anon_sym__Alignas] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_STAR_EQ] = ACTIONS(4398),
    [anon_sym_SLASH_EQ] = ACTIONS(4398),
    [anon_sym_PERCENT_EQ] = ACTIONS(4398),
    [anon_sym_PLUS_EQ] = ACTIONS(4398),
    [anon_sym_DASH_EQ] = ACTIONS(4398),
    [anon_sym_LT_LT_EQ] = ACTIONS(4398),
    [anon_sym_GT_GT_EQ] = ACTIONS(4398),
    [anon_sym_AMP_EQ] = ACTIONS(4398),
    [anon_sym_CARET_EQ] = ACTIONS(4398),
    [anon_sym_PIPE_EQ] = ACTIONS(4398),
    [anon_sym_and_eq] = ACTIONS(4396),
    [anon_sym_or_eq] = ACTIONS(4396),
    [anon_sym_xor_eq] = ACTIONS(4396),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_bitor] = ACTIONS(4396),
    [anon_sym_xor] = ACTIONS(4396),
    [anon_sym_bitand] = ACTIONS(4396),
    [anon_sym_not_eq] = ACTIONS(4396),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4396),
    [anon_sym_decltype] = ACTIONS(4396),
    [anon_sym_template] = ACTIONS(4396),
    [anon_sym_operator] = ACTIONS(4396),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
    [anon_sym___launch_bounds__] = ACTIONS(4396),
  },
  [STATE(946)] = {
    [sym_expression] = STATE(4945),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8075),
    [sym_initializer_pair] = STATE(8075),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_COMMA] = ACTIONS(169),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4400),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(947)] = {
    [sym_identifier] = ACTIONS(4402),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_RPAREN] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_TILDE] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4402),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4402),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4402),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4404),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4402),
    [anon_sym_SEMI] = ACTIONS(4404),
    [anon_sym___extension__] = ACTIONS(4402),
    [anon_sym___device__] = ACTIONS(4402),
    [anon_sym___host__] = ACTIONS(4402),
    [anon_sym___global__] = ACTIONS(4402),
    [anon_sym___forceinline__] = ACTIONS(4402),
    [anon_sym___noinline__] = ACTIONS(4402),
    [anon_sym_virtual] = ACTIONS(4402),
    [anon_sym_extern] = ACTIONS(4402),
    [anon_sym___attribute__] = ACTIONS(4402),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4404),
    [anon_sym___declspec] = ACTIONS(4402),
    [anon_sym___based] = ACTIONS(4402),
    [anon_sym___cdecl] = ACTIONS(4402),
    [anon_sym___clrcall] = ACTIONS(4402),
    [anon_sym___stdcall] = ACTIONS(4402),
    [anon_sym___fastcall] = ACTIONS(4402),
    [anon_sym___thiscall] = ACTIONS(4402),
    [anon_sym___vectorcall] = ACTIONS(4402),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_RBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4402),
    [anon_sym_static] = ACTIONS(4402),
    [anon_sym_EQ] = ACTIONS(4402),
    [anon_sym_register] = ACTIONS(4402),
    [anon_sym_inline] = ACTIONS(4402),
    [anon_sym___inline] = ACTIONS(4402),
    [anon_sym___inline__] = ACTIONS(4402),
    [anon_sym___forceinline] = ACTIONS(4402),
    [anon_sym_thread_local] = ACTIONS(4402),
    [anon_sym___thread] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4402),
    [anon_sym_volatile] = ACTIONS(4402),
    [anon_sym_restrict] = ACTIONS(4402),
    [anon_sym___restrict__] = ACTIONS(4402),
    [anon_sym__Atomic] = ACTIONS(4402),
    [anon_sym__Noreturn] = ACTIONS(4402),
    [anon_sym_noreturn] = ACTIONS(4402),
    [anon_sym__Nonnull] = ACTIONS(4402),
    [anon_sym_mutable] = ACTIONS(4402),
    [anon_sym_constinit] = ACTIONS(4402),
    [anon_sym_consteval] = ACTIONS(4402),
    [anon_sym___shared__] = ACTIONS(4402),
    [anon_sym___local__] = ACTIONS(4402),
    [anon_sym___constant__] = ACTIONS(4402),
    [anon_sym___managed__] = ACTIONS(4402),
    [anon_sym___grid_constant__] = ACTIONS(4402),
    [anon_sym_alignas] = ACTIONS(4402),
    [anon_sym__Alignas] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_STAR_EQ] = ACTIONS(4404),
    [anon_sym_SLASH_EQ] = ACTIONS(4404),
    [anon_sym_PERCENT_EQ] = ACTIONS(4404),
    [anon_sym_PLUS_EQ] = ACTIONS(4404),
    [anon_sym_DASH_EQ] = ACTIONS(4404),
    [anon_sym_LT_LT_EQ] = ACTIONS(4404),
    [anon_sym_GT_GT_EQ] = ACTIONS(4404),
    [anon_sym_AMP_EQ] = ACTIONS(4404),
    [anon_sym_CARET_EQ] = ACTIONS(4404),
    [anon_sym_PIPE_EQ] = ACTIONS(4404),
    [anon_sym_and_eq] = ACTIONS(4402),
    [anon_sym_or_eq] = ACTIONS(4402),
    [anon_sym_xor_eq] = ACTIONS(4402),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_bitor] = ACTIONS(4402),
    [anon_sym_xor] = ACTIONS(4402),
    [anon_sym_bitand] = ACTIONS(4402),
    [anon_sym_not_eq] = ACTIONS(4402),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4402),
    [anon_sym_decltype] = ACTIONS(4402),
    [anon_sym_template] = ACTIONS(4402),
    [anon_sym_operator] = ACTIONS(4402),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
    [anon_sym___launch_bounds__] = ACTIONS(4402),
  },
  [STATE(948)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(952),
    [sym_compound_requirement] = STATE(952),
    [sym__requirement] = STATE(952),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(952),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4406),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(949)] = {
    [sym_identifier] = ACTIONS(4408),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_RPAREN] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_TILDE] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4408),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4408),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4408),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4410),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4408),
    [anon_sym_SEMI] = ACTIONS(4410),
    [anon_sym___extension__] = ACTIONS(4408),
    [anon_sym___device__] = ACTIONS(4408),
    [anon_sym___host__] = ACTIONS(4408),
    [anon_sym___global__] = ACTIONS(4408),
    [anon_sym___forceinline__] = ACTIONS(4408),
    [anon_sym___noinline__] = ACTIONS(4408),
    [anon_sym_virtual] = ACTIONS(4408),
    [anon_sym_extern] = ACTIONS(4408),
    [anon_sym___attribute__] = ACTIONS(4408),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4410),
    [anon_sym___declspec] = ACTIONS(4408),
    [anon_sym___based] = ACTIONS(4408),
    [anon_sym___cdecl] = ACTIONS(4408),
    [anon_sym___clrcall] = ACTIONS(4408),
    [anon_sym___stdcall] = ACTIONS(4408),
    [anon_sym___fastcall] = ACTIONS(4408),
    [anon_sym___thiscall] = ACTIONS(4408),
    [anon_sym___vectorcall] = ACTIONS(4408),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_RBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4408),
    [anon_sym_static] = ACTIONS(4408),
    [anon_sym_EQ] = ACTIONS(4408),
    [anon_sym_register] = ACTIONS(4408),
    [anon_sym_inline] = ACTIONS(4408),
    [anon_sym___inline] = ACTIONS(4408),
    [anon_sym___inline__] = ACTIONS(4408),
    [anon_sym___forceinline] = ACTIONS(4408),
    [anon_sym_thread_local] = ACTIONS(4408),
    [anon_sym___thread] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4408),
    [anon_sym_volatile] = ACTIONS(4408),
    [anon_sym_restrict] = ACTIONS(4408),
    [anon_sym___restrict__] = ACTIONS(4408),
    [anon_sym__Atomic] = ACTIONS(4408),
    [anon_sym__Noreturn] = ACTIONS(4408),
    [anon_sym_noreturn] = ACTIONS(4408),
    [anon_sym__Nonnull] = ACTIONS(4408),
    [anon_sym_mutable] = ACTIONS(4408),
    [anon_sym_constinit] = ACTIONS(4408),
    [anon_sym_consteval] = ACTIONS(4408),
    [anon_sym___shared__] = ACTIONS(4408),
    [anon_sym___local__] = ACTIONS(4408),
    [anon_sym___constant__] = ACTIONS(4408),
    [anon_sym___managed__] = ACTIONS(4408),
    [anon_sym___grid_constant__] = ACTIONS(4408),
    [anon_sym_alignas] = ACTIONS(4408),
    [anon_sym__Alignas] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_STAR_EQ] = ACTIONS(4410),
    [anon_sym_SLASH_EQ] = ACTIONS(4410),
    [anon_sym_PERCENT_EQ] = ACTIONS(4410),
    [anon_sym_PLUS_EQ] = ACTIONS(4410),
    [anon_sym_DASH_EQ] = ACTIONS(4410),
    [anon_sym_LT_LT_EQ] = ACTIONS(4410),
    [anon_sym_GT_GT_EQ] = ACTIONS(4410),
    [anon_sym_AMP_EQ] = ACTIONS(4410),
    [anon_sym_CARET_EQ] = ACTIONS(4410),
    [anon_sym_PIPE_EQ] = ACTIONS(4410),
    [anon_sym_and_eq] = ACTIONS(4408),
    [anon_sym_or_eq] = ACTIONS(4408),
    [anon_sym_xor_eq] = ACTIONS(4408),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_bitor] = ACTIONS(4408),
    [anon_sym_xor] = ACTIONS(4408),
    [anon_sym_bitand] = ACTIONS(4408),
    [anon_sym_not_eq] = ACTIONS(4408),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4408),
    [anon_sym_decltype] = ACTIONS(4408),
    [anon_sym_template] = ACTIONS(4408),
    [anon_sym_operator] = ACTIONS(4408),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
    [anon_sym___launch_bounds__] = ACTIONS(4408),
  },
  [STATE(950)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4412),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(951)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(4414),
    [anon_sym_LPAREN2] = ACTIONS(4417),
    [anon_sym_BANG] = ACTIONS(4420),
    [anon_sym_TILDE] = ACTIONS(4420),
    [anon_sym_DASH] = ACTIONS(4423),
    [anon_sym_PLUS] = ACTIONS(4423),
    [anon_sym_STAR] = ACTIONS(4426),
    [anon_sym_AMP] = ACTIONS(4426),
    [anon_sym_SEMI] = ACTIONS(4429),
    [anon_sym___extension__] = ACTIONS(4432),
    [anon_sym_COLON_COLON] = ACTIONS(4435),
    [anon_sym_LBRACE] = ACTIONS(4438),
    [anon_sym_RBRACE] = ACTIONS(4441),
    [anon_sym_LBRACK] = ACTIONS(4443),
    [sym_primitive_type] = ACTIONS(4446),
    [anon_sym_not] = ACTIONS(4423),
    [anon_sym_compl] = ACTIONS(4423),
    [anon_sym_DASH_DASH] = ACTIONS(4449),
    [anon_sym_PLUS_PLUS] = ACTIONS(4449),
    [anon_sym_sizeof] = ACTIONS(4452),
    [anon_sym___alignof__] = ACTIONS(4455),
    [anon_sym___alignof] = ACTIONS(4455),
    [anon_sym__alignof] = ACTIONS(4455),
    [anon_sym_alignof] = ACTIONS(4455),
    [anon_sym__Alignof] = ACTIONS(4455),
    [anon_sym_offsetof] = ACTIONS(4458),
    [anon_sym__Generic] = ACTIONS(4461),
    [anon_sym_asm] = ACTIONS(4464),
    [anon_sym___asm__] = ACTIONS(4464),
    [anon_sym___asm] = ACTIONS(4464),
    [sym_number_literal] = ACTIONS(4467),
    [anon_sym_L_SQUOTE] = ACTIONS(4470),
    [anon_sym_u_SQUOTE] = ACTIONS(4470),
    [anon_sym_U_SQUOTE] = ACTIONS(4470),
    [anon_sym_u8_SQUOTE] = ACTIONS(4470),
    [anon_sym_SQUOTE] = ACTIONS(4470),
    [anon_sym_L_DQUOTE] = ACTIONS(4473),
    [anon_sym_u_DQUOTE] = ACTIONS(4473),
    [anon_sym_U_DQUOTE] = ACTIONS(4473),
    [anon_sym_u8_DQUOTE] = ACTIONS(4473),
    [anon_sym_DQUOTE] = ACTIONS(4473),
    [sym_true] = ACTIONS(4476),
    [sym_false] = ACTIONS(4476),
    [anon_sym_NULL] = ACTIONS(4479),
    [anon_sym_nullptr] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(4482),
    [anon_sym_typename] = ACTIONS(4485),
    [anon_sym_template] = ACTIONS(4488),
    [anon_sym_delete] = ACTIONS(4491),
    [anon_sym_R_DQUOTE] = ACTIONS(4494),
    [anon_sym_LR_DQUOTE] = ACTIONS(4494),
    [anon_sym_uR_DQUOTE] = ACTIONS(4494),
    [anon_sym_UR_DQUOTE] = ACTIONS(4494),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4494),
    [anon_sym_co_await] = ACTIONS(4497),
    [anon_sym_new] = ACTIONS(4500),
    [anon_sym_requires] = ACTIONS(4503),
    [sym_this] = ACTIONS(4476),
  },
  [STATE(952)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4506),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(953)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(959),
    [sym_compound_requirement] = STATE(959),
    [sym__requirement] = STATE(959),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(959),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4508),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(954)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(922),
    [sym_compound_requirement] = STATE(922),
    [sym__requirement] = STATE(922),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(922),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4510),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(955)] = {
    [sym_template_argument_list] = STATE(967),
    [sym_identifier] = ACTIONS(4512),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4514),
    [anon_sym_COMMA] = ACTIONS(4514),
    [anon_sym_LPAREN2] = ACTIONS(4516),
    [anon_sym_TILDE] = ACTIONS(4519),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4523),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4516),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4523),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4514),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4526),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym_SEMI] = ACTIONS(4516),
    [anon_sym___extension__] = ACTIONS(4512),
    [anon_sym___device__] = ACTIONS(4512),
    [anon_sym___host__] = ACTIONS(4512),
    [anon_sym___global__] = ACTIONS(4512),
    [anon_sym___forceinline__] = ACTIONS(4512),
    [anon_sym___noinline__] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym___attribute__] = ACTIONS(4512),
    [anon_sym___attribute] = ACTIONS(4512),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4516),
    [anon_sym___declspec] = ACTIONS(4512),
    [anon_sym___based] = ACTIONS(4512),
    [anon_sym___cdecl] = ACTIONS(4512),
    [anon_sym___clrcall] = ACTIONS(4512),
    [anon_sym___stdcall] = ACTIONS(4512),
    [anon_sym___fastcall] = ACTIONS(4512),
    [anon_sym___thiscall] = ACTIONS(4512),
    [anon_sym___vectorcall] = ACTIONS(4512),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_RBRACE] = ACTIONS(4514),
    [anon_sym_LBRACK] = ACTIONS(4523),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_EQ] = ACTIONS(4521),
    [anon_sym_register] = ACTIONS(4512),
    [anon_sym_inline] = ACTIONS(4512),
    [anon_sym___inline] = ACTIONS(4512),
    [anon_sym___inline__] = ACTIONS(4512),
    [anon_sym___forceinline] = ACTIONS(4512),
    [anon_sym_thread_local] = ACTIONS(4512),
    [anon_sym___thread] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4512),
    [anon_sym_volatile] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym___restrict__] = ACTIONS(4512),
    [anon_sym__Atomic] = ACTIONS(4512),
    [anon_sym__Noreturn] = ACTIONS(4512),
    [anon_sym_noreturn] = ACTIONS(4512),
    [anon_sym__Nonnull] = ACTIONS(4512),
    [anon_sym_mutable] = ACTIONS(4512),
    [anon_sym_constinit] = ACTIONS(4512),
    [anon_sym_consteval] = ACTIONS(4512),
    [anon_sym___shared__] = ACTIONS(4512),
    [anon_sym___local__] = ACTIONS(4512),
    [anon_sym___constant__] = ACTIONS(4512),
    [anon_sym___managed__] = ACTIONS(4512),
    [anon_sym___grid_constant__] = ACTIONS(4512),
    [anon_sym_alignas] = ACTIONS(4512),
    [anon_sym__Alignas] = ACTIONS(4512),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4514),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4521),
    [anon_sym_or_eq] = ACTIONS(4521),
    [anon_sym_xor_eq] = ACTIONS(4521),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4521),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4521),
    [anon_sym_not_eq] = ACTIONS(4521),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4514),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4512),
    [anon_sym_decltype] = ACTIONS(4512),
    [anon_sym_template] = ACTIONS(4512),
    [anon_sym_operator] = ACTIONS(4512),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
    [anon_sym___launch_bounds__] = ACTIONS(4512),
  },
  [STATE(956)] = {
    [sym_expression] = STATE(4994),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8166),
    [sym_initializer_pair] = STATE(8166),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_COMMA] = ACTIONS(4529),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4531),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(957)] = {
    [sym_expression] = STATE(4993),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8104),
    [sym_initializer_pair] = STATE(8104),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_COMMA] = ACTIONS(4533),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4535),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(958)] = {
    [sym_expression] = STATE(4992),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(7992),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4537),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(959)] = {
    [sym_expression_statement] = STATE(3103),
    [sym_expression] = STATE(5121),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9131),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_type_requirement] = STATE(951),
    [sym_compound_requirement] = STATE(951),
    [sym__requirement] = STATE(951),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_requirement_seq_repeat1] = STATE(951),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4320),
    [anon_sym_RBRACE] = ACTIONS(4539),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_typename] = ACTIONS(4324),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(960)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4541),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(961)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4537),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(962)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4543),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(963)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4545),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(964)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4547),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(965)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4549),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(966)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4551),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(967)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4555),
    [anon_sym_COMMA] = ACTIONS(4555),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym_SEMI] = ACTIONS(4557),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4557),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym___cdecl] = ACTIONS(4553),
    [anon_sym___clrcall] = ACTIONS(4553),
    [anon_sym___stdcall] = ACTIONS(4553),
    [anon_sym___fastcall] = ACTIONS(4553),
    [anon_sym___thiscall] = ACTIONS(4553),
    [anon_sym___vectorcall] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_RBRACE] = ACTIONS(4555),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_EQ] = ACTIONS(4562),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4562),
    [anon_sym_or_eq] = ACTIONS(4562),
    [anon_sym_xor_eq] = ACTIONS(4562),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_operator] = ACTIONS(4553),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(968)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4567),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(969)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4569),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(970)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4571),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(971)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4573),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(972)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4575),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(973)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(974)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(975)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4581),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(976)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_RBRACE] = ACTIONS(4583),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(977)] = {
    [sym_expression] = STATE(5203),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8285),
    [sym_initializer_pair] = STATE(8285),
    [sym_subscript_designator] = STATE(7358),
    [sym_subscript_range_designator] = STATE(7358),
    [sym_field_designator] = STATE(7358),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [aux_sym_initializer_pair_repeat1] = STATE(7358),
    [sym_identifier] = ACTIONS(4334),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(4340),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(219),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(978)] = {
    [sym_expression] = STATE(5273),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_lambda_default_capture] = STATE(8280),
    [sym__lambda_capture_identifier] = STATE(7899),
    [sym_lambda_capture_initializer] = STATE(7899),
    [sym__lambda_capture] = STATE(7899),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_identifier_parameter_pack_expansion] = STATE(7899),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4262),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4585),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4587),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4589),
    [anon_sym_AMP] = ACTIONS(4591),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4593),
    [anon_sym_EQ] = ACTIONS(4595),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(4597),
  },
  [STATE(979)] = {
    [sym_expression] = STATE(5273),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_lambda_default_capture] = STATE(8280),
    [sym__lambda_capture_identifier] = STATE(7899),
    [sym_lambda_capture_initializer] = STATE(7899),
    [sym__lambda_capture] = STATE(7899),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_identifier_parameter_pack_expansion] = STATE(7899),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4262),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4599),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4587),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4589),
    [anon_sym_AMP] = ACTIONS(4591),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4593),
    [anon_sym_EQ] = ACTIONS(4595),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(4597),
  },
  [STATE(980)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_ms_call_modifier] = STATE(6972),
    [sym__abstract_declarator] = STATE(7470),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_list] = STATE(2996),
    [sym_parameter_declaration] = STATE(8202),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(8202),
    [sym_variadic_parameter_declaration] = STATE(8202),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1846),
    [anon_sym_RPAREN] = ACTIONS(4195),
    [anon_sym_LPAREN2] = ACTIONS(4603),
    [anon_sym_STAR] = ACTIONS(4605),
    [anon_sym_AMP_AMP] = ACTIONS(4607),
    [anon_sym_AMP] = ACTIONS(4609),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(1870),
    [anon_sym___clrcall] = ACTIONS(1870),
    [anon_sym___stdcall] = ACTIONS(1870),
    [anon_sym___fastcall] = ACTIONS(1870),
    [anon_sym___thiscall] = ACTIONS(1870),
    [anon_sym___vectorcall] = ACTIONS(1870),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(4613),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(981)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_ms_call_modifier] = STATE(6949),
    [sym__abstract_declarator] = STATE(7441),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_list] = STATE(2996),
    [sym_parameter_declaration] = STATE(8202),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(8202),
    [sym_variadic_parameter_declaration] = STATE(8202),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1846),
    [anon_sym_RPAREN] = ACTIONS(4195),
    [anon_sym_LPAREN2] = ACTIONS(4603),
    [anon_sym_STAR] = ACTIONS(4605),
    [anon_sym_AMP_AMP] = ACTIONS(4607),
    [anon_sym_AMP] = ACTIONS(4609),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(1870),
    [anon_sym___clrcall] = ACTIONS(1870),
    [anon_sym___stdcall] = ACTIONS(1870),
    [anon_sym___fastcall] = ACTIONS(1870),
    [anon_sym___thiscall] = ACTIONS(1870),
    [anon_sym___vectorcall] = ACTIONS(1870),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(4613),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(982)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5864),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7297),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_parameter_list] = STATE(813),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(3773),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6270),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4615),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_LT] = ACTIONS(4617),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(983)] = {
    [sym_template_argument_list] = STATE(991),
    [sym_identifier] = ACTIONS(4512),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4514),
    [anon_sym_COMMA] = ACTIONS(4514),
    [anon_sym_RPAREN] = ACTIONS(4514),
    [anon_sym_LPAREN2] = ACTIONS(4516),
    [anon_sym_TILDE] = ACTIONS(4519),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4523),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4516),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4523),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4514),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4526),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym_SEMI] = ACTIONS(4514),
    [anon_sym___extension__] = ACTIONS(4512),
    [anon_sym___device__] = ACTIONS(4512),
    [anon_sym___host__] = ACTIONS(4512),
    [anon_sym___global__] = ACTIONS(4512),
    [anon_sym___forceinline__] = ACTIONS(4512),
    [anon_sym___noinline__] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym___attribute__] = ACTIONS(4512),
    [anon_sym___attribute] = ACTIONS(4512),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4519),
    [anon_sym___declspec] = ACTIONS(4512),
    [anon_sym___based] = ACTIONS(4512),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_RBRACE] = ACTIONS(4514),
    [anon_sym_LBRACK] = ACTIONS(4523),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_EQ] = ACTIONS(4521),
    [anon_sym_register] = ACTIONS(4512),
    [anon_sym_inline] = ACTIONS(4512),
    [anon_sym___inline] = ACTIONS(4512),
    [anon_sym___inline__] = ACTIONS(4512),
    [anon_sym___forceinline] = ACTIONS(4512),
    [anon_sym_thread_local] = ACTIONS(4512),
    [anon_sym___thread] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4512),
    [anon_sym_volatile] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym___restrict__] = ACTIONS(4512),
    [anon_sym__Atomic] = ACTIONS(4512),
    [anon_sym__Noreturn] = ACTIONS(4512),
    [anon_sym_noreturn] = ACTIONS(4512),
    [anon_sym__Nonnull] = ACTIONS(4512),
    [anon_sym_mutable] = ACTIONS(4512),
    [anon_sym_constinit] = ACTIONS(4512),
    [anon_sym_consteval] = ACTIONS(4512),
    [anon_sym___shared__] = ACTIONS(4512),
    [anon_sym___local__] = ACTIONS(4512),
    [anon_sym___constant__] = ACTIONS(4512),
    [anon_sym___managed__] = ACTIONS(4512),
    [anon_sym___grid_constant__] = ACTIONS(4512),
    [anon_sym_alignas] = ACTIONS(4512),
    [anon_sym__Alignas] = ACTIONS(4512),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4514),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4521),
    [anon_sym_or_eq] = ACTIONS(4521),
    [anon_sym_xor_eq] = ACTIONS(4521),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4521),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4521),
    [anon_sym_not_eq] = ACTIONS(4521),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4514),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4512),
    [anon_sym_decltype] = ACTIONS(4512),
    [anon_sym_template] = ACTIONS(4512),
    [anon_sym_operator] = ACTIONS(4512),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
    [anon_sym___launch_bounds__] = ACTIONS(4512),
  },
  [STATE(984)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5881),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7259),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_parameter_list] = STATE(811),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(3773),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6270),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4615),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_LT] = ACTIONS(4617),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(985)] = {
    [sym_identifier] = ACTIONS(2110),
    [anon_sym_LPAREN2] = ACTIONS(2115),
    [anon_sym_BANG] = ACTIONS(2115),
    [anon_sym_TILDE] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2110),
    [anon_sym_PLUS] = ACTIONS(2110),
    [anon_sym_STAR] = ACTIONS(2115),
    [anon_sym_AMP] = ACTIONS(2115),
    [anon_sym___extension__] = ACTIONS(2110),
    [anon_sym___device__] = ACTIONS(2110),
    [anon_sym___host__] = ACTIONS(2110),
    [anon_sym___global__] = ACTIONS(2110),
    [anon_sym___forceinline__] = ACTIONS(2110),
    [anon_sym___noinline__] = ACTIONS(2110),
    [anon_sym_virtual] = ACTIONS(2110),
    [anon_sym_extern] = ACTIONS(2110),
    [anon_sym___attribute__] = ACTIONS(2110),
    [anon_sym___attribute] = ACTIONS(2110),
    [anon_sym_COLON_COLON] = ACTIONS(2115),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2115),
    [anon_sym___declspec] = ACTIONS(2110),
    [anon_sym_signed] = ACTIONS(2110),
    [anon_sym_unsigned] = ACTIONS(2110),
    [anon_sym_long] = ACTIONS(2110),
    [anon_sym_short] = ACTIONS(2110),
    [anon_sym_LBRACK] = ACTIONS(2110),
    [anon_sym_static] = ACTIONS(2110),
    [anon_sym_register] = ACTIONS(2110),
    [anon_sym_inline] = ACTIONS(2110),
    [anon_sym___inline] = ACTIONS(2110),
    [anon_sym___inline__] = ACTIONS(2110),
    [anon_sym___forceinline] = ACTIONS(2110),
    [anon_sym_thread_local] = ACTIONS(2110),
    [anon_sym___thread] = ACTIONS(2110),
    [anon_sym_const] = ACTIONS(2110),
    [anon_sym_constexpr] = ACTIONS(2110),
    [anon_sym_volatile] = ACTIONS(2110),
    [anon_sym_restrict] = ACTIONS(2110),
    [anon_sym___restrict__] = ACTIONS(2110),
    [anon_sym__Atomic] = ACTIONS(2110),
    [anon_sym__Noreturn] = ACTIONS(2110),
    [anon_sym_noreturn] = ACTIONS(2110),
    [anon_sym__Nonnull] = ACTIONS(2110),
    [anon_sym_mutable] = ACTIONS(2110),
    [anon_sym_constinit] = ACTIONS(2110),
    [anon_sym_consteval] = ACTIONS(2110),
    [anon_sym___shared__] = ACTIONS(2110),
    [anon_sym___local__] = ACTIONS(2110),
    [anon_sym___constant__] = ACTIONS(2110),
    [anon_sym___managed__] = ACTIONS(2110),
    [anon_sym___grid_constant__] = ACTIONS(2110),
    [anon_sym_alignas] = ACTIONS(2110),
    [anon_sym__Alignas] = ACTIONS(2110),
    [sym_primitive_type] = ACTIONS(2110),
    [anon_sym_enum] = ACTIONS(2110),
    [anon_sym_class] = ACTIONS(2110),
    [anon_sym_struct] = ACTIONS(2110),
    [anon_sym_union] = ACTIONS(2110),
    [anon_sym_not] = ACTIONS(2110),
    [anon_sym_compl] = ACTIONS(2110),
    [anon_sym_DASH_DASH] = ACTIONS(2115),
    [anon_sym_PLUS_PLUS] = ACTIONS(2115),
    [anon_sym_sizeof] = ACTIONS(2110),
    [anon_sym___alignof__] = ACTIONS(2110),
    [anon_sym___alignof] = ACTIONS(2110),
    [anon_sym__alignof] = ACTIONS(2110),
    [anon_sym_alignof] = ACTIONS(2110),
    [anon_sym__Alignof] = ACTIONS(2110),
    [anon_sym_offsetof] = ACTIONS(2110),
    [anon_sym__Generic] = ACTIONS(2110),
    [anon_sym_asm] = ACTIONS(2110),
    [anon_sym___asm__] = ACTIONS(2110),
    [anon_sym___asm] = ACTIONS(2110),
    [sym_number_literal] = ACTIONS(2115),
    [anon_sym_L_SQUOTE] = ACTIONS(2115),
    [anon_sym_u_SQUOTE] = ACTIONS(2115),
    [anon_sym_U_SQUOTE] = ACTIONS(2115),
    [anon_sym_u8_SQUOTE] = ACTIONS(2115),
    [anon_sym_SQUOTE] = ACTIONS(2115),
    [anon_sym_L_DQUOTE] = ACTIONS(2115),
    [anon_sym_u_DQUOTE] = ACTIONS(2115),
    [anon_sym_U_DQUOTE] = ACTIONS(2115),
    [anon_sym_u8_DQUOTE] = ACTIONS(2115),
    [anon_sym_DQUOTE] = ACTIONS(2115),
    [sym_true] = ACTIONS(2110),
    [sym_false] = ACTIONS(2110),
    [anon_sym_NULL] = ACTIONS(2110),
    [anon_sym_nullptr] = ACTIONS(2110),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2110),
    [anon_sym_decltype] = ACTIONS(2110),
    [anon_sym_typename] = ACTIONS(2110),
    [anon_sym_template] = ACTIONS(2110),
    [anon_sym_delete] = ACTIONS(2110),
    [anon_sym_R_DQUOTE] = ACTIONS(2115),
    [anon_sym_LR_DQUOTE] = ACTIONS(2115),
    [anon_sym_uR_DQUOTE] = ACTIONS(2115),
    [anon_sym_UR_DQUOTE] = ACTIONS(2115),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2115),
    [anon_sym_co_await] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(2110),
    [anon_sym_requires] = ACTIONS(2110),
    [sym_this] = ACTIONS(2110),
    [anon_sym___launch_bounds__] = ACTIONS(2110),
  },
  [STATE(986)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5880),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7236),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_parameter_list] = STATE(808),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(3773),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6270),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4615),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_LT] = ACTIONS(4617),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(987)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5868),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7240),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6660),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_parameter_list] = STATE(809),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(3773),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6270),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4615),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_LT] = ACTIONS(4617),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(988)] = {
    [sym_identifier] = ACTIONS(2595),
    [anon_sym_LPAREN2] = ACTIONS(2597),
    [anon_sym_BANG] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_DASH] = ACTIONS(2595),
    [anon_sym_PLUS] = ACTIONS(2595),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_AMP] = ACTIONS(2597),
    [anon_sym___extension__] = ACTIONS(2595),
    [anon_sym___device__] = ACTIONS(2595),
    [anon_sym___host__] = ACTIONS(2595),
    [anon_sym___global__] = ACTIONS(2595),
    [anon_sym___forceinline__] = ACTIONS(2595),
    [anon_sym___noinline__] = ACTIONS(2595),
    [anon_sym_virtual] = ACTIONS(2595),
    [anon_sym_extern] = ACTIONS(2595),
    [anon_sym___attribute__] = ACTIONS(2595),
    [anon_sym___attribute] = ACTIONS(2595),
    [anon_sym_COLON_COLON] = ACTIONS(2597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2597),
    [anon_sym___declspec] = ACTIONS(2595),
    [anon_sym_signed] = ACTIONS(2595),
    [anon_sym_unsigned] = ACTIONS(2595),
    [anon_sym_long] = ACTIONS(2595),
    [anon_sym_short] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_register] = ACTIONS(2595),
    [anon_sym_inline] = ACTIONS(2595),
    [anon_sym___inline] = ACTIONS(2595),
    [anon_sym___inline__] = ACTIONS(2595),
    [anon_sym___forceinline] = ACTIONS(2595),
    [anon_sym_thread_local] = ACTIONS(2595),
    [anon_sym___thread] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_constexpr] = ACTIONS(2595),
    [anon_sym_volatile] = ACTIONS(2595),
    [anon_sym_restrict] = ACTIONS(2595),
    [anon_sym___restrict__] = ACTIONS(2595),
    [anon_sym__Atomic] = ACTIONS(2595),
    [anon_sym__Noreturn] = ACTIONS(2595),
    [anon_sym_noreturn] = ACTIONS(2595),
    [anon_sym__Nonnull] = ACTIONS(2595),
    [anon_sym_mutable] = ACTIONS(2595),
    [anon_sym_constinit] = ACTIONS(2595),
    [anon_sym_consteval] = ACTIONS(2595),
    [anon_sym___shared__] = ACTIONS(2595),
    [anon_sym___local__] = ACTIONS(2595),
    [anon_sym___constant__] = ACTIONS(2595),
    [anon_sym___managed__] = ACTIONS(2595),
    [anon_sym___grid_constant__] = ACTIONS(2595),
    [anon_sym_alignas] = ACTIONS(2595),
    [anon_sym__Alignas] = ACTIONS(2595),
    [sym_primitive_type] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_struct] = ACTIONS(2595),
    [anon_sym_union] = ACTIONS(2595),
    [anon_sym_not] = ACTIONS(2595),
    [anon_sym_compl] = ACTIONS(2595),
    [anon_sym_DASH_DASH] = ACTIONS(2597),
    [anon_sym_PLUS_PLUS] = ACTIONS(2597),
    [anon_sym_sizeof] = ACTIONS(2595),
    [anon_sym___alignof__] = ACTIONS(2595),
    [anon_sym___alignof] = ACTIONS(2595),
    [anon_sym__alignof] = ACTIONS(2595),
    [anon_sym_alignof] = ACTIONS(2595),
    [anon_sym__Alignof] = ACTIONS(2595),
    [anon_sym_offsetof] = ACTIONS(2595),
    [anon_sym__Generic] = ACTIONS(2595),
    [anon_sym_asm] = ACTIONS(2595),
    [anon_sym___asm__] = ACTIONS(2595),
    [anon_sym___asm] = ACTIONS(2595),
    [sym_number_literal] = ACTIONS(2597),
    [anon_sym_L_SQUOTE] = ACTIONS(2597),
    [anon_sym_u_SQUOTE] = ACTIONS(2597),
    [anon_sym_U_SQUOTE] = ACTIONS(2597),
    [anon_sym_u8_SQUOTE] = ACTIONS(2597),
    [anon_sym_SQUOTE] = ACTIONS(2597),
    [anon_sym_L_DQUOTE] = ACTIONS(2597),
    [anon_sym_u_DQUOTE] = ACTIONS(2597),
    [anon_sym_U_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8_DQUOTE] = ACTIONS(2597),
    [anon_sym_DQUOTE] = ACTIONS(2597),
    [sym_true] = ACTIONS(2595),
    [sym_false] = ACTIONS(2595),
    [anon_sym_NULL] = ACTIONS(2595),
    [anon_sym_nullptr] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2595),
    [anon_sym_decltype] = ACTIONS(2595),
    [anon_sym_typename] = ACTIONS(2595),
    [anon_sym_template] = ACTIONS(2595),
    [anon_sym_delete] = ACTIONS(2595),
    [anon_sym_R_DQUOTE] = ACTIONS(2597),
    [anon_sym_LR_DQUOTE] = ACTIONS(2597),
    [anon_sym_uR_DQUOTE] = ACTIONS(2597),
    [anon_sym_UR_DQUOTE] = ACTIONS(2597),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2597),
    [anon_sym_co_await] = ACTIONS(2595),
    [anon_sym_new] = ACTIONS(2595),
    [anon_sym_requires] = ACTIONS(2595),
    [sym_this] = ACTIONS(2595),
    [anon_sym___launch_bounds__] = ACTIONS(2595),
  },
  [STATE(989)] = {
    [sym_identifier] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2385),
    [anon_sym_BANG] = ACTIONS(2385),
    [anon_sym_TILDE] = ACTIONS(2385),
    [anon_sym_DASH] = ACTIONS(2383),
    [anon_sym_PLUS] = ACTIONS(2383),
    [anon_sym_STAR] = ACTIONS(2385),
    [anon_sym_AMP] = ACTIONS(2385),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym___device__] = ACTIONS(2383),
    [anon_sym___host__] = ACTIONS(2383),
    [anon_sym___global__] = ACTIONS(2383),
    [anon_sym___forceinline__] = ACTIONS(2383),
    [anon_sym___noinline__] = ACTIONS(2383),
    [anon_sym_virtual] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym___attribute] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2385),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2385),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym__Nonnull] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym___shared__] = ACTIONS(2383),
    [anon_sym___local__] = ACTIONS(2383),
    [anon_sym___constant__] = ACTIONS(2383),
    [anon_sym___managed__] = ACTIONS(2383),
    [anon_sym___grid_constant__] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [anon_sym_not] = ACTIONS(2383),
    [anon_sym_compl] = ACTIONS(2383),
    [anon_sym_DASH_DASH] = ACTIONS(2385),
    [anon_sym_PLUS_PLUS] = ACTIONS(2385),
    [anon_sym_sizeof] = ACTIONS(2383),
    [anon_sym___alignof__] = ACTIONS(2383),
    [anon_sym___alignof] = ACTIONS(2383),
    [anon_sym__alignof] = ACTIONS(2383),
    [anon_sym_alignof] = ACTIONS(2383),
    [anon_sym__Alignof] = ACTIONS(2383),
    [anon_sym_offsetof] = ACTIONS(2383),
    [anon_sym__Generic] = ACTIONS(2383),
    [anon_sym_asm] = ACTIONS(2383),
    [anon_sym___asm__] = ACTIONS(2383),
    [anon_sym___asm] = ACTIONS(2383),
    [sym_number_literal] = ACTIONS(2385),
    [anon_sym_L_SQUOTE] = ACTIONS(2385),
    [anon_sym_u_SQUOTE] = ACTIONS(2385),
    [anon_sym_U_SQUOTE] = ACTIONS(2385),
    [anon_sym_u8_SQUOTE] = ACTIONS(2385),
    [anon_sym_SQUOTE] = ACTIONS(2385),
    [anon_sym_L_DQUOTE] = ACTIONS(2385),
    [anon_sym_u_DQUOTE] = ACTIONS(2385),
    [anon_sym_U_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8_DQUOTE] = ACTIONS(2385),
    [anon_sym_DQUOTE] = ACTIONS(2385),
    [sym_true] = ACTIONS(2383),
    [sym_false] = ACTIONS(2383),
    [anon_sym_NULL] = ACTIONS(2383),
    [anon_sym_nullptr] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_delete] = ACTIONS(2383),
    [anon_sym_R_DQUOTE] = ACTIONS(2385),
    [anon_sym_LR_DQUOTE] = ACTIONS(2385),
    [anon_sym_uR_DQUOTE] = ACTIONS(2385),
    [anon_sym_UR_DQUOTE] = ACTIONS(2385),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2385),
    [anon_sym_co_await] = ACTIONS(2383),
    [anon_sym_new] = ACTIONS(2383),
    [anon_sym_requires] = ACTIONS(2383),
    [sym_this] = ACTIONS(2383),
    [anon_sym___launch_bounds__] = ACTIONS(2383),
  },
  [STATE(990)] = {
    [sym_expression] = STATE(3511),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9222),
    [sym__unary_right_fold] = STATE(9260),
    [sym__binary_fold] = STATE(9292),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(991)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4555),
    [anon_sym_COMMA] = ACTIONS(4555),
    [anon_sym_RPAREN] = ACTIONS(4555),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym_SEMI] = ACTIONS(4555),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4560),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_RBRACE] = ACTIONS(4555),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_EQ] = ACTIONS(4562),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4562),
    [anon_sym_or_eq] = ACTIONS(4562),
    [anon_sym_xor_eq] = ACTIONS(4562),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_operator] = ACTIONS(4553),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(992)] = {
    [sym_compound_statement] = STATE(8044),
    [sym_expression] = STATE(5006),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8044),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4621),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(993)] = {
    [sym_compound_statement] = STATE(7796),
    [sym_expression] = STATE(4983),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(7796),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4623),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(994)] = {
    [sym_expression] = STATE(5083),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9103),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9103),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4625),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(995)] = {
    [sym_compound_statement] = STATE(8106),
    [sym_expression] = STATE(4961),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8106),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4627),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(996)] = {
    [sym_expression] = STATE(4718),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_initializer_list] = STATE(7427),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_default] = ACTIONS(4633),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(4637),
    [aux_sym_pure_virtual_clause_token1] = ACTIONS(4639),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(997)] = {
    [sym_compound_statement] = STATE(9055),
    [sym_expression] = STATE(3458),
    [sym__string] = STATE(3222),
    [sym_comma_expression] = STATE(9055),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym__assignment_expression_lhs] = STATE(8752),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(998)] = {
    [sym_expression] = STATE(3489),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9403),
    [sym__unary_right_fold] = STATE(9405),
    [sym__binary_fold] = STATE(9406),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(999)] = {
    [sym_expression] = STATE(4713),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_initializer_list] = STATE(7429),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_default] = ACTIONS(4643),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(4645),
    [aux_sym_pure_virtual_clause_token1] = ACTIONS(4647),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1000)] = {
    [sym_expression] = STATE(5168),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9393),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9393),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4649),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1001)] = {
    [sym_expression] = STATE(3507),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(8665),
    [sym__unary_right_fold] = STATE(8670),
    [sym__binary_fold] = STATE(8709),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1002)] = {
    [sym_compound_statement] = STATE(7811),
    [sym_expression] = STATE(4990),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(7811),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4651),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1003)] = {
    [sym_expression] = STATE(3497),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9444),
    [sym__unary_right_fold] = STATE(9449),
    [sym__binary_fold] = STATE(9452),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1004)] = {
    [sym_expression] = STATE(3535),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9069),
    [sym__unary_right_fold] = STATE(9071),
    [sym__binary_fold] = STATE(9084),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1005)] = {
    [sym_expression] = STATE(3502),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(8842),
    [sym__unary_right_fold] = STATE(8886),
    [sym__binary_fold] = STATE(8891),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1006)] = {
    [sym_expression] = STATE(3480),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9186),
    [sym__unary_right_fold] = STATE(9143),
    [sym__binary_fold] = STATE(8639),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1007)] = {
    [sym_compound_statement] = STATE(7943),
    [sym_expression] = STATE(5000),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(7943),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4653),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1008)] = {
    [sym_expression] = STATE(3531),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9035),
    [sym__unary_right_fold] = STATE(9043),
    [sym__binary_fold] = STATE(9045),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1009)] = {
    [sym_expression] = STATE(5046),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8664),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8664),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4655),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1010)] = {
    [sym_expression] = STATE(3533),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(8711),
    [sym__unary_right_fold] = STATE(8719),
    [sym__binary_fold] = STATE(8774),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1011)] = {
    [sym_compound_statement] = STATE(8119),
    [sym_expression] = STATE(4988),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8119),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4657),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1012)] = {
    [sym_expression] = STATE(3539),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(8735),
    [sym__unary_right_fold] = STATE(8747),
    [sym__binary_fold] = STATE(8755),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1013)] = {
    [sym_compound_statement] = STATE(7844),
    [sym_expression] = STATE(4975),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(7844),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4659),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1014)] = {
    [sym_compound_statement] = STATE(8032),
    [sym_expression] = STATE(4916),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8032),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4661),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1015)] = {
    [sym_expression] = STATE(5125),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9085),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9085),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4663),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1016)] = {
    [sym_compound_statement] = STATE(8074),
    [sym_expression] = STATE(4982),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8074),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4665),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1017)] = {
    [sym_expression] = STATE(5068),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9167),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9167),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4667),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1018)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_identifier_parameter_pack_expansion] = STATE(8267),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4213),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(4669),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4671),
    [anon_sym_COMMA] = ACTIONS(4673),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4673),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1019)] = {
    [sym_expression] = STATE(3519),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym__unary_left_fold] = STATE(9010),
    [sym__unary_right_fold] = STATE(9011),
    [sym__binary_fold] = STATE(9024),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1782),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1020)] = {
    [sym_template_argument_list] = STATE(1070),
    [sym_identifier] = ACTIONS(4512),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4516),
    [anon_sym_COMMA] = ACTIONS(4516),
    [anon_sym_RPAREN] = ACTIONS(4516),
    [anon_sym_LPAREN2] = ACTIONS(4516),
    [anon_sym_TILDE] = ACTIONS(4519),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4523),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4516),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4523),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4514),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4675),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym___extension__] = ACTIONS(4512),
    [anon_sym___device__] = ACTIONS(4512),
    [anon_sym___host__] = ACTIONS(4512),
    [anon_sym___global__] = ACTIONS(4512),
    [anon_sym___forceinline__] = ACTIONS(4512),
    [anon_sym___noinline__] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym___attribute__] = ACTIONS(4512),
    [anon_sym___attribute] = ACTIONS(4512),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4519),
    [anon_sym___declspec] = ACTIONS(4512),
    [anon_sym___based] = ACTIONS(4512),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4523),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_EQ] = ACTIONS(4523),
    [anon_sym_register] = ACTIONS(4512),
    [anon_sym_inline] = ACTIONS(4512),
    [anon_sym___inline] = ACTIONS(4512),
    [anon_sym___inline__] = ACTIONS(4512),
    [anon_sym___forceinline] = ACTIONS(4512),
    [anon_sym_thread_local] = ACTIONS(4512),
    [anon_sym___thread] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4512),
    [anon_sym_volatile] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym___restrict__] = ACTIONS(4512),
    [anon_sym__Atomic] = ACTIONS(4512),
    [anon_sym__Noreturn] = ACTIONS(4512),
    [anon_sym_noreturn] = ACTIONS(4512),
    [anon_sym__Nonnull] = ACTIONS(4512),
    [anon_sym_mutable] = ACTIONS(4512),
    [anon_sym_constinit] = ACTIONS(4512),
    [anon_sym_consteval] = ACTIONS(4512),
    [anon_sym___shared__] = ACTIONS(4512),
    [anon_sym___local__] = ACTIONS(4512),
    [anon_sym___constant__] = ACTIONS(4512),
    [anon_sym___managed__] = ACTIONS(4512),
    [anon_sym___grid_constant__] = ACTIONS(4512),
    [anon_sym_alignas] = ACTIONS(4512),
    [anon_sym__Alignas] = ACTIONS(4512),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4514),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4521),
    [anon_sym_or_eq] = ACTIONS(4521),
    [anon_sym_xor_eq] = ACTIONS(4521),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4521),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4521),
    [anon_sym_not_eq] = ACTIONS(4521),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4512),
    [anon_sym_decltype] = ACTIONS(4512),
    [anon_sym_template] = ACTIONS(4512),
    [anon_sym_operator] = ACTIONS(4512),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4514),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
    [anon_sym___launch_bounds__] = ACTIONS(4512),
  },
  [STATE(1021)] = {
    [sym_expression] = STATE(4732),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_initializer_list] = STATE(7388),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_default] = ACTIONS(4678),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(4680),
    [aux_sym_pure_virtual_clause_token1] = ACTIONS(4682),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1022)] = {
    [sym_expression] = STATE(3634),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1023)] = {
    [sym_identifier] = ACTIONS(4408),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_RPAREN] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_TILDE] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4410),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4410),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4410),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4410),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4410),
    [anon_sym_SEMI] = ACTIONS(4410),
    [anon_sym___extension__] = ACTIONS(4408),
    [anon_sym___device__] = ACTIONS(4408),
    [anon_sym___host__] = ACTIONS(4408),
    [anon_sym___global__] = ACTIONS(4408),
    [anon_sym___forceinline__] = ACTIONS(4408),
    [anon_sym___noinline__] = ACTIONS(4408),
    [anon_sym_virtual] = ACTIONS(4408),
    [anon_sym_extern] = ACTIONS(4408),
    [anon_sym___attribute__] = ACTIONS(4408),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4410),
    [anon_sym___declspec] = ACTIONS(4408),
    [anon_sym___based] = ACTIONS(4408),
    [anon_sym___cdecl] = ACTIONS(4408),
    [anon_sym___clrcall] = ACTIONS(4408),
    [anon_sym___stdcall] = ACTIONS(4408),
    [anon_sym___fastcall] = ACTIONS(4408),
    [anon_sym___thiscall] = ACTIONS(4408),
    [anon_sym___vectorcall] = ACTIONS(4408),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_RBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4408),
    [anon_sym_static] = ACTIONS(4408),
    [anon_sym_RBRACK] = ACTIONS(4410),
    [anon_sym_EQ] = ACTIONS(4408),
    [anon_sym_register] = ACTIONS(4408),
    [anon_sym_inline] = ACTIONS(4408),
    [anon_sym___inline] = ACTIONS(4408),
    [anon_sym___inline__] = ACTIONS(4408),
    [anon_sym___forceinline] = ACTIONS(4408),
    [anon_sym_thread_local] = ACTIONS(4408),
    [anon_sym___thread] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4408),
    [anon_sym_volatile] = ACTIONS(4408),
    [anon_sym_restrict] = ACTIONS(4408),
    [anon_sym___restrict__] = ACTIONS(4408),
    [anon_sym__Atomic] = ACTIONS(4408),
    [anon_sym__Noreturn] = ACTIONS(4408),
    [anon_sym_noreturn] = ACTIONS(4408),
    [anon_sym__Nonnull] = ACTIONS(4408),
    [anon_sym_mutable] = ACTIONS(4408),
    [anon_sym_constinit] = ACTIONS(4408),
    [anon_sym_consteval] = ACTIONS(4408),
    [anon_sym___shared__] = ACTIONS(4408),
    [anon_sym___local__] = ACTIONS(4408),
    [anon_sym___constant__] = ACTIONS(4408),
    [anon_sym___managed__] = ACTIONS(4408),
    [anon_sym___grid_constant__] = ACTIONS(4408),
    [anon_sym_alignas] = ACTIONS(4408),
    [anon_sym__Alignas] = ACTIONS(4408),
    [anon_sym_COLON] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_bitor] = ACTIONS(4408),
    [anon_sym_xor] = ACTIONS(4408),
    [anon_sym_bitand] = ACTIONS(4408),
    [anon_sym_not_eq] = ACTIONS(4408),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4408),
    [anon_sym_decltype] = ACTIONS(4408),
    [anon_sym_final] = ACTIONS(4408),
    [anon_sym_override] = ACTIONS(4408),
    [anon_sym_template] = ACTIONS(4408),
    [anon_sym_operator] = ACTIONS(4408),
    [anon_sym_try] = ACTIONS(4408),
    [anon_sym_requires] = ACTIONS(4408),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
    [anon_sym___launch_bounds__] = ACTIONS(4408),
  },
  [STATE(1024)] = {
    [sym_expression] = STATE(4911),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(7898),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4690),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1025)] = {
    [sym_identifier] = ACTIONS(4396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_RPAREN] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_TILDE] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4396),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4396),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4396),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4398),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4396),
    [anon_sym___extension__] = ACTIONS(4396),
    [anon_sym___device__] = ACTIONS(4396),
    [anon_sym___host__] = ACTIONS(4396),
    [anon_sym___global__] = ACTIONS(4396),
    [anon_sym___forceinline__] = ACTIONS(4396),
    [anon_sym___noinline__] = ACTIONS(4396),
    [anon_sym_virtual] = ACTIONS(4396),
    [anon_sym_extern] = ACTIONS(4396),
    [anon_sym___attribute__] = ACTIONS(4396),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4398),
    [anon_sym___declspec] = ACTIONS(4396),
    [anon_sym___based] = ACTIONS(4396),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4396),
    [anon_sym_static] = ACTIONS(4396),
    [anon_sym_EQ] = ACTIONS(4396),
    [anon_sym_register] = ACTIONS(4396),
    [anon_sym_inline] = ACTIONS(4396),
    [anon_sym___inline] = ACTIONS(4396),
    [anon_sym___inline__] = ACTIONS(4396),
    [anon_sym___forceinline] = ACTIONS(4396),
    [anon_sym_thread_local] = ACTIONS(4396),
    [anon_sym___thread] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4396),
    [anon_sym_volatile] = ACTIONS(4396),
    [anon_sym_restrict] = ACTIONS(4396),
    [anon_sym___restrict__] = ACTIONS(4396),
    [anon_sym__Atomic] = ACTIONS(4396),
    [anon_sym__Noreturn] = ACTIONS(4396),
    [anon_sym_noreturn] = ACTIONS(4396),
    [anon_sym__Nonnull] = ACTIONS(4396),
    [anon_sym_mutable] = ACTIONS(4396),
    [anon_sym_constinit] = ACTIONS(4396),
    [anon_sym_consteval] = ACTIONS(4396),
    [anon_sym___shared__] = ACTIONS(4396),
    [anon_sym___local__] = ACTIONS(4396),
    [anon_sym___constant__] = ACTIONS(4396),
    [anon_sym___managed__] = ACTIONS(4396),
    [anon_sym___grid_constant__] = ACTIONS(4396),
    [anon_sym_alignas] = ACTIONS(4396),
    [anon_sym__Alignas] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_STAR_EQ] = ACTIONS(4398),
    [anon_sym_SLASH_EQ] = ACTIONS(4398),
    [anon_sym_PERCENT_EQ] = ACTIONS(4398),
    [anon_sym_PLUS_EQ] = ACTIONS(4398),
    [anon_sym_DASH_EQ] = ACTIONS(4398),
    [anon_sym_LT_LT_EQ] = ACTIONS(4398),
    [anon_sym_GT_GT_EQ] = ACTIONS(4398),
    [anon_sym_AMP_EQ] = ACTIONS(4398),
    [anon_sym_CARET_EQ] = ACTIONS(4398),
    [anon_sym_PIPE_EQ] = ACTIONS(4398),
    [anon_sym_and_eq] = ACTIONS(4396),
    [anon_sym_or_eq] = ACTIONS(4396),
    [anon_sym_xor_eq] = ACTIONS(4396),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_bitor] = ACTIONS(4396),
    [anon_sym_xor] = ACTIONS(4396),
    [anon_sym_bitand] = ACTIONS(4396),
    [anon_sym_not_eq] = ACTIONS(4396),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4396),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4396),
    [anon_sym_decltype] = ACTIONS(4396),
    [anon_sym_template] = ACTIONS(4396),
    [anon_sym_operator] = ACTIONS(4396),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4398),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
    [anon_sym___launch_bounds__] = ACTIONS(4396),
  },
  [STATE(1026)] = {
    [sym_identifier] = ACTIONS(4402),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_RPAREN] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_TILDE] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4402),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4402),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4402),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4404),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4402),
    [anon_sym___extension__] = ACTIONS(4402),
    [anon_sym___device__] = ACTIONS(4402),
    [anon_sym___host__] = ACTIONS(4402),
    [anon_sym___global__] = ACTIONS(4402),
    [anon_sym___forceinline__] = ACTIONS(4402),
    [anon_sym___noinline__] = ACTIONS(4402),
    [anon_sym_virtual] = ACTIONS(4402),
    [anon_sym_extern] = ACTIONS(4402),
    [anon_sym___attribute__] = ACTIONS(4402),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4404),
    [anon_sym___declspec] = ACTIONS(4402),
    [anon_sym___based] = ACTIONS(4402),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4402),
    [anon_sym_static] = ACTIONS(4402),
    [anon_sym_EQ] = ACTIONS(4402),
    [anon_sym_register] = ACTIONS(4402),
    [anon_sym_inline] = ACTIONS(4402),
    [anon_sym___inline] = ACTIONS(4402),
    [anon_sym___inline__] = ACTIONS(4402),
    [anon_sym___forceinline] = ACTIONS(4402),
    [anon_sym_thread_local] = ACTIONS(4402),
    [anon_sym___thread] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4402),
    [anon_sym_volatile] = ACTIONS(4402),
    [anon_sym_restrict] = ACTIONS(4402),
    [anon_sym___restrict__] = ACTIONS(4402),
    [anon_sym__Atomic] = ACTIONS(4402),
    [anon_sym__Noreturn] = ACTIONS(4402),
    [anon_sym_noreturn] = ACTIONS(4402),
    [anon_sym__Nonnull] = ACTIONS(4402),
    [anon_sym_mutable] = ACTIONS(4402),
    [anon_sym_constinit] = ACTIONS(4402),
    [anon_sym_consteval] = ACTIONS(4402),
    [anon_sym___shared__] = ACTIONS(4402),
    [anon_sym___local__] = ACTIONS(4402),
    [anon_sym___constant__] = ACTIONS(4402),
    [anon_sym___managed__] = ACTIONS(4402),
    [anon_sym___grid_constant__] = ACTIONS(4402),
    [anon_sym_alignas] = ACTIONS(4402),
    [anon_sym__Alignas] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_STAR_EQ] = ACTIONS(4404),
    [anon_sym_SLASH_EQ] = ACTIONS(4404),
    [anon_sym_PERCENT_EQ] = ACTIONS(4404),
    [anon_sym_PLUS_EQ] = ACTIONS(4404),
    [anon_sym_DASH_EQ] = ACTIONS(4404),
    [anon_sym_LT_LT_EQ] = ACTIONS(4404),
    [anon_sym_GT_GT_EQ] = ACTIONS(4404),
    [anon_sym_AMP_EQ] = ACTIONS(4404),
    [anon_sym_CARET_EQ] = ACTIONS(4404),
    [anon_sym_PIPE_EQ] = ACTIONS(4404),
    [anon_sym_and_eq] = ACTIONS(4402),
    [anon_sym_or_eq] = ACTIONS(4402),
    [anon_sym_xor_eq] = ACTIONS(4402),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_bitor] = ACTIONS(4402),
    [anon_sym_xor] = ACTIONS(4402),
    [anon_sym_bitand] = ACTIONS(4402),
    [anon_sym_not_eq] = ACTIONS(4402),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4402),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4402),
    [anon_sym_decltype] = ACTIONS(4402),
    [anon_sym_template] = ACTIONS(4402),
    [anon_sym_operator] = ACTIONS(4402),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4404),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
    [anon_sym___launch_bounds__] = ACTIONS(4402),
  },
  [STATE(1027)] = {
    [sym_identifier] = ACTIONS(4408),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_RPAREN] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_TILDE] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4408),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4408),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4408),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4410),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4408),
    [anon_sym___extension__] = ACTIONS(4408),
    [anon_sym___device__] = ACTIONS(4408),
    [anon_sym___host__] = ACTIONS(4408),
    [anon_sym___global__] = ACTIONS(4408),
    [anon_sym___forceinline__] = ACTIONS(4408),
    [anon_sym___noinline__] = ACTIONS(4408),
    [anon_sym_virtual] = ACTIONS(4408),
    [anon_sym_extern] = ACTIONS(4408),
    [anon_sym___attribute__] = ACTIONS(4408),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4410),
    [anon_sym___declspec] = ACTIONS(4408),
    [anon_sym___based] = ACTIONS(4408),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4408),
    [anon_sym_static] = ACTIONS(4408),
    [anon_sym_EQ] = ACTIONS(4408),
    [anon_sym_register] = ACTIONS(4408),
    [anon_sym_inline] = ACTIONS(4408),
    [anon_sym___inline] = ACTIONS(4408),
    [anon_sym___inline__] = ACTIONS(4408),
    [anon_sym___forceinline] = ACTIONS(4408),
    [anon_sym_thread_local] = ACTIONS(4408),
    [anon_sym___thread] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4408),
    [anon_sym_volatile] = ACTIONS(4408),
    [anon_sym_restrict] = ACTIONS(4408),
    [anon_sym___restrict__] = ACTIONS(4408),
    [anon_sym__Atomic] = ACTIONS(4408),
    [anon_sym__Noreturn] = ACTIONS(4408),
    [anon_sym_noreturn] = ACTIONS(4408),
    [anon_sym__Nonnull] = ACTIONS(4408),
    [anon_sym_mutable] = ACTIONS(4408),
    [anon_sym_constinit] = ACTIONS(4408),
    [anon_sym_consteval] = ACTIONS(4408),
    [anon_sym___shared__] = ACTIONS(4408),
    [anon_sym___local__] = ACTIONS(4408),
    [anon_sym___constant__] = ACTIONS(4408),
    [anon_sym___managed__] = ACTIONS(4408),
    [anon_sym___grid_constant__] = ACTIONS(4408),
    [anon_sym_alignas] = ACTIONS(4408),
    [anon_sym__Alignas] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_STAR_EQ] = ACTIONS(4410),
    [anon_sym_SLASH_EQ] = ACTIONS(4410),
    [anon_sym_PERCENT_EQ] = ACTIONS(4410),
    [anon_sym_PLUS_EQ] = ACTIONS(4410),
    [anon_sym_DASH_EQ] = ACTIONS(4410),
    [anon_sym_LT_LT_EQ] = ACTIONS(4410),
    [anon_sym_GT_GT_EQ] = ACTIONS(4410),
    [anon_sym_AMP_EQ] = ACTIONS(4410),
    [anon_sym_CARET_EQ] = ACTIONS(4410),
    [anon_sym_PIPE_EQ] = ACTIONS(4410),
    [anon_sym_and_eq] = ACTIONS(4408),
    [anon_sym_or_eq] = ACTIONS(4408),
    [anon_sym_xor_eq] = ACTIONS(4408),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_bitor] = ACTIONS(4408),
    [anon_sym_xor] = ACTIONS(4408),
    [anon_sym_bitand] = ACTIONS(4408),
    [anon_sym_not_eq] = ACTIONS(4408),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4408),
    [anon_sym_decltype] = ACTIONS(4408),
    [anon_sym_template] = ACTIONS(4408),
    [anon_sym_operator] = ACTIONS(4408),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4410),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
    [anon_sym___launch_bounds__] = ACTIONS(4408),
  },
  [STATE(1028)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4692),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1029)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4695),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1030)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4698),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1031)] = {
    [sym_expression] = STATE(3036),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1032)] = {
    [sym_expression] = STATE(3038),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1033)] = {
    [sym_expression] = STATE(3673),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1034)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4705),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1035)] = {
    [sym_expression] = STATE(3571),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1036)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4708),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1037)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4711),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1038)] = {
    [sym_expression] = STATE(3273),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1039)] = {
    [sym_identifier] = ACTIONS(4396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_RPAREN] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_TILDE] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4398),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4398),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4398),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4398),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4398),
    [anon_sym_SEMI] = ACTIONS(4398),
    [anon_sym___extension__] = ACTIONS(4396),
    [anon_sym___device__] = ACTIONS(4396),
    [anon_sym___host__] = ACTIONS(4396),
    [anon_sym___global__] = ACTIONS(4396),
    [anon_sym___forceinline__] = ACTIONS(4396),
    [anon_sym___noinline__] = ACTIONS(4396),
    [anon_sym_virtual] = ACTIONS(4396),
    [anon_sym_extern] = ACTIONS(4396),
    [anon_sym___attribute__] = ACTIONS(4396),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4398),
    [anon_sym___declspec] = ACTIONS(4396),
    [anon_sym___based] = ACTIONS(4396),
    [anon_sym___cdecl] = ACTIONS(4396),
    [anon_sym___clrcall] = ACTIONS(4396),
    [anon_sym___stdcall] = ACTIONS(4396),
    [anon_sym___fastcall] = ACTIONS(4396),
    [anon_sym___thiscall] = ACTIONS(4396),
    [anon_sym___vectorcall] = ACTIONS(4396),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_RBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4396),
    [anon_sym_static] = ACTIONS(4396),
    [anon_sym_RBRACK] = ACTIONS(4398),
    [anon_sym_EQ] = ACTIONS(4396),
    [anon_sym_register] = ACTIONS(4396),
    [anon_sym_inline] = ACTIONS(4396),
    [anon_sym___inline] = ACTIONS(4396),
    [anon_sym___inline__] = ACTIONS(4396),
    [anon_sym___forceinline] = ACTIONS(4396),
    [anon_sym_thread_local] = ACTIONS(4396),
    [anon_sym___thread] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4396),
    [anon_sym_volatile] = ACTIONS(4396),
    [anon_sym_restrict] = ACTIONS(4396),
    [anon_sym___restrict__] = ACTIONS(4396),
    [anon_sym__Atomic] = ACTIONS(4396),
    [anon_sym__Noreturn] = ACTIONS(4396),
    [anon_sym_noreturn] = ACTIONS(4396),
    [anon_sym__Nonnull] = ACTIONS(4396),
    [anon_sym_mutable] = ACTIONS(4396),
    [anon_sym_constinit] = ACTIONS(4396),
    [anon_sym_consteval] = ACTIONS(4396),
    [anon_sym___shared__] = ACTIONS(4396),
    [anon_sym___local__] = ACTIONS(4396),
    [anon_sym___constant__] = ACTIONS(4396),
    [anon_sym___managed__] = ACTIONS(4396),
    [anon_sym___grid_constant__] = ACTIONS(4396),
    [anon_sym_alignas] = ACTIONS(4396),
    [anon_sym__Alignas] = ACTIONS(4396),
    [anon_sym_COLON] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_bitor] = ACTIONS(4396),
    [anon_sym_xor] = ACTIONS(4396),
    [anon_sym_bitand] = ACTIONS(4396),
    [anon_sym_not_eq] = ACTIONS(4396),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4396),
    [anon_sym_decltype] = ACTIONS(4396),
    [anon_sym_final] = ACTIONS(4396),
    [anon_sym_override] = ACTIONS(4396),
    [anon_sym_template] = ACTIONS(4396),
    [anon_sym_operator] = ACTIONS(4396),
    [anon_sym_try] = ACTIONS(4396),
    [anon_sym_requires] = ACTIONS(4396),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
    [anon_sym___launch_bounds__] = ACTIONS(4396),
  },
  [STATE(1040)] = {
    [sym_expression] = STATE(4849),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1041)] = {
    [sym_expression] = STATE(4954),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(7942),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4714),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1042)] = {
    [sym_identifier] = ACTIONS(4350),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_RPAREN] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_TILDE] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4352),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4352),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4352),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4352),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4352),
    [anon_sym_SEMI] = ACTIONS(4352),
    [anon_sym___extension__] = ACTIONS(4350),
    [anon_sym___device__] = ACTIONS(4350),
    [anon_sym___host__] = ACTIONS(4350),
    [anon_sym___global__] = ACTIONS(4350),
    [anon_sym___forceinline__] = ACTIONS(4350),
    [anon_sym___noinline__] = ACTIONS(4350),
    [anon_sym_virtual] = ACTIONS(4350),
    [anon_sym_extern] = ACTIONS(4350),
    [anon_sym___attribute__] = ACTIONS(4350),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4352),
    [anon_sym___declspec] = ACTIONS(4350),
    [anon_sym___based] = ACTIONS(4350),
    [anon_sym___cdecl] = ACTIONS(4350),
    [anon_sym___clrcall] = ACTIONS(4350),
    [anon_sym___stdcall] = ACTIONS(4350),
    [anon_sym___fastcall] = ACTIONS(4350),
    [anon_sym___thiscall] = ACTIONS(4350),
    [anon_sym___vectorcall] = ACTIONS(4350),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_RBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_static] = ACTIONS(4350),
    [anon_sym_RBRACK] = ACTIONS(4352),
    [anon_sym_EQ] = ACTIONS(4350),
    [anon_sym_register] = ACTIONS(4350),
    [anon_sym_inline] = ACTIONS(4350),
    [anon_sym___inline] = ACTIONS(4350),
    [anon_sym___inline__] = ACTIONS(4350),
    [anon_sym___forceinline] = ACTIONS(4350),
    [anon_sym_thread_local] = ACTIONS(4350),
    [anon_sym___thread] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4350),
    [anon_sym_volatile] = ACTIONS(4350),
    [anon_sym_restrict] = ACTIONS(4350),
    [anon_sym___restrict__] = ACTIONS(4350),
    [anon_sym__Atomic] = ACTIONS(4350),
    [anon_sym__Noreturn] = ACTIONS(4350),
    [anon_sym_noreturn] = ACTIONS(4350),
    [anon_sym__Nonnull] = ACTIONS(4350),
    [anon_sym_mutable] = ACTIONS(4350),
    [anon_sym_constinit] = ACTIONS(4350),
    [anon_sym_consteval] = ACTIONS(4350),
    [anon_sym___shared__] = ACTIONS(4350),
    [anon_sym___local__] = ACTIONS(4350),
    [anon_sym___constant__] = ACTIONS(4350),
    [anon_sym___managed__] = ACTIONS(4350),
    [anon_sym___grid_constant__] = ACTIONS(4350),
    [anon_sym_alignas] = ACTIONS(4350),
    [anon_sym__Alignas] = ACTIONS(4350),
    [anon_sym_COLON] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_bitor] = ACTIONS(4350),
    [anon_sym_xor] = ACTIONS(4350),
    [anon_sym_bitand] = ACTIONS(4350),
    [anon_sym_not_eq] = ACTIONS(4350),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4350),
    [anon_sym_decltype] = ACTIONS(4350),
    [anon_sym_final] = ACTIONS(4350),
    [anon_sym_override] = ACTIONS(4350),
    [anon_sym_template] = ACTIONS(4350),
    [anon_sym_operator] = ACTIONS(4350),
    [anon_sym_try] = ACTIONS(4350),
    [anon_sym_requires] = ACTIONS(4350),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
    [anon_sym___launch_bounds__] = ACTIONS(4350),
  },
  [STATE(1043)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4716),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1044)] = {
    [sym_identifier] = ACTIONS(4356),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_RPAREN] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_TILDE] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4358),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4358),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4358),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4358),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4358),
    [anon_sym_SEMI] = ACTIONS(4358),
    [anon_sym___extension__] = ACTIONS(4356),
    [anon_sym___device__] = ACTIONS(4356),
    [anon_sym___host__] = ACTIONS(4356),
    [anon_sym___global__] = ACTIONS(4356),
    [anon_sym___forceinline__] = ACTIONS(4356),
    [anon_sym___noinline__] = ACTIONS(4356),
    [anon_sym_virtual] = ACTIONS(4356),
    [anon_sym_extern] = ACTIONS(4356),
    [anon_sym___attribute__] = ACTIONS(4356),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4358),
    [anon_sym___declspec] = ACTIONS(4356),
    [anon_sym___based] = ACTIONS(4356),
    [anon_sym___cdecl] = ACTIONS(4356),
    [anon_sym___clrcall] = ACTIONS(4356),
    [anon_sym___stdcall] = ACTIONS(4356),
    [anon_sym___fastcall] = ACTIONS(4356),
    [anon_sym___thiscall] = ACTIONS(4356),
    [anon_sym___vectorcall] = ACTIONS(4356),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_RBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_static] = ACTIONS(4356),
    [anon_sym_RBRACK] = ACTIONS(4358),
    [anon_sym_EQ] = ACTIONS(4356),
    [anon_sym_register] = ACTIONS(4356),
    [anon_sym_inline] = ACTIONS(4356),
    [anon_sym___inline] = ACTIONS(4356),
    [anon_sym___inline__] = ACTIONS(4356),
    [anon_sym___forceinline] = ACTIONS(4356),
    [anon_sym_thread_local] = ACTIONS(4356),
    [anon_sym___thread] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4356),
    [anon_sym_volatile] = ACTIONS(4356),
    [anon_sym_restrict] = ACTIONS(4356),
    [anon_sym___restrict__] = ACTIONS(4356),
    [anon_sym__Atomic] = ACTIONS(4356),
    [anon_sym__Noreturn] = ACTIONS(4356),
    [anon_sym_noreturn] = ACTIONS(4356),
    [anon_sym__Nonnull] = ACTIONS(4356),
    [anon_sym_mutable] = ACTIONS(4356),
    [anon_sym_constinit] = ACTIONS(4356),
    [anon_sym_consteval] = ACTIONS(4356),
    [anon_sym___shared__] = ACTIONS(4356),
    [anon_sym___local__] = ACTIONS(4356),
    [anon_sym___constant__] = ACTIONS(4356),
    [anon_sym___managed__] = ACTIONS(4356),
    [anon_sym___grid_constant__] = ACTIONS(4356),
    [anon_sym_alignas] = ACTIONS(4356),
    [anon_sym__Alignas] = ACTIONS(4356),
    [anon_sym_COLON] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_bitor] = ACTIONS(4356),
    [anon_sym_xor] = ACTIONS(4356),
    [anon_sym_bitand] = ACTIONS(4356),
    [anon_sym_not_eq] = ACTIONS(4356),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4358),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4356),
    [anon_sym_decltype] = ACTIONS(4356),
    [anon_sym_final] = ACTIONS(4356),
    [anon_sym_override] = ACTIONS(4356),
    [anon_sym_template] = ACTIONS(4356),
    [anon_sym_operator] = ACTIONS(4356),
    [anon_sym_try] = ACTIONS(4356),
    [anon_sym_requires] = ACTIONS(4356),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
    [anon_sym___launch_bounds__] = ACTIONS(4356),
  },
  [STATE(1045)] = {
    [sym_identifier] = ACTIONS(4366),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_RPAREN] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_TILDE] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4368),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4368),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4368),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4368),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4368),
    [anon_sym_SEMI] = ACTIONS(4368),
    [anon_sym___extension__] = ACTIONS(4366),
    [anon_sym___device__] = ACTIONS(4366),
    [anon_sym___host__] = ACTIONS(4366),
    [anon_sym___global__] = ACTIONS(4366),
    [anon_sym___forceinline__] = ACTIONS(4366),
    [anon_sym___noinline__] = ACTIONS(4366),
    [anon_sym_virtual] = ACTIONS(4366),
    [anon_sym_extern] = ACTIONS(4366),
    [anon_sym___attribute__] = ACTIONS(4366),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4368),
    [anon_sym___declspec] = ACTIONS(4366),
    [anon_sym___based] = ACTIONS(4366),
    [anon_sym___cdecl] = ACTIONS(4366),
    [anon_sym___clrcall] = ACTIONS(4366),
    [anon_sym___stdcall] = ACTIONS(4366),
    [anon_sym___fastcall] = ACTIONS(4366),
    [anon_sym___thiscall] = ACTIONS(4366),
    [anon_sym___vectorcall] = ACTIONS(4366),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_RBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4366),
    [anon_sym_static] = ACTIONS(4366),
    [anon_sym_RBRACK] = ACTIONS(4368),
    [anon_sym_EQ] = ACTIONS(4366),
    [anon_sym_register] = ACTIONS(4366),
    [anon_sym_inline] = ACTIONS(4366),
    [anon_sym___inline] = ACTIONS(4366),
    [anon_sym___inline__] = ACTIONS(4366),
    [anon_sym___forceinline] = ACTIONS(4366),
    [anon_sym_thread_local] = ACTIONS(4366),
    [anon_sym___thread] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4366),
    [anon_sym_volatile] = ACTIONS(4366),
    [anon_sym_restrict] = ACTIONS(4366),
    [anon_sym___restrict__] = ACTIONS(4366),
    [anon_sym__Atomic] = ACTIONS(4366),
    [anon_sym__Noreturn] = ACTIONS(4366),
    [anon_sym_noreturn] = ACTIONS(4366),
    [anon_sym__Nonnull] = ACTIONS(4366),
    [anon_sym_mutable] = ACTIONS(4366),
    [anon_sym_constinit] = ACTIONS(4366),
    [anon_sym_consteval] = ACTIONS(4366),
    [anon_sym___shared__] = ACTIONS(4366),
    [anon_sym___local__] = ACTIONS(4366),
    [anon_sym___constant__] = ACTIONS(4366),
    [anon_sym___managed__] = ACTIONS(4366),
    [anon_sym___grid_constant__] = ACTIONS(4366),
    [anon_sym_alignas] = ACTIONS(4366),
    [anon_sym__Alignas] = ACTIONS(4366),
    [anon_sym_COLON] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_bitor] = ACTIONS(4366),
    [anon_sym_xor] = ACTIONS(4366),
    [anon_sym_bitand] = ACTIONS(4366),
    [anon_sym_not_eq] = ACTIONS(4366),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4366),
    [anon_sym_decltype] = ACTIONS(4366),
    [anon_sym_final] = ACTIONS(4366),
    [anon_sym_override] = ACTIONS(4366),
    [anon_sym_template] = ACTIONS(4366),
    [anon_sym_operator] = ACTIONS(4366),
    [anon_sym_try] = ACTIONS(4366),
    [anon_sym_requires] = ACTIONS(4366),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
    [anon_sym___launch_bounds__] = ACTIONS(4366),
  },
  [STATE(1046)] = {
    [sym_identifier] = ACTIONS(4330),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_RPAREN] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_TILDE] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4332),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4332),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4332),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4332),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4332),
    [anon_sym_SEMI] = ACTIONS(4332),
    [anon_sym___extension__] = ACTIONS(4330),
    [anon_sym___device__] = ACTIONS(4330),
    [anon_sym___host__] = ACTIONS(4330),
    [anon_sym___global__] = ACTIONS(4330),
    [anon_sym___forceinline__] = ACTIONS(4330),
    [anon_sym___noinline__] = ACTIONS(4330),
    [anon_sym_virtual] = ACTIONS(4330),
    [anon_sym_extern] = ACTIONS(4330),
    [anon_sym___attribute__] = ACTIONS(4330),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4332),
    [anon_sym___declspec] = ACTIONS(4330),
    [anon_sym___based] = ACTIONS(4330),
    [anon_sym___cdecl] = ACTIONS(4330),
    [anon_sym___clrcall] = ACTIONS(4330),
    [anon_sym___stdcall] = ACTIONS(4330),
    [anon_sym___fastcall] = ACTIONS(4330),
    [anon_sym___thiscall] = ACTIONS(4330),
    [anon_sym___vectorcall] = ACTIONS(4330),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_RBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4330),
    [anon_sym_static] = ACTIONS(4330),
    [anon_sym_RBRACK] = ACTIONS(4332),
    [anon_sym_EQ] = ACTIONS(4330),
    [anon_sym_register] = ACTIONS(4330),
    [anon_sym_inline] = ACTIONS(4330),
    [anon_sym___inline] = ACTIONS(4330),
    [anon_sym___inline__] = ACTIONS(4330),
    [anon_sym___forceinline] = ACTIONS(4330),
    [anon_sym_thread_local] = ACTIONS(4330),
    [anon_sym___thread] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4330),
    [anon_sym_volatile] = ACTIONS(4330),
    [anon_sym_restrict] = ACTIONS(4330),
    [anon_sym___restrict__] = ACTIONS(4330),
    [anon_sym__Atomic] = ACTIONS(4330),
    [anon_sym__Noreturn] = ACTIONS(4330),
    [anon_sym_noreturn] = ACTIONS(4330),
    [anon_sym__Nonnull] = ACTIONS(4330),
    [anon_sym_mutable] = ACTIONS(4330),
    [anon_sym_constinit] = ACTIONS(4330),
    [anon_sym_consteval] = ACTIONS(4330),
    [anon_sym___shared__] = ACTIONS(4330),
    [anon_sym___local__] = ACTIONS(4330),
    [anon_sym___constant__] = ACTIONS(4330),
    [anon_sym___managed__] = ACTIONS(4330),
    [anon_sym___grid_constant__] = ACTIONS(4330),
    [anon_sym_alignas] = ACTIONS(4330),
    [anon_sym__Alignas] = ACTIONS(4330),
    [anon_sym_COLON] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_bitor] = ACTIONS(4330),
    [anon_sym_xor] = ACTIONS(4330),
    [anon_sym_bitand] = ACTIONS(4330),
    [anon_sym_not_eq] = ACTIONS(4330),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4330),
    [anon_sym_decltype] = ACTIONS(4330),
    [anon_sym_final] = ACTIONS(4330),
    [anon_sym_override] = ACTIONS(4330),
    [anon_sym_template] = ACTIONS(4330),
    [anon_sym_operator] = ACTIONS(4330),
    [anon_sym_try] = ACTIONS(4330),
    [anon_sym_requires] = ACTIONS(4330),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
    [anon_sym___launch_bounds__] = ACTIONS(4330),
  },
  [STATE(1047)] = {
    [sym_expression] = STATE(5034),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1048)] = {
    [sym_compound_statement] = STATE(8548),
    [sym_expression] = STATE(5092),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8548),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1049)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4721),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1050)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4724),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1051)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4727),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1052)] = {
    [sym_expression] = STATE(4609),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1053)] = {
    [sym_expression] = STATE(4915),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(7887),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4734),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1054)] = {
    [sym_expression] = STATE(4614),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1055)] = {
    [sym_expression] = STATE(5078),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1056)] = {
    [sym_expression] = STATE(3244),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1057)] = {
    [sym_expression] = STATE(3221),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1058)] = {
    [sym_expression] = STATE(3378),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1059)] = {
    [sym_identifier] = ACTIONS(4330),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_RPAREN] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_TILDE] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4330),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4330),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4330),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4332),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4330),
    [anon_sym___extension__] = ACTIONS(4330),
    [anon_sym___device__] = ACTIONS(4330),
    [anon_sym___host__] = ACTIONS(4330),
    [anon_sym___global__] = ACTIONS(4330),
    [anon_sym___forceinline__] = ACTIONS(4330),
    [anon_sym___noinline__] = ACTIONS(4330),
    [anon_sym_virtual] = ACTIONS(4330),
    [anon_sym_extern] = ACTIONS(4330),
    [anon_sym___attribute__] = ACTIONS(4330),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4332),
    [anon_sym___declspec] = ACTIONS(4330),
    [anon_sym___based] = ACTIONS(4330),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4330),
    [anon_sym_static] = ACTIONS(4330),
    [anon_sym_EQ] = ACTIONS(4330),
    [anon_sym_register] = ACTIONS(4330),
    [anon_sym_inline] = ACTIONS(4330),
    [anon_sym___inline] = ACTIONS(4330),
    [anon_sym___inline__] = ACTIONS(4330),
    [anon_sym___forceinline] = ACTIONS(4330),
    [anon_sym_thread_local] = ACTIONS(4330),
    [anon_sym___thread] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4330),
    [anon_sym_volatile] = ACTIONS(4330),
    [anon_sym_restrict] = ACTIONS(4330),
    [anon_sym___restrict__] = ACTIONS(4330),
    [anon_sym__Atomic] = ACTIONS(4330),
    [anon_sym__Noreturn] = ACTIONS(4330),
    [anon_sym_noreturn] = ACTIONS(4330),
    [anon_sym__Nonnull] = ACTIONS(4330),
    [anon_sym_mutable] = ACTIONS(4330),
    [anon_sym_constinit] = ACTIONS(4330),
    [anon_sym_consteval] = ACTIONS(4330),
    [anon_sym___shared__] = ACTIONS(4330),
    [anon_sym___local__] = ACTIONS(4330),
    [anon_sym___constant__] = ACTIONS(4330),
    [anon_sym___managed__] = ACTIONS(4330),
    [anon_sym___grid_constant__] = ACTIONS(4330),
    [anon_sym_alignas] = ACTIONS(4330),
    [anon_sym__Alignas] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_STAR_EQ] = ACTIONS(4332),
    [anon_sym_SLASH_EQ] = ACTIONS(4332),
    [anon_sym_PERCENT_EQ] = ACTIONS(4332),
    [anon_sym_PLUS_EQ] = ACTIONS(4332),
    [anon_sym_DASH_EQ] = ACTIONS(4332),
    [anon_sym_LT_LT_EQ] = ACTIONS(4332),
    [anon_sym_GT_GT_EQ] = ACTIONS(4332),
    [anon_sym_AMP_EQ] = ACTIONS(4332),
    [anon_sym_CARET_EQ] = ACTIONS(4332),
    [anon_sym_PIPE_EQ] = ACTIONS(4332),
    [anon_sym_and_eq] = ACTIONS(4330),
    [anon_sym_or_eq] = ACTIONS(4330),
    [anon_sym_xor_eq] = ACTIONS(4330),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_bitor] = ACTIONS(4330),
    [anon_sym_xor] = ACTIONS(4330),
    [anon_sym_bitand] = ACTIONS(4330),
    [anon_sym_not_eq] = ACTIONS(4330),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4330),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4330),
    [anon_sym_decltype] = ACTIONS(4330),
    [anon_sym_template] = ACTIONS(4330),
    [anon_sym_operator] = ACTIONS(4330),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4332),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
    [anon_sym___launch_bounds__] = ACTIONS(4330),
  },
  [STATE(1060)] = {
    [sym_expression] = STATE(4882),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1061)] = {
    [sym_template_argument_list] = STATE(1113),
    [sym_identifier] = ACTIONS(4512),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4516),
    [anon_sym_COMMA] = ACTIONS(4516),
    [anon_sym_RPAREN] = ACTIONS(4516),
    [anon_sym_LPAREN2] = ACTIONS(4516),
    [anon_sym_TILDE] = ACTIONS(4519),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4523),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4516),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4523),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4514),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4526),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym___extension__] = ACTIONS(4512),
    [anon_sym___device__] = ACTIONS(4512),
    [anon_sym___host__] = ACTIONS(4512),
    [anon_sym___global__] = ACTIONS(4512),
    [anon_sym___forceinline__] = ACTIONS(4512),
    [anon_sym___noinline__] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym___attribute__] = ACTIONS(4512),
    [anon_sym___attribute] = ACTIONS(4512),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4519),
    [anon_sym___declspec] = ACTIONS(4512),
    [anon_sym___based] = ACTIONS(4512),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4523),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_EQ] = ACTIONS(4523),
    [anon_sym_register] = ACTIONS(4512),
    [anon_sym_inline] = ACTIONS(4512),
    [anon_sym___inline] = ACTIONS(4512),
    [anon_sym___inline__] = ACTIONS(4512),
    [anon_sym___forceinline] = ACTIONS(4512),
    [anon_sym_thread_local] = ACTIONS(4512),
    [anon_sym___thread] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4512),
    [anon_sym_volatile] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym___restrict__] = ACTIONS(4512),
    [anon_sym__Atomic] = ACTIONS(4512),
    [anon_sym__Noreturn] = ACTIONS(4512),
    [anon_sym_noreturn] = ACTIONS(4512),
    [anon_sym__Nonnull] = ACTIONS(4512),
    [anon_sym_mutable] = ACTIONS(4512),
    [anon_sym_constinit] = ACTIONS(4512),
    [anon_sym_consteval] = ACTIONS(4512),
    [anon_sym___shared__] = ACTIONS(4512),
    [anon_sym___local__] = ACTIONS(4512),
    [anon_sym___constant__] = ACTIONS(4512),
    [anon_sym___managed__] = ACTIONS(4512),
    [anon_sym___grid_constant__] = ACTIONS(4512),
    [anon_sym_alignas] = ACTIONS(4512),
    [anon_sym__Alignas] = ACTIONS(4512),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4514),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4521),
    [anon_sym_or_eq] = ACTIONS(4521),
    [anon_sym_xor_eq] = ACTIONS(4521),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4521),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4521),
    [anon_sym_not_eq] = ACTIONS(4521),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4514),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4512),
    [anon_sym_decltype] = ACTIONS(4512),
    [anon_sym_template] = ACTIONS(4512),
    [anon_sym_operator] = ACTIONS(4512),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
    [anon_sym___launch_bounds__] = ACTIONS(4512),
  },
  [STATE(1062)] = {
    [sym_expression] = STATE(5020),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1063)] = {
    [sym_expression] = STATE(5224),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1064)] = {
    [sym_expression] = STATE(5050),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1065)] = {
    [sym_identifier] = ACTIONS(4350),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_RPAREN] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_TILDE] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4350),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4350),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4350),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4352),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4350),
    [anon_sym___extension__] = ACTIONS(4350),
    [anon_sym___device__] = ACTIONS(4350),
    [anon_sym___host__] = ACTIONS(4350),
    [anon_sym___global__] = ACTIONS(4350),
    [anon_sym___forceinline__] = ACTIONS(4350),
    [anon_sym___noinline__] = ACTIONS(4350),
    [anon_sym_virtual] = ACTIONS(4350),
    [anon_sym_extern] = ACTIONS(4350),
    [anon_sym___attribute__] = ACTIONS(4350),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4352),
    [anon_sym___declspec] = ACTIONS(4350),
    [anon_sym___based] = ACTIONS(4350),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_static] = ACTIONS(4350),
    [anon_sym_EQ] = ACTIONS(4350),
    [anon_sym_register] = ACTIONS(4350),
    [anon_sym_inline] = ACTIONS(4350),
    [anon_sym___inline] = ACTIONS(4350),
    [anon_sym___inline__] = ACTIONS(4350),
    [anon_sym___forceinline] = ACTIONS(4350),
    [anon_sym_thread_local] = ACTIONS(4350),
    [anon_sym___thread] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4350),
    [anon_sym_volatile] = ACTIONS(4350),
    [anon_sym_restrict] = ACTIONS(4350),
    [anon_sym___restrict__] = ACTIONS(4350),
    [anon_sym__Atomic] = ACTIONS(4350),
    [anon_sym__Noreturn] = ACTIONS(4350),
    [anon_sym_noreturn] = ACTIONS(4350),
    [anon_sym__Nonnull] = ACTIONS(4350),
    [anon_sym_mutable] = ACTIONS(4350),
    [anon_sym_constinit] = ACTIONS(4350),
    [anon_sym_consteval] = ACTIONS(4350),
    [anon_sym___shared__] = ACTIONS(4350),
    [anon_sym___local__] = ACTIONS(4350),
    [anon_sym___constant__] = ACTIONS(4350),
    [anon_sym___managed__] = ACTIONS(4350),
    [anon_sym___grid_constant__] = ACTIONS(4350),
    [anon_sym_alignas] = ACTIONS(4350),
    [anon_sym__Alignas] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_STAR_EQ] = ACTIONS(4352),
    [anon_sym_SLASH_EQ] = ACTIONS(4352),
    [anon_sym_PERCENT_EQ] = ACTIONS(4352),
    [anon_sym_PLUS_EQ] = ACTIONS(4352),
    [anon_sym_DASH_EQ] = ACTIONS(4352),
    [anon_sym_LT_LT_EQ] = ACTIONS(4352),
    [anon_sym_GT_GT_EQ] = ACTIONS(4352),
    [anon_sym_AMP_EQ] = ACTIONS(4352),
    [anon_sym_CARET_EQ] = ACTIONS(4352),
    [anon_sym_PIPE_EQ] = ACTIONS(4352),
    [anon_sym_and_eq] = ACTIONS(4350),
    [anon_sym_or_eq] = ACTIONS(4350),
    [anon_sym_xor_eq] = ACTIONS(4350),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_bitor] = ACTIONS(4350),
    [anon_sym_xor] = ACTIONS(4350),
    [anon_sym_bitand] = ACTIONS(4350),
    [anon_sym_not_eq] = ACTIONS(4350),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4350),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4350),
    [anon_sym_decltype] = ACTIONS(4350),
    [anon_sym_template] = ACTIONS(4350),
    [anon_sym_operator] = ACTIONS(4350),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
    [anon_sym___launch_bounds__] = ACTIONS(4350),
  },
  [STATE(1066)] = {
    [sym_identifier] = ACTIONS(4356),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_RPAREN] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_TILDE] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4356),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4356),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4356),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4358),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4356),
    [anon_sym___extension__] = ACTIONS(4356),
    [anon_sym___device__] = ACTIONS(4356),
    [anon_sym___host__] = ACTIONS(4356),
    [anon_sym___global__] = ACTIONS(4356),
    [anon_sym___forceinline__] = ACTIONS(4356),
    [anon_sym___noinline__] = ACTIONS(4356),
    [anon_sym_virtual] = ACTIONS(4356),
    [anon_sym_extern] = ACTIONS(4356),
    [anon_sym___attribute__] = ACTIONS(4356),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4358),
    [anon_sym___declspec] = ACTIONS(4356),
    [anon_sym___based] = ACTIONS(4356),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_static] = ACTIONS(4356),
    [anon_sym_EQ] = ACTIONS(4356),
    [anon_sym_register] = ACTIONS(4356),
    [anon_sym_inline] = ACTIONS(4356),
    [anon_sym___inline] = ACTIONS(4356),
    [anon_sym___inline__] = ACTIONS(4356),
    [anon_sym___forceinline] = ACTIONS(4356),
    [anon_sym_thread_local] = ACTIONS(4356),
    [anon_sym___thread] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4356),
    [anon_sym_volatile] = ACTIONS(4356),
    [anon_sym_restrict] = ACTIONS(4356),
    [anon_sym___restrict__] = ACTIONS(4356),
    [anon_sym__Atomic] = ACTIONS(4356),
    [anon_sym__Noreturn] = ACTIONS(4356),
    [anon_sym_noreturn] = ACTIONS(4356),
    [anon_sym__Nonnull] = ACTIONS(4356),
    [anon_sym_mutable] = ACTIONS(4356),
    [anon_sym_constinit] = ACTIONS(4356),
    [anon_sym_consteval] = ACTIONS(4356),
    [anon_sym___shared__] = ACTIONS(4356),
    [anon_sym___local__] = ACTIONS(4356),
    [anon_sym___constant__] = ACTIONS(4356),
    [anon_sym___managed__] = ACTIONS(4356),
    [anon_sym___grid_constant__] = ACTIONS(4356),
    [anon_sym_alignas] = ACTIONS(4356),
    [anon_sym__Alignas] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_STAR_EQ] = ACTIONS(4358),
    [anon_sym_SLASH_EQ] = ACTIONS(4358),
    [anon_sym_PERCENT_EQ] = ACTIONS(4358),
    [anon_sym_PLUS_EQ] = ACTIONS(4358),
    [anon_sym_DASH_EQ] = ACTIONS(4358),
    [anon_sym_LT_LT_EQ] = ACTIONS(4358),
    [anon_sym_GT_GT_EQ] = ACTIONS(4358),
    [anon_sym_AMP_EQ] = ACTIONS(4358),
    [anon_sym_CARET_EQ] = ACTIONS(4358),
    [anon_sym_PIPE_EQ] = ACTIONS(4358),
    [anon_sym_and_eq] = ACTIONS(4356),
    [anon_sym_or_eq] = ACTIONS(4356),
    [anon_sym_xor_eq] = ACTIONS(4356),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_bitor] = ACTIONS(4356),
    [anon_sym_xor] = ACTIONS(4356),
    [anon_sym_bitand] = ACTIONS(4356),
    [anon_sym_not_eq] = ACTIONS(4356),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4356),
    [anon_sym_decltype] = ACTIONS(4356),
    [anon_sym_template] = ACTIONS(4356),
    [anon_sym_operator] = ACTIONS(4356),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4358),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
    [anon_sym___launch_bounds__] = ACTIONS(4356),
  },
  [STATE(1067)] = {
    [sym_identifier] = ACTIONS(4366),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_RPAREN] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_TILDE] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4366),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4366),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4366),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4368),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4366),
    [anon_sym___extension__] = ACTIONS(4366),
    [anon_sym___device__] = ACTIONS(4366),
    [anon_sym___host__] = ACTIONS(4366),
    [anon_sym___global__] = ACTIONS(4366),
    [anon_sym___forceinline__] = ACTIONS(4366),
    [anon_sym___noinline__] = ACTIONS(4366),
    [anon_sym_virtual] = ACTIONS(4366),
    [anon_sym_extern] = ACTIONS(4366),
    [anon_sym___attribute__] = ACTIONS(4366),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4368),
    [anon_sym___declspec] = ACTIONS(4366),
    [anon_sym___based] = ACTIONS(4366),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4366),
    [anon_sym_static] = ACTIONS(4366),
    [anon_sym_EQ] = ACTIONS(4366),
    [anon_sym_register] = ACTIONS(4366),
    [anon_sym_inline] = ACTIONS(4366),
    [anon_sym___inline] = ACTIONS(4366),
    [anon_sym___inline__] = ACTIONS(4366),
    [anon_sym___forceinline] = ACTIONS(4366),
    [anon_sym_thread_local] = ACTIONS(4366),
    [anon_sym___thread] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4366),
    [anon_sym_volatile] = ACTIONS(4366),
    [anon_sym_restrict] = ACTIONS(4366),
    [anon_sym___restrict__] = ACTIONS(4366),
    [anon_sym__Atomic] = ACTIONS(4366),
    [anon_sym__Noreturn] = ACTIONS(4366),
    [anon_sym_noreturn] = ACTIONS(4366),
    [anon_sym__Nonnull] = ACTIONS(4366),
    [anon_sym_mutable] = ACTIONS(4366),
    [anon_sym_constinit] = ACTIONS(4366),
    [anon_sym_consteval] = ACTIONS(4366),
    [anon_sym___shared__] = ACTIONS(4366),
    [anon_sym___local__] = ACTIONS(4366),
    [anon_sym___constant__] = ACTIONS(4366),
    [anon_sym___managed__] = ACTIONS(4366),
    [anon_sym___grid_constant__] = ACTIONS(4366),
    [anon_sym_alignas] = ACTIONS(4366),
    [anon_sym__Alignas] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_STAR_EQ] = ACTIONS(4368),
    [anon_sym_SLASH_EQ] = ACTIONS(4368),
    [anon_sym_PERCENT_EQ] = ACTIONS(4368),
    [anon_sym_PLUS_EQ] = ACTIONS(4368),
    [anon_sym_DASH_EQ] = ACTIONS(4368),
    [anon_sym_LT_LT_EQ] = ACTIONS(4368),
    [anon_sym_GT_GT_EQ] = ACTIONS(4368),
    [anon_sym_AMP_EQ] = ACTIONS(4368),
    [anon_sym_CARET_EQ] = ACTIONS(4368),
    [anon_sym_PIPE_EQ] = ACTIONS(4368),
    [anon_sym_and_eq] = ACTIONS(4366),
    [anon_sym_or_eq] = ACTIONS(4366),
    [anon_sym_xor_eq] = ACTIONS(4366),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_bitor] = ACTIONS(4366),
    [anon_sym_xor] = ACTIONS(4366),
    [anon_sym_bitand] = ACTIONS(4366),
    [anon_sym_not_eq] = ACTIONS(4366),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4366),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4366),
    [anon_sym_decltype] = ACTIONS(4366),
    [anon_sym_template] = ACTIONS(4366),
    [anon_sym_operator] = ACTIONS(4366),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4368),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
    [anon_sym___launch_bounds__] = ACTIONS(4366),
  },
  [STATE(1068)] = {
    [sym_expression] = STATE(3196),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1069)] = {
    [sym_expression] = STATE(4931),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(7805),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4740),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1070)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4557),
    [anon_sym_COMMA] = ACTIONS(4557),
    [anon_sym_RPAREN] = ACTIONS(4557),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4560),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_EQ] = ACTIONS(4564),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4562),
    [anon_sym_or_eq] = ACTIONS(4562),
    [anon_sym_xor_eq] = ACTIONS(4562),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4562),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_operator] = ACTIONS(4553),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4555),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(1071)] = {
    [sym_expression] = STATE(3580),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1072)] = {
    [sym_expression] = STATE(4900),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1073)] = {
    [sym_expression] = STATE(3961),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1074)] = {
    [sym_expression] = STATE(4860),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1075)] = {
    [sym_expression] = STATE(3588),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1076)] = {
    [sym_expression] = STATE(5190),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1077)] = {
    [sym_expression] = STATE(5192),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1078)] = {
    [sym_identifier] = ACTIONS(4402),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_RPAREN] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_TILDE] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4404),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4404),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4404),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4404),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4404),
    [anon_sym_SEMI] = ACTIONS(4404),
    [anon_sym___extension__] = ACTIONS(4402),
    [anon_sym___device__] = ACTIONS(4402),
    [anon_sym___host__] = ACTIONS(4402),
    [anon_sym___global__] = ACTIONS(4402),
    [anon_sym___forceinline__] = ACTIONS(4402),
    [anon_sym___noinline__] = ACTIONS(4402),
    [anon_sym_virtual] = ACTIONS(4402),
    [anon_sym_extern] = ACTIONS(4402),
    [anon_sym___attribute__] = ACTIONS(4402),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4404),
    [anon_sym___declspec] = ACTIONS(4402),
    [anon_sym___based] = ACTIONS(4402),
    [anon_sym___cdecl] = ACTIONS(4402),
    [anon_sym___clrcall] = ACTIONS(4402),
    [anon_sym___stdcall] = ACTIONS(4402),
    [anon_sym___fastcall] = ACTIONS(4402),
    [anon_sym___thiscall] = ACTIONS(4402),
    [anon_sym___vectorcall] = ACTIONS(4402),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_RBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4402),
    [anon_sym_static] = ACTIONS(4402),
    [anon_sym_RBRACK] = ACTIONS(4404),
    [anon_sym_EQ] = ACTIONS(4402),
    [anon_sym_register] = ACTIONS(4402),
    [anon_sym_inline] = ACTIONS(4402),
    [anon_sym___inline] = ACTIONS(4402),
    [anon_sym___inline__] = ACTIONS(4402),
    [anon_sym___forceinline] = ACTIONS(4402),
    [anon_sym_thread_local] = ACTIONS(4402),
    [anon_sym___thread] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4402),
    [anon_sym_volatile] = ACTIONS(4402),
    [anon_sym_restrict] = ACTIONS(4402),
    [anon_sym___restrict__] = ACTIONS(4402),
    [anon_sym__Atomic] = ACTIONS(4402),
    [anon_sym__Noreturn] = ACTIONS(4402),
    [anon_sym_noreturn] = ACTIONS(4402),
    [anon_sym__Nonnull] = ACTIONS(4402),
    [anon_sym_mutable] = ACTIONS(4402),
    [anon_sym_constinit] = ACTIONS(4402),
    [anon_sym_consteval] = ACTIONS(4402),
    [anon_sym___shared__] = ACTIONS(4402),
    [anon_sym___local__] = ACTIONS(4402),
    [anon_sym___constant__] = ACTIONS(4402),
    [anon_sym___managed__] = ACTIONS(4402),
    [anon_sym___grid_constant__] = ACTIONS(4402),
    [anon_sym_alignas] = ACTIONS(4402),
    [anon_sym__Alignas] = ACTIONS(4402),
    [anon_sym_COLON] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_bitor] = ACTIONS(4402),
    [anon_sym_xor] = ACTIONS(4402),
    [anon_sym_bitand] = ACTIONS(4402),
    [anon_sym_not_eq] = ACTIONS(4402),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4402),
    [anon_sym_decltype] = ACTIONS(4402),
    [anon_sym_final] = ACTIONS(4402),
    [anon_sym_override] = ACTIONS(4402),
    [anon_sym_template] = ACTIONS(4402),
    [anon_sym_operator] = ACTIONS(4402),
    [anon_sym_try] = ACTIONS(4402),
    [anon_sym_requires] = ACTIONS(4402),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
    [anon_sym___launch_bounds__] = ACTIONS(4402),
  },
  [STATE(1079)] = {
    [sym_expression] = STATE(3983),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1080)] = {
    [sym_expression] = STATE(5161),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1081)] = {
    [sym_expression] = STATE(3201),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1082)] = {
    [sym_expression] = STATE(3636),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4684),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4684),
    [anon_sym_AMP_AMP] = ACTIONS(4684),
    [anon_sym_AMP] = ACTIONS(4686),
    [anon_sym_LT] = ACTIONS(4684),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACE] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4684),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1083)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4744),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1084)] = {
    [sym_expression] = STATE(5016),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8760),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4751),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1085)] = {
    [sym_expression] = STATE(5315),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9412),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1086)] = {
    [sym_expression] = STATE(4883),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_initializer_list] = STATE(7591),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1087)] = {
    [sym_expression] = STATE(2632),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_initializer_list] = STATE(2799),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1088)] = {
    [sym_expression] = STATE(3661),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_initializer_list] = STATE(4246),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACE] = ACTIONS(3369),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1089)] = {
    [sym_expression] = STATE(4741),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1090)] = {
    [sym_expression] = STATE(4942),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(7992),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4757),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1091)] = {
    [sym_expression] = STATE(5098),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9410),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4760),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1092)] = {
    [sym_expression] = STATE(3886),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_initializer_list] = STATE(4354),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACE] = ACTIONS(3558),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1093)] = {
    [sym_expression] = STATE(5072),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_initializer_list] = STATE(5458),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACE] = ACTIONS(3920),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1094)] = {
    [sym_expression] = STATE(5009),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9081),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4764),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1095)] = {
    [sym_expression] = STATE(5093),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8757),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4766),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1096)] = {
    [sym_expression] = STATE(3935),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_initializer_list] = STATE(4374),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACE] = ACTIONS(3558),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1097)] = {
    [sym_expression] = STATE(3559),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_initializer_list] = STATE(4125),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACE] = ACTIONS(3209),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1098)] = {
    [sym_expression] = STATE(4922),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8325),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1099)] = {
    [sym_expression] = STATE(5229),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_initializer_list] = STATE(4357),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1100)] = {
    [sym_expression] = STATE(5061),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8584),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4770),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1101)] = {
    [sym_expression] = STATE(5087),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1102)] = {
    [sym_expression] = STATE(2632),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_initializer_list] = STATE(2799),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1103)] = {
    [sym_expression] = STATE(5069),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8585),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4776),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1104)] = {
    [sym_expression] = STATE(5222),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8661),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4778),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1105)] = {
    [sym_expression] = STATE(4573),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1106)] = {
    [sym_expression] = STATE(5112),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9230),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4782),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1107)] = {
    [sym_expression] = STATE(5137),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8944),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4784),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1108)] = {
    [sym_expression] = STATE(4839),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(4357),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1109)] = {
    [sym_expression] = STATE(5254),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8951),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4786),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1110)] = {
    [sym_expression] = STATE(5225),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9025),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4788),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1111)] = {
    [sym_expression] = STATE(5097),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8583),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4790),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1112)] = {
    [sym_expression] = STATE(2632),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_initializer_list] = STATE(2799),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1113)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4557),
    [anon_sym_COMMA] = ACTIONS(4557),
    [anon_sym_RPAREN] = ACTIONS(4557),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4560),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_EQ] = ACTIONS(4564),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4562),
    [anon_sym_or_eq] = ACTIONS(4562),
    [anon_sym_xor_eq] = ACTIONS(4562),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_operator] = ACTIONS(4553),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(1114)] = {
    [sym_expression] = STATE(5344),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8994),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1115)] = {
    [sym_expression] = STATE(4637),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_initializer_list] = STATE(4357),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1116)] = {
    [sym_expression] = STATE(5156),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_initializer_list] = STATE(5465),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACE] = ACTIONS(3920),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1117)] = {
    [sym_expression] = STATE(5368),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(9067),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1118)] = {
    [sym_expression] = STATE(5096),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_initializer_list] = STATE(5450),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACE] = ACTIONS(3906),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1119)] = {
    [sym_expression] = STATE(5151),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(8258),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1120)] = {
    [sym_expression] = STATE(5251),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9236),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4794),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1121)] = {
    [sym_expression] = STATE(5026),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(4357),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1122)] = {
    [sym_expression] = STATE(5155),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9033),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4796),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1123)] = {
    [sym_expression] = STATE(5176),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(4357),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1124)] = {
    [sym_expression] = STATE(4573),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1125)] = {
    [sym_expression] = STATE(5197),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_initializer_list] = STATE(5515),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACE] = ACTIONS(3906),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1126)] = {
    [sym_expression] = STATE(4878),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_initializer_list] = STATE(4357),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1127)] = {
    [sym_expression] = STATE(5126),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8325),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1128)] = {
    [sym_expression] = STATE(5189),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8254),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1129)] = {
    [sym_expression] = STATE(5216),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9235),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4798),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1130)] = {
    [sym_expression] = STATE(5252),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8593),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4800),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1131)] = {
    [sym_expression] = STATE(3633),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_initializer_list] = STATE(2799),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1132)] = {
    [sym_expression] = STATE(5205),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(8300),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1133)] = {
    [sym_expression] = STATE(5147),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9022),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4804),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1134)] = {
    [sym_expression] = STATE(5237),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(9429),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1135)] = {
    [sym_expression] = STATE(3298),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_initializer_list] = STATE(3925),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(2936),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1136)] = {
    [sym_expression] = STATE(5154),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8620),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4808),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1137)] = {
    [sym_expression] = STATE(5019),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8659),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4810),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1138)] = {
    [sym_expression] = STATE(4741),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_initializer_list] = STATE(4378),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1139)] = {
    [sym_expression] = STATE(5159),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(8817),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_COLON] = ACTIONS(4812),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1140)] = {
    [sym_expression] = STATE(3902),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4814),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1141)] = {
    [sym_expression] = STATE(3442),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4817),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1142)] = {
    [sym_expression] = STATE(3276),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4820),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1143)] = {
    [sym_expression] = STATE(5146),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4823),
    [anon_sym_LPAREN2] = ACTIONS(4825),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1144)] = {
    [sym_expression] = STATE(3902),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4827),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1145)] = {
    [sym_expression] = STATE(5316),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4830),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1146)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4832),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1147)] = {
    [sym_expression] = STATE(5325),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4834),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1148)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4836),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1149)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4838),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1150)] = {
    [sym_expression] = STATE(3525),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4840),
    [anon_sym_LPAREN2] = ACTIONS(4842),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1151)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4844),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1152)] = {
    [sym_expression] = STATE(5032),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4846),
    [anon_sym_LPAREN2] = ACTIONS(4848),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1153)] = {
    [sym_expression] = STATE(3904),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4850),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1154)] = {
    [sym_expression] = STATE(3904),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4853),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1155)] = {
    [sym_expression] = STATE(3904),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4856),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1156)] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4859),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1157)] = {
    [sym_expression] = STATE(4942),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(7992),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1158)] = {
    [sym_expression] = STATE(4015),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4862),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1159)] = {
    [sym_expression] = STATE(3907),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4865),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1160)] = {
    [sym_expression] = STATE(3319),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4859),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1161)] = {
    [sym_expression] = STATE(3308),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4850),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1162)] = {
    [sym_expression] = STATE(3322),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4862),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1163)] = {
    [sym_expression] = STATE(5294),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_RPAREN] = ACTIONS(4868),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1164)] = {
    [sym_expression] = STATE(3260),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4870),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1165)] = {
    [sym_expression] = STATE(3308),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4853),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1166)] = {
    [sym_expression] = STATE(5348),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4873),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1167)] = {
    [sym_expression] = STATE(4704),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4875),
    [anon_sym_LPAREN2] = ACTIONS(4877),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1168)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4879),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1169)] = {
    [sym_expression] = STATE(5276),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4881),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1170)] = {
    [sym_expression] = STATE(5230),
    [sym__string] = STATE(4873),
    [sym_comma_expression] = STATE(7992),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1171)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4883),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1172)] = {
    [sym_expression] = STATE(4704),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4875),
    [anon_sym_LPAREN2] = ACTIONS(4885),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1173)] = {
    [sym_expression] = STATE(3391),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4887),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1174)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4890),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1175)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4892),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1176)] = {
    [sym_expression] = STATE(3408),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4827),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1177)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4894),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1178)] = {
    [sym_expression] = STATE(3909),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4896),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1179)] = {
    [sym_expression] = STATE(5301),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4899),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1180)] = {
    [sym_expression] = STATE(5369),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4901),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1181)] = {
    [sym_expression] = STATE(3308),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4856),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1182)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4903),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1183)] = {
    [sym_expression] = STATE(5312),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4905),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1184)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4907),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1185)] = {
    [sym_expression] = STATE(3260),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4909),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1186)] = {
    [sym_expression] = STATE(4576),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4875),
    [anon_sym_LPAREN2] = ACTIONS(4912),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1187)] = {
    [sym_expression] = STATE(3260),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4914),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1188)] = {
    [sym_expression] = STATE(5272),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4917),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1189)] = {
    [sym_expression] = STATE(4865),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym_SEMI] = ACTIONS(4919),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(4921),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1190)] = {
    [sym_expression] = STATE(5279),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4923),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1191)] = {
    [sym_expression] = STATE(3609),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4925),
    [anon_sym_LPAREN2] = ACTIONS(4927),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1192)] = {
    [sym_expression] = STATE(3911),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4929),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1193)] = {
    [sym_expression] = STATE(5268),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4932),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1194)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4934),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1195)] = {
    [sym_expression] = STATE(3339),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4865),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1196)] = {
    [sym_expression] = STATE(5274),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4936),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1197)] = {
    [sym_expression] = STATE(3260),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4938),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1198)] = {
    [sym_expression] = STATE(3391),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4941),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1199)] = {
    [sym_expression] = STATE(5284),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4944),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1200)] = {
    [sym_expression] = STATE(3406),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4946),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1201)] = {
    [sym_expression] = STATE(3912),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4949),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1202)] = {
    [sym_expression] = STATE(5367),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4952),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1203)] = {
    [sym_expression] = STATE(3406),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4896),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1204)] = {
    [sym_expression] = STATE(3442),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4929),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1205)] = {
    [sym_expression] = STATE(5330),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4954),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1206)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4956),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1207)] = {
    [sym_expression] = STATE(3366),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4958),
    [anon_sym_LPAREN2] = ACTIONS(4960),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1208)] = {
    [sym_expression] = STATE(5364),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4962),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1209)] = {
    [sym_expression] = STATE(4865),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym_SEMI] = ACTIONS(4964),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(4921),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1210)] = {
    [sym_expression] = STATE(3912),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4966),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1211)] = {
    [sym_expression] = STATE(5371),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4969),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1212)] = {
    [sym_expression] = STATE(3913),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4870),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1213)] = {
    [sym_expression] = STATE(5360),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4971),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1214)] = {
    [sym_expression] = STATE(3913),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4909),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1215)] = {
    [sym_expression] = STATE(3913),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4914),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1216)] = {
    [sym_expression] = STATE(5049),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4875),
    [anon_sym_LPAREN2] = ACTIONS(4973),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1217)] = {
    [sym_expression] = STATE(3913),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4938),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1218)] = {
    [sym_expression] = STATE(3919),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4941),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1219)] = {
    [sym_expression] = STATE(3919),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4887),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1220)] = {
    [sym_expression] = STATE(3408),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4814),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1221)] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4975),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1222)] = {
    [sym_expression] = STATE(4015),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4978),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1223)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4981),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1224)] = {
    [sym_expression] = STATE(3617),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4983),
    [anon_sym_LPAREN2] = ACTIONS(4985),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1225)] = {
    [sym_expression] = STATE(2681),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4983),
    [anon_sym_LPAREN2] = ACTIONS(4987),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1226)] = {
    [sym_expression] = STATE(3319),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4975),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1227)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4989),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1228)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4991),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1229)] = {
    [sym_expression] = STATE(4576),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4875),
    [anon_sym_LPAREN2] = ACTIONS(4993),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1230)] = {
    [sym_expression] = STATE(2681),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4983),
    [anon_sym_LPAREN2] = ACTIONS(4995),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1231)] = {
    [sym_expression] = STATE(5255),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(4997),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1232)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(4999),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1233)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(5001),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1234)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(5003),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1235)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(5005),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1236)] = {
    [sym_expression] = STATE(3907),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5007),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1237)] = {
    [sym_expression] = STATE(3909),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4946),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1238)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(5010),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1239)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_RBRACK] = ACTIONS(5012),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1240)] = {
    [sym_expression] = STATE(2681),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4983),
    [anon_sym_LPAREN2] = ACTIONS(5014),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1241)] = {
    [sym_expression] = STATE(3276),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4949),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1242)] = {
    [sym_expression] = STATE(3911),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4817),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1243)] = {
    [sym_expression] = STATE(3912),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4820),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1244)] = {
    [sym_expression] = STATE(4865),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym_SEMI] = ACTIONS(5016),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(4921),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1245)] = {
    [sym_expression] = STATE(3276),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4966),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1246)] = {
    [sym_expression] = STATE(5329),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(5018),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1247)] = {
    [sym_expression] = STATE(3322),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4978),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1248)] = {
    [sym_expression] = STATE(3339),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5007),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1249)] = {
    [sym_expression] = STATE(3781),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5020),
    [anon_sym_LPAREN2] = ACTIONS(5022),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1250)] = {
    [sym_expression] = STATE(5305),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(5024),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1251)] = {
    [sym_expression] = STATE(5310),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym_SEMI] = ACTIONS(5026),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1252)] = {
    [sym_expression] = STATE(5284),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5028),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1253)] = {
    [sym_expression] = STATE(4851),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(5030),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1254)] = {
    [sym_expression] = STATE(5322),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1255)] = {
    [sym_expression] = STATE(3156),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1256)] = {
    [sym_expression] = STATE(4950),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1257)] = {
    [sym_expression] = STATE(5303),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1258)] = {
    [sym_expression] = STATE(4698),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1259)] = {
    [sym_expression] = STATE(5355),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1260)] = {
    [sym_expression] = STATE(5160),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(5032),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1261)] = {
    [sym_expression] = STATE(5173),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1262)] = {
    [sym_expression] = STATE(3910),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1263)] = {
    [sym_expression] = STATE(5054),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(5034),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1264)] = {
    [sym_expression] = STATE(5342),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1265)] = {
    [sym_expression] = STATE(5071),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1266)] = {
    [sym_expression] = STATE(5287),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1267)] = {
    [sym_expression] = STATE(3265),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(5036),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1268)] = {
    [sym_expression] = STATE(3398),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1269)] = {
    [sym_expression] = STATE(3902),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1270)] = {
    [sym_expression] = STATE(3904),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1271)] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1272)] = {
    [sym_expression] = STATE(4015),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1273)] = {
    [sym_expression] = STATE(3907),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1274)] = {
    [sym_expression] = STATE(3909),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1275)] = {
    [sym_expression] = STATE(3911),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1276)] = {
    [sym_expression] = STATE(3912),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1277)] = {
    [sym_expression] = STATE(3913),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1278)] = {
    [sym_expression] = STATE(3919),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1279)] = {
    [sym_expression] = STATE(5144),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1280)] = {
    [sym_expression] = STATE(4838),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1281)] = {
    [sym_expression] = STATE(3334),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1282)] = {
    [sym_expression] = STATE(3175),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1283)] = {
    [sym_expression] = STATE(3413),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(5038),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1284)] = {
    [sym_expression] = STATE(5233),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1285)] = {
    [sym_expression] = STATE(5356),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1286)] = {
    [sym_expression] = STATE(5021),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1287)] = {
    [sym_expression] = STATE(3194),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1288)] = {
    [sym_expression] = STATE(2675),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1289)] = {
    [sym_expression] = STATE(3197),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1290)] = {
    [sym_expression] = STATE(3198),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1291)] = {
    [sym_expression] = STATE(3199),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1292)] = {
    [sym_expression] = STATE(3203),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1293)] = {
    [sym_expression] = STATE(3205),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1294)] = {
    [sym_expression] = STATE(3206),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1295)] = {
    [sym_expression] = STATE(3195),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1296)] = {
    [sym_expression] = STATE(3176),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1297)] = {
    [sym_expression] = STATE(3283),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1298)] = {
    [sym_expression] = STATE(5361),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1299)] = {
    [sym_expression] = STATE(3791),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(5040),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1300)] = {
    [sym_expression] = STATE(3792),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1301)] = {
    [sym_expression] = STATE(3845),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(5042),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1302)] = {
    [sym_expression] = STATE(3922),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1303)] = {
    [sym_expression] = STATE(5110),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1304)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(5044),
  },
  [STATE(1305)] = {
    [sym_expression] = STATE(4679),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1306)] = {
    [sym_expression] = STATE(5273),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1307)] = {
    [sym_expression] = STATE(5213),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1308)] = {
    [sym_expression] = STATE(3975),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1309)] = {
    [sym_expression] = STATE(4004),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1310)] = {
    [sym_expression] = STATE(5063),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(5046),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1311)] = {
    [sym_expression] = STATE(5065),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1312)] = {
    [sym_expression] = STATE(5013),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(5048),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1313)] = {
    [sym_expression] = STATE(5123),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1314)] = {
    [sym_expression] = STATE(5375),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1315)] = {
    [sym_expression] = STATE(4725),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(5050),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1316)] = {
    [sym_expression] = STATE(5067),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1317)] = {
    [sym_expression] = STATE(5108),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1318)] = {
    [sym_expression] = STATE(3527),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(5052),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1319)] = {
    [sym_expression] = STATE(3529),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1320)] = {
    [sym_expression] = STATE(3534),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(5054),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1321)] = {
    [sym_expression] = STATE(3558),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1322)] = {
    [sym_expression] = STATE(3263),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1323)] = {
    [sym_expression] = STATE(3585),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1324)] = {
    [sym_expression] = STATE(3597),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1325)] = {
    [sym_expression] = STATE(3611),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(5056),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1326)] = {
    [sym_expression] = STATE(3612),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1327)] = {
    [sym_expression] = STATE(3638),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(5058),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1328)] = {
    [sym_expression] = STATE(3659),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1329)] = {
    [sym_expression] = STATE(3461),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1330)] = {
    [sym_expression] = STATE(5286),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1331)] = {
    [sym_expression] = STATE(3447),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1332)] = {
    [sym_expression] = STATE(3228),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(5060),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1333)] = {
    [sym_expression] = STATE(3257),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1334)] = {
    [sym_identifier] = ACTIONS(4330),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_RPAREN] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_TILDE] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4330),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4330),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4330),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4332),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4330),
    [anon_sym___extension__] = ACTIONS(4330),
    [anon_sym___device__] = ACTIONS(4330),
    [anon_sym___host__] = ACTIONS(4330),
    [anon_sym___global__] = ACTIONS(4330),
    [anon_sym___forceinline__] = ACTIONS(4330),
    [anon_sym___noinline__] = ACTIONS(4330),
    [anon_sym_virtual] = ACTIONS(4330),
    [anon_sym_extern] = ACTIONS(4330),
    [anon_sym___attribute__] = ACTIONS(4330),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4332),
    [anon_sym___declspec] = ACTIONS(4330),
    [anon_sym___based] = ACTIONS(4330),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4330),
    [anon_sym_static] = ACTIONS(4330),
    [anon_sym_EQ] = ACTIONS(4330),
    [anon_sym_register] = ACTIONS(4330),
    [anon_sym_inline] = ACTIONS(4330),
    [anon_sym___inline] = ACTIONS(4330),
    [anon_sym___inline__] = ACTIONS(4330),
    [anon_sym___forceinline] = ACTIONS(4330),
    [anon_sym_thread_local] = ACTIONS(4330),
    [anon_sym___thread] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4330),
    [anon_sym_volatile] = ACTIONS(4330),
    [anon_sym_restrict] = ACTIONS(4330),
    [anon_sym___restrict__] = ACTIONS(4330),
    [anon_sym__Atomic] = ACTIONS(4330),
    [anon_sym__Noreturn] = ACTIONS(4330),
    [anon_sym_noreturn] = ACTIONS(4330),
    [anon_sym__Nonnull] = ACTIONS(4330),
    [anon_sym_mutable] = ACTIONS(4330),
    [anon_sym_constinit] = ACTIONS(4330),
    [anon_sym_consteval] = ACTIONS(4330),
    [anon_sym___shared__] = ACTIONS(4330),
    [anon_sym___local__] = ACTIONS(4330),
    [anon_sym___constant__] = ACTIONS(4330),
    [anon_sym___managed__] = ACTIONS(4330),
    [anon_sym___grid_constant__] = ACTIONS(4330),
    [anon_sym_alignas] = ACTIONS(4330),
    [anon_sym__Alignas] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_STAR_EQ] = ACTIONS(4332),
    [anon_sym_SLASH_EQ] = ACTIONS(4332),
    [anon_sym_PERCENT_EQ] = ACTIONS(4332),
    [anon_sym_PLUS_EQ] = ACTIONS(4332),
    [anon_sym_DASH_EQ] = ACTIONS(4332),
    [anon_sym_LT_LT_EQ] = ACTIONS(4332),
    [anon_sym_GT_GT_EQ] = ACTIONS(4332),
    [anon_sym_AMP_EQ] = ACTIONS(4332),
    [anon_sym_CARET_EQ] = ACTIONS(4332),
    [anon_sym_PIPE_EQ] = ACTIONS(4332),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_bitor] = ACTIONS(4330),
    [anon_sym_xor] = ACTIONS(4330),
    [anon_sym_bitand] = ACTIONS(4330),
    [anon_sym_not_eq] = ACTIONS(4330),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4330),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4330),
    [anon_sym_decltype] = ACTIONS(4330),
    [anon_sym_template] = ACTIONS(4330),
    [anon_sym_operator] = ACTIONS(4330),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4332),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
    [anon_sym___launch_bounds__] = ACTIONS(4330),
  },
  [STATE(1335)] = {
    [sym_expression] = STATE(3247),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1336)] = {
    [sym_identifier] = ACTIONS(4396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_RPAREN] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_TILDE] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4396),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4396),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4396),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4398),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4396),
    [anon_sym___extension__] = ACTIONS(4396),
    [anon_sym___device__] = ACTIONS(4396),
    [anon_sym___host__] = ACTIONS(4396),
    [anon_sym___global__] = ACTIONS(4396),
    [anon_sym___forceinline__] = ACTIONS(4396),
    [anon_sym___noinline__] = ACTIONS(4396),
    [anon_sym_virtual] = ACTIONS(4396),
    [anon_sym_extern] = ACTIONS(4396),
    [anon_sym___attribute__] = ACTIONS(4396),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4398),
    [anon_sym___declspec] = ACTIONS(4396),
    [anon_sym___based] = ACTIONS(4396),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4396),
    [anon_sym_static] = ACTIONS(4396),
    [anon_sym_EQ] = ACTIONS(4396),
    [anon_sym_register] = ACTIONS(4396),
    [anon_sym_inline] = ACTIONS(4396),
    [anon_sym___inline] = ACTIONS(4396),
    [anon_sym___inline__] = ACTIONS(4396),
    [anon_sym___forceinline] = ACTIONS(4396),
    [anon_sym_thread_local] = ACTIONS(4396),
    [anon_sym___thread] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4396),
    [anon_sym_volatile] = ACTIONS(4396),
    [anon_sym_restrict] = ACTIONS(4396),
    [anon_sym___restrict__] = ACTIONS(4396),
    [anon_sym__Atomic] = ACTIONS(4396),
    [anon_sym__Noreturn] = ACTIONS(4396),
    [anon_sym_noreturn] = ACTIONS(4396),
    [anon_sym__Nonnull] = ACTIONS(4396),
    [anon_sym_mutable] = ACTIONS(4396),
    [anon_sym_constinit] = ACTIONS(4396),
    [anon_sym_consteval] = ACTIONS(4396),
    [anon_sym___shared__] = ACTIONS(4396),
    [anon_sym___local__] = ACTIONS(4396),
    [anon_sym___constant__] = ACTIONS(4396),
    [anon_sym___managed__] = ACTIONS(4396),
    [anon_sym___grid_constant__] = ACTIONS(4396),
    [anon_sym_alignas] = ACTIONS(4396),
    [anon_sym__Alignas] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_STAR_EQ] = ACTIONS(4398),
    [anon_sym_SLASH_EQ] = ACTIONS(4398),
    [anon_sym_PERCENT_EQ] = ACTIONS(4398),
    [anon_sym_PLUS_EQ] = ACTIONS(4398),
    [anon_sym_DASH_EQ] = ACTIONS(4398),
    [anon_sym_LT_LT_EQ] = ACTIONS(4398),
    [anon_sym_GT_GT_EQ] = ACTIONS(4398),
    [anon_sym_AMP_EQ] = ACTIONS(4398),
    [anon_sym_CARET_EQ] = ACTIONS(4398),
    [anon_sym_PIPE_EQ] = ACTIONS(4398),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_bitor] = ACTIONS(4396),
    [anon_sym_xor] = ACTIONS(4396),
    [anon_sym_bitand] = ACTIONS(4396),
    [anon_sym_not_eq] = ACTIONS(4396),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4396),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4396),
    [anon_sym_decltype] = ACTIONS(4396),
    [anon_sym_template] = ACTIONS(4396),
    [anon_sym_operator] = ACTIONS(4396),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4398),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
    [anon_sym___launch_bounds__] = ACTIONS(4396),
  },
  [STATE(1337)] = {
    [sym_identifier] = ACTIONS(4402),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_RPAREN] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_TILDE] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4402),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4402),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4402),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4404),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4402),
    [anon_sym___extension__] = ACTIONS(4402),
    [anon_sym___device__] = ACTIONS(4402),
    [anon_sym___host__] = ACTIONS(4402),
    [anon_sym___global__] = ACTIONS(4402),
    [anon_sym___forceinline__] = ACTIONS(4402),
    [anon_sym___noinline__] = ACTIONS(4402),
    [anon_sym_virtual] = ACTIONS(4402),
    [anon_sym_extern] = ACTIONS(4402),
    [anon_sym___attribute__] = ACTIONS(4402),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4404),
    [anon_sym___declspec] = ACTIONS(4402),
    [anon_sym___based] = ACTIONS(4402),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4402),
    [anon_sym_static] = ACTIONS(4402),
    [anon_sym_EQ] = ACTIONS(4402),
    [anon_sym_register] = ACTIONS(4402),
    [anon_sym_inline] = ACTIONS(4402),
    [anon_sym___inline] = ACTIONS(4402),
    [anon_sym___inline__] = ACTIONS(4402),
    [anon_sym___forceinline] = ACTIONS(4402),
    [anon_sym_thread_local] = ACTIONS(4402),
    [anon_sym___thread] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4402),
    [anon_sym_volatile] = ACTIONS(4402),
    [anon_sym_restrict] = ACTIONS(4402),
    [anon_sym___restrict__] = ACTIONS(4402),
    [anon_sym__Atomic] = ACTIONS(4402),
    [anon_sym__Noreturn] = ACTIONS(4402),
    [anon_sym_noreturn] = ACTIONS(4402),
    [anon_sym__Nonnull] = ACTIONS(4402),
    [anon_sym_mutable] = ACTIONS(4402),
    [anon_sym_constinit] = ACTIONS(4402),
    [anon_sym_consteval] = ACTIONS(4402),
    [anon_sym___shared__] = ACTIONS(4402),
    [anon_sym___local__] = ACTIONS(4402),
    [anon_sym___constant__] = ACTIONS(4402),
    [anon_sym___managed__] = ACTIONS(4402),
    [anon_sym___grid_constant__] = ACTIONS(4402),
    [anon_sym_alignas] = ACTIONS(4402),
    [anon_sym__Alignas] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_STAR_EQ] = ACTIONS(4404),
    [anon_sym_SLASH_EQ] = ACTIONS(4404),
    [anon_sym_PERCENT_EQ] = ACTIONS(4404),
    [anon_sym_PLUS_EQ] = ACTIONS(4404),
    [anon_sym_DASH_EQ] = ACTIONS(4404),
    [anon_sym_LT_LT_EQ] = ACTIONS(4404),
    [anon_sym_GT_GT_EQ] = ACTIONS(4404),
    [anon_sym_AMP_EQ] = ACTIONS(4404),
    [anon_sym_CARET_EQ] = ACTIONS(4404),
    [anon_sym_PIPE_EQ] = ACTIONS(4404),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_bitor] = ACTIONS(4402),
    [anon_sym_xor] = ACTIONS(4402),
    [anon_sym_bitand] = ACTIONS(4402),
    [anon_sym_not_eq] = ACTIONS(4402),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4402),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4402),
    [anon_sym_decltype] = ACTIONS(4402),
    [anon_sym_template] = ACTIONS(4402),
    [anon_sym_operator] = ACTIONS(4402),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4404),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
    [anon_sym___launch_bounds__] = ACTIONS(4402),
  },
  [STATE(1338)] = {
    [sym_identifier] = ACTIONS(4408),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_RPAREN] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_TILDE] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4408),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4408),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4408),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4410),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4408),
    [anon_sym___extension__] = ACTIONS(4408),
    [anon_sym___device__] = ACTIONS(4408),
    [anon_sym___host__] = ACTIONS(4408),
    [anon_sym___global__] = ACTIONS(4408),
    [anon_sym___forceinline__] = ACTIONS(4408),
    [anon_sym___noinline__] = ACTIONS(4408),
    [anon_sym_virtual] = ACTIONS(4408),
    [anon_sym_extern] = ACTIONS(4408),
    [anon_sym___attribute__] = ACTIONS(4408),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4410),
    [anon_sym___declspec] = ACTIONS(4408),
    [anon_sym___based] = ACTIONS(4408),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4408),
    [anon_sym_static] = ACTIONS(4408),
    [anon_sym_EQ] = ACTIONS(4408),
    [anon_sym_register] = ACTIONS(4408),
    [anon_sym_inline] = ACTIONS(4408),
    [anon_sym___inline] = ACTIONS(4408),
    [anon_sym___inline__] = ACTIONS(4408),
    [anon_sym___forceinline] = ACTIONS(4408),
    [anon_sym_thread_local] = ACTIONS(4408),
    [anon_sym___thread] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4408),
    [anon_sym_volatile] = ACTIONS(4408),
    [anon_sym_restrict] = ACTIONS(4408),
    [anon_sym___restrict__] = ACTIONS(4408),
    [anon_sym__Atomic] = ACTIONS(4408),
    [anon_sym__Noreturn] = ACTIONS(4408),
    [anon_sym_noreturn] = ACTIONS(4408),
    [anon_sym__Nonnull] = ACTIONS(4408),
    [anon_sym_mutable] = ACTIONS(4408),
    [anon_sym_constinit] = ACTIONS(4408),
    [anon_sym_consteval] = ACTIONS(4408),
    [anon_sym___shared__] = ACTIONS(4408),
    [anon_sym___local__] = ACTIONS(4408),
    [anon_sym___constant__] = ACTIONS(4408),
    [anon_sym___managed__] = ACTIONS(4408),
    [anon_sym___grid_constant__] = ACTIONS(4408),
    [anon_sym_alignas] = ACTIONS(4408),
    [anon_sym__Alignas] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_STAR_EQ] = ACTIONS(4410),
    [anon_sym_SLASH_EQ] = ACTIONS(4410),
    [anon_sym_PERCENT_EQ] = ACTIONS(4410),
    [anon_sym_PLUS_EQ] = ACTIONS(4410),
    [anon_sym_DASH_EQ] = ACTIONS(4410),
    [anon_sym_LT_LT_EQ] = ACTIONS(4410),
    [anon_sym_GT_GT_EQ] = ACTIONS(4410),
    [anon_sym_AMP_EQ] = ACTIONS(4410),
    [anon_sym_CARET_EQ] = ACTIONS(4410),
    [anon_sym_PIPE_EQ] = ACTIONS(4410),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_bitor] = ACTIONS(4408),
    [anon_sym_xor] = ACTIONS(4408),
    [anon_sym_bitand] = ACTIONS(4408),
    [anon_sym_not_eq] = ACTIONS(4408),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4408),
    [anon_sym_decltype] = ACTIONS(4408),
    [anon_sym_template] = ACTIONS(4408),
    [anon_sym_operator] = ACTIONS(4408),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4410),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
    [anon_sym___launch_bounds__] = ACTIONS(4408),
  },
  [STATE(1339)] = {
    [sym_expression] = STATE(3236),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1340)] = {
    [sym_identifier] = ACTIONS(4350),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_RPAREN] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_TILDE] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4350),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4350),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4350),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4352),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4350),
    [anon_sym___extension__] = ACTIONS(4350),
    [anon_sym___device__] = ACTIONS(4350),
    [anon_sym___host__] = ACTIONS(4350),
    [anon_sym___global__] = ACTIONS(4350),
    [anon_sym___forceinline__] = ACTIONS(4350),
    [anon_sym___noinline__] = ACTIONS(4350),
    [anon_sym_virtual] = ACTIONS(4350),
    [anon_sym_extern] = ACTIONS(4350),
    [anon_sym___attribute__] = ACTIONS(4350),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4352),
    [anon_sym___declspec] = ACTIONS(4350),
    [anon_sym___based] = ACTIONS(4350),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_static] = ACTIONS(4350),
    [anon_sym_EQ] = ACTIONS(4350),
    [anon_sym_register] = ACTIONS(4350),
    [anon_sym_inline] = ACTIONS(4350),
    [anon_sym___inline] = ACTIONS(4350),
    [anon_sym___inline__] = ACTIONS(4350),
    [anon_sym___forceinline] = ACTIONS(4350),
    [anon_sym_thread_local] = ACTIONS(4350),
    [anon_sym___thread] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4350),
    [anon_sym_volatile] = ACTIONS(4350),
    [anon_sym_restrict] = ACTIONS(4350),
    [anon_sym___restrict__] = ACTIONS(4350),
    [anon_sym__Atomic] = ACTIONS(4350),
    [anon_sym__Noreturn] = ACTIONS(4350),
    [anon_sym_noreturn] = ACTIONS(4350),
    [anon_sym__Nonnull] = ACTIONS(4350),
    [anon_sym_mutable] = ACTIONS(4350),
    [anon_sym_constinit] = ACTIONS(4350),
    [anon_sym_consteval] = ACTIONS(4350),
    [anon_sym___shared__] = ACTIONS(4350),
    [anon_sym___local__] = ACTIONS(4350),
    [anon_sym___constant__] = ACTIONS(4350),
    [anon_sym___managed__] = ACTIONS(4350),
    [anon_sym___grid_constant__] = ACTIONS(4350),
    [anon_sym_alignas] = ACTIONS(4350),
    [anon_sym__Alignas] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_STAR_EQ] = ACTIONS(4352),
    [anon_sym_SLASH_EQ] = ACTIONS(4352),
    [anon_sym_PERCENT_EQ] = ACTIONS(4352),
    [anon_sym_PLUS_EQ] = ACTIONS(4352),
    [anon_sym_DASH_EQ] = ACTIONS(4352),
    [anon_sym_LT_LT_EQ] = ACTIONS(4352),
    [anon_sym_GT_GT_EQ] = ACTIONS(4352),
    [anon_sym_AMP_EQ] = ACTIONS(4352),
    [anon_sym_CARET_EQ] = ACTIONS(4352),
    [anon_sym_PIPE_EQ] = ACTIONS(4352),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_bitor] = ACTIONS(4350),
    [anon_sym_xor] = ACTIONS(4350),
    [anon_sym_bitand] = ACTIONS(4350),
    [anon_sym_not_eq] = ACTIONS(4350),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4350),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4350),
    [anon_sym_decltype] = ACTIONS(4350),
    [anon_sym_template] = ACTIONS(4350),
    [anon_sym_operator] = ACTIONS(4350),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
    [anon_sym___launch_bounds__] = ACTIONS(4350),
  },
  [STATE(1341)] = {
    [sym_identifier] = ACTIONS(4356),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_RPAREN] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_TILDE] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4356),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4356),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4356),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4358),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4356),
    [anon_sym___extension__] = ACTIONS(4356),
    [anon_sym___device__] = ACTIONS(4356),
    [anon_sym___host__] = ACTIONS(4356),
    [anon_sym___global__] = ACTIONS(4356),
    [anon_sym___forceinline__] = ACTIONS(4356),
    [anon_sym___noinline__] = ACTIONS(4356),
    [anon_sym_virtual] = ACTIONS(4356),
    [anon_sym_extern] = ACTIONS(4356),
    [anon_sym___attribute__] = ACTIONS(4356),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4358),
    [anon_sym___declspec] = ACTIONS(4356),
    [anon_sym___based] = ACTIONS(4356),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_static] = ACTIONS(4356),
    [anon_sym_EQ] = ACTIONS(4356),
    [anon_sym_register] = ACTIONS(4356),
    [anon_sym_inline] = ACTIONS(4356),
    [anon_sym___inline] = ACTIONS(4356),
    [anon_sym___inline__] = ACTIONS(4356),
    [anon_sym___forceinline] = ACTIONS(4356),
    [anon_sym_thread_local] = ACTIONS(4356),
    [anon_sym___thread] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4356),
    [anon_sym_volatile] = ACTIONS(4356),
    [anon_sym_restrict] = ACTIONS(4356),
    [anon_sym___restrict__] = ACTIONS(4356),
    [anon_sym__Atomic] = ACTIONS(4356),
    [anon_sym__Noreturn] = ACTIONS(4356),
    [anon_sym_noreturn] = ACTIONS(4356),
    [anon_sym__Nonnull] = ACTIONS(4356),
    [anon_sym_mutable] = ACTIONS(4356),
    [anon_sym_constinit] = ACTIONS(4356),
    [anon_sym_consteval] = ACTIONS(4356),
    [anon_sym___shared__] = ACTIONS(4356),
    [anon_sym___local__] = ACTIONS(4356),
    [anon_sym___constant__] = ACTIONS(4356),
    [anon_sym___managed__] = ACTIONS(4356),
    [anon_sym___grid_constant__] = ACTIONS(4356),
    [anon_sym_alignas] = ACTIONS(4356),
    [anon_sym__Alignas] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_STAR_EQ] = ACTIONS(4358),
    [anon_sym_SLASH_EQ] = ACTIONS(4358),
    [anon_sym_PERCENT_EQ] = ACTIONS(4358),
    [anon_sym_PLUS_EQ] = ACTIONS(4358),
    [anon_sym_DASH_EQ] = ACTIONS(4358),
    [anon_sym_LT_LT_EQ] = ACTIONS(4358),
    [anon_sym_GT_GT_EQ] = ACTIONS(4358),
    [anon_sym_AMP_EQ] = ACTIONS(4358),
    [anon_sym_CARET_EQ] = ACTIONS(4358),
    [anon_sym_PIPE_EQ] = ACTIONS(4358),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_bitor] = ACTIONS(4356),
    [anon_sym_xor] = ACTIONS(4356),
    [anon_sym_bitand] = ACTIONS(4356),
    [anon_sym_not_eq] = ACTIONS(4356),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4356),
    [anon_sym_decltype] = ACTIONS(4356),
    [anon_sym_template] = ACTIONS(4356),
    [anon_sym_operator] = ACTIONS(4356),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4358),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
    [anon_sym___launch_bounds__] = ACTIONS(4356),
  },
  [STATE(1342)] = {
    [sym_identifier] = ACTIONS(4366),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_RPAREN] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_TILDE] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4366),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4366),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4366),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4368),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4366),
    [anon_sym___extension__] = ACTIONS(4366),
    [anon_sym___device__] = ACTIONS(4366),
    [anon_sym___host__] = ACTIONS(4366),
    [anon_sym___global__] = ACTIONS(4366),
    [anon_sym___forceinline__] = ACTIONS(4366),
    [anon_sym___noinline__] = ACTIONS(4366),
    [anon_sym_virtual] = ACTIONS(4366),
    [anon_sym_extern] = ACTIONS(4366),
    [anon_sym___attribute__] = ACTIONS(4366),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4368),
    [anon_sym___declspec] = ACTIONS(4366),
    [anon_sym___based] = ACTIONS(4366),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4366),
    [anon_sym_static] = ACTIONS(4366),
    [anon_sym_EQ] = ACTIONS(4366),
    [anon_sym_register] = ACTIONS(4366),
    [anon_sym_inline] = ACTIONS(4366),
    [anon_sym___inline] = ACTIONS(4366),
    [anon_sym___inline__] = ACTIONS(4366),
    [anon_sym___forceinline] = ACTIONS(4366),
    [anon_sym_thread_local] = ACTIONS(4366),
    [anon_sym___thread] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4366),
    [anon_sym_volatile] = ACTIONS(4366),
    [anon_sym_restrict] = ACTIONS(4366),
    [anon_sym___restrict__] = ACTIONS(4366),
    [anon_sym__Atomic] = ACTIONS(4366),
    [anon_sym__Noreturn] = ACTIONS(4366),
    [anon_sym_noreturn] = ACTIONS(4366),
    [anon_sym__Nonnull] = ACTIONS(4366),
    [anon_sym_mutable] = ACTIONS(4366),
    [anon_sym_constinit] = ACTIONS(4366),
    [anon_sym_consteval] = ACTIONS(4366),
    [anon_sym___shared__] = ACTIONS(4366),
    [anon_sym___local__] = ACTIONS(4366),
    [anon_sym___constant__] = ACTIONS(4366),
    [anon_sym___managed__] = ACTIONS(4366),
    [anon_sym___grid_constant__] = ACTIONS(4366),
    [anon_sym_alignas] = ACTIONS(4366),
    [anon_sym__Alignas] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_STAR_EQ] = ACTIONS(4368),
    [anon_sym_SLASH_EQ] = ACTIONS(4368),
    [anon_sym_PERCENT_EQ] = ACTIONS(4368),
    [anon_sym_PLUS_EQ] = ACTIONS(4368),
    [anon_sym_DASH_EQ] = ACTIONS(4368),
    [anon_sym_LT_LT_EQ] = ACTIONS(4368),
    [anon_sym_GT_GT_EQ] = ACTIONS(4368),
    [anon_sym_AMP_EQ] = ACTIONS(4368),
    [anon_sym_CARET_EQ] = ACTIONS(4368),
    [anon_sym_PIPE_EQ] = ACTIONS(4368),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_bitor] = ACTIONS(4366),
    [anon_sym_xor] = ACTIONS(4366),
    [anon_sym_bitand] = ACTIONS(4366),
    [anon_sym_not_eq] = ACTIONS(4366),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4366),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4366),
    [anon_sym_decltype] = ACTIONS(4366),
    [anon_sym_template] = ACTIONS(4366),
    [anon_sym_operator] = ACTIONS(4366),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4368),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
    [anon_sym___launch_bounds__] = ACTIONS(4366),
  },
  [STATE(1343)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4557),
    [anon_sym_COMMA] = ACTIONS(4557),
    [anon_sym_RPAREN] = ACTIONS(4557),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4560),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_EQ] = ACTIONS(4564),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4562),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_operator] = ACTIONS(4553),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4555),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(1344)] = {
    [sym_expression] = STATE(3348),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1345)] = {
    [sym_expression] = STATE(3348),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(5062),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1346)] = {
    [sym_expression] = STATE(3409),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1347)] = {
    [sym_expression] = STATE(4865),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(4921),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1348)] = {
    [sym_expression] = STATE(4698),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1349)] = {
    [sym_expression] = STATE(3583),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1350)] = {
    [sym_expression] = STATE(4864),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1351)] = {
    [sym_expression] = STATE(4898),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(5064),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1352)] = {
    [sym_expression] = STATE(5382),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1353)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1354)] = {
    [sym_expression] = STATE(5210),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1355)] = {
    [sym_expression] = STATE(4897),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1356)] = {
    [sym_expression] = STATE(4717),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1357)] = {
    [sym_expression] = STATE(4901),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1358)] = {
    [sym_expression] = STATE(4841),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1359)] = {
    [sym_expression] = STATE(4842),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1360)] = {
    [sym_expression] = STATE(4843),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1361)] = {
    [sym_expression] = STATE(4844),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1362)] = {
    [sym_expression] = STATE(4846),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1363)] = {
    [sym_expression] = STATE(4848),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1364)] = {
    [sym_expression] = STATE(4850),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1365)] = {
    [sym_expression] = STATE(4725),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1366)] = {
    [sym_expression] = STATE(4856),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1367)] = {
    [sym_expression] = STATE(4840),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1368)] = {
    [sym_expression] = STATE(5311),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1369)] = {
    [sym_expression] = STATE(5031),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1370)] = {
    [sym_expression] = STATE(4890),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1371)] = {
    [sym_expression] = STATE(5284),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1372)] = {
    [sym_expression] = STATE(5352),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1373)] = {
    [sym_expression] = STATE(4626),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1374)] = {
    [sym_expression] = STATE(5056),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1375)] = {
    [sym_expression] = STATE(4845),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1376)] = {
    [sym_expression] = STATE(3342),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1377)] = {
    [sym_expression] = STATE(5236),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1378)] = {
    [sym_expression] = STATE(5199),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1379)] = {
    [sym_expression] = STATE(5131),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1380)] = {
    [sym_expression] = STATE(5133),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1381)] = {
    [sym_expression] = STATE(5134),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1382)] = {
    [sym_expression] = STATE(5135),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1383)] = {
    [sym_expression] = STATE(5136),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1384)] = {
    [sym_expression] = STATE(5138),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1385)] = {
    [sym_expression] = STATE(5139),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1386)] = {
    [sym_expression] = STATE(5140),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1387)] = {
    [sym_expression] = STATE(5141),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1388)] = {
    [sym_expression] = STATE(5142),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1389)] = {
    [sym_expression] = STATE(3246),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(5066),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1390)] = {
    [sym_expression] = STATE(2628),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1391)] = {
    [sym_expression] = STATE(3015),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(5068),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1392)] = {
    [sym_expression] = STATE(3054),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1393)] = {
    [sym_expression] = STATE(3037),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1394)] = {
    [sym_expression] = STATE(3039),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1395)] = {
    [sym_expression] = STATE(2627),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1396)] = {
    [sym_expression] = STATE(2627),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(5070),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1397)] = {
    [sym_expression] = STATE(2676),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1398)] = {
    [sym_expression] = STATE(4618),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(5072),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1399)] = {
    [sym_expression] = STATE(4577),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1400)] = {
    [sym_expression] = STATE(3508),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1401)] = {
    [sym_expression] = STATE(4617),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1402)] = {
    [sym_expression] = STATE(4635),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(5074),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1403)] = {
    [sym_expression] = STATE(4899),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1404)] = {
    [sym_expression] = STATE(5239),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1405)] = {
    [sym_expression] = STATE(4638),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1406)] = {
    [sym_expression] = STATE(4572),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1407)] = {
    [sym_expression] = STATE(4649),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1408)] = {
    [sym_expression] = STATE(4662),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1409)] = {
    [sym_expression] = STATE(4664),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1410)] = {
    [sym_expression] = STATE(4585),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1411)] = {
    [sym_expression] = STATE(4595),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1412)] = {
    [sym_expression] = STATE(4596),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1413)] = {
    [sym_expression] = STATE(4597),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1414)] = {
    [sym_expression] = STATE(4598),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1415)] = {
    [sym_expression] = STATE(5227),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1416)] = {
    [sym_expression] = STATE(4605),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1417)] = {
    [sym_expression] = STATE(5165),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1418)] = {
    [sym_expression] = STATE(5201),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1419)] = {
    [sym_expression] = STATE(4612),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1420)] = {
    [sym_expression] = STATE(4615),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1421)] = {
    [sym_expression] = STATE(5089),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1422)] = {
    [sym_expression] = STATE(5099),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1423)] = {
    [sym_expression] = STATE(5100),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1424)] = {
    [sym_expression] = STATE(5101),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1425)] = {
    [sym_expression] = STATE(5102),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1426)] = {
    [sym_expression] = STATE(5103),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1427)] = {
    [sym_expression] = STATE(5107),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1428)] = {
    [sym_expression] = STATE(5113),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1429)] = {
    [sym_expression] = STATE(5115),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1430)] = {
    [sym_expression] = STATE(5116),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1431)] = {
    [sym_expression] = STATE(5118),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1432)] = {
    [sym_expression] = STATE(3019),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(5076),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1433)] = {
    [sym_expression] = STATE(5381),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1434)] = {
    [sym_expression] = STATE(5075),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1435)] = {
    [sym_expression] = STATE(5145),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1436)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1437)] = {
    [sym_expression] = STATE(3204),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(5078),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1438)] = {
    [sym_expression] = STATE(2628),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1439)] = {
    [sym_expression] = STATE(3517),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1440)] = {
    [sym_expression] = STATE(3547),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1441)] = {
    [sym_expression] = STATE(3548),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1442)] = {
    [sym_expression] = STATE(3549),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1443)] = {
    [sym_expression] = STATE(3551),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1444)] = {
    [sym_expression] = STATE(3552),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1445)] = {
    [sym_expression] = STATE(3553),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1446)] = {
    [sym_expression] = STATE(3554),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1447)] = {
    [sym_expression] = STATE(3555),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1448)] = {
    [sym_expression] = STATE(3556),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1449)] = {
    [sym_expression] = STATE(3557),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1450)] = {
    [sym_expression] = STATE(3882),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1451)] = {
    [sym_expression] = STATE(5022),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1452)] = {
    [sym_expression] = STATE(3779),
    [sym__string] = STATE(4275),
    [sym_conditional_expression] = STATE(4307),
    [sym_assignment_expression] = STATE(4307),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4307),
    [sym_binary_expression] = STATE(4307),
    [sym_update_expression] = STATE(4307),
    [sym_cast_expression] = STATE(4307),
    [sym_sizeof_expression] = STATE(4307),
    [sym_alignof_expression] = STATE(4307),
    [sym_offsetof_expression] = STATE(4307),
    [sym_generic_expression] = STATE(4307),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4307),
    [sym_extension_expression] = STATE(4307),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4307),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4275),
    [sym_concatenated_string] = STATE(4275),
    [sym_string_literal] = STATE(2845),
    [sym_null] = STATE(4307),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8242),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4307),
    [sym_raw_string_literal] = STATE(2845),
    [sym_co_await_expression] = STATE(4307),
    [sym_new_expression] = STATE(4307),
    [sym_delete_expression] = STATE(4307),
    [sym_requires_clause] = STATE(4307),
    [sym_requires_expression] = STATE(4307),
    [sym_lambda_expression] = STATE(4307),
    [sym_lambda_capture_specifier] = STATE(6545),
    [sym_fold_expression] = STATE(4307),
    [sym_parameter_pack_expansion] = STATE(4307),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3824),
    [sym_qualified_type_identifier] = STATE(8242),
    [sym_user_defined_literal] = STATE(3824),
    [sym_kernel_call_expression] = STATE(4310),
    [sym_identifier] = ACTIONS(3554),
    [anon_sym_LPAREN2] = ACTIONS(1786),
    [anon_sym_BANG] = ACTIONS(1788),
    [anon_sym_TILDE] = ACTIONS(1788),
    [anon_sym_DASH] = ACTIONS(1790),
    [anon_sym_PLUS] = ACTIONS(1790),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(3556),
    [anon_sym_COLON_COLON] = ACTIONS(1798),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3560),
    [anon_sym_not] = ACTIONS(1790),
    [anon_sym_compl] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_sizeof] = ACTIONS(1812),
    [anon_sym___alignof__] = ACTIONS(1814),
    [anon_sym___alignof] = ACTIONS(1814),
    [anon_sym__alignof] = ACTIONS(1814),
    [anon_sym_alignof] = ACTIONS(1814),
    [anon_sym__Alignof] = ACTIONS(1814),
    [anon_sym_offsetof] = ACTIONS(1816),
    [anon_sym__Generic] = ACTIONS(1818),
    [anon_sym_asm] = ACTIONS(1820),
    [anon_sym___asm__] = ACTIONS(1820),
    [anon_sym___asm] = ACTIONS(1820),
    [sym_number_literal] = ACTIONS(1822),
    [anon_sym_L_SQUOTE] = ACTIONS(1824),
    [anon_sym_u_SQUOTE] = ACTIONS(1824),
    [anon_sym_U_SQUOTE] = ACTIONS(1824),
    [anon_sym_u8_SQUOTE] = ACTIONS(1824),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [anon_sym_L_DQUOTE] = ACTIONS(1826),
    [anon_sym_u_DQUOTE] = ACTIONS(1826),
    [anon_sym_U_DQUOTE] = ACTIONS(1826),
    [anon_sym_u8_DQUOTE] = ACTIONS(1826),
    [anon_sym_DQUOTE] = ACTIONS(1826),
    [sym_true] = ACTIONS(1828),
    [sym_false] = ACTIONS(1828),
    [anon_sym_NULL] = ACTIONS(1830),
    [anon_sym_nullptr] = ACTIONS(1830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1834),
    [anon_sym_R_DQUOTE] = ACTIONS(1836),
    [anon_sym_LR_DQUOTE] = ACTIONS(1836),
    [anon_sym_uR_DQUOTE] = ACTIONS(1836),
    [anon_sym_UR_DQUOTE] = ACTIONS(1836),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1836),
    [anon_sym_co_await] = ACTIONS(1838),
    [anon_sym_new] = ACTIONS(1840),
    [anon_sym_requires] = ACTIONS(1842),
    [sym_this] = ACTIONS(1828),
  },
  [STATE(1453)] = {
    [sym_expression] = STATE(3419),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1454)] = {
    [sym_expression] = STATE(2662),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1455)] = {
    [sym_expression] = STATE(3163),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(5080),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1456)] = {
    [sym_expression] = STATE(3603),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1457)] = {
    [sym_expression] = STATE(3649),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1458)] = {
    [sym_expression] = STATE(3650),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1459)] = {
    [sym_expression] = STATE(3651),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1460)] = {
    [sym_expression] = STATE(3652),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1461)] = {
    [sym_expression] = STATE(3653),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1462)] = {
    [sym_expression] = STATE(3654),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1463)] = {
    [sym_expression] = STATE(3655),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1464)] = {
    [sym_expression] = STATE(3656),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1465)] = {
    [sym_expression] = STATE(3657),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1466)] = {
    [sym_expression] = STATE(3658),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1467)] = {
    [sym_expression] = STATE(5234),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1468)] = {
    [sym_expression] = STATE(5030),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1469)] = {
    [sym_expression] = STATE(3243),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1470)] = {
    [sym_expression] = STATE(3255),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1471)] = {
    [sym_expression] = STATE(2675),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1472)] = {
    [sym_expression] = STATE(3233),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1473)] = {
    [sym_expression] = STATE(3211),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1474)] = {
    [sym_expression] = STATE(3241),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1475)] = {
    [sym_expression] = STATE(3217),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1476)] = {
    [sym_expression] = STATE(3230),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1477)] = {
    [sym_expression] = STATE(3231),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1478)] = {
    [sym_expression] = STATE(3209),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1479)] = {
    [sym_expression] = STATE(3256),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1480)] = {
    [sym_expression] = STATE(3516),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1481)] = {
    [sym_expression] = STATE(3524),
    [sym__string] = STATE(4002),
    [sym_conditional_expression] = STATE(4040),
    [sym_assignment_expression] = STATE(4040),
    [sym_pointer_expression] = STATE(4045),
    [sym_unary_expression] = STATE(4040),
    [sym_binary_expression] = STATE(4040),
    [sym_update_expression] = STATE(4040),
    [sym_cast_expression] = STATE(4040),
    [sym_sizeof_expression] = STATE(4040),
    [sym_alignof_expression] = STATE(4040),
    [sym_offsetof_expression] = STATE(4040),
    [sym_generic_expression] = STATE(4040),
    [sym_subscript_expression] = STATE(4045),
    [sym_call_expression] = STATE(4045),
    [sym_gnu_asm_expression] = STATE(4040),
    [sym_extension_expression] = STATE(4040),
    [sym_field_expression] = STATE(4045),
    [sym_compound_literal_expression] = STATE(4040),
    [sym_parenthesized_expression] = STATE(4045),
    [sym_char_literal] = STATE(4002),
    [sym_concatenated_string] = STATE(4002),
    [sym_string_literal] = STATE(2699),
    [sym_null] = STATE(4040),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8349),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4040),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(4040),
    [sym_new_expression] = STATE(4040),
    [sym_delete_expression] = STATE(4040),
    [sym_requires_clause] = STATE(4040),
    [sym_requires_expression] = STATE(4040),
    [sym_lambda_expression] = STATE(4040),
    [sym_lambda_capture_specifier] = STATE(6573),
    [sym_fold_expression] = STATE(4040),
    [sym_parameter_pack_expansion] = STATE(4040),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4045),
    [sym_qualified_type_identifier] = STATE(8349),
    [sym_user_defined_literal] = STATE(4045),
    [sym_kernel_call_expression] = STATE(4042),
    [sym_identifier] = ACTIONS(3199),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(3203),
    [anon_sym_TILDE] = ACTIONS(3203),
    [anon_sym_DASH] = ACTIONS(3201),
    [anon_sym_PLUS] = ACTIONS(3201),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3205),
    [anon_sym_COLON_COLON] = ACTIONS(3207),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3211),
    [anon_sym_not] = ACTIONS(3201),
    [anon_sym_compl] = ACTIONS(3201),
    [anon_sym_DASH_DASH] = ACTIONS(4742),
    [anon_sym_PLUS_PLUS] = ACTIONS(4742),
    [anon_sym_sizeof] = ACTIONS(3213),
    [anon_sym___alignof__] = ACTIONS(3215),
    [anon_sym___alignof] = ACTIONS(3215),
    [anon_sym__alignof] = ACTIONS(3215),
    [anon_sym_alignof] = ACTIONS(3215),
    [anon_sym__Alignof] = ACTIONS(3215),
    [anon_sym_offsetof] = ACTIONS(3217),
    [anon_sym__Generic] = ACTIONS(3219),
    [anon_sym_asm] = ACTIONS(3221),
    [anon_sym___asm__] = ACTIONS(3221),
    [anon_sym___asm] = ACTIONS(3221),
    [sym_number_literal] = ACTIONS(3223),
    [anon_sym_L_SQUOTE] = ACTIONS(3225),
    [anon_sym_u_SQUOTE] = ACTIONS(3225),
    [anon_sym_U_SQUOTE] = ACTIONS(3225),
    [anon_sym_u8_SQUOTE] = ACTIONS(3225),
    [anon_sym_SQUOTE] = ACTIONS(3225),
    [anon_sym_L_DQUOTE] = ACTIONS(3227),
    [anon_sym_u_DQUOTE] = ACTIONS(3227),
    [anon_sym_U_DQUOTE] = ACTIONS(3227),
    [anon_sym_u8_DQUOTE] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [sym_true] = ACTIONS(3229),
    [sym_false] = ACTIONS(3229),
    [anon_sym_NULL] = ACTIONS(3231),
    [anon_sym_nullptr] = ACTIONS(3231),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_R_DQUOTE] = ACTIONS(3235),
    [anon_sym_LR_DQUOTE] = ACTIONS(3235),
    [anon_sym_uR_DQUOTE] = ACTIONS(3235),
    [anon_sym_UR_DQUOTE] = ACTIONS(3235),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3235),
    [anon_sym_co_await] = ACTIONS(3237),
    [anon_sym_new] = ACTIONS(3239),
    [anon_sym_requires] = ACTIONS(3241),
    [sym_this] = ACTIONS(3229),
  },
  [STATE(1482)] = {
    [sym_expression] = STATE(3408),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1483)] = {
    [sym_expression] = STATE(3308),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1484)] = {
    [sym_expression] = STATE(3319),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1485)] = {
    [sym_expression] = STATE(3322),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1486)] = {
    [sym_expression] = STATE(3339),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1487)] = {
    [sym_expression] = STATE(3406),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1488)] = {
    [sym_expression] = STATE(3442),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1489)] = {
    [sym_expression] = STATE(3276),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1490)] = {
    [sym_expression] = STATE(3260),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1491)] = {
    [sym_expression] = STATE(3391),
    [sym__string] = STATE(3751),
    [sym_conditional_expression] = STATE(3842),
    [sym_assignment_expression] = STATE(3842),
    [sym_pointer_expression] = STATE(3968),
    [sym_unary_expression] = STATE(3842),
    [sym_binary_expression] = STATE(3842),
    [sym_update_expression] = STATE(3842),
    [sym_cast_expression] = STATE(3842),
    [sym_sizeof_expression] = STATE(3842),
    [sym_alignof_expression] = STATE(3842),
    [sym_offsetof_expression] = STATE(3842),
    [sym_generic_expression] = STATE(3842),
    [sym_subscript_expression] = STATE(3968),
    [sym_call_expression] = STATE(3968),
    [sym_gnu_asm_expression] = STATE(3842),
    [sym_extension_expression] = STATE(3842),
    [sym_field_expression] = STATE(3968),
    [sym_compound_literal_expression] = STATE(3842),
    [sym_parenthesized_expression] = STATE(3968),
    [sym_char_literal] = STATE(3751),
    [sym_concatenated_string] = STATE(3751),
    [sym_string_literal] = STATE(2636),
    [sym_null] = STATE(3842),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8521),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(3842),
    [sym_raw_string_literal] = STATE(2636),
    [sym_co_await_expression] = STATE(3842),
    [sym_new_expression] = STATE(3842),
    [sym_delete_expression] = STATE(3842),
    [sym_requires_clause] = STATE(3842),
    [sym_requires_expression] = STATE(3842),
    [sym_lambda_expression] = STATE(3842),
    [sym_lambda_capture_specifier] = STATE(6574),
    [sym_fold_expression] = STATE(3842),
    [sym_parameter_pack_expansion] = STATE(3842),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6219),
    [sym_qualified_identifier] = STATE(3968),
    [sym_qualified_type_identifier] = STATE(8521),
    [sym_user_defined_literal] = STATE(3968),
    [sym_kernel_call_expression] = STATE(3856),
    [sym_identifier] = ACTIONS(2932),
    [anon_sym_LPAREN2] = ACTIONS(2002),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_DASH] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1860),
    [anon_sym_STAR] = ACTIONS(1792),
    [anon_sym_AMP] = ACTIONS(1792),
    [anon_sym___extension__] = ACTIONS(2934),
    [anon_sym_COLON_COLON] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2938),
    [anon_sym_not] = ACTIONS(1860),
    [anon_sym_compl] = ACTIONS(1860),
    [anon_sym_DASH_DASH] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1886),
    [anon_sym_sizeof] = ACTIONS(1888),
    [anon_sym___alignof__] = ACTIONS(1890),
    [anon_sym___alignof] = ACTIONS(1890),
    [anon_sym__alignof] = ACTIONS(1890),
    [anon_sym_alignof] = ACTIONS(1890),
    [anon_sym__Alignof] = ACTIONS(1890),
    [anon_sym_offsetof] = ACTIONS(1892),
    [anon_sym__Generic] = ACTIONS(1894),
    [anon_sym_asm] = ACTIONS(1896),
    [anon_sym___asm__] = ACTIONS(1896),
    [anon_sym___asm] = ACTIONS(1896),
    [sym_number_literal] = ACTIONS(1898),
    [anon_sym_L_SQUOTE] = ACTIONS(1900),
    [anon_sym_u_SQUOTE] = ACTIONS(1900),
    [anon_sym_U_SQUOTE] = ACTIONS(1900),
    [anon_sym_u8_SQUOTE] = ACTIONS(1900),
    [anon_sym_SQUOTE] = ACTIONS(1900),
    [anon_sym_L_DQUOTE] = ACTIONS(1902),
    [anon_sym_u_DQUOTE] = ACTIONS(1902),
    [anon_sym_U_DQUOTE] = ACTIONS(1902),
    [anon_sym_u8_DQUOTE] = ACTIONS(1902),
    [anon_sym_DQUOTE] = ACTIONS(1902),
    [sym_true] = ACTIONS(1904),
    [sym_false] = ACTIONS(1904),
    [anon_sym_NULL] = ACTIONS(1906),
    [anon_sym_nullptr] = ACTIONS(1906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(1916),
    [anon_sym_R_DQUOTE] = ACTIONS(1918),
    [anon_sym_LR_DQUOTE] = ACTIONS(1918),
    [anon_sym_uR_DQUOTE] = ACTIONS(1918),
    [anon_sym_UR_DQUOTE] = ACTIONS(1918),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1918),
    [anon_sym_co_await] = ACTIONS(1920),
    [anon_sym_new] = ACTIONS(1922),
    [anon_sym_requires] = ACTIONS(1924),
    [sym_this] = ACTIONS(1904),
  },
  [STATE(1492)] = {
    [sym_expression] = STATE(3143),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1493)] = {
    [sym_expression] = STATE(3016),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1494)] = {
    [sym_expression] = STATE(3052),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1495)] = {
    [sym_expression] = STATE(2675),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1496)] = {
    [sym_expression] = STATE(3020),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1497)] = {
    [sym_expression] = STATE(3021),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1498)] = {
    [sym_expression] = STATE(3022),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1499)] = {
    [sym_expression] = STATE(3024),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1500)] = {
    [sym_expression] = STATE(3011),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1501)] = {
    [sym_expression] = STATE(3057),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1502)] = {
    [sym_expression] = STATE(3033),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1503)] = {
    [sym_expression] = STATE(3053),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1504)] = {
    [sym_expression] = STATE(3602),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1505)] = {
    [sym_expression] = STATE(3608),
    [sym__string] = STATE(3927),
    [sym_conditional_expression] = STATE(4193),
    [sym_assignment_expression] = STATE(4193),
    [sym_pointer_expression] = STATE(4195),
    [sym_unary_expression] = STATE(4193),
    [sym_binary_expression] = STATE(4193),
    [sym_update_expression] = STATE(4193),
    [sym_cast_expression] = STATE(4193),
    [sym_sizeof_expression] = STATE(4193),
    [sym_alignof_expression] = STATE(4193),
    [sym_offsetof_expression] = STATE(4193),
    [sym_generic_expression] = STATE(4193),
    [sym_subscript_expression] = STATE(4195),
    [sym_call_expression] = STATE(4195),
    [sym_gnu_asm_expression] = STATE(4193),
    [sym_extension_expression] = STATE(4193),
    [sym_field_expression] = STATE(4195),
    [sym_compound_literal_expression] = STATE(4193),
    [sym_parenthesized_expression] = STATE(4195),
    [sym_char_literal] = STATE(3927),
    [sym_concatenated_string] = STATE(3927),
    [sym_string_literal] = STATE(2725),
    [sym_null] = STATE(4193),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8246),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4193),
    [sym_raw_string_literal] = STATE(2725),
    [sym_co_await_expression] = STATE(4193),
    [sym_new_expression] = STATE(4193),
    [sym_delete_expression] = STATE(4193),
    [sym_requires_clause] = STATE(4193),
    [sym_requires_expression] = STATE(4193),
    [sym_lambda_expression] = STATE(4193),
    [sym_lambda_capture_specifier] = STATE(6561),
    [sym_fold_expression] = STATE(4193),
    [sym_parameter_pack_expansion] = STATE(4193),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4195),
    [sym_qualified_type_identifier] = STATE(8246),
    [sym_user_defined_literal] = STATE(4195),
    [sym_kernel_call_expression] = STATE(4194),
    [sym_identifier] = ACTIONS(3359),
    [anon_sym_LPAREN2] = ACTIONS(4753),
    [anon_sym_BANG] = ACTIONS(3363),
    [anon_sym_TILDE] = ACTIONS(3363),
    [anon_sym_DASH] = ACTIONS(3361),
    [anon_sym_PLUS] = ACTIONS(3361),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3365),
    [anon_sym_COLON_COLON] = ACTIONS(3367),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3371),
    [anon_sym_not] = ACTIONS(3361),
    [anon_sym_compl] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym___alignof__] = ACTIONS(3375),
    [anon_sym___alignof] = ACTIONS(3375),
    [anon_sym__alignof] = ACTIONS(3375),
    [anon_sym_alignof] = ACTIONS(3375),
    [anon_sym__Alignof] = ACTIONS(3375),
    [anon_sym_offsetof] = ACTIONS(3377),
    [anon_sym__Generic] = ACTIONS(3379),
    [anon_sym_asm] = ACTIONS(3381),
    [anon_sym___asm__] = ACTIONS(3381),
    [anon_sym___asm] = ACTIONS(3381),
    [sym_number_literal] = ACTIONS(3383),
    [anon_sym_L_SQUOTE] = ACTIONS(3385),
    [anon_sym_u_SQUOTE] = ACTIONS(3385),
    [anon_sym_U_SQUOTE] = ACTIONS(3385),
    [anon_sym_u8_SQUOTE] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3385),
    [anon_sym_L_DQUOTE] = ACTIONS(3387),
    [anon_sym_u_DQUOTE] = ACTIONS(3387),
    [anon_sym_U_DQUOTE] = ACTIONS(3387),
    [anon_sym_u8_DQUOTE] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_true] = ACTIONS(3389),
    [sym_false] = ACTIONS(3389),
    [anon_sym_NULL] = ACTIONS(3391),
    [anon_sym_nullptr] = ACTIONS(3391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3393),
    [anon_sym_R_DQUOTE] = ACTIONS(3395),
    [anon_sym_LR_DQUOTE] = ACTIONS(3395),
    [anon_sym_uR_DQUOTE] = ACTIONS(3395),
    [anon_sym_UR_DQUOTE] = ACTIONS(3395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3395),
    [anon_sym_co_await] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3399),
    [anon_sym_requires] = ACTIONS(3401),
    [sym_this] = ACTIONS(3389),
  },
  [STATE(1506)] = {
    [sym_expression] = STATE(4725),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1507)] = {
    [sym_expression] = STATE(4679),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1508)] = {
    [sym_expression] = STATE(4871),
    [sym__string] = STATE(5231),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3775),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3775),
    [sym_call_expression] = STATE(3775),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3775),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3775),
    [sym_char_literal] = STATE(5231),
    [sym_concatenated_string] = STATE(5231),
    [sym_string_literal] = STATE(3879),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3879),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3775),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3775),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3802),
    [anon_sym_LPAREN2] = ACTIONS(4629),
    [anon_sym_BANG] = ACTIONS(3806),
    [anon_sym_TILDE] = ACTIONS(3806),
    [anon_sym_DASH] = ACTIONS(3804),
    [anon_sym_PLUS] = ACTIONS(3804),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(3808),
    [anon_sym_COLON_COLON] = ACTIONS(3810),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3804),
    [anon_sym_compl] = ACTIONS(3804),
    [anon_sym_DASH_DASH] = ACTIONS(4635),
    [anon_sym_PLUS_PLUS] = ACTIONS(4635),
    [anon_sym_sizeof] = ACTIONS(3812),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3814),
    [anon_sym_L_SQUOTE] = ACTIONS(3816),
    [anon_sym_u_SQUOTE] = ACTIONS(3816),
    [anon_sym_U_SQUOTE] = ACTIONS(3816),
    [anon_sym_u8_SQUOTE] = ACTIONS(3816),
    [anon_sym_SQUOTE] = ACTIONS(3816),
    [anon_sym_L_DQUOTE] = ACTIONS(3818),
    [anon_sym_u_DQUOTE] = ACTIONS(3818),
    [anon_sym_U_DQUOTE] = ACTIONS(3818),
    [anon_sym_u8_DQUOTE] = ACTIONS(3818),
    [anon_sym_DQUOTE] = ACTIONS(3818),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3820),
    [anon_sym_R_DQUOTE] = ACTIONS(3822),
    [anon_sym_LR_DQUOTE] = ACTIONS(3822),
    [anon_sym_uR_DQUOTE] = ACTIONS(3822),
    [anon_sym_UR_DQUOTE] = ACTIONS(3822),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3822),
    [anon_sym_co_await] = ACTIONS(3824),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1509)] = {
    [sym_expression] = STATE(4574),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1510)] = {
    [sym_expression] = STATE(4575),
    [sym__string] = STATE(4747),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3237),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3237),
    [sym_call_expression] = STATE(3237),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3237),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3237),
    [sym_char_literal] = STATE(4747),
    [sym_concatenated_string] = STATE(4747),
    [sym_string_literal] = STATE(3347),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3347),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3237),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3237),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(4780),
    [anon_sym_BANG] = ACTIONS(3774),
    [anon_sym_TILDE] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_compl] = ACTIONS(3772),
    [anon_sym_DASH_DASH] = ACTIONS(4732),
    [anon_sym_PLUS_PLUS] = ACTIONS(4732),
    [anon_sym_sizeof] = ACTIONS(3782),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(3784),
    [anon_sym_L_SQUOTE] = ACTIONS(3786),
    [anon_sym_u_SQUOTE] = ACTIONS(3786),
    [anon_sym_U_SQUOTE] = ACTIONS(3786),
    [anon_sym_u8_SQUOTE] = ACTIONS(3786),
    [anon_sym_SQUOTE] = ACTIONS(3786),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3790),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [anon_sym_co_await] = ACTIONS(3794),
    [anon_sym_new] = ACTIONS(3796),
    [anon_sym_requires] = ACTIONS(3798),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1511)] = {
    [sym_expression] = STATE(2627),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1512)] = {
    [sym_expression] = STATE(2676),
    [sym__string] = STATE(3466),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3466),
    [sym_concatenated_string] = STATE(3466),
    [sym_string_literal] = STATE(2606),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2606),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_LPAREN2] = ACTIONS(4792),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2715),
    [anon_sym_PLUS] = ACTIONS(2715),
    [anon_sym_STAR] = ACTIONS(4631),
    [anon_sym_AMP] = ACTIONS(4631),
    [anon_sym___extension__] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2715),
    [anon_sym_compl] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(4736),
    [anon_sym_PLUS_PLUS] = ACTIONS(4736),
    [anon_sym_sizeof] = ACTIONS(2723),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2725),
    [anon_sym_L_SQUOTE] = ACTIONS(2727),
    [anon_sym_u_SQUOTE] = ACTIONS(2727),
    [anon_sym_U_SQUOTE] = ACTIONS(2727),
    [anon_sym_u8_SQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [anon_sym_L_DQUOTE] = ACTIONS(2729),
    [anon_sym_u_DQUOTE] = ACTIONS(2729),
    [anon_sym_U_DQUOTE] = ACTIONS(2729),
    [anon_sym_u8_DQUOTE] = ACTIONS(2729),
    [anon_sym_DQUOTE] = ACTIONS(2729),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2731),
    [anon_sym_R_DQUOTE] = ACTIONS(2733),
    [anon_sym_LR_DQUOTE] = ACTIONS(2733),
    [anon_sym_uR_DQUOTE] = ACTIONS(2733),
    [anon_sym_UR_DQUOTE] = ACTIONS(2733),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2733),
    [anon_sym_co_await] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1513)] = {
    [sym_expression] = STATE(2627),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1514)] = {
    [sym_expression] = STATE(4861),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1515)] = {
    [sym_expression] = STATE(2676),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1516)] = {
    [sym_expression] = STATE(4717),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1517)] = {
    [sym_expression] = STATE(4863),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1518)] = {
    [sym_expression] = STATE(4866),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1519)] = {
    [sym_expression] = STATE(4870),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1520)] = {
    [sym_expression] = STATE(4902),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1521)] = {
    [sym_expression] = STATE(4903),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1522)] = {
    [sym_expression] = STATE(4905),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1523)] = {
    [sym_expression] = STATE(4906),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1524)] = {
    [sym_expression] = STATE(4907),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1525)] = {
    [sym_expression] = STATE(5163),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1526)] = {
    [sym_expression] = STATE(5267),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1527)] = {
    [sym_expression] = STATE(5164),
    [sym__string] = STATE(5415),
    [sym_conditional_expression] = STATE(5512),
    [sym_assignment_expression] = STATE(5512),
    [sym_pointer_expression] = STATE(4025),
    [sym_unary_expression] = STATE(5512),
    [sym_binary_expression] = STATE(5512),
    [sym_update_expression] = STATE(5512),
    [sym_cast_expression] = STATE(5512),
    [sym_sizeof_expression] = STATE(5512),
    [sym_alignof_expression] = STATE(5512),
    [sym_offsetof_expression] = STATE(5512),
    [sym_generic_expression] = STATE(5512),
    [sym_subscript_expression] = STATE(4025),
    [sym_call_expression] = STATE(4025),
    [sym_gnu_asm_expression] = STATE(5512),
    [sym_extension_expression] = STATE(5512),
    [sym_field_expression] = STATE(4025),
    [sym_compound_literal_expression] = STATE(5512),
    [sym_parenthesized_expression] = STATE(4025),
    [sym_char_literal] = STATE(5415),
    [sym_concatenated_string] = STATE(5415),
    [sym_string_literal] = STATE(4274),
    [sym_null] = STATE(5512),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8513),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5512),
    [sym_raw_string_literal] = STATE(4274),
    [sym_co_await_expression] = STATE(5512),
    [sym_new_expression] = STATE(5512),
    [sym_delete_expression] = STATE(5512),
    [sym_requires_clause] = STATE(5512),
    [sym_requires_expression] = STATE(5512),
    [sym_lambda_expression] = STATE(5512),
    [sym_lambda_capture_specifier] = STATE(6526),
    [sym_fold_expression] = STATE(5512),
    [sym_parameter_pack_expansion] = STATE(5512),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6284),
    [sym_qualified_identifier] = STATE(4025),
    [sym_qualified_type_identifier] = STATE(8513),
    [sym_user_defined_literal] = STATE(4025),
    [sym_kernel_call_expression] = STATE(5518),
    [sym_identifier] = ACTIONS(3902),
    [anon_sym_LPAREN2] = ACTIONS(2864),
    [anon_sym_BANG] = ACTIONS(2866),
    [anon_sym_TILDE] = ACTIONS(2866),
    [anon_sym_DASH] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2868),
    [anon_sym_STAR] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2874),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3908),
    [anon_sym_not] = ACTIONS(2868),
    [anon_sym_compl] = ACTIONS(2868),
    [anon_sym_DASH_DASH] = ACTIONS(2888),
    [anon_sym_PLUS_PLUS] = ACTIONS(2888),
    [anon_sym_sizeof] = ACTIONS(2890),
    [anon_sym___alignof__] = ACTIONS(2892),
    [anon_sym___alignof] = ACTIONS(2892),
    [anon_sym__alignof] = ACTIONS(2892),
    [anon_sym_alignof] = ACTIONS(2892),
    [anon_sym__Alignof] = ACTIONS(2892),
    [anon_sym_offsetof] = ACTIONS(2894),
    [anon_sym__Generic] = ACTIONS(2896),
    [anon_sym_asm] = ACTIONS(2898),
    [anon_sym___asm__] = ACTIONS(2898),
    [anon_sym___asm] = ACTIONS(2898),
    [sym_number_literal] = ACTIONS(2900),
    [anon_sym_L_SQUOTE] = ACTIONS(2902),
    [anon_sym_u_SQUOTE] = ACTIONS(2902),
    [anon_sym_U_SQUOTE] = ACTIONS(2902),
    [anon_sym_u8_SQUOTE] = ACTIONS(2902),
    [anon_sym_SQUOTE] = ACTIONS(2902),
    [anon_sym_L_DQUOTE] = ACTIONS(2904),
    [anon_sym_u_DQUOTE] = ACTIONS(2904),
    [anon_sym_U_DQUOTE] = ACTIONS(2904),
    [anon_sym_u8_DQUOTE] = ACTIONS(2904),
    [anon_sym_DQUOTE] = ACTIONS(2904),
    [sym_true] = ACTIONS(2906),
    [sym_false] = ACTIONS(2906),
    [anon_sym_NULL] = ACTIONS(2908),
    [anon_sym_nullptr] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2918),
    [anon_sym_R_DQUOTE] = ACTIONS(2920),
    [anon_sym_LR_DQUOTE] = ACTIONS(2920),
    [anon_sym_uR_DQUOTE] = ACTIONS(2920),
    [anon_sym_UR_DQUOTE] = ACTIONS(2920),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2920),
    [anon_sym_co_await] = ACTIONS(2922),
    [anon_sym_new] = ACTIONS(2924),
    [anon_sym_requires] = ACTIONS(2926),
    [sym_this] = ACTIONS(2906),
  },
  [STATE(1528)] = {
    [sym_expression] = STATE(5278),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1529)] = {
    [sym_expression] = STATE(5047),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1530)] = {
    [sym_expression] = STATE(5223),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(5082),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1531)] = {
    [sym_expression] = STATE(5238),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1532)] = {
    [sym_expression] = STATE(5240),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1533)] = {
    [sym_expression] = STATE(5241),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1534)] = {
    [sym_expression] = STATE(5242),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1535)] = {
    [sym_expression] = STATE(5243),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1536)] = {
    [sym_expression] = STATE(5244),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1537)] = {
    [sym_expression] = STATE(5245),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1538)] = {
    [sym_expression] = STATE(5246),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1539)] = {
    [sym_expression] = STATE(5247),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1540)] = {
    [sym_expression] = STATE(5248),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1541)] = {
    [sym_expression] = STATE(5250),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1542)] = {
    [sym_expression] = STATE(5253),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1543)] = {
    [sym_expression] = STATE(5385),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1544)] = {
    [sym_expression] = STATE(5260),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1545)] = {
    [sym_expression] = STATE(5351),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1546)] = {
    [sym_expression] = STATE(5085),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1547)] = {
    [sym_expression] = STATE(5269),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1548)] = {
    [sym_expression] = STATE(3158),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4641),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2689),
    [anon_sym_compl] = ACTIONS(2689),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(2697),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1549)] = {
    [sym_expression] = STATE(5271),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1550)] = {
    [sym_expression] = STATE(5079),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1551)] = {
    [sym_expression] = STATE(4963),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1552)] = {
    [sym_expression] = STATE(5262),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1553)] = {
    [sym_expression] = STATE(5334),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1554)] = {
    [sym_expression] = STATE(4908),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1555)] = {
    [sym_expression] = STATE(4944),
    [sym__string] = STATE(5400),
    [sym_conditional_expression] = STATE(5429),
    [sym_assignment_expression] = STATE(5429),
    [sym_pointer_expression] = STATE(4189),
    [sym_unary_expression] = STATE(5429),
    [sym_binary_expression] = STATE(5429),
    [sym_update_expression] = STATE(5429),
    [sym_cast_expression] = STATE(5429),
    [sym_sizeof_expression] = STATE(5429),
    [sym_alignof_expression] = STATE(5429),
    [sym_offsetof_expression] = STATE(5429),
    [sym_generic_expression] = STATE(5429),
    [sym_subscript_expression] = STATE(4189),
    [sym_call_expression] = STATE(4189),
    [sym_gnu_asm_expression] = STATE(5429),
    [sym_extension_expression] = STATE(5429),
    [sym_field_expression] = STATE(4189),
    [sym_compound_literal_expression] = STATE(5429),
    [sym_parenthesized_expression] = STATE(4189),
    [sym_char_literal] = STATE(5400),
    [sym_concatenated_string] = STATE(5400),
    [sym_string_literal] = STATE(4265),
    [sym_null] = STATE(5429),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8462),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(5429),
    [sym_raw_string_literal] = STATE(4265),
    [sym_co_await_expression] = STATE(5429),
    [sym_new_expression] = STATE(5429),
    [sym_delete_expression] = STATE(5429),
    [sym_requires_clause] = STATE(5429),
    [sym_requires_expression] = STATE(5429),
    [sym_lambda_expression] = STATE(5429),
    [sym_lambda_capture_specifier] = STATE(6569),
    [sym_fold_expression] = STATE(5429),
    [sym_parameter_pack_expansion] = STATE(5429),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6282),
    [sym_qualified_identifier] = STATE(4189),
    [sym_qualified_type_identifier] = STATE(8462),
    [sym_user_defined_literal] = STATE(4189),
    [sym_kernel_call_expression] = STATE(5433),
    [sym_identifier] = ACTIONS(3910),
    [anon_sym_LPAREN2] = ACTIONS(4762),
    [anon_sym_BANG] = ACTIONS(3914),
    [anon_sym_TILDE] = ACTIONS(3914),
    [anon_sym_DASH] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3912),
    [anon_sym_STAR] = ACTIONS(4755),
    [anon_sym_AMP] = ACTIONS(4755),
    [anon_sym___extension__] = ACTIONS(3916),
    [anon_sym_COLON_COLON] = ACTIONS(3918),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(3922),
    [anon_sym_not] = ACTIONS(3912),
    [anon_sym_compl] = ACTIONS(3912),
    [anon_sym_DASH_DASH] = ACTIONS(4719),
    [anon_sym_PLUS_PLUS] = ACTIONS(4719),
    [anon_sym_sizeof] = ACTIONS(3924),
    [anon_sym___alignof__] = ACTIONS(3926),
    [anon_sym___alignof] = ACTIONS(3926),
    [anon_sym__alignof] = ACTIONS(3926),
    [anon_sym_alignof] = ACTIONS(3926),
    [anon_sym__Alignof] = ACTIONS(3926),
    [anon_sym_offsetof] = ACTIONS(3928),
    [anon_sym__Generic] = ACTIONS(3930),
    [anon_sym_asm] = ACTIONS(3932),
    [anon_sym___asm__] = ACTIONS(3932),
    [anon_sym___asm] = ACTIONS(3932),
    [sym_number_literal] = ACTIONS(3934),
    [anon_sym_L_SQUOTE] = ACTIONS(3936),
    [anon_sym_u_SQUOTE] = ACTIONS(3936),
    [anon_sym_U_SQUOTE] = ACTIONS(3936),
    [anon_sym_u8_SQUOTE] = ACTIONS(3936),
    [anon_sym_SQUOTE] = ACTIONS(3936),
    [anon_sym_L_DQUOTE] = ACTIONS(3938),
    [anon_sym_u_DQUOTE] = ACTIONS(3938),
    [anon_sym_U_DQUOTE] = ACTIONS(3938),
    [anon_sym_u8_DQUOTE] = ACTIONS(3938),
    [anon_sym_DQUOTE] = ACTIONS(3938),
    [sym_true] = ACTIONS(3940),
    [sym_false] = ACTIONS(3940),
    [anon_sym_NULL] = ACTIONS(3942),
    [anon_sym_nullptr] = ACTIONS(3942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3944),
    [anon_sym_R_DQUOTE] = ACTIONS(3946),
    [anon_sym_LR_DQUOTE] = ACTIONS(3946),
    [anon_sym_uR_DQUOTE] = ACTIONS(3946),
    [anon_sym_UR_DQUOTE] = ACTIONS(3946),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3946),
    [anon_sym_co_await] = ACTIONS(3948),
    [anon_sym_new] = ACTIONS(3950),
    [anon_sym_requires] = ACTIONS(3952),
    [sym_this] = ACTIONS(3940),
  },
  [STATE(1556)] = {
    [sym_expression] = STATE(5373),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1557)] = {
    [sym_expression] = STATE(5277),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1558)] = {
    [sym_expression] = STATE(5299),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1559)] = {
    [sym_expression] = STATE(5336),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1560)] = {
    [sym_expression] = STATE(4855),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(5084),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1561)] = {
    [sym_expression] = STATE(5335),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1562)] = {
    [sym_expression] = STATE(4966),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1563)] = {
    [sym_expression] = STATE(5300),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1564)] = {
    [sym_expression] = STATE(5332),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1565)] = {
    [sym_expression] = STATE(5349),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1566)] = {
    [sym_expression] = STATE(5265),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1567)] = {
    [sym_expression] = STATE(5266),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1568)] = {
    [sym_expression] = STATE(5292),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1569)] = {
    [sym_expression] = STATE(4969),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1570)] = {
    [sym_expression] = STATE(5282),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1571)] = {
    [sym_expression] = STATE(5333),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1572)] = {
    [sym_expression] = STATE(5281),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1573)] = {
    [sym_expression] = STATE(5288),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1574)] = {
    [sym_expression] = STATE(5289),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1575)] = {
    [sym_expression] = STATE(5297),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1576)] = {
    [sym_expression] = STATE(4949),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1577)] = {
    [sym_expression] = STATE(5343),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1578)] = {
    [sym_expression] = STATE(5283),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1579)] = {
    [sym_expression] = STATE(5290),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1580)] = {
    [sym_expression] = STATE(5291),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1581)] = {
    [sym_expression] = STATE(5296),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1582)] = {
    [sym_expression] = STATE(5313),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1583)] = {
    [sym_expression] = STATE(4933),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1584)] = {
    [sym_expression] = STATE(5374),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1585)] = {
    [sym_expression] = STATE(5384),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1586)] = {
    [sym_expression] = STATE(5326),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1587)] = {
    [sym_expression] = STATE(5327),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1588)] = {
    [sym_expression] = STATE(5366),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1589)] = {
    [sym_expression] = STATE(4960),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1590)] = {
    [sym_expression] = STATE(5338),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1591)] = {
    [sym_expression] = STATE(4952),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1592)] = {
    [sym_expression] = STATE(5044),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1593)] = {
    [sym_expression] = STATE(5048),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1594)] = {
    [sym_expression] = STATE(5051),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(5086),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1595)] = {
    [sym_expression] = STATE(5052),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4139),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4139),
    [sym_call_expression] = STATE(4139),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4139),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4139),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4139),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4139),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3884),
    [anon_sym_LPAREN2] = ACTIONS(4747),
    [anon_sym_BANG] = ACTIONS(3888),
    [anon_sym_TILDE] = ACTIONS(3888),
    [anon_sym_DASH] = ACTIONS(3886),
    [anon_sym_PLUS] = ACTIONS(3886),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3890),
    [anon_sym_COLON_COLON] = ACTIONS(3892),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3886),
    [anon_sym_compl] = ACTIONS(3886),
    [anon_sym_DASH_DASH] = ACTIONS(4738),
    [anon_sym_PLUS_PLUS] = ACTIONS(4738),
    [anon_sym_sizeof] = ACTIONS(3894),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3896),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3898),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1596)] = {
    [sym_expression] = STATE(5058),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1597)] = {
    [sym_expression] = STATE(3614),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1598)] = {
    [sym_expression] = STATE(3616),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1599)] = {
    [sym_expression] = STATE(5175),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(5088),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1600)] = {
    [sym_expression] = STATE(5177),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1601)] = {
    [sym_expression] = STATE(4572),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1602)] = {
    [sym_expression] = STATE(5179),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1603)] = {
    [sym_expression] = STATE(5180),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1604)] = {
    [sym_expression] = STATE(5181),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1605)] = {
    [sym_expression] = STATE(5182),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1606)] = {
    [sym_expression] = STATE(5183),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1607)] = {
    [sym_expression] = STATE(5184),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1608)] = {
    [sym_expression] = STATE(5185),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1609)] = {
    [sym_expression] = STATE(5186),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1610)] = {
    [sym_expression] = STATE(5187),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1611)] = {
    [sym_expression] = STATE(5308),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1612)] = {
    [sym_expression] = STATE(5191),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1613)] = {
    [sym_expression] = STATE(5193),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1614)] = {
    [sym_expression] = STATE(4574),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1615)] = {
    [sym_expression] = STATE(4575),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1616)] = {
    [sym_expression] = STATE(5200),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(5090),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1617)] = {
    [sym_expression] = STATE(4577),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1618)] = {
    [sym_expression] = STATE(5095),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1619)] = {
    [sym_expression] = STATE(5111),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1620)] = {
    [sym_expression] = STATE(5120),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1621)] = {
    [sym_expression] = STATE(5128),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1622)] = {
    [sym_expression] = STATE(5132),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1623)] = {
    [sym_expression] = STATE(5324),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1624)] = {
    [sym_expression] = STATE(3660),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1625)] = {
    [sym_expression] = STATE(3615),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1626)] = {
    [sym_expression] = STATE(3622),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1627)] = {
    [sym_expression] = STATE(3623),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1628)] = {
    [sym_expression] = STATE(3624),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1629)] = {
    [sym_expression] = STATE(3625),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1630)] = {
    [sym_expression] = STATE(3626),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1631)] = {
    [sym_expression] = STATE(3627),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1632)] = {
    [sym_expression] = STATE(3628),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1633)] = {
    [sym_expression] = STATE(3629),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1634)] = {
    [sym_expression] = STATE(3630),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1635)] = {
    [sym_expression] = STATE(3631),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1636)] = {
    [sym_expression] = STATE(3618),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(5092),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1637)] = {
    [sym_expression] = STATE(3619),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1638)] = {
    [sym_expression] = STATE(3620),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(5094),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1639)] = {
    [sym_expression] = STATE(3632),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1640)] = {
    [sym_expression] = STATE(3635),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1641)] = {
    [sym_expression] = STATE(3637),
    [sym__string] = STATE(3222),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3222),
    [sym_concatenated_string] = STATE(3222),
    [sym_string_literal] = STATE(2398),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2398),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4802),
    [anon_sym_BANG] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3403),
    [anon_sym_PLUS] = ACTIONS(3403),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym___extension__] = ACTIONS(3407),
    [anon_sym_COLON_COLON] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(3403),
    [anon_sym_compl] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(4688),
    [anon_sym_PLUS_PLUS] = ACTIONS(4688),
    [anon_sym_sizeof] = ACTIONS(3411),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2699),
    [anon_sym_L_SQUOTE] = ACTIONS(2701),
    [anon_sym_u_SQUOTE] = ACTIONS(2701),
    [anon_sym_U_SQUOTE] = ACTIONS(2701),
    [anon_sym_u8_SQUOTE] = ACTIONS(2701),
    [anon_sym_SQUOTE] = ACTIONS(2701),
    [anon_sym_L_DQUOTE] = ACTIONS(2703),
    [anon_sym_u_DQUOTE] = ACTIONS(2703),
    [anon_sym_U_DQUOTE] = ACTIONS(2703),
    [anon_sym_u8_DQUOTE] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3413),
    [anon_sym_R_DQUOTE] = ACTIONS(2707),
    [anon_sym_LR_DQUOTE] = ACTIONS(2707),
    [anon_sym_uR_DQUOTE] = ACTIONS(2707),
    [anon_sym_UR_DQUOTE] = ACTIONS(2707),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2707),
    [anon_sym_co_await] = ACTIONS(3415),
    [anon_sym_new] = ACTIONS(2711),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1642)] = {
    [sym_expression] = STATE(5196),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(4016),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(4016),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(4016),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(4016),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3954),
    [anon_sym_LPAREN2] = ACTIONS(3996),
    [anon_sym_BANG] = ACTIONS(3958),
    [anon_sym_TILDE] = ACTIONS(3958),
    [anon_sym_DASH] = ACTIONS(3956),
    [anon_sym_PLUS] = ACTIONS(3956),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(3960),
    [anon_sym_COLON_COLON] = ACTIONS(3962),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(3956),
    [anon_sym_compl] = ACTIONS(3956),
    [anon_sym_DASH_DASH] = ACTIONS(4000),
    [anon_sym_PLUS_PLUS] = ACTIONS(4000),
    [anon_sym_sizeof] = ACTIONS(3964),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(3966),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(3968),
    [anon_sym_new] = ACTIONS(3900),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1643)] = {
    [sym_expression] = STATE(5376),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1644)] = {
    [sym_expression] = STATE(5377),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1645)] = {
    [sym_expression] = STATE(5378),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1646)] = {
    [sym_expression] = STATE(5379),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1647)] = {
    [sym_expression] = STATE(5380),
    [sym__string] = STATE(4873),
    [sym_conditional_expression] = STATE(4360),
    [sym_assignment_expression] = STATE(4360),
    [sym_pointer_expression] = STATE(3694),
    [sym_unary_expression] = STATE(4360),
    [sym_binary_expression] = STATE(4360),
    [sym_update_expression] = STATE(4360),
    [sym_cast_expression] = STATE(4360),
    [sym_sizeof_expression] = STATE(4360),
    [sym_alignof_expression] = STATE(4360),
    [sym_offsetof_expression] = STATE(4360),
    [sym_generic_expression] = STATE(4360),
    [sym_subscript_expression] = STATE(3694),
    [sym_call_expression] = STATE(3694),
    [sym_gnu_asm_expression] = STATE(4360),
    [sym_extension_expression] = STATE(4360),
    [sym_field_expression] = STATE(3694),
    [sym_compound_literal_expression] = STATE(4360),
    [sym_parenthesized_expression] = STATE(3694),
    [sym_char_literal] = STATE(4873),
    [sym_concatenated_string] = STATE(4873),
    [sym_string_literal] = STATE(3579),
    [sym_null] = STATE(4360),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8212),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(4360),
    [sym_raw_string_literal] = STATE(3579),
    [sym_co_await_expression] = STATE(4360),
    [sym_new_expression] = STATE(4360),
    [sym_delete_expression] = STATE(4360),
    [sym_requires_clause] = STATE(4360),
    [sym_requires_expression] = STATE(4360),
    [sym_lambda_expression] = STATE(4360),
    [sym_lambda_capture_specifier] = STATE(6533),
    [sym_fold_expression] = STATE(4360),
    [sym_parameter_pack_expansion] = STATE(4360),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(8212),
    [sym_user_defined_literal] = STATE(3694),
    [sym_kernel_call_expression] = STATE(4373),
    [sym_identifier] = ACTIONS(3800),
    [anon_sym_LPAREN2] = ACTIONS(1235),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1237),
    [anon_sym_AMP] = ACTIONS(1237),
    [anon_sym___extension__] = ACTIONS(2974),
    [anon_sym_COLON_COLON] = ACTIONS(45),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2976),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(101),
    [anon_sym_sizeof] = ACTIONS(103),
    [anon_sym___alignof__] = ACTIONS(105),
    [anon_sym___alignof] = ACTIONS(105),
    [anon_sym__alignof] = ACTIONS(105),
    [anon_sym_alignof] = ACTIONS(105),
    [anon_sym__Alignof] = ACTIONS(105),
    [anon_sym_offsetof] = ACTIONS(107),
    [anon_sym__Generic] = ACTIONS(109),
    [anon_sym_asm] = ACTIONS(111),
    [anon_sym___asm__] = ACTIONS(111),
    [anon_sym___asm] = ACTIONS(111),
    [sym_number_literal] = ACTIONS(221),
    [anon_sym_L_SQUOTE] = ACTIONS(115),
    [anon_sym_u_SQUOTE] = ACTIONS(115),
    [anon_sym_U_SQUOTE] = ACTIONS(115),
    [anon_sym_u8_SQUOTE] = ACTIONS(115),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_L_DQUOTE] = ACTIONS(117),
    [anon_sym_u_DQUOTE] = ACTIONS(117),
    [anon_sym_U_DQUOTE] = ACTIONS(117),
    [anon_sym_u8_DQUOTE] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_true] = ACTIONS(223),
    [sym_false] = ACTIONS(223),
    [anon_sym_NULL] = ACTIONS(121),
    [anon_sym_nullptr] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(137),
    [anon_sym_R_DQUOTE] = ACTIONS(153),
    [anon_sym_LR_DQUOTE] = ACTIONS(153),
    [anon_sym_uR_DQUOTE] = ACTIONS(153),
    [anon_sym_UR_DQUOTE] = ACTIONS(153),
    [anon_sym_u8R_DQUOTE] = ACTIONS(153),
    [anon_sym_co_await] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
    [anon_sym_requires] = ACTIONS(159),
    [sym_this] = ACTIONS(223),
  },
  [STATE(1648)] = {
    [sym_expression] = STATE(2628),
    [sym__string] = STATE(3146),
    [sym_conditional_expression] = STATE(2817),
    [sym_assignment_expression] = STATE(2817),
    [sym_pointer_expression] = STATE(2739),
    [sym_unary_expression] = STATE(2817),
    [sym_binary_expression] = STATE(2817),
    [sym_update_expression] = STATE(2817),
    [sym_cast_expression] = STATE(2817),
    [sym_sizeof_expression] = STATE(2817),
    [sym_alignof_expression] = STATE(2817),
    [sym_offsetof_expression] = STATE(2817),
    [sym_generic_expression] = STATE(2817),
    [sym_subscript_expression] = STATE(2739),
    [sym_call_expression] = STATE(2739),
    [sym_gnu_asm_expression] = STATE(2817),
    [sym_extension_expression] = STATE(2817),
    [sym_field_expression] = STATE(2739),
    [sym_compound_literal_expression] = STATE(2817),
    [sym_parenthesized_expression] = STATE(2739),
    [sym_char_literal] = STATE(3146),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2358),
    [sym_null] = STATE(2817),
    [sym_decltype] = STATE(9247),
    [sym__class_name] = STATE(8547),
    [sym_template_type] = STATE(2161),
    [sym_template_function] = STATE(2817),
    [sym_raw_string_literal] = STATE(2358),
    [sym_co_await_expression] = STATE(2817),
    [sym_new_expression] = STATE(2817),
    [sym_delete_expression] = STATE(2817),
    [sym_requires_clause] = STATE(2817),
    [sym_requires_expression] = STATE(2817),
    [sym_lambda_expression] = STATE(2817),
    [sym_lambda_capture_specifier] = STATE(6572),
    [sym_fold_expression] = STATE(2817),
    [sym_parameter_pack_expansion] = STATE(2817),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6291),
    [sym_qualified_identifier] = STATE(2739),
    [sym_qualified_type_identifier] = STATE(8547),
    [sym_user_defined_literal] = STATE(2739),
    [sym_kernel_call_expression] = STATE(2833),
    [sym_identifier] = ACTIONS(2687),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2637),
    [anon_sym_PLUS] = ACTIONS(2637),
    [anon_sym_STAR] = ACTIONS(4774),
    [anon_sym_AMP] = ACTIONS(4774),
    [anon_sym___extension__] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2647),
    [anon_sym_not] = ACTIONS(2637),
    [anon_sym_compl] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4701),
    [anon_sym_sizeof] = ACTIONS(2649),
    [anon_sym___alignof__] = ACTIONS(2651),
    [anon_sym___alignof] = ACTIONS(2651),
    [anon_sym__alignof] = ACTIONS(2651),
    [anon_sym_alignof] = ACTIONS(2651),
    [anon_sym__Alignof] = ACTIONS(2651),
    [anon_sym_offsetof] = ACTIONS(2653),
    [anon_sym__Generic] = ACTIONS(2655),
    [anon_sym_asm] = ACTIONS(2657),
    [anon_sym___asm__] = ACTIONS(2657),
    [anon_sym___asm] = ACTIONS(2657),
    [sym_number_literal] = ACTIONS(2659),
    [anon_sym_L_SQUOTE] = ACTIONS(2661),
    [anon_sym_u_SQUOTE] = ACTIONS(2661),
    [anon_sym_U_SQUOTE] = ACTIONS(2661),
    [anon_sym_u8_SQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_true] = ACTIONS(2665),
    [sym_false] = ACTIONS(2665),
    [anon_sym_NULL] = ACTIONS(2667),
    [anon_sym_nullptr] = ACTIONS(2667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_delete] = ACTIONS(2671),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [anon_sym_co_await] = ACTIONS(2675),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_requires] = ACTIONS(2679),
    [sym_this] = ACTIONS(2665),
  },
  [STATE(1649)] = {
    [sym_string_literal] = STATE(2433),
    [sym_template_argument_list] = STATE(1905),
    [sym_raw_string_literal] = STATE(2433),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2201),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(4006),
    [anon_sym_LPAREN2] = ACTIONS(4006),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5096),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym___extension__] = ACTIONS(4010),
    [anon_sym___global__] = ACTIONS(4010),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5099),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(5101),
    [anon_sym_unsigned] = ACTIONS(5101),
    [anon_sym_long] = ACTIONS(5101),
    [anon_sym_short] = ACTIONS(5101),
    [anon_sym_LBRACK] = ACTIONS(4032),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4010),
    [anon_sym_volatile] = ACTIONS(4010),
    [anon_sym_restrict] = ACTIONS(4010),
    [anon_sym___restrict__] = ACTIONS(4010),
    [anon_sym__Atomic] = ACTIONS(4010),
    [anon_sym__Noreturn] = ACTIONS(4010),
    [anon_sym_noreturn] = ACTIONS(4010),
    [anon_sym__Nonnull] = ACTIONS(4010),
    [anon_sym_mutable] = ACTIONS(4010),
    [anon_sym_constinit] = ACTIONS(4010),
    [anon_sym_consteval] = ACTIONS(4010),
    [anon_sym___shared__] = ACTIONS(4010),
    [anon_sym___local__] = ACTIONS(4010),
    [anon_sym___constant__] = ACTIONS(4010),
    [anon_sym___managed__] = ACTIONS(4010),
    [anon_sym___grid_constant__] = ACTIONS(4010),
    [anon_sym_alignas] = ACTIONS(4010),
    [anon_sym__Alignas] = ACTIONS(4010),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4012),
    [anon_sym_L_DQUOTE] = ACTIONS(5103),
    [anon_sym_u_DQUOTE] = ACTIONS(5103),
    [anon_sym_U_DQUOTE] = ACTIONS(5103),
    [anon_sym_u8_DQUOTE] = ACTIONS(5103),
    [anon_sym_DQUOTE] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4010),
    [anon_sym_decltype] = ACTIONS(4010),
    [anon_sym_R_DQUOTE] = ACTIONS(5105),
    [anon_sym_LR_DQUOTE] = ACTIONS(5105),
    [anon_sym_uR_DQUOTE] = ACTIONS(5105),
    [anon_sym_UR_DQUOTE] = ACTIONS(5105),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5105),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(1650)] = {
    [sym_string_literal] = STATE(2433),
    [sym_template_argument_list] = STATE(2147),
    [sym_raw_string_literal] = STATE(2433),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2201),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5107),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym___extension__] = ACTIONS(4010),
    [anon_sym___global__] = ACTIONS(4010),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(5101),
    [anon_sym_unsigned] = ACTIONS(5101),
    [anon_sym_long] = ACTIONS(5101),
    [anon_sym_short] = ACTIONS(5101),
    [anon_sym_LBRACK] = ACTIONS(4017),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4010),
    [anon_sym_volatile] = ACTIONS(4010),
    [anon_sym_restrict] = ACTIONS(4010),
    [anon_sym___restrict__] = ACTIONS(4010),
    [anon_sym__Atomic] = ACTIONS(4010),
    [anon_sym__Noreturn] = ACTIONS(4010),
    [anon_sym_noreturn] = ACTIONS(4010),
    [anon_sym__Nonnull] = ACTIONS(4010),
    [anon_sym_mutable] = ACTIONS(4010),
    [anon_sym_constinit] = ACTIONS(4010),
    [anon_sym_consteval] = ACTIONS(4010),
    [anon_sym___shared__] = ACTIONS(4010),
    [anon_sym___local__] = ACTIONS(4010),
    [anon_sym___constant__] = ACTIONS(4010),
    [anon_sym___managed__] = ACTIONS(4010),
    [anon_sym___grid_constant__] = ACTIONS(4010),
    [anon_sym_alignas] = ACTIONS(4010),
    [anon_sym__Alignas] = ACTIONS(4010),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4012),
    [anon_sym_L_DQUOTE] = ACTIONS(5103),
    [anon_sym_u_DQUOTE] = ACTIONS(5103),
    [anon_sym_U_DQUOTE] = ACTIONS(5103),
    [anon_sym_u8_DQUOTE] = ACTIONS(5103),
    [anon_sym_DQUOTE] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4010),
    [anon_sym_decltype] = ACTIONS(4010),
    [anon_sym_R_DQUOTE] = ACTIONS(5105),
    [anon_sym_LR_DQUOTE] = ACTIONS(5105),
    [anon_sym_uR_DQUOTE] = ACTIONS(5105),
    [anon_sym_UR_DQUOTE] = ACTIONS(5105),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5105),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(1651)] = {
    [sym_type_qualifier] = STATE(1651),
    [sym_alignas_qualifier] = STATE(1656),
    [aux_sym__type_definition_type_repeat1] = STATE(1651),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_RPAREN] = ACTIONS(5112),
    [aux_sym_preproc_if_token2] = ACTIONS(5112),
    [aux_sym_preproc_else_token1] = ACTIONS(5112),
    [aux_sym_preproc_elif_token1] = ACTIONS(5110),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5112),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_DASH] = ACTIONS(5110),
    [anon_sym_PLUS] = ACTIONS(5110),
    [anon_sym_STAR] = ACTIONS(5110),
    [anon_sym_SLASH] = ACTIONS(5110),
    [anon_sym_PERCENT] = ACTIONS(5110),
    [anon_sym_PIPE_PIPE] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_PIPE] = ACTIONS(5110),
    [anon_sym_CARET] = ACTIONS(5110),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_EQ_EQ] = ACTIONS(5112),
    [anon_sym_BANG_EQ] = ACTIONS(5112),
    [anon_sym_GT] = ACTIONS(5110),
    [anon_sym_GT_EQ] = ACTIONS(5112),
    [anon_sym_LT_EQ] = ACTIONS(5110),
    [anon_sym_LT] = ACTIONS(5110),
    [anon_sym_LT_LT] = ACTIONS(5110),
    [anon_sym_GT_GT] = ACTIONS(5110),
    [anon_sym_SEMI] = ACTIONS(5112),
    [anon_sym___extension__] = ACTIONS(5114),
    [anon_sym___global__] = ACTIONS(5114),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_RBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5112),
    [anon_sym_RBRACK] = ACTIONS(5112),
    [anon_sym_EQ] = ACTIONS(5110),
    [anon_sym_const] = ACTIONS(5114),
    [anon_sym_constexpr] = ACTIONS(5114),
    [anon_sym_volatile] = ACTIONS(5114),
    [anon_sym_restrict] = ACTIONS(5114),
    [anon_sym___restrict__] = ACTIONS(5114),
    [anon_sym__Atomic] = ACTIONS(5114),
    [anon_sym__Noreturn] = ACTIONS(5114),
    [anon_sym_noreturn] = ACTIONS(5114),
    [anon_sym__Nonnull] = ACTIONS(5114),
    [anon_sym_mutable] = ACTIONS(5114),
    [anon_sym_constinit] = ACTIONS(5114),
    [anon_sym_consteval] = ACTIONS(5114),
    [anon_sym___shared__] = ACTIONS(5114),
    [anon_sym___local__] = ACTIONS(5114),
    [anon_sym___constant__] = ACTIONS(5114),
    [anon_sym___managed__] = ACTIONS(5114),
    [anon_sym___grid_constant__] = ACTIONS(5114),
    [anon_sym_alignas] = ACTIONS(5117),
    [anon_sym__Alignas] = ACTIONS(5117),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_COLON] = ACTIONS(5112),
    [anon_sym_QMARK] = ACTIONS(5112),
    [anon_sym_STAR_EQ] = ACTIONS(5112),
    [anon_sym_SLASH_EQ] = ACTIONS(5112),
    [anon_sym_PERCENT_EQ] = ACTIONS(5112),
    [anon_sym_PLUS_EQ] = ACTIONS(5112),
    [anon_sym_DASH_EQ] = ACTIONS(5112),
    [anon_sym_LT_LT_EQ] = ACTIONS(5112),
    [anon_sym_GT_GT_EQ] = ACTIONS(5112),
    [anon_sym_AMP_EQ] = ACTIONS(5112),
    [anon_sym_CARET_EQ] = ACTIONS(5112),
    [anon_sym_PIPE_EQ] = ACTIONS(5112),
    [anon_sym_and_eq] = ACTIONS(5110),
    [anon_sym_or_eq] = ACTIONS(5110),
    [anon_sym_xor_eq] = ACTIONS(5110),
    [anon_sym_LT_EQ_GT] = ACTIONS(5112),
    [anon_sym_or] = ACTIONS(5110),
    [anon_sym_and] = ACTIONS(5110),
    [anon_sym_bitor] = ACTIONS(5110),
    [anon_sym_xor] = ACTIONS(5110),
    [anon_sym_bitand] = ACTIONS(5110),
    [anon_sym_not_eq] = ACTIONS(5110),
    [anon_sym_DASH_DASH] = ACTIONS(5112),
    [anon_sym_PLUS_PLUS] = ACTIONS(5112),
    [anon_sym_DOT] = ACTIONS(5110),
    [anon_sym_DOT_STAR] = ACTIONS(5112),
    [anon_sym_DASH_GT] = ACTIONS(5112),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5112),
  },
  [STATE(1652)] = {
    [sym_string_literal] = STATE(3782),
    [sym_template_argument_list] = STATE(2866),
    [sym_raw_string_literal] = STATE(3782),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2287),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4017),
    [anon_sym_COMMA] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4012),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5120),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym___extension__] = ACTIONS(4010),
    [anon_sym___global__] = ACTIONS(4010),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(5123),
    [anon_sym_unsigned] = ACTIONS(5123),
    [anon_sym_long] = ACTIONS(5123),
    [anon_sym_short] = ACTIONS(5123),
    [anon_sym_LBRACK] = ACTIONS(4017),
    [anon_sym_EQ] = ACTIONS(5125),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4010),
    [anon_sym_volatile] = ACTIONS(4010),
    [anon_sym_restrict] = ACTIONS(4010),
    [anon_sym___restrict__] = ACTIONS(4010),
    [anon_sym__Atomic] = ACTIONS(4010),
    [anon_sym__Noreturn] = ACTIONS(4010),
    [anon_sym_noreturn] = ACTIONS(4010),
    [anon_sym__Nonnull] = ACTIONS(4010),
    [anon_sym_mutable] = ACTIONS(4010),
    [anon_sym_constinit] = ACTIONS(4010),
    [anon_sym_consteval] = ACTIONS(4010),
    [anon_sym___shared__] = ACTIONS(4010),
    [anon_sym___local__] = ACTIONS(4010),
    [anon_sym___constant__] = ACTIONS(4010),
    [anon_sym___managed__] = ACTIONS(4010),
    [anon_sym___grid_constant__] = ACTIONS(4010),
    [anon_sym_alignas] = ACTIONS(4010),
    [anon_sym__Alignas] = ACTIONS(4010),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(5127),
    [anon_sym_SLASH_EQ] = ACTIONS(5127),
    [anon_sym_PERCENT_EQ] = ACTIONS(5127),
    [anon_sym_PLUS_EQ] = ACTIONS(5127),
    [anon_sym_DASH_EQ] = ACTIONS(5127),
    [anon_sym_LT_LT_EQ] = ACTIONS(5127),
    [anon_sym_GT_GT_EQ] = ACTIONS(5125),
    [anon_sym_AMP_EQ] = ACTIONS(5127),
    [anon_sym_CARET_EQ] = ACTIONS(5127),
    [anon_sym_PIPE_EQ] = ACTIONS(5127),
    [anon_sym_and_eq] = ACTIONS(5127),
    [anon_sym_or_eq] = ACTIONS(5127),
    [anon_sym_xor_eq] = ACTIONS(5127),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(5129),
    [anon_sym_u_DQUOTE] = ACTIONS(5129),
    [anon_sym_U_DQUOTE] = ACTIONS(5129),
    [anon_sym_u8_DQUOTE] = ACTIONS(5129),
    [anon_sym_DQUOTE] = ACTIONS(5129),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4010),
    [anon_sym_decltype] = ACTIONS(4010),
    [anon_sym_GT2] = ACTIONS(4017),
    [anon_sym_R_DQUOTE] = ACTIONS(5131),
    [anon_sym_LR_DQUOTE] = ACTIONS(5131),
    [anon_sym_uR_DQUOTE] = ACTIONS(5131),
    [anon_sym_UR_DQUOTE] = ACTIONS(5131),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5131),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(1653)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4555),
    [anon_sym_COMMA] = ACTIONS(4555),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4557),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4555),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4555),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4555),
    [anon_sym_SEMI] = ACTIONS(4557),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4557),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym___cdecl] = ACTIONS(4553),
    [anon_sym___clrcall] = ACTIONS(4553),
    [anon_sym___stdcall] = ACTIONS(4553),
    [anon_sym___fastcall] = ACTIONS(4553),
    [anon_sym___thiscall] = ACTIONS(4553),
    [anon_sym___vectorcall] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_RBRACE] = ACTIONS(4555),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_RBRACK] = ACTIONS(4555),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_operator] = ACTIONS(4553),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(1654)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [aux_sym_preproc_if_token2] = ACTIONS(5135),
    [aux_sym_preproc_else_token1] = ACTIONS(5135),
    [aux_sym_preproc_elif_token1] = ACTIONS(5133),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5135),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_RBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(5137),
    [anon_sym_unsigned] = ACTIONS(5137),
    [anon_sym_long] = ACTIONS(5137),
    [anon_sym_short] = ACTIONS(5137),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_RBRACK] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_COLON] = ACTIONS(5135),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5135),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_and_eq] = ACTIONS(5133),
    [anon_sym_or_eq] = ACTIONS(5133),
    [anon_sym_xor_eq] = ACTIONS(5133),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
  },
  [STATE(1655)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(2945),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2201),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(4017),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4014),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4017),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4014),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym___extension__] = ACTIONS(4010),
    [anon_sym___global__] = ACTIONS(4010),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_signed] = ACTIONS(5101),
    [anon_sym_unsigned] = ACTIONS(5101),
    [anon_sym_long] = ACTIONS(5101),
    [anon_sym_short] = ACTIONS(5101),
    [anon_sym_LBRACK] = ACTIONS(4017),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4010),
    [anon_sym_volatile] = ACTIONS(4010),
    [anon_sym_restrict] = ACTIONS(4010),
    [anon_sym___restrict__] = ACTIONS(4010),
    [anon_sym__Atomic] = ACTIONS(4010),
    [anon_sym__Noreturn] = ACTIONS(4010),
    [anon_sym_noreturn] = ACTIONS(4010),
    [anon_sym__Nonnull] = ACTIONS(4010),
    [anon_sym_mutable] = ACTIONS(4010),
    [anon_sym_constinit] = ACTIONS(4010),
    [anon_sym_consteval] = ACTIONS(4010),
    [anon_sym___shared__] = ACTIONS(4010),
    [anon_sym___local__] = ACTIONS(4010),
    [anon_sym___constant__] = ACTIONS(4010),
    [anon_sym___managed__] = ACTIONS(4010),
    [anon_sym___grid_constant__] = ACTIONS(4010),
    [anon_sym_alignas] = ACTIONS(4010),
    [anon_sym__Alignas] = ACTIONS(4010),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4010),
    [anon_sym_decltype] = ACTIONS(4010),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(1656)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_RPAREN] = ACTIONS(1959),
    [aux_sym_preproc_if_token2] = ACTIONS(1959),
    [aux_sym_preproc_else_token1] = ACTIONS(1959),
    [aux_sym_preproc_elif_token1] = ACTIONS(1969),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1959),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1969),
    [anon_sym_PIPE_PIPE] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1959),
    [anon_sym_BANG_EQ] = ACTIONS(1959),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1959),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_RBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_RBRACK] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(1959),
    [anon_sym_STAR_EQ] = ACTIONS(1959),
    [anon_sym_SLASH_EQ] = ACTIONS(1959),
    [anon_sym_PERCENT_EQ] = ACTIONS(1959),
    [anon_sym_PLUS_EQ] = ACTIONS(1959),
    [anon_sym_DASH_EQ] = ACTIONS(1959),
    [anon_sym_LT_LT_EQ] = ACTIONS(1959),
    [anon_sym_GT_GT_EQ] = ACTIONS(1959),
    [anon_sym_AMP_EQ] = ACTIONS(1959),
    [anon_sym_CARET_EQ] = ACTIONS(1959),
    [anon_sym_PIPE_EQ] = ACTIONS(1959),
    [anon_sym_and_eq] = ACTIONS(1969),
    [anon_sym_or_eq] = ACTIONS(1969),
    [anon_sym_xor_eq] = ACTIONS(1969),
    [anon_sym_LT_EQ_GT] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1959),
    [anon_sym_DASH_GT] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1959),
  },
  [STATE(1657)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_RPAREN] = ACTIONS(5145),
    [aux_sym_preproc_if_token2] = ACTIONS(5145),
    [aux_sym_preproc_else_token1] = ACTIONS(5145),
    [aux_sym_preproc_elif_token1] = ACTIONS(5143),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5145),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5143),
    [anon_sym_SLASH] = ACTIONS(5143),
    [anon_sym_PERCENT] = ACTIONS(5143),
    [anon_sym_PIPE_PIPE] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_PIPE] = ACTIONS(5143),
    [anon_sym_CARET] = ACTIONS(5143),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_GT] = ACTIONS(5143),
    [anon_sym_GT_EQ] = ACTIONS(5145),
    [anon_sym_LT_EQ] = ACTIONS(5143),
    [anon_sym_LT] = ACTIONS(5143),
    [anon_sym_LT_LT] = ACTIONS(5143),
    [anon_sym_GT_GT] = ACTIONS(5143),
    [anon_sym_SEMI] = ACTIONS(5145),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_RBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_RBRACK] = ACTIONS(5145),
    [anon_sym_EQ] = ACTIONS(5143),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_COLON] = ACTIONS(5145),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_STAR_EQ] = ACTIONS(5145),
    [anon_sym_SLASH_EQ] = ACTIONS(5145),
    [anon_sym_PERCENT_EQ] = ACTIONS(5145),
    [anon_sym_PLUS_EQ] = ACTIONS(5145),
    [anon_sym_DASH_EQ] = ACTIONS(5145),
    [anon_sym_LT_LT_EQ] = ACTIONS(5145),
    [anon_sym_GT_GT_EQ] = ACTIONS(5145),
    [anon_sym_AMP_EQ] = ACTIONS(5145),
    [anon_sym_CARET_EQ] = ACTIONS(5145),
    [anon_sym_PIPE_EQ] = ACTIONS(5145),
    [anon_sym_and_eq] = ACTIONS(5143),
    [anon_sym_or_eq] = ACTIONS(5143),
    [anon_sym_xor_eq] = ACTIONS(5143),
    [anon_sym_LT_EQ_GT] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5143),
    [anon_sym_and] = ACTIONS(5143),
    [anon_sym_bitor] = ACTIONS(5143),
    [anon_sym_xor] = ACTIONS(5143),
    [anon_sym_bitand] = ACTIONS(5143),
    [anon_sym_not_eq] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5143),
    [anon_sym_DOT_STAR] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5145),
  },
  [STATE(1658)] = {
    [sym_function_definition] = STATE(482),
    [sym_declaration] = STATE(482),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5455),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1891),
    [sym_declaration_list] = STATE(482),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(5151),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1659)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4560),
    [anon_sym_COMMA] = ACTIONS(4560),
    [anon_sym_RPAREN] = ACTIONS(4560),
    [anon_sym_LPAREN2] = ACTIONS(4560),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_STAR] = ACTIONS(4560),
    [anon_sym_PIPE_PIPE] = ACTIONS(4560),
    [anon_sym_AMP_AMP] = ACTIONS(4560),
    [anon_sym_AMP] = ACTIONS(4553),
    [anon_sym_SEMI] = ACTIONS(4560),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4560),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym___cdecl] = ACTIONS(4553),
    [anon_sym___clrcall] = ACTIONS(4553),
    [anon_sym___stdcall] = ACTIONS(4553),
    [anon_sym___fastcall] = ACTIONS(4553),
    [anon_sym___thiscall] = ACTIONS(4553),
    [anon_sym___vectorcall] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_signed] = ACTIONS(4553),
    [anon_sym_unsigned] = ACTIONS(4553),
    [anon_sym_long] = ACTIONS(4553),
    [anon_sym_short] = ACTIONS(4553),
    [anon_sym_LBRACK] = ACTIONS(4553),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_EQ] = ACTIONS(4560),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [sym_primitive_type] = ACTIONS(4553),
    [anon_sym_enum] = ACTIONS(4553),
    [anon_sym_class] = ACTIONS(4553),
    [anon_sym_struct] = ACTIONS(4553),
    [anon_sym_union] = ACTIONS(4553),
    [anon_sym_COLON] = ACTIONS(4553),
    [anon_sym_or] = ACTIONS(4553),
    [anon_sym_and] = ACTIONS(4553),
    [anon_sym_asm] = ACTIONS(4553),
    [anon_sym___asm__] = ACTIONS(4553),
    [anon_sym___asm] = ACTIONS(4553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_final] = ACTIONS(4553),
    [anon_sym_override] = ACTIONS(4553),
    [anon_sym_explicit] = ACTIONS(4553),
    [anon_sym_typename] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_GT2] = ACTIONS(4560),
    [anon_sym_operator] = ACTIONS(4553),
    [anon_sym_try] = ACTIONS(4553),
    [anon_sym_friend] = ACTIONS(4553),
    [anon_sym_using] = ACTIONS(4553),
    [anon_sym_concept] = ACTIONS(4553),
    [anon_sym_requires] = ACTIONS(4553),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(1660)] = {
    [sym_function_definition] = STATE(301),
    [sym_declaration] = STATE(301),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1890),
    [sym_declaration_list] = STATE(301),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(5153),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1661)] = {
    [sym_type_qualifier] = STATE(1662),
    [sym_alignas_qualifier] = STATE(1656),
    [aux_sym__type_definition_type_repeat1] = STATE(1662),
    [aux_sym_sized_type_specifier_repeat1] = STATE(1706),
    [sym_identifier] = ACTIONS(5155),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [aux_sym_preproc_if_token2] = ACTIONS(5158),
    [aux_sym_preproc_else_token1] = ACTIONS(5158),
    [aux_sym_preproc_elif_token1] = ACTIONS(5160),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5158),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5160),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5160),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5160),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5160),
    [anon_sym___extension__] = ACTIONS(5162),
    [anon_sym___global__] = ACTIONS(5162),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5164),
    [anon_sym_unsigned] = ACTIONS(5164),
    [anon_sym_long] = ACTIONS(5164),
    [anon_sym_short] = ACTIONS(5164),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_EQ] = ACTIONS(5160),
    [anon_sym_const] = ACTIONS(5162),
    [anon_sym_constexpr] = ACTIONS(5162),
    [anon_sym_volatile] = ACTIONS(5162),
    [anon_sym_restrict] = ACTIONS(5162),
    [anon_sym___restrict__] = ACTIONS(5162),
    [anon_sym__Atomic] = ACTIONS(5162),
    [anon_sym__Noreturn] = ACTIONS(5162),
    [anon_sym_noreturn] = ACTIONS(5162),
    [anon_sym__Nonnull] = ACTIONS(5162),
    [anon_sym_mutable] = ACTIONS(5162),
    [anon_sym_constinit] = ACTIONS(5162),
    [anon_sym_consteval] = ACTIONS(5162),
    [anon_sym___shared__] = ACTIONS(5162),
    [anon_sym___local__] = ACTIONS(5162),
    [anon_sym___constant__] = ACTIONS(5162),
    [anon_sym___managed__] = ACTIONS(5162),
    [anon_sym___grid_constant__] = ACTIONS(5162),
    [anon_sym_alignas] = ACTIONS(5166),
    [anon_sym__Alignas] = ACTIONS(5166),
    [sym_primitive_type] = ACTIONS(5168),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_STAR_EQ] = ACTIONS(5158),
    [anon_sym_SLASH_EQ] = ACTIONS(5158),
    [anon_sym_PERCENT_EQ] = ACTIONS(5158),
    [anon_sym_PLUS_EQ] = ACTIONS(5158),
    [anon_sym_DASH_EQ] = ACTIONS(5158),
    [anon_sym_LT_LT_EQ] = ACTIONS(5158),
    [anon_sym_GT_GT_EQ] = ACTIONS(5158),
    [anon_sym_AMP_EQ] = ACTIONS(5158),
    [anon_sym_CARET_EQ] = ACTIONS(5158),
    [anon_sym_PIPE_EQ] = ACTIONS(5158),
    [anon_sym_and_eq] = ACTIONS(5160),
    [anon_sym_or_eq] = ACTIONS(5160),
    [anon_sym_xor_eq] = ACTIONS(5160),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
  },
  [STATE(1662)] = {
    [sym_type_qualifier] = STATE(1651),
    [sym_alignas_qualifier] = STATE(1656),
    [aux_sym__type_definition_type_repeat1] = STATE(1651),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2480),
    [sym_identifier] = ACTIONS(5170),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [aux_sym_preproc_if_token2] = ACTIONS(5173),
    [aux_sym_preproc_else_token1] = ACTIONS(5173),
    [aux_sym_preproc_elif_token1] = ACTIONS(5175),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5173),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5175),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5175),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5175),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5175),
    [anon_sym___extension__] = ACTIONS(5162),
    [anon_sym___global__] = ACTIONS(5162),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5177),
    [anon_sym_unsigned] = ACTIONS(5177),
    [anon_sym_long] = ACTIONS(5177),
    [anon_sym_short] = ACTIONS(5177),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_EQ] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5162),
    [anon_sym_constexpr] = ACTIONS(5162),
    [anon_sym_volatile] = ACTIONS(5162),
    [anon_sym_restrict] = ACTIONS(5162),
    [anon_sym___restrict__] = ACTIONS(5162),
    [anon_sym__Atomic] = ACTIONS(5162),
    [anon_sym__Noreturn] = ACTIONS(5162),
    [anon_sym_noreturn] = ACTIONS(5162),
    [anon_sym__Nonnull] = ACTIONS(5162),
    [anon_sym_mutable] = ACTIONS(5162),
    [anon_sym_constinit] = ACTIONS(5162),
    [anon_sym_consteval] = ACTIONS(5162),
    [anon_sym___shared__] = ACTIONS(5162),
    [anon_sym___local__] = ACTIONS(5162),
    [anon_sym___constant__] = ACTIONS(5162),
    [anon_sym___managed__] = ACTIONS(5162),
    [anon_sym___grid_constant__] = ACTIONS(5162),
    [anon_sym_alignas] = ACTIONS(5166),
    [anon_sym__Alignas] = ACTIONS(5166),
    [sym_primitive_type] = ACTIONS(5179),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_STAR_EQ] = ACTIONS(5173),
    [anon_sym_SLASH_EQ] = ACTIONS(5173),
    [anon_sym_PERCENT_EQ] = ACTIONS(5173),
    [anon_sym_PLUS_EQ] = ACTIONS(5173),
    [anon_sym_DASH_EQ] = ACTIONS(5173),
    [anon_sym_LT_LT_EQ] = ACTIONS(5173),
    [anon_sym_GT_GT_EQ] = ACTIONS(5173),
    [anon_sym_AMP_EQ] = ACTIONS(5173),
    [anon_sym_CARET_EQ] = ACTIONS(5173),
    [anon_sym_PIPE_EQ] = ACTIONS(5173),
    [anon_sym_and_eq] = ACTIONS(5175),
    [anon_sym_or_eq] = ACTIONS(5175),
    [anon_sym_xor_eq] = ACTIONS(5175),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5173),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
  },
  [STATE(1663)] = {
    [sym_function_definition] = STATE(587),
    [sym_declaration] = STATE(587),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1889),
    [sym_declaration_list] = STATE(587),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(5181),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1664)] = {
    [sym_function_definition] = STATE(720),
    [sym_declaration] = STATE(720),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5483),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1888),
    [sym_declaration_list] = STATE(720),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(5183),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1665)] = {
    [sym_type_qualifier] = STATE(1666),
    [sym_alignas_qualifier] = STATE(1656),
    [aux_sym__type_definition_type_repeat1] = STATE(1666),
    [aux_sym_sized_type_specifier_repeat1] = STATE(1710),
    [sym_identifier] = ACTIONS(5185),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_RPAREN] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5160),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5160),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5160),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5160),
    [anon_sym_SEMI] = ACTIONS(5158),
    [anon_sym___extension__] = ACTIONS(5162),
    [anon_sym___global__] = ACTIONS(5162),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_RBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5187),
    [anon_sym_unsigned] = ACTIONS(5187),
    [anon_sym_long] = ACTIONS(5187),
    [anon_sym_short] = ACTIONS(5187),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_RBRACK] = ACTIONS(5158),
    [anon_sym_EQ] = ACTIONS(5160),
    [anon_sym_const] = ACTIONS(5162),
    [anon_sym_constexpr] = ACTIONS(5162),
    [anon_sym_volatile] = ACTIONS(5162),
    [anon_sym_restrict] = ACTIONS(5162),
    [anon_sym___restrict__] = ACTIONS(5162),
    [anon_sym__Atomic] = ACTIONS(5162),
    [anon_sym__Noreturn] = ACTIONS(5162),
    [anon_sym_noreturn] = ACTIONS(5162),
    [anon_sym__Nonnull] = ACTIONS(5162),
    [anon_sym_mutable] = ACTIONS(5162),
    [anon_sym_constinit] = ACTIONS(5162),
    [anon_sym_consteval] = ACTIONS(5162),
    [anon_sym___shared__] = ACTIONS(5162),
    [anon_sym___local__] = ACTIONS(5162),
    [anon_sym___constant__] = ACTIONS(5162),
    [anon_sym___managed__] = ACTIONS(5162),
    [anon_sym___grid_constant__] = ACTIONS(5162),
    [anon_sym_alignas] = ACTIONS(5166),
    [anon_sym__Alignas] = ACTIONS(5166),
    [sym_primitive_type] = ACTIONS(5189),
    [anon_sym_COLON] = ACTIONS(5158),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_STAR_EQ] = ACTIONS(5158),
    [anon_sym_SLASH_EQ] = ACTIONS(5158),
    [anon_sym_PERCENT_EQ] = ACTIONS(5158),
    [anon_sym_PLUS_EQ] = ACTIONS(5158),
    [anon_sym_DASH_EQ] = ACTIONS(5158),
    [anon_sym_LT_LT_EQ] = ACTIONS(5158),
    [anon_sym_GT_GT_EQ] = ACTIONS(5158),
    [anon_sym_AMP_EQ] = ACTIONS(5158),
    [anon_sym_CARET_EQ] = ACTIONS(5158),
    [anon_sym_PIPE_EQ] = ACTIONS(5158),
    [anon_sym_and_eq] = ACTIONS(5160),
    [anon_sym_or_eq] = ACTIONS(5160),
    [anon_sym_xor_eq] = ACTIONS(5160),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
  },
  [STATE(1666)] = {
    [sym_type_qualifier] = STATE(1651),
    [sym_alignas_qualifier] = STATE(1656),
    [aux_sym__type_definition_type_repeat1] = STATE(1651),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2637),
    [sym_identifier] = ACTIONS(5191),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_RPAREN] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5175),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5175),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5175),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5175),
    [anon_sym_SEMI] = ACTIONS(5173),
    [anon_sym___extension__] = ACTIONS(5162),
    [anon_sym___global__] = ACTIONS(5162),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_RBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5193),
    [anon_sym_unsigned] = ACTIONS(5193),
    [anon_sym_long] = ACTIONS(5193),
    [anon_sym_short] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_RBRACK] = ACTIONS(5173),
    [anon_sym_EQ] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5162),
    [anon_sym_constexpr] = ACTIONS(5162),
    [anon_sym_volatile] = ACTIONS(5162),
    [anon_sym_restrict] = ACTIONS(5162),
    [anon_sym___restrict__] = ACTIONS(5162),
    [anon_sym__Atomic] = ACTIONS(5162),
    [anon_sym__Noreturn] = ACTIONS(5162),
    [anon_sym_noreturn] = ACTIONS(5162),
    [anon_sym__Nonnull] = ACTIONS(5162),
    [anon_sym_mutable] = ACTIONS(5162),
    [anon_sym_constinit] = ACTIONS(5162),
    [anon_sym_consteval] = ACTIONS(5162),
    [anon_sym___shared__] = ACTIONS(5162),
    [anon_sym___local__] = ACTIONS(5162),
    [anon_sym___constant__] = ACTIONS(5162),
    [anon_sym___managed__] = ACTIONS(5162),
    [anon_sym___grid_constant__] = ACTIONS(5162),
    [anon_sym_alignas] = ACTIONS(5166),
    [anon_sym__Alignas] = ACTIONS(5166),
    [sym_primitive_type] = ACTIONS(5195),
    [anon_sym_COLON] = ACTIONS(5173),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_STAR_EQ] = ACTIONS(5173),
    [anon_sym_SLASH_EQ] = ACTIONS(5173),
    [anon_sym_PERCENT_EQ] = ACTIONS(5173),
    [anon_sym_PLUS_EQ] = ACTIONS(5173),
    [anon_sym_DASH_EQ] = ACTIONS(5173),
    [anon_sym_LT_LT_EQ] = ACTIONS(5173),
    [anon_sym_GT_GT_EQ] = ACTIONS(5173),
    [anon_sym_AMP_EQ] = ACTIONS(5173),
    [anon_sym_CARET_EQ] = ACTIONS(5173),
    [anon_sym_PIPE_EQ] = ACTIONS(5173),
    [anon_sym_and_eq] = ACTIONS(5175),
    [anon_sym_or_eq] = ACTIONS(5175),
    [anon_sym_xor_eq] = ACTIONS(5175),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5173),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
  },
  [STATE(1667)] = {
    [sym_function_definition] = STATE(283),
    [sym_declaration] = STATE(283),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1890),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(9233),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5199),
    [anon_sym_struct] = ACTIONS(5201),
    [anon_sym_union] = ACTIONS(5203),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1668)] = {
    [sym_function_definition] = STATE(1768),
    [sym_declaration] = STATE(1768),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5466),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1893),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8630),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5205),
    [anon_sym_struct] = ACTIONS(5207),
    [anon_sym_union] = ACTIONS(5209),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1669)] = {
    [sym_function_definition] = STATE(1777),
    [sym_declaration] = STATE(1777),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5466),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1893),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8729),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5211),
    [anon_sym_struct] = ACTIONS(5213),
    [anon_sym_union] = ACTIONS(5215),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1670)] = {
    [sym_function_definition] = STATE(756),
    [sym_declaration] = STATE(756),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5483),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1888),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8867),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5217),
    [anon_sym_struct] = ACTIONS(5219),
    [anon_sym_union] = ACTIONS(5221),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1671)] = {
    [sym_function_definition] = STATE(2017),
    [sym_declaration] = STATE(2017),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5472),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1894),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8979),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5223),
    [anon_sym_struct] = ACTIONS(5225),
    [anon_sym_union] = ACTIONS(5227),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1672)] = {
    [sym_function_definition] = STATE(2043),
    [sym_declaration] = STATE(2043),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5472),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1894),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(9183),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5229),
    [anon_sym_struct] = ACTIONS(5231),
    [anon_sym_union] = ACTIONS(5233),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1673)] = {
    [sym_function_definition] = STATE(524),
    [sym_declaration] = STATE(524),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1889),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8813),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5235),
    [anon_sym_struct] = ACTIONS(5237),
    [anon_sym_union] = ACTIONS(5239),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1674)] = {
    [sym_identifier] = ACTIONS(4396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_RPAREN] = ACTIONS(4398),
    [aux_sym_preproc_if_token2] = ACTIONS(4398),
    [aux_sym_preproc_else_token1] = ACTIONS(4398),
    [aux_sym_preproc_elif_token1] = ACTIONS(4396),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4398),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4396),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4396),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4396),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4398),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4396),
    [anon_sym_SEMI] = ACTIONS(4398),
    [anon_sym___extension__] = ACTIONS(4396),
    [anon_sym___global__] = ACTIONS(4396),
    [anon_sym___attribute__] = ACTIONS(4396),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_RBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4398),
    [anon_sym_RBRACK] = ACTIONS(4398),
    [anon_sym_EQ] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4396),
    [anon_sym_volatile] = ACTIONS(4396),
    [anon_sym_restrict] = ACTIONS(4396),
    [anon_sym___restrict__] = ACTIONS(4396),
    [anon_sym__Atomic] = ACTIONS(4396),
    [anon_sym__Noreturn] = ACTIONS(4396),
    [anon_sym_noreturn] = ACTIONS(4396),
    [anon_sym__Nonnull] = ACTIONS(4396),
    [anon_sym_mutable] = ACTIONS(4396),
    [anon_sym_constinit] = ACTIONS(4396),
    [anon_sym_consteval] = ACTIONS(4396),
    [anon_sym___shared__] = ACTIONS(4396),
    [anon_sym___local__] = ACTIONS(4396),
    [anon_sym___constant__] = ACTIONS(4396),
    [anon_sym___managed__] = ACTIONS(4396),
    [anon_sym___grid_constant__] = ACTIONS(4396),
    [anon_sym_alignas] = ACTIONS(4396),
    [anon_sym__Alignas] = ACTIONS(4396),
    [anon_sym_COLON] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_STAR_EQ] = ACTIONS(4398),
    [anon_sym_SLASH_EQ] = ACTIONS(4398),
    [anon_sym_PERCENT_EQ] = ACTIONS(4398),
    [anon_sym_PLUS_EQ] = ACTIONS(4398),
    [anon_sym_DASH_EQ] = ACTIONS(4398),
    [anon_sym_LT_LT_EQ] = ACTIONS(4398),
    [anon_sym_GT_GT_EQ] = ACTIONS(4398),
    [anon_sym_AMP_EQ] = ACTIONS(4398),
    [anon_sym_CARET_EQ] = ACTIONS(4398),
    [anon_sym_PIPE_EQ] = ACTIONS(4398),
    [anon_sym_and_eq] = ACTIONS(4396),
    [anon_sym_or_eq] = ACTIONS(4396),
    [anon_sym_xor_eq] = ACTIONS(4396),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_bitor] = ACTIONS(4396),
    [anon_sym_xor] = ACTIONS(4396),
    [anon_sym_bitand] = ACTIONS(4396),
    [anon_sym_not_eq] = ACTIONS(4396),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4396),
    [anon_sym_decltype] = ACTIONS(4396),
    [anon_sym_final] = ACTIONS(4396),
    [anon_sym_override] = ACTIONS(4396),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
  },
  [STATE(1675)] = {
    [sym_identifier] = ACTIONS(4402),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_RPAREN] = ACTIONS(4404),
    [aux_sym_preproc_if_token2] = ACTIONS(4404),
    [aux_sym_preproc_else_token1] = ACTIONS(4404),
    [aux_sym_preproc_elif_token1] = ACTIONS(4402),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4404),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4402),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4402),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4402),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4404),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4402),
    [anon_sym_SEMI] = ACTIONS(4404),
    [anon_sym___extension__] = ACTIONS(4402),
    [anon_sym___global__] = ACTIONS(4402),
    [anon_sym___attribute__] = ACTIONS(4402),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_RBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_RBRACK] = ACTIONS(4404),
    [anon_sym_EQ] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4402),
    [anon_sym_volatile] = ACTIONS(4402),
    [anon_sym_restrict] = ACTIONS(4402),
    [anon_sym___restrict__] = ACTIONS(4402),
    [anon_sym__Atomic] = ACTIONS(4402),
    [anon_sym__Noreturn] = ACTIONS(4402),
    [anon_sym_noreturn] = ACTIONS(4402),
    [anon_sym__Nonnull] = ACTIONS(4402),
    [anon_sym_mutable] = ACTIONS(4402),
    [anon_sym_constinit] = ACTIONS(4402),
    [anon_sym_consteval] = ACTIONS(4402),
    [anon_sym___shared__] = ACTIONS(4402),
    [anon_sym___local__] = ACTIONS(4402),
    [anon_sym___constant__] = ACTIONS(4402),
    [anon_sym___managed__] = ACTIONS(4402),
    [anon_sym___grid_constant__] = ACTIONS(4402),
    [anon_sym_alignas] = ACTIONS(4402),
    [anon_sym__Alignas] = ACTIONS(4402),
    [anon_sym_COLON] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_STAR_EQ] = ACTIONS(4404),
    [anon_sym_SLASH_EQ] = ACTIONS(4404),
    [anon_sym_PERCENT_EQ] = ACTIONS(4404),
    [anon_sym_PLUS_EQ] = ACTIONS(4404),
    [anon_sym_DASH_EQ] = ACTIONS(4404),
    [anon_sym_LT_LT_EQ] = ACTIONS(4404),
    [anon_sym_GT_GT_EQ] = ACTIONS(4404),
    [anon_sym_AMP_EQ] = ACTIONS(4404),
    [anon_sym_CARET_EQ] = ACTIONS(4404),
    [anon_sym_PIPE_EQ] = ACTIONS(4404),
    [anon_sym_and_eq] = ACTIONS(4402),
    [anon_sym_or_eq] = ACTIONS(4402),
    [anon_sym_xor_eq] = ACTIONS(4402),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_bitor] = ACTIONS(4402),
    [anon_sym_xor] = ACTIONS(4402),
    [anon_sym_bitand] = ACTIONS(4402),
    [anon_sym_not_eq] = ACTIONS(4402),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4402),
    [anon_sym_decltype] = ACTIONS(4402),
    [anon_sym_final] = ACTIONS(4402),
    [anon_sym_override] = ACTIONS(4402),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
  },
  [STATE(1676)] = {
    [sym_function_definition] = STATE(548),
    [sym_declaration] = STATE(548),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5469),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1889),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8637),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5241),
    [anon_sym_struct] = ACTIONS(5243),
    [anon_sym_union] = ACTIONS(5245),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1677)] = {
    [sym_identifier] = ACTIONS(4330),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_RPAREN] = ACTIONS(4332),
    [aux_sym_preproc_if_token2] = ACTIONS(4332),
    [aux_sym_preproc_else_token1] = ACTIONS(4332),
    [aux_sym_preproc_elif_token1] = ACTIONS(4330),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4330),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4330),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4330),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4332),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4330),
    [anon_sym_SEMI] = ACTIONS(4332),
    [anon_sym___extension__] = ACTIONS(4330),
    [anon_sym___global__] = ACTIONS(4330),
    [anon_sym___attribute__] = ACTIONS(4330),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_RBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4332),
    [anon_sym_RBRACK] = ACTIONS(4332),
    [anon_sym_EQ] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4330),
    [anon_sym_volatile] = ACTIONS(4330),
    [anon_sym_restrict] = ACTIONS(4330),
    [anon_sym___restrict__] = ACTIONS(4330),
    [anon_sym__Atomic] = ACTIONS(4330),
    [anon_sym__Noreturn] = ACTIONS(4330),
    [anon_sym_noreturn] = ACTIONS(4330),
    [anon_sym__Nonnull] = ACTIONS(4330),
    [anon_sym_mutable] = ACTIONS(4330),
    [anon_sym_constinit] = ACTIONS(4330),
    [anon_sym_consteval] = ACTIONS(4330),
    [anon_sym___shared__] = ACTIONS(4330),
    [anon_sym___local__] = ACTIONS(4330),
    [anon_sym___constant__] = ACTIONS(4330),
    [anon_sym___managed__] = ACTIONS(4330),
    [anon_sym___grid_constant__] = ACTIONS(4330),
    [anon_sym_alignas] = ACTIONS(4330),
    [anon_sym__Alignas] = ACTIONS(4330),
    [anon_sym_COLON] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_STAR_EQ] = ACTIONS(4332),
    [anon_sym_SLASH_EQ] = ACTIONS(4332),
    [anon_sym_PERCENT_EQ] = ACTIONS(4332),
    [anon_sym_PLUS_EQ] = ACTIONS(4332),
    [anon_sym_DASH_EQ] = ACTIONS(4332),
    [anon_sym_LT_LT_EQ] = ACTIONS(4332),
    [anon_sym_GT_GT_EQ] = ACTIONS(4332),
    [anon_sym_AMP_EQ] = ACTIONS(4332),
    [anon_sym_CARET_EQ] = ACTIONS(4332),
    [anon_sym_PIPE_EQ] = ACTIONS(4332),
    [anon_sym_and_eq] = ACTIONS(4330),
    [anon_sym_or_eq] = ACTIONS(4330),
    [anon_sym_xor_eq] = ACTIONS(4330),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_bitor] = ACTIONS(4330),
    [anon_sym_xor] = ACTIONS(4330),
    [anon_sym_bitand] = ACTIONS(4330),
    [anon_sym_not_eq] = ACTIONS(4330),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4330),
    [anon_sym_decltype] = ACTIONS(4330),
    [anon_sym_final] = ACTIONS(4330),
    [anon_sym_override] = ACTIONS(4330),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
  },
  [STATE(1678)] = {
    [sym_function_definition] = STATE(509),
    [sym_declaration] = STATE(509),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5455),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1891),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(9407),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5247),
    [anon_sym_struct] = ACTIONS(5249),
    [anon_sym_union] = ACTIONS(5251),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1679)] = {
    [sym_function_definition] = STATE(511),
    [sym_declaration] = STATE(511),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5455),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1891),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8920),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5253),
    [anon_sym_struct] = ACTIONS(5255),
    [anon_sym_union] = ACTIONS(5257),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1680)] = {
    [sym_function_definition] = STATE(707),
    [sym_declaration] = STATE(707),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5483),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1888),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8710),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5259),
    [anon_sym_struct] = ACTIONS(5261),
    [anon_sym_union] = ACTIONS(5263),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1681)] = {
    [sym_identifier] = ACTIONS(4408),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_RPAREN] = ACTIONS(4410),
    [aux_sym_preproc_if_token2] = ACTIONS(4410),
    [aux_sym_preproc_else_token1] = ACTIONS(4410),
    [aux_sym_preproc_elif_token1] = ACTIONS(4408),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4410),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4408),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4408),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4408),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4410),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4408),
    [anon_sym_SEMI] = ACTIONS(4410),
    [anon_sym___extension__] = ACTIONS(4408),
    [anon_sym___global__] = ACTIONS(4408),
    [anon_sym___attribute__] = ACTIONS(4408),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_RBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4410),
    [anon_sym_RBRACK] = ACTIONS(4410),
    [anon_sym_EQ] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4408),
    [anon_sym_volatile] = ACTIONS(4408),
    [anon_sym_restrict] = ACTIONS(4408),
    [anon_sym___restrict__] = ACTIONS(4408),
    [anon_sym__Atomic] = ACTIONS(4408),
    [anon_sym__Noreturn] = ACTIONS(4408),
    [anon_sym_noreturn] = ACTIONS(4408),
    [anon_sym__Nonnull] = ACTIONS(4408),
    [anon_sym_mutable] = ACTIONS(4408),
    [anon_sym_constinit] = ACTIONS(4408),
    [anon_sym_consteval] = ACTIONS(4408),
    [anon_sym___shared__] = ACTIONS(4408),
    [anon_sym___local__] = ACTIONS(4408),
    [anon_sym___constant__] = ACTIONS(4408),
    [anon_sym___managed__] = ACTIONS(4408),
    [anon_sym___grid_constant__] = ACTIONS(4408),
    [anon_sym_alignas] = ACTIONS(4408),
    [anon_sym__Alignas] = ACTIONS(4408),
    [anon_sym_COLON] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_STAR_EQ] = ACTIONS(4410),
    [anon_sym_SLASH_EQ] = ACTIONS(4410),
    [anon_sym_PERCENT_EQ] = ACTIONS(4410),
    [anon_sym_PLUS_EQ] = ACTIONS(4410),
    [anon_sym_DASH_EQ] = ACTIONS(4410),
    [anon_sym_LT_LT_EQ] = ACTIONS(4410),
    [anon_sym_GT_GT_EQ] = ACTIONS(4410),
    [anon_sym_AMP_EQ] = ACTIONS(4410),
    [anon_sym_CARET_EQ] = ACTIONS(4410),
    [anon_sym_PIPE_EQ] = ACTIONS(4410),
    [anon_sym_and_eq] = ACTIONS(4408),
    [anon_sym_or_eq] = ACTIONS(4408),
    [anon_sym_xor_eq] = ACTIONS(4408),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_bitor] = ACTIONS(4408),
    [anon_sym_xor] = ACTIONS(4408),
    [anon_sym_bitand] = ACTIONS(4408),
    [anon_sym_not_eq] = ACTIONS(4408),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4408),
    [anon_sym_decltype] = ACTIONS(4408),
    [anon_sym_final] = ACTIONS(4408),
    [anon_sym_override] = ACTIONS(4408),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
  },
  [STATE(1682)] = {
    [sym_identifier] = ACTIONS(4350),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_RPAREN] = ACTIONS(4352),
    [aux_sym_preproc_if_token2] = ACTIONS(4352),
    [aux_sym_preproc_else_token1] = ACTIONS(4352),
    [aux_sym_preproc_elif_token1] = ACTIONS(4350),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4352),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4350),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4350),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4350),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4352),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4350),
    [anon_sym_SEMI] = ACTIONS(4352),
    [anon_sym___extension__] = ACTIONS(4350),
    [anon_sym___global__] = ACTIONS(4350),
    [anon_sym___attribute__] = ACTIONS(4350),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_RBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4352),
    [anon_sym_RBRACK] = ACTIONS(4352),
    [anon_sym_EQ] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4350),
    [anon_sym_volatile] = ACTIONS(4350),
    [anon_sym_restrict] = ACTIONS(4350),
    [anon_sym___restrict__] = ACTIONS(4350),
    [anon_sym__Atomic] = ACTIONS(4350),
    [anon_sym__Noreturn] = ACTIONS(4350),
    [anon_sym_noreturn] = ACTIONS(4350),
    [anon_sym__Nonnull] = ACTIONS(4350),
    [anon_sym_mutable] = ACTIONS(4350),
    [anon_sym_constinit] = ACTIONS(4350),
    [anon_sym_consteval] = ACTIONS(4350),
    [anon_sym___shared__] = ACTIONS(4350),
    [anon_sym___local__] = ACTIONS(4350),
    [anon_sym___constant__] = ACTIONS(4350),
    [anon_sym___managed__] = ACTIONS(4350),
    [anon_sym___grid_constant__] = ACTIONS(4350),
    [anon_sym_alignas] = ACTIONS(4350),
    [anon_sym__Alignas] = ACTIONS(4350),
    [anon_sym_COLON] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_STAR_EQ] = ACTIONS(4352),
    [anon_sym_SLASH_EQ] = ACTIONS(4352),
    [anon_sym_PERCENT_EQ] = ACTIONS(4352),
    [anon_sym_PLUS_EQ] = ACTIONS(4352),
    [anon_sym_DASH_EQ] = ACTIONS(4352),
    [anon_sym_LT_LT_EQ] = ACTIONS(4352),
    [anon_sym_GT_GT_EQ] = ACTIONS(4352),
    [anon_sym_AMP_EQ] = ACTIONS(4352),
    [anon_sym_CARET_EQ] = ACTIONS(4352),
    [anon_sym_PIPE_EQ] = ACTIONS(4352),
    [anon_sym_and_eq] = ACTIONS(4350),
    [anon_sym_or_eq] = ACTIONS(4350),
    [anon_sym_xor_eq] = ACTIONS(4350),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_bitor] = ACTIONS(4350),
    [anon_sym_xor] = ACTIONS(4350),
    [anon_sym_bitand] = ACTIONS(4350),
    [anon_sym_not_eq] = ACTIONS(4350),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4350),
    [anon_sym_decltype] = ACTIONS(4350),
    [anon_sym_final] = ACTIONS(4350),
    [anon_sym_override] = ACTIONS(4350),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
  },
  [STATE(1683)] = {
    [sym_identifier] = ACTIONS(4356),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_RPAREN] = ACTIONS(4358),
    [aux_sym_preproc_if_token2] = ACTIONS(4358),
    [aux_sym_preproc_else_token1] = ACTIONS(4358),
    [aux_sym_preproc_elif_token1] = ACTIONS(4356),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4358),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4356),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4356),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4356),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4358),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4356),
    [anon_sym_SEMI] = ACTIONS(4358),
    [anon_sym___extension__] = ACTIONS(4356),
    [anon_sym___global__] = ACTIONS(4356),
    [anon_sym___attribute__] = ACTIONS(4356),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_RBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4358),
    [anon_sym_RBRACK] = ACTIONS(4358),
    [anon_sym_EQ] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4356),
    [anon_sym_volatile] = ACTIONS(4356),
    [anon_sym_restrict] = ACTIONS(4356),
    [anon_sym___restrict__] = ACTIONS(4356),
    [anon_sym__Atomic] = ACTIONS(4356),
    [anon_sym__Noreturn] = ACTIONS(4356),
    [anon_sym_noreturn] = ACTIONS(4356),
    [anon_sym__Nonnull] = ACTIONS(4356),
    [anon_sym_mutable] = ACTIONS(4356),
    [anon_sym_constinit] = ACTIONS(4356),
    [anon_sym_consteval] = ACTIONS(4356),
    [anon_sym___shared__] = ACTIONS(4356),
    [anon_sym___local__] = ACTIONS(4356),
    [anon_sym___constant__] = ACTIONS(4356),
    [anon_sym___managed__] = ACTIONS(4356),
    [anon_sym___grid_constant__] = ACTIONS(4356),
    [anon_sym_alignas] = ACTIONS(4356),
    [anon_sym__Alignas] = ACTIONS(4356),
    [anon_sym_COLON] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_STAR_EQ] = ACTIONS(4358),
    [anon_sym_SLASH_EQ] = ACTIONS(4358),
    [anon_sym_PERCENT_EQ] = ACTIONS(4358),
    [anon_sym_PLUS_EQ] = ACTIONS(4358),
    [anon_sym_DASH_EQ] = ACTIONS(4358),
    [anon_sym_LT_LT_EQ] = ACTIONS(4358),
    [anon_sym_GT_GT_EQ] = ACTIONS(4358),
    [anon_sym_AMP_EQ] = ACTIONS(4358),
    [anon_sym_CARET_EQ] = ACTIONS(4358),
    [anon_sym_PIPE_EQ] = ACTIONS(4358),
    [anon_sym_and_eq] = ACTIONS(4356),
    [anon_sym_or_eq] = ACTIONS(4356),
    [anon_sym_xor_eq] = ACTIONS(4356),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_bitor] = ACTIONS(4356),
    [anon_sym_xor] = ACTIONS(4356),
    [anon_sym_bitand] = ACTIONS(4356),
    [anon_sym_not_eq] = ACTIONS(4356),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4358),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4356),
    [anon_sym_decltype] = ACTIONS(4356),
    [anon_sym_final] = ACTIONS(4356),
    [anon_sym_override] = ACTIONS(4356),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
  },
  [STATE(1684)] = {
    [sym_function_definition] = STATE(1915),
    [sym_declaration] = STATE(1915),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5463),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1892),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(9083),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5265),
    [anon_sym_struct] = ACTIONS(5267),
    [anon_sym_union] = ACTIONS(5269),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1685)] = {
    [sym_identifier] = ACTIONS(4366),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_RPAREN] = ACTIONS(4368),
    [aux_sym_preproc_if_token2] = ACTIONS(4368),
    [aux_sym_preproc_else_token1] = ACTIONS(4368),
    [aux_sym_preproc_elif_token1] = ACTIONS(4366),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4368),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4366),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4366),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4366),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4368),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4366),
    [anon_sym_SEMI] = ACTIONS(4368),
    [anon_sym___extension__] = ACTIONS(4366),
    [anon_sym___global__] = ACTIONS(4366),
    [anon_sym___attribute__] = ACTIONS(4366),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_RBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4368),
    [anon_sym_RBRACK] = ACTIONS(4368),
    [anon_sym_EQ] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4366),
    [anon_sym_volatile] = ACTIONS(4366),
    [anon_sym_restrict] = ACTIONS(4366),
    [anon_sym___restrict__] = ACTIONS(4366),
    [anon_sym__Atomic] = ACTIONS(4366),
    [anon_sym__Noreturn] = ACTIONS(4366),
    [anon_sym_noreturn] = ACTIONS(4366),
    [anon_sym__Nonnull] = ACTIONS(4366),
    [anon_sym_mutable] = ACTIONS(4366),
    [anon_sym_constinit] = ACTIONS(4366),
    [anon_sym_consteval] = ACTIONS(4366),
    [anon_sym___shared__] = ACTIONS(4366),
    [anon_sym___local__] = ACTIONS(4366),
    [anon_sym___constant__] = ACTIONS(4366),
    [anon_sym___managed__] = ACTIONS(4366),
    [anon_sym___grid_constant__] = ACTIONS(4366),
    [anon_sym_alignas] = ACTIONS(4366),
    [anon_sym__Alignas] = ACTIONS(4366),
    [anon_sym_COLON] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_STAR_EQ] = ACTIONS(4368),
    [anon_sym_SLASH_EQ] = ACTIONS(4368),
    [anon_sym_PERCENT_EQ] = ACTIONS(4368),
    [anon_sym_PLUS_EQ] = ACTIONS(4368),
    [anon_sym_DASH_EQ] = ACTIONS(4368),
    [anon_sym_LT_LT_EQ] = ACTIONS(4368),
    [anon_sym_GT_GT_EQ] = ACTIONS(4368),
    [anon_sym_AMP_EQ] = ACTIONS(4368),
    [anon_sym_CARET_EQ] = ACTIONS(4368),
    [anon_sym_PIPE_EQ] = ACTIONS(4368),
    [anon_sym_and_eq] = ACTIONS(4366),
    [anon_sym_or_eq] = ACTIONS(4366),
    [anon_sym_xor_eq] = ACTIONS(4366),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_bitor] = ACTIONS(4366),
    [anon_sym_xor] = ACTIONS(4366),
    [anon_sym_bitand] = ACTIONS(4366),
    [anon_sym_not_eq] = ACTIONS(4366),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4366),
    [anon_sym_decltype] = ACTIONS(4366),
    [anon_sym_final] = ACTIONS(4366),
    [anon_sym_override] = ACTIONS(4366),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
  },
  [STATE(1686)] = {
    [sym_function_definition] = STATE(322),
    [sym_declaration] = STATE(322),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5444),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1890),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(8733),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5271),
    [anon_sym_struct] = ACTIONS(5273),
    [anon_sym_union] = ACTIONS(5275),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1687)] = {
    [sym_function_definition] = STATE(1978),
    [sym_declaration] = STATE(1978),
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5463),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_ms_call_modifier] = STATE(1892),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym__class_name] = STATE(9041),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2969),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2973),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5197),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(53),
    [anon_sym___clrcall] = ACTIONS(53),
    [anon_sym___stdcall] = ACTIONS(53),
    [anon_sym___fastcall] = ACTIONS(53),
    [anon_sym___thiscall] = ACTIONS(53),
    [anon_sym___vectorcall] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(5277),
    [anon_sym_struct] = ACTIONS(5279),
    [anon_sym_union] = ACTIONS(5281),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1688)] = {
    [sym_identifier] = ACTIONS(5283),
    [anon_sym_COMMA] = ACTIONS(5285),
    [anon_sym_RPAREN] = ACTIONS(5285),
    [anon_sym_LPAREN2] = ACTIONS(5285),
    [anon_sym_TILDE] = ACTIONS(5285),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_PIPE_PIPE] = ACTIONS(5285),
    [anon_sym_AMP_AMP] = ACTIONS(5285),
    [anon_sym_AMP] = ACTIONS(5283),
    [anon_sym_SEMI] = ACTIONS(5285),
    [anon_sym___extension__] = ACTIONS(5283),
    [anon_sym___device__] = ACTIONS(5283),
    [anon_sym___host__] = ACTIONS(5283),
    [anon_sym___global__] = ACTIONS(5283),
    [anon_sym___forceinline__] = ACTIONS(5283),
    [anon_sym___noinline__] = ACTIONS(5283),
    [anon_sym_virtual] = ACTIONS(5283),
    [anon_sym_extern] = ACTIONS(5283),
    [anon_sym___attribute__] = ACTIONS(5283),
    [anon_sym___attribute] = ACTIONS(5283),
    [anon_sym_COLON_COLON] = ACTIONS(5285),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5285),
    [anon_sym___declspec] = ACTIONS(5283),
    [anon_sym___based] = ACTIONS(5283),
    [anon_sym___cdecl] = ACTIONS(5283),
    [anon_sym___clrcall] = ACTIONS(5283),
    [anon_sym___stdcall] = ACTIONS(5283),
    [anon_sym___fastcall] = ACTIONS(5283),
    [anon_sym___thiscall] = ACTIONS(5283),
    [anon_sym___vectorcall] = ACTIONS(5283),
    [anon_sym_LBRACE] = ACTIONS(5285),
    [anon_sym_signed] = ACTIONS(5283),
    [anon_sym_unsigned] = ACTIONS(5283),
    [anon_sym_long] = ACTIONS(5283),
    [anon_sym_short] = ACTIONS(5283),
    [anon_sym_LBRACK] = ACTIONS(5283),
    [anon_sym_static] = ACTIONS(5283),
    [anon_sym_EQ] = ACTIONS(5285),
    [anon_sym_register] = ACTIONS(5283),
    [anon_sym_inline] = ACTIONS(5283),
    [anon_sym___inline] = ACTIONS(5283),
    [anon_sym___inline__] = ACTIONS(5283),
    [anon_sym___forceinline] = ACTIONS(5283),
    [anon_sym_thread_local] = ACTIONS(5283),
    [anon_sym___thread] = ACTIONS(5283),
    [anon_sym_const] = ACTIONS(5283),
    [anon_sym_constexpr] = ACTIONS(5283),
    [anon_sym_volatile] = ACTIONS(5283),
    [anon_sym_restrict] = ACTIONS(5283),
    [anon_sym___restrict__] = ACTIONS(5283),
    [anon_sym__Atomic] = ACTIONS(5283),
    [anon_sym__Noreturn] = ACTIONS(5283),
    [anon_sym_noreturn] = ACTIONS(5283),
    [anon_sym__Nonnull] = ACTIONS(5283),
    [anon_sym_mutable] = ACTIONS(5283),
    [anon_sym_constinit] = ACTIONS(5283),
    [anon_sym_consteval] = ACTIONS(5283),
    [anon_sym___shared__] = ACTIONS(5283),
    [anon_sym___local__] = ACTIONS(5283),
    [anon_sym___constant__] = ACTIONS(5283),
    [anon_sym___managed__] = ACTIONS(5283),
    [anon_sym___grid_constant__] = ACTIONS(5283),
    [anon_sym_alignas] = ACTIONS(5283),
    [anon_sym__Alignas] = ACTIONS(5283),
    [sym_primitive_type] = ACTIONS(5283),
    [anon_sym_enum] = ACTIONS(5283),
    [anon_sym_class] = ACTIONS(5283),
    [anon_sym_struct] = ACTIONS(5283),
    [anon_sym_union] = ACTIONS(5283),
    [anon_sym_or] = ACTIONS(5283),
    [anon_sym_and] = ACTIONS(5283),
    [anon_sym_asm] = ACTIONS(5283),
    [anon_sym___asm__] = ACTIONS(5283),
    [anon_sym___asm] = ACTIONS(5283),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5283),
    [anon_sym_decltype] = ACTIONS(5283),
    [anon_sym_final] = ACTIONS(5283),
    [anon_sym_override] = ACTIONS(5283),
    [anon_sym_explicit] = ACTIONS(5283),
    [anon_sym_typename] = ACTIONS(5283),
    [anon_sym_template] = ACTIONS(5283),
    [anon_sym_GT2] = ACTIONS(5285),
    [anon_sym_operator] = ACTIONS(5283),
    [anon_sym_try] = ACTIONS(5283),
    [anon_sym_friend] = ACTIONS(5283),
    [anon_sym_using] = ACTIONS(5283),
    [anon_sym_concept] = ACTIONS(5283),
    [anon_sym_requires] = ACTIONS(5283),
    [anon_sym___launch_bounds__] = ACTIONS(5283),
  },
  [STATE(1689)] = {
    [sym_identifier] = ACTIONS(5287),
    [anon_sym_COMMA] = ACTIONS(5289),
    [anon_sym_RPAREN] = ACTIONS(5289),
    [anon_sym_LPAREN2] = ACTIONS(5289),
    [anon_sym_TILDE] = ACTIONS(5289),
    [anon_sym_STAR] = ACTIONS(5289),
    [anon_sym_PIPE_PIPE] = ACTIONS(5289),
    [anon_sym_AMP_AMP] = ACTIONS(5289),
    [anon_sym_AMP] = ACTIONS(5287),
    [anon_sym_SEMI] = ACTIONS(5289),
    [anon_sym___extension__] = ACTIONS(5287),
    [anon_sym___device__] = ACTIONS(5287),
    [anon_sym___host__] = ACTIONS(5287),
    [anon_sym___global__] = ACTIONS(5287),
    [anon_sym___forceinline__] = ACTIONS(5287),
    [anon_sym___noinline__] = ACTIONS(5287),
    [anon_sym_virtual] = ACTIONS(5287),
    [anon_sym_extern] = ACTIONS(5287),
    [anon_sym___attribute__] = ACTIONS(5287),
    [anon_sym___attribute] = ACTIONS(5287),
    [anon_sym_COLON_COLON] = ACTIONS(5289),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5289),
    [anon_sym___declspec] = ACTIONS(5287),
    [anon_sym___based] = ACTIONS(5287),
    [anon_sym___cdecl] = ACTIONS(5287),
    [anon_sym___clrcall] = ACTIONS(5287),
    [anon_sym___stdcall] = ACTIONS(5287),
    [anon_sym___fastcall] = ACTIONS(5287),
    [anon_sym___thiscall] = ACTIONS(5287),
    [anon_sym___vectorcall] = ACTIONS(5287),
    [anon_sym_LBRACE] = ACTIONS(5289),
    [anon_sym_signed] = ACTIONS(5287),
    [anon_sym_unsigned] = ACTIONS(5287),
    [anon_sym_long] = ACTIONS(5287),
    [anon_sym_short] = ACTIONS(5287),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [anon_sym_static] = ACTIONS(5287),
    [anon_sym_EQ] = ACTIONS(5289),
    [anon_sym_register] = ACTIONS(5287),
    [anon_sym_inline] = ACTIONS(5287),
    [anon_sym___inline] = ACTIONS(5287),
    [anon_sym___inline__] = ACTIONS(5287),
    [anon_sym___forceinline] = ACTIONS(5287),
    [anon_sym_thread_local] = ACTIONS(5287),
    [anon_sym___thread] = ACTIONS(5287),
    [anon_sym_const] = ACTIONS(5287),
    [anon_sym_constexpr] = ACTIONS(5287),
    [anon_sym_volatile] = ACTIONS(5287),
    [anon_sym_restrict] = ACTIONS(5287),
    [anon_sym___restrict__] = ACTIONS(5287),
    [anon_sym__Atomic] = ACTIONS(5287),
    [anon_sym__Noreturn] = ACTIONS(5287),
    [anon_sym_noreturn] = ACTIONS(5287),
    [anon_sym__Nonnull] = ACTIONS(5287),
    [anon_sym_mutable] = ACTIONS(5287),
    [anon_sym_constinit] = ACTIONS(5287),
    [anon_sym_consteval] = ACTIONS(5287),
    [anon_sym___shared__] = ACTIONS(5287),
    [anon_sym___local__] = ACTIONS(5287),
    [anon_sym___constant__] = ACTIONS(5287),
    [anon_sym___managed__] = ACTIONS(5287),
    [anon_sym___grid_constant__] = ACTIONS(5287),
    [anon_sym_alignas] = ACTIONS(5287),
    [anon_sym__Alignas] = ACTIONS(5287),
    [sym_primitive_type] = ACTIONS(5287),
    [anon_sym_enum] = ACTIONS(5287),
    [anon_sym_class] = ACTIONS(5287),
    [anon_sym_struct] = ACTIONS(5287),
    [anon_sym_union] = ACTIONS(5287),
    [anon_sym_or] = ACTIONS(5287),
    [anon_sym_and] = ACTIONS(5287),
    [anon_sym_asm] = ACTIONS(5287),
    [anon_sym___asm__] = ACTIONS(5287),
    [anon_sym___asm] = ACTIONS(5287),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5287),
    [anon_sym_decltype] = ACTIONS(5287),
    [anon_sym_final] = ACTIONS(5287),
    [anon_sym_override] = ACTIONS(5287),
    [anon_sym_explicit] = ACTIONS(5287),
    [anon_sym_typename] = ACTIONS(5287),
    [anon_sym_template] = ACTIONS(5287),
    [anon_sym_GT2] = ACTIONS(5289),
    [anon_sym_operator] = ACTIONS(5287),
    [anon_sym_try] = ACTIONS(5287),
    [anon_sym_friend] = ACTIONS(5287),
    [anon_sym_using] = ACTIONS(5287),
    [anon_sym_concept] = ACTIONS(5287),
    [anon_sym_requires] = ACTIONS(5287),
    [anon_sym___launch_bounds__] = ACTIONS(5287),
  },
  [STATE(1690)] = {
    [sym_identifier] = ACTIONS(5291),
    [anon_sym_COMMA] = ACTIONS(5293),
    [anon_sym_RPAREN] = ACTIONS(5293),
    [anon_sym_LPAREN2] = ACTIONS(5293),
    [anon_sym_TILDE] = ACTIONS(5293),
    [anon_sym_STAR] = ACTIONS(5293),
    [anon_sym_PIPE_PIPE] = ACTIONS(5293),
    [anon_sym_AMP_AMP] = ACTIONS(5293),
    [anon_sym_AMP] = ACTIONS(5291),
    [anon_sym_SEMI] = ACTIONS(5293),
    [anon_sym___extension__] = ACTIONS(5291),
    [anon_sym___device__] = ACTIONS(5291),
    [anon_sym___host__] = ACTIONS(5291),
    [anon_sym___global__] = ACTIONS(5291),
    [anon_sym___forceinline__] = ACTIONS(5291),
    [anon_sym___noinline__] = ACTIONS(5291),
    [anon_sym_virtual] = ACTIONS(5291),
    [anon_sym_extern] = ACTIONS(5291),
    [anon_sym___attribute__] = ACTIONS(5291),
    [anon_sym___attribute] = ACTIONS(5291),
    [anon_sym_COLON_COLON] = ACTIONS(5293),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5293),
    [anon_sym___declspec] = ACTIONS(5291),
    [anon_sym___based] = ACTIONS(5291),
    [anon_sym___cdecl] = ACTIONS(5291),
    [anon_sym___clrcall] = ACTIONS(5291),
    [anon_sym___stdcall] = ACTIONS(5291),
    [anon_sym___fastcall] = ACTIONS(5291),
    [anon_sym___thiscall] = ACTIONS(5291),
    [anon_sym___vectorcall] = ACTIONS(5291),
    [anon_sym_LBRACE] = ACTIONS(5293),
    [anon_sym_signed] = ACTIONS(5291),
    [anon_sym_unsigned] = ACTIONS(5291),
    [anon_sym_long] = ACTIONS(5291),
    [anon_sym_short] = ACTIONS(5291),
    [anon_sym_LBRACK] = ACTIONS(5291),
    [anon_sym_static] = ACTIONS(5291),
    [anon_sym_EQ] = ACTIONS(5293),
    [anon_sym_register] = ACTIONS(5291),
    [anon_sym_inline] = ACTIONS(5291),
    [anon_sym___inline] = ACTIONS(5291),
    [anon_sym___inline__] = ACTIONS(5291),
    [anon_sym___forceinline] = ACTIONS(5291),
    [anon_sym_thread_local] = ACTIONS(5291),
    [anon_sym___thread] = ACTIONS(5291),
    [anon_sym_const] = ACTIONS(5291),
    [anon_sym_constexpr] = ACTIONS(5291),
    [anon_sym_volatile] = ACTIONS(5291),
    [anon_sym_restrict] = ACTIONS(5291),
    [anon_sym___restrict__] = ACTIONS(5291),
    [anon_sym__Atomic] = ACTIONS(5291),
    [anon_sym__Noreturn] = ACTIONS(5291),
    [anon_sym_noreturn] = ACTIONS(5291),
    [anon_sym__Nonnull] = ACTIONS(5291),
    [anon_sym_mutable] = ACTIONS(5291),
    [anon_sym_constinit] = ACTIONS(5291),
    [anon_sym_consteval] = ACTIONS(5291),
    [anon_sym___shared__] = ACTIONS(5291),
    [anon_sym___local__] = ACTIONS(5291),
    [anon_sym___constant__] = ACTIONS(5291),
    [anon_sym___managed__] = ACTIONS(5291),
    [anon_sym___grid_constant__] = ACTIONS(5291),
    [anon_sym_alignas] = ACTIONS(5291),
    [anon_sym__Alignas] = ACTIONS(5291),
    [sym_primitive_type] = ACTIONS(5291),
    [anon_sym_enum] = ACTIONS(5291),
    [anon_sym_class] = ACTIONS(5291),
    [anon_sym_struct] = ACTIONS(5291),
    [anon_sym_union] = ACTIONS(5291),
    [anon_sym_or] = ACTIONS(5291),
    [anon_sym_and] = ACTIONS(5291),
    [anon_sym_asm] = ACTIONS(5291),
    [anon_sym___asm__] = ACTIONS(5291),
    [anon_sym___asm] = ACTIONS(5291),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5291),
    [anon_sym_decltype] = ACTIONS(5291),
    [anon_sym_final] = ACTIONS(5291),
    [anon_sym_override] = ACTIONS(5291),
    [anon_sym_explicit] = ACTIONS(5291),
    [anon_sym_typename] = ACTIONS(5291),
    [anon_sym_template] = ACTIONS(5291),
    [anon_sym_GT2] = ACTIONS(5293),
    [anon_sym_operator] = ACTIONS(5291),
    [anon_sym_try] = ACTIONS(5291),
    [anon_sym_friend] = ACTIONS(5291),
    [anon_sym_using] = ACTIONS(5291),
    [anon_sym_concept] = ACTIONS(5291),
    [anon_sym_requires] = ACTIONS(5291),
    [anon_sym___launch_bounds__] = ACTIONS(5291),
  },
  [STATE(1691)] = {
    [sym_identifier] = ACTIONS(5287),
    [anon_sym_COMMA] = ACTIONS(5289),
    [anon_sym_RPAREN] = ACTIONS(5289),
    [anon_sym_LPAREN2] = ACTIONS(5289),
    [anon_sym_TILDE] = ACTIONS(5289),
    [anon_sym_STAR] = ACTIONS(5289),
    [anon_sym_PIPE_PIPE] = ACTIONS(5289),
    [anon_sym_AMP_AMP] = ACTIONS(5289),
    [anon_sym_AMP] = ACTIONS(5287),
    [anon_sym_SEMI] = ACTIONS(5289),
    [anon_sym___extension__] = ACTIONS(5287),
    [anon_sym___device__] = ACTIONS(5287),
    [anon_sym___host__] = ACTIONS(5287),
    [anon_sym___global__] = ACTIONS(5287),
    [anon_sym___forceinline__] = ACTIONS(5287),
    [anon_sym___noinline__] = ACTIONS(5287),
    [anon_sym_virtual] = ACTIONS(5287),
    [anon_sym_extern] = ACTIONS(5287),
    [anon_sym___attribute__] = ACTIONS(5287),
    [anon_sym___attribute] = ACTIONS(5287),
    [anon_sym_COLON_COLON] = ACTIONS(5289),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5289),
    [anon_sym___declspec] = ACTIONS(5287),
    [anon_sym___based] = ACTIONS(5287),
    [anon_sym___cdecl] = ACTIONS(5287),
    [anon_sym___clrcall] = ACTIONS(5287),
    [anon_sym___stdcall] = ACTIONS(5287),
    [anon_sym___fastcall] = ACTIONS(5287),
    [anon_sym___thiscall] = ACTIONS(5287),
    [anon_sym___vectorcall] = ACTIONS(5287),
    [anon_sym_LBRACE] = ACTIONS(5289),
    [anon_sym_signed] = ACTIONS(5287),
    [anon_sym_unsigned] = ACTIONS(5287),
    [anon_sym_long] = ACTIONS(5287),
    [anon_sym_short] = ACTIONS(5287),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [anon_sym_static] = ACTIONS(5287),
    [anon_sym_EQ] = ACTIONS(5289),
    [anon_sym_register] = ACTIONS(5287),
    [anon_sym_inline] = ACTIONS(5287),
    [anon_sym___inline] = ACTIONS(5287),
    [anon_sym___inline__] = ACTIONS(5287),
    [anon_sym___forceinline] = ACTIONS(5287),
    [anon_sym_thread_local] = ACTIONS(5287),
    [anon_sym___thread] = ACTIONS(5287),
    [anon_sym_const] = ACTIONS(5287),
    [anon_sym_constexpr] = ACTIONS(5287),
    [anon_sym_volatile] = ACTIONS(5287),
    [anon_sym_restrict] = ACTIONS(5287),
    [anon_sym___restrict__] = ACTIONS(5287),
    [anon_sym__Atomic] = ACTIONS(5287),
    [anon_sym__Noreturn] = ACTIONS(5287),
    [anon_sym_noreturn] = ACTIONS(5287),
    [anon_sym__Nonnull] = ACTIONS(5287),
    [anon_sym_mutable] = ACTIONS(5287),
    [anon_sym_constinit] = ACTIONS(5287),
    [anon_sym_consteval] = ACTIONS(5287),
    [anon_sym___shared__] = ACTIONS(5287),
    [anon_sym___local__] = ACTIONS(5287),
    [anon_sym___constant__] = ACTIONS(5287),
    [anon_sym___managed__] = ACTIONS(5287),
    [anon_sym___grid_constant__] = ACTIONS(5287),
    [anon_sym_alignas] = ACTIONS(5287),
    [anon_sym__Alignas] = ACTIONS(5287),
    [sym_primitive_type] = ACTIONS(5287),
    [anon_sym_enum] = ACTIONS(5287),
    [anon_sym_class] = ACTIONS(5287),
    [anon_sym_struct] = ACTIONS(5287),
    [anon_sym_union] = ACTIONS(5287),
    [anon_sym_or] = ACTIONS(5287),
    [anon_sym_and] = ACTIONS(5287),
    [anon_sym_asm] = ACTIONS(5287),
    [anon_sym___asm__] = ACTIONS(5287),
    [anon_sym___asm] = ACTIONS(5287),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5287),
    [anon_sym_decltype] = ACTIONS(5287),
    [anon_sym_final] = ACTIONS(5287),
    [anon_sym_override] = ACTIONS(5287),
    [anon_sym_explicit] = ACTIONS(5287),
    [anon_sym_typename] = ACTIONS(5287),
    [anon_sym_template] = ACTIONS(5287),
    [anon_sym_GT2] = ACTIONS(5289),
    [anon_sym_operator] = ACTIONS(5287),
    [anon_sym_try] = ACTIONS(5287),
    [anon_sym_friend] = ACTIONS(5287),
    [anon_sym_using] = ACTIONS(5287),
    [anon_sym_concept] = ACTIONS(5287),
    [anon_sym_requires] = ACTIONS(5287),
    [anon_sym___launch_bounds__] = ACTIONS(5287),
  },
  [STATE(1692)] = {
    [sym_identifier] = ACTIONS(5295),
    [anon_sym_COMMA] = ACTIONS(5297),
    [anon_sym_RPAREN] = ACTIONS(5297),
    [anon_sym_LPAREN2] = ACTIONS(5297),
    [anon_sym_TILDE] = ACTIONS(5297),
    [anon_sym_STAR] = ACTIONS(5297),
    [anon_sym_PIPE_PIPE] = ACTIONS(5297),
    [anon_sym_AMP_AMP] = ACTIONS(5297),
    [anon_sym_AMP] = ACTIONS(5295),
    [anon_sym_SEMI] = ACTIONS(5297),
    [anon_sym___extension__] = ACTIONS(5295),
    [anon_sym___device__] = ACTIONS(5295),
    [anon_sym___host__] = ACTIONS(5295),
    [anon_sym___global__] = ACTIONS(5295),
    [anon_sym___forceinline__] = ACTIONS(5295),
    [anon_sym___noinline__] = ACTIONS(5295),
    [anon_sym_virtual] = ACTIONS(5295),
    [anon_sym_extern] = ACTIONS(5295),
    [anon_sym___attribute__] = ACTIONS(5295),
    [anon_sym___attribute] = ACTIONS(5295),
    [anon_sym_COLON_COLON] = ACTIONS(5297),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5297),
    [anon_sym___declspec] = ACTIONS(5295),
    [anon_sym___based] = ACTIONS(5295),
    [anon_sym___cdecl] = ACTIONS(5295),
    [anon_sym___clrcall] = ACTIONS(5295),
    [anon_sym___stdcall] = ACTIONS(5295),
    [anon_sym___fastcall] = ACTIONS(5295),
    [anon_sym___thiscall] = ACTIONS(5295),
    [anon_sym___vectorcall] = ACTIONS(5295),
    [anon_sym_LBRACE] = ACTIONS(5297),
    [anon_sym_signed] = ACTIONS(5295),
    [anon_sym_unsigned] = ACTIONS(5295),
    [anon_sym_long] = ACTIONS(5295),
    [anon_sym_short] = ACTIONS(5295),
    [anon_sym_LBRACK] = ACTIONS(5295),
    [anon_sym_static] = ACTIONS(5295),
    [anon_sym_EQ] = ACTIONS(5297),
    [anon_sym_register] = ACTIONS(5295),
    [anon_sym_inline] = ACTIONS(5295),
    [anon_sym___inline] = ACTIONS(5295),
    [anon_sym___inline__] = ACTIONS(5295),
    [anon_sym___forceinline] = ACTIONS(5295),
    [anon_sym_thread_local] = ACTIONS(5295),
    [anon_sym___thread] = ACTIONS(5295),
    [anon_sym_const] = ACTIONS(5295),
    [anon_sym_constexpr] = ACTIONS(5295),
    [anon_sym_volatile] = ACTIONS(5295),
    [anon_sym_restrict] = ACTIONS(5295),
    [anon_sym___restrict__] = ACTIONS(5295),
    [anon_sym__Atomic] = ACTIONS(5295),
    [anon_sym__Noreturn] = ACTIONS(5295),
    [anon_sym_noreturn] = ACTIONS(5295),
    [anon_sym__Nonnull] = ACTIONS(5295),
    [anon_sym_mutable] = ACTIONS(5295),
    [anon_sym_constinit] = ACTIONS(5295),
    [anon_sym_consteval] = ACTIONS(5295),
    [anon_sym___shared__] = ACTIONS(5295),
    [anon_sym___local__] = ACTIONS(5295),
    [anon_sym___constant__] = ACTIONS(5295),
    [anon_sym___managed__] = ACTIONS(5295),
    [anon_sym___grid_constant__] = ACTIONS(5295),
    [anon_sym_alignas] = ACTIONS(5295),
    [anon_sym__Alignas] = ACTIONS(5295),
    [sym_primitive_type] = ACTIONS(5295),
    [anon_sym_enum] = ACTIONS(5295),
    [anon_sym_class] = ACTIONS(5295),
    [anon_sym_struct] = ACTIONS(5295),
    [anon_sym_union] = ACTIONS(5295),
    [anon_sym_or] = ACTIONS(5295),
    [anon_sym_and] = ACTIONS(5295),
    [anon_sym_asm] = ACTIONS(5295),
    [anon_sym___asm__] = ACTIONS(5295),
    [anon_sym___asm] = ACTIONS(5295),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5295),
    [anon_sym_decltype] = ACTIONS(5295),
    [anon_sym_final] = ACTIONS(5295),
    [anon_sym_override] = ACTIONS(5295),
    [anon_sym_explicit] = ACTIONS(5295),
    [anon_sym_typename] = ACTIONS(5295),
    [anon_sym_template] = ACTIONS(5295),
    [anon_sym_GT2] = ACTIONS(5297),
    [anon_sym_operator] = ACTIONS(5295),
    [anon_sym_try] = ACTIONS(5295),
    [anon_sym_friend] = ACTIONS(5295),
    [anon_sym_using] = ACTIONS(5295),
    [anon_sym_concept] = ACTIONS(5295),
    [anon_sym_requires] = ACTIONS(5295),
    [anon_sym___launch_bounds__] = ACTIONS(5295),
  },
  [STATE(1693)] = {
    [sym_identifier] = ACTIONS(5299),
    [anon_sym_COMMA] = ACTIONS(5301),
    [anon_sym_RPAREN] = ACTIONS(5301),
    [anon_sym_LPAREN2] = ACTIONS(5301),
    [anon_sym_TILDE] = ACTIONS(5301),
    [anon_sym_STAR] = ACTIONS(5301),
    [anon_sym_PIPE_PIPE] = ACTIONS(5301),
    [anon_sym_AMP_AMP] = ACTIONS(5301),
    [anon_sym_AMP] = ACTIONS(5299),
    [anon_sym_SEMI] = ACTIONS(5301),
    [anon_sym___extension__] = ACTIONS(5299),
    [anon_sym___device__] = ACTIONS(5299),
    [anon_sym___host__] = ACTIONS(5299),
    [anon_sym___global__] = ACTIONS(5299),
    [anon_sym___forceinline__] = ACTIONS(5299),
    [anon_sym___noinline__] = ACTIONS(5299),
    [anon_sym_virtual] = ACTIONS(5299),
    [anon_sym_extern] = ACTIONS(5299),
    [anon_sym___attribute__] = ACTIONS(5299),
    [anon_sym___attribute] = ACTIONS(5299),
    [anon_sym_COLON_COLON] = ACTIONS(5301),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5301),
    [anon_sym___declspec] = ACTIONS(5299),
    [anon_sym___based] = ACTIONS(5299),
    [anon_sym___cdecl] = ACTIONS(5299),
    [anon_sym___clrcall] = ACTIONS(5299),
    [anon_sym___stdcall] = ACTIONS(5299),
    [anon_sym___fastcall] = ACTIONS(5299),
    [anon_sym___thiscall] = ACTIONS(5299),
    [anon_sym___vectorcall] = ACTIONS(5299),
    [anon_sym_LBRACE] = ACTIONS(5301),
    [anon_sym_signed] = ACTIONS(5299),
    [anon_sym_unsigned] = ACTIONS(5299),
    [anon_sym_long] = ACTIONS(5299),
    [anon_sym_short] = ACTIONS(5299),
    [anon_sym_LBRACK] = ACTIONS(5299),
    [anon_sym_static] = ACTIONS(5299),
    [anon_sym_EQ] = ACTIONS(5301),
    [anon_sym_register] = ACTIONS(5299),
    [anon_sym_inline] = ACTIONS(5299),
    [anon_sym___inline] = ACTIONS(5299),
    [anon_sym___inline__] = ACTIONS(5299),
    [anon_sym___forceinline] = ACTIONS(5299),
    [anon_sym_thread_local] = ACTIONS(5299),
    [anon_sym___thread] = ACTIONS(5299),
    [anon_sym_const] = ACTIONS(5299),
    [anon_sym_constexpr] = ACTIONS(5299),
    [anon_sym_volatile] = ACTIONS(5299),
    [anon_sym_restrict] = ACTIONS(5299),
    [anon_sym___restrict__] = ACTIONS(5299),
    [anon_sym__Atomic] = ACTIONS(5299),
    [anon_sym__Noreturn] = ACTIONS(5299),
    [anon_sym_noreturn] = ACTIONS(5299),
    [anon_sym__Nonnull] = ACTIONS(5299),
    [anon_sym_mutable] = ACTIONS(5299),
    [anon_sym_constinit] = ACTIONS(5299),
    [anon_sym_consteval] = ACTIONS(5299),
    [anon_sym___shared__] = ACTIONS(5299),
    [anon_sym___local__] = ACTIONS(5299),
    [anon_sym___constant__] = ACTIONS(5299),
    [anon_sym___managed__] = ACTIONS(5299),
    [anon_sym___grid_constant__] = ACTIONS(5299),
    [anon_sym_alignas] = ACTIONS(5299),
    [anon_sym__Alignas] = ACTIONS(5299),
    [sym_primitive_type] = ACTIONS(5299),
    [anon_sym_enum] = ACTIONS(5299),
    [anon_sym_class] = ACTIONS(5299),
    [anon_sym_struct] = ACTIONS(5299),
    [anon_sym_union] = ACTIONS(5299),
    [anon_sym_or] = ACTIONS(5299),
    [anon_sym_and] = ACTIONS(5299),
    [anon_sym_asm] = ACTIONS(5299),
    [anon_sym___asm__] = ACTIONS(5299),
    [anon_sym___asm] = ACTIONS(5299),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5299),
    [anon_sym_decltype] = ACTIONS(5299),
    [anon_sym_final] = ACTIONS(5299),
    [anon_sym_override] = ACTIONS(5299),
    [anon_sym_explicit] = ACTIONS(5299),
    [anon_sym_typename] = ACTIONS(5299),
    [anon_sym_template] = ACTIONS(5299),
    [anon_sym_GT2] = ACTIONS(5301),
    [anon_sym_operator] = ACTIONS(5299),
    [anon_sym_try] = ACTIONS(5299),
    [anon_sym_friend] = ACTIONS(5299),
    [anon_sym_using] = ACTIONS(5299),
    [anon_sym_concept] = ACTIONS(5299),
    [anon_sym_requires] = ACTIONS(5299),
    [anon_sym___launch_bounds__] = ACTIONS(5299),
  },
  [STATE(1694)] = {
    [sym_identifier] = ACTIONS(5303),
    [anon_sym_COMMA] = ACTIONS(5305),
    [anon_sym_RPAREN] = ACTIONS(5305),
    [anon_sym_LPAREN2] = ACTIONS(5305),
    [anon_sym_TILDE] = ACTIONS(5305),
    [anon_sym_STAR] = ACTIONS(5305),
    [anon_sym_PIPE_PIPE] = ACTIONS(5305),
    [anon_sym_AMP_AMP] = ACTIONS(5305),
    [anon_sym_AMP] = ACTIONS(5303),
    [anon_sym_SEMI] = ACTIONS(5305),
    [anon_sym___extension__] = ACTIONS(5303),
    [anon_sym___device__] = ACTIONS(5303),
    [anon_sym___host__] = ACTIONS(5303),
    [anon_sym___global__] = ACTIONS(5303),
    [anon_sym___forceinline__] = ACTIONS(5303),
    [anon_sym___noinline__] = ACTIONS(5303),
    [anon_sym_virtual] = ACTIONS(5303),
    [anon_sym_extern] = ACTIONS(5303),
    [anon_sym___attribute__] = ACTIONS(5303),
    [anon_sym___attribute] = ACTIONS(5303),
    [anon_sym_COLON_COLON] = ACTIONS(5305),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5305),
    [anon_sym___declspec] = ACTIONS(5303),
    [anon_sym___based] = ACTIONS(5303),
    [anon_sym___cdecl] = ACTIONS(5303),
    [anon_sym___clrcall] = ACTIONS(5303),
    [anon_sym___stdcall] = ACTIONS(5303),
    [anon_sym___fastcall] = ACTIONS(5303),
    [anon_sym___thiscall] = ACTIONS(5303),
    [anon_sym___vectorcall] = ACTIONS(5303),
    [anon_sym_LBRACE] = ACTIONS(5305),
    [anon_sym_signed] = ACTIONS(5303),
    [anon_sym_unsigned] = ACTIONS(5303),
    [anon_sym_long] = ACTIONS(5303),
    [anon_sym_short] = ACTIONS(5303),
    [anon_sym_LBRACK] = ACTIONS(5303),
    [anon_sym_static] = ACTIONS(5303),
    [anon_sym_EQ] = ACTIONS(5305),
    [anon_sym_register] = ACTIONS(5303),
    [anon_sym_inline] = ACTIONS(5303),
    [anon_sym___inline] = ACTIONS(5303),
    [anon_sym___inline__] = ACTIONS(5303),
    [anon_sym___forceinline] = ACTIONS(5303),
    [anon_sym_thread_local] = ACTIONS(5303),
    [anon_sym___thread] = ACTIONS(5303),
    [anon_sym_const] = ACTIONS(5303),
    [anon_sym_constexpr] = ACTIONS(5303),
    [anon_sym_volatile] = ACTIONS(5303),
    [anon_sym_restrict] = ACTIONS(5303),
    [anon_sym___restrict__] = ACTIONS(5303),
    [anon_sym__Atomic] = ACTIONS(5303),
    [anon_sym__Noreturn] = ACTIONS(5303),
    [anon_sym_noreturn] = ACTIONS(5303),
    [anon_sym__Nonnull] = ACTIONS(5303),
    [anon_sym_mutable] = ACTIONS(5303),
    [anon_sym_constinit] = ACTIONS(5303),
    [anon_sym_consteval] = ACTIONS(5303),
    [anon_sym___shared__] = ACTIONS(5303),
    [anon_sym___local__] = ACTIONS(5303),
    [anon_sym___constant__] = ACTIONS(5303),
    [anon_sym___managed__] = ACTIONS(5303),
    [anon_sym___grid_constant__] = ACTIONS(5303),
    [anon_sym_alignas] = ACTIONS(5303),
    [anon_sym__Alignas] = ACTIONS(5303),
    [sym_primitive_type] = ACTIONS(5303),
    [anon_sym_enum] = ACTIONS(5303),
    [anon_sym_class] = ACTIONS(5303),
    [anon_sym_struct] = ACTIONS(5303),
    [anon_sym_union] = ACTIONS(5303),
    [anon_sym_or] = ACTIONS(5303),
    [anon_sym_and] = ACTIONS(5303),
    [anon_sym_asm] = ACTIONS(5303),
    [anon_sym___asm__] = ACTIONS(5303),
    [anon_sym___asm] = ACTIONS(5303),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5303),
    [anon_sym_decltype] = ACTIONS(5303),
    [anon_sym_final] = ACTIONS(5303),
    [anon_sym_override] = ACTIONS(5303),
    [anon_sym_explicit] = ACTIONS(5303),
    [anon_sym_typename] = ACTIONS(5303),
    [anon_sym_template] = ACTIONS(5303),
    [anon_sym_GT2] = ACTIONS(5305),
    [anon_sym_operator] = ACTIONS(5303),
    [anon_sym_try] = ACTIONS(5303),
    [anon_sym_friend] = ACTIONS(5303),
    [anon_sym_using] = ACTIONS(5303),
    [anon_sym_concept] = ACTIONS(5303),
    [anon_sym_requires] = ACTIONS(5303),
    [anon_sym___launch_bounds__] = ACTIONS(5303),
  },
  [STATE(1695)] = {
    [sym_identifier] = ACTIONS(5307),
    [anon_sym_COMMA] = ACTIONS(5309),
    [anon_sym_RPAREN] = ACTIONS(5309),
    [anon_sym_LPAREN2] = ACTIONS(5309),
    [anon_sym_TILDE] = ACTIONS(5309),
    [anon_sym_STAR] = ACTIONS(5309),
    [anon_sym_PIPE_PIPE] = ACTIONS(5309),
    [anon_sym_AMP_AMP] = ACTIONS(5309),
    [anon_sym_AMP] = ACTIONS(5307),
    [anon_sym_SEMI] = ACTIONS(5309),
    [anon_sym___extension__] = ACTIONS(5307),
    [anon_sym___device__] = ACTIONS(5307),
    [anon_sym___host__] = ACTIONS(5307),
    [anon_sym___global__] = ACTIONS(5307),
    [anon_sym___forceinline__] = ACTIONS(5307),
    [anon_sym___noinline__] = ACTIONS(5307),
    [anon_sym_virtual] = ACTIONS(5307),
    [anon_sym_extern] = ACTIONS(5307),
    [anon_sym___attribute__] = ACTIONS(5307),
    [anon_sym___attribute] = ACTIONS(5307),
    [anon_sym_COLON_COLON] = ACTIONS(5309),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5309),
    [anon_sym___declspec] = ACTIONS(5307),
    [anon_sym___based] = ACTIONS(5307),
    [anon_sym___cdecl] = ACTIONS(5307),
    [anon_sym___clrcall] = ACTIONS(5307),
    [anon_sym___stdcall] = ACTIONS(5307),
    [anon_sym___fastcall] = ACTIONS(5307),
    [anon_sym___thiscall] = ACTIONS(5307),
    [anon_sym___vectorcall] = ACTIONS(5307),
    [anon_sym_LBRACE] = ACTIONS(5309),
    [anon_sym_signed] = ACTIONS(5307),
    [anon_sym_unsigned] = ACTIONS(5307),
    [anon_sym_long] = ACTIONS(5307),
    [anon_sym_short] = ACTIONS(5307),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_static] = ACTIONS(5307),
    [anon_sym_EQ] = ACTIONS(5309),
    [anon_sym_register] = ACTIONS(5307),
    [anon_sym_inline] = ACTIONS(5307),
    [anon_sym___inline] = ACTIONS(5307),
    [anon_sym___inline__] = ACTIONS(5307),
    [anon_sym___forceinline] = ACTIONS(5307),
    [anon_sym_thread_local] = ACTIONS(5307),
    [anon_sym___thread] = ACTIONS(5307),
    [anon_sym_const] = ACTIONS(5307),
    [anon_sym_constexpr] = ACTIONS(5307),
    [anon_sym_volatile] = ACTIONS(5307),
    [anon_sym_restrict] = ACTIONS(5307),
    [anon_sym___restrict__] = ACTIONS(5307),
    [anon_sym__Atomic] = ACTIONS(5307),
    [anon_sym__Noreturn] = ACTIONS(5307),
    [anon_sym_noreturn] = ACTIONS(5307),
    [anon_sym__Nonnull] = ACTIONS(5307),
    [anon_sym_mutable] = ACTIONS(5307),
    [anon_sym_constinit] = ACTIONS(5307),
    [anon_sym_consteval] = ACTIONS(5307),
    [anon_sym___shared__] = ACTIONS(5307),
    [anon_sym___local__] = ACTIONS(5307),
    [anon_sym___constant__] = ACTIONS(5307),
    [anon_sym___managed__] = ACTIONS(5307),
    [anon_sym___grid_constant__] = ACTIONS(5307),
    [anon_sym_alignas] = ACTIONS(5307),
    [anon_sym__Alignas] = ACTIONS(5307),
    [sym_primitive_type] = ACTIONS(5307),
    [anon_sym_enum] = ACTIONS(5307),
    [anon_sym_class] = ACTIONS(5307),
    [anon_sym_struct] = ACTIONS(5307),
    [anon_sym_union] = ACTIONS(5307),
    [anon_sym_or] = ACTIONS(5307),
    [anon_sym_and] = ACTIONS(5307),
    [anon_sym_asm] = ACTIONS(5307),
    [anon_sym___asm__] = ACTIONS(5307),
    [anon_sym___asm] = ACTIONS(5307),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5307),
    [anon_sym_decltype] = ACTIONS(5307),
    [anon_sym_final] = ACTIONS(5307),
    [anon_sym_override] = ACTIONS(5307),
    [anon_sym_explicit] = ACTIONS(5307),
    [anon_sym_typename] = ACTIONS(5307),
    [anon_sym_template] = ACTIONS(5307),
    [anon_sym_GT2] = ACTIONS(5309),
    [anon_sym_operator] = ACTIONS(5307),
    [anon_sym_try] = ACTIONS(5307),
    [anon_sym_friend] = ACTIONS(5307),
    [anon_sym_using] = ACTIONS(5307),
    [anon_sym_concept] = ACTIONS(5307),
    [anon_sym_requires] = ACTIONS(5307),
    [anon_sym___launch_bounds__] = ACTIONS(5307),
  },
  [STATE(1696)] = {
    [sym_identifier] = ACTIONS(5311),
    [anon_sym_COMMA] = ACTIONS(5313),
    [anon_sym_RPAREN] = ACTIONS(5313),
    [anon_sym_LPAREN2] = ACTIONS(5313),
    [anon_sym_TILDE] = ACTIONS(5313),
    [anon_sym_STAR] = ACTIONS(5313),
    [anon_sym_PIPE_PIPE] = ACTIONS(5313),
    [anon_sym_AMP_AMP] = ACTIONS(5313),
    [anon_sym_AMP] = ACTIONS(5311),
    [anon_sym_SEMI] = ACTIONS(5313),
    [anon_sym___extension__] = ACTIONS(5311),
    [anon_sym___device__] = ACTIONS(5311),
    [anon_sym___host__] = ACTIONS(5311),
    [anon_sym___global__] = ACTIONS(5311),
    [anon_sym___forceinline__] = ACTIONS(5311),
    [anon_sym___noinline__] = ACTIONS(5311),
    [anon_sym_virtual] = ACTIONS(5311),
    [anon_sym_extern] = ACTIONS(5311),
    [anon_sym___attribute__] = ACTIONS(5311),
    [anon_sym___attribute] = ACTIONS(5311),
    [anon_sym_COLON_COLON] = ACTIONS(5313),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5313),
    [anon_sym___declspec] = ACTIONS(5311),
    [anon_sym___based] = ACTIONS(5311),
    [anon_sym___cdecl] = ACTIONS(5311),
    [anon_sym___clrcall] = ACTIONS(5311),
    [anon_sym___stdcall] = ACTIONS(5311),
    [anon_sym___fastcall] = ACTIONS(5311),
    [anon_sym___thiscall] = ACTIONS(5311),
    [anon_sym___vectorcall] = ACTIONS(5311),
    [anon_sym_LBRACE] = ACTIONS(5313),
    [anon_sym_signed] = ACTIONS(5311),
    [anon_sym_unsigned] = ACTIONS(5311),
    [anon_sym_long] = ACTIONS(5311),
    [anon_sym_short] = ACTIONS(5311),
    [anon_sym_LBRACK] = ACTIONS(5311),
    [anon_sym_static] = ACTIONS(5311),
    [anon_sym_EQ] = ACTIONS(5313),
    [anon_sym_register] = ACTIONS(5311),
    [anon_sym_inline] = ACTIONS(5311),
    [anon_sym___inline] = ACTIONS(5311),
    [anon_sym___inline__] = ACTIONS(5311),
    [anon_sym___forceinline] = ACTIONS(5311),
    [anon_sym_thread_local] = ACTIONS(5311),
    [anon_sym___thread] = ACTIONS(5311),
    [anon_sym_const] = ACTIONS(5311),
    [anon_sym_constexpr] = ACTIONS(5311),
    [anon_sym_volatile] = ACTIONS(5311),
    [anon_sym_restrict] = ACTIONS(5311),
    [anon_sym___restrict__] = ACTIONS(5311),
    [anon_sym__Atomic] = ACTIONS(5311),
    [anon_sym__Noreturn] = ACTIONS(5311),
    [anon_sym_noreturn] = ACTIONS(5311),
    [anon_sym__Nonnull] = ACTIONS(5311),
    [anon_sym_mutable] = ACTIONS(5311),
    [anon_sym_constinit] = ACTIONS(5311),
    [anon_sym_consteval] = ACTIONS(5311),
    [anon_sym___shared__] = ACTIONS(5311),
    [anon_sym___local__] = ACTIONS(5311),
    [anon_sym___constant__] = ACTIONS(5311),
    [anon_sym___managed__] = ACTIONS(5311),
    [anon_sym___grid_constant__] = ACTIONS(5311),
    [anon_sym_alignas] = ACTIONS(5311),
    [anon_sym__Alignas] = ACTIONS(5311),
    [sym_primitive_type] = ACTIONS(5311),
    [anon_sym_enum] = ACTIONS(5311),
    [anon_sym_class] = ACTIONS(5311),
    [anon_sym_struct] = ACTIONS(5311),
    [anon_sym_union] = ACTIONS(5311),
    [anon_sym_or] = ACTIONS(5311),
    [anon_sym_and] = ACTIONS(5311),
    [anon_sym_asm] = ACTIONS(5311),
    [anon_sym___asm__] = ACTIONS(5311),
    [anon_sym___asm] = ACTIONS(5311),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5311),
    [anon_sym_decltype] = ACTIONS(5311),
    [anon_sym_final] = ACTIONS(5311),
    [anon_sym_override] = ACTIONS(5311),
    [anon_sym_explicit] = ACTIONS(5311),
    [anon_sym_typename] = ACTIONS(5311),
    [anon_sym_template] = ACTIONS(5311),
    [anon_sym_GT2] = ACTIONS(5313),
    [anon_sym_operator] = ACTIONS(5311),
    [anon_sym_try] = ACTIONS(5311),
    [anon_sym_friend] = ACTIONS(5311),
    [anon_sym_using] = ACTIONS(5311),
    [anon_sym_concept] = ACTIONS(5311),
    [anon_sym_requires] = ACTIONS(5311),
    [anon_sym___launch_bounds__] = ACTIONS(5311),
  },
  [STATE(1697)] = {
    [sym_identifier] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5317),
    [anon_sym_RPAREN] = ACTIONS(5317),
    [anon_sym_LPAREN2] = ACTIONS(5317),
    [anon_sym_TILDE] = ACTIONS(5317),
    [anon_sym_STAR] = ACTIONS(5317),
    [anon_sym_PIPE_PIPE] = ACTIONS(5317),
    [anon_sym_AMP_AMP] = ACTIONS(5317),
    [anon_sym_AMP] = ACTIONS(5315),
    [anon_sym_SEMI] = ACTIONS(5317),
    [anon_sym___extension__] = ACTIONS(5315),
    [anon_sym___device__] = ACTIONS(5315),
    [anon_sym___host__] = ACTIONS(5315),
    [anon_sym___global__] = ACTIONS(5315),
    [anon_sym___forceinline__] = ACTIONS(5315),
    [anon_sym___noinline__] = ACTIONS(5315),
    [anon_sym_virtual] = ACTIONS(5315),
    [anon_sym_extern] = ACTIONS(5315),
    [anon_sym___attribute__] = ACTIONS(5315),
    [anon_sym___attribute] = ACTIONS(5315),
    [anon_sym_COLON_COLON] = ACTIONS(5317),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5317),
    [anon_sym___declspec] = ACTIONS(5315),
    [anon_sym___based] = ACTIONS(5315),
    [anon_sym___cdecl] = ACTIONS(5315),
    [anon_sym___clrcall] = ACTIONS(5315),
    [anon_sym___stdcall] = ACTIONS(5315),
    [anon_sym___fastcall] = ACTIONS(5315),
    [anon_sym___thiscall] = ACTIONS(5315),
    [anon_sym___vectorcall] = ACTIONS(5315),
    [anon_sym_LBRACE] = ACTIONS(5317),
    [anon_sym_signed] = ACTIONS(5315),
    [anon_sym_unsigned] = ACTIONS(5315),
    [anon_sym_long] = ACTIONS(5315),
    [anon_sym_short] = ACTIONS(5315),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_static] = ACTIONS(5315),
    [anon_sym_EQ] = ACTIONS(5317),
    [anon_sym_register] = ACTIONS(5315),
    [anon_sym_inline] = ACTIONS(5315),
    [anon_sym___inline] = ACTIONS(5315),
    [anon_sym___inline__] = ACTIONS(5315),
    [anon_sym___forceinline] = ACTIONS(5315),
    [anon_sym_thread_local] = ACTIONS(5315),
    [anon_sym___thread] = ACTIONS(5315),
    [anon_sym_const] = ACTIONS(5315),
    [anon_sym_constexpr] = ACTIONS(5315),
    [anon_sym_volatile] = ACTIONS(5315),
    [anon_sym_restrict] = ACTIONS(5315),
    [anon_sym___restrict__] = ACTIONS(5315),
    [anon_sym__Atomic] = ACTIONS(5315),
    [anon_sym__Noreturn] = ACTIONS(5315),
    [anon_sym_noreturn] = ACTIONS(5315),
    [anon_sym__Nonnull] = ACTIONS(5315),
    [anon_sym_mutable] = ACTIONS(5315),
    [anon_sym_constinit] = ACTIONS(5315),
    [anon_sym_consteval] = ACTIONS(5315),
    [anon_sym___shared__] = ACTIONS(5315),
    [anon_sym___local__] = ACTIONS(5315),
    [anon_sym___constant__] = ACTIONS(5315),
    [anon_sym___managed__] = ACTIONS(5315),
    [anon_sym___grid_constant__] = ACTIONS(5315),
    [anon_sym_alignas] = ACTIONS(5315),
    [anon_sym__Alignas] = ACTIONS(5315),
    [sym_primitive_type] = ACTIONS(5315),
    [anon_sym_enum] = ACTIONS(5315),
    [anon_sym_class] = ACTIONS(5315),
    [anon_sym_struct] = ACTIONS(5315),
    [anon_sym_union] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5315),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_asm] = ACTIONS(5315),
    [anon_sym___asm__] = ACTIONS(5315),
    [anon_sym___asm] = ACTIONS(5315),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5315),
    [anon_sym_decltype] = ACTIONS(5315),
    [anon_sym_final] = ACTIONS(5315),
    [anon_sym_override] = ACTIONS(5315),
    [anon_sym_explicit] = ACTIONS(5315),
    [anon_sym_typename] = ACTIONS(5315),
    [anon_sym_template] = ACTIONS(5315),
    [anon_sym_GT2] = ACTIONS(5317),
    [anon_sym_operator] = ACTIONS(5315),
    [anon_sym_try] = ACTIONS(5315),
    [anon_sym_friend] = ACTIONS(5315),
    [anon_sym_using] = ACTIONS(5315),
    [anon_sym_concept] = ACTIONS(5315),
    [anon_sym_requires] = ACTIONS(5315),
    [anon_sym___launch_bounds__] = ACTIONS(5315),
  },
  [STATE(1698)] = {
    [sym_type_qualifier] = STATE(1698),
    [sym_alignas_qualifier] = STATE(1719),
    [aux_sym__type_definition_type_repeat1] = STATE(1698),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_RPAREN] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_TILDE] = ACTIONS(5112),
    [anon_sym_STAR] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_SEMI] = ACTIONS(5112),
    [anon_sym___extension__] = ACTIONS(5319),
    [anon_sym___device__] = ACTIONS(5110),
    [anon_sym___host__] = ACTIONS(5110),
    [anon_sym___global__] = ACTIONS(5319),
    [anon_sym___forceinline__] = ACTIONS(5110),
    [anon_sym___noinline__] = ACTIONS(5110),
    [anon_sym_virtual] = ACTIONS(5110),
    [anon_sym_extern] = ACTIONS(5110),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_COLON_COLON] = ACTIONS(5112),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5112),
    [anon_sym___declspec] = ACTIONS(5110),
    [anon_sym___based] = ACTIONS(5110),
    [anon_sym___cdecl] = ACTIONS(5110),
    [anon_sym___clrcall] = ACTIONS(5110),
    [anon_sym___stdcall] = ACTIONS(5110),
    [anon_sym___fastcall] = ACTIONS(5110),
    [anon_sym___thiscall] = ACTIONS(5110),
    [anon_sym___vectorcall] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5110),
    [anon_sym_static] = ACTIONS(5110),
    [anon_sym_EQ] = ACTIONS(5112),
    [anon_sym_register] = ACTIONS(5110),
    [anon_sym_inline] = ACTIONS(5110),
    [anon_sym___inline] = ACTIONS(5110),
    [anon_sym___inline__] = ACTIONS(5110),
    [anon_sym___forceinline] = ACTIONS(5110),
    [anon_sym_thread_local] = ACTIONS(5110),
    [anon_sym___thread] = ACTIONS(5110),
    [anon_sym_const] = ACTIONS(5319),
    [anon_sym_constexpr] = ACTIONS(5319),
    [anon_sym_volatile] = ACTIONS(5319),
    [anon_sym_restrict] = ACTIONS(5319),
    [anon_sym___restrict__] = ACTIONS(5319),
    [anon_sym__Atomic] = ACTIONS(5319),
    [anon_sym__Noreturn] = ACTIONS(5319),
    [anon_sym_noreturn] = ACTIONS(5319),
    [anon_sym__Nonnull] = ACTIONS(5319),
    [anon_sym_mutable] = ACTIONS(5319),
    [anon_sym_constinit] = ACTIONS(5319),
    [anon_sym_consteval] = ACTIONS(5319),
    [anon_sym___shared__] = ACTIONS(5319),
    [anon_sym___local__] = ACTIONS(5319),
    [anon_sym___constant__] = ACTIONS(5319),
    [anon_sym___managed__] = ACTIONS(5319),
    [anon_sym___grid_constant__] = ACTIONS(5319),
    [anon_sym_alignas] = ACTIONS(5322),
    [anon_sym__Alignas] = ACTIONS(5322),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_enum] = ACTIONS(5110),
    [anon_sym_class] = ACTIONS(5110),
    [anon_sym_struct] = ACTIONS(5110),
    [anon_sym_union] = ACTIONS(5110),
    [anon_sym_asm] = ACTIONS(5110),
    [anon_sym___asm__] = ACTIONS(5110),
    [anon_sym___asm] = ACTIONS(5110),
    [anon_sym_DASH_GT] = ACTIONS(5112),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [anon_sym_final] = ACTIONS(5110),
    [anon_sym_override] = ACTIONS(5110),
    [anon_sym_typename] = ACTIONS(5110),
    [anon_sym_template] = ACTIONS(5110),
    [anon_sym_GT2] = ACTIONS(5112),
    [anon_sym_operator] = ACTIONS(5110),
    [anon_sym_try] = ACTIONS(5110),
    [anon_sym_noexcept] = ACTIONS(5110),
    [anon_sym_throw] = ACTIONS(5110),
    [anon_sym_requires] = ACTIONS(5110),
    [anon_sym___launch_bounds__] = ACTIONS(5110),
  },
  [STATE(1699)] = {
    [sym_identifier] = ACTIONS(5325),
    [anon_sym_COMMA] = ACTIONS(5327),
    [anon_sym_RPAREN] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5327),
    [anon_sym_TILDE] = ACTIONS(5327),
    [anon_sym_STAR] = ACTIONS(5327),
    [anon_sym_PIPE_PIPE] = ACTIONS(5327),
    [anon_sym_AMP_AMP] = ACTIONS(5327),
    [anon_sym_AMP] = ACTIONS(5325),
    [anon_sym_SEMI] = ACTIONS(5327),
    [anon_sym___extension__] = ACTIONS(5325),
    [anon_sym___device__] = ACTIONS(5325),
    [anon_sym___host__] = ACTIONS(5325),
    [anon_sym___global__] = ACTIONS(5325),
    [anon_sym___forceinline__] = ACTIONS(5325),
    [anon_sym___noinline__] = ACTIONS(5325),
    [anon_sym_virtual] = ACTIONS(5325),
    [anon_sym_extern] = ACTIONS(5325),
    [anon_sym___attribute__] = ACTIONS(5325),
    [anon_sym___attribute] = ACTIONS(5325),
    [anon_sym_COLON_COLON] = ACTIONS(5327),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5327),
    [anon_sym___declspec] = ACTIONS(5325),
    [anon_sym___based] = ACTIONS(5325),
    [anon_sym___cdecl] = ACTIONS(5325),
    [anon_sym___clrcall] = ACTIONS(5325),
    [anon_sym___stdcall] = ACTIONS(5325),
    [anon_sym___fastcall] = ACTIONS(5325),
    [anon_sym___thiscall] = ACTIONS(5325),
    [anon_sym___vectorcall] = ACTIONS(5325),
    [anon_sym_LBRACE] = ACTIONS(5327),
    [anon_sym_signed] = ACTIONS(5325),
    [anon_sym_unsigned] = ACTIONS(5325),
    [anon_sym_long] = ACTIONS(5325),
    [anon_sym_short] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(5325),
    [anon_sym_static] = ACTIONS(5325),
    [anon_sym_EQ] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5325),
    [anon_sym_inline] = ACTIONS(5325),
    [anon_sym___inline] = ACTIONS(5325),
    [anon_sym___inline__] = ACTIONS(5325),
    [anon_sym___forceinline] = ACTIONS(5325),
    [anon_sym_thread_local] = ACTIONS(5325),
    [anon_sym___thread] = ACTIONS(5325),
    [anon_sym_const] = ACTIONS(5325),
    [anon_sym_constexpr] = ACTIONS(5325),
    [anon_sym_volatile] = ACTIONS(5325),
    [anon_sym_restrict] = ACTIONS(5325),
    [anon_sym___restrict__] = ACTIONS(5325),
    [anon_sym__Atomic] = ACTIONS(5325),
    [anon_sym__Noreturn] = ACTIONS(5325),
    [anon_sym_noreturn] = ACTIONS(5325),
    [anon_sym__Nonnull] = ACTIONS(5325),
    [anon_sym_mutable] = ACTIONS(5325),
    [anon_sym_constinit] = ACTIONS(5325),
    [anon_sym_consteval] = ACTIONS(5325),
    [anon_sym___shared__] = ACTIONS(5325),
    [anon_sym___local__] = ACTIONS(5325),
    [anon_sym___constant__] = ACTIONS(5325),
    [anon_sym___managed__] = ACTIONS(5325),
    [anon_sym___grid_constant__] = ACTIONS(5325),
    [anon_sym_alignas] = ACTIONS(5325),
    [anon_sym__Alignas] = ACTIONS(5325),
    [sym_primitive_type] = ACTIONS(5325),
    [anon_sym_enum] = ACTIONS(5325),
    [anon_sym_class] = ACTIONS(5325),
    [anon_sym_struct] = ACTIONS(5325),
    [anon_sym_union] = ACTIONS(5325),
    [anon_sym_or] = ACTIONS(5325),
    [anon_sym_and] = ACTIONS(5325),
    [anon_sym_asm] = ACTIONS(5325),
    [anon_sym___asm__] = ACTIONS(5325),
    [anon_sym___asm] = ACTIONS(5325),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5325),
    [anon_sym_decltype] = ACTIONS(5325),
    [anon_sym_final] = ACTIONS(5325),
    [anon_sym_override] = ACTIONS(5325),
    [anon_sym_explicit] = ACTIONS(5325),
    [anon_sym_typename] = ACTIONS(5325),
    [anon_sym_template] = ACTIONS(5325),
    [anon_sym_GT2] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5325),
    [anon_sym_try] = ACTIONS(5325),
    [anon_sym_friend] = ACTIONS(5325),
    [anon_sym_using] = ACTIONS(5325),
    [anon_sym_concept] = ACTIONS(5325),
    [anon_sym_requires] = ACTIONS(5325),
    [anon_sym___launch_bounds__] = ACTIONS(5325),
  },
  [STATE(1700)] = {
    [sym_identifier] = ACTIONS(5329),
    [anon_sym_COMMA] = ACTIONS(5331),
    [anon_sym_RPAREN] = ACTIONS(5331),
    [anon_sym_LPAREN2] = ACTIONS(5331),
    [anon_sym_TILDE] = ACTIONS(5331),
    [anon_sym_STAR] = ACTIONS(5331),
    [anon_sym_PIPE_PIPE] = ACTIONS(5331),
    [anon_sym_AMP_AMP] = ACTIONS(5331),
    [anon_sym_AMP] = ACTIONS(5329),
    [anon_sym_SEMI] = ACTIONS(5331),
    [anon_sym___extension__] = ACTIONS(5329),
    [anon_sym___device__] = ACTIONS(5329),
    [anon_sym___host__] = ACTIONS(5329),
    [anon_sym___global__] = ACTIONS(5329),
    [anon_sym___forceinline__] = ACTIONS(5329),
    [anon_sym___noinline__] = ACTIONS(5329),
    [anon_sym_virtual] = ACTIONS(5329),
    [anon_sym_extern] = ACTIONS(5329),
    [anon_sym___attribute__] = ACTIONS(5329),
    [anon_sym___attribute] = ACTIONS(5329),
    [anon_sym_COLON_COLON] = ACTIONS(5331),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5331),
    [anon_sym___declspec] = ACTIONS(5329),
    [anon_sym___based] = ACTIONS(5329),
    [anon_sym___cdecl] = ACTIONS(5329),
    [anon_sym___clrcall] = ACTIONS(5329),
    [anon_sym___stdcall] = ACTIONS(5329),
    [anon_sym___fastcall] = ACTIONS(5329),
    [anon_sym___thiscall] = ACTIONS(5329),
    [anon_sym___vectorcall] = ACTIONS(5329),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_signed] = ACTIONS(5329),
    [anon_sym_unsigned] = ACTIONS(5329),
    [anon_sym_long] = ACTIONS(5329),
    [anon_sym_short] = ACTIONS(5329),
    [anon_sym_LBRACK] = ACTIONS(5329),
    [anon_sym_static] = ACTIONS(5329),
    [anon_sym_EQ] = ACTIONS(5331),
    [anon_sym_register] = ACTIONS(5329),
    [anon_sym_inline] = ACTIONS(5329),
    [anon_sym___inline] = ACTIONS(5329),
    [anon_sym___inline__] = ACTIONS(5329),
    [anon_sym___forceinline] = ACTIONS(5329),
    [anon_sym_thread_local] = ACTIONS(5329),
    [anon_sym___thread] = ACTIONS(5329),
    [anon_sym_const] = ACTIONS(5329),
    [anon_sym_constexpr] = ACTIONS(5329),
    [anon_sym_volatile] = ACTIONS(5329),
    [anon_sym_restrict] = ACTIONS(5329),
    [anon_sym___restrict__] = ACTIONS(5329),
    [anon_sym__Atomic] = ACTIONS(5329),
    [anon_sym__Noreturn] = ACTIONS(5329),
    [anon_sym_noreturn] = ACTIONS(5329),
    [anon_sym__Nonnull] = ACTIONS(5329),
    [anon_sym_mutable] = ACTIONS(5329),
    [anon_sym_constinit] = ACTIONS(5329),
    [anon_sym_consteval] = ACTIONS(5329),
    [anon_sym___shared__] = ACTIONS(5329),
    [anon_sym___local__] = ACTIONS(5329),
    [anon_sym___constant__] = ACTIONS(5329),
    [anon_sym___managed__] = ACTIONS(5329),
    [anon_sym___grid_constant__] = ACTIONS(5329),
    [anon_sym_alignas] = ACTIONS(5329),
    [anon_sym__Alignas] = ACTIONS(5329),
    [sym_primitive_type] = ACTIONS(5329),
    [anon_sym_enum] = ACTIONS(5329),
    [anon_sym_class] = ACTIONS(5329),
    [anon_sym_struct] = ACTIONS(5329),
    [anon_sym_union] = ACTIONS(5329),
    [anon_sym_or] = ACTIONS(5329),
    [anon_sym_and] = ACTIONS(5329),
    [anon_sym_asm] = ACTIONS(5329),
    [anon_sym___asm__] = ACTIONS(5329),
    [anon_sym___asm] = ACTIONS(5329),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5329),
    [anon_sym_decltype] = ACTIONS(5329),
    [anon_sym_final] = ACTIONS(5329),
    [anon_sym_override] = ACTIONS(5329),
    [anon_sym_explicit] = ACTIONS(5329),
    [anon_sym_typename] = ACTIONS(5329),
    [anon_sym_template] = ACTIONS(5329),
    [anon_sym_GT2] = ACTIONS(5331),
    [anon_sym_operator] = ACTIONS(5329),
    [anon_sym_try] = ACTIONS(5329),
    [anon_sym_friend] = ACTIONS(5329),
    [anon_sym_using] = ACTIONS(5329),
    [anon_sym_concept] = ACTIONS(5329),
    [anon_sym_requires] = ACTIONS(5329),
    [anon_sym___launch_bounds__] = ACTIONS(5329),
  },
  [STATE(1701)] = {
    [sym_identifier] = ACTIONS(5287),
    [anon_sym_COMMA] = ACTIONS(5289),
    [anon_sym_RPAREN] = ACTIONS(5289),
    [anon_sym_LPAREN2] = ACTIONS(5289),
    [anon_sym_TILDE] = ACTIONS(5289),
    [anon_sym_STAR] = ACTIONS(5289),
    [anon_sym_PIPE_PIPE] = ACTIONS(5289),
    [anon_sym_AMP_AMP] = ACTIONS(5289),
    [anon_sym_AMP] = ACTIONS(5287),
    [anon_sym_SEMI] = ACTIONS(5289),
    [anon_sym___extension__] = ACTIONS(5287),
    [anon_sym___device__] = ACTIONS(5287),
    [anon_sym___host__] = ACTIONS(5287),
    [anon_sym___global__] = ACTIONS(5287),
    [anon_sym___forceinline__] = ACTIONS(5287),
    [anon_sym___noinline__] = ACTIONS(5287),
    [anon_sym_virtual] = ACTIONS(5287),
    [anon_sym_extern] = ACTIONS(5287),
    [anon_sym___attribute__] = ACTIONS(5287),
    [anon_sym___attribute] = ACTIONS(5287),
    [anon_sym_COLON_COLON] = ACTIONS(5289),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5289),
    [anon_sym___declspec] = ACTIONS(5287),
    [anon_sym___based] = ACTIONS(5287),
    [anon_sym___cdecl] = ACTIONS(5287),
    [anon_sym___clrcall] = ACTIONS(5287),
    [anon_sym___stdcall] = ACTIONS(5287),
    [anon_sym___fastcall] = ACTIONS(5287),
    [anon_sym___thiscall] = ACTIONS(5287),
    [anon_sym___vectorcall] = ACTIONS(5287),
    [anon_sym_LBRACE] = ACTIONS(5289),
    [anon_sym_signed] = ACTIONS(5287),
    [anon_sym_unsigned] = ACTIONS(5287),
    [anon_sym_long] = ACTIONS(5287),
    [anon_sym_short] = ACTIONS(5287),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [anon_sym_static] = ACTIONS(5287),
    [anon_sym_EQ] = ACTIONS(5289),
    [anon_sym_register] = ACTIONS(5287),
    [anon_sym_inline] = ACTIONS(5287),
    [anon_sym___inline] = ACTIONS(5287),
    [anon_sym___inline__] = ACTIONS(5287),
    [anon_sym___forceinline] = ACTIONS(5287),
    [anon_sym_thread_local] = ACTIONS(5287),
    [anon_sym___thread] = ACTIONS(5287),
    [anon_sym_const] = ACTIONS(5287),
    [anon_sym_constexpr] = ACTIONS(5287),
    [anon_sym_volatile] = ACTIONS(5287),
    [anon_sym_restrict] = ACTIONS(5287),
    [anon_sym___restrict__] = ACTIONS(5287),
    [anon_sym__Atomic] = ACTIONS(5287),
    [anon_sym__Noreturn] = ACTIONS(5287),
    [anon_sym_noreturn] = ACTIONS(5287),
    [anon_sym__Nonnull] = ACTIONS(5287),
    [anon_sym_mutable] = ACTIONS(5287),
    [anon_sym_constinit] = ACTIONS(5287),
    [anon_sym_consteval] = ACTIONS(5287),
    [anon_sym___shared__] = ACTIONS(5287),
    [anon_sym___local__] = ACTIONS(5287),
    [anon_sym___constant__] = ACTIONS(5287),
    [anon_sym___managed__] = ACTIONS(5287),
    [anon_sym___grid_constant__] = ACTIONS(5287),
    [anon_sym_alignas] = ACTIONS(5287),
    [anon_sym__Alignas] = ACTIONS(5287),
    [sym_primitive_type] = ACTIONS(5287),
    [anon_sym_enum] = ACTIONS(5287),
    [anon_sym_class] = ACTIONS(5287),
    [anon_sym_struct] = ACTIONS(5287),
    [anon_sym_union] = ACTIONS(5287),
    [anon_sym_or] = ACTIONS(5287),
    [anon_sym_and] = ACTIONS(5287),
    [anon_sym_asm] = ACTIONS(5287),
    [anon_sym___asm__] = ACTIONS(5287),
    [anon_sym___asm] = ACTIONS(5287),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5287),
    [anon_sym_decltype] = ACTIONS(5287),
    [anon_sym_final] = ACTIONS(5287),
    [anon_sym_override] = ACTIONS(5287),
    [anon_sym_explicit] = ACTIONS(5287),
    [anon_sym_typename] = ACTIONS(5287),
    [anon_sym_template] = ACTIONS(5287),
    [anon_sym_GT2] = ACTIONS(5289),
    [anon_sym_operator] = ACTIONS(5287),
    [anon_sym_try] = ACTIONS(5287),
    [anon_sym_friend] = ACTIONS(5287),
    [anon_sym_using] = ACTIONS(5287),
    [anon_sym_concept] = ACTIONS(5287),
    [anon_sym_requires] = ACTIONS(5287),
    [anon_sym___launch_bounds__] = ACTIONS(5287),
  },
  [STATE(1702)] = {
    [sym_identifier] = ACTIONS(5333),
    [anon_sym_COMMA] = ACTIONS(5335),
    [anon_sym_RPAREN] = ACTIONS(5335),
    [anon_sym_LPAREN2] = ACTIONS(5335),
    [anon_sym_TILDE] = ACTIONS(5335),
    [anon_sym_STAR] = ACTIONS(5335),
    [anon_sym_PIPE_PIPE] = ACTIONS(5335),
    [anon_sym_AMP_AMP] = ACTIONS(5335),
    [anon_sym_AMP] = ACTIONS(5333),
    [anon_sym_SEMI] = ACTIONS(5335),
    [anon_sym___extension__] = ACTIONS(5333),
    [anon_sym___device__] = ACTIONS(5333),
    [anon_sym___host__] = ACTIONS(5333),
    [anon_sym___global__] = ACTIONS(5333),
    [anon_sym___forceinline__] = ACTIONS(5333),
    [anon_sym___noinline__] = ACTIONS(5333),
    [anon_sym_virtual] = ACTIONS(5333),
    [anon_sym_extern] = ACTIONS(5333),
    [anon_sym___attribute__] = ACTIONS(5333),
    [anon_sym___attribute] = ACTIONS(5333),
    [anon_sym_COLON_COLON] = ACTIONS(5335),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5335),
    [anon_sym___declspec] = ACTIONS(5333),
    [anon_sym___based] = ACTIONS(5333),
    [anon_sym___cdecl] = ACTIONS(5333),
    [anon_sym___clrcall] = ACTIONS(5333),
    [anon_sym___stdcall] = ACTIONS(5333),
    [anon_sym___fastcall] = ACTIONS(5333),
    [anon_sym___thiscall] = ACTIONS(5333),
    [anon_sym___vectorcall] = ACTIONS(5333),
    [anon_sym_LBRACE] = ACTIONS(5335),
    [anon_sym_signed] = ACTIONS(5333),
    [anon_sym_unsigned] = ACTIONS(5333),
    [anon_sym_long] = ACTIONS(5333),
    [anon_sym_short] = ACTIONS(5333),
    [anon_sym_LBRACK] = ACTIONS(5333),
    [anon_sym_static] = ACTIONS(5333),
    [anon_sym_EQ] = ACTIONS(5335),
    [anon_sym_register] = ACTIONS(5333),
    [anon_sym_inline] = ACTIONS(5333),
    [anon_sym___inline] = ACTIONS(5333),
    [anon_sym___inline__] = ACTIONS(5333),
    [anon_sym___forceinline] = ACTIONS(5333),
    [anon_sym_thread_local] = ACTIONS(5333),
    [anon_sym___thread] = ACTIONS(5333),
    [anon_sym_const] = ACTIONS(5333),
    [anon_sym_constexpr] = ACTIONS(5333),
    [anon_sym_volatile] = ACTIONS(5333),
    [anon_sym_restrict] = ACTIONS(5333),
    [anon_sym___restrict__] = ACTIONS(5333),
    [anon_sym__Atomic] = ACTIONS(5333),
    [anon_sym__Noreturn] = ACTIONS(5333),
    [anon_sym_noreturn] = ACTIONS(5333),
    [anon_sym__Nonnull] = ACTIONS(5333),
    [anon_sym_mutable] = ACTIONS(5333),
    [anon_sym_constinit] = ACTIONS(5333),
    [anon_sym_consteval] = ACTIONS(5333),
    [anon_sym___shared__] = ACTIONS(5333),
    [anon_sym___local__] = ACTIONS(5333),
    [anon_sym___constant__] = ACTIONS(5333),
    [anon_sym___managed__] = ACTIONS(5333),
    [anon_sym___grid_constant__] = ACTIONS(5333),
    [anon_sym_alignas] = ACTIONS(5333),
    [anon_sym__Alignas] = ACTIONS(5333),
    [sym_primitive_type] = ACTIONS(5333),
    [anon_sym_enum] = ACTIONS(5333),
    [anon_sym_class] = ACTIONS(5333),
    [anon_sym_struct] = ACTIONS(5333),
    [anon_sym_union] = ACTIONS(5333),
    [anon_sym_or] = ACTIONS(5333),
    [anon_sym_and] = ACTIONS(5333),
    [anon_sym_asm] = ACTIONS(5333),
    [anon_sym___asm__] = ACTIONS(5333),
    [anon_sym___asm] = ACTIONS(5333),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5333),
    [anon_sym_decltype] = ACTIONS(5333),
    [anon_sym_final] = ACTIONS(5333),
    [anon_sym_override] = ACTIONS(5333),
    [anon_sym_explicit] = ACTIONS(5333),
    [anon_sym_typename] = ACTIONS(5333),
    [anon_sym_template] = ACTIONS(5333),
    [anon_sym_GT2] = ACTIONS(5335),
    [anon_sym_operator] = ACTIONS(5333),
    [anon_sym_try] = ACTIONS(5333),
    [anon_sym_friend] = ACTIONS(5333),
    [anon_sym_using] = ACTIONS(5333),
    [anon_sym_concept] = ACTIONS(5333),
    [anon_sym_requires] = ACTIONS(5333),
    [anon_sym___launch_bounds__] = ACTIONS(5333),
  },
  [STATE(1703)] = {
    [sym_identifier] = ACTIONS(5337),
    [anon_sym_COMMA] = ACTIONS(5339),
    [anon_sym_RPAREN] = ACTIONS(5339),
    [anon_sym_LPAREN2] = ACTIONS(5339),
    [anon_sym_TILDE] = ACTIONS(5339),
    [anon_sym_STAR] = ACTIONS(5339),
    [anon_sym_PIPE_PIPE] = ACTIONS(5339),
    [anon_sym_AMP_AMP] = ACTIONS(5339),
    [anon_sym_AMP] = ACTIONS(5337),
    [anon_sym_SEMI] = ACTIONS(5339),
    [anon_sym___extension__] = ACTIONS(5337),
    [anon_sym___device__] = ACTIONS(5337),
    [anon_sym___host__] = ACTIONS(5337),
    [anon_sym___global__] = ACTIONS(5337),
    [anon_sym___forceinline__] = ACTIONS(5337),
    [anon_sym___noinline__] = ACTIONS(5337),
    [anon_sym_virtual] = ACTIONS(5337),
    [anon_sym_extern] = ACTIONS(5337),
    [anon_sym___attribute__] = ACTIONS(5337),
    [anon_sym___attribute] = ACTIONS(5337),
    [anon_sym_COLON_COLON] = ACTIONS(5339),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5339),
    [anon_sym___declspec] = ACTIONS(5337),
    [anon_sym___based] = ACTIONS(5337),
    [anon_sym___cdecl] = ACTIONS(5337),
    [anon_sym___clrcall] = ACTIONS(5337),
    [anon_sym___stdcall] = ACTIONS(5337),
    [anon_sym___fastcall] = ACTIONS(5337),
    [anon_sym___thiscall] = ACTIONS(5337),
    [anon_sym___vectorcall] = ACTIONS(5337),
    [anon_sym_LBRACE] = ACTIONS(5339),
    [anon_sym_signed] = ACTIONS(5337),
    [anon_sym_unsigned] = ACTIONS(5337),
    [anon_sym_long] = ACTIONS(5337),
    [anon_sym_short] = ACTIONS(5337),
    [anon_sym_LBRACK] = ACTIONS(5337),
    [anon_sym_static] = ACTIONS(5337),
    [anon_sym_EQ] = ACTIONS(5339),
    [anon_sym_register] = ACTIONS(5337),
    [anon_sym_inline] = ACTIONS(5337),
    [anon_sym___inline] = ACTIONS(5337),
    [anon_sym___inline__] = ACTIONS(5337),
    [anon_sym___forceinline] = ACTIONS(5337),
    [anon_sym_thread_local] = ACTIONS(5337),
    [anon_sym___thread] = ACTIONS(5337),
    [anon_sym_const] = ACTIONS(5337),
    [anon_sym_constexpr] = ACTIONS(5337),
    [anon_sym_volatile] = ACTIONS(5337),
    [anon_sym_restrict] = ACTIONS(5337),
    [anon_sym___restrict__] = ACTIONS(5337),
    [anon_sym__Atomic] = ACTIONS(5337),
    [anon_sym__Noreturn] = ACTIONS(5337),
    [anon_sym_noreturn] = ACTIONS(5337),
    [anon_sym__Nonnull] = ACTIONS(5337),
    [anon_sym_mutable] = ACTIONS(5337),
    [anon_sym_constinit] = ACTIONS(5337),
    [anon_sym_consteval] = ACTIONS(5337),
    [anon_sym___shared__] = ACTIONS(5337),
    [anon_sym___local__] = ACTIONS(5337),
    [anon_sym___constant__] = ACTIONS(5337),
    [anon_sym___managed__] = ACTIONS(5337),
    [anon_sym___grid_constant__] = ACTIONS(5337),
    [anon_sym_alignas] = ACTIONS(5337),
    [anon_sym__Alignas] = ACTIONS(5337),
    [sym_primitive_type] = ACTIONS(5337),
    [anon_sym_enum] = ACTIONS(5337),
    [anon_sym_class] = ACTIONS(5337),
    [anon_sym_struct] = ACTIONS(5337),
    [anon_sym_union] = ACTIONS(5337),
    [anon_sym_or] = ACTIONS(5337),
    [anon_sym_and] = ACTIONS(5337),
    [anon_sym_asm] = ACTIONS(5337),
    [anon_sym___asm__] = ACTIONS(5337),
    [anon_sym___asm] = ACTIONS(5337),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5337),
    [anon_sym_decltype] = ACTIONS(5337),
    [anon_sym_final] = ACTIONS(5337),
    [anon_sym_override] = ACTIONS(5337),
    [anon_sym_explicit] = ACTIONS(5337),
    [anon_sym_typename] = ACTIONS(5337),
    [anon_sym_template] = ACTIONS(5337),
    [anon_sym_GT2] = ACTIONS(5339),
    [anon_sym_operator] = ACTIONS(5337),
    [anon_sym_try] = ACTIONS(5337),
    [anon_sym_friend] = ACTIONS(5337),
    [anon_sym_using] = ACTIONS(5337),
    [anon_sym_concept] = ACTIONS(5337),
    [anon_sym_requires] = ACTIONS(5337),
    [anon_sym___launch_bounds__] = ACTIONS(5337),
  },
  [STATE(1704)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4525),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7846),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_type_parameter_declaration] = STATE(7846),
    [sym_variadic_type_parameter_declaration] = STATE(7846),
    [sym_optional_type_parameter_declaration] = STATE(7846),
    [sym_template_template_parameter_declaration] = STATE(7846),
    [sym_optional_parameter_declaration] = STATE(7846),
    [sym_variadic_parameter_declaration] = STATE(7846),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(5341),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(5343),
    [anon_sym_template] = ACTIONS(5345),
    [anon_sym_GT2] = ACTIONS(5347),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1705)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4525),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(8080),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_type_parameter_declaration] = STATE(8080),
    [sym_variadic_type_parameter_declaration] = STATE(8080),
    [sym_optional_type_parameter_declaration] = STATE(8080),
    [sym_template_template_parameter_declaration] = STATE(8080),
    [sym_optional_parameter_declaration] = STATE(8080),
    [sym_variadic_parameter_declaration] = STATE(8080),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(5341),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(5343),
    [anon_sym_template] = ACTIONS(5345),
    [anon_sym_GT2] = ACTIONS(5349),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1706)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [sym_identifier] = ACTIONS(5351),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [aux_sym_preproc_if_token2] = ACTIONS(5354),
    [aux_sym_preproc_else_token1] = ACTIONS(5354),
    [aux_sym_preproc_elif_token1] = ACTIONS(5351),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5354),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5351),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5351),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5351),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5351),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5137),
    [anon_sym_unsigned] = ACTIONS(5137),
    [anon_sym_long] = ACTIONS(5137),
    [anon_sym_short] = ACTIONS(5137),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_EQ] = ACTIONS(5351),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_STAR_EQ] = ACTIONS(5354),
    [anon_sym_SLASH_EQ] = ACTIONS(5354),
    [anon_sym_PERCENT_EQ] = ACTIONS(5354),
    [anon_sym_PLUS_EQ] = ACTIONS(5354),
    [anon_sym_DASH_EQ] = ACTIONS(5354),
    [anon_sym_LT_LT_EQ] = ACTIONS(5354),
    [anon_sym_GT_GT_EQ] = ACTIONS(5354),
    [anon_sym_AMP_EQ] = ACTIONS(5354),
    [anon_sym_CARET_EQ] = ACTIONS(5354),
    [anon_sym_PIPE_EQ] = ACTIONS(5354),
    [anon_sym_and_eq] = ACTIONS(5351),
    [anon_sym_or_eq] = ACTIONS(5351),
    [anon_sym_xor_eq] = ACTIONS(5351),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5354),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
  },
  [STATE(1707)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4555),
    [anon_sym_COMMA] = ACTIONS(4555),
    [anon_sym_RPAREN] = ACTIONS(4555),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4557),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4555),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4555),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4555),
    [anon_sym_SEMI] = ACTIONS(4555),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4560),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_RBRACE] = ACTIONS(4555),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_operator] = ACTIONS(4553),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(1708)] = {
    [sym_type_qualifier] = STATE(1715),
    [sym_alignas_qualifier] = STATE(1737),
    [aux_sym__type_definition_type_repeat1] = STATE(1715),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2855),
    [sym_identifier] = ACTIONS(5357),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_RPAREN] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5175),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5175),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5175),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5175),
    [anon_sym___extension__] = ACTIONS(5359),
    [anon_sym___global__] = ACTIONS(5359),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5361),
    [anon_sym_unsigned] = ACTIONS(5361),
    [anon_sym_long] = ACTIONS(5361),
    [anon_sym_short] = ACTIONS(5361),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_EQ] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5359),
    [anon_sym_constexpr] = ACTIONS(5359),
    [anon_sym_volatile] = ACTIONS(5359),
    [anon_sym_restrict] = ACTIONS(5359),
    [anon_sym___restrict__] = ACTIONS(5359),
    [anon_sym__Atomic] = ACTIONS(5359),
    [anon_sym__Noreturn] = ACTIONS(5359),
    [anon_sym_noreturn] = ACTIONS(5359),
    [anon_sym__Nonnull] = ACTIONS(5359),
    [anon_sym_mutable] = ACTIONS(5359),
    [anon_sym_constinit] = ACTIONS(5359),
    [anon_sym_consteval] = ACTIONS(5359),
    [anon_sym___shared__] = ACTIONS(5359),
    [anon_sym___local__] = ACTIONS(5359),
    [anon_sym___constant__] = ACTIONS(5359),
    [anon_sym___managed__] = ACTIONS(5359),
    [anon_sym___grid_constant__] = ACTIONS(5359),
    [anon_sym_alignas] = ACTIONS(5363),
    [anon_sym__Alignas] = ACTIONS(5363),
    [sym_primitive_type] = ACTIONS(5365),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_STAR_EQ] = ACTIONS(5173),
    [anon_sym_SLASH_EQ] = ACTIONS(5173),
    [anon_sym_PERCENT_EQ] = ACTIONS(5173),
    [anon_sym_PLUS_EQ] = ACTIONS(5173),
    [anon_sym_DASH_EQ] = ACTIONS(5173),
    [anon_sym_LT_LT_EQ] = ACTIONS(5173),
    [anon_sym_GT_GT_EQ] = ACTIONS(5173),
    [anon_sym_AMP_EQ] = ACTIONS(5173),
    [anon_sym_CARET_EQ] = ACTIONS(5173),
    [anon_sym_PIPE_EQ] = ACTIONS(5173),
    [anon_sym_and_eq] = ACTIONS(5175),
    [anon_sym_or_eq] = ACTIONS(5175),
    [anon_sym_xor_eq] = ACTIONS(5175),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5175),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5173),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
  },
  [STATE(1709)] = {
    [sym_type_qualifier] = STATE(1708),
    [sym_alignas_qualifier] = STATE(1737),
    [aux_sym__type_definition_type_repeat1] = STATE(1708),
    [aux_sym_sized_type_specifier_repeat1] = STATE(1729),
    [sym_identifier] = ACTIONS(5367),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_RPAREN] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5160),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5160),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5160),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5160),
    [anon_sym___extension__] = ACTIONS(5359),
    [anon_sym___global__] = ACTIONS(5359),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5369),
    [anon_sym_unsigned] = ACTIONS(5369),
    [anon_sym_long] = ACTIONS(5369),
    [anon_sym_short] = ACTIONS(5369),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_EQ] = ACTIONS(5160),
    [anon_sym_const] = ACTIONS(5359),
    [anon_sym_constexpr] = ACTIONS(5359),
    [anon_sym_volatile] = ACTIONS(5359),
    [anon_sym_restrict] = ACTIONS(5359),
    [anon_sym___restrict__] = ACTIONS(5359),
    [anon_sym__Atomic] = ACTIONS(5359),
    [anon_sym__Noreturn] = ACTIONS(5359),
    [anon_sym_noreturn] = ACTIONS(5359),
    [anon_sym__Nonnull] = ACTIONS(5359),
    [anon_sym_mutable] = ACTIONS(5359),
    [anon_sym_constinit] = ACTIONS(5359),
    [anon_sym_consteval] = ACTIONS(5359),
    [anon_sym___shared__] = ACTIONS(5359),
    [anon_sym___local__] = ACTIONS(5359),
    [anon_sym___constant__] = ACTIONS(5359),
    [anon_sym___managed__] = ACTIONS(5359),
    [anon_sym___grid_constant__] = ACTIONS(5359),
    [anon_sym_alignas] = ACTIONS(5363),
    [anon_sym__Alignas] = ACTIONS(5363),
    [sym_primitive_type] = ACTIONS(5371),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_STAR_EQ] = ACTIONS(5158),
    [anon_sym_SLASH_EQ] = ACTIONS(5158),
    [anon_sym_PERCENT_EQ] = ACTIONS(5158),
    [anon_sym_PLUS_EQ] = ACTIONS(5158),
    [anon_sym_DASH_EQ] = ACTIONS(5158),
    [anon_sym_LT_LT_EQ] = ACTIONS(5158),
    [anon_sym_GT_GT_EQ] = ACTIONS(5158),
    [anon_sym_AMP_EQ] = ACTIONS(5158),
    [anon_sym_CARET_EQ] = ACTIONS(5158),
    [anon_sym_PIPE_EQ] = ACTIONS(5158),
    [anon_sym_and_eq] = ACTIONS(5160),
    [anon_sym_or_eq] = ACTIONS(5160),
    [anon_sym_xor_eq] = ACTIONS(5160),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5160),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5158),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
  },
  [STATE(1710)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_RPAREN] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5351),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5351),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5351),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5351),
    [anon_sym_SEMI] = ACTIONS(5354),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_RBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5137),
    [anon_sym_unsigned] = ACTIONS(5137),
    [anon_sym_long] = ACTIONS(5137),
    [anon_sym_short] = ACTIONS(5137),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_RBRACK] = ACTIONS(5354),
    [anon_sym_EQ] = ACTIONS(5351),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_COLON] = ACTIONS(5354),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_STAR_EQ] = ACTIONS(5354),
    [anon_sym_SLASH_EQ] = ACTIONS(5354),
    [anon_sym_PERCENT_EQ] = ACTIONS(5354),
    [anon_sym_PLUS_EQ] = ACTIONS(5354),
    [anon_sym_DASH_EQ] = ACTIONS(5354),
    [anon_sym_LT_LT_EQ] = ACTIONS(5354),
    [anon_sym_GT_GT_EQ] = ACTIONS(5354),
    [anon_sym_AMP_EQ] = ACTIONS(5354),
    [anon_sym_CARET_EQ] = ACTIONS(5354),
    [anon_sym_PIPE_EQ] = ACTIONS(5354),
    [anon_sym_and_eq] = ACTIONS(5351),
    [anon_sym_or_eq] = ACTIONS(5351),
    [anon_sym_xor_eq] = ACTIONS(5351),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5354),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
  },
  [STATE(1711)] = {
    [sym_type_qualifier] = STATE(1718),
    [sym_alignas_qualifier] = STATE(1763),
    [aux_sym__type_definition_type_repeat1] = STATE(1718),
    [aux_sym_sized_type_specifier_repeat1] = STATE(1736),
    [sym_identifier] = ACTIONS(5373),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5160),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5160),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5160),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5160),
    [anon_sym___extension__] = ACTIONS(5375),
    [anon_sym___global__] = ACTIONS(5375),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5377),
    [anon_sym_unsigned] = ACTIONS(5377),
    [anon_sym_long] = ACTIONS(5377),
    [anon_sym_short] = ACTIONS(5377),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_EQ] = ACTIONS(5160),
    [anon_sym_const] = ACTIONS(5375),
    [anon_sym_constexpr] = ACTIONS(5375),
    [anon_sym_volatile] = ACTIONS(5375),
    [anon_sym_restrict] = ACTIONS(5375),
    [anon_sym___restrict__] = ACTIONS(5375),
    [anon_sym__Atomic] = ACTIONS(5375),
    [anon_sym__Noreturn] = ACTIONS(5375),
    [anon_sym_noreturn] = ACTIONS(5375),
    [anon_sym__Nonnull] = ACTIONS(5375),
    [anon_sym_mutable] = ACTIONS(5375),
    [anon_sym_constinit] = ACTIONS(5375),
    [anon_sym_consteval] = ACTIONS(5375),
    [anon_sym___shared__] = ACTIONS(5375),
    [anon_sym___local__] = ACTIONS(5375),
    [anon_sym___constant__] = ACTIONS(5375),
    [anon_sym___managed__] = ACTIONS(5375),
    [anon_sym___grid_constant__] = ACTIONS(5375),
    [anon_sym_alignas] = ACTIONS(5379),
    [anon_sym__Alignas] = ACTIONS(5379),
    [sym_primitive_type] = ACTIONS(5381),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_STAR_EQ] = ACTIONS(5158),
    [anon_sym_SLASH_EQ] = ACTIONS(5158),
    [anon_sym_PERCENT_EQ] = ACTIONS(5158),
    [anon_sym_PLUS_EQ] = ACTIONS(5158),
    [anon_sym_DASH_EQ] = ACTIONS(5158),
    [anon_sym_LT_LT_EQ] = ACTIONS(5158),
    [anon_sym_GT_GT_EQ] = ACTIONS(5158),
    [anon_sym_AMP_EQ] = ACTIONS(5158),
    [anon_sym_CARET_EQ] = ACTIONS(5158),
    [anon_sym_PIPE_EQ] = ACTIONS(5158),
    [anon_sym_and_eq] = ACTIONS(5160),
    [anon_sym_or_eq] = ACTIONS(5160),
    [anon_sym_xor_eq] = ACTIONS(5160),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5158),
  },
  [STATE(1712)] = {
    [sym_type_qualifier] = STATE(1714),
    [sym_alignas_qualifier] = STATE(1754),
    [aux_sym__type_definition_type_repeat1] = STATE(1714),
    [aux_sym_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(5383),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5160),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5160),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5160),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5160),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5160),
    [anon_sym___extension__] = ACTIONS(5385),
    [anon_sym___global__] = ACTIONS(5385),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5387),
    [anon_sym_unsigned] = ACTIONS(5387),
    [anon_sym_long] = ACTIONS(5387),
    [anon_sym_short] = ACTIONS(5387),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_EQ] = ACTIONS(5160),
    [anon_sym_const] = ACTIONS(5385),
    [anon_sym_constexpr] = ACTIONS(5385),
    [anon_sym_volatile] = ACTIONS(5385),
    [anon_sym_restrict] = ACTIONS(5385),
    [anon_sym___restrict__] = ACTIONS(5385),
    [anon_sym__Atomic] = ACTIONS(5385),
    [anon_sym__Noreturn] = ACTIONS(5385),
    [anon_sym_noreturn] = ACTIONS(5385),
    [anon_sym__Nonnull] = ACTIONS(5385),
    [anon_sym_mutable] = ACTIONS(5385),
    [anon_sym_constinit] = ACTIONS(5385),
    [anon_sym_consteval] = ACTIONS(5385),
    [anon_sym___shared__] = ACTIONS(5385),
    [anon_sym___local__] = ACTIONS(5385),
    [anon_sym___constant__] = ACTIONS(5385),
    [anon_sym___managed__] = ACTIONS(5385),
    [anon_sym___grid_constant__] = ACTIONS(5385),
    [anon_sym_alignas] = ACTIONS(5389),
    [anon_sym__Alignas] = ACTIONS(5389),
    [sym_primitive_type] = ACTIONS(5391),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_STAR_EQ] = ACTIONS(5158),
    [anon_sym_SLASH_EQ] = ACTIONS(5158),
    [anon_sym_PERCENT_EQ] = ACTIONS(5158),
    [anon_sym_PLUS_EQ] = ACTIONS(5158),
    [anon_sym_DASH_EQ] = ACTIONS(5158),
    [anon_sym_LT_LT_EQ] = ACTIONS(5158),
    [anon_sym_GT_GT_EQ] = ACTIONS(5160),
    [anon_sym_AMP_EQ] = ACTIONS(5158),
    [anon_sym_CARET_EQ] = ACTIONS(5158),
    [anon_sym_PIPE_EQ] = ACTIONS(5158),
    [anon_sym_and_eq] = ACTIONS(5160),
    [anon_sym_or_eq] = ACTIONS(5160),
    [anon_sym_xor_eq] = ACTIONS(5160),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [anon_sym_GT2] = ACTIONS(5158),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
  },
  [STATE(1713)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4557),
    [anon_sym_COMMA] = ACTIONS(4557),
    [anon_sym_RPAREN] = ACTIONS(4557),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4557),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4555),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4555),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4555),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4560),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_EQ] = ACTIONS(4553),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_operator] = ACTIONS(4553),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(1714)] = {
    [sym_type_qualifier] = STATE(1720),
    [sym_alignas_qualifier] = STATE(1754),
    [aux_sym__type_definition_type_repeat1] = STATE(1720),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2962),
    [sym_identifier] = ACTIONS(5393),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5175),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5175),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5175),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5175),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5175),
    [anon_sym___extension__] = ACTIONS(5385),
    [anon_sym___global__] = ACTIONS(5385),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5395),
    [anon_sym_unsigned] = ACTIONS(5395),
    [anon_sym_long] = ACTIONS(5395),
    [anon_sym_short] = ACTIONS(5395),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_EQ] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5385),
    [anon_sym_constexpr] = ACTIONS(5385),
    [anon_sym_volatile] = ACTIONS(5385),
    [anon_sym_restrict] = ACTIONS(5385),
    [anon_sym___restrict__] = ACTIONS(5385),
    [anon_sym__Atomic] = ACTIONS(5385),
    [anon_sym__Noreturn] = ACTIONS(5385),
    [anon_sym_noreturn] = ACTIONS(5385),
    [anon_sym__Nonnull] = ACTIONS(5385),
    [anon_sym_mutable] = ACTIONS(5385),
    [anon_sym_constinit] = ACTIONS(5385),
    [anon_sym_consteval] = ACTIONS(5385),
    [anon_sym___shared__] = ACTIONS(5385),
    [anon_sym___local__] = ACTIONS(5385),
    [anon_sym___constant__] = ACTIONS(5385),
    [anon_sym___managed__] = ACTIONS(5385),
    [anon_sym___grid_constant__] = ACTIONS(5385),
    [anon_sym_alignas] = ACTIONS(5389),
    [anon_sym__Alignas] = ACTIONS(5389),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_STAR_EQ] = ACTIONS(5173),
    [anon_sym_SLASH_EQ] = ACTIONS(5173),
    [anon_sym_PERCENT_EQ] = ACTIONS(5173),
    [anon_sym_PLUS_EQ] = ACTIONS(5173),
    [anon_sym_DASH_EQ] = ACTIONS(5173),
    [anon_sym_LT_LT_EQ] = ACTIONS(5173),
    [anon_sym_GT_GT_EQ] = ACTIONS(5175),
    [anon_sym_AMP_EQ] = ACTIONS(5173),
    [anon_sym_CARET_EQ] = ACTIONS(5173),
    [anon_sym_PIPE_EQ] = ACTIONS(5173),
    [anon_sym_and_eq] = ACTIONS(5175),
    [anon_sym_or_eq] = ACTIONS(5175),
    [anon_sym_xor_eq] = ACTIONS(5175),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5173),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [anon_sym_GT2] = ACTIONS(5173),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
  },
  [STATE(1715)] = {
    [sym_type_qualifier] = STATE(1715),
    [sym_alignas_qualifier] = STATE(1737),
    [aux_sym__type_definition_type_repeat1] = STATE(1715),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_RPAREN] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_DASH] = ACTIONS(5110),
    [anon_sym_PLUS] = ACTIONS(5110),
    [anon_sym_STAR] = ACTIONS(5110),
    [anon_sym_SLASH] = ACTIONS(5110),
    [anon_sym_PERCENT] = ACTIONS(5110),
    [anon_sym_PIPE_PIPE] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_PIPE] = ACTIONS(5110),
    [anon_sym_CARET] = ACTIONS(5110),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_EQ_EQ] = ACTIONS(5112),
    [anon_sym_BANG_EQ] = ACTIONS(5112),
    [anon_sym_GT] = ACTIONS(5110),
    [anon_sym_GT_EQ] = ACTIONS(5112),
    [anon_sym_LT_EQ] = ACTIONS(5110),
    [anon_sym_LT] = ACTIONS(5110),
    [anon_sym_LT_LT] = ACTIONS(5110),
    [anon_sym_GT_GT] = ACTIONS(5110),
    [anon_sym___extension__] = ACTIONS(5399),
    [anon_sym___global__] = ACTIONS(5399),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5112),
    [anon_sym_EQ] = ACTIONS(5110),
    [anon_sym_const] = ACTIONS(5399),
    [anon_sym_constexpr] = ACTIONS(5399),
    [anon_sym_volatile] = ACTIONS(5399),
    [anon_sym_restrict] = ACTIONS(5399),
    [anon_sym___restrict__] = ACTIONS(5399),
    [anon_sym__Atomic] = ACTIONS(5399),
    [anon_sym__Noreturn] = ACTIONS(5399),
    [anon_sym_noreturn] = ACTIONS(5399),
    [anon_sym__Nonnull] = ACTIONS(5399),
    [anon_sym_mutable] = ACTIONS(5399),
    [anon_sym_constinit] = ACTIONS(5399),
    [anon_sym_consteval] = ACTIONS(5399),
    [anon_sym___shared__] = ACTIONS(5399),
    [anon_sym___local__] = ACTIONS(5399),
    [anon_sym___constant__] = ACTIONS(5399),
    [anon_sym___managed__] = ACTIONS(5399),
    [anon_sym___grid_constant__] = ACTIONS(5399),
    [anon_sym_alignas] = ACTIONS(5402),
    [anon_sym__Alignas] = ACTIONS(5402),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_QMARK] = ACTIONS(5112),
    [anon_sym_STAR_EQ] = ACTIONS(5112),
    [anon_sym_SLASH_EQ] = ACTIONS(5112),
    [anon_sym_PERCENT_EQ] = ACTIONS(5112),
    [anon_sym_PLUS_EQ] = ACTIONS(5112),
    [anon_sym_DASH_EQ] = ACTIONS(5112),
    [anon_sym_LT_LT_EQ] = ACTIONS(5112),
    [anon_sym_GT_GT_EQ] = ACTIONS(5112),
    [anon_sym_AMP_EQ] = ACTIONS(5112),
    [anon_sym_CARET_EQ] = ACTIONS(5112),
    [anon_sym_PIPE_EQ] = ACTIONS(5112),
    [anon_sym_and_eq] = ACTIONS(5110),
    [anon_sym_or_eq] = ACTIONS(5110),
    [anon_sym_xor_eq] = ACTIONS(5110),
    [anon_sym_LT_EQ_GT] = ACTIONS(5112),
    [anon_sym_or] = ACTIONS(5110),
    [anon_sym_and] = ACTIONS(5110),
    [anon_sym_bitor] = ACTIONS(5110),
    [anon_sym_xor] = ACTIONS(5110),
    [anon_sym_bitand] = ACTIONS(5110),
    [anon_sym_not_eq] = ACTIONS(5110),
    [anon_sym_DASH_DASH] = ACTIONS(5112),
    [anon_sym_PLUS_PLUS] = ACTIONS(5112),
    [anon_sym_DOT] = ACTIONS(5110),
    [anon_sym_DOT_STAR] = ACTIONS(5112),
    [anon_sym_DASH_GT] = ACTIONS(5110),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5112),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5112),
  },
  [STATE(1716)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_RPAREN] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_TILDE] = ACTIONS(5145),
    [anon_sym_STAR] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_SEMI] = ACTIONS(5145),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___device__] = ACTIONS(5143),
    [anon_sym___host__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___forceinline__] = ACTIONS(5143),
    [anon_sym___noinline__] = ACTIONS(5143),
    [anon_sym_virtual] = ACTIONS(5143),
    [anon_sym_extern] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_COLON_COLON] = ACTIONS(5145),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5145),
    [anon_sym___declspec] = ACTIONS(5143),
    [anon_sym___based] = ACTIONS(5143),
    [anon_sym___cdecl] = ACTIONS(5143),
    [anon_sym___clrcall] = ACTIONS(5143),
    [anon_sym___stdcall] = ACTIONS(5143),
    [anon_sym___fastcall] = ACTIONS(5143),
    [anon_sym___thiscall] = ACTIONS(5143),
    [anon_sym___vectorcall] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5143),
    [anon_sym_static] = ACTIONS(5143),
    [anon_sym_EQ] = ACTIONS(5145),
    [anon_sym_register] = ACTIONS(5143),
    [anon_sym_inline] = ACTIONS(5143),
    [anon_sym___inline] = ACTIONS(5143),
    [anon_sym___inline__] = ACTIONS(5143),
    [anon_sym___forceinline] = ACTIONS(5143),
    [anon_sym_thread_local] = ACTIONS(5143),
    [anon_sym___thread] = ACTIONS(5143),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_enum] = ACTIONS(5143),
    [anon_sym_class] = ACTIONS(5143),
    [anon_sym_struct] = ACTIONS(5143),
    [anon_sym_union] = ACTIONS(5143),
    [anon_sym_asm] = ACTIONS(5143),
    [anon_sym___asm__] = ACTIONS(5143),
    [anon_sym___asm] = ACTIONS(5143),
    [anon_sym_DASH_GT] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [anon_sym_final] = ACTIONS(5143),
    [anon_sym_override] = ACTIONS(5143),
    [anon_sym_explicit] = ACTIONS(5143),
    [anon_sym_typename] = ACTIONS(5143),
    [anon_sym_template] = ACTIONS(5143),
    [anon_sym_GT2] = ACTIONS(5145),
    [anon_sym_operator] = ACTIONS(5143),
    [anon_sym_try] = ACTIONS(5143),
    [anon_sym_noexcept] = ACTIONS(5143),
    [anon_sym_throw] = ACTIONS(5143),
    [anon_sym_requires] = ACTIONS(5143),
    [anon_sym___launch_bounds__] = ACTIONS(5143),
  },
  [STATE(1717)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4525),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(8535),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_type_parameter_declaration] = STATE(8535),
    [sym_variadic_type_parameter_declaration] = STATE(8535),
    [sym_optional_type_parameter_declaration] = STATE(8535),
    [sym_template_template_parameter_declaration] = STATE(8535),
    [sym_optional_parameter_declaration] = STATE(8535),
    [sym_variadic_parameter_declaration] = STATE(8535),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(5341),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(5343),
    [anon_sym_template] = ACTIONS(5345),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1718)] = {
    [sym_type_qualifier] = STATE(1721),
    [sym_alignas_qualifier] = STATE(1763),
    [aux_sym__type_definition_type_repeat1] = STATE(1721),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2935),
    [sym_identifier] = ACTIONS(5405),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5175),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5175),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5175),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5175),
    [anon_sym___extension__] = ACTIONS(5375),
    [anon_sym___global__] = ACTIONS(5375),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5407),
    [anon_sym_unsigned] = ACTIONS(5407),
    [anon_sym_long] = ACTIONS(5407),
    [anon_sym_short] = ACTIONS(5407),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_EQ] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5375),
    [anon_sym_constexpr] = ACTIONS(5375),
    [anon_sym_volatile] = ACTIONS(5375),
    [anon_sym_restrict] = ACTIONS(5375),
    [anon_sym___restrict__] = ACTIONS(5375),
    [anon_sym__Atomic] = ACTIONS(5375),
    [anon_sym__Noreturn] = ACTIONS(5375),
    [anon_sym_noreturn] = ACTIONS(5375),
    [anon_sym__Nonnull] = ACTIONS(5375),
    [anon_sym_mutable] = ACTIONS(5375),
    [anon_sym_constinit] = ACTIONS(5375),
    [anon_sym_consteval] = ACTIONS(5375),
    [anon_sym___shared__] = ACTIONS(5375),
    [anon_sym___local__] = ACTIONS(5375),
    [anon_sym___constant__] = ACTIONS(5375),
    [anon_sym___managed__] = ACTIONS(5375),
    [anon_sym___grid_constant__] = ACTIONS(5375),
    [anon_sym_alignas] = ACTIONS(5379),
    [anon_sym__Alignas] = ACTIONS(5379),
    [sym_primitive_type] = ACTIONS(5409),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_STAR_EQ] = ACTIONS(5173),
    [anon_sym_SLASH_EQ] = ACTIONS(5173),
    [anon_sym_PERCENT_EQ] = ACTIONS(5173),
    [anon_sym_PLUS_EQ] = ACTIONS(5173),
    [anon_sym_DASH_EQ] = ACTIONS(5173),
    [anon_sym_LT_LT_EQ] = ACTIONS(5173),
    [anon_sym_GT_GT_EQ] = ACTIONS(5173),
    [anon_sym_AMP_EQ] = ACTIONS(5173),
    [anon_sym_CARET_EQ] = ACTIONS(5173),
    [anon_sym_PIPE_EQ] = ACTIONS(5173),
    [anon_sym_and_eq] = ACTIONS(5175),
    [anon_sym_or_eq] = ACTIONS(5175),
    [anon_sym_xor_eq] = ACTIONS(5175),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5173),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5173),
  },
  [STATE(1719)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_RPAREN] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym___cdecl] = ACTIONS(1969),
    [anon_sym___clrcall] = ACTIONS(1969),
    [anon_sym___stdcall] = ACTIONS(1969),
    [anon_sym___fastcall] = ACTIONS(1969),
    [anon_sym___thiscall] = ACTIONS(1969),
    [anon_sym___vectorcall] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_EQ] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_asm] = ACTIONS(1969),
    [anon_sym___asm__] = ACTIONS(1969),
    [anon_sym___asm] = ACTIONS(1969),
    [anon_sym_DASH_GT] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_GT2] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_try] = ACTIONS(1969),
    [anon_sym_noexcept] = ACTIONS(1969),
    [anon_sym_throw] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(1720)] = {
    [sym_type_qualifier] = STATE(1720),
    [sym_alignas_qualifier] = STATE(1754),
    [aux_sym__type_definition_type_repeat1] = STATE(1720),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_DASH] = ACTIONS(5110),
    [anon_sym_PLUS] = ACTIONS(5110),
    [anon_sym_STAR] = ACTIONS(5110),
    [anon_sym_SLASH] = ACTIONS(5110),
    [anon_sym_PERCENT] = ACTIONS(5110),
    [anon_sym_PIPE_PIPE] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_PIPE] = ACTIONS(5110),
    [anon_sym_CARET] = ACTIONS(5110),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_EQ_EQ] = ACTIONS(5112),
    [anon_sym_BANG_EQ] = ACTIONS(5112),
    [anon_sym_GT] = ACTIONS(5110),
    [anon_sym_GT_EQ] = ACTIONS(5110),
    [anon_sym_LT_EQ] = ACTIONS(5110),
    [anon_sym_LT] = ACTIONS(5110),
    [anon_sym_LT_LT] = ACTIONS(5110),
    [anon_sym_GT_GT] = ACTIONS(5110),
    [anon_sym___extension__] = ACTIONS(5411),
    [anon_sym___global__] = ACTIONS(5411),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5112),
    [anon_sym_EQ] = ACTIONS(5110),
    [anon_sym_const] = ACTIONS(5411),
    [anon_sym_constexpr] = ACTIONS(5411),
    [anon_sym_volatile] = ACTIONS(5411),
    [anon_sym_restrict] = ACTIONS(5411),
    [anon_sym___restrict__] = ACTIONS(5411),
    [anon_sym__Atomic] = ACTIONS(5411),
    [anon_sym__Noreturn] = ACTIONS(5411),
    [anon_sym_noreturn] = ACTIONS(5411),
    [anon_sym__Nonnull] = ACTIONS(5411),
    [anon_sym_mutable] = ACTIONS(5411),
    [anon_sym_constinit] = ACTIONS(5411),
    [anon_sym_consteval] = ACTIONS(5411),
    [anon_sym___shared__] = ACTIONS(5411),
    [anon_sym___local__] = ACTIONS(5411),
    [anon_sym___constant__] = ACTIONS(5411),
    [anon_sym___managed__] = ACTIONS(5411),
    [anon_sym___grid_constant__] = ACTIONS(5411),
    [anon_sym_alignas] = ACTIONS(5414),
    [anon_sym__Alignas] = ACTIONS(5414),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_QMARK] = ACTIONS(5112),
    [anon_sym_STAR_EQ] = ACTIONS(5112),
    [anon_sym_SLASH_EQ] = ACTIONS(5112),
    [anon_sym_PERCENT_EQ] = ACTIONS(5112),
    [anon_sym_PLUS_EQ] = ACTIONS(5112),
    [anon_sym_DASH_EQ] = ACTIONS(5112),
    [anon_sym_LT_LT_EQ] = ACTIONS(5112),
    [anon_sym_GT_GT_EQ] = ACTIONS(5110),
    [anon_sym_AMP_EQ] = ACTIONS(5112),
    [anon_sym_CARET_EQ] = ACTIONS(5112),
    [anon_sym_PIPE_EQ] = ACTIONS(5112),
    [anon_sym_and_eq] = ACTIONS(5110),
    [anon_sym_or_eq] = ACTIONS(5110),
    [anon_sym_xor_eq] = ACTIONS(5110),
    [anon_sym_LT_EQ_GT] = ACTIONS(5112),
    [anon_sym_or] = ACTIONS(5110),
    [anon_sym_and] = ACTIONS(5110),
    [anon_sym_bitor] = ACTIONS(5110),
    [anon_sym_xor] = ACTIONS(5110),
    [anon_sym_bitand] = ACTIONS(5110),
    [anon_sym_not_eq] = ACTIONS(5110),
    [anon_sym_DASH_DASH] = ACTIONS(5112),
    [anon_sym_PLUS_PLUS] = ACTIONS(5112),
    [anon_sym_DOT] = ACTIONS(5110),
    [anon_sym_DOT_STAR] = ACTIONS(5112),
    [anon_sym_DASH_GT] = ACTIONS(5112),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [anon_sym_GT2] = ACTIONS(5112),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5112),
  },
  [STATE(1721)] = {
    [sym_type_qualifier] = STATE(1721),
    [sym_alignas_qualifier] = STATE(1763),
    [aux_sym__type_definition_type_repeat1] = STATE(1721),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_DASH] = ACTIONS(5110),
    [anon_sym_PLUS] = ACTIONS(5110),
    [anon_sym_STAR] = ACTIONS(5110),
    [anon_sym_SLASH] = ACTIONS(5110),
    [anon_sym_PERCENT] = ACTIONS(5110),
    [anon_sym_PIPE_PIPE] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_PIPE] = ACTIONS(5110),
    [anon_sym_CARET] = ACTIONS(5110),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_EQ_EQ] = ACTIONS(5112),
    [anon_sym_BANG_EQ] = ACTIONS(5112),
    [anon_sym_GT] = ACTIONS(5110),
    [anon_sym_GT_EQ] = ACTIONS(5112),
    [anon_sym_LT_EQ] = ACTIONS(5110),
    [anon_sym_LT] = ACTIONS(5110),
    [anon_sym_LT_LT] = ACTIONS(5110),
    [anon_sym_GT_GT] = ACTIONS(5110),
    [anon_sym___extension__] = ACTIONS(5417),
    [anon_sym___global__] = ACTIONS(5417),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5112),
    [anon_sym_EQ] = ACTIONS(5110),
    [anon_sym_const] = ACTIONS(5417),
    [anon_sym_constexpr] = ACTIONS(5417),
    [anon_sym_volatile] = ACTIONS(5417),
    [anon_sym_restrict] = ACTIONS(5417),
    [anon_sym___restrict__] = ACTIONS(5417),
    [anon_sym__Atomic] = ACTIONS(5417),
    [anon_sym__Noreturn] = ACTIONS(5417),
    [anon_sym_noreturn] = ACTIONS(5417),
    [anon_sym__Nonnull] = ACTIONS(5417),
    [anon_sym_mutable] = ACTIONS(5417),
    [anon_sym_constinit] = ACTIONS(5417),
    [anon_sym_consteval] = ACTIONS(5417),
    [anon_sym___shared__] = ACTIONS(5417),
    [anon_sym___local__] = ACTIONS(5417),
    [anon_sym___constant__] = ACTIONS(5417),
    [anon_sym___managed__] = ACTIONS(5417),
    [anon_sym___grid_constant__] = ACTIONS(5417),
    [anon_sym_alignas] = ACTIONS(5420),
    [anon_sym__Alignas] = ACTIONS(5420),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_QMARK] = ACTIONS(5112),
    [anon_sym_STAR_EQ] = ACTIONS(5112),
    [anon_sym_SLASH_EQ] = ACTIONS(5112),
    [anon_sym_PERCENT_EQ] = ACTIONS(5112),
    [anon_sym_PLUS_EQ] = ACTIONS(5112),
    [anon_sym_DASH_EQ] = ACTIONS(5112),
    [anon_sym_LT_LT_EQ] = ACTIONS(5112),
    [anon_sym_GT_GT_EQ] = ACTIONS(5112),
    [anon_sym_AMP_EQ] = ACTIONS(5112),
    [anon_sym_CARET_EQ] = ACTIONS(5112),
    [anon_sym_PIPE_EQ] = ACTIONS(5112),
    [anon_sym_and_eq] = ACTIONS(5110),
    [anon_sym_or_eq] = ACTIONS(5110),
    [anon_sym_xor_eq] = ACTIONS(5110),
    [anon_sym_LT_EQ_GT] = ACTIONS(5112),
    [anon_sym_or] = ACTIONS(5110),
    [anon_sym_and] = ACTIONS(5110),
    [anon_sym_bitor] = ACTIONS(5110),
    [anon_sym_xor] = ACTIONS(5110),
    [anon_sym_bitand] = ACTIONS(5110),
    [anon_sym_not_eq] = ACTIONS(5110),
    [anon_sym_DASH_DASH] = ACTIONS(5112),
    [anon_sym_PLUS_PLUS] = ACTIONS(5112),
    [anon_sym_DOT] = ACTIONS(5110),
    [anon_sym_DOT_STAR] = ACTIONS(5112),
    [anon_sym_DASH_GT] = ACTIONS(5112),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5112),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5112),
  },
  [STATE(1722)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7766),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7766),
    [sym_variadic_parameter_declaration] = STATE(7766),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5423),
    [anon_sym_RPAREN] = ACTIONS(5425),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1723)] = {
    [sym_type_qualifier] = STATE(1739),
    [sym_alignas_qualifier] = STATE(1886),
    [aux_sym__type_definition_type_repeat1] = STATE(1739),
    [aux_sym_sized_type_specifier_repeat1] = STATE(3029),
    [sym_identifier] = ACTIONS(5427),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_RPAREN] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5175),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5175),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5175),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5175),
    [anon_sym___extension__] = ACTIONS(5429),
    [anon_sym___global__] = ACTIONS(5429),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5431),
    [anon_sym_unsigned] = ACTIONS(5431),
    [anon_sym_long] = ACTIONS(5431),
    [anon_sym_short] = ACTIONS(5431),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_EQ] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5429),
    [anon_sym_constexpr] = ACTIONS(5429),
    [anon_sym_volatile] = ACTIONS(5429),
    [anon_sym_restrict] = ACTIONS(5429),
    [anon_sym___restrict__] = ACTIONS(5429),
    [anon_sym__Atomic] = ACTIONS(5429),
    [anon_sym__Noreturn] = ACTIONS(5429),
    [anon_sym_noreturn] = ACTIONS(5429),
    [anon_sym__Nonnull] = ACTIONS(5429),
    [anon_sym_mutable] = ACTIONS(5429),
    [anon_sym_constinit] = ACTIONS(5429),
    [anon_sym_consteval] = ACTIONS(5429),
    [anon_sym___shared__] = ACTIONS(5429),
    [anon_sym___local__] = ACTIONS(5429),
    [anon_sym___constant__] = ACTIONS(5429),
    [anon_sym___managed__] = ACTIONS(5429),
    [anon_sym___grid_constant__] = ACTIONS(5429),
    [anon_sym_alignas] = ACTIONS(5433),
    [anon_sym__Alignas] = ACTIONS(5433),
    [sym_primitive_type] = ACTIONS(5435),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_STAR_EQ] = ACTIONS(5173),
    [anon_sym_SLASH_EQ] = ACTIONS(5173),
    [anon_sym_PERCENT_EQ] = ACTIONS(5173),
    [anon_sym_PLUS_EQ] = ACTIONS(5173),
    [anon_sym_DASH_EQ] = ACTIONS(5173),
    [anon_sym_LT_LT_EQ] = ACTIONS(5173),
    [anon_sym_GT_GT_EQ] = ACTIONS(5173),
    [anon_sym_AMP_EQ] = ACTIONS(5173),
    [anon_sym_CARET_EQ] = ACTIONS(5173),
    [anon_sym_PIPE_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5175),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5173),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
  },
  [STATE(1724)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(8125),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(8125),
    [sym_variadic_parameter_declaration] = STATE(8125),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5437),
    [anon_sym_RPAREN] = ACTIONS(5439),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1725)] = {
    [sym_type_qualifier] = STATE(1723),
    [sym_alignas_qualifier] = STATE(1886),
    [aux_sym__type_definition_type_repeat1] = STATE(1723),
    [aux_sym_sized_type_specifier_repeat1] = STATE(1844),
    [sym_identifier] = ACTIONS(5441),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_RPAREN] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5160),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5160),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5160),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5160),
    [anon_sym___extension__] = ACTIONS(5429),
    [anon_sym___global__] = ACTIONS(5429),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5443),
    [anon_sym_unsigned] = ACTIONS(5443),
    [anon_sym_long] = ACTIONS(5443),
    [anon_sym_short] = ACTIONS(5443),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_EQ] = ACTIONS(5160),
    [anon_sym_const] = ACTIONS(5429),
    [anon_sym_constexpr] = ACTIONS(5429),
    [anon_sym_volatile] = ACTIONS(5429),
    [anon_sym_restrict] = ACTIONS(5429),
    [anon_sym___restrict__] = ACTIONS(5429),
    [anon_sym__Atomic] = ACTIONS(5429),
    [anon_sym__Noreturn] = ACTIONS(5429),
    [anon_sym_noreturn] = ACTIONS(5429),
    [anon_sym__Nonnull] = ACTIONS(5429),
    [anon_sym_mutable] = ACTIONS(5429),
    [anon_sym_constinit] = ACTIONS(5429),
    [anon_sym_consteval] = ACTIONS(5429),
    [anon_sym___shared__] = ACTIONS(5429),
    [anon_sym___local__] = ACTIONS(5429),
    [anon_sym___constant__] = ACTIONS(5429),
    [anon_sym___managed__] = ACTIONS(5429),
    [anon_sym___grid_constant__] = ACTIONS(5429),
    [anon_sym_alignas] = ACTIONS(5433),
    [anon_sym__Alignas] = ACTIONS(5433),
    [sym_primitive_type] = ACTIONS(5445),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_STAR_EQ] = ACTIONS(5158),
    [anon_sym_SLASH_EQ] = ACTIONS(5158),
    [anon_sym_PERCENT_EQ] = ACTIONS(5158),
    [anon_sym_PLUS_EQ] = ACTIONS(5158),
    [anon_sym_DASH_EQ] = ACTIONS(5158),
    [anon_sym_LT_LT_EQ] = ACTIONS(5158),
    [anon_sym_GT_GT_EQ] = ACTIONS(5158),
    [anon_sym_AMP_EQ] = ACTIONS(5158),
    [anon_sym_CARET_EQ] = ACTIONS(5158),
    [anon_sym_PIPE_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5160),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5158),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
  },
  [STATE(1726)] = {
    [sym_catch_clause] = STATE(1733),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1733),
    [sym_identifier] = ACTIONS(1996),
    [aux_sym_preproc_def_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token2] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1996),
    [aux_sym_preproc_else_token1] = ACTIONS(1996),
    [aux_sym_preproc_elif_token1] = ACTIONS(1996),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1996),
    [sym_preproc_directive] = ACTIONS(1996),
    [anon_sym_LPAREN2] = ACTIONS(1998),
    [anon_sym_TILDE] = ACTIONS(1998),
    [anon_sym_STAR] = ACTIONS(1998),
    [anon_sym_AMP_AMP] = ACTIONS(1998),
    [anon_sym_AMP] = ACTIONS(1996),
    [anon_sym_SEMI] = ACTIONS(1998),
    [anon_sym___extension__] = ACTIONS(1996),
    [anon_sym_typedef] = ACTIONS(1996),
    [anon_sym___device__] = ACTIONS(1996),
    [anon_sym___host__] = ACTIONS(1996),
    [anon_sym___global__] = ACTIONS(1996),
    [anon_sym___forceinline__] = ACTIONS(1996),
    [anon_sym___noinline__] = ACTIONS(1996),
    [anon_sym_virtual] = ACTIONS(1996),
    [anon_sym_extern] = ACTIONS(1996),
    [anon_sym___attribute__] = ACTIONS(1996),
    [anon_sym___attribute] = ACTIONS(1996),
    [anon_sym_COLON_COLON] = ACTIONS(1998),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1998),
    [anon_sym___declspec] = ACTIONS(1996),
    [anon_sym___based] = ACTIONS(1996),
    [anon_sym_signed] = ACTIONS(1996),
    [anon_sym_unsigned] = ACTIONS(1996),
    [anon_sym_long] = ACTIONS(1996),
    [anon_sym_short] = ACTIONS(1996),
    [anon_sym_LBRACK] = ACTIONS(1996),
    [anon_sym_static] = ACTIONS(1996),
    [anon_sym_register] = ACTIONS(1996),
    [anon_sym_inline] = ACTIONS(1996),
    [anon_sym___inline] = ACTIONS(1996),
    [anon_sym___inline__] = ACTIONS(1996),
    [anon_sym___forceinline] = ACTIONS(1996),
    [anon_sym_thread_local] = ACTIONS(1996),
    [anon_sym___thread] = ACTIONS(1996),
    [anon_sym_const] = ACTIONS(1996),
    [anon_sym_constexpr] = ACTIONS(1996),
    [anon_sym_volatile] = ACTIONS(1996),
    [anon_sym_restrict] = ACTIONS(1996),
    [anon_sym___restrict__] = ACTIONS(1996),
    [anon_sym__Atomic] = ACTIONS(1996),
    [anon_sym__Noreturn] = ACTIONS(1996),
    [anon_sym_noreturn] = ACTIONS(1996),
    [anon_sym__Nonnull] = ACTIONS(1996),
    [anon_sym_mutable] = ACTIONS(1996),
    [anon_sym_constinit] = ACTIONS(1996),
    [anon_sym_consteval] = ACTIONS(1996),
    [anon_sym___shared__] = ACTIONS(1996),
    [anon_sym___local__] = ACTIONS(1996),
    [anon_sym___constant__] = ACTIONS(1996),
    [anon_sym___managed__] = ACTIONS(1996),
    [anon_sym___grid_constant__] = ACTIONS(1996),
    [anon_sym_alignas] = ACTIONS(1996),
    [anon_sym__Alignas] = ACTIONS(1996),
    [sym_primitive_type] = ACTIONS(1996),
    [anon_sym_enum] = ACTIONS(1996),
    [anon_sym_class] = ACTIONS(1996),
    [anon_sym_struct] = ACTIONS(1996),
    [anon_sym_union] = ACTIONS(1996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1996),
    [anon_sym_decltype] = ACTIONS(1996),
    [anon_sym_explicit] = ACTIONS(1996),
    [anon_sym_typename] = ACTIONS(1996),
    [anon_sym_template] = ACTIONS(1996),
    [anon_sym_operator] = ACTIONS(1996),
    [anon_sym_friend] = ACTIONS(1996),
    [anon_sym_public] = ACTIONS(1996),
    [anon_sym_private] = ACTIONS(1996),
    [anon_sym_protected] = ACTIONS(1996),
    [anon_sym_using] = ACTIONS(1996),
    [anon_sym_static_assert] = ACTIONS(1996),
    [anon_sym_catch] = ACTIONS(5447),
    [anon_sym___launch_bounds__] = ACTIONS(1996),
  },
  [STATE(1727)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7876),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7876),
    [sym_variadic_parameter_declaration] = STATE(7876),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5449),
    [anon_sym_RPAREN] = ACTIONS(5451),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1728)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7869),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7869),
    [sym_variadic_parameter_declaration] = STATE(7869),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5455),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1729)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1734),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_RPAREN] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5351),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5351),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5351),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5351),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5457),
    [anon_sym_unsigned] = ACTIONS(5457),
    [anon_sym_long] = ACTIONS(5457),
    [anon_sym_short] = ACTIONS(5457),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_EQ] = ACTIONS(5351),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_STAR_EQ] = ACTIONS(5354),
    [anon_sym_SLASH_EQ] = ACTIONS(5354),
    [anon_sym_PERCENT_EQ] = ACTIONS(5354),
    [anon_sym_PLUS_EQ] = ACTIONS(5354),
    [anon_sym_DASH_EQ] = ACTIONS(5354),
    [anon_sym_LT_LT_EQ] = ACTIONS(5354),
    [anon_sym_GT_GT_EQ] = ACTIONS(5354),
    [anon_sym_AMP_EQ] = ACTIONS(5354),
    [anon_sym_CARET_EQ] = ACTIONS(5354),
    [anon_sym_PIPE_EQ] = ACTIONS(5354),
    [anon_sym_and_eq] = ACTIONS(5351),
    [anon_sym_or_eq] = ACTIONS(5351),
    [anon_sym_xor_eq] = ACTIONS(5351),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5354),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
  },
  [STATE(1730)] = {
    [sym_catch_clause] = STATE(1733),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1733),
    [sym_identifier] = ACTIONS(1992),
    [aux_sym_preproc_def_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token2] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1992),
    [aux_sym_preproc_else_token1] = ACTIONS(1992),
    [aux_sym_preproc_elif_token1] = ACTIONS(1992),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1992),
    [sym_preproc_directive] = ACTIONS(1992),
    [anon_sym_LPAREN2] = ACTIONS(1994),
    [anon_sym_TILDE] = ACTIONS(1994),
    [anon_sym_STAR] = ACTIONS(1994),
    [anon_sym_AMP_AMP] = ACTIONS(1994),
    [anon_sym_AMP] = ACTIONS(1992),
    [anon_sym_SEMI] = ACTIONS(1994),
    [anon_sym___extension__] = ACTIONS(1992),
    [anon_sym_typedef] = ACTIONS(1992),
    [anon_sym___device__] = ACTIONS(1992),
    [anon_sym___host__] = ACTIONS(1992),
    [anon_sym___global__] = ACTIONS(1992),
    [anon_sym___forceinline__] = ACTIONS(1992),
    [anon_sym___noinline__] = ACTIONS(1992),
    [anon_sym_virtual] = ACTIONS(1992),
    [anon_sym_extern] = ACTIONS(1992),
    [anon_sym___attribute__] = ACTIONS(1992),
    [anon_sym___attribute] = ACTIONS(1992),
    [anon_sym_COLON_COLON] = ACTIONS(1994),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1994),
    [anon_sym___declspec] = ACTIONS(1992),
    [anon_sym___based] = ACTIONS(1992),
    [anon_sym_signed] = ACTIONS(1992),
    [anon_sym_unsigned] = ACTIONS(1992),
    [anon_sym_long] = ACTIONS(1992),
    [anon_sym_short] = ACTIONS(1992),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_static] = ACTIONS(1992),
    [anon_sym_register] = ACTIONS(1992),
    [anon_sym_inline] = ACTIONS(1992),
    [anon_sym___inline] = ACTIONS(1992),
    [anon_sym___inline__] = ACTIONS(1992),
    [anon_sym___forceinline] = ACTIONS(1992),
    [anon_sym_thread_local] = ACTIONS(1992),
    [anon_sym___thread] = ACTIONS(1992),
    [anon_sym_const] = ACTIONS(1992),
    [anon_sym_constexpr] = ACTIONS(1992),
    [anon_sym_volatile] = ACTIONS(1992),
    [anon_sym_restrict] = ACTIONS(1992),
    [anon_sym___restrict__] = ACTIONS(1992),
    [anon_sym__Atomic] = ACTIONS(1992),
    [anon_sym__Noreturn] = ACTIONS(1992),
    [anon_sym_noreturn] = ACTIONS(1992),
    [anon_sym__Nonnull] = ACTIONS(1992),
    [anon_sym_mutable] = ACTIONS(1992),
    [anon_sym_constinit] = ACTIONS(1992),
    [anon_sym_consteval] = ACTIONS(1992),
    [anon_sym___shared__] = ACTIONS(1992),
    [anon_sym___local__] = ACTIONS(1992),
    [anon_sym___constant__] = ACTIONS(1992),
    [anon_sym___managed__] = ACTIONS(1992),
    [anon_sym___grid_constant__] = ACTIONS(1992),
    [anon_sym_alignas] = ACTIONS(1992),
    [anon_sym__Alignas] = ACTIONS(1992),
    [sym_primitive_type] = ACTIONS(1992),
    [anon_sym_enum] = ACTIONS(1992),
    [anon_sym_class] = ACTIONS(1992),
    [anon_sym_struct] = ACTIONS(1992),
    [anon_sym_union] = ACTIONS(1992),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1992),
    [anon_sym_decltype] = ACTIONS(1992),
    [anon_sym_explicit] = ACTIONS(1992),
    [anon_sym_typename] = ACTIONS(1992),
    [anon_sym_template] = ACTIONS(1992),
    [anon_sym_operator] = ACTIONS(1992),
    [anon_sym_friend] = ACTIONS(1992),
    [anon_sym_public] = ACTIONS(1992),
    [anon_sym_private] = ACTIONS(1992),
    [anon_sym_protected] = ACTIONS(1992),
    [anon_sym_using] = ACTIONS(1992),
    [anon_sym_static_assert] = ACTIONS(1992),
    [anon_sym_catch] = ACTIONS(5447),
    [anon_sym___launch_bounds__] = ACTIONS(1992),
  },
  [STATE(1731)] = {
    [sym_catch_clause] = STATE(1733),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1733),
    [sym_identifier] = ACTIONS(1934),
    [aux_sym_preproc_def_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token2] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1934),
    [aux_sym_preproc_else_token1] = ACTIONS(1934),
    [aux_sym_preproc_elif_token1] = ACTIONS(1934),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1934),
    [sym_preproc_directive] = ACTIONS(1934),
    [anon_sym_LPAREN2] = ACTIONS(1936),
    [anon_sym_TILDE] = ACTIONS(1936),
    [anon_sym_STAR] = ACTIONS(1936),
    [anon_sym_AMP_AMP] = ACTIONS(1936),
    [anon_sym_AMP] = ACTIONS(1934),
    [anon_sym_SEMI] = ACTIONS(1936),
    [anon_sym___extension__] = ACTIONS(1934),
    [anon_sym_typedef] = ACTIONS(1934),
    [anon_sym___device__] = ACTIONS(1934),
    [anon_sym___host__] = ACTIONS(1934),
    [anon_sym___global__] = ACTIONS(1934),
    [anon_sym___forceinline__] = ACTIONS(1934),
    [anon_sym___noinline__] = ACTIONS(1934),
    [anon_sym_virtual] = ACTIONS(1934),
    [anon_sym_extern] = ACTIONS(1934),
    [anon_sym___attribute__] = ACTIONS(1934),
    [anon_sym___attribute] = ACTIONS(1934),
    [anon_sym_COLON_COLON] = ACTIONS(1936),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1936),
    [anon_sym___declspec] = ACTIONS(1934),
    [anon_sym___based] = ACTIONS(1934),
    [anon_sym_signed] = ACTIONS(1934),
    [anon_sym_unsigned] = ACTIONS(1934),
    [anon_sym_long] = ACTIONS(1934),
    [anon_sym_short] = ACTIONS(1934),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [anon_sym_static] = ACTIONS(1934),
    [anon_sym_register] = ACTIONS(1934),
    [anon_sym_inline] = ACTIONS(1934),
    [anon_sym___inline] = ACTIONS(1934),
    [anon_sym___inline__] = ACTIONS(1934),
    [anon_sym___forceinline] = ACTIONS(1934),
    [anon_sym_thread_local] = ACTIONS(1934),
    [anon_sym___thread] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1934),
    [anon_sym_constexpr] = ACTIONS(1934),
    [anon_sym_volatile] = ACTIONS(1934),
    [anon_sym_restrict] = ACTIONS(1934),
    [anon_sym___restrict__] = ACTIONS(1934),
    [anon_sym__Atomic] = ACTIONS(1934),
    [anon_sym__Noreturn] = ACTIONS(1934),
    [anon_sym_noreturn] = ACTIONS(1934),
    [anon_sym__Nonnull] = ACTIONS(1934),
    [anon_sym_mutable] = ACTIONS(1934),
    [anon_sym_constinit] = ACTIONS(1934),
    [anon_sym_consteval] = ACTIONS(1934),
    [anon_sym___shared__] = ACTIONS(1934),
    [anon_sym___local__] = ACTIONS(1934),
    [anon_sym___constant__] = ACTIONS(1934),
    [anon_sym___managed__] = ACTIONS(1934),
    [anon_sym___grid_constant__] = ACTIONS(1934),
    [anon_sym_alignas] = ACTIONS(1934),
    [anon_sym__Alignas] = ACTIONS(1934),
    [sym_primitive_type] = ACTIONS(1934),
    [anon_sym_enum] = ACTIONS(1934),
    [anon_sym_class] = ACTIONS(1934),
    [anon_sym_struct] = ACTIONS(1934),
    [anon_sym_union] = ACTIONS(1934),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1934),
    [anon_sym_decltype] = ACTIONS(1934),
    [anon_sym_explicit] = ACTIONS(1934),
    [anon_sym_typename] = ACTIONS(1934),
    [anon_sym_template] = ACTIONS(1934),
    [anon_sym_operator] = ACTIONS(1934),
    [anon_sym_friend] = ACTIONS(1934),
    [anon_sym_public] = ACTIONS(1934),
    [anon_sym_private] = ACTIONS(1934),
    [anon_sym_protected] = ACTIONS(1934),
    [anon_sym_using] = ACTIONS(1934),
    [anon_sym_static_assert] = ACTIONS(1934),
    [anon_sym_catch] = ACTIONS(5447),
    [anon_sym___launch_bounds__] = ACTIONS(1934),
  },
  [STATE(1732)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(8202),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(8202),
    [sym_variadic_parameter_declaration] = STATE(8202),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1846),
    [anon_sym_RPAREN] = ACTIONS(4195),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1733)] = {
    [sym_catch_clause] = STATE(1733),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1733),
    [sym_identifier] = ACTIONS(1940),
    [aux_sym_preproc_def_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token2] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1940),
    [aux_sym_preproc_else_token1] = ACTIONS(1940),
    [aux_sym_preproc_elif_token1] = ACTIONS(1940),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1940),
    [sym_preproc_directive] = ACTIONS(1940),
    [anon_sym_LPAREN2] = ACTIONS(1942),
    [anon_sym_TILDE] = ACTIONS(1942),
    [anon_sym_STAR] = ACTIONS(1942),
    [anon_sym_AMP_AMP] = ACTIONS(1942),
    [anon_sym_AMP] = ACTIONS(1940),
    [anon_sym_SEMI] = ACTIONS(1942),
    [anon_sym___extension__] = ACTIONS(1940),
    [anon_sym_typedef] = ACTIONS(1940),
    [anon_sym___device__] = ACTIONS(1940),
    [anon_sym___host__] = ACTIONS(1940),
    [anon_sym___global__] = ACTIONS(1940),
    [anon_sym___forceinline__] = ACTIONS(1940),
    [anon_sym___noinline__] = ACTIONS(1940),
    [anon_sym_virtual] = ACTIONS(1940),
    [anon_sym_extern] = ACTIONS(1940),
    [anon_sym___attribute__] = ACTIONS(1940),
    [anon_sym___attribute] = ACTIONS(1940),
    [anon_sym_COLON_COLON] = ACTIONS(1942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1942),
    [anon_sym___declspec] = ACTIONS(1940),
    [anon_sym___based] = ACTIONS(1940),
    [anon_sym_signed] = ACTIONS(1940),
    [anon_sym_unsigned] = ACTIONS(1940),
    [anon_sym_long] = ACTIONS(1940),
    [anon_sym_short] = ACTIONS(1940),
    [anon_sym_LBRACK] = ACTIONS(1940),
    [anon_sym_static] = ACTIONS(1940),
    [anon_sym_register] = ACTIONS(1940),
    [anon_sym_inline] = ACTIONS(1940),
    [anon_sym___inline] = ACTIONS(1940),
    [anon_sym___inline__] = ACTIONS(1940),
    [anon_sym___forceinline] = ACTIONS(1940),
    [anon_sym_thread_local] = ACTIONS(1940),
    [anon_sym___thread] = ACTIONS(1940),
    [anon_sym_const] = ACTIONS(1940),
    [anon_sym_constexpr] = ACTIONS(1940),
    [anon_sym_volatile] = ACTIONS(1940),
    [anon_sym_restrict] = ACTIONS(1940),
    [anon_sym___restrict__] = ACTIONS(1940),
    [anon_sym__Atomic] = ACTIONS(1940),
    [anon_sym__Noreturn] = ACTIONS(1940),
    [anon_sym_noreturn] = ACTIONS(1940),
    [anon_sym__Nonnull] = ACTIONS(1940),
    [anon_sym_mutable] = ACTIONS(1940),
    [anon_sym_constinit] = ACTIONS(1940),
    [anon_sym_consteval] = ACTIONS(1940),
    [anon_sym___shared__] = ACTIONS(1940),
    [anon_sym___local__] = ACTIONS(1940),
    [anon_sym___constant__] = ACTIONS(1940),
    [anon_sym___managed__] = ACTIONS(1940),
    [anon_sym___grid_constant__] = ACTIONS(1940),
    [anon_sym_alignas] = ACTIONS(1940),
    [anon_sym__Alignas] = ACTIONS(1940),
    [sym_primitive_type] = ACTIONS(1940),
    [anon_sym_enum] = ACTIONS(1940),
    [anon_sym_class] = ACTIONS(1940),
    [anon_sym_struct] = ACTIONS(1940),
    [anon_sym_union] = ACTIONS(1940),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1940),
    [anon_sym_decltype] = ACTIONS(1940),
    [anon_sym_explicit] = ACTIONS(1940),
    [anon_sym_typename] = ACTIONS(1940),
    [anon_sym_template] = ACTIONS(1940),
    [anon_sym_operator] = ACTIONS(1940),
    [anon_sym_friend] = ACTIONS(1940),
    [anon_sym_public] = ACTIONS(1940),
    [anon_sym_private] = ACTIONS(1940),
    [anon_sym_protected] = ACTIONS(1940),
    [anon_sym_using] = ACTIONS(1940),
    [anon_sym_static_assert] = ACTIONS(1940),
    [anon_sym_catch] = ACTIONS(5460),
    [anon_sym___launch_bounds__] = ACTIONS(1940),
  },
  [STATE(1734)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1734),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(5457),
    [anon_sym_unsigned] = ACTIONS(5457),
    [anon_sym_long] = ACTIONS(5457),
    [anon_sym_short] = ACTIONS(5457),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5135),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_and_eq] = ACTIONS(5133),
    [anon_sym_or_eq] = ACTIONS(5133),
    [anon_sym_xor_eq] = ACTIONS(5133),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5135),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
  },
  [STATE(1735)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(7773),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(7773),
    [sym_variadic_parameter_declaration] = STATE(7773),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_RPAREN] = ACTIONS(1784),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1736)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1741),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5351),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5351),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5351),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5351),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5463),
    [anon_sym_unsigned] = ACTIONS(5463),
    [anon_sym_long] = ACTIONS(5463),
    [anon_sym_short] = ACTIONS(5463),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_EQ] = ACTIONS(5351),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_STAR_EQ] = ACTIONS(5354),
    [anon_sym_SLASH_EQ] = ACTIONS(5354),
    [anon_sym_PERCENT_EQ] = ACTIONS(5354),
    [anon_sym_PLUS_EQ] = ACTIONS(5354),
    [anon_sym_DASH_EQ] = ACTIONS(5354),
    [anon_sym_LT_LT_EQ] = ACTIONS(5354),
    [anon_sym_GT_GT_EQ] = ACTIONS(5354),
    [anon_sym_AMP_EQ] = ACTIONS(5354),
    [anon_sym_CARET_EQ] = ACTIONS(5354),
    [anon_sym_PIPE_EQ] = ACTIONS(5354),
    [anon_sym_and_eq] = ACTIONS(5351),
    [anon_sym_or_eq] = ACTIONS(5351),
    [anon_sym_xor_eq] = ACTIONS(5351),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5354),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5354),
  },
  [STATE(1737)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_RPAREN] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1969),
    [anon_sym_PIPE_PIPE] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1959),
    [anon_sym_BANG_EQ] = ACTIONS(1959),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1959),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(1959),
    [anon_sym_STAR_EQ] = ACTIONS(1959),
    [anon_sym_SLASH_EQ] = ACTIONS(1959),
    [anon_sym_PERCENT_EQ] = ACTIONS(1959),
    [anon_sym_PLUS_EQ] = ACTIONS(1959),
    [anon_sym_DASH_EQ] = ACTIONS(1959),
    [anon_sym_LT_LT_EQ] = ACTIONS(1959),
    [anon_sym_GT_GT_EQ] = ACTIONS(1959),
    [anon_sym_AMP_EQ] = ACTIONS(1959),
    [anon_sym_CARET_EQ] = ACTIONS(1959),
    [anon_sym_PIPE_EQ] = ACTIONS(1959),
    [anon_sym_and_eq] = ACTIONS(1969),
    [anon_sym_or_eq] = ACTIONS(1969),
    [anon_sym_xor_eq] = ACTIONS(1969),
    [anon_sym_LT_EQ_GT] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1959),
    [anon_sym_DASH_GT] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1959),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1959),
  },
  [STATE(1738)] = {
    [sym_type_qualifier] = STATE(1738),
    [sym_alignas_qualifier] = STATE(1873),
    [aux_sym__type_definition_type_repeat1] = STATE(1738),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_RPAREN] = ACTIONS(5112),
    [aux_sym_preproc_if_token2] = ACTIONS(5112),
    [aux_sym_preproc_else_token1] = ACTIONS(5112),
    [aux_sym_preproc_elif_token1] = ACTIONS(5110),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5112),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_DASH] = ACTIONS(5110),
    [anon_sym_PLUS] = ACTIONS(5110),
    [anon_sym_STAR] = ACTIONS(5112),
    [anon_sym_SLASH] = ACTIONS(5110),
    [anon_sym_PERCENT] = ACTIONS(5112),
    [anon_sym_PIPE_PIPE] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_PIPE] = ACTIONS(5110),
    [anon_sym_CARET] = ACTIONS(5112),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_EQ_EQ] = ACTIONS(5112),
    [anon_sym_BANG_EQ] = ACTIONS(5112),
    [anon_sym_GT] = ACTIONS(5110),
    [anon_sym_GT_EQ] = ACTIONS(5112),
    [anon_sym_LT_EQ] = ACTIONS(5110),
    [anon_sym_LT] = ACTIONS(5110),
    [anon_sym_LT_LT] = ACTIONS(5110),
    [anon_sym_GT_GT] = ACTIONS(5112),
    [anon_sym_SEMI] = ACTIONS(5112),
    [anon_sym___extension__] = ACTIONS(5466),
    [anon_sym___global__] = ACTIONS(5466),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_RBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5112),
    [anon_sym_RBRACK] = ACTIONS(5112),
    [anon_sym_const] = ACTIONS(5466),
    [anon_sym_constexpr] = ACTIONS(5466),
    [anon_sym_volatile] = ACTIONS(5466),
    [anon_sym_restrict] = ACTIONS(5466),
    [anon_sym___restrict__] = ACTIONS(5466),
    [anon_sym__Atomic] = ACTIONS(5466),
    [anon_sym__Noreturn] = ACTIONS(5466),
    [anon_sym_noreturn] = ACTIONS(5466),
    [anon_sym__Nonnull] = ACTIONS(5466),
    [anon_sym_mutable] = ACTIONS(5466),
    [anon_sym_constinit] = ACTIONS(5466),
    [anon_sym_consteval] = ACTIONS(5466),
    [anon_sym___shared__] = ACTIONS(5466),
    [anon_sym___local__] = ACTIONS(5466),
    [anon_sym___constant__] = ACTIONS(5466),
    [anon_sym___managed__] = ACTIONS(5466),
    [anon_sym___grid_constant__] = ACTIONS(5466),
    [anon_sym_alignas] = ACTIONS(5469),
    [anon_sym__Alignas] = ACTIONS(5469),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_COLON] = ACTIONS(5112),
    [anon_sym_QMARK] = ACTIONS(5112),
    [anon_sym_LT_EQ_GT] = ACTIONS(5112),
    [anon_sym_or] = ACTIONS(5110),
    [anon_sym_and] = ACTIONS(5110),
    [anon_sym_bitor] = ACTIONS(5110),
    [anon_sym_xor] = ACTIONS(5110),
    [anon_sym_bitand] = ACTIONS(5110),
    [anon_sym_not_eq] = ACTIONS(5110),
    [anon_sym_DASH_DASH] = ACTIONS(5112),
    [anon_sym_PLUS_PLUS] = ACTIONS(5112),
    [anon_sym_DOT] = ACTIONS(5110),
    [anon_sym_DOT_STAR] = ACTIONS(5112),
    [anon_sym_DASH_GT] = ACTIONS(5112),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [anon_sym_final] = ACTIONS(5110),
    [anon_sym_override] = ACTIONS(5110),
    [anon_sym_requires] = ACTIONS(5110),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5112),
  },
  [STATE(1739)] = {
    [sym_type_qualifier] = STATE(1739),
    [sym_alignas_qualifier] = STATE(1886),
    [aux_sym__type_definition_type_repeat1] = STATE(1739),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_RPAREN] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_DASH] = ACTIONS(5110),
    [anon_sym_PLUS] = ACTIONS(5110),
    [anon_sym_STAR] = ACTIONS(5110),
    [anon_sym_SLASH] = ACTIONS(5110),
    [anon_sym_PERCENT] = ACTIONS(5110),
    [anon_sym_PIPE_PIPE] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_PIPE] = ACTIONS(5110),
    [anon_sym_CARET] = ACTIONS(5110),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_EQ_EQ] = ACTIONS(5112),
    [anon_sym_BANG_EQ] = ACTIONS(5112),
    [anon_sym_GT] = ACTIONS(5110),
    [anon_sym_GT_EQ] = ACTIONS(5112),
    [anon_sym_LT_EQ] = ACTIONS(5110),
    [anon_sym_LT] = ACTIONS(5110),
    [anon_sym_LT_LT] = ACTIONS(5110),
    [anon_sym_GT_GT] = ACTIONS(5110),
    [anon_sym___extension__] = ACTIONS(5472),
    [anon_sym___global__] = ACTIONS(5472),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5112),
    [anon_sym_EQ] = ACTIONS(5110),
    [anon_sym_const] = ACTIONS(5472),
    [anon_sym_constexpr] = ACTIONS(5472),
    [anon_sym_volatile] = ACTIONS(5472),
    [anon_sym_restrict] = ACTIONS(5472),
    [anon_sym___restrict__] = ACTIONS(5472),
    [anon_sym__Atomic] = ACTIONS(5472),
    [anon_sym__Noreturn] = ACTIONS(5472),
    [anon_sym_noreturn] = ACTIONS(5472),
    [anon_sym__Nonnull] = ACTIONS(5472),
    [anon_sym_mutable] = ACTIONS(5472),
    [anon_sym_constinit] = ACTIONS(5472),
    [anon_sym_consteval] = ACTIONS(5472),
    [anon_sym___shared__] = ACTIONS(5472),
    [anon_sym___local__] = ACTIONS(5472),
    [anon_sym___constant__] = ACTIONS(5472),
    [anon_sym___managed__] = ACTIONS(5472),
    [anon_sym___grid_constant__] = ACTIONS(5472),
    [anon_sym_alignas] = ACTIONS(5475),
    [anon_sym__Alignas] = ACTIONS(5475),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_QMARK] = ACTIONS(5112),
    [anon_sym_STAR_EQ] = ACTIONS(5112),
    [anon_sym_SLASH_EQ] = ACTIONS(5112),
    [anon_sym_PERCENT_EQ] = ACTIONS(5112),
    [anon_sym_PLUS_EQ] = ACTIONS(5112),
    [anon_sym_DASH_EQ] = ACTIONS(5112),
    [anon_sym_LT_LT_EQ] = ACTIONS(5112),
    [anon_sym_GT_GT_EQ] = ACTIONS(5112),
    [anon_sym_AMP_EQ] = ACTIONS(5112),
    [anon_sym_CARET_EQ] = ACTIONS(5112),
    [anon_sym_PIPE_EQ] = ACTIONS(5112),
    [anon_sym_LT_EQ_GT] = ACTIONS(5112),
    [anon_sym_or] = ACTIONS(5110),
    [anon_sym_and] = ACTIONS(5110),
    [anon_sym_bitor] = ACTIONS(5110),
    [anon_sym_xor] = ACTIONS(5110),
    [anon_sym_bitand] = ACTIONS(5110),
    [anon_sym_not_eq] = ACTIONS(5110),
    [anon_sym_DASH_DASH] = ACTIONS(5112),
    [anon_sym_PLUS_PLUS] = ACTIONS(5112),
    [anon_sym_DOT] = ACTIONS(5110),
    [anon_sym_DOT_STAR] = ACTIONS(5112),
    [anon_sym_DASH_GT] = ACTIONS(5110),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5112),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5112),
  },
  [STATE(1740)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(8231),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(8231),
    [sym_variadic_parameter_declaration] = STATE(8231),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5478),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1741)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1741),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(5463),
    [anon_sym_unsigned] = ACTIONS(5463),
    [anon_sym_long] = ACTIONS(5463),
    [anon_sym_short] = ACTIONS(5463),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5135),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_and_eq] = ACTIONS(5133),
    [anon_sym_or_eq] = ACTIONS(5133),
    [anon_sym_xor_eq] = ACTIONS(5133),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5135),
  },
  [STATE(1742)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_RPAREN] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5143),
    [anon_sym_SLASH] = ACTIONS(5143),
    [anon_sym_PERCENT] = ACTIONS(5143),
    [anon_sym_PIPE_PIPE] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_PIPE] = ACTIONS(5143),
    [anon_sym_CARET] = ACTIONS(5143),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_GT] = ACTIONS(5143),
    [anon_sym_GT_EQ] = ACTIONS(5145),
    [anon_sym_LT_EQ] = ACTIONS(5143),
    [anon_sym_LT] = ACTIONS(5143),
    [anon_sym_LT_LT] = ACTIONS(5143),
    [anon_sym_GT_GT] = ACTIONS(5143),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_EQ] = ACTIONS(5143),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_STAR_EQ] = ACTIONS(5145),
    [anon_sym_SLASH_EQ] = ACTIONS(5145),
    [anon_sym_PERCENT_EQ] = ACTIONS(5145),
    [anon_sym_PLUS_EQ] = ACTIONS(5145),
    [anon_sym_DASH_EQ] = ACTIONS(5145),
    [anon_sym_LT_LT_EQ] = ACTIONS(5145),
    [anon_sym_GT_GT_EQ] = ACTIONS(5145),
    [anon_sym_AMP_EQ] = ACTIONS(5145),
    [anon_sym_CARET_EQ] = ACTIONS(5145),
    [anon_sym_PIPE_EQ] = ACTIONS(5145),
    [anon_sym_and_eq] = ACTIONS(5143),
    [anon_sym_or_eq] = ACTIONS(5143),
    [anon_sym_xor_eq] = ACTIONS(5143),
    [anon_sym_LT_EQ_GT] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5143),
    [anon_sym_and] = ACTIONS(5143),
    [anon_sym_bitor] = ACTIONS(5143),
    [anon_sym_xor] = ACTIONS(5143),
    [anon_sym_bitand] = ACTIONS(5143),
    [anon_sym_not_eq] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5143),
    [anon_sym_DOT_STAR] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5143),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5145),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5145),
  },
  [STATE(1743)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1744),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5351),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5351),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5351),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5351),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5351),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5480),
    [anon_sym_unsigned] = ACTIONS(5480),
    [anon_sym_long] = ACTIONS(5480),
    [anon_sym_short] = ACTIONS(5480),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_EQ] = ACTIONS(5351),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_STAR_EQ] = ACTIONS(5354),
    [anon_sym_SLASH_EQ] = ACTIONS(5354),
    [anon_sym_PERCENT_EQ] = ACTIONS(5354),
    [anon_sym_PLUS_EQ] = ACTIONS(5354),
    [anon_sym_DASH_EQ] = ACTIONS(5354),
    [anon_sym_LT_LT_EQ] = ACTIONS(5354),
    [anon_sym_GT_GT_EQ] = ACTIONS(5351),
    [anon_sym_AMP_EQ] = ACTIONS(5354),
    [anon_sym_CARET_EQ] = ACTIONS(5354),
    [anon_sym_PIPE_EQ] = ACTIONS(5354),
    [anon_sym_and_eq] = ACTIONS(5351),
    [anon_sym_or_eq] = ACTIONS(5351),
    [anon_sym_xor_eq] = ACTIONS(5351),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5354),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [anon_sym_GT2] = ACTIONS(5354),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
  },
  [STATE(1744)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1744),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5133),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(5480),
    [anon_sym_unsigned] = ACTIONS(5480),
    [anon_sym_long] = ACTIONS(5480),
    [anon_sym_short] = ACTIONS(5480),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5133),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_and_eq] = ACTIONS(5133),
    [anon_sym_or_eq] = ACTIONS(5133),
    [anon_sym_xor_eq] = ACTIONS(5133),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_GT2] = ACTIONS(5135),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
  },
  [STATE(1745)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6889),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7404),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7404),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1746)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6840),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7385),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7385),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1747)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6814),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7393),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7393),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1748)] = {
    [sym__declaration_modifiers] = STATE(1907),
    [sym__declaration_specifiers] = STATE(4530),
    [sym_attribute_specifier] = STATE(1907),
    [sym_attribute_declaration] = STATE(1907),
    [sym_ms_declspec_modifier] = STATE(1907),
    [sym_storage_class_specifier] = STATE(1907),
    [sym_type_qualifier] = STATE(1907),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_parameter_declaration] = STATE(8216),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_optional_parameter_declaration] = STATE(8216),
    [sym_variadic_parameter_declaration] = STATE(8216),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1907),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1907),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1796),
    [anon_sym___host__] = ACTIONS(1796),
    [anon_sym___global__] = ACTIONS(1796),
    [anon_sym___forceinline__] = ACTIONS(1796),
    [anon_sym___noinline__] = ACTIONS(1796),
    [anon_sym_virtual] = ACTIONS(1796),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1749)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6938),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7424),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7424),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1750)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [aux_sym_preproc_else_token1] = ACTIONS(1932),
    [aux_sym_preproc_elif_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_catch] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1751)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6832),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7424),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7424),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1752)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5143),
    [anon_sym_SLASH] = ACTIONS(5143),
    [anon_sym_PERCENT] = ACTIONS(5143),
    [anon_sym_PIPE_PIPE] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_PIPE] = ACTIONS(5143),
    [anon_sym_CARET] = ACTIONS(5143),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_GT] = ACTIONS(5143),
    [anon_sym_GT_EQ] = ACTIONS(5145),
    [anon_sym_LT_EQ] = ACTIONS(5143),
    [anon_sym_LT] = ACTIONS(5143),
    [anon_sym_LT_LT] = ACTIONS(5143),
    [anon_sym_GT_GT] = ACTIONS(5143),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_EQ] = ACTIONS(5143),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_STAR_EQ] = ACTIONS(5145),
    [anon_sym_SLASH_EQ] = ACTIONS(5145),
    [anon_sym_PERCENT_EQ] = ACTIONS(5145),
    [anon_sym_PLUS_EQ] = ACTIONS(5145),
    [anon_sym_DASH_EQ] = ACTIONS(5145),
    [anon_sym_LT_LT_EQ] = ACTIONS(5145),
    [anon_sym_GT_GT_EQ] = ACTIONS(5145),
    [anon_sym_AMP_EQ] = ACTIONS(5145),
    [anon_sym_CARET_EQ] = ACTIONS(5145),
    [anon_sym_PIPE_EQ] = ACTIONS(5145),
    [anon_sym_and_eq] = ACTIONS(5143),
    [anon_sym_or_eq] = ACTIONS(5143),
    [anon_sym_xor_eq] = ACTIONS(5143),
    [anon_sym_LT_EQ_GT] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5143),
    [anon_sym_and] = ACTIONS(5143),
    [anon_sym_bitor] = ACTIONS(5143),
    [anon_sym_xor] = ACTIONS(5143),
    [anon_sym_bitand] = ACTIONS(5143),
    [anon_sym_not_eq] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5143),
    [anon_sym_DOT_STAR] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5145),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5145),
  },
  [STATE(1753)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6952),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7404),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7404),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1754)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1969),
    [anon_sym_PIPE_PIPE] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1959),
    [anon_sym_BANG_EQ] = ACTIONS(1959),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1969),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(1959),
    [anon_sym_STAR_EQ] = ACTIONS(1959),
    [anon_sym_SLASH_EQ] = ACTIONS(1959),
    [anon_sym_PERCENT_EQ] = ACTIONS(1959),
    [anon_sym_PLUS_EQ] = ACTIONS(1959),
    [anon_sym_DASH_EQ] = ACTIONS(1959),
    [anon_sym_LT_LT_EQ] = ACTIONS(1959),
    [anon_sym_GT_GT_EQ] = ACTIONS(1969),
    [anon_sym_AMP_EQ] = ACTIONS(1959),
    [anon_sym_CARET_EQ] = ACTIONS(1959),
    [anon_sym_PIPE_EQ] = ACTIONS(1959),
    [anon_sym_and_eq] = ACTIONS(1969),
    [anon_sym_or_eq] = ACTIONS(1969),
    [anon_sym_xor_eq] = ACTIONS(1969),
    [anon_sym_LT_EQ_GT] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1959),
    [anon_sym_DASH_GT] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_GT2] = ACTIONS(1959),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1959),
  },
  [STATE(1755)] = {
    [sym_identifier] = ACTIONS(1928),
    [aux_sym_preproc_def_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token2] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1928),
    [aux_sym_preproc_else_token1] = ACTIONS(1928),
    [aux_sym_preproc_elif_token1] = ACTIONS(1928),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1928),
    [sym_preproc_directive] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_AMP_AMP] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1928),
    [anon_sym_SEMI] = ACTIONS(1926),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym_typedef] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym___based] = ACTIONS(1928),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_explicit] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_operator] = ACTIONS(1928),
    [anon_sym_friend] = ACTIONS(1928),
    [anon_sym_public] = ACTIONS(1928),
    [anon_sym_private] = ACTIONS(1928),
    [anon_sym_protected] = ACTIONS(1928),
    [anon_sym_using] = ACTIONS(1928),
    [anon_sym_static_assert] = ACTIONS(1928),
    [anon_sym_catch] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(1756)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6945),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7426),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7426),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1757)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6877),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7405),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7405),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1758)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6831),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7426),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7426),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1759)] = {
    [sym_identifier] = ACTIONS(2006),
    [aux_sym_preproc_def_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token2] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2006),
    [aux_sym_preproc_else_token1] = ACTIONS(2006),
    [aux_sym_preproc_elif_token1] = ACTIONS(2006),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2006),
    [sym_preproc_directive] = ACTIONS(2006),
    [anon_sym_LPAREN2] = ACTIONS(2008),
    [anon_sym_TILDE] = ACTIONS(2008),
    [anon_sym_STAR] = ACTIONS(2008),
    [anon_sym_AMP_AMP] = ACTIONS(2008),
    [anon_sym_AMP] = ACTIONS(2006),
    [anon_sym_SEMI] = ACTIONS(2008),
    [anon_sym___extension__] = ACTIONS(2006),
    [anon_sym_typedef] = ACTIONS(2006),
    [anon_sym___device__] = ACTIONS(2006),
    [anon_sym___host__] = ACTIONS(2006),
    [anon_sym___global__] = ACTIONS(2006),
    [anon_sym___forceinline__] = ACTIONS(2006),
    [anon_sym___noinline__] = ACTIONS(2006),
    [anon_sym_virtual] = ACTIONS(2006),
    [anon_sym_extern] = ACTIONS(2006),
    [anon_sym___attribute__] = ACTIONS(2006),
    [anon_sym___attribute] = ACTIONS(2006),
    [anon_sym_COLON_COLON] = ACTIONS(2008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2008),
    [anon_sym___declspec] = ACTIONS(2006),
    [anon_sym___based] = ACTIONS(2006),
    [anon_sym_signed] = ACTIONS(2006),
    [anon_sym_unsigned] = ACTIONS(2006),
    [anon_sym_long] = ACTIONS(2006),
    [anon_sym_short] = ACTIONS(2006),
    [anon_sym_LBRACK] = ACTIONS(2006),
    [anon_sym_static] = ACTIONS(2006),
    [anon_sym_register] = ACTIONS(2006),
    [anon_sym_inline] = ACTIONS(2006),
    [anon_sym___inline] = ACTIONS(2006),
    [anon_sym___inline__] = ACTIONS(2006),
    [anon_sym___forceinline] = ACTIONS(2006),
    [anon_sym_thread_local] = ACTIONS(2006),
    [anon_sym___thread] = ACTIONS(2006),
    [anon_sym_const] = ACTIONS(2006),
    [anon_sym_constexpr] = ACTIONS(2006),
    [anon_sym_volatile] = ACTIONS(2006),
    [anon_sym_restrict] = ACTIONS(2006),
    [anon_sym___restrict__] = ACTIONS(2006),
    [anon_sym__Atomic] = ACTIONS(2006),
    [anon_sym__Noreturn] = ACTIONS(2006),
    [anon_sym_noreturn] = ACTIONS(2006),
    [anon_sym__Nonnull] = ACTIONS(2006),
    [anon_sym_mutable] = ACTIONS(2006),
    [anon_sym_constinit] = ACTIONS(2006),
    [anon_sym_consteval] = ACTIONS(2006),
    [anon_sym___shared__] = ACTIONS(2006),
    [anon_sym___local__] = ACTIONS(2006),
    [anon_sym___constant__] = ACTIONS(2006),
    [anon_sym___managed__] = ACTIONS(2006),
    [anon_sym___grid_constant__] = ACTIONS(2006),
    [anon_sym_alignas] = ACTIONS(2006),
    [anon_sym__Alignas] = ACTIONS(2006),
    [sym_primitive_type] = ACTIONS(2006),
    [anon_sym_enum] = ACTIONS(2006),
    [anon_sym_class] = ACTIONS(2006),
    [anon_sym_struct] = ACTIONS(2006),
    [anon_sym_union] = ACTIONS(2006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2006),
    [anon_sym_decltype] = ACTIONS(2006),
    [anon_sym_explicit] = ACTIONS(2006),
    [anon_sym_typename] = ACTIONS(2006),
    [anon_sym_template] = ACTIONS(2006),
    [anon_sym_operator] = ACTIONS(2006),
    [anon_sym_friend] = ACTIONS(2006),
    [anon_sym_public] = ACTIONS(2006),
    [anon_sym_private] = ACTIONS(2006),
    [anon_sym_protected] = ACTIONS(2006),
    [anon_sym_using] = ACTIONS(2006),
    [anon_sym_static_assert] = ACTIONS(2006),
    [anon_sym_catch] = ACTIONS(2006),
    [anon_sym___launch_bounds__] = ACTIONS(2006),
  },
  [STATE(1760)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6888),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7421),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7421),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1761)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5143),
    [anon_sym_SLASH] = ACTIONS(5143),
    [anon_sym_PERCENT] = ACTIONS(5143),
    [anon_sym_PIPE_PIPE] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_PIPE] = ACTIONS(5143),
    [anon_sym_CARET] = ACTIONS(5143),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_GT] = ACTIONS(5143),
    [anon_sym_GT_EQ] = ACTIONS(5143),
    [anon_sym_LT_EQ] = ACTIONS(5143),
    [anon_sym_LT] = ACTIONS(5143),
    [anon_sym_LT_LT] = ACTIONS(5143),
    [anon_sym_GT_GT] = ACTIONS(5143),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_EQ] = ACTIONS(5143),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_STAR_EQ] = ACTIONS(5145),
    [anon_sym_SLASH_EQ] = ACTIONS(5145),
    [anon_sym_PERCENT_EQ] = ACTIONS(5145),
    [anon_sym_PLUS_EQ] = ACTIONS(5145),
    [anon_sym_DASH_EQ] = ACTIONS(5145),
    [anon_sym_LT_LT_EQ] = ACTIONS(5145),
    [anon_sym_GT_GT_EQ] = ACTIONS(5143),
    [anon_sym_AMP_EQ] = ACTIONS(5145),
    [anon_sym_CARET_EQ] = ACTIONS(5145),
    [anon_sym_PIPE_EQ] = ACTIONS(5145),
    [anon_sym_and_eq] = ACTIONS(5143),
    [anon_sym_or_eq] = ACTIONS(5143),
    [anon_sym_xor_eq] = ACTIONS(5143),
    [anon_sym_LT_EQ_GT] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5143),
    [anon_sym_and] = ACTIONS(5143),
    [anon_sym_bitor] = ACTIONS(5143),
    [anon_sym_xor] = ACTIONS(5143),
    [anon_sym_bitand] = ACTIONS(5143),
    [anon_sym_not_eq] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5143),
    [anon_sym_DOT_STAR] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [anon_sym_GT2] = ACTIONS(5145),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5145),
  },
  [STATE(1762)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [aux_sym_preproc_else_token1] = ACTIONS(1932),
    [aux_sym_preproc_elif_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(5503),
    [anon_sym___attribute] = ACTIONS(5503),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1763)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1969),
    [anon_sym_PIPE_PIPE] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1959),
    [anon_sym_BANG_EQ] = ACTIONS(1959),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1959),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(1959),
    [anon_sym_STAR_EQ] = ACTIONS(1959),
    [anon_sym_SLASH_EQ] = ACTIONS(1959),
    [anon_sym_PERCENT_EQ] = ACTIONS(1959),
    [anon_sym_PLUS_EQ] = ACTIONS(1959),
    [anon_sym_DASH_EQ] = ACTIONS(1959),
    [anon_sym_LT_LT_EQ] = ACTIONS(1959),
    [anon_sym_GT_GT_EQ] = ACTIONS(1959),
    [anon_sym_AMP_EQ] = ACTIONS(1959),
    [anon_sym_CARET_EQ] = ACTIONS(1959),
    [anon_sym_PIPE_EQ] = ACTIONS(1959),
    [anon_sym_and_eq] = ACTIONS(1969),
    [anon_sym_or_eq] = ACTIONS(1969),
    [anon_sym_xor_eq] = ACTIONS(1969),
    [anon_sym_LT_EQ_GT] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1959),
    [anon_sym_DASH_GT] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1959),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(1959),
  },
  [STATE(1764)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_ms_based_modifier] = STATE(9004),
    [sym__declarator] = STATE(7339),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_function_declarator] = STATE(6917),
    [sym_array_declarator] = STATE(6660),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype] = STATE(9247),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym_operator_cast] = STATE(7385),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_reference_declarator] = STATE(6660),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6126),
    [sym_qualified_identifier] = STATE(6660),
    [sym_qualified_operator_cast_identifier] = STATE(7385),
    [sym_operator_name] = STATE(6660),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_LPAREN2] = ACTIONS(2256),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5487),
    [anon_sym___host__] = ACTIONS(5487),
    [anon_sym___global__] = ACTIONS(5487),
    [anon_sym___forceinline__] = ACTIONS(5487),
    [anon_sym___noinline__] = ACTIONS(5487),
    [anon_sym_virtual] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_explicit] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(133),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(1765)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [aux_sym_preproc_else_token1] = ACTIONS(1932),
    [aux_sym_preproc_elif_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1766)] = {
    [sym_identifier] = ACTIONS(2373),
    [aux_sym_preproc_def_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token2] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2373),
    [aux_sym_preproc_else_token1] = ACTIONS(2373),
    [aux_sym_preproc_elif_token1] = ACTIONS(2373),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2373),
    [sym_preproc_directive] = ACTIONS(2373),
    [anon_sym_LPAREN2] = ACTIONS(2375),
    [anon_sym_TILDE] = ACTIONS(2375),
    [anon_sym_STAR] = ACTIONS(2375),
    [anon_sym_AMP_AMP] = ACTIONS(2375),
    [anon_sym_AMP] = ACTIONS(2373),
    [anon_sym_SEMI] = ACTIONS(2375),
    [anon_sym___extension__] = ACTIONS(2373),
    [anon_sym_typedef] = ACTIONS(2373),
    [anon_sym___device__] = ACTIONS(2373),
    [anon_sym___host__] = ACTIONS(2373),
    [anon_sym___global__] = ACTIONS(2373),
    [anon_sym___forceinline__] = ACTIONS(2373),
    [anon_sym___noinline__] = ACTIONS(2373),
    [anon_sym_virtual] = ACTIONS(2373),
    [anon_sym_extern] = ACTIONS(2373),
    [anon_sym___attribute__] = ACTIONS(2373),
    [anon_sym___attribute] = ACTIONS(2373),
    [anon_sym_COLON_COLON] = ACTIONS(2375),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2375),
    [anon_sym___declspec] = ACTIONS(2373),
    [anon_sym___based] = ACTIONS(2373),
    [anon_sym_signed] = ACTIONS(2373),
    [anon_sym_unsigned] = ACTIONS(2373),
    [anon_sym_long] = ACTIONS(2373),
    [anon_sym_short] = ACTIONS(2373),
    [anon_sym_LBRACK] = ACTIONS(2373),
    [anon_sym_static] = ACTIONS(2373),
    [anon_sym_register] = ACTIONS(2373),
    [anon_sym_inline] = ACTIONS(2373),
    [anon_sym___inline] = ACTIONS(2373),
    [anon_sym___inline__] = ACTIONS(2373),
    [anon_sym___forceinline] = ACTIONS(2373),
    [anon_sym_thread_local] = ACTIONS(2373),
    [anon_sym___thread] = ACTIONS(2373),
    [anon_sym_const] = ACTIONS(2373),
    [anon_sym_constexpr] = ACTIONS(2373),
    [anon_sym_volatile] = ACTIONS(2373),
    [anon_sym_restrict] = ACTIONS(2373),
    [anon_sym___restrict__] = ACTIONS(2373),
    [anon_sym__Atomic] = ACTIONS(2373),
    [anon_sym__Noreturn] = ACTIONS(2373),
    [anon_sym_noreturn] = ACTIONS(2373),
    [anon_sym__Nonnull] = ACTIONS(2373),
    [anon_sym_mutable] = ACTIONS(2373),
    [anon_sym_constinit] = ACTIONS(2373),
    [anon_sym_consteval] = ACTIONS(2373),
    [anon_sym___shared__] = ACTIONS(2373),
    [anon_sym___local__] = ACTIONS(2373),
    [anon_sym___constant__] = ACTIONS(2373),
    [anon_sym___managed__] = ACTIONS(2373),
    [anon_sym___grid_constant__] = ACTIONS(2373),
    [anon_sym_alignas] = ACTIONS(2373),
    [anon_sym__Alignas] = ACTIONS(2373),
    [sym_primitive_type] = ACTIONS(2373),
    [anon_sym_enum] = ACTIONS(2373),
    [anon_sym_class] = ACTIONS(2373),
    [anon_sym_struct] = ACTIONS(2373),
    [anon_sym_union] = ACTIONS(2373),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2373),
    [anon_sym_decltype] = ACTIONS(2373),
    [anon_sym_explicit] = ACTIONS(2373),
    [anon_sym_typename] = ACTIONS(2373),
    [anon_sym_template] = ACTIONS(2373),
    [anon_sym_operator] = ACTIONS(2373),
    [anon_sym_friend] = ACTIONS(2373),
    [anon_sym_public] = ACTIONS(2373),
    [anon_sym_private] = ACTIONS(2373),
    [anon_sym_protected] = ACTIONS(2373),
    [anon_sym_using] = ACTIONS(2373),
    [anon_sym_static_assert] = ACTIONS(2373),
    [anon_sym___launch_bounds__] = ACTIONS(2373),
  },
  [STATE(1767)] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token2] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [aux_sym_preproc_else_token1] = ACTIONS(2383),
    [aux_sym_preproc_elif_token1] = ACTIONS(2383),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2385),
    [anon_sym_TILDE] = ACTIONS(2385),
    [anon_sym_STAR] = ACTIONS(2385),
    [anon_sym_AMP_AMP] = ACTIONS(2385),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym___device__] = ACTIONS(2383),
    [anon_sym___host__] = ACTIONS(2383),
    [anon_sym___global__] = ACTIONS(2383),
    [anon_sym___forceinline__] = ACTIONS(2383),
    [anon_sym___noinline__] = ACTIONS(2383),
    [anon_sym_virtual] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym___attribute] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2385),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2385),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym__Nonnull] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym___shared__] = ACTIONS(2383),
    [anon_sym___local__] = ACTIONS(2383),
    [anon_sym___constant__] = ACTIONS(2383),
    [anon_sym___managed__] = ACTIONS(2383),
    [anon_sym___grid_constant__] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_friend] = ACTIONS(2383),
    [anon_sym_public] = ACTIONS(2383),
    [anon_sym_private] = ACTIONS(2383),
    [anon_sym_protected] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym___launch_bounds__] = ACTIONS(2383),
  },
  [STATE(1768)] = {
    [sym_identifier] = ACTIONS(2617),
    [aux_sym_preproc_def_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token2] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2617),
    [aux_sym_preproc_else_token1] = ACTIONS(2617),
    [aux_sym_preproc_elif_token1] = ACTIONS(2617),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2617),
    [sym_preproc_directive] = ACTIONS(2617),
    [anon_sym_LPAREN2] = ACTIONS(2619),
    [anon_sym_TILDE] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_AMP_AMP] = ACTIONS(2619),
    [anon_sym_AMP] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2619),
    [anon_sym___extension__] = ACTIONS(2617),
    [anon_sym_typedef] = ACTIONS(2617),
    [anon_sym___device__] = ACTIONS(2617),
    [anon_sym___host__] = ACTIONS(2617),
    [anon_sym___global__] = ACTIONS(2617),
    [anon_sym___forceinline__] = ACTIONS(2617),
    [anon_sym___noinline__] = ACTIONS(2617),
    [anon_sym_virtual] = ACTIONS(2617),
    [anon_sym_extern] = ACTIONS(2617),
    [anon_sym___attribute__] = ACTIONS(2617),
    [anon_sym___attribute] = ACTIONS(2617),
    [anon_sym_COLON_COLON] = ACTIONS(2619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2619),
    [anon_sym___declspec] = ACTIONS(2617),
    [anon_sym___based] = ACTIONS(2617),
    [anon_sym_signed] = ACTIONS(2617),
    [anon_sym_unsigned] = ACTIONS(2617),
    [anon_sym_long] = ACTIONS(2617),
    [anon_sym_short] = ACTIONS(2617),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2617),
    [anon_sym_register] = ACTIONS(2617),
    [anon_sym_inline] = ACTIONS(2617),
    [anon_sym___inline] = ACTIONS(2617),
    [anon_sym___inline__] = ACTIONS(2617),
    [anon_sym___forceinline] = ACTIONS(2617),
    [anon_sym_thread_local] = ACTIONS(2617),
    [anon_sym___thread] = ACTIONS(2617),
    [anon_sym_const] = ACTIONS(2617),
    [anon_sym_constexpr] = ACTIONS(2617),
    [anon_sym_volatile] = ACTIONS(2617),
    [anon_sym_restrict] = ACTIONS(2617),
    [anon_sym___restrict__] = ACTIONS(2617),
    [anon_sym__Atomic] = ACTIONS(2617),
    [anon_sym__Noreturn] = ACTIONS(2617),
    [anon_sym_noreturn] = ACTIONS(2617),
    [anon_sym__Nonnull] = ACTIONS(2617),
    [anon_sym_mutable] = ACTIONS(2617),
    [anon_sym_constinit] = ACTIONS(2617),
    [anon_sym_consteval] = ACTIONS(2617),
    [anon_sym___shared__] = ACTIONS(2617),
    [anon_sym___local__] = ACTIONS(2617),
    [anon_sym___constant__] = ACTIONS(2617),
    [anon_sym___managed__] = ACTIONS(2617),
    [anon_sym___grid_constant__] = ACTIONS(2617),
    [anon_sym_alignas] = ACTIONS(2617),
    [anon_sym__Alignas] = ACTIONS(2617),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2617),
    [anon_sym_struct] = ACTIONS(2617),
    [anon_sym_union] = ACTIONS(2617),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2617),
    [anon_sym_decltype] = ACTIONS(2617),
    [anon_sym_explicit] = ACTIONS(2617),
    [anon_sym_typename] = ACTIONS(2617),
    [anon_sym_template] = ACTIONS(2617),
    [anon_sym_operator] = ACTIONS(2617),
    [anon_sym_friend] = ACTIONS(2617),
    [anon_sym_public] = ACTIONS(2617),
    [anon_sym_private] = ACTIONS(2617),
    [anon_sym_protected] = ACTIONS(2617),
    [anon_sym_using] = ACTIONS(2617),
    [anon_sym_static_assert] = ACTIONS(2617),
    [anon_sym___launch_bounds__] = ACTIONS(2617),
  },
  [STATE(1769)] = {
    [sym_identifier] = ACTIONS(2467),
    [aux_sym_preproc_def_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token2] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2467),
    [aux_sym_preproc_else_token1] = ACTIONS(2467),
    [aux_sym_preproc_elif_token1] = ACTIONS(2467),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2467),
    [sym_preproc_directive] = ACTIONS(2467),
    [anon_sym_LPAREN2] = ACTIONS(2469),
    [anon_sym_TILDE] = ACTIONS(2469),
    [anon_sym_STAR] = ACTIONS(2469),
    [anon_sym_AMP_AMP] = ACTIONS(2469),
    [anon_sym_AMP] = ACTIONS(2467),
    [anon_sym_SEMI] = ACTIONS(2469),
    [anon_sym___extension__] = ACTIONS(2467),
    [anon_sym_typedef] = ACTIONS(2467),
    [anon_sym___device__] = ACTIONS(2467),
    [anon_sym___host__] = ACTIONS(2467),
    [anon_sym___global__] = ACTIONS(2467),
    [anon_sym___forceinline__] = ACTIONS(2467),
    [anon_sym___noinline__] = ACTIONS(2467),
    [anon_sym_virtual] = ACTIONS(2467),
    [anon_sym_extern] = ACTIONS(2467),
    [anon_sym___attribute__] = ACTIONS(2467),
    [anon_sym___attribute] = ACTIONS(2467),
    [anon_sym_COLON_COLON] = ACTIONS(2469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2469),
    [anon_sym___declspec] = ACTIONS(2467),
    [anon_sym___based] = ACTIONS(2467),
    [anon_sym_signed] = ACTIONS(2467),
    [anon_sym_unsigned] = ACTIONS(2467),
    [anon_sym_long] = ACTIONS(2467),
    [anon_sym_short] = ACTIONS(2467),
    [anon_sym_LBRACK] = ACTIONS(2467),
    [anon_sym_static] = ACTIONS(2467),
    [anon_sym_register] = ACTIONS(2467),
    [anon_sym_inline] = ACTIONS(2467),
    [anon_sym___inline] = ACTIONS(2467),
    [anon_sym___inline__] = ACTIONS(2467),
    [anon_sym___forceinline] = ACTIONS(2467),
    [anon_sym_thread_local] = ACTIONS(2467),
    [anon_sym___thread] = ACTIONS(2467),
    [anon_sym_const] = ACTIONS(2467),
    [anon_sym_constexpr] = ACTIONS(2467),
    [anon_sym_volatile] = ACTIONS(2467),
    [anon_sym_restrict] = ACTIONS(2467),
    [anon_sym___restrict__] = ACTIONS(2467),
    [anon_sym__Atomic] = ACTIONS(2467),
    [anon_sym__Noreturn] = ACTIONS(2467),
    [anon_sym_noreturn] = ACTIONS(2467),
    [anon_sym__Nonnull] = ACTIONS(2467),
    [anon_sym_mutable] = ACTIONS(2467),
    [anon_sym_constinit] = ACTIONS(2467),
    [anon_sym_consteval] = ACTIONS(2467),
    [anon_sym___shared__] = ACTIONS(2467),
    [anon_sym___local__] = ACTIONS(2467),
    [anon_sym___constant__] = ACTIONS(2467),
    [anon_sym___managed__] = ACTIONS(2467),
    [anon_sym___grid_constant__] = ACTIONS(2467),
    [anon_sym_alignas] = ACTIONS(2467),
    [anon_sym__Alignas] = ACTIONS(2467),
    [sym_primitive_type] = ACTIONS(2467),
    [anon_sym_enum] = ACTIONS(2467),
    [anon_sym_class] = ACTIONS(2467),
    [anon_sym_struct] = ACTIONS(2467),
    [anon_sym_union] = ACTIONS(2467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2467),
    [anon_sym_decltype] = ACTIONS(2467),
    [anon_sym_explicit] = ACTIONS(2467),
    [anon_sym_typename] = ACTIONS(2467),
    [anon_sym_template] = ACTIONS(2467),
    [anon_sym_operator] = ACTIONS(2467),
    [anon_sym_friend] = ACTIONS(2467),
    [anon_sym_public] = ACTIONS(2467),
    [anon_sym_private] = ACTIONS(2467),
    [anon_sym_protected] = ACTIONS(2467),
    [anon_sym_using] = ACTIONS(2467),
    [anon_sym_static_assert] = ACTIONS(2467),
    [anon_sym___launch_bounds__] = ACTIONS(2467),
  },
  [STATE(1770)] = {
    [sym_identifier] = ACTIONS(5505),
    [aux_sym_preproc_def_token1] = ACTIONS(5505),
    [aux_sym_preproc_if_token1] = ACTIONS(5505),
    [aux_sym_preproc_if_token2] = ACTIONS(5505),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5505),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5505),
    [aux_sym_preproc_else_token1] = ACTIONS(5505),
    [aux_sym_preproc_elif_token1] = ACTIONS(5505),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5505),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5505),
    [sym_preproc_directive] = ACTIONS(5505),
    [anon_sym_LPAREN2] = ACTIONS(5507),
    [anon_sym_TILDE] = ACTIONS(5507),
    [anon_sym_STAR] = ACTIONS(5507),
    [anon_sym_AMP_AMP] = ACTIONS(5507),
    [anon_sym_AMP] = ACTIONS(5505),
    [anon_sym_SEMI] = ACTIONS(5507),
    [anon_sym___extension__] = ACTIONS(5505),
    [anon_sym_typedef] = ACTIONS(5505),
    [anon_sym___device__] = ACTIONS(5505),
    [anon_sym___host__] = ACTIONS(5505),
    [anon_sym___global__] = ACTIONS(5505),
    [anon_sym___forceinline__] = ACTIONS(5505),
    [anon_sym___noinline__] = ACTIONS(5505),
    [anon_sym_virtual] = ACTIONS(5505),
    [anon_sym_extern] = ACTIONS(5505),
    [anon_sym___attribute__] = ACTIONS(5505),
    [anon_sym___attribute] = ACTIONS(5505),
    [anon_sym_COLON_COLON] = ACTIONS(5507),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5507),
    [anon_sym___declspec] = ACTIONS(5505),
    [anon_sym___based] = ACTIONS(5505),
    [anon_sym_signed] = ACTIONS(5505),
    [anon_sym_unsigned] = ACTIONS(5505),
    [anon_sym_long] = ACTIONS(5505),
    [anon_sym_short] = ACTIONS(5505),
    [anon_sym_LBRACK] = ACTIONS(5505),
    [anon_sym_static] = ACTIONS(5505),
    [anon_sym_register] = ACTIONS(5505),
    [anon_sym_inline] = ACTIONS(5505),
    [anon_sym___inline] = ACTIONS(5505),
    [anon_sym___inline__] = ACTIONS(5505),
    [anon_sym___forceinline] = ACTIONS(5505),
    [anon_sym_thread_local] = ACTIONS(5505),
    [anon_sym___thread] = ACTIONS(5505),
    [anon_sym_const] = ACTIONS(5505),
    [anon_sym_constexpr] = ACTIONS(5505),
    [anon_sym_volatile] = ACTIONS(5505),
    [anon_sym_restrict] = ACTIONS(5505),
    [anon_sym___restrict__] = ACTIONS(5505),
    [anon_sym__Atomic] = ACTIONS(5505),
    [anon_sym__Noreturn] = ACTIONS(5505),
    [anon_sym_noreturn] = ACTIONS(5505),
    [anon_sym__Nonnull] = ACTIONS(5505),
    [anon_sym_mutable] = ACTIONS(5505),
    [anon_sym_constinit] = ACTIONS(5505),
    [anon_sym_consteval] = ACTIONS(5505),
    [anon_sym___shared__] = ACTIONS(5505),
    [anon_sym___local__] = ACTIONS(5505),
    [anon_sym___constant__] = ACTIONS(5505),
    [anon_sym___managed__] = ACTIONS(5505),
    [anon_sym___grid_constant__] = ACTIONS(5505),
    [anon_sym_alignas] = ACTIONS(5505),
    [anon_sym__Alignas] = ACTIONS(5505),
    [sym_primitive_type] = ACTIONS(5505),
    [anon_sym_enum] = ACTIONS(5505),
    [anon_sym_class] = ACTIONS(5505),
    [anon_sym_struct] = ACTIONS(5505),
    [anon_sym_union] = ACTIONS(5505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5505),
    [anon_sym_decltype] = ACTIONS(5505),
    [anon_sym_explicit] = ACTIONS(5505),
    [anon_sym_typename] = ACTIONS(5505),
    [anon_sym_template] = ACTIONS(5505),
    [anon_sym_operator] = ACTIONS(5505),
    [anon_sym_friend] = ACTIONS(5505),
    [anon_sym_public] = ACTIONS(5505),
    [anon_sym_private] = ACTIONS(5505),
    [anon_sym_protected] = ACTIONS(5505),
    [anon_sym_using] = ACTIONS(5505),
    [anon_sym_static_assert] = ACTIONS(5505),
    [anon_sym___launch_bounds__] = ACTIONS(5505),
  },
  [STATE(1771)] = {
    [sym_identifier] = ACTIONS(5509),
    [aux_sym_preproc_def_token1] = ACTIONS(5509),
    [aux_sym_preproc_if_token1] = ACTIONS(5509),
    [aux_sym_preproc_if_token2] = ACTIONS(5509),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5509),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5509),
    [aux_sym_preproc_else_token1] = ACTIONS(5509),
    [aux_sym_preproc_elif_token1] = ACTIONS(5509),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5509),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5509),
    [sym_preproc_directive] = ACTIONS(5509),
    [anon_sym_LPAREN2] = ACTIONS(5511),
    [anon_sym_TILDE] = ACTIONS(5511),
    [anon_sym_STAR] = ACTIONS(5511),
    [anon_sym_AMP_AMP] = ACTIONS(5511),
    [anon_sym_AMP] = ACTIONS(5509),
    [anon_sym_SEMI] = ACTIONS(5511),
    [anon_sym___extension__] = ACTIONS(5509),
    [anon_sym_typedef] = ACTIONS(5509),
    [anon_sym___device__] = ACTIONS(5509),
    [anon_sym___host__] = ACTIONS(5509),
    [anon_sym___global__] = ACTIONS(5509),
    [anon_sym___forceinline__] = ACTIONS(5509),
    [anon_sym___noinline__] = ACTIONS(5509),
    [anon_sym_virtual] = ACTIONS(5509),
    [anon_sym_extern] = ACTIONS(5509),
    [anon_sym___attribute__] = ACTIONS(5509),
    [anon_sym___attribute] = ACTIONS(5509),
    [anon_sym_COLON_COLON] = ACTIONS(5511),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5511),
    [anon_sym___declspec] = ACTIONS(5509),
    [anon_sym___based] = ACTIONS(5509),
    [anon_sym_signed] = ACTIONS(5509),
    [anon_sym_unsigned] = ACTIONS(5509),
    [anon_sym_long] = ACTIONS(5509),
    [anon_sym_short] = ACTIONS(5509),
    [anon_sym_LBRACK] = ACTIONS(5509),
    [anon_sym_static] = ACTIONS(5509),
    [anon_sym_register] = ACTIONS(5509),
    [anon_sym_inline] = ACTIONS(5509),
    [anon_sym___inline] = ACTIONS(5509),
    [anon_sym___inline__] = ACTIONS(5509),
    [anon_sym___forceinline] = ACTIONS(5509),
    [anon_sym_thread_local] = ACTIONS(5509),
    [anon_sym___thread] = ACTIONS(5509),
    [anon_sym_const] = ACTIONS(5509),
    [anon_sym_constexpr] = ACTIONS(5509),
    [anon_sym_volatile] = ACTIONS(5509),
    [anon_sym_restrict] = ACTIONS(5509),
    [anon_sym___restrict__] = ACTIONS(5509),
    [anon_sym__Atomic] = ACTIONS(5509),
    [anon_sym__Noreturn] = ACTIONS(5509),
    [anon_sym_noreturn] = ACTIONS(5509),
    [anon_sym__Nonnull] = ACTIONS(5509),
    [anon_sym_mutable] = ACTIONS(5509),
    [anon_sym_constinit] = ACTIONS(5509),
    [anon_sym_consteval] = ACTIONS(5509),
    [anon_sym___shared__] = ACTIONS(5509),
    [anon_sym___local__] = ACTIONS(5509),
    [anon_sym___constant__] = ACTIONS(5509),
    [anon_sym___managed__] = ACTIONS(5509),
    [anon_sym___grid_constant__] = ACTIONS(5509),
    [anon_sym_alignas] = ACTIONS(5509),
    [anon_sym__Alignas] = ACTIONS(5509),
    [sym_primitive_type] = ACTIONS(5509),
    [anon_sym_enum] = ACTIONS(5509),
    [anon_sym_class] = ACTIONS(5509),
    [anon_sym_struct] = ACTIONS(5509),
    [anon_sym_union] = ACTIONS(5509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5509),
    [anon_sym_decltype] = ACTIONS(5509),
    [anon_sym_explicit] = ACTIONS(5509),
    [anon_sym_typename] = ACTIONS(5509),
    [anon_sym_template] = ACTIONS(5509),
    [anon_sym_operator] = ACTIONS(5509),
    [anon_sym_friend] = ACTIONS(5509),
    [anon_sym_public] = ACTIONS(5509),
    [anon_sym_private] = ACTIONS(5509),
    [anon_sym_protected] = ACTIONS(5509),
    [anon_sym_using] = ACTIONS(5509),
    [anon_sym_static_assert] = ACTIONS(5509),
    [anon_sym___launch_bounds__] = ACTIONS(5509),
  },
  [STATE(1772)] = {
    [sym_identifier] = ACTIONS(5513),
    [aux_sym_preproc_def_token1] = ACTIONS(5513),
    [aux_sym_preproc_if_token1] = ACTIONS(5513),
    [aux_sym_preproc_if_token2] = ACTIONS(5513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5513),
    [aux_sym_preproc_else_token1] = ACTIONS(5513),
    [aux_sym_preproc_elif_token1] = ACTIONS(5513),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5513),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5513),
    [sym_preproc_directive] = ACTIONS(5513),
    [anon_sym_LPAREN2] = ACTIONS(5515),
    [anon_sym_TILDE] = ACTIONS(5515),
    [anon_sym_STAR] = ACTIONS(5515),
    [anon_sym_AMP_AMP] = ACTIONS(5515),
    [anon_sym_AMP] = ACTIONS(5513),
    [anon_sym_SEMI] = ACTIONS(5515),
    [anon_sym___extension__] = ACTIONS(5513),
    [anon_sym_typedef] = ACTIONS(5513),
    [anon_sym___device__] = ACTIONS(5513),
    [anon_sym___host__] = ACTIONS(5513),
    [anon_sym___global__] = ACTIONS(5513),
    [anon_sym___forceinline__] = ACTIONS(5513),
    [anon_sym___noinline__] = ACTIONS(5513),
    [anon_sym_virtual] = ACTIONS(5513),
    [anon_sym_extern] = ACTIONS(5513),
    [anon_sym___attribute__] = ACTIONS(5513),
    [anon_sym___attribute] = ACTIONS(5513),
    [anon_sym_COLON_COLON] = ACTIONS(5515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5515),
    [anon_sym___declspec] = ACTIONS(5513),
    [anon_sym___based] = ACTIONS(5513),
    [anon_sym_signed] = ACTIONS(5513),
    [anon_sym_unsigned] = ACTIONS(5513),
    [anon_sym_long] = ACTIONS(5513),
    [anon_sym_short] = ACTIONS(5513),
    [anon_sym_LBRACK] = ACTIONS(5513),
    [anon_sym_static] = ACTIONS(5513),
    [anon_sym_register] = ACTIONS(5513),
    [anon_sym_inline] = ACTIONS(5513),
    [anon_sym___inline] = ACTIONS(5513),
    [anon_sym___inline__] = ACTIONS(5513),
    [anon_sym___forceinline] = ACTIONS(5513),
    [anon_sym_thread_local] = ACTIONS(5513),
    [anon_sym___thread] = ACTIONS(5513),
    [anon_sym_const] = ACTIONS(5513),
    [anon_sym_constexpr] = ACTIONS(5513),
    [anon_sym_volatile] = ACTIONS(5513),
    [anon_sym_restrict] = ACTIONS(5513),
    [anon_sym___restrict__] = ACTIONS(5513),
    [anon_sym__Atomic] = ACTIONS(5513),
    [anon_sym__Noreturn] = ACTIONS(5513),
    [anon_sym_noreturn] = ACTIONS(5513),
    [anon_sym__Nonnull] = ACTIONS(5513),
    [anon_sym_mutable] = ACTIONS(5513),
    [anon_sym_constinit] = ACTIONS(5513),
    [anon_sym_consteval] = ACTIONS(5513),
    [anon_sym___shared__] = ACTIONS(5513),
    [anon_sym___local__] = ACTIONS(5513),
    [anon_sym___constant__] = ACTIONS(5513),
    [anon_sym___managed__] = ACTIONS(5513),
    [anon_sym___grid_constant__] = ACTIONS(5513),
    [anon_sym_alignas] = ACTIONS(5513),
    [anon_sym__Alignas] = ACTIONS(5513),
    [sym_primitive_type] = ACTIONS(5513),
    [anon_sym_enum] = ACTIONS(5513),
    [anon_sym_class] = ACTIONS(5513),
    [anon_sym_struct] = ACTIONS(5513),
    [anon_sym_union] = ACTIONS(5513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5513),
    [anon_sym_decltype] = ACTIONS(5513),
    [anon_sym_explicit] = ACTIONS(5513),
    [anon_sym_typename] = ACTIONS(5513),
    [anon_sym_template] = ACTIONS(5513),
    [anon_sym_operator] = ACTIONS(5513),
    [anon_sym_friend] = ACTIONS(5513),
    [anon_sym_public] = ACTIONS(5513),
    [anon_sym_private] = ACTIONS(5513),
    [anon_sym_protected] = ACTIONS(5513),
    [anon_sym_using] = ACTIONS(5513),
    [anon_sym_static_assert] = ACTIONS(5513),
    [anon_sym___launch_bounds__] = ACTIONS(5513),
  },
  [STATE(1773)] = {
    [sym_identifier] = ACTIONS(5517),
    [aux_sym_preproc_def_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token2] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5517),
    [aux_sym_preproc_else_token1] = ACTIONS(5517),
    [aux_sym_preproc_elif_token1] = ACTIONS(5517),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5517),
    [sym_preproc_directive] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5519),
    [anon_sym_TILDE] = ACTIONS(5519),
    [anon_sym_STAR] = ACTIONS(5519),
    [anon_sym_AMP_AMP] = ACTIONS(5519),
    [anon_sym_AMP] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym___extension__] = ACTIONS(5517),
    [anon_sym_typedef] = ACTIONS(5517),
    [anon_sym___device__] = ACTIONS(5517),
    [anon_sym___host__] = ACTIONS(5517),
    [anon_sym___global__] = ACTIONS(5517),
    [anon_sym___forceinline__] = ACTIONS(5517),
    [anon_sym___noinline__] = ACTIONS(5517),
    [anon_sym_virtual] = ACTIONS(5517),
    [anon_sym_extern] = ACTIONS(5517),
    [anon_sym___attribute__] = ACTIONS(5517),
    [anon_sym___attribute] = ACTIONS(5517),
    [anon_sym_COLON_COLON] = ACTIONS(5519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5519),
    [anon_sym___declspec] = ACTIONS(5517),
    [anon_sym___based] = ACTIONS(5517),
    [anon_sym_signed] = ACTIONS(5517),
    [anon_sym_unsigned] = ACTIONS(5517),
    [anon_sym_long] = ACTIONS(5517),
    [anon_sym_short] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5517),
    [anon_sym_static] = ACTIONS(5517),
    [anon_sym_register] = ACTIONS(5517),
    [anon_sym_inline] = ACTIONS(5517),
    [anon_sym___inline] = ACTIONS(5517),
    [anon_sym___inline__] = ACTIONS(5517),
    [anon_sym___forceinline] = ACTIONS(5517),
    [anon_sym_thread_local] = ACTIONS(5517),
    [anon_sym___thread] = ACTIONS(5517),
    [anon_sym_const] = ACTIONS(5517),
    [anon_sym_constexpr] = ACTIONS(5517),
    [anon_sym_volatile] = ACTIONS(5517),
    [anon_sym_restrict] = ACTIONS(5517),
    [anon_sym___restrict__] = ACTIONS(5517),
    [anon_sym__Atomic] = ACTIONS(5517),
    [anon_sym__Noreturn] = ACTIONS(5517),
    [anon_sym_noreturn] = ACTIONS(5517),
    [anon_sym__Nonnull] = ACTIONS(5517),
    [anon_sym_mutable] = ACTIONS(5517),
    [anon_sym_constinit] = ACTIONS(5517),
    [anon_sym_consteval] = ACTIONS(5517),
    [anon_sym___shared__] = ACTIONS(5517),
    [anon_sym___local__] = ACTIONS(5517),
    [anon_sym___constant__] = ACTIONS(5517),
    [anon_sym___managed__] = ACTIONS(5517),
    [anon_sym___grid_constant__] = ACTIONS(5517),
    [anon_sym_alignas] = ACTIONS(5517),
    [anon_sym__Alignas] = ACTIONS(5517),
    [sym_primitive_type] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_class] = ACTIONS(5517),
    [anon_sym_struct] = ACTIONS(5517),
    [anon_sym_union] = ACTIONS(5517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5517),
    [anon_sym_decltype] = ACTIONS(5517),
    [anon_sym_explicit] = ACTIONS(5517),
    [anon_sym_typename] = ACTIONS(5517),
    [anon_sym_template] = ACTIONS(5517),
    [anon_sym_operator] = ACTIONS(5517),
    [anon_sym_friend] = ACTIONS(5517),
    [anon_sym_public] = ACTIONS(5517),
    [anon_sym_private] = ACTIONS(5517),
    [anon_sym_protected] = ACTIONS(5517),
    [anon_sym_using] = ACTIONS(5517),
    [anon_sym_static_assert] = ACTIONS(5517),
    [anon_sym___launch_bounds__] = ACTIONS(5517),
  },
  [STATE(1774)] = {
    [sym_identifier] = ACTIONS(5517),
    [aux_sym_preproc_def_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token2] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5517),
    [aux_sym_preproc_else_token1] = ACTIONS(5517),
    [aux_sym_preproc_elif_token1] = ACTIONS(5517),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5517),
    [sym_preproc_directive] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5519),
    [anon_sym_TILDE] = ACTIONS(5519),
    [anon_sym_STAR] = ACTIONS(5519),
    [anon_sym_AMP_AMP] = ACTIONS(5519),
    [anon_sym_AMP] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym___extension__] = ACTIONS(5517),
    [anon_sym_typedef] = ACTIONS(5517),
    [anon_sym___device__] = ACTIONS(5517),
    [anon_sym___host__] = ACTIONS(5517),
    [anon_sym___global__] = ACTIONS(5517),
    [anon_sym___forceinline__] = ACTIONS(5517),
    [anon_sym___noinline__] = ACTIONS(5517),
    [anon_sym_virtual] = ACTIONS(5517),
    [anon_sym_extern] = ACTIONS(5517),
    [anon_sym___attribute__] = ACTIONS(5517),
    [anon_sym___attribute] = ACTIONS(5517),
    [anon_sym_COLON_COLON] = ACTIONS(5519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5519),
    [anon_sym___declspec] = ACTIONS(5517),
    [anon_sym___based] = ACTIONS(5517),
    [anon_sym_signed] = ACTIONS(5517),
    [anon_sym_unsigned] = ACTIONS(5517),
    [anon_sym_long] = ACTIONS(5517),
    [anon_sym_short] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5517),
    [anon_sym_static] = ACTIONS(5517),
    [anon_sym_register] = ACTIONS(5517),
    [anon_sym_inline] = ACTIONS(5517),
    [anon_sym___inline] = ACTIONS(5517),
    [anon_sym___inline__] = ACTIONS(5517),
    [anon_sym___forceinline] = ACTIONS(5517),
    [anon_sym_thread_local] = ACTIONS(5517),
    [anon_sym___thread] = ACTIONS(5517),
    [anon_sym_const] = ACTIONS(5517),
    [anon_sym_constexpr] = ACTIONS(5517),
    [anon_sym_volatile] = ACTIONS(5517),
    [anon_sym_restrict] = ACTIONS(5517),
    [anon_sym___restrict__] = ACTIONS(5517),
    [anon_sym__Atomic] = ACTIONS(5517),
    [anon_sym__Noreturn] = ACTIONS(5517),
    [anon_sym_noreturn] = ACTIONS(5517),
    [anon_sym__Nonnull] = ACTIONS(5517),
    [anon_sym_mutable] = ACTIONS(5517),
    [anon_sym_constinit] = ACTIONS(5517),
    [anon_sym_consteval] = ACTIONS(5517),
    [anon_sym___shared__] = ACTIONS(5517),
    [anon_sym___local__] = ACTIONS(5517),
    [anon_sym___constant__] = ACTIONS(5517),
    [anon_sym___managed__] = ACTIONS(5517),
    [anon_sym___grid_constant__] = ACTIONS(5517),
    [anon_sym_alignas] = ACTIONS(5517),
    [anon_sym__Alignas] = ACTIONS(5517),
    [sym_primitive_type] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_class] = ACTIONS(5517),
    [anon_sym_struct] = ACTIONS(5517),
    [anon_sym_union] = ACTIONS(5517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5517),
    [anon_sym_decltype] = ACTIONS(5517),
    [anon_sym_explicit] = ACTIONS(5517),
    [anon_sym_typename] = ACTIONS(5517),
    [anon_sym_template] = ACTIONS(5517),
    [anon_sym_operator] = ACTIONS(5517),
    [anon_sym_friend] = ACTIONS(5517),
    [anon_sym_public] = ACTIONS(5517),
    [anon_sym_private] = ACTIONS(5517),
    [anon_sym_protected] = ACTIONS(5517),
    [anon_sym_using] = ACTIONS(5517),
    [anon_sym_static_assert] = ACTIONS(5517),
    [anon_sym___launch_bounds__] = ACTIONS(5517),
  },
  [STATE(1775)] = {
    [sym_identifier] = ACTIONS(5521),
    [aux_sym_preproc_def_token1] = ACTIONS(5521),
    [aux_sym_preproc_if_token1] = ACTIONS(5521),
    [aux_sym_preproc_if_token2] = ACTIONS(5521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5521),
    [aux_sym_preproc_else_token1] = ACTIONS(5521),
    [aux_sym_preproc_elif_token1] = ACTIONS(5521),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5521),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5521),
    [sym_preproc_directive] = ACTIONS(5521),
    [anon_sym_LPAREN2] = ACTIONS(5523),
    [anon_sym_TILDE] = ACTIONS(5523),
    [anon_sym_STAR] = ACTIONS(5523),
    [anon_sym_AMP_AMP] = ACTIONS(5523),
    [anon_sym_AMP] = ACTIONS(5521),
    [anon_sym_SEMI] = ACTIONS(5523),
    [anon_sym___extension__] = ACTIONS(5521),
    [anon_sym_typedef] = ACTIONS(5521),
    [anon_sym___device__] = ACTIONS(5521),
    [anon_sym___host__] = ACTIONS(5521),
    [anon_sym___global__] = ACTIONS(5521),
    [anon_sym___forceinline__] = ACTIONS(5521),
    [anon_sym___noinline__] = ACTIONS(5521),
    [anon_sym_virtual] = ACTIONS(5521),
    [anon_sym_extern] = ACTIONS(5521),
    [anon_sym___attribute__] = ACTIONS(5521),
    [anon_sym___attribute] = ACTIONS(5521),
    [anon_sym_COLON_COLON] = ACTIONS(5523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5523),
    [anon_sym___declspec] = ACTIONS(5521),
    [anon_sym___based] = ACTIONS(5521),
    [anon_sym_signed] = ACTIONS(5521),
    [anon_sym_unsigned] = ACTIONS(5521),
    [anon_sym_long] = ACTIONS(5521),
    [anon_sym_short] = ACTIONS(5521),
    [anon_sym_LBRACK] = ACTIONS(5521),
    [anon_sym_static] = ACTIONS(5521),
    [anon_sym_register] = ACTIONS(5521),
    [anon_sym_inline] = ACTIONS(5521),
    [anon_sym___inline] = ACTIONS(5521),
    [anon_sym___inline__] = ACTIONS(5521),
    [anon_sym___forceinline] = ACTIONS(5521),
    [anon_sym_thread_local] = ACTIONS(5521),
    [anon_sym___thread] = ACTIONS(5521),
    [anon_sym_const] = ACTIONS(5521),
    [anon_sym_constexpr] = ACTIONS(5521),
    [anon_sym_volatile] = ACTIONS(5521),
    [anon_sym_restrict] = ACTIONS(5521),
    [anon_sym___restrict__] = ACTIONS(5521),
    [anon_sym__Atomic] = ACTIONS(5521),
    [anon_sym__Noreturn] = ACTIONS(5521),
    [anon_sym_noreturn] = ACTIONS(5521),
    [anon_sym__Nonnull] = ACTIONS(5521),
    [anon_sym_mutable] = ACTIONS(5521),
    [anon_sym_constinit] = ACTIONS(5521),
    [anon_sym_consteval] = ACTIONS(5521),
    [anon_sym___shared__] = ACTIONS(5521),
    [anon_sym___local__] = ACTIONS(5521),
    [anon_sym___constant__] = ACTIONS(5521),
    [anon_sym___managed__] = ACTIONS(5521),
    [anon_sym___grid_constant__] = ACTIONS(5521),
    [anon_sym_alignas] = ACTIONS(5521),
    [anon_sym__Alignas] = ACTIONS(5521),
    [sym_primitive_type] = ACTIONS(5521),
    [anon_sym_enum] = ACTIONS(5521),
    [anon_sym_class] = ACTIONS(5521),
    [anon_sym_struct] = ACTIONS(5521),
    [anon_sym_union] = ACTIONS(5521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5521),
    [anon_sym_decltype] = ACTIONS(5521),
    [anon_sym_explicit] = ACTIONS(5521),
    [anon_sym_typename] = ACTIONS(5521),
    [anon_sym_template] = ACTIONS(5521),
    [anon_sym_operator] = ACTIONS(5521),
    [anon_sym_friend] = ACTIONS(5521),
    [anon_sym_public] = ACTIONS(5521),
    [anon_sym_private] = ACTIONS(5521),
    [anon_sym_protected] = ACTIONS(5521),
    [anon_sym_using] = ACTIONS(5521),
    [anon_sym_static_assert] = ACTIONS(5521),
    [anon_sym___launch_bounds__] = ACTIONS(5521),
  },
  [STATE(1776)] = {
    [sym_identifier] = ACTIONS(5525),
    [aux_sym_preproc_def_token1] = ACTIONS(5525),
    [aux_sym_preproc_if_token1] = ACTIONS(5525),
    [aux_sym_preproc_if_token2] = ACTIONS(5525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5525),
    [aux_sym_preproc_else_token1] = ACTIONS(5525),
    [aux_sym_preproc_elif_token1] = ACTIONS(5525),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5525),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5525),
    [sym_preproc_directive] = ACTIONS(5525),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_TILDE] = ACTIONS(5527),
    [anon_sym_STAR] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___extension__] = ACTIONS(5525),
    [anon_sym_typedef] = ACTIONS(5525),
    [anon_sym___device__] = ACTIONS(5525),
    [anon_sym___host__] = ACTIONS(5525),
    [anon_sym___global__] = ACTIONS(5525),
    [anon_sym___forceinline__] = ACTIONS(5525),
    [anon_sym___noinline__] = ACTIONS(5525),
    [anon_sym_virtual] = ACTIONS(5525),
    [anon_sym_extern] = ACTIONS(5525),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym___attribute] = ACTIONS(5525),
    [anon_sym_COLON_COLON] = ACTIONS(5527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5527),
    [anon_sym___declspec] = ACTIONS(5525),
    [anon_sym___based] = ACTIONS(5525),
    [anon_sym_signed] = ACTIONS(5525),
    [anon_sym_unsigned] = ACTIONS(5525),
    [anon_sym_long] = ACTIONS(5525),
    [anon_sym_short] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5525),
    [anon_sym_static] = ACTIONS(5525),
    [anon_sym_register] = ACTIONS(5525),
    [anon_sym_inline] = ACTIONS(5525),
    [anon_sym___inline] = ACTIONS(5525),
    [anon_sym___inline__] = ACTIONS(5525),
    [anon_sym___forceinline] = ACTIONS(5525),
    [anon_sym_thread_local] = ACTIONS(5525),
    [anon_sym___thread] = ACTIONS(5525),
    [anon_sym_const] = ACTIONS(5525),
    [anon_sym_constexpr] = ACTIONS(5525),
    [anon_sym_volatile] = ACTIONS(5525),
    [anon_sym_restrict] = ACTIONS(5525),
    [anon_sym___restrict__] = ACTIONS(5525),
    [anon_sym__Atomic] = ACTIONS(5525),
    [anon_sym__Noreturn] = ACTIONS(5525),
    [anon_sym_noreturn] = ACTIONS(5525),
    [anon_sym__Nonnull] = ACTIONS(5525),
    [anon_sym_mutable] = ACTIONS(5525),
    [anon_sym_constinit] = ACTIONS(5525),
    [anon_sym_consteval] = ACTIONS(5525),
    [anon_sym___shared__] = ACTIONS(5525),
    [anon_sym___local__] = ACTIONS(5525),
    [anon_sym___constant__] = ACTIONS(5525),
    [anon_sym___managed__] = ACTIONS(5525),
    [anon_sym___grid_constant__] = ACTIONS(5525),
    [anon_sym_alignas] = ACTIONS(5525),
    [anon_sym__Alignas] = ACTIONS(5525),
    [sym_primitive_type] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_class] = ACTIONS(5525),
    [anon_sym_struct] = ACTIONS(5525),
    [anon_sym_union] = ACTIONS(5525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
    [anon_sym_explicit] = ACTIONS(5525),
    [anon_sym_typename] = ACTIONS(5525),
    [anon_sym_template] = ACTIONS(5525),
    [anon_sym_operator] = ACTIONS(5525),
    [anon_sym_friend] = ACTIONS(5525),
    [anon_sym_public] = ACTIONS(5525),
    [anon_sym_private] = ACTIONS(5525),
    [anon_sym_protected] = ACTIONS(5525),
    [anon_sym_using] = ACTIONS(5525),
    [anon_sym_static_assert] = ACTIONS(5525),
    [anon_sym___launch_bounds__] = ACTIONS(5525),
  },
  [STATE(1777)] = {
    [sym_identifier] = ACTIONS(2485),
    [aux_sym_preproc_def_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token2] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2485),
    [aux_sym_preproc_else_token1] = ACTIONS(2485),
    [aux_sym_preproc_elif_token1] = ACTIONS(2485),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2485),
    [sym_preproc_directive] = ACTIONS(2485),
    [anon_sym_LPAREN2] = ACTIONS(2487),
    [anon_sym_TILDE] = ACTIONS(2487),
    [anon_sym_STAR] = ACTIONS(2487),
    [anon_sym_AMP_AMP] = ACTIONS(2487),
    [anon_sym_AMP] = ACTIONS(2485),
    [anon_sym_SEMI] = ACTIONS(2487),
    [anon_sym___extension__] = ACTIONS(2485),
    [anon_sym_typedef] = ACTIONS(2485),
    [anon_sym___device__] = ACTIONS(2485),
    [anon_sym___host__] = ACTIONS(2485),
    [anon_sym___global__] = ACTIONS(2485),
    [anon_sym___forceinline__] = ACTIONS(2485),
    [anon_sym___noinline__] = ACTIONS(2485),
    [anon_sym_virtual] = ACTIONS(2485),
    [anon_sym_extern] = ACTIONS(2485),
    [anon_sym___attribute__] = ACTIONS(2485),
    [anon_sym___attribute] = ACTIONS(2485),
    [anon_sym_COLON_COLON] = ACTIONS(2487),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2487),
    [anon_sym___declspec] = ACTIONS(2485),
    [anon_sym___based] = ACTIONS(2485),
    [anon_sym_signed] = ACTIONS(2485),
    [anon_sym_unsigned] = ACTIONS(2485),
    [anon_sym_long] = ACTIONS(2485),
    [anon_sym_short] = ACTIONS(2485),
    [anon_sym_LBRACK] = ACTIONS(2485),
    [anon_sym_static] = ACTIONS(2485),
    [anon_sym_register] = ACTIONS(2485),
    [anon_sym_inline] = ACTIONS(2485),
    [anon_sym___inline] = ACTIONS(2485),
    [anon_sym___inline__] = ACTIONS(2485),
    [anon_sym___forceinline] = ACTIONS(2485),
    [anon_sym_thread_local] = ACTIONS(2485),
    [anon_sym___thread] = ACTIONS(2485),
    [anon_sym_const] = ACTIONS(2485),
    [anon_sym_constexpr] = ACTIONS(2485),
    [anon_sym_volatile] = ACTIONS(2485),
    [anon_sym_restrict] = ACTIONS(2485),
    [anon_sym___restrict__] = ACTIONS(2485),
    [anon_sym__Atomic] = ACTIONS(2485),
    [anon_sym__Noreturn] = ACTIONS(2485),
    [anon_sym_noreturn] = ACTIONS(2485),
    [anon_sym__Nonnull] = ACTIONS(2485),
    [anon_sym_mutable] = ACTIONS(2485),
    [anon_sym_constinit] = ACTIONS(2485),
    [anon_sym_consteval] = ACTIONS(2485),
    [anon_sym___shared__] = ACTIONS(2485),
    [anon_sym___local__] = ACTIONS(2485),
    [anon_sym___constant__] = ACTIONS(2485),
    [anon_sym___managed__] = ACTIONS(2485),
    [anon_sym___grid_constant__] = ACTIONS(2485),
    [anon_sym_alignas] = ACTIONS(2485),
    [anon_sym__Alignas] = ACTIONS(2485),
    [sym_primitive_type] = ACTIONS(2485),
    [anon_sym_enum] = ACTIONS(2485),
    [anon_sym_class] = ACTIONS(2485),
    [anon_sym_struct] = ACTIONS(2485),
    [anon_sym_union] = ACTIONS(2485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2485),
    [anon_sym_decltype] = ACTIONS(2485),
    [anon_sym_explicit] = ACTIONS(2485),
    [anon_sym_typename] = ACTIONS(2485),
    [anon_sym_template] = ACTIONS(2485),
    [anon_sym_operator] = ACTIONS(2485),
    [anon_sym_friend] = ACTIONS(2485),
    [anon_sym_public] = ACTIONS(2485),
    [anon_sym_private] = ACTIONS(2485),
    [anon_sym_protected] = ACTIONS(2485),
    [anon_sym_using] = ACTIONS(2485),
    [anon_sym_static_assert] = ACTIONS(2485),
    [anon_sym___launch_bounds__] = ACTIONS(2485),
  },
  [STATE(1778)] = {
    [sym_identifier] = ACTIONS(2493),
    [aux_sym_preproc_def_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token2] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2493),
    [aux_sym_preproc_else_token1] = ACTIONS(2493),
    [aux_sym_preproc_elif_token1] = ACTIONS(2493),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2493),
    [sym_preproc_directive] = ACTIONS(2493),
    [anon_sym_LPAREN2] = ACTIONS(2495),
    [anon_sym_TILDE] = ACTIONS(2495),
    [anon_sym_STAR] = ACTIONS(2495),
    [anon_sym_AMP_AMP] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(2493),
    [anon_sym_SEMI] = ACTIONS(2495),
    [anon_sym___extension__] = ACTIONS(2493),
    [anon_sym_typedef] = ACTIONS(2493),
    [anon_sym___device__] = ACTIONS(2493),
    [anon_sym___host__] = ACTIONS(2493),
    [anon_sym___global__] = ACTIONS(2493),
    [anon_sym___forceinline__] = ACTIONS(2493),
    [anon_sym___noinline__] = ACTIONS(2493),
    [anon_sym_virtual] = ACTIONS(2493),
    [anon_sym_extern] = ACTIONS(2493),
    [anon_sym___attribute__] = ACTIONS(2493),
    [anon_sym___attribute] = ACTIONS(2493),
    [anon_sym_COLON_COLON] = ACTIONS(2495),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2495),
    [anon_sym___declspec] = ACTIONS(2493),
    [anon_sym___based] = ACTIONS(2493),
    [anon_sym_signed] = ACTIONS(2493),
    [anon_sym_unsigned] = ACTIONS(2493),
    [anon_sym_long] = ACTIONS(2493),
    [anon_sym_short] = ACTIONS(2493),
    [anon_sym_LBRACK] = ACTIONS(2493),
    [anon_sym_static] = ACTIONS(2493),
    [anon_sym_register] = ACTIONS(2493),
    [anon_sym_inline] = ACTIONS(2493),
    [anon_sym___inline] = ACTIONS(2493),
    [anon_sym___inline__] = ACTIONS(2493),
    [anon_sym___forceinline] = ACTIONS(2493),
    [anon_sym_thread_local] = ACTIONS(2493),
    [anon_sym___thread] = ACTIONS(2493),
    [anon_sym_const] = ACTIONS(2493),
    [anon_sym_constexpr] = ACTIONS(2493),
    [anon_sym_volatile] = ACTIONS(2493),
    [anon_sym_restrict] = ACTIONS(2493),
    [anon_sym___restrict__] = ACTIONS(2493),
    [anon_sym__Atomic] = ACTIONS(2493),
    [anon_sym__Noreturn] = ACTIONS(2493),
    [anon_sym_noreturn] = ACTIONS(2493),
    [anon_sym__Nonnull] = ACTIONS(2493),
    [anon_sym_mutable] = ACTIONS(2493),
    [anon_sym_constinit] = ACTIONS(2493),
    [anon_sym_consteval] = ACTIONS(2493),
    [anon_sym___shared__] = ACTIONS(2493),
    [anon_sym___local__] = ACTIONS(2493),
    [anon_sym___constant__] = ACTIONS(2493),
    [anon_sym___managed__] = ACTIONS(2493),
    [anon_sym___grid_constant__] = ACTIONS(2493),
    [anon_sym_alignas] = ACTIONS(2493),
    [anon_sym__Alignas] = ACTIONS(2493),
    [sym_primitive_type] = ACTIONS(2493),
    [anon_sym_enum] = ACTIONS(2493),
    [anon_sym_class] = ACTIONS(2493),
    [anon_sym_struct] = ACTIONS(2493),
    [anon_sym_union] = ACTIONS(2493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2493),
    [anon_sym_decltype] = ACTIONS(2493),
    [anon_sym_explicit] = ACTIONS(2493),
    [anon_sym_typename] = ACTIONS(2493),
    [anon_sym_template] = ACTIONS(2493),
    [anon_sym_operator] = ACTIONS(2493),
    [anon_sym_friend] = ACTIONS(2493),
    [anon_sym_public] = ACTIONS(2493),
    [anon_sym_private] = ACTIONS(2493),
    [anon_sym_protected] = ACTIONS(2493),
    [anon_sym_using] = ACTIONS(2493),
    [anon_sym_static_assert] = ACTIONS(2493),
    [anon_sym___launch_bounds__] = ACTIONS(2493),
  },
  [STATE(1779)] = {
    [sym_identifier] = ACTIONS(5529),
    [aux_sym_preproc_def_token1] = ACTIONS(5529),
    [aux_sym_preproc_if_token1] = ACTIONS(5529),
    [aux_sym_preproc_if_token2] = ACTIONS(5529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5529),
    [aux_sym_preproc_else_token1] = ACTIONS(5529),
    [aux_sym_preproc_elif_token1] = ACTIONS(5529),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5529),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5529),
    [sym_preproc_directive] = ACTIONS(5529),
    [anon_sym_LPAREN2] = ACTIONS(5531),
    [anon_sym_TILDE] = ACTIONS(5531),
    [anon_sym_STAR] = ACTIONS(5531),
    [anon_sym_AMP_AMP] = ACTIONS(5531),
    [anon_sym_AMP] = ACTIONS(5529),
    [anon_sym_SEMI] = ACTIONS(5531),
    [anon_sym___extension__] = ACTIONS(5529),
    [anon_sym_typedef] = ACTIONS(5529),
    [anon_sym___device__] = ACTIONS(5529),
    [anon_sym___host__] = ACTIONS(5529),
    [anon_sym___global__] = ACTIONS(5529),
    [anon_sym___forceinline__] = ACTIONS(5529),
    [anon_sym___noinline__] = ACTIONS(5529),
    [anon_sym_virtual] = ACTIONS(5529),
    [anon_sym_extern] = ACTIONS(5529),
    [anon_sym___attribute__] = ACTIONS(5529),
    [anon_sym___attribute] = ACTIONS(5529),
    [anon_sym_COLON_COLON] = ACTIONS(5531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5531),
    [anon_sym___declspec] = ACTIONS(5529),
    [anon_sym___based] = ACTIONS(5529),
    [anon_sym_signed] = ACTIONS(5529),
    [anon_sym_unsigned] = ACTIONS(5529),
    [anon_sym_long] = ACTIONS(5529),
    [anon_sym_short] = ACTIONS(5529),
    [anon_sym_LBRACK] = ACTIONS(5529),
    [anon_sym_static] = ACTIONS(5529),
    [anon_sym_register] = ACTIONS(5529),
    [anon_sym_inline] = ACTIONS(5529),
    [anon_sym___inline] = ACTIONS(5529),
    [anon_sym___inline__] = ACTIONS(5529),
    [anon_sym___forceinline] = ACTIONS(5529),
    [anon_sym_thread_local] = ACTIONS(5529),
    [anon_sym___thread] = ACTIONS(5529),
    [anon_sym_const] = ACTIONS(5529),
    [anon_sym_constexpr] = ACTIONS(5529),
    [anon_sym_volatile] = ACTIONS(5529),
    [anon_sym_restrict] = ACTIONS(5529),
    [anon_sym___restrict__] = ACTIONS(5529),
    [anon_sym__Atomic] = ACTIONS(5529),
    [anon_sym__Noreturn] = ACTIONS(5529),
    [anon_sym_noreturn] = ACTIONS(5529),
    [anon_sym__Nonnull] = ACTIONS(5529),
    [anon_sym_mutable] = ACTIONS(5529),
    [anon_sym_constinit] = ACTIONS(5529),
    [anon_sym_consteval] = ACTIONS(5529),
    [anon_sym___shared__] = ACTIONS(5529),
    [anon_sym___local__] = ACTIONS(5529),
    [anon_sym___constant__] = ACTIONS(5529),
    [anon_sym___managed__] = ACTIONS(5529),
    [anon_sym___grid_constant__] = ACTIONS(5529),
    [anon_sym_alignas] = ACTIONS(5529),
    [anon_sym__Alignas] = ACTIONS(5529),
    [sym_primitive_type] = ACTIONS(5529),
    [anon_sym_enum] = ACTIONS(5529),
    [anon_sym_class] = ACTIONS(5529),
    [anon_sym_struct] = ACTIONS(5529),
    [anon_sym_union] = ACTIONS(5529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5529),
    [anon_sym_decltype] = ACTIONS(5529),
    [anon_sym_explicit] = ACTIONS(5529),
    [anon_sym_typename] = ACTIONS(5529),
    [anon_sym_template] = ACTIONS(5529),
    [anon_sym_operator] = ACTIONS(5529),
    [anon_sym_friend] = ACTIONS(5529),
    [anon_sym_public] = ACTIONS(5529),
    [anon_sym_private] = ACTIONS(5529),
    [anon_sym_protected] = ACTIONS(5529),
    [anon_sym_using] = ACTIONS(5529),
    [anon_sym_static_assert] = ACTIONS(5529),
    [anon_sym___launch_bounds__] = ACTIONS(5529),
  },
  [STATE(1780)] = {
    [sym_identifier] = ACTIONS(5533),
    [aux_sym_preproc_def_token1] = ACTIONS(5533),
    [aux_sym_preproc_if_token1] = ACTIONS(5533),
    [aux_sym_preproc_if_token2] = ACTIONS(5533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5533),
    [aux_sym_preproc_else_token1] = ACTIONS(5533),
    [aux_sym_preproc_elif_token1] = ACTIONS(5533),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5533),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5533),
    [sym_preproc_directive] = ACTIONS(5533),
    [anon_sym_LPAREN2] = ACTIONS(5535),
    [anon_sym_TILDE] = ACTIONS(5535),
    [anon_sym_STAR] = ACTIONS(5535),
    [anon_sym_AMP_AMP] = ACTIONS(5535),
    [anon_sym_AMP] = ACTIONS(5533),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym___extension__] = ACTIONS(5533),
    [anon_sym_typedef] = ACTIONS(5533),
    [anon_sym___device__] = ACTIONS(5533),
    [anon_sym___host__] = ACTIONS(5533),
    [anon_sym___global__] = ACTIONS(5533),
    [anon_sym___forceinline__] = ACTIONS(5533),
    [anon_sym___noinline__] = ACTIONS(5533),
    [anon_sym_virtual] = ACTIONS(5533),
    [anon_sym_extern] = ACTIONS(5533),
    [anon_sym___attribute__] = ACTIONS(5533),
    [anon_sym___attribute] = ACTIONS(5533),
    [anon_sym_COLON_COLON] = ACTIONS(5535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5535),
    [anon_sym___declspec] = ACTIONS(5533),
    [anon_sym___based] = ACTIONS(5533),
    [anon_sym_signed] = ACTIONS(5533),
    [anon_sym_unsigned] = ACTIONS(5533),
    [anon_sym_long] = ACTIONS(5533),
    [anon_sym_short] = ACTIONS(5533),
    [anon_sym_LBRACK] = ACTIONS(5533),
    [anon_sym_static] = ACTIONS(5533),
    [anon_sym_register] = ACTIONS(5533),
    [anon_sym_inline] = ACTIONS(5533),
    [anon_sym___inline] = ACTIONS(5533),
    [anon_sym___inline__] = ACTIONS(5533),
    [anon_sym___forceinline] = ACTIONS(5533),
    [anon_sym_thread_local] = ACTIONS(5533),
    [anon_sym___thread] = ACTIONS(5533),
    [anon_sym_const] = ACTIONS(5533),
    [anon_sym_constexpr] = ACTIONS(5533),
    [anon_sym_volatile] = ACTIONS(5533),
    [anon_sym_restrict] = ACTIONS(5533),
    [anon_sym___restrict__] = ACTIONS(5533),
    [anon_sym__Atomic] = ACTIONS(5533),
    [anon_sym__Noreturn] = ACTIONS(5533),
    [anon_sym_noreturn] = ACTIONS(5533),
    [anon_sym__Nonnull] = ACTIONS(5533),
    [anon_sym_mutable] = ACTIONS(5533),
    [anon_sym_constinit] = ACTIONS(5533),
    [anon_sym_consteval] = ACTIONS(5533),
    [anon_sym___shared__] = ACTIONS(5533),
    [anon_sym___local__] = ACTIONS(5533),
    [anon_sym___constant__] = ACTIONS(5533),
    [anon_sym___managed__] = ACTIONS(5533),
    [anon_sym___grid_constant__] = ACTIONS(5533),
    [anon_sym_alignas] = ACTIONS(5533),
    [anon_sym__Alignas] = ACTIONS(5533),
    [sym_primitive_type] = ACTIONS(5533),
    [anon_sym_enum] = ACTIONS(5533),
    [anon_sym_class] = ACTIONS(5533),
    [anon_sym_struct] = ACTIONS(5533),
    [anon_sym_union] = ACTIONS(5533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5533),
    [anon_sym_decltype] = ACTIONS(5533),
    [anon_sym_explicit] = ACTIONS(5533),
    [anon_sym_typename] = ACTIONS(5533),
    [anon_sym_template] = ACTIONS(5533),
    [anon_sym_operator] = ACTIONS(5533),
    [anon_sym_friend] = ACTIONS(5533),
    [anon_sym_public] = ACTIONS(5533),
    [anon_sym_private] = ACTIONS(5533),
    [anon_sym_protected] = ACTIONS(5533),
    [anon_sym_using] = ACTIONS(5533),
    [anon_sym_static_assert] = ACTIONS(5533),
    [anon_sym___launch_bounds__] = ACTIONS(5533),
  },
  [STATE(1781)] = {
    [sym_identifier] = ACTIONS(5537),
    [aux_sym_preproc_def_token1] = ACTIONS(5537),
    [aux_sym_preproc_if_token1] = ACTIONS(5537),
    [aux_sym_preproc_if_token2] = ACTIONS(5537),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5537),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5537),
    [aux_sym_preproc_else_token1] = ACTIONS(5537),
    [aux_sym_preproc_elif_token1] = ACTIONS(5537),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5537),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5537),
    [sym_preproc_directive] = ACTIONS(5537),
    [anon_sym_LPAREN2] = ACTIONS(5539),
    [anon_sym_TILDE] = ACTIONS(5539),
    [anon_sym_STAR] = ACTIONS(5539),
    [anon_sym_AMP_AMP] = ACTIONS(5539),
    [anon_sym_AMP] = ACTIONS(5537),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym___extension__] = ACTIONS(5537),
    [anon_sym_typedef] = ACTIONS(5537),
    [anon_sym___device__] = ACTIONS(5537),
    [anon_sym___host__] = ACTIONS(5537),
    [anon_sym___global__] = ACTIONS(5537),
    [anon_sym___forceinline__] = ACTIONS(5537),
    [anon_sym___noinline__] = ACTIONS(5537),
    [anon_sym_virtual] = ACTIONS(5537),
    [anon_sym_extern] = ACTIONS(5537),
    [anon_sym___attribute__] = ACTIONS(5537),
    [anon_sym___attribute] = ACTIONS(5537),
    [anon_sym_COLON_COLON] = ACTIONS(5539),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5539),
    [anon_sym___declspec] = ACTIONS(5537),
    [anon_sym___based] = ACTIONS(5537),
    [anon_sym_signed] = ACTIONS(5537),
    [anon_sym_unsigned] = ACTIONS(5537),
    [anon_sym_long] = ACTIONS(5537),
    [anon_sym_short] = ACTIONS(5537),
    [anon_sym_LBRACK] = ACTIONS(5537),
    [anon_sym_static] = ACTIONS(5537),
    [anon_sym_register] = ACTIONS(5537),
    [anon_sym_inline] = ACTIONS(5537),
    [anon_sym___inline] = ACTIONS(5537),
    [anon_sym___inline__] = ACTIONS(5537),
    [anon_sym___forceinline] = ACTIONS(5537),
    [anon_sym_thread_local] = ACTIONS(5537),
    [anon_sym___thread] = ACTIONS(5537),
    [anon_sym_const] = ACTIONS(5537),
    [anon_sym_constexpr] = ACTIONS(5537),
    [anon_sym_volatile] = ACTIONS(5537),
    [anon_sym_restrict] = ACTIONS(5537),
    [anon_sym___restrict__] = ACTIONS(5537),
    [anon_sym__Atomic] = ACTIONS(5537),
    [anon_sym__Noreturn] = ACTIONS(5537),
    [anon_sym_noreturn] = ACTIONS(5537),
    [anon_sym__Nonnull] = ACTIONS(5537),
    [anon_sym_mutable] = ACTIONS(5537),
    [anon_sym_constinit] = ACTIONS(5537),
    [anon_sym_consteval] = ACTIONS(5537),
    [anon_sym___shared__] = ACTIONS(5537),
    [anon_sym___local__] = ACTIONS(5537),
    [anon_sym___constant__] = ACTIONS(5537),
    [anon_sym___managed__] = ACTIONS(5537),
    [anon_sym___grid_constant__] = ACTIONS(5537),
    [anon_sym_alignas] = ACTIONS(5537),
    [anon_sym__Alignas] = ACTIONS(5537),
    [sym_primitive_type] = ACTIONS(5537),
    [anon_sym_enum] = ACTIONS(5537),
    [anon_sym_class] = ACTIONS(5537),
    [anon_sym_struct] = ACTIONS(5537),
    [anon_sym_union] = ACTIONS(5537),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5537),
    [anon_sym_decltype] = ACTIONS(5537),
    [anon_sym_explicit] = ACTIONS(5537),
    [anon_sym_typename] = ACTIONS(5537),
    [anon_sym_template] = ACTIONS(5537),
    [anon_sym_operator] = ACTIONS(5537),
    [anon_sym_friend] = ACTIONS(5537),
    [anon_sym_public] = ACTIONS(5537),
    [anon_sym_private] = ACTIONS(5537),
    [anon_sym_protected] = ACTIONS(5537),
    [anon_sym_using] = ACTIONS(5537),
    [anon_sym_static_assert] = ACTIONS(5537),
    [anon_sym___launch_bounds__] = ACTIONS(5537),
  },
  [STATE(1782)] = {
    [sym_identifier] = ACTIONS(5541),
    [aux_sym_preproc_def_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token2] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5541),
    [aux_sym_preproc_else_token1] = ACTIONS(5541),
    [aux_sym_preproc_elif_token1] = ACTIONS(5541),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5541),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5541),
    [sym_preproc_directive] = ACTIONS(5541),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_TILDE] = ACTIONS(5543),
    [anon_sym_STAR] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___extension__] = ACTIONS(5541),
    [anon_sym_typedef] = ACTIONS(5541),
    [anon_sym___device__] = ACTIONS(5541),
    [anon_sym___host__] = ACTIONS(5541),
    [anon_sym___global__] = ACTIONS(5541),
    [anon_sym___forceinline__] = ACTIONS(5541),
    [anon_sym___noinline__] = ACTIONS(5541),
    [anon_sym_virtual] = ACTIONS(5541),
    [anon_sym_extern] = ACTIONS(5541),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym___attribute] = ACTIONS(5541),
    [anon_sym_COLON_COLON] = ACTIONS(5543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5543),
    [anon_sym___declspec] = ACTIONS(5541),
    [anon_sym___based] = ACTIONS(5541),
    [anon_sym_signed] = ACTIONS(5541),
    [anon_sym_unsigned] = ACTIONS(5541),
    [anon_sym_long] = ACTIONS(5541),
    [anon_sym_short] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5541),
    [anon_sym_static] = ACTIONS(5541),
    [anon_sym_register] = ACTIONS(5541),
    [anon_sym_inline] = ACTIONS(5541),
    [anon_sym___inline] = ACTIONS(5541),
    [anon_sym___inline__] = ACTIONS(5541),
    [anon_sym___forceinline] = ACTIONS(5541),
    [anon_sym_thread_local] = ACTIONS(5541),
    [anon_sym___thread] = ACTIONS(5541),
    [anon_sym_const] = ACTIONS(5541),
    [anon_sym_constexpr] = ACTIONS(5541),
    [anon_sym_volatile] = ACTIONS(5541),
    [anon_sym_restrict] = ACTIONS(5541),
    [anon_sym___restrict__] = ACTIONS(5541),
    [anon_sym__Atomic] = ACTIONS(5541),
    [anon_sym__Noreturn] = ACTIONS(5541),
    [anon_sym_noreturn] = ACTIONS(5541),
    [anon_sym__Nonnull] = ACTIONS(5541),
    [anon_sym_mutable] = ACTIONS(5541),
    [anon_sym_constinit] = ACTIONS(5541),
    [anon_sym_consteval] = ACTIONS(5541),
    [anon_sym___shared__] = ACTIONS(5541),
    [anon_sym___local__] = ACTIONS(5541),
    [anon_sym___constant__] = ACTIONS(5541),
    [anon_sym___managed__] = ACTIONS(5541),
    [anon_sym___grid_constant__] = ACTIONS(5541),
    [anon_sym_alignas] = ACTIONS(5541),
    [anon_sym__Alignas] = ACTIONS(5541),
    [sym_primitive_type] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_class] = ACTIONS(5541),
    [anon_sym_struct] = ACTIONS(5541),
    [anon_sym_union] = ACTIONS(5541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
    [anon_sym_explicit] = ACTIONS(5541),
    [anon_sym_typename] = ACTIONS(5541),
    [anon_sym_template] = ACTIONS(5541),
    [anon_sym_operator] = ACTIONS(5541),
    [anon_sym_friend] = ACTIONS(5541),
    [anon_sym_public] = ACTIONS(5541),
    [anon_sym_private] = ACTIONS(5541),
    [anon_sym_protected] = ACTIONS(5541),
    [anon_sym_using] = ACTIONS(5541),
    [anon_sym_static_assert] = ACTIONS(5541),
    [anon_sym___launch_bounds__] = ACTIONS(5541),
  },
  [STATE(1783)] = {
    [sym_identifier] = ACTIONS(5541),
    [aux_sym_preproc_def_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token2] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5541),
    [aux_sym_preproc_else_token1] = ACTIONS(5541),
    [aux_sym_preproc_elif_token1] = ACTIONS(5541),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5541),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5541),
    [sym_preproc_directive] = ACTIONS(5541),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_TILDE] = ACTIONS(5543),
    [anon_sym_STAR] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___extension__] = ACTIONS(5541),
    [anon_sym_typedef] = ACTIONS(5541),
    [anon_sym___device__] = ACTIONS(5541),
    [anon_sym___host__] = ACTIONS(5541),
    [anon_sym___global__] = ACTIONS(5541),
    [anon_sym___forceinline__] = ACTIONS(5541),
    [anon_sym___noinline__] = ACTIONS(5541),
    [anon_sym_virtual] = ACTIONS(5541),
    [anon_sym_extern] = ACTIONS(5541),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym___attribute] = ACTIONS(5541),
    [anon_sym_COLON_COLON] = ACTIONS(5543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5543),
    [anon_sym___declspec] = ACTIONS(5541),
    [anon_sym___based] = ACTIONS(5541),
    [anon_sym_signed] = ACTIONS(5541),
    [anon_sym_unsigned] = ACTIONS(5541),
    [anon_sym_long] = ACTIONS(5541),
    [anon_sym_short] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5541),
    [anon_sym_static] = ACTIONS(5541),
    [anon_sym_register] = ACTIONS(5541),
    [anon_sym_inline] = ACTIONS(5541),
    [anon_sym___inline] = ACTIONS(5541),
    [anon_sym___inline__] = ACTIONS(5541),
    [anon_sym___forceinline] = ACTIONS(5541),
    [anon_sym_thread_local] = ACTIONS(5541),
    [anon_sym___thread] = ACTIONS(5541),
    [anon_sym_const] = ACTIONS(5541),
    [anon_sym_constexpr] = ACTIONS(5541),
    [anon_sym_volatile] = ACTIONS(5541),
    [anon_sym_restrict] = ACTIONS(5541),
    [anon_sym___restrict__] = ACTIONS(5541),
    [anon_sym__Atomic] = ACTIONS(5541),
    [anon_sym__Noreturn] = ACTIONS(5541),
    [anon_sym_noreturn] = ACTIONS(5541),
    [anon_sym__Nonnull] = ACTIONS(5541),
    [anon_sym_mutable] = ACTIONS(5541),
    [anon_sym_constinit] = ACTIONS(5541),
    [anon_sym_consteval] = ACTIONS(5541),
    [anon_sym___shared__] = ACTIONS(5541),
    [anon_sym___local__] = ACTIONS(5541),
    [anon_sym___constant__] = ACTIONS(5541),
    [anon_sym___managed__] = ACTIONS(5541),
    [anon_sym___grid_constant__] = ACTIONS(5541),
    [anon_sym_alignas] = ACTIONS(5541),
    [anon_sym__Alignas] = ACTIONS(5541),
    [sym_primitive_type] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_class] = ACTIONS(5541),
    [anon_sym_struct] = ACTIONS(5541),
    [anon_sym_union] = ACTIONS(5541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
    [anon_sym_explicit] = ACTIONS(5541),
    [anon_sym_typename] = ACTIONS(5541),
    [anon_sym_template] = ACTIONS(5541),
    [anon_sym_operator] = ACTIONS(5541),
    [anon_sym_friend] = ACTIONS(5541),
    [anon_sym_public] = ACTIONS(5541),
    [anon_sym_private] = ACTIONS(5541),
    [anon_sym_protected] = ACTIONS(5541),
    [anon_sym_using] = ACTIONS(5541),
    [anon_sym_static_assert] = ACTIONS(5541),
    [anon_sym___launch_bounds__] = ACTIONS(5541),
  },
  [STATE(1784)] = {
    [sym_identifier] = ACTIONS(5545),
    [aux_sym_preproc_def_token1] = ACTIONS(5545),
    [aux_sym_preproc_if_token1] = ACTIONS(5545),
    [aux_sym_preproc_if_token2] = ACTIONS(5545),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5545),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5545),
    [aux_sym_preproc_else_token1] = ACTIONS(5545),
    [aux_sym_preproc_elif_token1] = ACTIONS(5545),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5545),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5545),
    [sym_preproc_directive] = ACTIONS(5545),
    [anon_sym_LPAREN2] = ACTIONS(5547),
    [anon_sym_TILDE] = ACTIONS(5547),
    [anon_sym_STAR] = ACTIONS(5547),
    [anon_sym_AMP_AMP] = ACTIONS(5547),
    [anon_sym_AMP] = ACTIONS(5545),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym___extension__] = ACTIONS(5545),
    [anon_sym_typedef] = ACTIONS(5545),
    [anon_sym___device__] = ACTIONS(5545),
    [anon_sym___host__] = ACTIONS(5545),
    [anon_sym___global__] = ACTIONS(5545),
    [anon_sym___forceinline__] = ACTIONS(5545),
    [anon_sym___noinline__] = ACTIONS(5545),
    [anon_sym_virtual] = ACTIONS(5545),
    [anon_sym_extern] = ACTIONS(5545),
    [anon_sym___attribute__] = ACTIONS(5545),
    [anon_sym___attribute] = ACTIONS(5545),
    [anon_sym_COLON_COLON] = ACTIONS(5547),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5547),
    [anon_sym___declspec] = ACTIONS(5545),
    [anon_sym___based] = ACTIONS(5545),
    [anon_sym_signed] = ACTIONS(5545),
    [anon_sym_unsigned] = ACTIONS(5545),
    [anon_sym_long] = ACTIONS(5545),
    [anon_sym_short] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5545),
    [anon_sym_static] = ACTIONS(5545),
    [anon_sym_register] = ACTIONS(5545),
    [anon_sym_inline] = ACTIONS(5545),
    [anon_sym___inline] = ACTIONS(5545),
    [anon_sym___inline__] = ACTIONS(5545),
    [anon_sym___forceinline] = ACTIONS(5545),
    [anon_sym_thread_local] = ACTIONS(5545),
    [anon_sym___thread] = ACTIONS(5545),
    [anon_sym_const] = ACTIONS(5545),
    [anon_sym_constexpr] = ACTIONS(5545),
    [anon_sym_volatile] = ACTIONS(5545),
    [anon_sym_restrict] = ACTIONS(5545),
    [anon_sym___restrict__] = ACTIONS(5545),
    [anon_sym__Atomic] = ACTIONS(5545),
    [anon_sym__Noreturn] = ACTIONS(5545),
    [anon_sym_noreturn] = ACTIONS(5545),
    [anon_sym__Nonnull] = ACTIONS(5545),
    [anon_sym_mutable] = ACTIONS(5545),
    [anon_sym_constinit] = ACTIONS(5545),
    [anon_sym_consteval] = ACTIONS(5545),
    [anon_sym___shared__] = ACTIONS(5545),
    [anon_sym___local__] = ACTIONS(5545),
    [anon_sym___constant__] = ACTIONS(5545),
    [anon_sym___managed__] = ACTIONS(5545),
    [anon_sym___grid_constant__] = ACTIONS(5545),
    [anon_sym_alignas] = ACTIONS(5545),
    [anon_sym__Alignas] = ACTIONS(5545),
    [sym_primitive_type] = ACTIONS(5545),
    [anon_sym_enum] = ACTIONS(5545),
    [anon_sym_class] = ACTIONS(5545),
    [anon_sym_struct] = ACTIONS(5545),
    [anon_sym_union] = ACTIONS(5545),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5545),
    [anon_sym_decltype] = ACTIONS(5545),
    [anon_sym_explicit] = ACTIONS(5545),
    [anon_sym_typename] = ACTIONS(5545),
    [anon_sym_template] = ACTIONS(5545),
    [anon_sym_operator] = ACTIONS(5545),
    [anon_sym_friend] = ACTIONS(5545),
    [anon_sym_public] = ACTIONS(5545),
    [anon_sym_private] = ACTIONS(5545),
    [anon_sym_protected] = ACTIONS(5545),
    [anon_sym_using] = ACTIONS(5545),
    [anon_sym_static_assert] = ACTIONS(5545),
    [anon_sym___launch_bounds__] = ACTIONS(5545),
  },
  [STATE(1785)] = {
    [sym_identifier] = ACTIONS(5549),
    [aux_sym_preproc_def_token1] = ACTIONS(5549),
    [aux_sym_preproc_if_token1] = ACTIONS(5549),
    [aux_sym_preproc_if_token2] = ACTIONS(5549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5549),
    [aux_sym_preproc_else_token1] = ACTIONS(5549),
    [aux_sym_preproc_elif_token1] = ACTIONS(5549),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5549),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5549),
    [sym_preproc_directive] = ACTIONS(5549),
    [anon_sym_LPAREN2] = ACTIONS(5551),
    [anon_sym_TILDE] = ACTIONS(5551),
    [anon_sym_STAR] = ACTIONS(5551),
    [anon_sym_AMP_AMP] = ACTIONS(5551),
    [anon_sym_AMP] = ACTIONS(5549),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym___extension__] = ACTIONS(5549),
    [anon_sym_typedef] = ACTIONS(5549),
    [anon_sym___device__] = ACTIONS(5549),
    [anon_sym___host__] = ACTIONS(5549),
    [anon_sym___global__] = ACTIONS(5549),
    [anon_sym___forceinline__] = ACTIONS(5549),
    [anon_sym___noinline__] = ACTIONS(5549),
    [anon_sym_virtual] = ACTIONS(5549),
    [anon_sym_extern] = ACTIONS(5549),
    [anon_sym___attribute__] = ACTIONS(5549),
    [anon_sym___attribute] = ACTIONS(5549),
    [anon_sym_COLON_COLON] = ACTIONS(5551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5551),
    [anon_sym___declspec] = ACTIONS(5549),
    [anon_sym___based] = ACTIONS(5549),
    [anon_sym_signed] = ACTIONS(5549),
    [anon_sym_unsigned] = ACTIONS(5549),
    [anon_sym_long] = ACTIONS(5549),
    [anon_sym_short] = ACTIONS(5549),
    [anon_sym_LBRACK] = ACTIONS(5549),
    [anon_sym_static] = ACTIONS(5549),
    [anon_sym_register] = ACTIONS(5549),
    [anon_sym_inline] = ACTIONS(5549),
    [anon_sym___inline] = ACTIONS(5549),
    [anon_sym___inline__] = ACTIONS(5549),
    [anon_sym___forceinline] = ACTIONS(5549),
    [anon_sym_thread_local] = ACTIONS(5549),
    [anon_sym___thread] = ACTIONS(5549),
    [anon_sym_const] = ACTIONS(5549),
    [anon_sym_constexpr] = ACTIONS(5549),
    [anon_sym_volatile] = ACTIONS(5549),
    [anon_sym_restrict] = ACTIONS(5549),
    [anon_sym___restrict__] = ACTIONS(5549),
    [anon_sym__Atomic] = ACTIONS(5549),
    [anon_sym__Noreturn] = ACTIONS(5549),
    [anon_sym_noreturn] = ACTIONS(5549),
    [anon_sym__Nonnull] = ACTIONS(5549),
    [anon_sym_mutable] = ACTIONS(5549),
    [anon_sym_constinit] = ACTIONS(5549),
    [anon_sym_consteval] = ACTIONS(5549),
    [anon_sym___shared__] = ACTIONS(5549),
    [anon_sym___local__] = ACTIONS(5549),
    [anon_sym___constant__] = ACTIONS(5549),
    [anon_sym___managed__] = ACTIONS(5549),
    [anon_sym___grid_constant__] = ACTIONS(5549),
    [anon_sym_alignas] = ACTIONS(5549),
    [anon_sym__Alignas] = ACTIONS(5549),
    [sym_primitive_type] = ACTIONS(5549),
    [anon_sym_enum] = ACTIONS(5549),
    [anon_sym_class] = ACTIONS(5549),
    [anon_sym_struct] = ACTIONS(5549),
    [anon_sym_union] = ACTIONS(5549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5549),
    [anon_sym_decltype] = ACTIONS(5549),
    [anon_sym_explicit] = ACTIONS(5549),
    [anon_sym_typename] = ACTIONS(5549),
    [anon_sym_template] = ACTIONS(5549),
    [anon_sym_operator] = ACTIONS(5549),
    [anon_sym_friend] = ACTIONS(5549),
    [anon_sym_public] = ACTIONS(5549),
    [anon_sym_private] = ACTIONS(5549),
    [anon_sym_protected] = ACTIONS(5549),
    [anon_sym_using] = ACTIONS(5549),
    [anon_sym_static_assert] = ACTIONS(5549),
    [anon_sym___launch_bounds__] = ACTIONS(5549),
  },
  [STATE(1786)] = {
    [sym_identifier] = ACTIONS(5553),
    [aux_sym_preproc_def_token1] = ACTIONS(5553),
    [aux_sym_preproc_if_token1] = ACTIONS(5553),
    [aux_sym_preproc_if_token2] = ACTIONS(5553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5553),
    [aux_sym_preproc_else_token1] = ACTIONS(5553),
    [aux_sym_preproc_elif_token1] = ACTIONS(5553),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5553),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5553),
    [sym_preproc_directive] = ACTIONS(5553),
    [anon_sym_LPAREN2] = ACTIONS(5555),
    [anon_sym_TILDE] = ACTIONS(5555),
    [anon_sym_STAR] = ACTIONS(5555),
    [anon_sym_AMP_AMP] = ACTIONS(5555),
    [anon_sym_AMP] = ACTIONS(5553),
    [anon_sym_SEMI] = ACTIONS(5555),
    [anon_sym___extension__] = ACTIONS(5553),
    [anon_sym_typedef] = ACTIONS(5553),
    [anon_sym___device__] = ACTIONS(5553),
    [anon_sym___host__] = ACTIONS(5553),
    [anon_sym___global__] = ACTIONS(5553),
    [anon_sym___forceinline__] = ACTIONS(5553),
    [anon_sym___noinline__] = ACTIONS(5553),
    [anon_sym_virtual] = ACTIONS(5553),
    [anon_sym_extern] = ACTIONS(5553),
    [anon_sym___attribute__] = ACTIONS(5553),
    [anon_sym___attribute] = ACTIONS(5553),
    [anon_sym_COLON_COLON] = ACTIONS(5555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5555),
    [anon_sym___declspec] = ACTIONS(5553),
    [anon_sym___based] = ACTIONS(5553),
    [anon_sym_signed] = ACTIONS(5553),
    [anon_sym_unsigned] = ACTIONS(5553),
    [anon_sym_long] = ACTIONS(5553),
    [anon_sym_short] = ACTIONS(5553),
    [anon_sym_LBRACK] = ACTIONS(5553),
    [anon_sym_static] = ACTIONS(5553),
    [anon_sym_register] = ACTIONS(5553),
    [anon_sym_inline] = ACTIONS(5553),
    [anon_sym___inline] = ACTIONS(5553),
    [anon_sym___inline__] = ACTIONS(5553),
    [anon_sym___forceinline] = ACTIONS(5553),
    [anon_sym_thread_local] = ACTIONS(5553),
    [anon_sym___thread] = ACTIONS(5553),
    [anon_sym_const] = ACTIONS(5553),
    [anon_sym_constexpr] = ACTIONS(5553),
    [anon_sym_volatile] = ACTIONS(5553),
    [anon_sym_restrict] = ACTIONS(5553),
    [anon_sym___restrict__] = ACTIONS(5553),
    [anon_sym__Atomic] = ACTIONS(5553),
    [anon_sym__Noreturn] = ACTIONS(5553),
    [anon_sym_noreturn] = ACTIONS(5553),
    [anon_sym__Nonnull] = ACTIONS(5553),
    [anon_sym_mutable] = ACTIONS(5553),
    [anon_sym_constinit] = ACTIONS(5553),
    [anon_sym_consteval] = ACTIONS(5553),
    [anon_sym___shared__] = ACTIONS(5553),
    [anon_sym___local__] = ACTIONS(5553),
    [anon_sym___constant__] = ACTIONS(5553),
    [anon_sym___managed__] = ACTIONS(5553),
    [anon_sym___grid_constant__] = ACTIONS(5553),
    [anon_sym_alignas] = ACTIONS(5553),
    [anon_sym__Alignas] = ACTIONS(5553),
    [sym_primitive_type] = ACTIONS(5553),
    [anon_sym_enum] = ACTIONS(5553),
    [anon_sym_class] = ACTIONS(5553),
    [anon_sym_struct] = ACTIONS(5553),
    [anon_sym_union] = ACTIONS(5553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5553),
    [anon_sym_decltype] = ACTIONS(5553),
    [anon_sym_explicit] = ACTIONS(5553),
    [anon_sym_typename] = ACTIONS(5553),
    [anon_sym_template] = ACTIONS(5553),
    [anon_sym_operator] = ACTIONS(5553),
    [anon_sym_friend] = ACTIONS(5553),
    [anon_sym_public] = ACTIONS(5553),
    [anon_sym_private] = ACTIONS(5553),
    [anon_sym_protected] = ACTIONS(5553),
    [anon_sym_using] = ACTIONS(5553),
    [anon_sym_static_assert] = ACTIONS(5553),
    [anon_sym___launch_bounds__] = ACTIONS(5553),
  },
  [STATE(1787)] = {
    [sym_identifier] = ACTIONS(5557),
    [aux_sym_preproc_def_token1] = ACTIONS(5557),
    [aux_sym_preproc_if_token1] = ACTIONS(5557),
    [aux_sym_preproc_if_token2] = ACTIONS(5557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5557),
    [aux_sym_preproc_else_token1] = ACTIONS(5557),
    [aux_sym_preproc_elif_token1] = ACTIONS(5557),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5557),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5557),
    [sym_preproc_directive] = ACTIONS(5557),
    [anon_sym_LPAREN2] = ACTIONS(5559),
    [anon_sym_TILDE] = ACTIONS(5559),
    [anon_sym_STAR] = ACTIONS(5559),
    [anon_sym_AMP_AMP] = ACTIONS(5559),
    [anon_sym_AMP] = ACTIONS(5557),
    [anon_sym_SEMI] = ACTIONS(5559),
    [anon_sym___extension__] = ACTIONS(5557),
    [anon_sym_typedef] = ACTIONS(5557),
    [anon_sym___device__] = ACTIONS(5557),
    [anon_sym___host__] = ACTIONS(5557),
    [anon_sym___global__] = ACTIONS(5557),
    [anon_sym___forceinline__] = ACTIONS(5557),
    [anon_sym___noinline__] = ACTIONS(5557),
    [anon_sym_virtual] = ACTIONS(5557),
    [anon_sym_extern] = ACTIONS(5557),
    [anon_sym___attribute__] = ACTIONS(5557),
    [anon_sym___attribute] = ACTIONS(5557),
    [anon_sym_COLON_COLON] = ACTIONS(5559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5559),
    [anon_sym___declspec] = ACTIONS(5557),
    [anon_sym___based] = ACTIONS(5557),
    [anon_sym_signed] = ACTIONS(5557),
    [anon_sym_unsigned] = ACTIONS(5557),
    [anon_sym_long] = ACTIONS(5557),
    [anon_sym_short] = ACTIONS(5557),
    [anon_sym_LBRACK] = ACTIONS(5557),
    [anon_sym_static] = ACTIONS(5557),
    [anon_sym_register] = ACTIONS(5557),
    [anon_sym_inline] = ACTIONS(5557),
    [anon_sym___inline] = ACTIONS(5557),
    [anon_sym___inline__] = ACTIONS(5557),
    [anon_sym___forceinline] = ACTIONS(5557),
    [anon_sym_thread_local] = ACTIONS(5557),
    [anon_sym___thread] = ACTIONS(5557),
    [anon_sym_const] = ACTIONS(5557),
    [anon_sym_constexpr] = ACTIONS(5557),
    [anon_sym_volatile] = ACTIONS(5557),
    [anon_sym_restrict] = ACTIONS(5557),
    [anon_sym___restrict__] = ACTIONS(5557),
    [anon_sym__Atomic] = ACTIONS(5557),
    [anon_sym__Noreturn] = ACTIONS(5557),
    [anon_sym_noreturn] = ACTIONS(5557),
    [anon_sym__Nonnull] = ACTIONS(5557),
    [anon_sym_mutable] = ACTIONS(5557),
    [anon_sym_constinit] = ACTIONS(5557),
    [anon_sym_consteval] = ACTIONS(5557),
    [anon_sym___shared__] = ACTIONS(5557),
    [anon_sym___local__] = ACTIONS(5557),
    [anon_sym___constant__] = ACTIONS(5557),
    [anon_sym___managed__] = ACTIONS(5557),
    [anon_sym___grid_constant__] = ACTIONS(5557),
    [anon_sym_alignas] = ACTIONS(5557),
    [anon_sym__Alignas] = ACTIONS(5557),
    [sym_primitive_type] = ACTIONS(5557),
    [anon_sym_enum] = ACTIONS(5557),
    [anon_sym_class] = ACTIONS(5557),
    [anon_sym_struct] = ACTIONS(5557),
    [anon_sym_union] = ACTIONS(5557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5557),
    [anon_sym_decltype] = ACTIONS(5557),
    [anon_sym_explicit] = ACTIONS(5557),
    [anon_sym_typename] = ACTIONS(5557),
    [anon_sym_template] = ACTIONS(5557),
    [anon_sym_operator] = ACTIONS(5557),
    [anon_sym_friend] = ACTIONS(5557),
    [anon_sym_public] = ACTIONS(5557),
    [anon_sym_private] = ACTIONS(5557),
    [anon_sym_protected] = ACTIONS(5557),
    [anon_sym_using] = ACTIONS(5557),
    [anon_sym_static_assert] = ACTIONS(5557),
    [anon_sym___launch_bounds__] = ACTIONS(5557),
  },
  [STATE(1788)] = {
    [sym_identifier] = ACTIONS(5561),
    [aux_sym_preproc_def_token1] = ACTIONS(5561),
    [aux_sym_preproc_if_token1] = ACTIONS(5561),
    [aux_sym_preproc_if_token2] = ACTIONS(5561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5561),
    [aux_sym_preproc_else_token1] = ACTIONS(5561),
    [aux_sym_preproc_elif_token1] = ACTIONS(5561),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5561),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5561),
    [sym_preproc_directive] = ACTIONS(5561),
    [anon_sym_LPAREN2] = ACTIONS(5563),
    [anon_sym_TILDE] = ACTIONS(5563),
    [anon_sym_STAR] = ACTIONS(5563),
    [anon_sym_AMP_AMP] = ACTIONS(5563),
    [anon_sym_AMP] = ACTIONS(5561),
    [anon_sym_SEMI] = ACTIONS(5563),
    [anon_sym___extension__] = ACTIONS(5561),
    [anon_sym_typedef] = ACTIONS(5561),
    [anon_sym___device__] = ACTIONS(5561),
    [anon_sym___host__] = ACTIONS(5561),
    [anon_sym___global__] = ACTIONS(5561),
    [anon_sym___forceinline__] = ACTIONS(5561),
    [anon_sym___noinline__] = ACTIONS(5561),
    [anon_sym_virtual] = ACTIONS(5561),
    [anon_sym_extern] = ACTIONS(5561),
    [anon_sym___attribute__] = ACTIONS(5561),
    [anon_sym___attribute] = ACTIONS(5561),
    [anon_sym_COLON_COLON] = ACTIONS(5563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5563),
    [anon_sym___declspec] = ACTIONS(5561),
    [anon_sym___based] = ACTIONS(5561),
    [anon_sym_signed] = ACTIONS(5561),
    [anon_sym_unsigned] = ACTIONS(5561),
    [anon_sym_long] = ACTIONS(5561),
    [anon_sym_short] = ACTIONS(5561),
    [anon_sym_LBRACK] = ACTIONS(5561),
    [anon_sym_static] = ACTIONS(5561),
    [anon_sym_register] = ACTIONS(5561),
    [anon_sym_inline] = ACTIONS(5561),
    [anon_sym___inline] = ACTIONS(5561),
    [anon_sym___inline__] = ACTIONS(5561),
    [anon_sym___forceinline] = ACTIONS(5561),
    [anon_sym_thread_local] = ACTIONS(5561),
    [anon_sym___thread] = ACTIONS(5561),
    [anon_sym_const] = ACTIONS(5561),
    [anon_sym_constexpr] = ACTIONS(5561),
    [anon_sym_volatile] = ACTIONS(5561),
    [anon_sym_restrict] = ACTIONS(5561),
    [anon_sym___restrict__] = ACTIONS(5561),
    [anon_sym__Atomic] = ACTIONS(5561),
    [anon_sym__Noreturn] = ACTIONS(5561),
    [anon_sym_noreturn] = ACTIONS(5561),
    [anon_sym__Nonnull] = ACTIONS(5561),
    [anon_sym_mutable] = ACTIONS(5561),
    [anon_sym_constinit] = ACTIONS(5561),
    [anon_sym_consteval] = ACTIONS(5561),
    [anon_sym___shared__] = ACTIONS(5561),
    [anon_sym___local__] = ACTIONS(5561),
    [anon_sym___constant__] = ACTIONS(5561),
    [anon_sym___managed__] = ACTIONS(5561),
    [anon_sym___grid_constant__] = ACTIONS(5561),
    [anon_sym_alignas] = ACTIONS(5561),
    [anon_sym__Alignas] = ACTIONS(5561),
    [sym_primitive_type] = ACTIONS(5561),
    [anon_sym_enum] = ACTIONS(5561),
    [anon_sym_class] = ACTIONS(5561),
    [anon_sym_struct] = ACTIONS(5561),
    [anon_sym_union] = ACTIONS(5561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5561),
    [anon_sym_decltype] = ACTIONS(5561),
    [anon_sym_explicit] = ACTIONS(5561),
    [anon_sym_typename] = ACTIONS(5561),
    [anon_sym_template] = ACTIONS(5561),
    [anon_sym_operator] = ACTIONS(5561),
    [anon_sym_friend] = ACTIONS(5561),
    [anon_sym_public] = ACTIONS(5561),
    [anon_sym_private] = ACTIONS(5561),
    [anon_sym_protected] = ACTIONS(5561),
    [anon_sym_using] = ACTIONS(5561),
    [anon_sym_static_assert] = ACTIONS(5561),
    [anon_sym___launch_bounds__] = ACTIONS(5561),
  },
  [STATE(1789)] = {
    [sym_identifier] = ACTIONS(5565),
    [aux_sym_preproc_def_token1] = ACTIONS(5565),
    [aux_sym_preproc_if_token1] = ACTIONS(5565),
    [aux_sym_preproc_if_token2] = ACTIONS(5565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5565),
    [aux_sym_preproc_else_token1] = ACTIONS(5565),
    [aux_sym_preproc_elif_token1] = ACTIONS(5565),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5565),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5565),
    [sym_preproc_directive] = ACTIONS(5565),
    [anon_sym_LPAREN2] = ACTIONS(5567),
    [anon_sym_TILDE] = ACTIONS(5567),
    [anon_sym_STAR] = ACTIONS(5567),
    [anon_sym_AMP_AMP] = ACTIONS(5567),
    [anon_sym_AMP] = ACTIONS(5565),
    [anon_sym_SEMI] = ACTIONS(5567),
    [anon_sym___extension__] = ACTIONS(5565),
    [anon_sym_typedef] = ACTIONS(5565),
    [anon_sym___device__] = ACTIONS(5565),
    [anon_sym___host__] = ACTIONS(5565),
    [anon_sym___global__] = ACTIONS(5565),
    [anon_sym___forceinline__] = ACTIONS(5565),
    [anon_sym___noinline__] = ACTIONS(5565),
    [anon_sym_virtual] = ACTIONS(5565),
    [anon_sym_extern] = ACTIONS(5565),
    [anon_sym___attribute__] = ACTIONS(5565),
    [anon_sym___attribute] = ACTIONS(5565),
    [anon_sym_COLON_COLON] = ACTIONS(5567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5567),
    [anon_sym___declspec] = ACTIONS(5565),
    [anon_sym___based] = ACTIONS(5565),
    [anon_sym_signed] = ACTIONS(5565),
    [anon_sym_unsigned] = ACTIONS(5565),
    [anon_sym_long] = ACTIONS(5565),
    [anon_sym_short] = ACTIONS(5565),
    [anon_sym_LBRACK] = ACTIONS(5565),
    [anon_sym_static] = ACTIONS(5565),
    [anon_sym_register] = ACTIONS(5565),
    [anon_sym_inline] = ACTIONS(5565),
    [anon_sym___inline] = ACTIONS(5565),
    [anon_sym___inline__] = ACTIONS(5565),
    [anon_sym___forceinline] = ACTIONS(5565),
    [anon_sym_thread_local] = ACTIONS(5565),
    [anon_sym___thread] = ACTIONS(5565),
    [anon_sym_const] = ACTIONS(5565),
    [anon_sym_constexpr] = ACTIONS(5565),
    [anon_sym_volatile] = ACTIONS(5565),
    [anon_sym_restrict] = ACTIONS(5565),
    [anon_sym___restrict__] = ACTIONS(5565),
    [anon_sym__Atomic] = ACTIONS(5565),
    [anon_sym__Noreturn] = ACTIONS(5565),
    [anon_sym_noreturn] = ACTIONS(5565),
    [anon_sym__Nonnull] = ACTIONS(5565),
    [anon_sym_mutable] = ACTIONS(5565),
    [anon_sym_constinit] = ACTIONS(5565),
    [anon_sym_consteval] = ACTIONS(5565),
    [anon_sym___shared__] = ACTIONS(5565),
    [anon_sym___local__] = ACTIONS(5565),
    [anon_sym___constant__] = ACTIONS(5565),
    [anon_sym___managed__] = ACTIONS(5565),
    [anon_sym___grid_constant__] = ACTIONS(5565),
    [anon_sym_alignas] = ACTIONS(5565),
    [anon_sym__Alignas] = ACTIONS(5565),
    [sym_primitive_type] = ACTIONS(5565),
    [anon_sym_enum] = ACTIONS(5565),
    [anon_sym_class] = ACTIONS(5565),
    [anon_sym_struct] = ACTIONS(5565),
    [anon_sym_union] = ACTIONS(5565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5565),
    [anon_sym_decltype] = ACTIONS(5565),
    [anon_sym_explicit] = ACTIONS(5565),
    [anon_sym_typename] = ACTIONS(5565),
    [anon_sym_template] = ACTIONS(5565),
    [anon_sym_operator] = ACTIONS(5565),
    [anon_sym_friend] = ACTIONS(5565),
    [anon_sym_public] = ACTIONS(5565),
    [anon_sym_private] = ACTIONS(5565),
    [anon_sym_protected] = ACTIONS(5565),
    [anon_sym_using] = ACTIONS(5565),
    [anon_sym_static_assert] = ACTIONS(5565),
    [anon_sym___launch_bounds__] = ACTIONS(5565),
  },
  [STATE(1790)] = {
    [sym_identifier] = ACTIONS(5569),
    [aux_sym_preproc_def_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token2] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5569),
    [aux_sym_preproc_else_token1] = ACTIONS(5569),
    [aux_sym_preproc_elif_token1] = ACTIONS(5569),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5569),
    [sym_preproc_directive] = ACTIONS(5569),
    [anon_sym_LPAREN2] = ACTIONS(5571),
    [anon_sym_TILDE] = ACTIONS(5571),
    [anon_sym_STAR] = ACTIONS(5571),
    [anon_sym_AMP_AMP] = ACTIONS(5571),
    [anon_sym_AMP] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym___extension__] = ACTIONS(5569),
    [anon_sym_typedef] = ACTIONS(5569),
    [anon_sym___device__] = ACTIONS(5569),
    [anon_sym___host__] = ACTIONS(5569),
    [anon_sym___global__] = ACTIONS(5569),
    [anon_sym___forceinline__] = ACTIONS(5569),
    [anon_sym___noinline__] = ACTIONS(5569),
    [anon_sym_virtual] = ACTIONS(5569),
    [anon_sym_extern] = ACTIONS(5569),
    [anon_sym___attribute__] = ACTIONS(5569),
    [anon_sym___attribute] = ACTIONS(5569),
    [anon_sym_COLON_COLON] = ACTIONS(5571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5571),
    [anon_sym___declspec] = ACTIONS(5569),
    [anon_sym___based] = ACTIONS(5569),
    [anon_sym_signed] = ACTIONS(5569),
    [anon_sym_unsigned] = ACTIONS(5569),
    [anon_sym_long] = ACTIONS(5569),
    [anon_sym_short] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5569),
    [anon_sym_static] = ACTIONS(5569),
    [anon_sym_register] = ACTIONS(5569),
    [anon_sym_inline] = ACTIONS(5569),
    [anon_sym___inline] = ACTIONS(5569),
    [anon_sym___inline__] = ACTIONS(5569),
    [anon_sym___forceinline] = ACTIONS(5569),
    [anon_sym_thread_local] = ACTIONS(5569),
    [anon_sym___thread] = ACTIONS(5569),
    [anon_sym_const] = ACTIONS(5569),
    [anon_sym_constexpr] = ACTIONS(5569),
    [anon_sym_volatile] = ACTIONS(5569),
    [anon_sym_restrict] = ACTIONS(5569),
    [anon_sym___restrict__] = ACTIONS(5569),
    [anon_sym__Atomic] = ACTIONS(5569),
    [anon_sym__Noreturn] = ACTIONS(5569),
    [anon_sym_noreturn] = ACTIONS(5569),
    [anon_sym__Nonnull] = ACTIONS(5569),
    [anon_sym_mutable] = ACTIONS(5569),
    [anon_sym_constinit] = ACTIONS(5569),
    [anon_sym_consteval] = ACTIONS(5569),
    [anon_sym___shared__] = ACTIONS(5569),
    [anon_sym___local__] = ACTIONS(5569),
    [anon_sym___constant__] = ACTIONS(5569),
    [anon_sym___managed__] = ACTIONS(5569),
    [anon_sym___grid_constant__] = ACTIONS(5569),
    [anon_sym_alignas] = ACTIONS(5569),
    [anon_sym__Alignas] = ACTIONS(5569),
    [sym_primitive_type] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_class] = ACTIONS(5569),
    [anon_sym_struct] = ACTIONS(5569),
    [anon_sym_union] = ACTIONS(5569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5569),
    [anon_sym_decltype] = ACTIONS(5569),
    [anon_sym_explicit] = ACTIONS(5569),
    [anon_sym_typename] = ACTIONS(5569),
    [anon_sym_template] = ACTIONS(5569),
    [anon_sym_operator] = ACTIONS(5569),
    [anon_sym_friend] = ACTIONS(5569),
    [anon_sym_public] = ACTIONS(5569),
    [anon_sym_private] = ACTIONS(5569),
    [anon_sym_protected] = ACTIONS(5569),
    [anon_sym_using] = ACTIONS(5569),
    [anon_sym_static_assert] = ACTIONS(5569),
    [anon_sym___launch_bounds__] = ACTIONS(5569),
  },
  [STATE(1791)] = {
    [sym_identifier] = ACTIONS(5573),
    [aux_sym_preproc_def_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token2] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5573),
    [aux_sym_preproc_else_token1] = ACTIONS(5573),
    [aux_sym_preproc_elif_token1] = ACTIONS(5573),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5573),
    [sym_preproc_directive] = ACTIONS(5573),
    [anon_sym_LPAREN2] = ACTIONS(5575),
    [anon_sym_TILDE] = ACTIONS(5575),
    [anon_sym_STAR] = ACTIONS(5575),
    [anon_sym_AMP_AMP] = ACTIONS(5575),
    [anon_sym_AMP] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym___extension__] = ACTIONS(5573),
    [anon_sym_typedef] = ACTIONS(5573),
    [anon_sym___device__] = ACTIONS(5573),
    [anon_sym___host__] = ACTIONS(5573),
    [anon_sym___global__] = ACTIONS(5573),
    [anon_sym___forceinline__] = ACTIONS(5573),
    [anon_sym___noinline__] = ACTIONS(5573),
    [anon_sym_virtual] = ACTIONS(5573),
    [anon_sym_extern] = ACTIONS(5573),
    [anon_sym___attribute__] = ACTIONS(5573),
    [anon_sym___attribute] = ACTIONS(5573),
    [anon_sym_COLON_COLON] = ACTIONS(5575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5575),
    [anon_sym___declspec] = ACTIONS(5573),
    [anon_sym___based] = ACTIONS(5573),
    [anon_sym_signed] = ACTIONS(5573),
    [anon_sym_unsigned] = ACTIONS(5573),
    [anon_sym_long] = ACTIONS(5573),
    [anon_sym_short] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5573),
    [anon_sym_static] = ACTIONS(5573),
    [anon_sym_register] = ACTIONS(5573),
    [anon_sym_inline] = ACTIONS(5573),
    [anon_sym___inline] = ACTIONS(5573),
    [anon_sym___inline__] = ACTIONS(5573),
    [anon_sym___forceinline] = ACTIONS(5573),
    [anon_sym_thread_local] = ACTIONS(5573),
    [anon_sym___thread] = ACTIONS(5573),
    [anon_sym_const] = ACTIONS(5573),
    [anon_sym_constexpr] = ACTIONS(5573),
    [anon_sym_volatile] = ACTIONS(5573),
    [anon_sym_restrict] = ACTIONS(5573),
    [anon_sym___restrict__] = ACTIONS(5573),
    [anon_sym__Atomic] = ACTIONS(5573),
    [anon_sym__Noreturn] = ACTIONS(5573),
    [anon_sym_noreturn] = ACTIONS(5573),
    [anon_sym__Nonnull] = ACTIONS(5573),
    [anon_sym_mutable] = ACTIONS(5573),
    [anon_sym_constinit] = ACTIONS(5573),
    [anon_sym_consteval] = ACTIONS(5573),
    [anon_sym___shared__] = ACTIONS(5573),
    [anon_sym___local__] = ACTIONS(5573),
    [anon_sym___constant__] = ACTIONS(5573),
    [anon_sym___managed__] = ACTIONS(5573),
    [anon_sym___grid_constant__] = ACTIONS(5573),
    [anon_sym_alignas] = ACTIONS(5573),
    [anon_sym__Alignas] = ACTIONS(5573),
    [sym_primitive_type] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_class] = ACTIONS(5573),
    [anon_sym_struct] = ACTIONS(5573),
    [anon_sym_union] = ACTIONS(5573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5573),
    [anon_sym_decltype] = ACTIONS(5573),
    [anon_sym_explicit] = ACTIONS(5573),
    [anon_sym_typename] = ACTIONS(5573),
    [anon_sym_template] = ACTIONS(5573),
    [anon_sym_operator] = ACTIONS(5573),
    [anon_sym_friend] = ACTIONS(5573),
    [anon_sym_public] = ACTIONS(5573),
    [anon_sym_private] = ACTIONS(5573),
    [anon_sym_protected] = ACTIONS(5573),
    [anon_sym_using] = ACTIONS(5573),
    [anon_sym_static_assert] = ACTIONS(5573),
    [anon_sym___launch_bounds__] = ACTIONS(5573),
  },
  [STATE(1792)] = {
    [sym_identifier] = ACTIONS(5569),
    [aux_sym_preproc_def_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token2] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5569),
    [aux_sym_preproc_else_token1] = ACTIONS(5569),
    [aux_sym_preproc_elif_token1] = ACTIONS(5569),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5569),
    [sym_preproc_directive] = ACTIONS(5569),
    [anon_sym_LPAREN2] = ACTIONS(5571),
    [anon_sym_TILDE] = ACTIONS(5571),
    [anon_sym_STAR] = ACTIONS(5571),
    [anon_sym_AMP_AMP] = ACTIONS(5571),
    [anon_sym_AMP] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym___extension__] = ACTIONS(5569),
    [anon_sym_typedef] = ACTIONS(5569),
    [anon_sym___device__] = ACTIONS(5569),
    [anon_sym___host__] = ACTIONS(5569),
    [anon_sym___global__] = ACTIONS(5569),
    [anon_sym___forceinline__] = ACTIONS(5569),
    [anon_sym___noinline__] = ACTIONS(5569),
    [anon_sym_virtual] = ACTIONS(5569),
    [anon_sym_extern] = ACTIONS(5569),
    [anon_sym___attribute__] = ACTIONS(5569),
    [anon_sym___attribute] = ACTIONS(5569),
    [anon_sym_COLON_COLON] = ACTIONS(5571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5571),
    [anon_sym___declspec] = ACTIONS(5569),
    [anon_sym___based] = ACTIONS(5569),
    [anon_sym_signed] = ACTIONS(5569),
    [anon_sym_unsigned] = ACTIONS(5569),
    [anon_sym_long] = ACTIONS(5569),
    [anon_sym_short] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5569),
    [anon_sym_static] = ACTIONS(5569),
    [anon_sym_register] = ACTIONS(5569),
    [anon_sym_inline] = ACTIONS(5569),
    [anon_sym___inline] = ACTIONS(5569),
    [anon_sym___inline__] = ACTIONS(5569),
    [anon_sym___forceinline] = ACTIONS(5569),
    [anon_sym_thread_local] = ACTIONS(5569),
    [anon_sym___thread] = ACTIONS(5569),
    [anon_sym_const] = ACTIONS(5569),
    [anon_sym_constexpr] = ACTIONS(5569),
    [anon_sym_volatile] = ACTIONS(5569),
    [anon_sym_restrict] = ACTIONS(5569),
    [anon_sym___restrict__] = ACTIONS(5569),
    [anon_sym__Atomic] = ACTIONS(5569),
    [anon_sym__Noreturn] = ACTIONS(5569),
    [anon_sym_noreturn] = ACTIONS(5569),
    [anon_sym__Nonnull] = ACTIONS(5569),
    [anon_sym_mutable] = ACTIONS(5569),
    [anon_sym_constinit] = ACTIONS(5569),
    [anon_sym_consteval] = ACTIONS(5569),
    [anon_sym___shared__] = ACTIONS(5569),
    [anon_sym___local__] = ACTIONS(5569),
    [anon_sym___constant__] = ACTIONS(5569),
    [anon_sym___managed__] = ACTIONS(5569),
    [anon_sym___grid_constant__] = ACTIONS(5569),
    [anon_sym_alignas] = ACTIONS(5569),
    [anon_sym__Alignas] = ACTIONS(5569),
    [sym_primitive_type] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_class] = ACTIONS(5569),
    [anon_sym_struct] = ACTIONS(5569),
    [anon_sym_union] = ACTIONS(5569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5569),
    [anon_sym_decltype] = ACTIONS(5569),
    [anon_sym_explicit] = ACTIONS(5569),
    [anon_sym_typename] = ACTIONS(5569),
    [anon_sym_template] = ACTIONS(5569),
    [anon_sym_operator] = ACTIONS(5569),
    [anon_sym_friend] = ACTIONS(5569),
    [anon_sym_public] = ACTIONS(5569),
    [anon_sym_private] = ACTIONS(5569),
    [anon_sym_protected] = ACTIONS(5569),
    [anon_sym_using] = ACTIONS(5569),
    [anon_sym_static_assert] = ACTIONS(5569),
    [anon_sym___launch_bounds__] = ACTIONS(5569),
  },
  [STATE(1793)] = {
    [sym_identifier] = ACTIONS(5573),
    [aux_sym_preproc_def_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token2] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5573),
    [aux_sym_preproc_else_token1] = ACTIONS(5573),
    [aux_sym_preproc_elif_token1] = ACTIONS(5573),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5573),
    [sym_preproc_directive] = ACTIONS(5573),
    [anon_sym_LPAREN2] = ACTIONS(5575),
    [anon_sym_TILDE] = ACTIONS(5575),
    [anon_sym_STAR] = ACTIONS(5575),
    [anon_sym_AMP_AMP] = ACTIONS(5575),
    [anon_sym_AMP] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym___extension__] = ACTIONS(5573),
    [anon_sym_typedef] = ACTIONS(5573),
    [anon_sym___device__] = ACTIONS(5573),
    [anon_sym___host__] = ACTIONS(5573),
    [anon_sym___global__] = ACTIONS(5573),
    [anon_sym___forceinline__] = ACTIONS(5573),
    [anon_sym___noinline__] = ACTIONS(5573),
    [anon_sym_virtual] = ACTIONS(5573),
    [anon_sym_extern] = ACTIONS(5573),
    [anon_sym___attribute__] = ACTIONS(5573),
    [anon_sym___attribute] = ACTIONS(5573),
    [anon_sym_COLON_COLON] = ACTIONS(5575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5575),
    [anon_sym___declspec] = ACTIONS(5573),
    [anon_sym___based] = ACTIONS(5573),
    [anon_sym_signed] = ACTIONS(5573),
    [anon_sym_unsigned] = ACTIONS(5573),
    [anon_sym_long] = ACTIONS(5573),
    [anon_sym_short] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5573),
    [anon_sym_static] = ACTIONS(5573),
    [anon_sym_register] = ACTIONS(5573),
    [anon_sym_inline] = ACTIONS(5573),
    [anon_sym___inline] = ACTIONS(5573),
    [anon_sym___inline__] = ACTIONS(5573),
    [anon_sym___forceinline] = ACTIONS(5573),
    [anon_sym_thread_local] = ACTIONS(5573),
    [anon_sym___thread] = ACTIONS(5573),
    [anon_sym_const] = ACTIONS(5573),
    [anon_sym_constexpr] = ACTIONS(5573),
    [anon_sym_volatile] = ACTIONS(5573),
    [anon_sym_restrict] = ACTIONS(5573),
    [anon_sym___restrict__] = ACTIONS(5573),
    [anon_sym__Atomic] = ACTIONS(5573),
    [anon_sym__Noreturn] = ACTIONS(5573),
    [anon_sym_noreturn] = ACTIONS(5573),
    [anon_sym__Nonnull] = ACTIONS(5573),
    [anon_sym_mutable] = ACTIONS(5573),
    [anon_sym_constinit] = ACTIONS(5573),
    [anon_sym_consteval] = ACTIONS(5573),
    [anon_sym___shared__] = ACTIONS(5573),
    [anon_sym___local__] = ACTIONS(5573),
    [anon_sym___constant__] = ACTIONS(5573),
    [anon_sym___managed__] = ACTIONS(5573),
    [anon_sym___grid_constant__] = ACTIONS(5573),
    [anon_sym_alignas] = ACTIONS(5573),
    [anon_sym__Alignas] = ACTIONS(5573),
    [sym_primitive_type] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_class] = ACTIONS(5573),
    [anon_sym_struct] = ACTIONS(5573),
    [anon_sym_union] = ACTIONS(5573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5573),
    [anon_sym_decltype] = ACTIONS(5573),
    [anon_sym_explicit] = ACTIONS(5573),
    [anon_sym_typename] = ACTIONS(5573),
    [anon_sym_template] = ACTIONS(5573),
    [anon_sym_operator] = ACTIONS(5573),
    [anon_sym_friend] = ACTIONS(5573),
    [anon_sym_public] = ACTIONS(5573),
    [anon_sym_private] = ACTIONS(5573),
    [anon_sym_protected] = ACTIONS(5573),
    [anon_sym_using] = ACTIONS(5573),
    [anon_sym_static_assert] = ACTIONS(5573),
    [anon_sym___launch_bounds__] = ACTIONS(5573),
  },
  [STATE(1794)] = {
    [sym_identifier] = ACTIONS(5577),
    [aux_sym_preproc_def_token1] = ACTIONS(5577),
    [aux_sym_preproc_if_token1] = ACTIONS(5577),
    [aux_sym_preproc_if_token2] = ACTIONS(5577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5577),
    [aux_sym_preproc_else_token1] = ACTIONS(5577),
    [aux_sym_preproc_elif_token1] = ACTIONS(5577),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5577),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5577),
    [sym_preproc_directive] = ACTIONS(5577),
    [anon_sym_LPAREN2] = ACTIONS(5579),
    [anon_sym_TILDE] = ACTIONS(5579),
    [anon_sym_STAR] = ACTIONS(5579),
    [anon_sym_AMP_AMP] = ACTIONS(5579),
    [anon_sym_AMP] = ACTIONS(5577),
    [anon_sym_SEMI] = ACTIONS(5579),
    [anon_sym___extension__] = ACTIONS(5577),
    [anon_sym_typedef] = ACTIONS(5577),
    [anon_sym___device__] = ACTIONS(5577),
    [anon_sym___host__] = ACTIONS(5577),
    [anon_sym___global__] = ACTIONS(5577),
    [anon_sym___forceinline__] = ACTIONS(5577),
    [anon_sym___noinline__] = ACTIONS(5577),
    [anon_sym_virtual] = ACTIONS(5577),
    [anon_sym_extern] = ACTIONS(5577),
    [anon_sym___attribute__] = ACTIONS(5577),
    [anon_sym___attribute] = ACTIONS(5577),
    [anon_sym_COLON_COLON] = ACTIONS(5579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5579),
    [anon_sym___declspec] = ACTIONS(5577),
    [anon_sym___based] = ACTIONS(5577),
    [anon_sym_signed] = ACTIONS(5577),
    [anon_sym_unsigned] = ACTIONS(5577),
    [anon_sym_long] = ACTIONS(5577),
    [anon_sym_short] = ACTIONS(5577),
    [anon_sym_LBRACK] = ACTIONS(5577),
    [anon_sym_static] = ACTIONS(5577),
    [anon_sym_register] = ACTIONS(5577),
    [anon_sym_inline] = ACTIONS(5577),
    [anon_sym___inline] = ACTIONS(5577),
    [anon_sym___inline__] = ACTIONS(5577),
    [anon_sym___forceinline] = ACTIONS(5577),
    [anon_sym_thread_local] = ACTIONS(5577),
    [anon_sym___thread] = ACTIONS(5577),
    [anon_sym_const] = ACTIONS(5577),
    [anon_sym_constexpr] = ACTIONS(5577),
    [anon_sym_volatile] = ACTIONS(5577),
    [anon_sym_restrict] = ACTIONS(5577),
    [anon_sym___restrict__] = ACTIONS(5577),
    [anon_sym__Atomic] = ACTIONS(5577),
    [anon_sym__Noreturn] = ACTIONS(5577),
    [anon_sym_noreturn] = ACTIONS(5577),
    [anon_sym__Nonnull] = ACTIONS(5577),
    [anon_sym_mutable] = ACTIONS(5577),
    [anon_sym_constinit] = ACTIONS(5577),
    [anon_sym_consteval] = ACTIONS(5577),
    [anon_sym___shared__] = ACTIONS(5577),
    [anon_sym___local__] = ACTIONS(5577),
    [anon_sym___constant__] = ACTIONS(5577),
    [anon_sym___managed__] = ACTIONS(5577),
    [anon_sym___grid_constant__] = ACTIONS(5577),
    [anon_sym_alignas] = ACTIONS(5577),
    [anon_sym__Alignas] = ACTIONS(5577),
    [sym_primitive_type] = ACTIONS(5577),
    [anon_sym_enum] = ACTIONS(5577),
    [anon_sym_class] = ACTIONS(5577),
    [anon_sym_struct] = ACTIONS(5577),
    [anon_sym_union] = ACTIONS(5577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5577),
    [anon_sym_decltype] = ACTIONS(5577),
    [anon_sym_explicit] = ACTIONS(5577),
    [anon_sym_typename] = ACTIONS(5577),
    [anon_sym_template] = ACTIONS(5577),
    [anon_sym_operator] = ACTIONS(5577),
    [anon_sym_friend] = ACTIONS(5577),
    [anon_sym_public] = ACTIONS(5577),
    [anon_sym_private] = ACTIONS(5577),
    [anon_sym_protected] = ACTIONS(5577),
    [anon_sym_using] = ACTIONS(5577),
    [anon_sym_static_assert] = ACTIONS(5577),
    [anon_sym___launch_bounds__] = ACTIONS(5577),
  },
  [STATE(1795)] = {
    [sym_identifier] = ACTIONS(5581),
    [aux_sym_preproc_def_token1] = ACTIONS(5581),
    [aux_sym_preproc_if_token1] = ACTIONS(5581),
    [aux_sym_preproc_if_token2] = ACTIONS(5581),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5581),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5581),
    [aux_sym_preproc_else_token1] = ACTIONS(5581),
    [aux_sym_preproc_elif_token1] = ACTIONS(5581),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5581),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5581),
    [sym_preproc_directive] = ACTIONS(5581),
    [anon_sym_LPAREN2] = ACTIONS(5583),
    [anon_sym_TILDE] = ACTIONS(5583),
    [anon_sym_STAR] = ACTIONS(5583),
    [anon_sym_AMP_AMP] = ACTIONS(5583),
    [anon_sym_AMP] = ACTIONS(5581),
    [anon_sym_SEMI] = ACTIONS(5583),
    [anon_sym___extension__] = ACTIONS(5581),
    [anon_sym_typedef] = ACTIONS(5581),
    [anon_sym___device__] = ACTIONS(5581),
    [anon_sym___host__] = ACTIONS(5581),
    [anon_sym___global__] = ACTIONS(5581),
    [anon_sym___forceinline__] = ACTIONS(5581),
    [anon_sym___noinline__] = ACTIONS(5581),
    [anon_sym_virtual] = ACTIONS(5581),
    [anon_sym_extern] = ACTIONS(5581),
    [anon_sym___attribute__] = ACTIONS(5581),
    [anon_sym___attribute] = ACTIONS(5581),
    [anon_sym_COLON_COLON] = ACTIONS(5583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5583),
    [anon_sym___declspec] = ACTIONS(5581),
    [anon_sym___based] = ACTIONS(5581),
    [anon_sym_signed] = ACTIONS(5581),
    [anon_sym_unsigned] = ACTIONS(5581),
    [anon_sym_long] = ACTIONS(5581),
    [anon_sym_short] = ACTIONS(5581),
    [anon_sym_LBRACK] = ACTIONS(5581),
    [anon_sym_static] = ACTIONS(5581),
    [anon_sym_register] = ACTIONS(5581),
    [anon_sym_inline] = ACTIONS(5581),
    [anon_sym___inline] = ACTIONS(5581),
    [anon_sym___inline__] = ACTIONS(5581),
    [anon_sym___forceinline] = ACTIONS(5581),
    [anon_sym_thread_local] = ACTIONS(5581),
    [anon_sym___thread] = ACTIONS(5581),
    [anon_sym_const] = ACTIONS(5581),
    [anon_sym_constexpr] = ACTIONS(5581),
    [anon_sym_volatile] = ACTIONS(5581),
    [anon_sym_restrict] = ACTIONS(5581),
    [anon_sym___restrict__] = ACTIONS(5581),
    [anon_sym__Atomic] = ACTIONS(5581),
    [anon_sym__Noreturn] = ACTIONS(5581),
    [anon_sym_noreturn] = ACTIONS(5581),
    [anon_sym__Nonnull] = ACTIONS(5581),
    [anon_sym_mutable] = ACTIONS(5581),
    [anon_sym_constinit] = ACTIONS(5581),
    [anon_sym_consteval] = ACTIONS(5581),
    [anon_sym___shared__] = ACTIONS(5581),
    [anon_sym___local__] = ACTIONS(5581),
    [anon_sym___constant__] = ACTIONS(5581),
    [anon_sym___managed__] = ACTIONS(5581),
    [anon_sym___grid_constant__] = ACTIONS(5581),
    [anon_sym_alignas] = ACTIONS(5581),
    [anon_sym__Alignas] = ACTIONS(5581),
    [sym_primitive_type] = ACTIONS(5581),
    [anon_sym_enum] = ACTIONS(5581),
    [anon_sym_class] = ACTIONS(5581),
    [anon_sym_struct] = ACTIONS(5581),
    [anon_sym_union] = ACTIONS(5581),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5581),
    [anon_sym_decltype] = ACTIONS(5581),
    [anon_sym_explicit] = ACTIONS(5581),
    [anon_sym_typename] = ACTIONS(5581),
    [anon_sym_template] = ACTIONS(5581),
    [anon_sym_operator] = ACTIONS(5581),
    [anon_sym_friend] = ACTIONS(5581),
    [anon_sym_public] = ACTIONS(5581),
    [anon_sym_private] = ACTIONS(5581),
    [anon_sym_protected] = ACTIONS(5581),
    [anon_sym_using] = ACTIONS(5581),
    [anon_sym_static_assert] = ACTIONS(5581),
    [anon_sym___launch_bounds__] = ACTIONS(5581),
  },
  [STATE(1796)] = {
    [sym_identifier] = ACTIONS(5585),
    [aux_sym_preproc_def_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token2] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5585),
    [aux_sym_preproc_else_token1] = ACTIONS(5585),
    [aux_sym_preproc_elif_token1] = ACTIONS(5585),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5585),
    [sym_preproc_directive] = ACTIONS(5585),
    [anon_sym_LPAREN2] = ACTIONS(5587),
    [anon_sym_TILDE] = ACTIONS(5587),
    [anon_sym_STAR] = ACTIONS(5587),
    [anon_sym_AMP_AMP] = ACTIONS(5587),
    [anon_sym_AMP] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym___extension__] = ACTIONS(5585),
    [anon_sym_typedef] = ACTIONS(5585),
    [anon_sym___device__] = ACTIONS(5585),
    [anon_sym___host__] = ACTIONS(5585),
    [anon_sym___global__] = ACTIONS(5585),
    [anon_sym___forceinline__] = ACTIONS(5585),
    [anon_sym___noinline__] = ACTIONS(5585),
    [anon_sym_virtual] = ACTIONS(5585),
    [anon_sym_extern] = ACTIONS(5585),
    [anon_sym___attribute__] = ACTIONS(5585),
    [anon_sym___attribute] = ACTIONS(5585),
    [anon_sym_COLON_COLON] = ACTIONS(5587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5587),
    [anon_sym___declspec] = ACTIONS(5585),
    [anon_sym___based] = ACTIONS(5585),
    [anon_sym_signed] = ACTIONS(5585),
    [anon_sym_unsigned] = ACTIONS(5585),
    [anon_sym_long] = ACTIONS(5585),
    [anon_sym_short] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5585),
    [anon_sym_static] = ACTIONS(5585),
    [anon_sym_register] = ACTIONS(5585),
    [anon_sym_inline] = ACTIONS(5585),
    [anon_sym___inline] = ACTIONS(5585),
    [anon_sym___inline__] = ACTIONS(5585),
    [anon_sym___forceinline] = ACTIONS(5585),
    [anon_sym_thread_local] = ACTIONS(5585),
    [anon_sym___thread] = ACTIONS(5585),
    [anon_sym_const] = ACTIONS(5585),
    [anon_sym_constexpr] = ACTIONS(5585),
    [anon_sym_volatile] = ACTIONS(5585),
    [anon_sym_restrict] = ACTIONS(5585),
    [anon_sym___restrict__] = ACTIONS(5585),
    [anon_sym__Atomic] = ACTIONS(5585),
    [anon_sym__Noreturn] = ACTIONS(5585),
    [anon_sym_noreturn] = ACTIONS(5585),
    [anon_sym__Nonnull] = ACTIONS(5585),
    [anon_sym_mutable] = ACTIONS(5585),
    [anon_sym_constinit] = ACTIONS(5585),
    [anon_sym_consteval] = ACTIONS(5585),
    [anon_sym___shared__] = ACTIONS(5585),
    [anon_sym___local__] = ACTIONS(5585),
    [anon_sym___constant__] = ACTIONS(5585),
    [anon_sym___managed__] = ACTIONS(5585),
    [anon_sym___grid_constant__] = ACTIONS(5585),
    [anon_sym_alignas] = ACTIONS(5585),
    [anon_sym__Alignas] = ACTIONS(5585),
    [sym_primitive_type] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_struct] = ACTIONS(5585),
    [anon_sym_union] = ACTIONS(5585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5585),
    [anon_sym_decltype] = ACTIONS(5585),
    [anon_sym_explicit] = ACTIONS(5585),
    [anon_sym_typename] = ACTIONS(5585),
    [anon_sym_template] = ACTIONS(5585),
    [anon_sym_operator] = ACTIONS(5585),
    [anon_sym_friend] = ACTIONS(5585),
    [anon_sym_public] = ACTIONS(5585),
    [anon_sym_private] = ACTIONS(5585),
    [anon_sym_protected] = ACTIONS(5585),
    [anon_sym_using] = ACTIONS(5585),
    [anon_sym_static_assert] = ACTIONS(5585),
    [anon_sym___launch_bounds__] = ACTIONS(5585),
  },
  [STATE(1797)] = {
    [sym_identifier] = ACTIONS(5585),
    [aux_sym_preproc_def_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token2] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5585),
    [aux_sym_preproc_else_token1] = ACTIONS(5585),
    [aux_sym_preproc_elif_token1] = ACTIONS(5585),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5585),
    [sym_preproc_directive] = ACTIONS(5585),
    [anon_sym_LPAREN2] = ACTIONS(5587),
    [anon_sym_TILDE] = ACTIONS(5587),
    [anon_sym_STAR] = ACTIONS(5587),
    [anon_sym_AMP_AMP] = ACTIONS(5587),
    [anon_sym_AMP] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym___extension__] = ACTIONS(5585),
    [anon_sym_typedef] = ACTIONS(5585),
    [anon_sym___device__] = ACTIONS(5585),
    [anon_sym___host__] = ACTIONS(5585),
    [anon_sym___global__] = ACTIONS(5585),
    [anon_sym___forceinline__] = ACTIONS(5585),
    [anon_sym___noinline__] = ACTIONS(5585),
    [anon_sym_virtual] = ACTIONS(5585),
    [anon_sym_extern] = ACTIONS(5585),
    [anon_sym___attribute__] = ACTIONS(5585),
    [anon_sym___attribute] = ACTIONS(5585),
    [anon_sym_COLON_COLON] = ACTIONS(5587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5587),
    [anon_sym___declspec] = ACTIONS(5585),
    [anon_sym___based] = ACTIONS(5585),
    [anon_sym_signed] = ACTIONS(5585),
    [anon_sym_unsigned] = ACTIONS(5585),
    [anon_sym_long] = ACTIONS(5585),
    [anon_sym_short] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5585),
    [anon_sym_static] = ACTIONS(5585),
    [anon_sym_register] = ACTIONS(5585),
    [anon_sym_inline] = ACTIONS(5585),
    [anon_sym___inline] = ACTIONS(5585),
    [anon_sym___inline__] = ACTIONS(5585),
    [anon_sym___forceinline] = ACTIONS(5585),
    [anon_sym_thread_local] = ACTIONS(5585),
    [anon_sym___thread] = ACTIONS(5585),
    [anon_sym_const] = ACTIONS(5585),
    [anon_sym_constexpr] = ACTIONS(5585),
    [anon_sym_volatile] = ACTIONS(5585),
    [anon_sym_restrict] = ACTIONS(5585),
    [anon_sym___restrict__] = ACTIONS(5585),
    [anon_sym__Atomic] = ACTIONS(5585),
    [anon_sym__Noreturn] = ACTIONS(5585),
    [anon_sym_noreturn] = ACTIONS(5585),
    [anon_sym__Nonnull] = ACTIONS(5585),
    [anon_sym_mutable] = ACTIONS(5585),
    [anon_sym_constinit] = ACTIONS(5585),
    [anon_sym_consteval] = ACTIONS(5585),
    [anon_sym___shared__] = ACTIONS(5585),
    [anon_sym___local__] = ACTIONS(5585),
    [anon_sym___constant__] = ACTIONS(5585),
    [anon_sym___managed__] = ACTIONS(5585),
    [anon_sym___grid_constant__] = ACTIONS(5585),
    [anon_sym_alignas] = ACTIONS(5585),
    [anon_sym__Alignas] = ACTIONS(5585),
    [sym_primitive_type] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_struct] = ACTIONS(5585),
    [anon_sym_union] = ACTIONS(5585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5585),
    [anon_sym_decltype] = ACTIONS(5585),
    [anon_sym_explicit] = ACTIONS(5585),
    [anon_sym_typename] = ACTIONS(5585),
    [anon_sym_template] = ACTIONS(5585),
    [anon_sym_operator] = ACTIONS(5585),
    [anon_sym_friend] = ACTIONS(5585),
    [anon_sym_public] = ACTIONS(5585),
    [anon_sym_private] = ACTIONS(5585),
    [anon_sym_protected] = ACTIONS(5585),
    [anon_sym_using] = ACTIONS(5585),
    [anon_sym_static_assert] = ACTIONS(5585),
    [anon_sym___launch_bounds__] = ACTIONS(5585),
  },
  [STATE(1798)] = {
    [sym_identifier] = ACTIONS(2497),
    [aux_sym_preproc_def_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token2] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2497),
    [aux_sym_preproc_else_token1] = ACTIONS(2497),
    [aux_sym_preproc_elif_token1] = ACTIONS(2497),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2497),
    [sym_preproc_directive] = ACTIONS(2497),
    [anon_sym_LPAREN2] = ACTIONS(2499),
    [anon_sym_TILDE] = ACTIONS(2499),
    [anon_sym_STAR] = ACTIONS(2499),
    [anon_sym_AMP_AMP] = ACTIONS(2499),
    [anon_sym_AMP] = ACTIONS(2497),
    [anon_sym_SEMI] = ACTIONS(2499),
    [anon_sym___extension__] = ACTIONS(2497),
    [anon_sym_typedef] = ACTIONS(2497),
    [anon_sym___device__] = ACTIONS(2497),
    [anon_sym___host__] = ACTIONS(2497),
    [anon_sym___global__] = ACTIONS(2497),
    [anon_sym___forceinline__] = ACTIONS(2497),
    [anon_sym___noinline__] = ACTIONS(2497),
    [anon_sym_virtual] = ACTIONS(2497),
    [anon_sym_extern] = ACTIONS(2497),
    [anon_sym___attribute__] = ACTIONS(2497),
    [anon_sym___attribute] = ACTIONS(2497),
    [anon_sym_COLON_COLON] = ACTIONS(2499),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2499),
    [anon_sym___declspec] = ACTIONS(2497),
    [anon_sym___based] = ACTIONS(2497),
    [anon_sym_signed] = ACTIONS(2497),
    [anon_sym_unsigned] = ACTIONS(2497),
    [anon_sym_long] = ACTIONS(2497),
    [anon_sym_short] = ACTIONS(2497),
    [anon_sym_LBRACK] = ACTIONS(2497),
    [anon_sym_static] = ACTIONS(2497),
    [anon_sym_register] = ACTIONS(2497),
    [anon_sym_inline] = ACTIONS(2497),
    [anon_sym___inline] = ACTIONS(2497),
    [anon_sym___inline__] = ACTIONS(2497),
    [anon_sym___forceinline] = ACTIONS(2497),
    [anon_sym_thread_local] = ACTIONS(2497),
    [anon_sym___thread] = ACTIONS(2497),
    [anon_sym_const] = ACTIONS(2497),
    [anon_sym_constexpr] = ACTIONS(2497),
    [anon_sym_volatile] = ACTIONS(2497),
    [anon_sym_restrict] = ACTIONS(2497),
    [anon_sym___restrict__] = ACTIONS(2497),
    [anon_sym__Atomic] = ACTIONS(2497),
    [anon_sym__Noreturn] = ACTIONS(2497),
    [anon_sym_noreturn] = ACTIONS(2497),
    [anon_sym__Nonnull] = ACTIONS(2497),
    [anon_sym_mutable] = ACTIONS(2497),
    [anon_sym_constinit] = ACTIONS(2497),
    [anon_sym_consteval] = ACTIONS(2497),
    [anon_sym___shared__] = ACTIONS(2497),
    [anon_sym___local__] = ACTIONS(2497),
    [anon_sym___constant__] = ACTIONS(2497),
    [anon_sym___managed__] = ACTIONS(2497),
    [anon_sym___grid_constant__] = ACTIONS(2497),
    [anon_sym_alignas] = ACTIONS(2497),
    [anon_sym__Alignas] = ACTIONS(2497),
    [sym_primitive_type] = ACTIONS(2497),
    [anon_sym_enum] = ACTIONS(2497),
    [anon_sym_class] = ACTIONS(2497),
    [anon_sym_struct] = ACTIONS(2497),
    [anon_sym_union] = ACTIONS(2497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2497),
    [anon_sym_decltype] = ACTIONS(2497),
    [anon_sym_explicit] = ACTIONS(2497),
    [anon_sym_typename] = ACTIONS(2497),
    [anon_sym_template] = ACTIONS(2497),
    [anon_sym_operator] = ACTIONS(2497),
    [anon_sym_friend] = ACTIONS(2497),
    [anon_sym_public] = ACTIONS(2497),
    [anon_sym_private] = ACTIONS(2497),
    [anon_sym_protected] = ACTIONS(2497),
    [anon_sym_using] = ACTIONS(2497),
    [anon_sym_static_assert] = ACTIONS(2497),
    [anon_sym___launch_bounds__] = ACTIONS(2497),
  },
  [STATE(1799)] = {
    [sym_identifier] = ACTIONS(2501),
    [aux_sym_preproc_def_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token2] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2501),
    [aux_sym_preproc_else_token1] = ACTIONS(2501),
    [aux_sym_preproc_elif_token1] = ACTIONS(2501),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2501),
    [sym_preproc_directive] = ACTIONS(2501),
    [anon_sym_LPAREN2] = ACTIONS(2503),
    [anon_sym_TILDE] = ACTIONS(2503),
    [anon_sym_STAR] = ACTIONS(2503),
    [anon_sym_AMP_AMP] = ACTIONS(2503),
    [anon_sym_AMP] = ACTIONS(2501),
    [anon_sym_SEMI] = ACTIONS(2503),
    [anon_sym___extension__] = ACTIONS(2501),
    [anon_sym_typedef] = ACTIONS(2501),
    [anon_sym___device__] = ACTIONS(2501),
    [anon_sym___host__] = ACTIONS(2501),
    [anon_sym___global__] = ACTIONS(2501),
    [anon_sym___forceinline__] = ACTIONS(2501),
    [anon_sym___noinline__] = ACTIONS(2501),
    [anon_sym_virtual] = ACTIONS(2501),
    [anon_sym_extern] = ACTIONS(2501),
    [anon_sym___attribute__] = ACTIONS(2501),
    [anon_sym___attribute] = ACTIONS(2501),
    [anon_sym_COLON_COLON] = ACTIONS(2503),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2503),
    [anon_sym___declspec] = ACTIONS(2501),
    [anon_sym___based] = ACTIONS(2501),
    [anon_sym_signed] = ACTIONS(2501),
    [anon_sym_unsigned] = ACTIONS(2501),
    [anon_sym_long] = ACTIONS(2501),
    [anon_sym_short] = ACTIONS(2501),
    [anon_sym_LBRACK] = ACTIONS(2501),
    [anon_sym_static] = ACTIONS(2501),
    [anon_sym_register] = ACTIONS(2501),
    [anon_sym_inline] = ACTIONS(2501),
    [anon_sym___inline] = ACTIONS(2501),
    [anon_sym___inline__] = ACTIONS(2501),
    [anon_sym___forceinline] = ACTIONS(2501),
    [anon_sym_thread_local] = ACTIONS(2501),
    [anon_sym___thread] = ACTIONS(2501),
    [anon_sym_const] = ACTIONS(2501),
    [anon_sym_constexpr] = ACTIONS(2501),
    [anon_sym_volatile] = ACTIONS(2501),
    [anon_sym_restrict] = ACTIONS(2501),
    [anon_sym___restrict__] = ACTIONS(2501),
    [anon_sym__Atomic] = ACTIONS(2501),
    [anon_sym__Noreturn] = ACTIONS(2501),
    [anon_sym_noreturn] = ACTIONS(2501),
    [anon_sym__Nonnull] = ACTIONS(2501),
    [anon_sym_mutable] = ACTIONS(2501),
    [anon_sym_constinit] = ACTIONS(2501),
    [anon_sym_consteval] = ACTIONS(2501),
    [anon_sym___shared__] = ACTIONS(2501),
    [anon_sym___local__] = ACTIONS(2501),
    [anon_sym___constant__] = ACTIONS(2501),
    [anon_sym___managed__] = ACTIONS(2501),
    [anon_sym___grid_constant__] = ACTIONS(2501),
    [anon_sym_alignas] = ACTIONS(2501),
    [anon_sym__Alignas] = ACTIONS(2501),
    [sym_primitive_type] = ACTIONS(2501),
    [anon_sym_enum] = ACTIONS(2501),
    [anon_sym_class] = ACTIONS(2501),
    [anon_sym_struct] = ACTIONS(2501),
    [anon_sym_union] = ACTIONS(2501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2501),
    [anon_sym_decltype] = ACTIONS(2501),
    [anon_sym_explicit] = ACTIONS(2501),
    [anon_sym_typename] = ACTIONS(2501),
    [anon_sym_template] = ACTIONS(2501),
    [anon_sym_operator] = ACTIONS(2501),
    [anon_sym_friend] = ACTIONS(2501),
    [anon_sym_public] = ACTIONS(2501),
    [anon_sym_private] = ACTIONS(2501),
    [anon_sym_protected] = ACTIONS(2501),
    [anon_sym_using] = ACTIONS(2501),
    [anon_sym_static_assert] = ACTIONS(2501),
    [anon_sym___launch_bounds__] = ACTIONS(2501),
  },
  [STATE(1800)] = {
    [sym_identifier] = ACTIONS(2489),
    [aux_sym_preproc_def_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token2] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2489),
    [aux_sym_preproc_else_token1] = ACTIONS(2489),
    [aux_sym_preproc_elif_token1] = ACTIONS(2489),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2489),
    [sym_preproc_directive] = ACTIONS(2489),
    [anon_sym_LPAREN2] = ACTIONS(2491),
    [anon_sym_TILDE] = ACTIONS(2491),
    [anon_sym_STAR] = ACTIONS(2491),
    [anon_sym_AMP_AMP] = ACTIONS(2491),
    [anon_sym_AMP] = ACTIONS(2489),
    [anon_sym_SEMI] = ACTIONS(2491),
    [anon_sym___extension__] = ACTIONS(2489),
    [anon_sym_typedef] = ACTIONS(2489),
    [anon_sym___device__] = ACTIONS(2489),
    [anon_sym___host__] = ACTIONS(2489),
    [anon_sym___global__] = ACTIONS(2489),
    [anon_sym___forceinline__] = ACTIONS(2489),
    [anon_sym___noinline__] = ACTIONS(2489),
    [anon_sym_virtual] = ACTIONS(2489),
    [anon_sym_extern] = ACTIONS(2489),
    [anon_sym___attribute__] = ACTIONS(2489),
    [anon_sym___attribute] = ACTIONS(2489),
    [anon_sym_COLON_COLON] = ACTIONS(2491),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2491),
    [anon_sym___declspec] = ACTIONS(2489),
    [anon_sym___based] = ACTIONS(2489),
    [anon_sym_signed] = ACTIONS(2489),
    [anon_sym_unsigned] = ACTIONS(2489),
    [anon_sym_long] = ACTIONS(2489),
    [anon_sym_short] = ACTIONS(2489),
    [anon_sym_LBRACK] = ACTIONS(2489),
    [anon_sym_static] = ACTIONS(2489),
    [anon_sym_register] = ACTIONS(2489),
    [anon_sym_inline] = ACTIONS(2489),
    [anon_sym___inline] = ACTIONS(2489),
    [anon_sym___inline__] = ACTIONS(2489),
    [anon_sym___forceinline] = ACTIONS(2489),
    [anon_sym_thread_local] = ACTIONS(2489),
    [anon_sym___thread] = ACTIONS(2489),
    [anon_sym_const] = ACTIONS(2489),
    [anon_sym_constexpr] = ACTIONS(2489),
    [anon_sym_volatile] = ACTIONS(2489),
    [anon_sym_restrict] = ACTIONS(2489),
    [anon_sym___restrict__] = ACTIONS(2489),
    [anon_sym__Atomic] = ACTIONS(2489),
    [anon_sym__Noreturn] = ACTIONS(2489),
    [anon_sym_noreturn] = ACTIONS(2489),
    [anon_sym__Nonnull] = ACTIONS(2489),
    [anon_sym_mutable] = ACTIONS(2489),
    [anon_sym_constinit] = ACTIONS(2489),
    [anon_sym_consteval] = ACTIONS(2489),
    [anon_sym___shared__] = ACTIONS(2489),
    [anon_sym___local__] = ACTIONS(2489),
    [anon_sym___constant__] = ACTIONS(2489),
    [anon_sym___managed__] = ACTIONS(2489),
    [anon_sym___grid_constant__] = ACTIONS(2489),
    [anon_sym_alignas] = ACTIONS(2489),
    [anon_sym__Alignas] = ACTIONS(2489),
    [sym_primitive_type] = ACTIONS(2489),
    [anon_sym_enum] = ACTIONS(2489),
    [anon_sym_class] = ACTIONS(2489),
    [anon_sym_struct] = ACTIONS(2489),
    [anon_sym_union] = ACTIONS(2489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2489),
    [anon_sym_decltype] = ACTIONS(2489),
    [anon_sym_explicit] = ACTIONS(2489),
    [anon_sym_typename] = ACTIONS(2489),
    [anon_sym_template] = ACTIONS(2489),
    [anon_sym_operator] = ACTIONS(2489),
    [anon_sym_friend] = ACTIONS(2489),
    [anon_sym_public] = ACTIONS(2489),
    [anon_sym_private] = ACTIONS(2489),
    [anon_sym_protected] = ACTIONS(2489),
    [anon_sym_using] = ACTIONS(2489),
    [anon_sym_static_assert] = ACTIONS(2489),
    [anon_sym___launch_bounds__] = ACTIONS(2489),
  },
  [STATE(1801)] = {
    [sym_identifier] = ACTIONS(2513),
    [aux_sym_preproc_def_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token2] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2513),
    [aux_sym_preproc_else_token1] = ACTIONS(2513),
    [aux_sym_preproc_elif_token1] = ACTIONS(2513),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2513),
    [sym_preproc_directive] = ACTIONS(2513),
    [anon_sym_LPAREN2] = ACTIONS(2515),
    [anon_sym_TILDE] = ACTIONS(2515),
    [anon_sym_STAR] = ACTIONS(2515),
    [anon_sym_AMP_AMP] = ACTIONS(2515),
    [anon_sym_AMP] = ACTIONS(2513),
    [anon_sym_SEMI] = ACTIONS(2515),
    [anon_sym___extension__] = ACTIONS(2513),
    [anon_sym_typedef] = ACTIONS(2513),
    [anon_sym___device__] = ACTIONS(2513),
    [anon_sym___host__] = ACTIONS(2513),
    [anon_sym___global__] = ACTIONS(2513),
    [anon_sym___forceinline__] = ACTIONS(2513),
    [anon_sym___noinline__] = ACTIONS(2513),
    [anon_sym_virtual] = ACTIONS(2513),
    [anon_sym_extern] = ACTIONS(2513),
    [anon_sym___attribute__] = ACTIONS(2513),
    [anon_sym___attribute] = ACTIONS(2513),
    [anon_sym_COLON_COLON] = ACTIONS(2515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2515),
    [anon_sym___declspec] = ACTIONS(2513),
    [anon_sym___based] = ACTIONS(2513),
    [anon_sym_signed] = ACTIONS(2513),
    [anon_sym_unsigned] = ACTIONS(2513),
    [anon_sym_long] = ACTIONS(2513),
    [anon_sym_short] = ACTIONS(2513),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_static] = ACTIONS(2513),
    [anon_sym_register] = ACTIONS(2513),
    [anon_sym_inline] = ACTIONS(2513),
    [anon_sym___inline] = ACTIONS(2513),
    [anon_sym___inline__] = ACTIONS(2513),
    [anon_sym___forceinline] = ACTIONS(2513),
    [anon_sym_thread_local] = ACTIONS(2513),
    [anon_sym___thread] = ACTIONS(2513),
    [anon_sym_const] = ACTIONS(2513),
    [anon_sym_constexpr] = ACTIONS(2513),
    [anon_sym_volatile] = ACTIONS(2513),
    [anon_sym_restrict] = ACTIONS(2513),
    [anon_sym___restrict__] = ACTIONS(2513),
    [anon_sym__Atomic] = ACTIONS(2513),
    [anon_sym__Noreturn] = ACTIONS(2513),
    [anon_sym_noreturn] = ACTIONS(2513),
    [anon_sym__Nonnull] = ACTIONS(2513),
    [anon_sym_mutable] = ACTIONS(2513),
    [anon_sym_constinit] = ACTIONS(2513),
    [anon_sym_consteval] = ACTIONS(2513),
    [anon_sym___shared__] = ACTIONS(2513),
    [anon_sym___local__] = ACTIONS(2513),
    [anon_sym___constant__] = ACTIONS(2513),
    [anon_sym___managed__] = ACTIONS(2513),
    [anon_sym___grid_constant__] = ACTIONS(2513),
    [anon_sym_alignas] = ACTIONS(2513),
    [anon_sym__Alignas] = ACTIONS(2513),
    [sym_primitive_type] = ACTIONS(2513),
    [anon_sym_enum] = ACTIONS(2513),
    [anon_sym_class] = ACTIONS(2513),
    [anon_sym_struct] = ACTIONS(2513),
    [anon_sym_union] = ACTIONS(2513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2513),
    [anon_sym_decltype] = ACTIONS(2513),
    [anon_sym_explicit] = ACTIONS(2513),
    [anon_sym_typename] = ACTIONS(2513),
    [anon_sym_template] = ACTIONS(2513),
    [anon_sym_operator] = ACTIONS(2513),
    [anon_sym_friend] = ACTIONS(2513),
    [anon_sym_public] = ACTIONS(2513),
    [anon_sym_private] = ACTIONS(2513),
    [anon_sym_protected] = ACTIONS(2513),
    [anon_sym_using] = ACTIONS(2513),
    [anon_sym_static_assert] = ACTIONS(2513),
    [anon_sym___launch_bounds__] = ACTIONS(2513),
  },
  [STATE(1802)] = {
    [sym_identifier] = ACTIONS(2517),
    [aux_sym_preproc_def_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token2] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2517),
    [aux_sym_preproc_else_token1] = ACTIONS(2517),
    [aux_sym_preproc_elif_token1] = ACTIONS(2517),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2517),
    [sym_preproc_directive] = ACTIONS(2517),
    [anon_sym_LPAREN2] = ACTIONS(2519),
    [anon_sym_TILDE] = ACTIONS(2519),
    [anon_sym_STAR] = ACTIONS(2519),
    [anon_sym_AMP_AMP] = ACTIONS(2519),
    [anon_sym_AMP] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym___extension__] = ACTIONS(2517),
    [anon_sym_typedef] = ACTIONS(2517),
    [anon_sym___device__] = ACTIONS(2517),
    [anon_sym___host__] = ACTIONS(2517),
    [anon_sym___global__] = ACTIONS(2517),
    [anon_sym___forceinline__] = ACTIONS(2517),
    [anon_sym___noinline__] = ACTIONS(2517),
    [anon_sym_virtual] = ACTIONS(2517),
    [anon_sym_extern] = ACTIONS(2517),
    [anon_sym___attribute__] = ACTIONS(2517),
    [anon_sym___attribute] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2519),
    [anon_sym___declspec] = ACTIONS(2517),
    [anon_sym___based] = ACTIONS(2517),
    [anon_sym_signed] = ACTIONS(2517),
    [anon_sym_unsigned] = ACTIONS(2517),
    [anon_sym_long] = ACTIONS(2517),
    [anon_sym_short] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2517),
    [anon_sym_static] = ACTIONS(2517),
    [anon_sym_register] = ACTIONS(2517),
    [anon_sym_inline] = ACTIONS(2517),
    [anon_sym___inline] = ACTIONS(2517),
    [anon_sym___inline__] = ACTIONS(2517),
    [anon_sym___forceinline] = ACTIONS(2517),
    [anon_sym_thread_local] = ACTIONS(2517),
    [anon_sym___thread] = ACTIONS(2517),
    [anon_sym_const] = ACTIONS(2517),
    [anon_sym_constexpr] = ACTIONS(2517),
    [anon_sym_volatile] = ACTIONS(2517),
    [anon_sym_restrict] = ACTIONS(2517),
    [anon_sym___restrict__] = ACTIONS(2517),
    [anon_sym__Atomic] = ACTIONS(2517),
    [anon_sym__Noreturn] = ACTIONS(2517),
    [anon_sym_noreturn] = ACTIONS(2517),
    [anon_sym__Nonnull] = ACTIONS(2517),
    [anon_sym_mutable] = ACTIONS(2517),
    [anon_sym_constinit] = ACTIONS(2517),
    [anon_sym_consteval] = ACTIONS(2517),
    [anon_sym___shared__] = ACTIONS(2517),
    [anon_sym___local__] = ACTIONS(2517),
    [anon_sym___constant__] = ACTIONS(2517),
    [anon_sym___managed__] = ACTIONS(2517),
    [anon_sym___grid_constant__] = ACTIONS(2517),
    [anon_sym_alignas] = ACTIONS(2517),
    [anon_sym__Alignas] = ACTIONS(2517),
    [sym_primitive_type] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_class] = ACTIONS(2517),
    [anon_sym_struct] = ACTIONS(2517),
    [anon_sym_union] = ACTIONS(2517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2517),
    [anon_sym_decltype] = ACTIONS(2517),
    [anon_sym_explicit] = ACTIONS(2517),
    [anon_sym_typename] = ACTIONS(2517),
    [anon_sym_template] = ACTIONS(2517),
    [anon_sym_operator] = ACTIONS(2517),
    [anon_sym_friend] = ACTIONS(2517),
    [anon_sym_public] = ACTIONS(2517),
    [anon_sym_private] = ACTIONS(2517),
    [anon_sym_protected] = ACTIONS(2517),
    [anon_sym_using] = ACTIONS(2517),
    [anon_sym_static_assert] = ACTIONS(2517),
    [anon_sym___launch_bounds__] = ACTIONS(2517),
  },
  [STATE(1803)] = {
    [sym_identifier] = ACTIONS(2521),
    [aux_sym_preproc_def_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token2] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2521),
    [aux_sym_preproc_else_token1] = ACTIONS(2521),
    [aux_sym_preproc_elif_token1] = ACTIONS(2521),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2521),
    [sym_preproc_directive] = ACTIONS(2521),
    [anon_sym_LPAREN2] = ACTIONS(2523),
    [anon_sym_TILDE] = ACTIONS(2523),
    [anon_sym_STAR] = ACTIONS(2523),
    [anon_sym_AMP_AMP] = ACTIONS(2523),
    [anon_sym_AMP] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym___extension__] = ACTIONS(2521),
    [anon_sym_typedef] = ACTIONS(2521),
    [anon_sym___device__] = ACTIONS(2521),
    [anon_sym___host__] = ACTIONS(2521),
    [anon_sym___global__] = ACTIONS(2521),
    [anon_sym___forceinline__] = ACTIONS(2521),
    [anon_sym___noinline__] = ACTIONS(2521),
    [anon_sym_virtual] = ACTIONS(2521),
    [anon_sym_extern] = ACTIONS(2521),
    [anon_sym___attribute__] = ACTIONS(2521),
    [anon_sym___attribute] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2523),
    [anon_sym___declspec] = ACTIONS(2521),
    [anon_sym___based] = ACTIONS(2521),
    [anon_sym_signed] = ACTIONS(2521),
    [anon_sym_unsigned] = ACTIONS(2521),
    [anon_sym_long] = ACTIONS(2521),
    [anon_sym_short] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2521),
    [anon_sym_static] = ACTIONS(2521),
    [anon_sym_register] = ACTIONS(2521),
    [anon_sym_inline] = ACTIONS(2521),
    [anon_sym___inline] = ACTIONS(2521),
    [anon_sym___inline__] = ACTIONS(2521),
    [anon_sym___forceinline] = ACTIONS(2521),
    [anon_sym_thread_local] = ACTIONS(2521),
    [anon_sym___thread] = ACTIONS(2521),
    [anon_sym_const] = ACTIONS(2521),
    [anon_sym_constexpr] = ACTIONS(2521),
    [anon_sym_volatile] = ACTIONS(2521),
    [anon_sym_restrict] = ACTIONS(2521),
    [anon_sym___restrict__] = ACTIONS(2521),
    [anon_sym__Atomic] = ACTIONS(2521),
    [anon_sym__Noreturn] = ACTIONS(2521),
    [anon_sym_noreturn] = ACTIONS(2521),
    [anon_sym__Nonnull] = ACTIONS(2521),
    [anon_sym_mutable] = ACTIONS(2521),
    [anon_sym_constinit] = ACTIONS(2521),
    [anon_sym_consteval] = ACTIONS(2521),
    [anon_sym___shared__] = ACTIONS(2521),
    [anon_sym___local__] = ACTIONS(2521),
    [anon_sym___constant__] = ACTIONS(2521),
    [anon_sym___managed__] = ACTIONS(2521),
    [anon_sym___grid_constant__] = ACTIONS(2521),
    [anon_sym_alignas] = ACTIONS(2521),
    [anon_sym__Alignas] = ACTIONS(2521),
    [sym_primitive_type] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_class] = ACTIONS(2521),
    [anon_sym_struct] = ACTIONS(2521),
    [anon_sym_union] = ACTIONS(2521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2521),
    [anon_sym_decltype] = ACTIONS(2521),
    [anon_sym_explicit] = ACTIONS(2521),
    [anon_sym_typename] = ACTIONS(2521),
    [anon_sym_template] = ACTIONS(2521),
    [anon_sym_operator] = ACTIONS(2521),
    [anon_sym_friend] = ACTIONS(2521),
    [anon_sym_public] = ACTIONS(2521),
    [anon_sym_private] = ACTIONS(2521),
    [anon_sym_protected] = ACTIONS(2521),
    [anon_sym_using] = ACTIONS(2521),
    [anon_sym_static_assert] = ACTIONS(2521),
    [anon_sym___launch_bounds__] = ACTIONS(2521),
  },
  [STATE(1804)] = {
    [sym_identifier] = ACTIONS(2525),
    [aux_sym_preproc_def_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token2] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2525),
    [aux_sym_preproc_else_token1] = ACTIONS(2525),
    [aux_sym_preproc_elif_token1] = ACTIONS(2525),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2525),
    [sym_preproc_directive] = ACTIONS(2525),
    [anon_sym_LPAREN2] = ACTIONS(2527),
    [anon_sym_TILDE] = ACTIONS(2527),
    [anon_sym_STAR] = ACTIONS(2527),
    [anon_sym_AMP_AMP] = ACTIONS(2527),
    [anon_sym_AMP] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym___extension__] = ACTIONS(2525),
    [anon_sym_typedef] = ACTIONS(2525),
    [anon_sym___device__] = ACTIONS(2525),
    [anon_sym___host__] = ACTIONS(2525),
    [anon_sym___global__] = ACTIONS(2525),
    [anon_sym___forceinline__] = ACTIONS(2525),
    [anon_sym___noinline__] = ACTIONS(2525),
    [anon_sym_virtual] = ACTIONS(2525),
    [anon_sym_extern] = ACTIONS(2525),
    [anon_sym___attribute__] = ACTIONS(2525),
    [anon_sym___attribute] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2527),
    [anon_sym___declspec] = ACTIONS(2525),
    [anon_sym___based] = ACTIONS(2525),
    [anon_sym_signed] = ACTIONS(2525),
    [anon_sym_unsigned] = ACTIONS(2525),
    [anon_sym_long] = ACTIONS(2525),
    [anon_sym_short] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2525),
    [anon_sym_static] = ACTIONS(2525),
    [anon_sym_register] = ACTIONS(2525),
    [anon_sym_inline] = ACTIONS(2525),
    [anon_sym___inline] = ACTIONS(2525),
    [anon_sym___inline__] = ACTIONS(2525),
    [anon_sym___forceinline] = ACTIONS(2525),
    [anon_sym_thread_local] = ACTIONS(2525),
    [anon_sym___thread] = ACTIONS(2525),
    [anon_sym_const] = ACTIONS(2525),
    [anon_sym_constexpr] = ACTIONS(2525),
    [anon_sym_volatile] = ACTIONS(2525),
    [anon_sym_restrict] = ACTIONS(2525),
    [anon_sym___restrict__] = ACTIONS(2525),
    [anon_sym__Atomic] = ACTIONS(2525),
    [anon_sym__Noreturn] = ACTIONS(2525),
    [anon_sym_noreturn] = ACTIONS(2525),
    [anon_sym__Nonnull] = ACTIONS(2525),
    [anon_sym_mutable] = ACTIONS(2525),
    [anon_sym_constinit] = ACTIONS(2525),
    [anon_sym_consteval] = ACTIONS(2525),
    [anon_sym___shared__] = ACTIONS(2525),
    [anon_sym___local__] = ACTIONS(2525),
    [anon_sym___constant__] = ACTIONS(2525),
    [anon_sym___managed__] = ACTIONS(2525),
    [anon_sym___grid_constant__] = ACTIONS(2525),
    [anon_sym_alignas] = ACTIONS(2525),
    [anon_sym__Alignas] = ACTIONS(2525),
    [sym_primitive_type] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_class] = ACTIONS(2525),
    [anon_sym_struct] = ACTIONS(2525),
    [anon_sym_union] = ACTIONS(2525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2525),
    [anon_sym_decltype] = ACTIONS(2525),
    [anon_sym_explicit] = ACTIONS(2525),
    [anon_sym_typename] = ACTIONS(2525),
    [anon_sym_template] = ACTIONS(2525),
    [anon_sym_operator] = ACTIONS(2525),
    [anon_sym_friend] = ACTIONS(2525),
    [anon_sym_public] = ACTIONS(2525),
    [anon_sym_private] = ACTIONS(2525),
    [anon_sym_protected] = ACTIONS(2525),
    [anon_sym_using] = ACTIONS(2525),
    [anon_sym_static_assert] = ACTIONS(2525),
    [anon_sym___launch_bounds__] = ACTIONS(2525),
  },
  [STATE(1805)] = {
    [sym_identifier] = ACTIONS(2529),
    [aux_sym_preproc_def_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token2] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2529),
    [aux_sym_preproc_else_token1] = ACTIONS(2529),
    [aux_sym_preproc_elif_token1] = ACTIONS(2529),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2529),
    [sym_preproc_directive] = ACTIONS(2529),
    [anon_sym_LPAREN2] = ACTIONS(2531),
    [anon_sym_TILDE] = ACTIONS(2531),
    [anon_sym_STAR] = ACTIONS(2531),
    [anon_sym_AMP_AMP] = ACTIONS(2531),
    [anon_sym_AMP] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym___extension__] = ACTIONS(2529),
    [anon_sym_typedef] = ACTIONS(2529),
    [anon_sym___device__] = ACTIONS(2529),
    [anon_sym___host__] = ACTIONS(2529),
    [anon_sym___global__] = ACTIONS(2529),
    [anon_sym___forceinline__] = ACTIONS(2529),
    [anon_sym___noinline__] = ACTIONS(2529),
    [anon_sym_virtual] = ACTIONS(2529),
    [anon_sym_extern] = ACTIONS(2529),
    [anon_sym___attribute__] = ACTIONS(2529),
    [anon_sym___attribute] = ACTIONS(2529),
    [anon_sym_COLON_COLON] = ACTIONS(2531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2531),
    [anon_sym___declspec] = ACTIONS(2529),
    [anon_sym___based] = ACTIONS(2529),
    [anon_sym_signed] = ACTIONS(2529),
    [anon_sym_unsigned] = ACTIONS(2529),
    [anon_sym_long] = ACTIONS(2529),
    [anon_sym_short] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2529),
    [anon_sym_register] = ACTIONS(2529),
    [anon_sym_inline] = ACTIONS(2529),
    [anon_sym___inline] = ACTIONS(2529),
    [anon_sym___inline__] = ACTIONS(2529),
    [anon_sym___forceinline] = ACTIONS(2529),
    [anon_sym_thread_local] = ACTIONS(2529),
    [anon_sym___thread] = ACTIONS(2529),
    [anon_sym_const] = ACTIONS(2529),
    [anon_sym_constexpr] = ACTIONS(2529),
    [anon_sym_volatile] = ACTIONS(2529),
    [anon_sym_restrict] = ACTIONS(2529),
    [anon_sym___restrict__] = ACTIONS(2529),
    [anon_sym__Atomic] = ACTIONS(2529),
    [anon_sym__Noreturn] = ACTIONS(2529),
    [anon_sym_noreturn] = ACTIONS(2529),
    [anon_sym__Nonnull] = ACTIONS(2529),
    [anon_sym_mutable] = ACTIONS(2529),
    [anon_sym_constinit] = ACTIONS(2529),
    [anon_sym_consteval] = ACTIONS(2529),
    [anon_sym___shared__] = ACTIONS(2529),
    [anon_sym___local__] = ACTIONS(2529),
    [anon_sym___constant__] = ACTIONS(2529),
    [anon_sym___managed__] = ACTIONS(2529),
    [anon_sym___grid_constant__] = ACTIONS(2529),
    [anon_sym_alignas] = ACTIONS(2529),
    [anon_sym__Alignas] = ACTIONS(2529),
    [sym_primitive_type] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2529),
    [anon_sym_struct] = ACTIONS(2529),
    [anon_sym_union] = ACTIONS(2529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2529),
    [anon_sym_decltype] = ACTIONS(2529),
    [anon_sym_explicit] = ACTIONS(2529),
    [anon_sym_typename] = ACTIONS(2529),
    [anon_sym_template] = ACTIONS(2529),
    [anon_sym_operator] = ACTIONS(2529),
    [anon_sym_friend] = ACTIONS(2529),
    [anon_sym_public] = ACTIONS(2529),
    [anon_sym_private] = ACTIONS(2529),
    [anon_sym_protected] = ACTIONS(2529),
    [anon_sym_using] = ACTIONS(2529),
    [anon_sym_static_assert] = ACTIONS(2529),
    [anon_sym___launch_bounds__] = ACTIONS(2529),
  },
  [STATE(1806)] = {
    [sym_identifier] = ACTIONS(5589),
    [aux_sym_preproc_def_token1] = ACTIONS(5589),
    [aux_sym_preproc_if_token1] = ACTIONS(5589),
    [aux_sym_preproc_if_token2] = ACTIONS(5589),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5589),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5589),
    [aux_sym_preproc_else_token1] = ACTIONS(5589),
    [aux_sym_preproc_elif_token1] = ACTIONS(5589),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5589),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5589),
    [sym_preproc_directive] = ACTIONS(5589),
    [anon_sym_LPAREN2] = ACTIONS(5591),
    [anon_sym_TILDE] = ACTIONS(5591),
    [anon_sym_STAR] = ACTIONS(5591),
    [anon_sym_AMP_AMP] = ACTIONS(5591),
    [anon_sym_AMP] = ACTIONS(5589),
    [anon_sym_SEMI] = ACTIONS(5591),
    [anon_sym___extension__] = ACTIONS(5589),
    [anon_sym_typedef] = ACTIONS(5589),
    [anon_sym___device__] = ACTIONS(5589),
    [anon_sym___host__] = ACTIONS(5589),
    [anon_sym___global__] = ACTIONS(5589),
    [anon_sym___forceinline__] = ACTIONS(5589),
    [anon_sym___noinline__] = ACTIONS(5589),
    [anon_sym_virtual] = ACTIONS(5589),
    [anon_sym_extern] = ACTIONS(5589),
    [anon_sym___attribute__] = ACTIONS(5589),
    [anon_sym___attribute] = ACTIONS(5589),
    [anon_sym_COLON_COLON] = ACTIONS(5591),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5591),
    [anon_sym___declspec] = ACTIONS(5589),
    [anon_sym___based] = ACTIONS(5589),
    [anon_sym_signed] = ACTIONS(5589),
    [anon_sym_unsigned] = ACTIONS(5589),
    [anon_sym_long] = ACTIONS(5589),
    [anon_sym_short] = ACTIONS(5589),
    [anon_sym_LBRACK] = ACTIONS(5589),
    [anon_sym_static] = ACTIONS(5589),
    [anon_sym_register] = ACTIONS(5589),
    [anon_sym_inline] = ACTIONS(5589),
    [anon_sym___inline] = ACTIONS(5589),
    [anon_sym___inline__] = ACTIONS(5589),
    [anon_sym___forceinline] = ACTIONS(5589),
    [anon_sym_thread_local] = ACTIONS(5589),
    [anon_sym___thread] = ACTIONS(5589),
    [anon_sym_const] = ACTIONS(5589),
    [anon_sym_constexpr] = ACTIONS(5589),
    [anon_sym_volatile] = ACTIONS(5589),
    [anon_sym_restrict] = ACTIONS(5589),
    [anon_sym___restrict__] = ACTIONS(5589),
    [anon_sym__Atomic] = ACTIONS(5589),
    [anon_sym__Noreturn] = ACTIONS(5589),
    [anon_sym_noreturn] = ACTIONS(5589),
    [anon_sym__Nonnull] = ACTIONS(5589),
    [anon_sym_mutable] = ACTIONS(5589),
    [anon_sym_constinit] = ACTIONS(5589),
    [anon_sym_consteval] = ACTIONS(5589),
    [anon_sym___shared__] = ACTIONS(5589),
    [anon_sym___local__] = ACTIONS(5589),
    [anon_sym___constant__] = ACTIONS(5589),
    [anon_sym___managed__] = ACTIONS(5589),
    [anon_sym___grid_constant__] = ACTIONS(5589),
    [anon_sym_alignas] = ACTIONS(5589),
    [anon_sym__Alignas] = ACTIONS(5589),
    [sym_primitive_type] = ACTIONS(5589),
    [anon_sym_enum] = ACTIONS(5589),
    [anon_sym_class] = ACTIONS(5589),
    [anon_sym_struct] = ACTIONS(5589),
    [anon_sym_union] = ACTIONS(5589),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5589),
    [anon_sym_decltype] = ACTIONS(5589),
    [anon_sym_explicit] = ACTIONS(5589),
    [anon_sym_typename] = ACTIONS(5589),
    [anon_sym_template] = ACTIONS(5589),
    [anon_sym_operator] = ACTIONS(5589),
    [anon_sym_friend] = ACTIONS(5589),
    [anon_sym_public] = ACTIONS(5589),
    [anon_sym_private] = ACTIONS(5589),
    [anon_sym_protected] = ACTIONS(5589),
    [anon_sym_using] = ACTIONS(5589),
    [anon_sym_static_assert] = ACTIONS(5589),
    [anon_sym___launch_bounds__] = ACTIONS(5589),
  },
  [STATE(1807)] = {
    [sym_identifier] = ACTIONS(2541),
    [aux_sym_preproc_def_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token2] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2541),
    [aux_sym_preproc_else_token1] = ACTIONS(2541),
    [aux_sym_preproc_elif_token1] = ACTIONS(2541),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2541),
    [sym_preproc_directive] = ACTIONS(2541),
    [anon_sym_LPAREN2] = ACTIONS(2543),
    [anon_sym_TILDE] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_AMP_AMP] = ACTIONS(2543),
    [anon_sym_AMP] = ACTIONS(2541),
    [anon_sym_SEMI] = ACTIONS(2543),
    [anon_sym___extension__] = ACTIONS(2541),
    [anon_sym_typedef] = ACTIONS(2541),
    [anon_sym___device__] = ACTIONS(2541),
    [anon_sym___host__] = ACTIONS(2541),
    [anon_sym___global__] = ACTIONS(2541),
    [anon_sym___forceinline__] = ACTIONS(2541),
    [anon_sym___noinline__] = ACTIONS(2541),
    [anon_sym_virtual] = ACTIONS(2541),
    [anon_sym_extern] = ACTIONS(2541),
    [anon_sym___attribute__] = ACTIONS(2541),
    [anon_sym___attribute] = ACTIONS(2541),
    [anon_sym_COLON_COLON] = ACTIONS(2543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2543),
    [anon_sym___declspec] = ACTIONS(2541),
    [anon_sym___based] = ACTIONS(2541),
    [anon_sym_signed] = ACTIONS(2541),
    [anon_sym_unsigned] = ACTIONS(2541),
    [anon_sym_long] = ACTIONS(2541),
    [anon_sym_short] = ACTIONS(2541),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [anon_sym_static] = ACTIONS(2541),
    [anon_sym_register] = ACTIONS(2541),
    [anon_sym_inline] = ACTIONS(2541),
    [anon_sym___inline] = ACTIONS(2541),
    [anon_sym___inline__] = ACTIONS(2541),
    [anon_sym___forceinline] = ACTIONS(2541),
    [anon_sym_thread_local] = ACTIONS(2541),
    [anon_sym___thread] = ACTIONS(2541),
    [anon_sym_const] = ACTIONS(2541),
    [anon_sym_constexpr] = ACTIONS(2541),
    [anon_sym_volatile] = ACTIONS(2541),
    [anon_sym_restrict] = ACTIONS(2541),
    [anon_sym___restrict__] = ACTIONS(2541),
    [anon_sym__Atomic] = ACTIONS(2541),
    [anon_sym__Noreturn] = ACTIONS(2541),
    [anon_sym_noreturn] = ACTIONS(2541),
    [anon_sym__Nonnull] = ACTIONS(2541),
    [anon_sym_mutable] = ACTIONS(2541),
    [anon_sym_constinit] = ACTIONS(2541),
    [anon_sym_consteval] = ACTIONS(2541),
    [anon_sym___shared__] = ACTIONS(2541),
    [anon_sym___local__] = ACTIONS(2541),
    [anon_sym___constant__] = ACTIONS(2541),
    [anon_sym___managed__] = ACTIONS(2541),
    [anon_sym___grid_constant__] = ACTIONS(2541),
    [anon_sym_alignas] = ACTIONS(2541),
    [anon_sym__Alignas] = ACTIONS(2541),
    [sym_primitive_type] = ACTIONS(2541),
    [anon_sym_enum] = ACTIONS(2541),
    [anon_sym_class] = ACTIONS(2541),
    [anon_sym_struct] = ACTIONS(2541),
    [anon_sym_union] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2541),
    [anon_sym_decltype] = ACTIONS(2541),
    [anon_sym_explicit] = ACTIONS(2541),
    [anon_sym_typename] = ACTIONS(2541),
    [anon_sym_template] = ACTIONS(2541),
    [anon_sym_operator] = ACTIONS(2541),
    [anon_sym_friend] = ACTIONS(2541),
    [anon_sym_public] = ACTIONS(2541),
    [anon_sym_private] = ACTIONS(2541),
    [anon_sym_protected] = ACTIONS(2541),
    [anon_sym_using] = ACTIONS(2541),
    [anon_sym_static_assert] = ACTIONS(2541),
    [anon_sym___launch_bounds__] = ACTIONS(2541),
  },
  [STATE(1808)] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token2] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [aux_sym_preproc_else_token1] = ACTIONS(2549),
    [aux_sym_preproc_elif_token1] = ACTIONS(2549),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym___device__] = ACTIONS(2549),
    [anon_sym___host__] = ACTIONS(2549),
    [anon_sym___global__] = ACTIONS(2549),
    [anon_sym___forceinline__] = ACTIONS(2549),
    [anon_sym___noinline__] = ACTIONS(2549),
    [anon_sym_virtual] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym___attribute] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym__Nonnull] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym___shared__] = ACTIONS(2549),
    [anon_sym___local__] = ACTIONS(2549),
    [anon_sym___constant__] = ACTIONS(2549),
    [anon_sym___managed__] = ACTIONS(2549),
    [anon_sym___grid_constant__] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_friend] = ACTIONS(2549),
    [anon_sym_public] = ACTIONS(2549),
    [anon_sym_private] = ACTIONS(2549),
    [anon_sym_protected] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym___launch_bounds__] = ACTIONS(2549),
  },
  [STATE(1809)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_RPAREN] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4330),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4330),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4330),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4332),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4330),
    [anon_sym___extension__] = ACTIONS(4332),
    [anon_sym___global__] = ACTIONS(4332),
    [anon_sym___attribute__] = ACTIONS(4332),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4332),
    [anon_sym_EQ] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4332),
    [anon_sym_volatile] = ACTIONS(4332),
    [anon_sym_restrict] = ACTIONS(4332),
    [anon_sym___restrict__] = ACTIONS(4332),
    [anon_sym__Atomic] = ACTIONS(4332),
    [anon_sym__Noreturn] = ACTIONS(4332),
    [anon_sym_noreturn] = ACTIONS(4332),
    [anon_sym__Nonnull] = ACTIONS(4332),
    [anon_sym_mutable] = ACTIONS(4332),
    [anon_sym_constinit] = ACTIONS(4332),
    [anon_sym_consteval] = ACTIONS(4332),
    [anon_sym___shared__] = ACTIONS(4332),
    [anon_sym___local__] = ACTIONS(4332),
    [anon_sym___constant__] = ACTIONS(4332),
    [anon_sym___managed__] = ACTIONS(4332),
    [anon_sym___grid_constant__] = ACTIONS(4332),
    [anon_sym_alignas] = ACTIONS(4332),
    [anon_sym__Alignas] = ACTIONS(4332),
    [anon_sym_COLON] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_STAR_EQ] = ACTIONS(4332),
    [anon_sym_SLASH_EQ] = ACTIONS(4332),
    [anon_sym_PERCENT_EQ] = ACTIONS(4332),
    [anon_sym_PLUS_EQ] = ACTIONS(4332),
    [anon_sym_DASH_EQ] = ACTIONS(4332),
    [anon_sym_LT_LT_EQ] = ACTIONS(4332),
    [anon_sym_GT_GT_EQ] = ACTIONS(4332),
    [anon_sym_AMP_EQ] = ACTIONS(4332),
    [anon_sym_CARET_EQ] = ACTIONS(4332),
    [anon_sym_PIPE_EQ] = ACTIONS(4332),
    [anon_sym_and_eq] = ACTIONS(4332),
    [anon_sym_or_eq] = ACTIONS(4332),
    [anon_sym_xor_eq] = ACTIONS(4332),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_bitor] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4330),
    [anon_sym_bitand] = ACTIONS(4332),
    [anon_sym_not_eq] = ACTIONS(4332),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4330),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4332),
    [anon_sym_decltype] = ACTIONS(4332),
    [anon_sym_final] = ACTIONS(4332),
    [anon_sym_override] = ACTIONS(4332),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4332),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
  },
  [STATE(1810)] = {
    [sym_identifier] = ACTIONS(2533),
    [aux_sym_preproc_def_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token2] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2533),
    [aux_sym_preproc_else_token1] = ACTIONS(2533),
    [aux_sym_preproc_elif_token1] = ACTIONS(2533),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2533),
    [sym_preproc_directive] = ACTIONS(2533),
    [anon_sym_LPAREN2] = ACTIONS(2535),
    [anon_sym_TILDE] = ACTIONS(2535),
    [anon_sym_STAR] = ACTIONS(2535),
    [anon_sym_AMP_AMP] = ACTIONS(2535),
    [anon_sym_AMP] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym___extension__] = ACTIONS(2533),
    [anon_sym_typedef] = ACTIONS(2533),
    [anon_sym___device__] = ACTIONS(2533),
    [anon_sym___host__] = ACTIONS(2533),
    [anon_sym___global__] = ACTIONS(2533),
    [anon_sym___forceinline__] = ACTIONS(2533),
    [anon_sym___noinline__] = ACTIONS(2533),
    [anon_sym_virtual] = ACTIONS(2533),
    [anon_sym_extern] = ACTIONS(2533),
    [anon_sym___attribute__] = ACTIONS(2533),
    [anon_sym___attribute] = ACTIONS(2533),
    [anon_sym_COLON_COLON] = ACTIONS(2535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2535),
    [anon_sym___declspec] = ACTIONS(2533),
    [anon_sym___based] = ACTIONS(2533),
    [anon_sym_signed] = ACTIONS(2533),
    [anon_sym_unsigned] = ACTIONS(2533),
    [anon_sym_long] = ACTIONS(2533),
    [anon_sym_short] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2533),
    [anon_sym_static] = ACTIONS(2533),
    [anon_sym_register] = ACTIONS(2533),
    [anon_sym_inline] = ACTIONS(2533),
    [anon_sym___inline] = ACTIONS(2533),
    [anon_sym___inline__] = ACTIONS(2533),
    [anon_sym___forceinline] = ACTIONS(2533),
    [anon_sym_thread_local] = ACTIONS(2533),
    [anon_sym___thread] = ACTIONS(2533),
    [anon_sym_const] = ACTIONS(2533),
    [anon_sym_constexpr] = ACTIONS(2533),
    [anon_sym_volatile] = ACTIONS(2533),
    [anon_sym_restrict] = ACTIONS(2533),
    [anon_sym___restrict__] = ACTIONS(2533),
    [anon_sym__Atomic] = ACTIONS(2533),
    [anon_sym__Noreturn] = ACTIONS(2533),
    [anon_sym_noreturn] = ACTIONS(2533),
    [anon_sym__Nonnull] = ACTIONS(2533),
    [anon_sym_mutable] = ACTIONS(2533),
    [anon_sym_constinit] = ACTIONS(2533),
    [anon_sym_consteval] = ACTIONS(2533),
    [anon_sym___shared__] = ACTIONS(2533),
    [anon_sym___local__] = ACTIONS(2533),
    [anon_sym___constant__] = ACTIONS(2533),
    [anon_sym___managed__] = ACTIONS(2533),
    [anon_sym___grid_constant__] = ACTIONS(2533),
    [anon_sym_alignas] = ACTIONS(2533),
    [anon_sym__Alignas] = ACTIONS(2533),
    [sym_primitive_type] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_class] = ACTIONS(2533),
    [anon_sym_struct] = ACTIONS(2533),
    [anon_sym_union] = ACTIONS(2533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2533),
    [anon_sym_decltype] = ACTIONS(2533),
    [anon_sym_explicit] = ACTIONS(2533),
    [anon_sym_typename] = ACTIONS(2533),
    [anon_sym_template] = ACTIONS(2533),
    [anon_sym_operator] = ACTIONS(2533),
    [anon_sym_friend] = ACTIONS(2533),
    [anon_sym_public] = ACTIONS(2533),
    [anon_sym_private] = ACTIONS(2533),
    [anon_sym_protected] = ACTIONS(2533),
    [anon_sym_using] = ACTIONS(2533),
    [anon_sym_static_assert] = ACTIONS(2533),
    [anon_sym___launch_bounds__] = ACTIONS(2533),
  },
  [STATE(1811)] = {
    [sym_identifier] = ACTIONS(2463),
    [aux_sym_preproc_def_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token2] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2463),
    [aux_sym_preproc_else_token1] = ACTIONS(2463),
    [aux_sym_preproc_elif_token1] = ACTIONS(2463),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2463),
    [sym_preproc_directive] = ACTIONS(2463),
    [anon_sym_LPAREN2] = ACTIONS(2465),
    [anon_sym_TILDE] = ACTIONS(2465),
    [anon_sym_STAR] = ACTIONS(2465),
    [anon_sym_AMP_AMP] = ACTIONS(2465),
    [anon_sym_AMP] = ACTIONS(2463),
    [anon_sym_SEMI] = ACTIONS(2465),
    [anon_sym___extension__] = ACTIONS(2463),
    [anon_sym_typedef] = ACTIONS(2463),
    [anon_sym___device__] = ACTIONS(2463),
    [anon_sym___host__] = ACTIONS(2463),
    [anon_sym___global__] = ACTIONS(2463),
    [anon_sym___forceinline__] = ACTIONS(2463),
    [anon_sym___noinline__] = ACTIONS(2463),
    [anon_sym_virtual] = ACTIONS(2463),
    [anon_sym_extern] = ACTIONS(2463),
    [anon_sym___attribute__] = ACTIONS(2463),
    [anon_sym___attribute] = ACTIONS(2463),
    [anon_sym_COLON_COLON] = ACTIONS(2465),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2465),
    [anon_sym___declspec] = ACTIONS(2463),
    [anon_sym___based] = ACTIONS(2463),
    [anon_sym_signed] = ACTIONS(2463),
    [anon_sym_unsigned] = ACTIONS(2463),
    [anon_sym_long] = ACTIONS(2463),
    [anon_sym_short] = ACTIONS(2463),
    [anon_sym_LBRACK] = ACTIONS(2463),
    [anon_sym_static] = ACTIONS(2463),
    [anon_sym_register] = ACTIONS(2463),
    [anon_sym_inline] = ACTIONS(2463),
    [anon_sym___inline] = ACTIONS(2463),
    [anon_sym___inline__] = ACTIONS(2463),
    [anon_sym___forceinline] = ACTIONS(2463),
    [anon_sym_thread_local] = ACTIONS(2463),
    [anon_sym___thread] = ACTIONS(2463),
    [anon_sym_const] = ACTIONS(2463),
    [anon_sym_constexpr] = ACTIONS(2463),
    [anon_sym_volatile] = ACTIONS(2463),
    [anon_sym_restrict] = ACTIONS(2463),
    [anon_sym___restrict__] = ACTIONS(2463),
    [anon_sym__Atomic] = ACTIONS(2463),
    [anon_sym__Noreturn] = ACTIONS(2463),
    [anon_sym_noreturn] = ACTIONS(2463),
    [anon_sym__Nonnull] = ACTIONS(2463),
    [anon_sym_mutable] = ACTIONS(2463),
    [anon_sym_constinit] = ACTIONS(2463),
    [anon_sym_consteval] = ACTIONS(2463),
    [anon_sym___shared__] = ACTIONS(2463),
    [anon_sym___local__] = ACTIONS(2463),
    [anon_sym___constant__] = ACTIONS(2463),
    [anon_sym___managed__] = ACTIONS(2463),
    [anon_sym___grid_constant__] = ACTIONS(2463),
    [anon_sym_alignas] = ACTIONS(2463),
    [anon_sym__Alignas] = ACTIONS(2463),
    [sym_primitive_type] = ACTIONS(2463),
    [anon_sym_enum] = ACTIONS(2463),
    [anon_sym_class] = ACTIONS(2463),
    [anon_sym_struct] = ACTIONS(2463),
    [anon_sym_union] = ACTIONS(2463),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2463),
    [anon_sym_decltype] = ACTIONS(2463),
    [anon_sym_explicit] = ACTIONS(2463),
    [anon_sym_typename] = ACTIONS(2463),
    [anon_sym_template] = ACTIONS(2463),
    [anon_sym_operator] = ACTIONS(2463),
    [anon_sym_friend] = ACTIONS(2463),
    [anon_sym_public] = ACTIONS(2463),
    [anon_sym_private] = ACTIONS(2463),
    [anon_sym_protected] = ACTIONS(2463),
    [anon_sym_using] = ACTIONS(2463),
    [anon_sym_static_assert] = ACTIONS(2463),
    [anon_sym___launch_bounds__] = ACTIONS(2463),
  },
  [STATE(1812)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [aux_sym_preproc_else_token1] = ACTIONS(2312),
    [aux_sym_preproc_elif_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(1813)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [aux_sym_preproc_else_token1] = ACTIONS(2312),
    [aux_sym_preproc_elif_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(1814)] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym___device__] = ACTIONS(2332),
    [anon_sym___host__] = ACTIONS(2332),
    [anon_sym___global__] = ACTIONS(2332),
    [anon_sym___forceinline__] = ACTIONS(2332),
    [anon_sym___noinline__] = ACTIONS(2332),
    [anon_sym_virtual] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym___attribute] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym__Nonnull] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym___shared__] = ACTIONS(2332),
    [anon_sym___local__] = ACTIONS(2332),
    [anon_sym___constant__] = ACTIONS(2332),
    [anon_sym___managed__] = ACTIONS(2332),
    [anon_sym___grid_constant__] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym___launch_bounds__] = ACTIONS(2332),
  },
  [STATE(1815)] = {
    [sym_identifier] = ACTIONS(2339),
    [aux_sym_preproc_def_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token2] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2339),
    [aux_sym_preproc_else_token1] = ACTIONS(2339),
    [aux_sym_preproc_elif_token1] = ACTIONS(2339),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2339),
    [sym_preproc_directive] = ACTIONS(2339),
    [anon_sym_LPAREN2] = ACTIONS(2341),
    [anon_sym_TILDE] = ACTIONS(2341),
    [anon_sym_STAR] = ACTIONS(2341),
    [anon_sym_AMP_AMP] = ACTIONS(2341),
    [anon_sym_AMP] = ACTIONS(2339),
    [anon_sym_SEMI] = ACTIONS(2341),
    [anon_sym___extension__] = ACTIONS(2339),
    [anon_sym_typedef] = ACTIONS(2339),
    [anon_sym___device__] = ACTIONS(2339),
    [anon_sym___host__] = ACTIONS(2339),
    [anon_sym___global__] = ACTIONS(2339),
    [anon_sym___forceinline__] = ACTIONS(2339),
    [anon_sym___noinline__] = ACTIONS(2339),
    [anon_sym_virtual] = ACTIONS(2339),
    [anon_sym_extern] = ACTIONS(2339),
    [anon_sym___attribute__] = ACTIONS(2339),
    [anon_sym___attribute] = ACTIONS(2339),
    [anon_sym_COLON_COLON] = ACTIONS(2341),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2341),
    [anon_sym___declspec] = ACTIONS(2339),
    [anon_sym___based] = ACTIONS(2339),
    [anon_sym_signed] = ACTIONS(2339),
    [anon_sym_unsigned] = ACTIONS(2339),
    [anon_sym_long] = ACTIONS(2339),
    [anon_sym_short] = ACTIONS(2339),
    [anon_sym_LBRACK] = ACTIONS(2339),
    [anon_sym_static] = ACTIONS(2339),
    [anon_sym_register] = ACTIONS(2339),
    [anon_sym_inline] = ACTIONS(2339),
    [anon_sym___inline] = ACTIONS(2339),
    [anon_sym___inline__] = ACTIONS(2339),
    [anon_sym___forceinline] = ACTIONS(2339),
    [anon_sym_thread_local] = ACTIONS(2339),
    [anon_sym___thread] = ACTIONS(2339),
    [anon_sym_const] = ACTIONS(2339),
    [anon_sym_constexpr] = ACTIONS(2339),
    [anon_sym_volatile] = ACTIONS(2339),
    [anon_sym_restrict] = ACTIONS(2339),
    [anon_sym___restrict__] = ACTIONS(2339),
    [anon_sym__Atomic] = ACTIONS(2339),
    [anon_sym__Noreturn] = ACTIONS(2339),
    [anon_sym_noreturn] = ACTIONS(2339),
    [anon_sym__Nonnull] = ACTIONS(2339),
    [anon_sym_mutable] = ACTIONS(2339),
    [anon_sym_constinit] = ACTIONS(2339),
    [anon_sym_consteval] = ACTIONS(2339),
    [anon_sym___shared__] = ACTIONS(2339),
    [anon_sym___local__] = ACTIONS(2339),
    [anon_sym___constant__] = ACTIONS(2339),
    [anon_sym___managed__] = ACTIONS(2339),
    [anon_sym___grid_constant__] = ACTIONS(2339),
    [anon_sym_alignas] = ACTIONS(2339),
    [anon_sym__Alignas] = ACTIONS(2339),
    [sym_primitive_type] = ACTIONS(2339),
    [anon_sym_enum] = ACTIONS(2339),
    [anon_sym_class] = ACTIONS(2339),
    [anon_sym_struct] = ACTIONS(2339),
    [anon_sym_union] = ACTIONS(2339),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2339),
    [anon_sym_decltype] = ACTIONS(2339),
    [anon_sym_explicit] = ACTIONS(2339),
    [anon_sym_typename] = ACTIONS(2339),
    [anon_sym_template] = ACTIONS(2339),
    [anon_sym_operator] = ACTIONS(2339),
    [anon_sym_friend] = ACTIONS(2339),
    [anon_sym_public] = ACTIONS(2339),
    [anon_sym_private] = ACTIONS(2339),
    [anon_sym_protected] = ACTIONS(2339),
    [anon_sym_using] = ACTIONS(2339),
    [anon_sym_static_assert] = ACTIONS(2339),
    [anon_sym___launch_bounds__] = ACTIONS(2339),
  },
  [STATE(1816)] = {
    [sym_identifier] = ACTIONS(2343),
    [aux_sym_preproc_def_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token2] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2343),
    [aux_sym_preproc_else_token1] = ACTIONS(2343),
    [aux_sym_preproc_elif_token1] = ACTIONS(2343),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2343),
    [sym_preproc_directive] = ACTIONS(2343),
    [anon_sym_LPAREN2] = ACTIONS(2345),
    [anon_sym_TILDE] = ACTIONS(2345),
    [anon_sym_STAR] = ACTIONS(2345),
    [anon_sym_AMP_AMP] = ACTIONS(2345),
    [anon_sym_AMP] = ACTIONS(2343),
    [anon_sym_SEMI] = ACTIONS(2345),
    [anon_sym___extension__] = ACTIONS(2343),
    [anon_sym_typedef] = ACTIONS(2343),
    [anon_sym___device__] = ACTIONS(2343),
    [anon_sym___host__] = ACTIONS(2343),
    [anon_sym___global__] = ACTIONS(2343),
    [anon_sym___forceinline__] = ACTIONS(2343),
    [anon_sym___noinline__] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2343),
    [anon_sym_extern] = ACTIONS(2343),
    [anon_sym___attribute__] = ACTIONS(2343),
    [anon_sym___attribute] = ACTIONS(2343),
    [anon_sym_COLON_COLON] = ACTIONS(2345),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2345),
    [anon_sym___declspec] = ACTIONS(2343),
    [anon_sym___based] = ACTIONS(2343),
    [anon_sym_signed] = ACTIONS(2343),
    [anon_sym_unsigned] = ACTIONS(2343),
    [anon_sym_long] = ACTIONS(2343),
    [anon_sym_short] = ACTIONS(2343),
    [anon_sym_LBRACK] = ACTIONS(2343),
    [anon_sym_static] = ACTIONS(2343),
    [anon_sym_register] = ACTIONS(2343),
    [anon_sym_inline] = ACTIONS(2343),
    [anon_sym___inline] = ACTIONS(2343),
    [anon_sym___inline__] = ACTIONS(2343),
    [anon_sym___forceinline] = ACTIONS(2343),
    [anon_sym_thread_local] = ACTIONS(2343),
    [anon_sym___thread] = ACTIONS(2343),
    [anon_sym_const] = ACTIONS(2343),
    [anon_sym_constexpr] = ACTIONS(2343),
    [anon_sym_volatile] = ACTIONS(2343),
    [anon_sym_restrict] = ACTIONS(2343),
    [anon_sym___restrict__] = ACTIONS(2343),
    [anon_sym__Atomic] = ACTIONS(2343),
    [anon_sym__Noreturn] = ACTIONS(2343),
    [anon_sym_noreturn] = ACTIONS(2343),
    [anon_sym__Nonnull] = ACTIONS(2343),
    [anon_sym_mutable] = ACTIONS(2343),
    [anon_sym_constinit] = ACTIONS(2343),
    [anon_sym_consteval] = ACTIONS(2343),
    [anon_sym___shared__] = ACTIONS(2343),
    [anon_sym___local__] = ACTIONS(2343),
    [anon_sym___constant__] = ACTIONS(2343),
    [anon_sym___managed__] = ACTIONS(2343),
    [anon_sym___grid_constant__] = ACTIONS(2343),
    [anon_sym_alignas] = ACTIONS(2343),
    [anon_sym__Alignas] = ACTIONS(2343),
    [sym_primitive_type] = ACTIONS(2343),
    [anon_sym_enum] = ACTIONS(2343),
    [anon_sym_class] = ACTIONS(2343),
    [anon_sym_struct] = ACTIONS(2343),
    [anon_sym_union] = ACTIONS(2343),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2343),
    [anon_sym_decltype] = ACTIONS(2343),
    [anon_sym_explicit] = ACTIONS(2343),
    [anon_sym_typename] = ACTIONS(2343),
    [anon_sym_template] = ACTIONS(2343),
    [anon_sym_operator] = ACTIONS(2343),
    [anon_sym_friend] = ACTIONS(2343),
    [anon_sym_public] = ACTIONS(2343),
    [anon_sym_private] = ACTIONS(2343),
    [anon_sym_protected] = ACTIONS(2343),
    [anon_sym_using] = ACTIONS(2343),
    [anon_sym_static_assert] = ACTIONS(2343),
    [anon_sym___launch_bounds__] = ACTIONS(2343),
  },
  [STATE(1817)] = {
    [sym_identifier] = ACTIONS(2347),
    [aux_sym_preproc_def_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token2] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2347),
    [aux_sym_preproc_else_token1] = ACTIONS(2347),
    [aux_sym_preproc_elif_token1] = ACTIONS(2347),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2347),
    [sym_preproc_directive] = ACTIONS(2347),
    [anon_sym_LPAREN2] = ACTIONS(2349),
    [anon_sym_TILDE] = ACTIONS(2349),
    [anon_sym_STAR] = ACTIONS(2349),
    [anon_sym_AMP_AMP] = ACTIONS(2349),
    [anon_sym_AMP] = ACTIONS(2347),
    [anon_sym_SEMI] = ACTIONS(2349),
    [anon_sym___extension__] = ACTIONS(2347),
    [anon_sym_typedef] = ACTIONS(2347),
    [anon_sym___device__] = ACTIONS(2347),
    [anon_sym___host__] = ACTIONS(2347),
    [anon_sym___global__] = ACTIONS(2347),
    [anon_sym___forceinline__] = ACTIONS(2347),
    [anon_sym___noinline__] = ACTIONS(2347),
    [anon_sym_virtual] = ACTIONS(2347),
    [anon_sym_extern] = ACTIONS(2347),
    [anon_sym___attribute__] = ACTIONS(2347),
    [anon_sym___attribute] = ACTIONS(2347),
    [anon_sym_COLON_COLON] = ACTIONS(2349),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2349),
    [anon_sym___declspec] = ACTIONS(2347),
    [anon_sym___based] = ACTIONS(2347),
    [anon_sym_signed] = ACTIONS(2347),
    [anon_sym_unsigned] = ACTIONS(2347),
    [anon_sym_long] = ACTIONS(2347),
    [anon_sym_short] = ACTIONS(2347),
    [anon_sym_LBRACK] = ACTIONS(2347),
    [anon_sym_static] = ACTIONS(2347),
    [anon_sym_register] = ACTIONS(2347),
    [anon_sym_inline] = ACTIONS(2347),
    [anon_sym___inline] = ACTIONS(2347),
    [anon_sym___inline__] = ACTIONS(2347),
    [anon_sym___forceinline] = ACTIONS(2347),
    [anon_sym_thread_local] = ACTIONS(2347),
    [anon_sym___thread] = ACTIONS(2347),
    [anon_sym_const] = ACTIONS(2347),
    [anon_sym_constexpr] = ACTIONS(2347),
    [anon_sym_volatile] = ACTIONS(2347),
    [anon_sym_restrict] = ACTIONS(2347),
    [anon_sym___restrict__] = ACTIONS(2347),
    [anon_sym__Atomic] = ACTIONS(2347),
    [anon_sym__Noreturn] = ACTIONS(2347),
    [anon_sym_noreturn] = ACTIONS(2347),
    [anon_sym__Nonnull] = ACTIONS(2347),
    [anon_sym_mutable] = ACTIONS(2347),
    [anon_sym_constinit] = ACTIONS(2347),
    [anon_sym_consteval] = ACTIONS(2347),
    [anon_sym___shared__] = ACTIONS(2347),
    [anon_sym___local__] = ACTIONS(2347),
    [anon_sym___constant__] = ACTIONS(2347),
    [anon_sym___managed__] = ACTIONS(2347),
    [anon_sym___grid_constant__] = ACTIONS(2347),
    [anon_sym_alignas] = ACTIONS(2347),
    [anon_sym__Alignas] = ACTIONS(2347),
    [sym_primitive_type] = ACTIONS(2347),
    [anon_sym_enum] = ACTIONS(2347),
    [anon_sym_class] = ACTIONS(2347),
    [anon_sym_struct] = ACTIONS(2347),
    [anon_sym_union] = ACTIONS(2347),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2347),
    [anon_sym_decltype] = ACTIONS(2347),
    [anon_sym_explicit] = ACTIONS(2347),
    [anon_sym_typename] = ACTIONS(2347),
    [anon_sym_template] = ACTIONS(2347),
    [anon_sym_operator] = ACTIONS(2347),
    [anon_sym_friend] = ACTIONS(2347),
    [anon_sym_public] = ACTIONS(2347),
    [anon_sym_private] = ACTIONS(2347),
    [anon_sym_protected] = ACTIONS(2347),
    [anon_sym_using] = ACTIONS(2347),
    [anon_sym_static_assert] = ACTIONS(2347),
    [anon_sym___launch_bounds__] = ACTIONS(2347),
  },
  [STATE(1818)] = {
    [sym_identifier] = ACTIONS(2351),
    [aux_sym_preproc_def_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token2] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2351),
    [aux_sym_preproc_else_token1] = ACTIONS(2351),
    [aux_sym_preproc_elif_token1] = ACTIONS(2351),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2351),
    [sym_preproc_directive] = ACTIONS(2351),
    [anon_sym_LPAREN2] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(2353),
    [anon_sym_STAR] = ACTIONS(2353),
    [anon_sym_AMP_AMP] = ACTIONS(2353),
    [anon_sym_AMP] = ACTIONS(2351),
    [anon_sym_SEMI] = ACTIONS(2353),
    [anon_sym___extension__] = ACTIONS(2351),
    [anon_sym_typedef] = ACTIONS(2351),
    [anon_sym___device__] = ACTIONS(2351),
    [anon_sym___host__] = ACTIONS(2351),
    [anon_sym___global__] = ACTIONS(2351),
    [anon_sym___forceinline__] = ACTIONS(2351),
    [anon_sym___noinline__] = ACTIONS(2351),
    [anon_sym_virtual] = ACTIONS(2351),
    [anon_sym_extern] = ACTIONS(2351),
    [anon_sym___attribute__] = ACTIONS(2351),
    [anon_sym___attribute] = ACTIONS(2351),
    [anon_sym_COLON_COLON] = ACTIONS(2353),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2353),
    [anon_sym___declspec] = ACTIONS(2351),
    [anon_sym___based] = ACTIONS(2351),
    [anon_sym_signed] = ACTIONS(2351),
    [anon_sym_unsigned] = ACTIONS(2351),
    [anon_sym_long] = ACTIONS(2351),
    [anon_sym_short] = ACTIONS(2351),
    [anon_sym_LBRACK] = ACTIONS(2351),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_register] = ACTIONS(2351),
    [anon_sym_inline] = ACTIONS(2351),
    [anon_sym___inline] = ACTIONS(2351),
    [anon_sym___inline__] = ACTIONS(2351),
    [anon_sym___forceinline] = ACTIONS(2351),
    [anon_sym_thread_local] = ACTIONS(2351),
    [anon_sym___thread] = ACTIONS(2351),
    [anon_sym_const] = ACTIONS(2351),
    [anon_sym_constexpr] = ACTIONS(2351),
    [anon_sym_volatile] = ACTIONS(2351),
    [anon_sym_restrict] = ACTIONS(2351),
    [anon_sym___restrict__] = ACTIONS(2351),
    [anon_sym__Atomic] = ACTIONS(2351),
    [anon_sym__Noreturn] = ACTIONS(2351),
    [anon_sym_noreturn] = ACTIONS(2351),
    [anon_sym__Nonnull] = ACTIONS(2351),
    [anon_sym_mutable] = ACTIONS(2351),
    [anon_sym_constinit] = ACTIONS(2351),
    [anon_sym_consteval] = ACTIONS(2351),
    [anon_sym___shared__] = ACTIONS(2351),
    [anon_sym___local__] = ACTIONS(2351),
    [anon_sym___constant__] = ACTIONS(2351),
    [anon_sym___managed__] = ACTIONS(2351),
    [anon_sym___grid_constant__] = ACTIONS(2351),
    [anon_sym_alignas] = ACTIONS(2351),
    [anon_sym__Alignas] = ACTIONS(2351),
    [sym_primitive_type] = ACTIONS(2351),
    [anon_sym_enum] = ACTIONS(2351),
    [anon_sym_class] = ACTIONS(2351),
    [anon_sym_struct] = ACTIONS(2351),
    [anon_sym_union] = ACTIONS(2351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2351),
    [anon_sym_decltype] = ACTIONS(2351),
    [anon_sym_explicit] = ACTIONS(2351),
    [anon_sym_typename] = ACTIONS(2351),
    [anon_sym_template] = ACTIONS(2351),
    [anon_sym_operator] = ACTIONS(2351),
    [anon_sym_friend] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_using] = ACTIONS(2351),
    [anon_sym_static_assert] = ACTIONS(2351),
    [anon_sym___launch_bounds__] = ACTIONS(2351),
  },
  [STATE(1819)] = {
    [sym_identifier] = ACTIONS(5593),
    [aux_sym_preproc_def_token1] = ACTIONS(5593),
    [aux_sym_preproc_if_token1] = ACTIONS(5593),
    [aux_sym_preproc_if_token2] = ACTIONS(5593),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5593),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5593),
    [aux_sym_preproc_else_token1] = ACTIONS(5593),
    [aux_sym_preproc_elif_token1] = ACTIONS(5593),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5593),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5593),
    [sym_preproc_directive] = ACTIONS(5593),
    [anon_sym_LPAREN2] = ACTIONS(5595),
    [anon_sym_TILDE] = ACTIONS(5595),
    [anon_sym_STAR] = ACTIONS(5595),
    [anon_sym_AMP_AMP] = ACTIONS(5595),
    [anon_sym_AMP] = ACTIONS(5593),
    [anon_sym_SEMI] = ACTIONS(5595),
    [anon_sym___extension__] = ACTIONS(5593),
    [anon_sym_typedef] = ACTIONS(5593),
    [anon_sym___device__] = ACTIONS(5593),
    [anon_sym___host__] = ACTIONS(5593),
    [anon_sym___global__] = ACTIONS(5593),
    [anon_sym___forceinline__] = ACTIONS(5593),
    [anon_sym___noinline__] = ACTIONS(5593),
    [anon_sym_virtual] = ACTIONS(5593),
    [anon_sym_extern] = ACTIONS(5593),
    [anon_sym___attribute__] = ACTIONS(5593),
    [anon_sym___attribute] = ACTIONS(5593),
    [anon_sym_COLON_COLON] = ACTIONS(5595),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5595),
    [anon_sym___declspec] = ACTIONS(5593),
    [anon_sym___based] = ACTIONS(5593),
    [anon_sym_signed] = ACTIONS(5593),
    [anon_sym_unsigned] = ACTIONS(5593),
    [anon_sym_long] = ACTIONS(5593),
    [anon_sym_short] = ACTIONS(5593),
    [anon_sym_LBRACK] = ACTIONS(5593),
    [anon_sym_static] = ACTIONS(5593),
    [anon_sym_register] = ACTIONS(5593),
    [anon_sym_inline] = ACTIONS(5593),
    [anon_sym___inline] = ACTIONS(5593),
    [anon_sym___inline__] = ACTIONS(5593),
    [anon_sym___forceinline] = ACTIONS(5593),
    [anon_sym_thread_local] = ACTIONS(5593),
    [anon_sym___thread] = ACTIONS(5593),
    [anon_sym_const] = ACTIONS(5593),
    [anon_sym_constexpr] = ACTIONS(5593),
    [anon_sym_volatile] = ACTIONS(5593),
    [anon_sym_restrict] = ACTIONS(5593),
    [anon_sym___restrict__] = ACTIONS(5593),
    [anon_sym__Atomic] = ACTIONS(5593),
    [anon_sym__Noreturn] = ACTIONS(5593),
    [anon_sym_noreturn] = ACTIONS(5593),
    [anon_sym__Nonnull] = ACTIONS(5593),
    [anon_sym_mutable] = ACTIONS(5593),
    [anon_sym_constinit] = ACTIONS(5593),
    [anon_sym_consteval] = ACTIONS(5593),
    [anon_sym___shared__] = ACTIONS(5593),
    [anon_sym___local__] = ACTIONS(5593),
    [anon_sym___constant__] = ACTIONS(5593),
    [anon_sym___managed__] = ACTIONS(5593),
    [anon_sym___grid_constant__] = ACTIONS(5593),
    [anon_sym_alignas] = ACTIONS(5593),
    [anon_sym__Alignas] = ACTIONS(5593),
    [sym_primitive_type] = ACTIONS(5593),
    [anon_sym_enum] = ACTIONS(5593),
    [anon_sym_class] = ACTIONS(5593),
    [anon_sym_struct] = ACTIONS(5593),
    [anon_sym_union] = ACTIONS(5593),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5593),
    [anon_sym_decltype] = ACTIONS(5593),
    [anon_sym_explicit] = ACTIONS(5593),
    [anon_sym_typename] = ACTIONS(5593),
    [anon_sym_template] = ACTIONS(5593),
    [anon_sym_operator] = ACTIONS(5593),
    [anon_sym_friend] = ACTIONS(5593),
    [anon_sym_public] = ACTIONS(5593),
    [anon_sym_private] = ACTIONS(5593),
    [anon_sym_protected] = ACTIONS(5593),
    [anon_sym_using] = ACTIONS(5593),
    [anon_sym_static_assert] = ACTIONS(5593),
    [anon_sym___launch_bounds__] = ACTIONS(5593),
  },
  [STATE(1820)] = {
    [sym_identifier] = ACTIONS(2387),
    [aux_sym_preproc_def_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token2] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2387),
    [aux_sym_preproc_else_token1] = ACTIONS(2387),
    [aux_sym_preproc_elif_token1] = ACTIONS(2387),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2387),
    [sym_preproc_directive] = ACTIONS(2387),
    [anon_sym_LPAREN2] = ACTIONS(2389),
    [anon_sym_TILDE] = ACTIONS(2389),
    [anon_sym_STAR] = ACTIONS(2389),
    [anon_sym_AMP_AMP] = ACTIONS(2389),
    [anon_sym_AMP] = ACTIONS(2387),
    [anon_sym_SEMI] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2387),
    [anon_sym_typedef] = ACTIONS(2387),
    [anon_sym___device__] = ACTIONS(2387),
    [anon_sym___host__] = ACTIONS(2387),
    [anon_sym___global__] = ACTIONS(2387),
    [anon_sym___forceinline__] = ACTIONS(2387),
    [anon_sym___noinline__] = ACTIONS(2387),
    [anon_sym_virtual] = ACTIONS(2387),
    [anon_sym_extern] = ACTIONS(2387),
    [anon_sym___attribute__] = ACTIONS(2387),
    [anon_sym___attribute] = ACTIONS(2387),
    [anon_sym_COLON_COLON] = ACTIONS(2389),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2389),
    [anon_sym___declspec] = ACTIONS(2387),
    [anon_sym___based] = ACTIONS(2387),
    [anon_sym_signed] = ACTIONS(2387),
    [anon_sym_unsigned] = ACTIONS(2387),
    [anon_sym_long] = ACTIONS(2387),
    [anon_sym_short] = ACTIONS(2387),
    [anon_sym_LBRACK] = ACTIONS(2387),
    [anon_sym_static] = ACTIONS(2387),
    [anon_sym_register] = ACTIONS(2387),
    [anon_sym_inline] = ACTIONS(2387),
    [anon_sym___inline] = ACTIONS(2387),
    [anon_sym___inline__] = ACTIONS(2387),
    [anon_sym___forceinline] = ACTIONS(2387),
    [anon_sym_thread_local] = ACTIONS(2387),
    [anon_sym___thread] = ACTIONS(2387),
    [anon_sym_const] = ACTIONS(2387),
    [anon_sym_constexpr] = ACTIONS(2387),
    [anon_sym_volatile] = ACTIONS(2387),
    [anon_sym_restrict] = ACTIONS(2387),
    [anon_sym___restrict__] = ACTIONS(2387),
    [anon_sym__Atomic] = ACTIONS(2387),
    [anon_sym__Noreturn] = ACTIONS(2387),
    [anon_sym_noreturn] = ACTIONS(2387),
    [anon_sym__Nonnull] = ACTIONS(2387),
    [anon_sym_mutable] = ACTIONS(2387),
    [anon_sym_constinit] = ACTIONS(2387),
    [anon_sym_consteval] = ACTIONS(2387),
    [anon_sym___shared__] = ACTIONS(2387),
    [anon_sym___local__] = ACTIONS(2387),
    [anon_sym___constant__] = ACTIONS(2387),
    [anon_sym___managed__] = ACTIONS(2387),
    [anon_sym___grid_constant__] = ACTIONS(2387),
    [anon_sym_alignas] = ACTIONS(2387),
    [anon_sym__Alignas] = ACTIONS(2387),
    [sym_primitive_type] = ACTIONS(2387),
    [anon_sym_enum] = ACTIONS(2387),
    [anon_sym_class] = ACTIONS(2387),
    [anon_sym_struct] = ACTIONS(2387),
    [anon_sym_union] = ACTIONS(2387),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2387),
    [anon_sym_decltype] = ACTIONS(2387),
    [anon_sym_explicit] = ACTIONS(2387),
    [anon_sym_typename] = ACTIONS(2387),
    [anon_sym_template] = ACTIONS(2387),
    [anon_sym_operator] = ACTIONS(2387),
    [anon_sym_friend] = ACTIONS(2387),
    [anon_sym_public] = ACTIONS(2387),
    [anon_sym_private] = ACTIONS(2387),
    [anon_sym_protected] = ACTIONS(2387),
    [anon_sym_using] = ACTIONS(2387),
    [anon_sym_static_assert] = ACTIONS(2387),
    [anon_sym___launch_bounds__] = ACTIONS(2387),
  },
  [STATE(1821)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_RPAREN] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4396),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4396),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4396),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4398),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4396),
    [anon_sym___extension__] = ACTIONS(4398),
    [anon_sym___global__] = ACTIONS(4398),
    [anon_sym___attribute__] = ACTIONS(4398),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4398),
    [anon_sym_EQ] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4398),
    [anon_sym_volatile] = ACTIONS(4398),
    [anon_sym_restrict] = ACTIONS(4398),
    [anon_sym___restrict__] = ACTIONS(4398),
    [anon_sym__Atomic] = ACTIONS(4398),
    [anon_sym__Noreturn] = ACTIONS(4398),
    [anon_sym_noreturn] = ACTIONS(4398),
    [anon_sym__Nonnull] = ACTIONS(4398),
    [anon_sym_mutable] = ACTIONS(4398),
    [anon_sym_constinit] = ACTIONS(4398),
    [anon_sym_consteval] = ACTIONS(4398),
    [anon_sym___shared__] = ACTIONS(4398),
    [anon_sym___local__] = ACTIONS(4398),
    [anon_sym___constant__] = ACTIONS(4398),
    [anon_sym___managed__] = ACTIONS(4398),
    [anon_sym___grid_constant__] = ACTIONS(4398),
    [anon_sym_alignas] = ACTIONS(4398),
    [anon_sym__Alignas] = ACTIONS(4398),
    [anon_sym_COLON] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_STAR_EQ] = ACTIONS(4398),
    [anon_sym_SLASH_EQ] = ACTIONS(4398),
    [anon_sym_PERCENT_EQ] = ACTIONS(4398),
    [anon_sym_PLUS_EQ] = ACTIONS(4398),
    [anon_sym_DASH_EQ] = ACTIONS(4398),
    [anon_sym_LT_LT_EQ] = ACTIONS(4398),
    [anon_sym_GT_GT_EQ] = ACTIONS(4398),
    [anon_sym_AMP_EQ] = ACTIONS(4398),
    [anon_sym_CARET_EQ] = ACTIONS(4398),
    [anon_sym_PIPE_EQ] = ACTIONS(4398),
    [anon_sym_and_eq] = ACTIONS(4398),
    [anon_sym_or_eq] = ACTIONS(4398),
    [anon_sym_xor_eq] = ACTIONS(4398),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_bitor] = ACTIONS(4398),
    [anon_sym_xor] = ACTIONS(4396),
    [anon_sym_bitand] = ACTIONS(4398),
    [anon_sym_not_eq] = ACTIONS(4398),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4396),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4398),
    [anon_sym_decltype] = ACTIONS(4398),
    [anon_sym_final] = ACTIONS(4398),
    [anon_sym_override] = ACTIONS(4398),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4398),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
  },
  [STATE(1822)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_RPAREN] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4402),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4402),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4402),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4404),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4402),
    [anon_sym___extension__] = ACTIONS(4404),
    [anon_sym___global__] = ACTIONS(4404),
    [anon_sym___attribute__] = ACTIONS(4404),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_EQ] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4404),
    [anon_sym_volatile] = ACTIONS(4404),
    [anon_sym_restrict] = ACTIONS(4404),
    [anon_sym___restrict__] = ACTIONS(4404),
    [anon_sym__Atomic] = ACTIONS(4404),
    [anon_sym__Noreturn] = ACTIONS(4404),
    [anon_sym_noreturn] = ACTIONS(4404),
    [anon_sym__Nonnull] = ACTIONS(4404),
    [anon_sym_mutable] = ACTIONS(4404),
    [anon_sym_constinit] = ACTIONS(4404),
    [anon_sym_consteval] = ACTIONS(4404),
    [anon_sym___shared__] = ACTIONS(4404),
    [anon_sym___local__] = ACTIONS(4404),
    [anon_sym___constant__] = ACTIONS(4404),
    [anon_sym___managed__] = ACTIONS(4404),
    [anon_sym___grid_constant__] = ACTIONS(4404),
    [anon_sym_alignas] = ACTIONS(4404),
    [anon_sym__Alignas] = ACTIONS(4404),
    [anon_sym_COLON] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_STAR_EQ] = ACTIONS(4404),
    [anon_sym_SLASH_EQ] = ACTIONS(4404),
    [anon_sym_PERCENT_EQ] = ACTIONS(4404),
    [anon_sym_PLUS_EQ] = ACTIONS(4404),
    [anon_sym_DASH_EQ] = ACTIONS(4404),
    [anon_sym_LT_LT_EQ] = ACTIONS(4404),
    [anon_sym_GT_GT_EQ] = ACTIONS(4404),
    [anon_sym_AMP_EQ] = ACTIONS(4404),
    [anon_sym_CARET_EQ] = ACTIONS(4404),
    [anon_sym_PIPE_EQ] = ACTIONS(4404),
    [anon_sym_and_eq] = ACTIONS(4404),
    [anon_sym_or_eq] = ACTIONS(4404),
    [anon_sym_xor_eq] = ACTIONS(4404),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_bitor] = ACTIONS(4404),
    [anon_sym_xor] = ACTIONS(4402),
    [anon_sym_bitand] = ACTIONS(4404),
    [anon_sym_not_eq] = ACTIONS(4404),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4402),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4404),
    [anon_sym_decltype] = ACTIONS(4404),
    [anon_sym_final] = ACTIONS(4404),
    [anon_sym_override] = ACTIONS(4404),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4404),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
  },
  [STATE(1823)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_RPAREN] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4408),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4408),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4408),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4410),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4408),
    [anon_sym___extension__] = ACTIONS(4410),
    [anon_sym___global__] = ACTIONS(4410),
    [anon_sym___attribute__] = ACTIONS(4410),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4410),
    [anon_sym_EQ] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4410),
    [anon_sym_volatile] = ACTIONS(4410),
    [anon_sym_restrict] = ACTIONS(4410),
    [anon_sym___restrict__] = ACTIONS(4410),
    [anon_sym__Atomic] = ACTIONS(4410),
    [anon_sym__Noreturn] = ACTIONS(4410),
    [anon_sym_noreturn] = ACTIONS(4410),
    [anon_sym__Nonnull] = ACTIONS(4410),
    [anon_sym_mutable] = ACTIONS(4410),
    [anon_sym_constinit] = ACTIONS(4410),
    [anon_sym_consteval] = ACTIONS(4410),
    [anon_sym___shared__] = ACTIONS(4410),
    [anon_sym___local__] = ACTIONS(4410),
    [anon_sym___constant__] = ACTIONS(4410),
    [anon_sym___managed__] = ACTIONS(4410),
    [anon_sym___grid_constant__] = ACTIONS(4410),
    [anon_sym_alignas] = ACTIONS(4410),
    [anon_sym__Alignas] = ACTIONS(4410),
    [anon_sym_COLON] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_STAR_EQ] = ACTIONS(4410),
    [anon_sym_SLASH_EQ] = ACTIONS(4410),
    [anon_sym_PERCENT_EQ] = ACTIONS(4410),
    [anon_sym_PLUS_EQ] = ACTIONS(4410),
    [anon_sym_DASH_EQ] = ACTIONS(4410),
    [anon_sym_LT_LT_EQ] = ACTIONS(4410),
    [anon_sym_GT_GT_EQ] = ACTIONS(4410),
    [anon_sym_AMP_EQ] = ACTIONS(4410),
    [anon_sym_CARET_EQ] = ACTIONS(4410),
    [anon_sym_PIPE_EQ] = ACTIONS(4410),
    [anon_sym_and_eq] = ACTIONS(4410),
    [anon_sym_or_eq] = ACTIONS(4410),
    [anon_sym_xor_eq] = ACTIONS(4410),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_bitor] = ACTIONS(4410),
    [anon_sym_xor] = ACTIONS(4408),
    [anon_sym_bitand] = ACTIONS(4410),
    [anon_sym_not_eq] = ACTIONS(4410),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4410),
    [anon_sym_decltype] = ACTIONS(4410),
    [anon_sym_final] = ACTIONS(4410),
    [anon_sym_override] = ACTIONS(4410),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4410),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
  },
  [STATE(1824)] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token2] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [aux_sym_preproc_else_token1] = ACTIONS(2565),
    [aux_sym_preproc_elif_token1] = ACTIONS(2565),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym___device__] = ACTIONS(2565),
    [anon_sym___host__] = ACTIONS(2565),
    [anon_sym___global__] = ACTIONS(2565),
    [anon_sym___forceinline__] = ACTIONS(2565),
    [anon_sym___noinline__] = ACTIONS(2565),
    [anon_sym_virtual] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym___attribute] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym__Nonnull] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym___shared__] = ACTIONS(2565),
    [anon_sym___local__] = ACTIONS(2565),
    [anon_sym___constant__] = ACTIONS(2565),
    [anon_sym___managed__] = ACTIONS(2565),
    [anon_sym___grid_constant__] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_friend] = ACTIONS(2565),
    [anon_sym_public] = ACTIONS(2565),
    [anon_sym_private] = ACTIONS(2565),
    [anon_sym_protected] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym___launch_bounds__] = ACTIONS(2565),
  },
  [STATE(1825)] = {
    [sym_identifier] = ACTIONS(2226),
    [aux_sym_preproc_def_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token2] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2226),
    [aux_sym_preproc_else_token1] = ACTIONS(2226),
    [aux_sym_preproc_elif_token1] = ACTIONS(2226),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2226),
    [sym_preproc_directive] = ACTIONS(2226),
    [anon_sym_LPAREN2] = ACTIONS(2228),
    [anon_sym_TILDE] = ACTIONS(2228),
    [anon_sym_STAR] = ACTIONS(2228),
    [anon_sym_AMP_AMP] = ACTIONS(2228),
    [anon_sym_AMP] = ACTIONS(2226),
    [anon_sym_SEMI] = ACTIONS(2228),
    [anon_sym___extension__] = ACTIONS(2226),
    [anon_sym_typedef] = ACTIONS(2226),
    [anon_sym___device__] = ACTIONS(2226),
    [anon_sym___host__] = ACTIONS(2226),
    [anon_sym___global__] = ACTIONS(2226),
    [anon_sym___forceinline__] = ACTIONS(2226),
    [anon_sym___noinline__] = ACTIONS(2226),
    [anon_sym_virtual] = ACTIONS(2226),
    [anon_sym_extern] = ACTIONS(2226),
    [anon_sym___attribute__] = ACTIONS(2226),
    [anon_sym___attribute] = ACTIONS(2226),
    [anon_sym_COLON_COLON] = ACTIONS(2228),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2228),
    [anon_sym___declspec] = ACTIONS(2226),
    [anon_sym___based] = ACTIONS(2226),
    [anon_sym_signed] = ACTIONS(2226),
    [anon_sym_unsigned] = ACTIONS(2226),
    [anon_sym_long] = ACTIONS(2226),
    [anon_sym_short] = ACTIONS(2226),
    [anon_sym_LBRACK] = ACTIONS(2226),
    [anon_sym_static] = ACTIONS(2226),
    [anon_sym_register] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(2226),
    [anon_sym___inline] = ACTIONS(2226),
    [anon_sym___inline__] = ACTIONS(2226),
    [anon_sym___forceinline] = ACTIONS(2226),
    [anon_sym_thread_local] = ACTIONS(2226),
    [anon_sym___thread] = ACTIONS(2226),
    [anon_sym_const] = ACTIONS(2226),
    [anon_sym_constexpr] = ACTIONS(2226),
    [anon_sym_volatile] = ACTIONS(2226),
    [anon_sym_restrict] = ACTIONS(2226),
    [anon_sym___restrict__] = ACTIONS(2226),
    [anon_sym__Atomic] = ACTIONS(2226),
    [anon_sym__Noreturn] = ACTIONS(2226),
    [anon_sym_noreturn] = ACTIONS(2226),
    [anon_sym__Nonnull] = ACTIONS(2226),
    [anon_sym_mutable] = ACTIONS(2226),
    [anon_sym_constinit] = ACTIONS(2226),
    [anon_sym_consteval] = ACTIONS(2226),
    [anon_sym___shared__] = ACTIONS(2226),
    [anon_sym___local__] = ACTIONS(2226),
    [anon_sym___constant__] = ACTIONS(2226),
    [anon_sym___managed__] = ACTIONS(2226),
    [anon_sym___grid_constant__] = ACTIONS(2226),
    [anon_sym_alignas] = ACTIONS(2226),
    [anon_sym__Alignas] = ACTIONS(2226),
    [sym_primitive_type] = ACTIONS(2226),
    [anon_sym_enum] = ACTIONS(2226),
    [anon_sym_class] = ACTIONS(2226),
    [anon_sym_struct] = ACTIONS(2226),
    [anon_sym_union] = ACTIONS(2226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2226),
    [anon_sym_decltype] = ACTIONS(2226),
    [anon_sym_explicit] = ACTIONS(2226),
    [anon_sym_typename] = ACTIONS(2226),
    [anon_sym_template] = ACTIONS(2226),
    [anon_sym_operator] = ACTIONS(2226),
    [anon_sym_friend] = ACTIONS(2226),
    [anon_sym_public] = ACTIONS(2226),
    [anon_sym_private] = ACTIONS(2226),
    [anon_sym_protected] = ACTIONS(2226),
    [anon_sym_using] = ACTIONS(2226),
    [anon_sym_static_assert] = ACTIONS(2226),
    [anon_sym___launch_bounds__] = ACTIONS(2226),
  },
  [STATE(1826)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token2] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [aux_sym_preproc_else_token1] = ACTIONS(2585),
    [aux_sym_preproc_elif_token1] = ACTIONS(2585),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_friend] = ACTIONS(2585),
    [anon_sym_public] = ACTIONS(2585),
    [anon_sym_private] = ACTIONS(2585),
    [anon_sym_protected] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(1827)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token2] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [aux_sym_preproc_else_token1] = ACTIONS(2585),
    [aux_sym_preproc_elif_token1] = ACTIONS(2585),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_friend] = ACTIONS(2585),
    [anon_sym_public] = ACTIONS(2585),
    [anon_sym_private] = ACTIONS(2585),
    [anon_sym_protected] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(1828)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [aux_sym_preproc_else_token1] = ACTIONS(2573),
    [aux_sym_preproc_elif_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(1829)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [aux_sym_preproc_else_token1] = ACTIONS(2573),
    [aux_sym_preproc_elif_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(1830)] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token2] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [aux_sym_preproc_else_token1] = ACTIONS(2328),
    [aux_sym_preproc_elif_token1] = ACTIONS(2328),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym___device__] = ACTIONS(2328),
    [anon_sym___host__] = ACTIONS(2328),
    [anon_sym___global__] = ACTIONS(2328),
    [anon_sym___forceinline__] = ACTIONS(2328),
    [anon_sym___noinline__] = ACTIONS(2328),
    [anon_sym_virtual] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym___attribute] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym__Nonnull] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym___shared__] = ACTIONS(2328),
    [anon_sym___local__] = ACTIONS(2328),
    [anon_sym___constant__] = ACTIONS(2328),
    [anon_sym___managed__] = ACTIONS(2328),
    [anon_sym___grid_constant__] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_friend] = ACTIONS(2328),
    [anon_sym_public] = ACTIONS(2328),
    [anon_sym_private] = ACTIONS(2328),
    [anon_sym_protected] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym___launch_bounds__] = ACTIONS(2328),
  },
  [STATE(1831)] = {
    [sym_identifier] = ACTIONS(2230),
    [aux_sym_preproc_def_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token2] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2230),
    [aux_sym_preproc_else_token1] = ACTIONS(2230),
    [aux_sym_preproc_elif_token1] = ACTIONS(2230),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2230),
    [sym_preproc_directive] = ACTIONS(2230),
    [anon_sym_LPAREN2] = ACTIONS(2232),
    [anon_sym_TILDE] = ACTIONS(2232),
    [anon_sym_STAR] = ACTIONS(2232),
    [anon_sym_AMP_AMP] = ACTIONS(2232),
    [anon_sym_AMP] = ACTIONS(2230),
    [anon_sym_SEMI] = ACTIONS(2232),
    [anon_sym___extension__] = ACTIONS(2230),
    [anon_sym_typedef] = ACTIONS(2230),
    [anon_sym___device__] = ACTIONS(2230),
    [anon_sym___host__] = ACTIONS(2230),
    [anon_sym___global__] = ACTIONS(2230),
    [anon_sym___forceinline__] = ACTIONS(2230),
    [anon_sym___noinline__] = ACTIONS(2230),
    [anon_sym_virtual] = ACTIONS(2230),
    [anon_sym_extern] = ACTIONS(2230),
    [anon_sym___attribute__] = ACTIONS(2230),
    [anon_sym___attribute] = ACTIONS(2230),
    [anon_sym_COLON_COLON] = ACTIONS(2232),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2232),
    [anon_sym___declspec] = ACTIONS(2230),
    [anon_sym___based] = ACTIONS(2230),
    [anon_sym_signed] = ACTIONS(2230),
    [anon_sym_unsigned] = ACTIONS(2230),
    [anon_sym_long] = ACTIONS(2230),
    [anon_sym_short] = ACTIONS(2230),
    [anon_sym_LBRACK] = ACTIONS(2230),
    [anon_sym_static] = ACTIONS(2230),
    [anon_sym_register] = ACTIONS(2230),
    [anon_sym_inline] = ACTIONS(2230),
    [anon_sym___inline] = ACTIONS(2230),
    [anon_sym___inline__] = ACTIONS(2230),
    [anon_sym___forceinline] = ACTIONS(2230),
    [anon_sym_thread_local] = ACTIONS(2230),
    [anon_sym___thread] = ACTIONS(2230),
    [anon_sym_const] = ACTIONS(2230),
    [anon_sym_constexpr] = ACTIONS(2230),
    [anon_sym_volatile] = ACTIONS(2230),
    [anon_sym_restrict] = ACTIONS(2230),
    [anon_sym___restrict__] = ACTIONS(2230),
    [anon_sym__Atomic] = ACTIONS(2230),
    [anon_sym__Noreturn] = ACTIONS(2230),
    [anon_sym_noreturn] = ACTIONS(2230),
    [anon_sym__Nonnull] = ACTIONS(2230),
    [anon_sym_mutable] = ACTIONS(2230),
    [anon_sym_constinit] = ACTIONS(2230),
    [anon_sym_consteval] = ACTIONS(2230),
    [anon_sym___shared__] = ACTIONS(2230),
    [anon_sym___local__] = ACTIONS(2230),
    [anon_sym___constant__] = ACTIONS(2230),
    [anon_sym___managed__] = ACTIONS(2230),
    [anon_sym___grid_constant__] = ACTIONS(2230),
    [anon_sym_alignas] = ACTIONS(2230),
    [anon_sym__Alignas] = ACTIONS(2230),
    [sym_primitive_type] = ACTIONS(2230),
    [anon_sym_enum] = ACTIONS(2230),
    [anon_sym_class] = ACTIONS(2230),
    [anon_sym_struct] = ACTIONS(2230),
    [anon_sym_union] = ACTIONS(2230),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2230),
    [anon_sym_decltype] = ACTIONS(2230),
    [anon_sym_explicit] = ACTIONS(2230),
    [anon_sym_typename] = ACTIONS(2230),
    [anon_sym_template] = ACTIONS(2230),
    [anon_sym_operator] = ACTIONS(2230),
    [anon_sym_friend] = ACTIONS(2230),
    [anon_sym_public] = ACTIONS(2230),
    [anon_sym_private] = ACTIONS(2230),
    [anon_sym_protected] = ACTIONS(2230),
    [anon_sym_using] = ACTIONS(2230),
    [anon_sym_static_assert] = ACTIONS(2230),
    [anon_sym___launch_bounds__] = ACTIONS(2230),
  },
  [STATE(1832)] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token2] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [aux_sym_preproc_else_token1] = ACTIONS(2316),
    [aux_sym_preproc_elif_token1] = ACTIONS(2316),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym___device__] = ACTIONS(2316),
    [anon_sym___host__] = ACTIONS(2316),
    [anon_sym___global__] = ACTIONS(2316),
    [anon_sym___forceinline__] = ACTIONS(2316),
    [anon_sym___noinline__] = ACTIONS(2316),
    [anon_sym_virtual] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym___attribute] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym__Nonnull] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym___shared__] = ACTIONS(2316),
    [anon_sym___local__] = ACTIONS(2316),
    [anon_sym___constant__] = ACTIONS(2316),
    [anon_sym___managed__] = ACTIONS(2316),
    [anon_sym___grid_constant__] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_friend] = ACTIONS(2316),
    [anon_sym_public] = ACTIONS(2316),
    [anon_sym_private] = ACTIONS(2316),
    [anon_sym_protected] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym___launch_bounds__] = ACTIONS(2316),
  },
  [STATE(1833)] = {
    [sym_identifier] = ACTIONS(2431),
    [aux_sym_preproc_def_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token2] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2431),
    [aux_sym_preproc_else_token1] = ACTIONS(2431),
    [aux_sym_preproc_elif_token1] = ACTIONS(2431),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2431),
    [sym_preproc_directive] = ACTIONS(2431),
    [anon_sym_LPAREN2] = ACTIONS(2433),
    [anon_sym_TILDE] = ACTIONS(2433),
    [anon_sym_STAR] = ACTIONS(2433),
    [anon_sym_AMP_AMP] = ACTIONS(2433),
    [anon_sym_AMP] = ACTIONS(2431),
    [anon_sym_SEMI] = ACTIONS(2433),
    [anon_sym___extension__] = ACTIONS(2431),
    [anon_sym_typedef] = ACTIONS(2431),
    [anon_sym___device__] = ACTIONS(2431),
    [anon_sym___host__] = ACTIONS(2431),
    [anon_sym___global__] = ACTIONS(2431),
    [anon_sym___forceinline__] = ACTIONS(2431),
    [anon_sym___noinline__] = ACTIONS(2431),
    [anon_sym_virtual] = ACTIONS(2431),
    [anon_sym_extern] = ACTIONS(2431),
    [anon_sym___attribute__] = ACTIONS(2431),
    [anon_sym___attribute] = ACTIONS(2431),
    [anon_sym_COLON_COLON] = ACTIONS(2433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2433),
    [anon_sym___declspec] = ACTIONS(2431),
    [anon_sym___based] = ACTIONS(2431),
    [anon_sym_signed] = ACTIONS(2431),
    [anon_sym_unsigned] = ACTIONS(2431),
    [anon_sym_long] = ACTIONS(2431),
    [anon_sym_short] = ACTIONS(2431),
    [anon_sym_LBRACK] = ACTIONS(2431),
    [anon_sym_static] = ACTIONS(2431),
    [anon_sym_register] = ACTIONS(2431),
    [anon_sym_inline] = ACTIONS(2431),
    [anon_sym___inline] = ACTIONS(2431),
    [anon_sym___inline__] = ACTIONS(2431),
    [anon_sym___forceinline] = ACTIONS(2431),
    [anon_sym_thread_local] = ACTIONS(2431),
    [anon_sym___thread] = ACTIONS(2431),
    [anon_sym_const] = ACTIONS(2431),
    [anon_sym_constexpr] = ACTIONS(2431),
    [anon_sym_volatile] = ACTIONS(2431),
    [anon_sym_restrict] = ACTIONS(2431),
    [anon_sym___restrict__] = ACTIONS(2431),
    [anon_sym__Atomic] = ACTIONS(2431),
    [anon_sym__Noreturn] = ACTIONS(2431),
    [anon_sym_noreturn] = ACTIONS(2431),
    [anon_sym__Nonnull] = ACTIONS(2431),
    [anon_sym_mutable] = ACTIONS(2431),
    [anon_sym_constinit] = ACTIONS(2431),
    [anon_sym_consteval] = ACTIONS(2431),
    [anon_sym___shared__] = ACTIONS(2431),
    [anon_sym___local__] = ACTIONS(2431),
    [anon_sym___constant__] = ACTIONS(2431),
    [anon_sym___managed__] = ACTIONS(2431),
    [anon_sym___grid_constant__] = ACTIONS(2431),
    [anon_sym_alignas] = ACTIONS(2431),
    [anon_sym__Alignas] = ACTIONS(2431),
    [sym_primitive_type] = ACTIONS(2431),
    [anon_sym_enum] = ACTIONS(2431),
    [anon_sym_class] = ACTIONS(2431),
    [anon_sym_struct] = ACTIONS(2431),
    [anon_sym_union] = ACTIONS(2431),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2431),
    [anon_sym_decltype] = ACTIONS(2431),
    [anon_sym_explicit] = ACTIONS(2431),
    [anon_sym_typename] = ACTIONS(2431),
    [anon_sym_template] = ACTIONS(2431),
    [anon_sym_operator] = ACTIONS(2431),
    [anon_sym_friend] = ACTIONS(2431),
    [anon_sym_public] = ACTIONS(2431),
    [anon_sym_private] = ACTIONS(2431),
    [anon_sym_protected] = ACTIONS(2431),
    [anon_sym_using] = ACTIONS(2431),
    [anon_sym_static_assert] = ACTIONS(2431),
    [anon_sym___launch_bounds__] = ACTIONS(2431),
  },
  [STATE(1834)] = {
    [sym_identifier] = ACTIONS(2435),
    [aux_sym_preproc_def_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token2] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2435),
    [aux_sym_preproc_else_token1] = ACTIONS(2435),
    [aux_sym_preproc_elif_token1] = ACTIONS(2435),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2435),
    [sym_preproc_directive] = ACTIONS(2435),
    [anon_sym_LPAREN2] = ACTIONS(2437),
    [anon_sym_TILDE] = ACTIONS(2437),
    [anon_sym_STAR] = ACTIONS(2437),
    [anon_sym_AMP_AMP] = ACTIONS(2437),
    [anon_sym_AMP] = ACTIONS(2435),
    [anon_sym_SEMI] = ACTIONS(2437),
    [anon_sym___extension__] = ACTIONS(2435),
    [anon_sym_typedef] = ACTIONS(2435),
    [anon_sym___device__] = ACTIONS(2435),
    [anon_sym___host__] = ACTIONS(2435),
    [anon_sym___global__] = ACTIONS(2435),
    [anon_sym___forceinline__] = ACTIONS(2435),
    [anon_sym___noinline__] = ACTIONS(2435),
    [anon_sym_virtual] = ACTIONS(2435),
    [anon_sym_extern] = ACTIONS(2435),
    [anon_sym___attribute__] = ACTIONS(2435),
    [anon_sym___attribute] = ACTIONS(2435),
    [anon_sym_COLON_COLON] = ACTIONS(2437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2437),
    [anon_sym___declspec] = ACTIONS(2435),
    [anon_sym___based] = ACTIONS(2435),
    [anon_sym_signed] = ACTIONS(2435),
    [anon_sym_unsigned] = ACTIONS(2435),
    [anon_sym_long] = ACTIONS(2435),
    [anon_sym_short] = ACTIONS(2435),
    [anon_sym_LBRACK] = ACTIONS(2435),
    [anon_sym_static] = ACTIONS(2435),
    [anon_sym_register] = ACTIONS(2435),
    [anon_sym_inline] = ACTIONS(2435),
    [anon_sym___inline] = ACTIONS(2435),
    [anon_sym___inline__] = ACTIONS(2435),
    [anon_sym___forceinline] = ACTIONS(2435),
    [anon_sym_thread_local] = ACTIONS(2435),
    [anon_sym___thread] = ACTIONS(2435),
    [anon_sym_const] = ACTIONS(2435),
    [anon_sym_constexpr] = ACTIONS(2435),
    [anon_sym_volatile] = ACTIONS(2435),
    [anon_sym_restrict] = ACTIONS(2435),
    [anon_sym___restrict__] = ACTIONS(2435),
    [anon_sym__Atomic] = ACTIONS(2435),
    [anon_sym__Noreturn] = ACTIONS(2435),
    [anon_sym_noreturn] = ACTIONS(2435),
    [anon_sym__Nonnull] = ACTIONS(2435),
    [anon_sym_mutable] = ACTIONS(2435),
    [anon_sym_constinit] = ACTIONS(2435),
    [anon_sym_consteval] = ACTIONS(2435),
    [anon_sym___shared__] = ACTIONS(2435),
    [anon_sym___local__] = ACTIONS(2435),
    [anon_sym___constant__] = ACTIONS(2435),
    [anon_sym___managed__] = ACTIONS(2435),
    [anon_sym___grid_constant__] = ACTIONS(2435),
    [anon_sym_alignas] = ACTIONS(2435),
    [anon_sym__Alignas] = ACTIONS(2435),
    [sym_primitive_type] = ACTIONS(2435),
    [anon_sym_enum] = ACTIONS(2435),
    [anon_sym_class] = ACTIONS(2435),
    [anon_sym_struct] = ACTIONS(2435),
    [anon_sym_union] = ACTIONS(2435),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2435),
    [anon_sym_decltype] = ACTIONS(2435),
    [anon_sym_explicit] = ACTIONS(2435),
    [anon_sym_typename] = ACTIONS(2435),
    [anon_sym_template] = ACTIONS(2435),
    [anon_sym_operator] = ACTIONS(2435),
    [anon_sym_friend] = ACTIONS(2435),
    [anon_sym_public] = ACTIONS(2435),
    [anon_sym_private] = ACTIONS(2435),
    [anon_sym_protected] = ACTIONS(2435),
    [anon_sym_using] = ACTIONS(2435),
    [anon_sym_static_assert] = ACTIONS(2435),
    [anon_sym___launch_bounds__] = ACTIONS(2435),
  },
  [STATE(1835)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_RPAREN] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4350),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4350),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4350),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4352),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4350),
    [anon_sym___extension__] = ACTIONS(4352),
    [anon_sym___global__] = ACTIONS(4352),
    [anon_sym___attribute__] = ACTIONS(4352),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4352),
    [anon_sym_EQ] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4352),
    [anon_sym_volatile] = ACTIONS(4352),
    [anon_sym_restrict] = ACTIONS(4352),
    [anon_sym___restrict__] = ACTIONS(4352),
    [anon_sym__Atomic] = ACTIONS(4352),
    [anon_sym__Noreturn] = ACTIONS(4352),
    [anon_sym_noreturn] = ACTIONS(4352),
    [anon_sym__Nonnull] = ACTIONS(4352),
    [anon_sym_mutable] = ACTIONS(4352),
    [anon_sym_constinit] = ACTIONS(4352),
    [anon_sym_consteval] = ACTIONS(4352),
    [anon_sym___shared__] = ACTIONS(4352),
    [anon_sym___local__] = ACTIONS(4352),
    [anon_sym___constant__] = ACTIONS(4352),
    [anon_sym___managed__] = ACTIONS(4352),
    [anon_sym___grid_constant__] = ACTIONS(4352),
    [anon_sym_alignas] = ACTIONS(4352),
    [anon_sym__Alignas] = ACTIONS(4352),
    [anon_sym_COLON] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_STAR_EQ] = ACTIONS(4352),
    [anon_sym_SLASH_EQ] = ACTIONS(4352),
    [anon_sym_PERCENT_EQ] = ACTIONS(4352),
    [anon_sym_PLUS_EQ] = ACTIONS(4352),
    [anon_sym_DASH_EQ] = ACTIONS(4352),
    [anon_sym_LT_LT_EQ] = ACTIONS(4352),
    [anon_sym_GT_GT_EQ] = ACTIONS(4352),
    [anon_sym_AMP_EQ] = ACTIONS(4352),
    [anon_sym_CARET_EQ] = ACTIONS(4352),
    [anon_sym_PIPE_EQ] = ACTIONS(4352),
    [anon_sym_and_eq] = ACTIONS(4352),
    [anon_sym_or_eq] = ACTIONS(4352),
    [anon_sym_xor_eq] = ACTIONS(4352),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_bitor] = ACTIONS(4352),
    [anon_sym_xor] = ACTIONS(4350),
    [anon_sym_bitand] = ACTIONS(4352),
    [anon_sym_not_eq] = ACTIONS(4352),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4350),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4352),
    [anon_sym_decltype] = ACTIONS(4352),
    [anon_sym_final] = ACTIONS(4352),
    [anon_sym_override] = ACTIONS(4352),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
  },
  [STATE(1836)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_RPAREN] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4356),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4356),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4356),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4358),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4356),
    [anon_sym___extension__] = ACTIONS(4358),
    [anon_sym___global__] = ACTIONS(4358),
    [anon_sym___attribute__] = ACTIONS(4358),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4358),
    [anon_sym_EQ] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4358),
    [anon_sym_volatile] = ACTIONS(4358),
    [anon_sym_restrict] = ACTIONS(4358),
    [anon_sym___restrict__] = ACTIONS(4358),
    [anon_sym__Atomic] = ACTIONS(4358),
    [anon_sym__Noreturn] = ACTIONS(4358),
    [anon_sym_noreturn] = ACTIONS(4358),
    [anon_sym__Nonnull] = ACTIONS(4358),
    [anon_sym_mutable] = ACTIONS(4358),
    [anon_sym_constinit] = ACTIONS(4358),
    [anon_sym_consteval] = ACTIONS(4358),
    [anon_sym___shared__] = ACTIONS(4358),
    [anon_sym___local__] = ACTIONS(4358),
    [anon_sym___constant__] = ACTIONS(4358),
    [anon_sym___managed__] = ACTIONS(4358),
    [anon_sym___grid_constant__] = ACTIONS(4358),
    [anon_sym_alignas] = ACTIONS(4358),
    [anon_sym__Alignas] = ACTIONS(4358),
    [anon_sym_COLON] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_STAR_EQ] = ACTIONS(4358),
    [anon_sym_SLASH_EQ] = ACTIONS(4358),
    [anon_sym_PERCENT_EQ] = ACTIONS(4358),
    [anon_sym_PLUS_EQ] = ACTIONS(4358),
    [anon_sym_DASH_EQ] = ACTIONS(4358),
    [anon_sym_LT_LT_EQ] = ACTIONS(4358),
    [anon_sym_GT_GT_EQ] = ACTIONS(4358),
    [anon_sym_AMP_EQ] = ACTIONS(4358),
    [anon_sym_CARET_EQ] = ACTIONS(4358),
    [anon_sym_PIPE_EQ] = ACTIONS(4358),
    [anon_sym_and_eq] = ACTIONS(4358),
    [anon_sym_or_eq] = ACTIONS(4358),
    [anon_sym_xor_eq] = ACTIONS(4358),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_bitor] = ACTIONS(4358),
    [anon_sym_xor] = ACTIONS(4356),
    [anon_sym_bitand] = ACTIONS(4358),
    [anon_sym_not_eq] = ACTIONS(4358),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4358),
    [anon_sym_decltype] = ACTIONS(4358),
    [anon_sym_final] = ACTIONS(4358),
    [anon_sym_override] = ACTIONS(4358),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4358),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
  },
  [STATE(1837)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_RPAREN] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4366),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4366),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4366),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4368),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4366),
    [anon_sym___extension__] = ACTIONS(4368),
    [anon_sym___global__] = ACTIONS(4368),
    [anon_sym___attribute__] = ACTIONS(4368),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4368),
    [anon_sym_EQ] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4368),
    [anon_sym_volatile] = ACTIONS(4368),
    [anon_sym_restrict] = ACTIONS(4368),
    [anon_sym___restrict__] = ACTIONS(4368),
    [anon_sym__Atomic] = ACTIONS(4368),
    [anon_sym__Noreturn] = ACTIONS(4368),
    [anon_sym_noreturn] = ACTIONS(4368),
    [anon_sym__Nonnull] = ACTIONS(4368),
    [anon_sym_mutable] = ACTIONS(4368),
    [anon_sym_constinit] = ACTIONS(4368),
    [anon_sym_consteval] = ACTIONS(4368),
    [anon_sym___shared__] = ACTIONS(4368),
    [anon_sym___local__] = ACTIONS(4368),
    [anon_sym___constant__] = ACTIONS(4368),
    [anon_sym___managed__] = ACTIONS(4368),
    [anon_sym___grid_constant__] = ACTIONS(4368),
    [anon_sym_alignas] = ACTIONS(4368),
    [anon_sym__Alignas] = ACTIONS(4368),
    [anon_sym_COLON] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_STAR_EQ] = ACTIONS(4368),
    [anon_sym_SLASH_EQ] = ACTIONS(4368),
    [anon_sym_PERCENT_EQ] = ACTIONS(4368),
    [anon_sym_PLUS_EQ] = ACTIONS(4368),
    [anon_sym_DASH_EQ] = ACTIONS(4368),
    [anon_sym_LT_LT_EQ] = ACTIONS(4368),
    [anon_sym_GT_GT_EQ] = ACTIONS(4368),
    [anon_sym_AMP_EQ] = ACTIONS(4368),
    [anon_sym_CARET_EQ] = ACTIONS(4368),
    [anon_sym_PIPE_EQ] = ACTIONS(4368),
    [anon_sym_and_eq] = ACTIONS(4368),
    [anon_sym_or_eq] = ACTIONS(4368),
    [anon_sym_xor_eq] = ACTIONS(4368),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_bitor] = ACTIONS(4368),
    [anon_sym_xor] = ACTIONS(4366),
    [anon_sym_bitand] = ACTIONS(4368),
    [anon_sym_not_eq] = ACTIONS(4368),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4366),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4368),
    [anon_sym_decltype] = ACTIONS(4368),
    [anon_sym_final] = ACTIONS(4368),
    [anon_sym_override] = ACTIONS(4368),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4368),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
  },
  [STATE(1838)] = {
    [sym_identifier] = ACTIONS(2605),
    [aux_sym_preproc_def_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token2] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2605),
    [aux_sym_preproc_else_token1] = ACTIONS(2605),
    [aux_sym_preproc_elif_token1] = ACTIONS(2605),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2605),
    [sym_preproc_directive] = ACTIONS(2605),
    [anon_sym_LPAREN2] = ACTIONS(2607),
    [anon_sym_TILDE] = ACTIONS(2607),
    [anon_sym_STAR] = ACTIONS(2607),
    [anon_sym_AMP_AMP] = ACTIONS(2607),
    [anon_sym_AMP] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2605),
    [anon_sym_typedef] = ACTIONS(2605),
    [anon_sym___device__] = ACTIONS(2605),
    [anon_sym___host__] = ACTIONS(2605),
    [anon_sym___global__] = ACTIONS(2605),
    [anon_sym___forceinline__] = ACTIONS(2605),
    [anon_sym___noinline__] = ACTIONS(2605),
    [anon_sym_virtual] = ACTIONS(2605),
    [anon_sym_extern] = ACTIONS(2605),
    [anon_sym___attribute__] = ACTIONS(2605),
    [anon_sym___attribute] = ACTIONS(2605),
    [anon_sym_COLON_COLON] = ACTIONS(2607),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2607),
    [anon_sym___declspec] = ACTIONS(2605),
    [anon_sym___based] = ACTIONS(2605),
    [anon_sym_signed] = ACTIONS(2605),
    [anon_sym_unsigned] = ACTIONS(2605),
    [anon_sym_long] = ACTIONS(2605),
    [anon_sym_short] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2605),
    [anon_sym_static] = ACTIONS(2605),
    [anon_sym_register] = ACTIONS(2605),
    [anon_sym_inline] = ACTIONS(2605),
    [anon_sym___inline] = ACTIONS(2605),
    [anon_sym___inline__] = ACTIONS(2605),
    [anon_sym___forceinline] = ACTIONS(2605),
    [anon_sym_thread_local] = ACTIONS(2605),
    [anon_sym___thread] = ACTIONS(2605),
    [anon_sym_const] = ACTIONS(2605),
    [anon_sym_constexpr] = ACTIONS(2605),
    [anon_sym_volatile] = ACTIONS(2605),
    [anon_sym_restrict] = ACTIONS(2605),
    [anon_sym___restrict__] = ACTIONS(2605),
    [anon_sym__Atomic] = ACTIONS(2605),
    [anon_sym__Noreturn] = ACTIONS(2605),
    [anon_sym_noreturn] = ACTIONS(2605),
    [anon_sym__Nonnull] = ACTIONS(2605),
    [anon_sym_mutable] = ACTIONS(2605),
    [anon_sym_constinit] = ACTIONS(2605),
    [anon_sym_consteval] = ACTIONS(2605),
    [anon_sym___shared__] = ACTIONS(2605),
    [anon_sym___local__] = ACTIONS(2605),
    [anon_sym___constant__] = ACTIONS(2605),
    [anon_sym___managed__] = ACTIONS(2605),
    [anon_sym___grid_constant__] = ACTIONS(2605),
    [anon_sym_alignas] = ACTIONS(2605),
    [anon_sym__Alignas] = ACTIONS(2605),
    [sym_primitive_type] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_class] = ACTIONS(2605),
    [anon_sym_struct] = ACTIONS(2605),
    [anon_sym_union] = ACTIONS(2605),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2605),
    [anon_sym_decltype] = ACTIONS(2605),
    [anon_sym_explicit] = ACTIONS(2605),
    [anon_sym_typename] = ACTIONS(2605),
    [anon_sym_template] = ACTIONS(2605),
    [anon_sym_operator] = ACTIONS(2605),
    [anon_sym_friend] = ACTIONS(2605),
    [anon_sym_public] = ACTIONS(2605),
    [anon_sym_private] = ACTIONS(2605),
    [anon_sym_protected] = ACTIONS(2605),
    [anon_sym_using] = ACTIONS(2605),
    [anon_sym_static_assert] = ACTIONS(2605),
    [anon_sym___launch_bounds__] = ACTIONS(2605),
  },
  [STATE(1839)] = {
    [sym_identifier] = ACTIONS(2613),
    [aux_sym_preproc_def_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token2] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2613),
    [aux_sym_preproc_else_token1] = ACTIONS(2613),
    [aux_sym_preproc_elif_token1] = ACTIONS(2613),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2613),
    [sym_preproc_directive] = ACTIONS(2613),
    [anon_sym_LPAREN2] = ACTIONS(2615),
    [anon_sym_TILDE] = ACTIONS(2615),
    [anon_sym_STAR] = ACTIONS(2615),
    [anon_sym_AMP_AMP] = ACTIONS(2615),
    [anon_sym_AMP] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym___extension__] = ACTIONS(2613),
    [anon_sym_typedef] = ACTIONS(2613),
    [anon_sym___device__] = ACTIONS(2613),
    [anon_sym___host__] = ACTIONS(2613),
    [anon_sym___global__] = ACTIONS(2613),
    [anon_sym___forceinline__] = ACTIONS(2613),
    [anon_sym___noinline__] = ACTIONS(2613),
    [anon_sym_virtual] = ACTIONS(2613),
    [anon_sym_extern] = ACTIONS(2613),
    [anon_sym___attribute__] = ACTIONS(2613),
    [anon_sym___attribute] = ACTIONS(2613),
    [anon_sym_COLON_COLON] = ACTIONS(2615),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2615),
    [anon_sym___declspec] = ACTIONS(2613),
    [anon_sym___based] = ACTIONS(2613),
    [anon_sym_signed] = ACTIONS(2613),
    [anon_sym_unsigned] = ACTIONS(2613),
    [anon_sym_long] = ACTIONS(2613),
    [anon_sym_short] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2613),
    [anon_sym_static] = ACTIONS(2613),
    [anon_sym_register] = ACTIONS(2613),
    [anon_sym_inline] = ACTIONS(2613),
    [anon_sym___inline] = ACTIONS(2613),
    [anon_sym___inline__] = ACTIONS(2613),
    [anon_sym___forceinline] = ACTIONS(2613),
    [anon_sym_thread_local] = ACTIONS(2613),
    [anon_sym___thread] = ACTIONS(2613),
    [anon_sym_const] = ACTIONS(2613),
    [anon_sym_constexpr] = ACTIONS(2613),
    [anon_sym_volatile] = ACTIONS(2613),
    [anon_sym_restrict] = ACTIONS(2613),
    [anon_sym___restrict__] = ACTIONS(2613),
    [anon_sym__Atomic] = ACTIONS(2613),
    [anon_sym__Noreturn] = ACTIONS(2613),
    [anon_sym_noreturn] = ACTIONS(2613),
    [anon_sym__Nonnull] = ACTIONS(2613),
    [anon_sym_mutable] = ACTIONS(2613),
    [anon_sym_constinit] = ACTIONS(2613),
    [anon_sym_consteval] = ACTIONS(2613),
    [anon_sym___shared__] = ACTIONS(2613),
    [anon_sym___local__] = ACTIONS(2613),
    [anon_sym___constant__] = ACTIONS(2613),
    [anon_sym___managed__] = ACTIONS(2613),
    [anon_sym___grid_constant__] = ACTIONS(2613),
    [anon_sym_alignas] = ACTIONS(2613),
    [anon_sym__Alignas] = ACTIONS(2613),
    [sym_primitive_type] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_class] = ACTIONS(2613),
    [anon_sym_struct] = ACTIONS(2613),
    [anon_sym_union] = ACTIONS(2613),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2613),
    [anon_sym_decltype] = ACTIONS(2613),
    [anon_sym_explicit] = ACTIONS(2613),
    [anon_sym_typename] = ACTIONS(2613),
    [anon_sym_template] = ACTIONS(2613),
    [anon_sym_operator] = ACTIONS(2613),
    [anon_sym_friend] = ACTIONS(2613),
    [anon_sym_public] = ACTIONS(2613),
    [anon_sym_private] = ACTIONS(2613),
    [anon_sym_protected] = ACTIONS(2613),
    [anon_sym_using] = ACTIONS(2613),
    [anon_sym_static_assert] = ACTIONS(2613),
    [anon_sym___launch_bounds__] = ACTIONS(2613),
  },
  [STATE(1840)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token2] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [aux_sym_preproc_else_token1] = ACTIONS(2234),
    [aux_sym_preproc_elif_token1] = ACTIONS(2234),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_friend] = ACTIONS(2234),
    [anon_sym_public] = ACTIONS(2234),
    [anon_sym_private] = ACTIONS(2234),
    [anon_sym_protected] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(1841)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token2] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [aux_sym_preproc_else_token1] = ACTIONS(2234),
    [aux_sym_preproc_elif_token1] = ACTIONS(2234),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_friend] = ACTIONS(2234),
    [anon_sym_public] = ACTIONS(2234),
    [anon_sym_private] = ACTIONS(2234),
    [anon_sym_protected] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(1842)] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token2] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [aux_sym_preproc_else_token1] = ACTIONS(2320),
    [aux_sym_preproc_elif_token1] = ACTIONS(2320),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym___device__] = ACTIONS(2320),
    [anon_sym___host__] = ACTIONS(2320),
    [anon_sym___global__] = ACTIONS(2320),
    [anon_sym___forceinline__] = ACTIONS(2320),
    [anon_sym___noinline__] = ACTIONS(2320),
    [anon_sym_virtual] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym___attribute] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym__Nonnull] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym___shared__] = ACTIONS(2320),
    [anon_sym___local__] = ACTIONS(2320),
    [anon_sym___constant__] = ACTIONS(2320),
    [anon_sym___managed__] = ACTIONS(2320),
    [anon_sym___grid_constant__] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_friend] = ACTIONS(2320),
    [anon_sym_public] = ACTIONS(2320),
    [anon_sym_private] = ACTIONS(2320),
    [anon_sym_protected] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym___launch_bounds__] = ACTIONS(2320),
  },
  [STATE(1843)] = {
    [sym_identifier] = ACTIONS(2415),
    [aux_sym_preproc_def_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token2] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2415),
    [aux_sym_preproc_else_token1] = ACTIONS(2415),
    [aux_sym_preproc_elif_token1] = ACTIONS(2415),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2415),
    [sym_preproc_directive] = ACTIONS(2415),
    [anon_sym_LPAREN2] = ACTIONS(2417),
    [anon_sym_TILDE] = ACTIONS(2417),
    [anon_sym_STAR] = ACTIONS(2417),
    [anon_sym_AMP_AMP] = ACTIONS(2417),
    [anon_sym_AMP] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(2417),
    [anon_sym___extension__] = ACTIONS(2415),
    [anon_sym_typedef] = ACTIONS(2415),
    [anon_sym___device__] = ACTIONS(2415),
    [anon_sym___host__] = ACTIONS(2415),
    [anon_sym___global__] = ACTIONS(2415),
    [anon_sym___forceinline__] = ACTIONS(2415),
    [anon_sym___noinline__] = ACTIONS(2415),
    [anon_sym_virtual] = ACTIONS(2415),
    [anon_sym_extern] = ACTIONS(2415),
    [anon_sym___attribute__] = ACTIONS(2415),
    [anon_sym___attribute] = ACTIONS(2415),
    [anon_sym_COLON_COLON] = ACTIONS(2417),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2417),
    [anon_sym___declspec] = ACTIONS(2415),
    [anon_sym___based] = ACTIONS(2415),
    [anon_sym_signed] = ACTIONS(2415),
    [anon_sym_unsigned] = ACTIONS(2415),
    [anon_sym_long] = ACTIONS(2415),
    [anon_sym_short] = ACTIONS(2415),
    [anon_sym_LBRACK] = ACTIONS(2415),
    [anon_sym_static] = ACTIONS(2415),
    [anon_sym_register] = ACTIONS(2415),
    [anon_sym_inline] = ACTIONS(2415),
    [anon_sym___inline] = ACTIONS(2415),
    [anon_sym___inline__] = ACTIONS(2415),
    [anon_sym___forceinline] = ACTIONS(2415),
    [anon_sym_thread_local] = ACTIONS(2415),
    [anon_sym___thread] = ACTIONS(2415),
    [anon_sym_const] = ACTIONS(2415),
    [anon_sym_constexpr] = ACTIONS(2415),
    [anon_sym_volatile] = ACTIONS(2415),
    [anon_sym_restrict] = ACTIONS(2415),
    [anon_sym___restrict__] = ACTIONS(2415),
    [anon_sym__Atomic] = ACTIONS(2415),
    [anon_sym__Noreturn] = ACTIONS(2415),
    [anon_sym_noreturn] = ACTIONS(2415),
    [anon_sym__Nonnull] = ACTIONS(2415),
    [anon_sym_mutable] = ACTIONS(2415),
    [anon_sym_constinit] = ACTIONS(2415),
    [anon_sym_consteval] = ACTIONS(2415),
    [anon_sym___shared__] = ACTIONS(2415),
    [anon_sym___local__] = ACTIONS(2415),
    [anon_sym___constant__] = ACTIONS(2415),
    [anon_sym___managed__] = ACTIONS(2415),
    [anon_sym___grid_constant__] = ACTIONS(2415),
    [anon_sym_alignas] = ACTIONS(2415),
    [anon_sym__Alignas] = ACTIONS(2415),
    [sym_primitive_type] = ACTIONS(2415),
    [anon_sym_enum] = ACTIONS(2415),
    [anon_sym_class] = ACTIONS(2415),
    [anon_sym_struct] = ACTIONS(2415),
    [anon_sym_union] = ACTIONS(2415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2415),
    [anon_sym_decltype] = ACTIONS(2415),
    [anon_sym_explicit] = ACTIONS(2415),
    [anon_sym_typename] = ACTIONS(2415),
    [anon_sym_template] = ACTIONS(2415),
    [anon_sym_operator] = ACTIONS(2415),
    [anon_sym_friend] = ACTIONS(2415),
    [anon_sym_public] = ACTIONS(2415),
    [anon_sym_private] = ACTIONS(2415),
    [anon_sym_protected] = ACTIONS(2415),
    [anon_sym_using] = ACTIONS(2415),
    [anon_sym_static_assert] = ACTIONS(2415),
    [anon_sym___launch_bounds__] = ACTIONS(2415),
  },
  [STATE(1844)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1846),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_RPAREN] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5351),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5351),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5351),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5351),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5597),
    [anon_sym_unsigned] = ACTIONS(5597),
    [anon_sym_long] = ACTIONS(5597),
    [anon_sym_short] = ACTIONS(5597),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_EQ] = ACTIONS(5351),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_STAR_EQ] = ACTIONS(5354),
    [anon_sym_SLASH_EQ] = ACTIONS(5354),
    [anon_sym_PERCENT_EQ] = ACTIONS(5354),
    [anon_sym_PLUS_EQ] = ACTIONS(5354),
    [anon_sym_DASH_EQ] = ACTIONS(5354),
    [anon_sym_LT_LT_EQ] = ACTIONS(5354),
    [anon_sym_GT_GT_EQ] = ACTIONS(5354),
    [anon_sym_AMP_EQ] = ACTIONS(5354),
    [anon_sym_CARET_EQ] = ACTIONS(5354),
    [anon_sym_PIPE_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5354),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
  },
  [STATE(1845)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [aux_sym_preproc_if_token2] = ACTIONS(5135),
    [aux_sym_preproc_else_token1] = ACTIONS(5135),
    [aux_sym_preproc_elif_token1] = ACTIONS(5133),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5135),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5135),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5135),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5135),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5135),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_RBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_long] = ACTIONS(5600),
    [anon_sym_short] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_RBRACK] = ACTIONS(5135),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_COLON] = ACTIONS(5135),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_final] = ACTIONS(5133),
    [anon_sym_override] = ACTIONS(5133),
    [anon_sym_requires] = ACTIONS(5133),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
  },
  [STATE(1846)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1846),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(5597),
    [anon_sym_unsigned] = ACTIONS(5597),
    [anon_sym_long] = ACTIONS(5597),
    [anon_sym_short] = ACTIONS(5597),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5135),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5135),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
  },
  [STATE(1847)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [aux_sym_preproc_else_token1] = ACTIONS(2178),
    [aux_sym_preproc_elif_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_friend] = ACTIONS(2178),
    [anon_sym_public] = ACTIONS(2178),
    [anon_sym_private] = ACTIONS(2178),
    [anon_sym_protected] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(1848)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [aux_sym_preproc_else_token1] = ACTIONS(2178),
    [aux_sym_preproc_elif_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_friend] = ACTIONS(2178),
    [anon_sym_public] = ACTIONS(2178),
    [anon_sym_private] = ACTIONS(2178),
    [anon_sym_protected] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(1849)] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token2] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [aux_sym_preproc_else_token1] = ACTIONS(2190),
    [aux_sym_preproc_elif_token1] = ACTIONS(2190),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym___device__] = ACTIONS(2190),
    [anon_sym___host__] = ACTIONS(2190),
    [anon_sym___global__] = ACTIONS(2190),
    [anon_sym___forceinline__] = ACTIONS(2190),
    [anon_sym___noinline__] = ACTIONS(2190),
    [anon_sym_virtual] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym___attribute] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym__Nonnull] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym___shared__] = ACTIONS(2190),
    [anon_sym___local__] = ACTIONS(2190),
    [anon_sym___constant__] = ACTIONS(2190),
    [anon_sym___managed__] = ACTIONS(2190),
    [anon_sym___grid_constant__] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_friend] = ACTIONS(2190),
    [anon_sym_public] = ACTIONS(2190),
    [anon_sym_private] = ACTIONS(2190),
    [anon_sym_protected] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym___launch_bounds__] = ACTIONS(2190),
  },
  [STATE(1850)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [aux_sym_preproc_else_token1] = ACTIONS(2182),
    [aux_sym_preproc_elif_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_friend] = ACTIONS(2182),
    [anon_sym_public] = ACTIONS(2182),
    [anon_sym_private] = ACTIONS(2182),
    [anon_sym_protected] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(1851)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [aux_sym_preproc_else_token1] = ACTIONS(2182),
    [aux_sym_preproc_elif_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_friend] = ACTIONS(2182),
    [anon_sym_public] = ACTIONS(2182),
    [anon_sym_private] = ACTIONS(2182),
    [anon_sym_protected] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(1852)] = {
    [sym_identifier] = ACTIONS(5603),
    [aux_sym_preproc_def_token1] = ACTIONS(5603),
    [aux_sym_preproc_if_token1] = ACTIONS(5603),
    [aux_sym_preproc_if_token2] = ACTIONS(5603),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5603),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5603),
    [aux_sym_preproc_else_token1] = ACTIONS(5603),
    [aux_sym_preproc_elif_token1] = ACTIONS(5603),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5603),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5603),
    [sym_preproc_directive] = ACTIONS(5603),
    [anon_sym_LPAREN2] = ACTIONS(5605),
    [anon_sym_TILDE] = ACTIONS(5605),
    [anon_sym_STAR] = ACTIONS(5605),
    [anon_sym_AMP_AMP] = ACTIONS(5605),
    [anon_sym_AMP] = ACTIONS(5603),
    [anon_sym_SEMI] = ACTIONS(5605),
    [anon_sym___extension__] = ACTIONS(5603),
    [anon_sym_typedef] = ACTIONS(5603),
    [anon_sym___device__] = ACTIONS(5603),
    [anon_sym___host__] = ACTIONS(5603),
    [anon_sym___global__] = ACTIONS(5603),
    [anon_sym___forceinline__] = ACTIONS(5603),
    [anon_sym___noinline__] = ACTIONS(5603),
    [anon_sym_virtual] = ACTIONS(5603),
    [anon_sym_extern] = ACTIONS(5603),
    [anon_sym___attribute__] = ACTIONS(5603),
    [anon_sym___attribute] = ACTIONS(5603),
    [anon_sym_COLON_COLON] = ACTIONS(5605),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5605),
    [anon_sym___declspec] = ACTIONS(5603),
    [anon_sym___based] = ACTIONS(5603),
    [anon_sym_signed] = ACTIONS(5603),
    [anon_sym_unsigned] = ACTIONS(5603),
    [anon_sym_long] = ACTIONS(5603),
    [anon_sym_short] = ACTIONS(5603),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [anon_sym_static] = ACTIONS(5603),
    [anon_sym_register] = ACTIONS(5603),
    [anon_sym_inline] = ACTIONS(5603),
    [anon_sym___inline] = ACTIONS(5603),
    [anon_sym___inline__] = ACTIONS(5603),
    [anon_sym___forceinline] = ACTIONS(5603),
    [anon_sym_thread_local] = ACTIONS(5603),
    [anon_sym___thread] = ACTIONS(5603),
    [anon_sym_const] = ACTIONS(5603),
    [anon_sym_constexpr] = ACTIONS(5603),
    [anon_sym_volatile] = ACTIONS(5603),
    [anon_sym_restrict] = ACTIONS(5603),
    [anon_sym___restrict__] = ACTIONS(5603),
    [anon_sym__Atomic] = ACTIONS(5603),
    [anon_sym__Noreturn] = ACTIONS(5603),
    [anon_sym_noreturn] = ACTIONS(5603),
    [anon_sym__Nonnull] = ACTIONS(5603),
    [anon_sym_mutable] = ACTIONS(5603),
    [anon_sym_constinit] = ACTIONS(5603),
    [anon_sym_consteval] = ACTIONS(5603),
    [anon_sym___shared__] = ACTIONS(5603),
    [anon_sym___local__] = ACTIONS(5603),
    [anon_sym___constant__] = ACTIONS(5603),
    [anon_sym___managed__] = ACTIONS(5603),
    [anon_sym___grid_constant__] = ACTIONS(5603),
    [anon_sym_alignas] = ACTIONS(5603),
    [anon_sym__Alignas] = ACTIONS(5603),
    [sym_primitive_type] = ACTIONS(5603),
    [anon_sym_enum] = ACTIONS(5603),
    [anon_sym_class] = ACTIONS(5603),
    [anon_sym_struct] = ACTIONS(5603),
    [anon_sym_union] = ACTIONS(5603),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5603),
    [anon_sym_decltype] = ACTIONS(5603),
    [anon_sym_explicit] = ACTIONS(5603),
    [anon_sym_typename] = ACTIONS(5603),
    [anon_sym_template] = ACTIONS(5603),
    [anon_sym_operator] = ACTIONS(5603),
    [anon_sym_friend] = ACTIONS(5603),
    [anon_sym_public] = ACTIONS(5603),
    [anon_sym_private] = ACTIONS(5603),
    [anon_sym_protected] = ACTIONS(5603),
    [anon_sym_using] = ACTIONS(5603),
    [anon_sym_static_assert] = ACTIONS(5603),
    [anon_sym___launch_bounds__] = ACTIONS(5603),
  },
  [STATE(1853)] = {
    [sym_identifier] = ACTIONS(5607),
    [aux_sym_preproc_def_token1] = ACTIONS(5607),
    [aux_sym_preproc_if_token1] = ACTIONS(5607),
    [aux_sym_preproc_if_token2] = ACTIONS(5607),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5607),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5607),
    [aux_sym_preproc_else_token1] = ACTIONS(5607),
    [aux_sym_preproc_elif_token1] = ACTIONS(5607),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5607),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5607),
    [sym_preproc_directive] = ACTIONS(5607),
    [anon_sym_LPAREN2] = ACTIONS(5609),
    [anon_sym_TILDE] = ACTIONS(5609),
    [anon_sym_STAR] = ACTIONS(5609),
    [anon_sym_AMP_AMP] = ACTIONS(5609),
    [anon_sym_AMP] = ACTIONS(5607),
    [anon_sym_SEMI] = ACTIONS(5609),
    [anon_sym___extension__] = ACTIONS(5607),
    [anon_sym_typedef] = ACTIONS(5607),
    [anon_sym___device__] = ACTIONS(5607),
    [anon_sym___host__] = ACTIONS(5607),
    [anon_sym___global__] = ACTIONS(5607),
    [anon_sym___forceinline__] = ACTIONS(5607),
    [anon_sym___noinline__] = ACTIONS(5607),
    [anon_sym_virtual] = ACTIONS(5607),
    [anon_sym_extern] = ACTIONS(5607),
    [anon_sym___attribute__] = ACTIONS(5607),
    [anon_sym___attribute] = ACTIONS(5607),
    [anon_sym_COLON_COLON] = ACTIONS(5609),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5609),
    [anon_sym___declspec] = ACTIONS(5607),
    [anon_sym___based] = ACTIONS(5607),
    [anon_sym_signed] = ACTIONS(5607),
    [anon_sym_unsigned] = ACTIONS(5607),
    [anon_sym_long] = ACTIONS(5607),
    [anon_sym_short] = ACTIONS(5607),
    [anon_sym_LBRACK] = ACTIONS(5607),
    [anon_sym_static] = ACTIONS(5607),
    [anon_sym_register] = ACTIONS(5607),
    [anon_sym_inline] = ACTIONS(5607),
    [anon_sym___inline] = ACTIONS(5607),
    [anon_sym___inline__] = ACTIONS(5607),
    [anon_sym___forceinline] = ACTIONS(5607),
    [anon_sym_thread_local] = ACTIONS(5607),
    [anon_sym___thread] = ACTIONS(5607),
    [anon_sym_const] = ACTIONS(5607),
    [anon_sym_constexpr] = ACTIONS(5607),
    [anon_sym_volatile] = ACTIONS(5607),
    [anon_sym_restrict] = ACTIONS(5607),
    [anon_sym___restrict__] = ACTIONS(5607),
    [anon_sym__Atomic] = ACTIONS(5607),
    [anon_sym__Noreturn] = ACTIONS(5607),
    [anon_sym_noreturn] = ACTIONS(5607),
    [anon_sym__Nonnull] = ACTIONS(5607),
    [anon_sym_mutable] = ACTIONS(5607),
    [anon_sym_constinit] = ACTIONS(5607),
    [anon_sym_consteval] = ACTIONS(5607),
    [anon_sym___shared__] = ACTIONS(5607),
    [anon_sym___local__] = ACTIONS(5607),
    [anon_sym___constant__] = ACTIONS(5607),
    [anon_sym___managed__] = ACTIONS(5607),
    [anon_sym___grid_constant__] = ACTIONS(5607),
    [anon_sym_alignas] = ACTIONS(5607),
    [anon_sym__Alignas] = ACTIONS(5607),
    [sym_primitive_type] = ACTIONS(5607),
    [anon_sym_enum] = ACTIONS(5607),
    [anon_sym_class] = ACTIONS(5607),
    [anon_sym_struct] = ACTIONS(5607),
    [anon_sym_union] = ACTIONS(5607),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5607),
    [anon_sym_decltype] = ACTIONS(5607),
    [anon_sym_explicit] = ACTIONS(5607),
    [anon_sym_typename] = ACTIONS(5607),
    [anon_sym_template] = ACTIONS(5607),
    [anon_sym_operator] = ACTIONS(5607),
    [anon_sym_friend] = ACTIONS(5607),
    [anon_sym_public] = ACTIONS(5607),
    [anon_sym_private] = ACTIONS(5607),
    [anon_sym_protected] = ACTIONS(5607),
    [anon_sym_using] = ACTIONS(5607),
    [anon_sym_static_assert] = ACTIONS(5607),
    [anon_sym___launch_bounds__] = ACTIONS(5607),
  },
  [STATE(1854)] = {
    [sym_identifier] = ACTIONS(5611),
    [aux_sym_preproc_def_token1] = ACTIONS(5611),
    [aux_sym_preproc_if_token1] = ACTIONS(5611),
    [aux_sym_preproc_if_token2] = ACTIONS(5611),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5611),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5611),
    [aux_sym_preproc_else_token1] = ACTIONS(5611),
    [aux_sym_preproc_elif_token1] = ACTIONS(5611),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5611),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5611),
    [sym_preproc_directive] = ACTIONS(5611),
    [anon_sym_LPAREN2] = ACTIONS(5613),
    [anon_sym_TILDE] = ACTIONS(5613),
    [anon_sym_STAR] = ACTIONS(5613),
    [anon_sym_AMP_AMP] = ACTIONS(5613),
    [anon_sym_AMP] = ACTIONS(5611),
    [anon_sym_SEMI] = ACTIONS(5613),
    [anon_sym___extension__] = ACTIONS(5611),
    [anon_sym_typedef] = ACTIONS(5611),
    [anon_sym___device__] = ACTIONS(5611),
    [anon_sym___host__] = ACTIONS(5611),
    [anon_sym___global__] = ACTIONS(5611),
    [anon_sym___forceinline__] = ACTIONS(5611),
    [anon_sym___noinline__] = ACTIONS(5611),
    [anon_sym_virtual] = ACTIONS(5611),
    [anon_sym_extern] = ACTIONS(5611),
    [anon_sym___attribute__] = ACTIONS(5611),
    [anon_sym___attribute] = ACTIONS(5611),
    [anon_sym_COLON_COLON] = ACTIONS(5613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5613),
    [anon_sym___declspec] = ACTIONS(5611),
    [anon_sym___based] = ACTIONS(5611),
    [anon_sym_signed] = ACTIONS(5611),
    [anon_sym_unsigned] = ACTIONS(5611),
    [anon_sym_long] = ACTIONS(5611),
    [anon_sym_short] = ACTIONS(5611),
    [anon_sym_LBRACK] = ACTIONS(5611),
    [anon_sym_static] = ACTIONS(5611),
    [anon_sym_register] = ACTIONS(5611),
    [anon_sym_inline] = ACTIONS(5611),
    [anon_sym___inline] = ACTIONS(5611),
    [anon_sym___inline__] = ACTIONS(5611),
    [anon_sym___forceinline] = ACTIONS(5611),
    [anon_sym_thread_local] = ACTIONS(5611),
    [anon_sym___thread] = ACTIONS(5611),
    [anon_sym_const] = ACTIONS(5611),
    [anon_sym_constexpr] = ACTIONS(5611),
    [anon_sym_volatile] = ACTIONS(5611),
    [anon_sym_restrict] = ACTIONS(5611),
    [anon_sym___restrict__] = ACTIONS(5611),
    [anon_sym__Atomic] = ACTIONS(5611),
    [anon_sym__Noreturn] = ACTIONS(5611),
    [anon_sym_noreturn] = ACTIONS(5611),
    [anon_sym__Nonnull] = ACTIONS(5611),
    [anon_sym_mutable] = ACTIONS(5611),
    [anon_sym_constinit] = ACTIONS(5611),
    [anon_sym_consteval] = ACTIONS(5611),
    [anon_sym___shared__] = ACTIONS(5611),
    [anon_sym___local__] = ACTIONS(5611),
    [anon_sym___constant__] = ACTIONS(5611),
    [anon_sym___managed__] = ACTIONS(5611),
    [anon_sym___grid_constant__] = ACTIONS(5611),
    [anon_sym_alignas] = ACTIONS(5611),
    [anon_sym__Alignas] = ACTIONS(5611),
    [sym_primitive_type] = ACTIONS(5611),
    [anon_sym_enum] = ACTIONS(5611),
    [anon_sym_class] = ACTIONS(5611),
    [anon_sym_struct] = ACTIONS(5611),
    [anon_sym_union] = ACTIONS(5611),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5611),
    [anon_sym_decltype] = ACTIONS(5611),
    [anon_sym_explicit] = ACTIONS(5611),
    [anon_sym_typename] = ACTIONS(5611),
    [anon_sym_template] = ACTIONS(5611),
    [anon_sym_operator] = ACTIONS(5611),
    [anon_sym_friend] = ACTIONS(5611),
    [anon_sym_public] = ACTIONS(5611),
    [anon_sym_private] = ACTIONS(5611),
    [anon_sym_protected] = ACTIONS(5611),
    [anon_sym_using] = ACTIONS(5611),
    [anon_sym_static_assert] = ACTIONS(5611),
    [anon_sym___launch_bounds__] = ACTIONS(5611),
  },
  [STATE(1855)] = {
    [sym_identifier] = ACTIONS(5615),
    [aux_sym_preproc_def_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token2] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5615),
    [aux_sym_preproc_else_token1] = ACTIONS(5615),
    [aux_sym_preproc_elif_token1] = ACTIONS(5615),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5615),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5615),
    [sym_preproc_directive] = ACTIONS(5615),
    [anon_sym_LPAREN2] = ACTIONS(5617),
    [anon_sym_TILDE] = ACTIONS(5617),
    [anon_sym_STAR] = ACTIONS(5617),
    [anon_sym_AMP_AMP] = ACTIONS(5617),
    [anon_sym_AMP] = ACTIONS(5615),
    [anon_sym_SEMI] = ACTIONS(5617),
    [anon_sym___extension__] = ACTIONS(5615),
    [anon_sym_typedef] = ACTIONS(5615),
    [anon_sym___device__] = ACTIONS(5615),
    [anon_sym___host__] = ACTIONS(5615),
    [anon_sym___global__] = ACTIONS(5615),
    [anon_sym___forceinline__] = ACTIONS(5615),
    [anon_sym___noinline__] = ACTIONS(5615),
    [anon_sym_virtual] = ACTIONS(5615),
    [anon_sym_extern] = ACTIONS(5615),
    [anon_sym___attribute__] = ACTIONS(5615),
    [anon_sym___attribute] = ACTIONS(5615),
    [anon_sym_COLON_COLON] = ACTIONS(5617),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5617),
    [anon_sym___declspec] = ACTIONS(5615),
    [anon_sym___based] = ACTIONS(5615),
    [anon_sym_signed] = ACTIONS(5615),
    [anon_sym_unsigned] = ACTIONS(5615),
    [anon_sym_long] = ACTIONS(5615),
    [anon_sym_short] = ACTIONS(5615),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [anon_sym_static] = ACTIONS(5615),
    [anon_sym_register] = ACTIONS(5615),
    [anon_sym_inline] = ACTIONS(5615),
    [anon_sym___inline] = ACTIONS(5615),
    [anon_sym___inline__] = ACTIONS(5615),
    [anon_sym___forceinline] = ACTIONS(5615),
    [anon_sym_thread_local] = ACTIONS(5615),
    [anon_sym___thread] = ACTIONS(5615),
    [anon_sym_const] = ACTIONS(5615),
    [anon_sym_constexpr] = ACTIONS(5615),
    [anon_sym_volatile] = ACTIONS(5615),
    [anon_sym_restrict] = ACTIONS(5615),
    [anon_sym___restrict__] = ACTIONS(5615),
    [anon_sym__Atomic] = ACTIONS(5615),
    [anon_sym__Noreturn] = ACTIONS(5615),
    [anon_sym_noreturn] = ACTIONS(5615),
    [anon_sym__Nonnull] = ACTIONS(5615),
    [anon_sym_mutable] = ACTIONS(5615),
    [anon_sym_constinit] = ACTIONS(5615),
    [anon_sym_consteval] = ACTIONS(5615),
    [anon_sym___shared__] = ACTIONS(5615),
    [anon_sym___local__] = ACTIONS(5615),
    [anon_sym___constant__] = ACTIONS(5615),
    [anon_sym___managed__] = ACTIONS(5615),
    [anon_sym___grid_constant__] = ACTIONS(5615),
    [anon_sym_alignas] = ACTIONS(5615),
    [anon_sym__Alignas] = ACTIONS(5615),
    [sym_primitive_type] = ACTIONS(5615),
    [anon_sym_enum] = ACTIONS(5615),
    [anon_sym_class] = ACTIONS(5615),
    [anon_sym_struct] = ACTIONS(5615),
    [anon_sym_union] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5615),
    [anon_sym_decltype] = ACTIONS(5615),
    [anon_sym_explicit] = ACTIONS(5615),
    [anon_sym_typename] = ACTIONS(5615),
    [anon_sym_template] = ACTIONS(5615),
    [anon_sym_operator] = ACTIONS(5615),
    [anon_sym_friend] = ACTIONS(5615),
    [anon_sym_public] = ACTIONS(5615),
    [anon_sym_private] = ACTIONS(5615),
    [anon_sym_protected] = ACTIONS(5615),
    [anon_sym_using] = ACTIONS(5615),
    [anon_sym_static_assert] = ACTIONS(5615),
    [anon_sym___launch_bounds__] = ACTIONS(5615),
  },
  [STATE(1856)] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token2] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [aux_sym_preproc_else_token1] = ACTIONS(2134),
    [aux_sym_preproc_elif_token1] = ACTIONS(2134),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym___device__] = ACTIONS(2134),
    [anon_sym___host__] = ACTIONS(2134),
    [anon_sym___global__] = ACTIONS(2134),
    [anon_sym___forceinline__] = ACTIONS(2134),
    [anon_sym___noinline__] = ACTIONS(2134),
    [anon_sym_virtual] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym___attribute] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym__Nonnull] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym___shared__] = ACTIONS(2134),
    [anon_sym___local__] = ACTIONS(2134),
    [anon_sym___constant__] = ACTIONS(2134),
    [anon_sym___managed__] = ACTIONS(2134),
    [anon_sym___grid_constant__] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_friend] = ACTIONS(2134),
    [anon_sym_public] = ACTIONS(2134),
    [anon_sym_private] = ACTIONS(2134),
    [anon_sym_protected] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym___launch_bounds__] = ACTIONS(2134),
  },
  [STATE(1857)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token2] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [aux_sym_preproc_else_token1] = ACTIONS(5619),
    [aux_sym_preproc_elif_token1] = ACTIONS(5619),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(1858)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token2] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [aux_sym_preproc_else_token1] = ACTIONS(5619),
    [aux_sym_preproc_elif_token1] = ACTIONS(5619),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(1859)] = {
    [sym_identifier] = ACTIONS(2032),
    [aux_sym_preproc_def_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token2] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2032),
    [aux_sym_preproc_else_token1] = ACTIONS(2032),
    [aux_sym_preproc_elif_token1] = ACTIONS(2032),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2032),
    [sym_preproc_directive] = ACTIONS(2032),
    [anon_sym_LPAREN2] = ACTIONS(2034),
    [anon_sym_TILDE] = ACTIONS(2034),
    [anon_sym_STAR] = ACTIONS(2034),
    [anon_sym_AMP_AMP] = ACTIONS(2034),
    [anon_sym_AMP] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(2034),
    [anon_sym___extension__] = ACTIONS(2032),
    [anon_sym_typedef] = ACTIONS(2032),
    [anon_sym___device__] = ACTIONS(2032),
    [anon_sym___host__] = ACTIONS(2032),
    [anon_sym___global__] = ACTIONS(2032),
    [anon_sym___forceinline__] = ACTIONS(2032),
    [anon_sym___noinline__] = ACTIONS(2032),
    [anon_sym_virtual] = ACTIONS(2032),
    [anon_sym_extern] = ACTIONS(2032),
    [anon_sym___attribute__] = ACTIONS(2032),
    [anon_sym___attribute] = ACTIONS(2032),
    [anon_sym_COLON_COLON] = ACTIONS(2034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2034),
    [anon_sym___declspec] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2032),
    [anon_sym_unsigned] = ACTIONS(2032),
    [anon_sym_long] = ACTIONS(2032),
    [anon_sym_short] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(2032),
    [anon_sym_static] = ACTIONS(2032),
    [anon_sym_register] = ACTIONS(2032),
    [anon_sym_inline] = ACTIONS(2032),
    [anon_sym___inline] = ACTIONS(2032),
    [anon_sym___inline__] = ACTIONS(2032),
    [anon_sym___forceinline] = ACTIONS(2032),
    [anon_sym_thread_local] = ACTIONS(2032),
    [anon_sym___thread] = ACTIONS(2032),
    [anon_sym_const] = ACTIONS(2032),
    [anon_sym_constexpr] = ACTIONS(2032),
    [anon_sym_volatile] = ACTIONS(2032),
    [anon_sym_restrict] = ACTIONS(2032),
    [anon_sym___restrict__] = ACTIONS(2032),
    [anon_sym__Atomic] = ACTIONS(2032),
    [anon_sym__Noreturn] = ACTIONS(2032),
    [anon_sym_noreturn] = ACTIONS(2032),
    [anon_sym__Nonnull] = ACTIONS(2032),
    [anon_sym_mutable] = ACTIONS(2032),
    [anon_sym_constinit] = ACTIONS(2032),
    [anon_sym_consteval] = ACTIONS(2032),
    [anon_sym___shared__] = ACTIONS(2032),
    [anon_sym___local__] = ACTIONS(2032),
    [anon_sym___constant__] = ACTIONS(2032),
    [anon_sym___managed__] = ACTIONS(2032),
    [anon_sym___grid_constant__] = ACTIONS(2032),
    [anon_sym_alignas] = ACTIONS(2032),
    [anon_sym__Alignas] = ACTIONS(2032),
    [sym_primitive_type] = ACTIONS(2032),
    [anon_sym_enum] = ACTIONS(2032),
    [anon_sym_class] = ACTIONS(2032),
    [anon_sym_struct] = ACTIONS(2032),
    [anon_sym_union] = ACTIONS(2032),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2032),
    [anon_sym_decltype] = ACTIONS(2032),
    [anon_sym_explicit] = ACTIONS(2032),
    [anon_sym_typename] = ACTIONS(2032),
    [anon_sym_template] = ACTIONS(2032),
    [anon_sym_operator] = ACTIONS(2032),
    [anon_sym_friend] = ACTIONS(2032),
    [anon_sym_public] = ACTIONS(2032),
    [anon_sym_private] = ACTIONS(2032),
    [anon_sym_protected] = ACTIONS(2032),
    [anon_sym_using] = ACTIONS(2032),
    [anon_sym_static_assert] = ACTIONS(2032),
    [anon_sym___launch_bounds__] = ACTIONS(2032),
  },
  [STATE(1860)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token2] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [aux_sym_preproc_else_token1] = ACTIONS(5619),
    [aux_sym_preproc_elif_token1] = ACTIONS(5619),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(1861)] = {
    [sym_identifier] = ACTIONS(5615),
    [aux_sym_preproc_def_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token2] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5615),
    [aux_sym_preproc_else_token1] = ACTIONS(5615),
    [aux_sym_preproc_elif_token1] = ACTIONS(5615),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5615),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5615),
    [sym_preproc_directive] = ACTIONS(5615),
    [anon_sym_LPAREN2] = ACTIONS(5617),
    [anon_sym_TILDE] = ACTIONS(5617),
    [anon_sym_STAR] = ACTIONS(5617),
    [anon_sym_AMP_AMP] = ACTIONS(5617),
    [anon_sym_AMP] = ACTIONS(5615),
    [anon_sym_SEMI] = ACTIONS(5617),
    [anon_sym___extension__] = ACTIONS(5615),
    [anon_sym_typedef] = ACTIONS(5615),
    [anon_sym___device__] = ACTIONS(5615),
    [anon_sym___host__] = ACTIONS(5615),
    [anon_sym___global__] = ACTIONS(5615),
    [anon_sym___forceinline__] = ACTIONS(5615),
    [anon_sym___noinline__] = ACTIONS(5615),
    [anon_sym_virtual] = ACTIONS(5615),
    [anon_sym_extern] = ACTIONS(5615),
    [anon_sym___attribute__] = ACTIONS(5615),
    [anon_sym___attribute] = ACTIONS(5615),
    [anon_sym_COLON_COLON] = ACTIONS(5617),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5617),
    [anon_sym___declspec] = ACTIONS(5615),
    [anon_sym___based] = ACTIONS(5615),
    [anon_sym_signed] = ACTIONS(5615),
    [anon_sym_unsigned] = ACTIONS(5615),
    [anon_sym_long] = ACTIONS(5615),
    [anon_sym_short] = ACTIONS(5615),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [anon_sym_static] = ACTIONS(5615),
    [anon_sym_register] = ACTIONS(5615),
    [anon_sym_inline] = ACTIONS(5615),
    [anon_sym___inline] = ACTIONS(5615),
    [anon_sym___inline__] = ACTIONS(5615),
    [anon_sym___forceinline] = ACTIONS(5615),
    [anon_sym_thread_local] = ACTIONS(5615),
    [anon_sym___thread] = ACTIONS(5615),
    [anon_sym_const] = ACTIONS(5615),
    [anon_sym_constexpr] = ACTIONS(5615),
    [anon_sym_volatile] = ACTIONS(5615),
    [anon_sym_restrict] = ACTIONS(5615),
    [anon_sym___restrict__] = ACTIONS(5615),
    [anon_sym__Atomic] = ACTIONS(5615),
    [anon_sym__Noreturn] = ACTIONS(5615),
    [anon_sym_noreturn] = ACTIONS(5615),
    [anon_sym__Nonnull] = ACTIONS(5615),
    [anon_sym_mutable] = ACTIONS(5615),
    [anon_sym_constinit] = ACTIONS(5615),
    [anon_sym_consteval] = ACTIONS(5615),
    [anon_sym___shared__] = ACTIONS(5615),
    [anon_sym___local__] = ACTIONS(5615),
    [anon_sym___constant__] = ACTIONS(5615),
    [anon_sym___managed__] = ACTIONS(5615),
    [anon_sym___grid_constant__] = ACTIONS(5615),
    [anon_sym_alignas] = ACTIONS(5615),
    [anon_sym__Alignas] = ACTIONS(5615),
    [sym_primitive_type] = ACTIONS(5615),
    [anon_sym_enum] = ACTIONS(5615),
    [anon_sym_class] = ACTIONS(5615),
    [anon_sym_struct] = ACTIONS(5615),
    [anon_sym_union] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5615),
    [anon_sym_decltype] = ACTIONS(5615),
    [anon_sym_explicit] = ACTIONS(5615),
    [anon_sym_typename] = ACTIONS(5615),
    [anon_sym_template] = ACTIONS(5615),
    [anon_sym_operator] = ACTIONS(5615),
    [anon_sym_friend] = ACTIONS(5615),
    [anon_sym_public] = ACTIONS(5615),
    [anon_sym_private] = ACTIONS(5615),
    [anon_sym_protected] = ACTIONS(5615),
    [anon_sym_using] = ACTIONS(5615),
    [anon_sym_static_assert] = ACTIONS(5615),
    [anon_sym___launch_bounds__] = ACTIONS(5615),
  },
  [STATE(1862)] = {
    [sym_identifier] = ACTIONS(2218),
    [aux_sym_preproc_def_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token2] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2218),
    [aux_sym_preproc_else_token1] = ACTIONS(2218),
    [aux_sym_preproc_elif_token1] = ACTIONS(2218),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2218),
    [sym_preproc_directive] = ACTIONS(2218),
    [anon_sym_LPAREN2] = ACTIONS(2220),
    [anon_sym_TILDE] = ACTIONS(2220),
    [anon_sym_STAR] = ACTIONS(2220),
    [anon_sym_AMP_AMP] = ACTIONS(2220),
    [anon_sym_AMP] = ACTIONS(2218),
    [anon_sym_SEMI] = ACTIONS(2220),
    [anon_sym___extension__] = ACTIONS(2218),
    [anon_sym_typedef] = ACTIONS(2218),
    [anon_sym___device__] = ACTIONS(2218),
    [anon_sym___host__] = ACTIONS(2218),
    [anon_sym___global__] = ACTIONS(2218),
    [anon_sym___forceinline__] = ACTIONS(2218),
    [anon_sym___noinline__] = ACTIONS(2218),
    [anon_sym_virtual] = ACTIONS(2218),
    [anon_sym_extern] = ACTIONS(2218),
    [anon_sym___attribute__] = ACTIONS(2218),
    [anon_sym___attribute] = ACTIONS(2218),
    [anon_sym_COLON_COLON] = ACTIONS(2220),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2220),
    [anon_sym___declspec] = ACTIONS(2218),
    [anon_sym___based] = ACTIONS(2218),
    [anon_sym_signed] = ACTIONS(2218),
    [anon_sym_unsigned] = ACTIONS(2218),
    [anon_sym_long] = ACTIONS(2218),
    [anon_sym_short] = ACTIONS(2218),
    [anon_sym_LBRACK] = ACTIONS(2218),
    [anon_sym_static] = ACTIONS(2218),
    [anon_sym_register] = ACTIONS(2218),
    [anon_sym_inline] = ACTIONS(2218),
    [anon_sym___inline] = ACTIONS(2218),
    [anon_sym___inline__] = ACTIONS(2218),
    [anon_sym___forceinline] = ACTIONS(2218),
    [anon_sym_thread_local] = ACTIONS(2218),
    [anon_sym___thread] = ACTIONS(2218),
    [anon_sym_const] = ACTIONS(2218),
    [anon_sym_constexpr] = ACTIONS(2218),
    [anon_sym_volatile] = ACTIONS(2218),
    [anon_sym_restrict] = ACTIONS(2218),
    [anon_sym___restrict__] = ACTIONS(2218),
    [anon_sym__Atomic] = ACTIONS(2218),
    [anon_sym__Noreturn] = ACTIONS(2218),
    [anon_sym_noreturn] = ACTIONS(2218),
    [anon_sym__Nonnull] = ACTIONS(2218),
    [anon_sym_mutable] = ACTIONS(2218),
    [anon_sym_constinit] = ACTIONS(2218),
    [anon_sym_consteval] = ACTIONS(2218),
    [anon_sym___shared__] = ACTIONS(2218),
    [anon_sym___local__] = ACTIONS(2218),
    [anon_sym___constant__] = ACTIONS(2218),
    [anon_sym___managed__] = ACTIONS(2218),
    [anon_sym___grid_constant__] = ACTIONS(2218),
    [anon_sym_alignas] = ACTIONS(2218),
    [anon_sym__Alignas] = ACTIONS(2218),
    [sym_primitive_type] = ACTIONS(2218),
    [anon_sym_enum] = ACTIONS(2218),
    [anon_sym_class] = ACTIONS(2218),
    [anon_sym_struct] = ACTIONS(2218),
    [anon_sym_union] = ACTIONS(2218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2218),
    [anon_sym_decltype] = ACTIONS(2218),
    [anon_sym_explicit] = ACTIONS(2218),
    [anon_sym_typename] = ACTIONS(2218),
    [anon_sym_template] = ACTIONS(2218),
    [anon_sym_operator] = ACTIONS(2218),
    [anon_sym_friend] = ACTIONS(2218),
    [anon_sym_public] = ACTIONS(2218),
    [anon_sym_private] = ACTIONS(2218),
    [anon_sym_protected] = ACTIONS(2218),
    [anon_sym_using] = ACTIONS(2218),
    [anon_sym_static_assert] = ACTIONS(2218),
    [anon_sym___launch_bounds__] = ACTIONS(2218),
  },
  [STATE(1863)] = {
    [sym_identifier] = ACTIONS(2044),
    [aux_sym_preproc_def_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token2] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2044),
    [aux_sym_preproc_else_token1] = ACTIONS(2044),
    [aux_sym_preproc_elif_token1] = ACTIONS(2044),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2044),
    [sym_preproc_directive] = ACTIONS(2044),
    [anon_sym_LPAREN2] = ACTIONS(2046),
    [anon_sym_TILDE] = ACTIONS(2046),
    [anon_sym_STAR] = ACTIONS(2046),
    [anon_sym_AMP_AMP] = ACTIONS(2046),
    [anon_sym_AMP] = ACTIONS(2044),
    [anon_sym_SEMI] = ACTIONS(2046),
    [anon_sym___extension__] = ACTIONS(2044),
    [anon_sym_typedef] = ACTIONS(2044),
    [anon_sym___device__] = ACTIONS(2044),
    [anon_sym___host__] = ACTIONS(2044),
    [anon_sym___global__] = ACTIONS(2044),
    [anon_sym___forceinline__] = ACTIONS(2044),
    [anon_sym___noinline__] = ACTIONS(2044),
    [anon_sym_virtual] = ACTIONS(2044),
    [anon_sym_extern] = ACTIONS(2044),
    [anon_sym___attribute__] = ACTIONS(2044),
    [anon_sym___attribute] = ACTIONS(2044),
    [anon_sym_COLON_COLON] = ACTIONS(2046),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2046),
    [anon_sym___declspec] = ACTIONS(2044),
    [anon_sym___based] = ACTIONS(2044),
    [anon_sym_signed] = ACTIONS(2044),
    [anon_sym_unsigned] = ACTIONS(2044),
    [anon_sym_long] = ACTIONS(2044),
    [anon_sym_short] = ACTIONS(2044),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_static] = ACTIONS(2044),
    [anon_sym_register] = ACTIONS(2044),
    [anon_sym_inline] = ACTIONS(2044),
    [anon_sym___inline] = ACTIONS(2044),
    [anon_sym___inline__] = ACTIONS(2044),
    [anon_sym___forceinline] = ACTIONS(2044),
    [anon_sym_thread_local] = ACTIONS(2044),
    [anon_sym___thread] = ACTIONS(2044),
    [anon_sym_const] = ACTIONS(2044),
    [anon_sym_constexpr] = ACTIONS(2044),
    [anon_sym_volatile] = ACTIONS(2044),
    [anon_sym_restrict] = ACTIONS(2044),
    [anon_sym___restrict__] = ACTIONS(2044),
    [anon_sym__Atomic] = ACTIONS(2044),
    [anon_sym__Noreturn] = ACTIONS(2044),
    [anon_sym_noreturn] = ACTIONS(2044),
    [anon_sym__Nonnull] = ACTIONS(2044),
    [anon_sym_mutable] = ACTIONS(2044),
    [anon_sym_constinit] = ACTIONS(2044),
    [anon_sym_consteval] = ACTIONS(2044),
    [anon_sym___shared__] = ACTIONS(2044),
    [anon_sym___local__] = ACTIONS(2044),
    [anon_sym___constant__] = ACTIONS(2044),
    [anon_sym___managed__] = ACTIONS(2044),
    [anon_sym___grid_constant__] = ACTIONS(2044),
    [anon_sym_alignas] = ACTIONS(2044),
    [anon_sym__Alignas] = ACTIONS(2044),
    [sym_primitive_type] = ACTIONS(2044),
    [anon_sym_enum] = ACTIONS(2044),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2044),
    [anon_sym_union] = ACTIONS(2044),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2044),
    [anon_sym_decltype] = ACTIONS(2044),
    [anon_sym_explicit] = ACTIONS(2044),
    [anon_sym_typename] = ACTIONS(2044),
    [anon_sym_template] = ACTIONS(2044),
    [anon_sym_operator] = ACTIONS(2044),
    [anon_sym_friend] = ACTIONS(2044),
    [anon_sym_public] = ACTIONS(2044),
    [anon_sym_private] = ACTIONS(2044),
    [anon_sym_protected] = ACTIONS(2044),
    [anon_sym_using] = ACTIONS(2044),
    [anon_sym_static_assert] = ACTIONS(2044),
    [anon_sym___launch_bounds__] = ACTIONS(2044),
  },
  [STATE(1864)] = {
    [sym_identifier] = ACTIONS(2595),
    [aux_sym_preproc_def_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token2] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2595),
    [aux_sym_preproc_else_token1] = ACTIONS(2595),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2595),
    [sym_preproc_directive] = ACTIONS(2595),
    [anon_sym_LPAREN2] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_AMP_AMP] = ACTIONS(2597),
    [anon_sym_AMP] = ACTIONS(2595),
    [anon_sym_SEMI] = ACTIONS(2597),
    [anon_sym___extension__] = ACTIONS(2595),
    [anon_sym_typedef] = ACTIONS(2595),
    [anon_sym___device__] = ACTIONS(2595),
    [anon_sym___host__] = ACTIONS(2595),
    [anon_sym___global__] = ACTIONS(2595),
    [anon_sym___forceinline__] = ACTIONS(2595),
    [anon_sym___noinline__] = ACTIONS(2595),
    [anon_sym_virtual] = ACTIONS(2595),
    [anon_sym_extern] = ACTIONS(2595),
    [anon_sym___attribute__] = ACTIONS(2595),
    [anon_sym___attribute] = ACTIONS(2595),
    [anon_sym_COLON_COLON] = ACTIONS(2597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2597),
    [anon_sym___declspec] = ACTIONS(2595),
    [anon_sym___based] = ACTIONS(2595),
    [anon_sym_signed] = ACTIONS(2595),
    [anon_sym_unsigned] = ACTIONS(2595),
    [anon_sym_long] = ACTIONS(2595),
    [anon_sym_short] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_register] = ACTIONS(2595),
    [anon_sym_inline] = ACTIONS(2595),
    [anon_sym___inline] = ACTIONS(2595),
    [anon_sym___inline__] = ACTIONS(2595),
    [anon_sym___forceinline] = ACTIONS(2595),
    [anon_sym_thread_local] = ACTIONS(2595),
    [anon_sym___thread] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_constexpr] = ACTIONS(2595),
    [anon_sym_volatile] = ACTIONS(2595),
    [anon_sym_restrict] = ACTIONS(2595),
    [anon_sym___restrict__] = ACTIONS(2595),
    [anon_sym__Atomic] = ACTIONS(2595),
    [anon_sym__Noreturn] = ACTIONS(2595),
    [anon_sym_noreturn] = ACTIONS(2595),
    [anon_sym__Nonnull] = ACTIONS(2595),
    [anon_sym_mutable] = ACTIONS(2595),
    [anon_sym_constinit] = ACTIONS(2595),
    [anon_sym_consteval] = ACTIONS(2595),
    [anon_sym___shared__] = ACTIONS(2595),
    [anon_sym___local__] = ACTIONS(2595),
    [anon_sym___constant__] = ACTIONS(2595),
    [anon_sym___managed__] = ACTIONS(2595),
    [anon_sym___grid_constant__] = ACTIONS(2595),
    [anon_sym_alignas] = ACTIONS(2595),
    [anon_sym__Alignas] = ACTIONS(2595),
    [sym_primitive_type] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_struct] = ACTIONS(2595),
    [anon_sym_union] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2595),
    [anon_sym_decltype] = ACTIONS(2595),
    [anon_sym_explicit] = ACTIONS(2595),
    [anon_sym_typename] = ACTIONS(2595),
    [anon_sym_template] = ACTIONS(2595),
    [anon_sym_operator] = ACTIONS(2595),
    [anon_sym_friend] = ACTIONS(2595),
    [anon_sym_public] = ACTIONS(2595),
    [anon_sym_private] = ACTIONS(2595),
    [anon_sym_protected] = ACTIONS(2595),
    [anon_sym_using] = ACTIONS(2595),
    [anon_sym_static_assert] = ACTIONS(2595),
    [anon_sym___launch_bounds__] = ACTIONS(2595),
  },
  [STATE(1865)] = {
    [sym_identifier] = ACTIONS(2028),
    [aux_sym_preproc_def_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token2] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2028),
    [aux_sym_preproc_else_token1] = ACTIONS(2028),
    [aux_sym_preproc_elif_token1] = ACTIONS(2028),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2028),
    [sym_preproc_directive] = ACTIONS(2028),
    [anon_sym_LPAREN2] = ACTIONS(2030),
    [anon_sym_TILDE] = ACTIONS(2030),
    [anon_sym_STAR] = ACTIONS(2030),
    [anon_sym_AMP_AMP] = ACTIONS(2030),
    [anon_sym_AMP] = ACTIONS(2028),
    [anon_sym_SEMI] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(2028),
    [anon_sym_typedef] = ACTIONS(2028),
    [anon_sym___device__] = ACTIONS(2028),
    [anon_sym___host__] = ACTIONS(2028),
    [anon_sym___global__] = ACTIONS(2028),
    [anon_sym___forceinline__] = ACTIONS(2028),
    [anon_sym___noinline__] = ACTIONS(2028),
    [anon_sym_virtual] = ACTIONS(2028),
    [anon_sym_extern] = ACTIONS(2028),
    [anon_sym___attribute__] = ACTIONS(2028),
    [anon_sym___attribute] = ACTIONS(2028),
    [anon_sym_COLON_COLON] = ACTIONS(2030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2030),
    [anon_sym___declspec] = ACTIONS(2028),
    [anon_sym___based] = ACTIONS(2028),
    [anon_sym_signed] = ACTIONS(2028),
    [anon_sym_unsigned] = ACTIONS(2028),
    [anon_sym_long] = ACTIONS(2028),
    [anon_sym_short] = ACTIONS(2028),
    [anon_sym_LBRACK] = ACTIONS(2028),
    [anon_sym_static] = ACTIONS(2028),
    [anon_sym_register] = ACTIONS(2028),
    [anon_sym_inline] = ACTIONS(2028),
    [anon_sym___inline] = ACTIONS(2028),
    [anon_sym___inline__] = ACTIONS(2028),
    [anon_sym___forceinline] = ACTIONS(2028),
    [anon_sym_thread_local] = ACTIONS(2028),
    [anon_sym___thread] = ACTIONS(2028),
    [anon_sym_const] = ACTIONS(2028),
    [anon_sym_constexpr] = ACTIONS(2028),
    [anon_sym_volatile] = ACTIONS(2028),
    [anon_sym_restrict] = ACTIONS(2028),
    [anon_sym___restrict__] = ACTIONS(2028),
    [anon_sym__Atomic] = ACTIONS(2028),
    [anon_sym__Noreturn] = ACTIONS(2028),
    [anon_sym_noreturn] = ACTIONS(2028),
    [anon_sym__Nonnull] = ACTIONS(2028),
    [anon_sym_mutable] = ACTIONS(2028),
    [anon_sym_constinit] = ACTIONS(2028),
    [anon_sym_consteval] = ACTIONS(2028),
    [anon_sym___shared__] = ACTIONS(2028),
    [anon_sym___local__] = ACTIONS(2028),
    [anon_sym___constant__] = ACTIONS(2028),
    [anon_sym___managed__] = ACTIONS(2028),
    [anon_sym___grid_constant__] = ACTIONS(2028),
    [anon_sym_alignas] = ACTIONS(2028),
    [anon_sym__Alignas] = ACTIONS(2028),
    [sym_primitive_type] = ACTIONS(2028),
    [anon_sym_enum] = ACTIONS(2028),
    [anon_sym_class] = ACTIONS(2028),
    [anon_sym_struct] = ACTIONS(2028),
    [anon_sym_union] = ACTIONS(2028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2028),
    [anon_sym_decltype] = ACTIONS(2028),
    [anon_sym_explicit] = ACTIONS(2028),
    [anon_sym_typename] = ACTIONS(2028),
    [anon_sym_template] = ACTIONS(2028),
    [anon_sym_operator] = ACTIONS(2028),
    [anon_sym_friend] = ACTIONS(2028),
    [anon_sym_public] = ACTIONS(2028),
    [anon_sym_private] = ACTIONS(2028),
    [anon_sym_protected] = ACTIONS(2028),
    [anon_sym_using] = ACTIONS(2028),
    [anon_sym_static_assert] = ACTIONS(2028),
    [anon_sym___launch_bounds__] = ACTIONS(2028),
  },
  [STATE(1866)] = {
    [sym_identifier] = ACTIONS(2447),
    [aux_sym_preproc_def_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token2] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2447),
    [aux_sym_preproc_else_token1] = ACTIONS(2447),
    [aux_sym_preproc_elif_token1] = ACTIONS(2447),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2447),
    [sym_preproc_directive] = ACTIONS(2447),
    [anon_sym_LPAREN2] = ACTIONS(2449),
    [anon_sym_TILDE] = ACTIONS(2449),
    [anon_sym_STAR] = ACTIONS(2449),
    [anon_sym_AMP_AMP] = ACTIONS(2449),
    [anon_sym_AMP] = ACTIONS(2447),
    [anon_sym_SEMI] = ACTIONS(2449),
    [anon_sym___extension__] = ACTIONS(2447),
    [anon_sym_typedef] = ACTIONS(2447),
    [anon_sym___device__] = ACTIONS(2447),
    [anon_sym___host__] = ACTIONS(2447),
    [anon_sym___global__] = ACTIONS(2447),
    [anon_sym___forceinline__] = ACTIONS(2447),
    [anon_sym___noinline__] = ACTIONS(2447),
    [anon_sym_virtual] = ACTIONS(2447),
    [anon_sym_extern] = ACTIONS(2447),
    [anon_sym___attribute__] = ACTIONS(2447),
    [anon_sym___attribute] = ACTIONS(2447),
    [anon_sym_COLON_COLON] = ACTIONS(2449),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2449),
    [anon_sym___declspec] = ACTIONS(2447),
    [anon_sym___based] = ACTIONS(2447),
    [anon_sym_signed] = ACTIONS(2447),
    [anon_sym_unsigned] = ACTIONS(2447),
    [anon_sym_long] = ACTIONS(2447),
    [anon_sym_short] = ACTIONS(2447),
    [anon_sym_LBRACK] = ACTIONS(2447),
    [anon_sym_static] = ACTIONS(2447),
    [anon_sym_register] = ACTIONS(2447),
    [anon_sym_inline] = ACTIONS(2447),
    [anon_sym___inline] = ACTIONS(2447),
    [anon_sym___inline__] = ACTIONS(2447),
    [anon_sym___forceinline] = ACTIONS(2447),
    [anon_sym_thread_local] = ACTIONS(2447),
    [anon_sym___thread] = ACTIONS(2447),
    [anon_sym_const] = ACTIONS(2447),
    [anon_sym_constexpr] = ACTIONS(2447),
    [anon_sym_volatile] = ACTIONS(2447),
    [anon_sym_restrict] = ACTIONS(2447),
    [anon_sym___restrict__] = ACTIONS(2447),
    [anon_sym__Atomic] = ACTIONS(2447),
    [anon_sym__Noreturn] = ACTIONS(2447),
    [anon_sym_noreturn] = ACTIONS(2447),
    [anon_sym__Nonnull] = ACTIONS(2447),
    [anon_sym_mutable] = ACTIONS(2447),
    [anon_sym_constinit] = ACTIONS(2447),
    [anon_sym_consteval] = ACTIONS(2447),
    [anon_sym___shared__] = ACTIONS(2447),
    [anon_sym___local__] = ACTIONS(2447),
    [anon_sym___constant__] = ACTIONS(2447),
    [anon_sym___managed__] = ACTIONS(2447),
    [anon_sym___grid_constant__] = ACTIONS(2447),
    [anon_sym_alignas] = ACTIONS(2447),
    [anon_sym__Alignas] = ACTIONS(2447),
    [sym_primitive_type] = ACTIONS(2447),
    [anon_sym_enum] = ACTIONS(2447),
    [anon_sym_class] = ACTIONS(2447),
    [anon_sym_struct] = ACTIONS(2447),
    [anon_sym_union] = ACTIONS(2447),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2447),
    [anon_sym_decltype] = ACTIONS(2447),
    [anon_sym_explicit] = ACTIONS(2447),
    [anon_sym_typename] = ACTIONS(2447),
    [anon_sym_template] = ACTIONS(2447),
    [anon_sym_operator] = ACTIONS(2447),
    [anon_sym_friend] = ACTIONS(2447),
    [anon_sym_public] = ACTIONS(2447),
    [anon_sym_private] = ACTIONS(2447),
    [anon_sym_protected] = ACTIONS(2447),
    [anon_sym_using] = ACTIONS(2447),
    [anon_sym_static_assert] = ACTIONS(2447),
    [anon_sym___launch_bounds__] = ACTIONS(2447),
  },
  [STATE(1867)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_RPAREN] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5143),
    [anon_sym_SLASH] = ACTIONS(5143),
    [anon_sym_PERCENT] = ACTIONS(5143),
    [anon_sym_PIPE_PIPE] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_PIPE] = ACTIONS(5143),
    [anon_sym_CARET] = ACTIONS(5143),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_GT] = ACTIONS(5143),
    [anon_sym_GT_EQ] = ACTIONS(5145),
    [anon_sym_LT_EQ] = ACTIONS(5143),
    [anon_sym_LT] = ACTIONS(5143),
    [anon_sym_LT_LT] = ACTIONS(5143),
    [anon_sym_GT_GT] = ACTIONS(5143),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_EQ] = ACTIONS(5143),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_STAR_EQ] = ACTIONS(5145),
    [anon_sym_SLASH_EQ] = ACTIONS(5145),
    [anon_sym_PERCENT_EQ] = ACTIONS(5145),
    [anon_sym_PLUS_EQ] = ACTIONS(5145),
    [anon_sym_DASH_EQ] = ACTIONS(5145),
    [anon_sym_LT_LT_EQ] = ACTIONS(5145),
    [anon_sym_GT_GT_EQ] = ACTIONS(5145),
    [anon_sym_AMP_EQ] = ACTIONS(5145),
    [anon_sym_CARET_EQ] = ACTIONS(5145),
    [anon_sym_PIPE_EQ] = ACTIONS(5145),
    [anon_sym_LT_EQ_GT] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5143),
    [anon_sym_and] = ACTIONS(5143),
    [anon_sym_bitor] = ACTIONS(5143),
    [anon_sym_xor] = ACTIONS(5143),
    [anon_sym_bitand] = ACTIONS(5143),
    [anon_sym_not_eq] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5143),
    [anon_sym_DOT_STAR] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5143),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5145),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5145),
  },
  [STATE(1868)] = {
    [sym_catch_clause] = STATE(1868),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1868),
    [sym_identifier] = ACTIONS(1940),
    [aux_sym_preproc_def_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1940),
    [sym_preproc_directive] = ACTIONS(1940),
    [anon_sym_LPAREN2] = ACTIONS(1942),
    [anon_sym_TILDE] = ACTIONS(1942),
    [anon_sym_STAR] = ACTIONS(1942),
    [anon_sym_AMP_AMP] = ACTIONS(1942),
    [anon_sym_AMP] = ACTIONS(1940),
    [anon_sym_SEMI] = ACTIONS(1942),
    [anon_sym___extension__] = ACTIONS(1940),
    [anon_sym_typedef] = ACTIONS(1940),
    [anon_sym___device__] = ACTIONS(1940),
    [anon_sym___host__] = ACTIONS(1940),
    [anon_sym___global__] = ACTIONS(1940),
    [anon_sym___forceinline__] = ACTIONS(1940),
    [anon_sym___noinline__] = ACTIONS(1940),
    [anon_sym_virtual] = ACTIONS(1940),
    [anon_sym_extern] = ACTIONS(1940),
    [anon_sym___attribute__] = ACTIONS(1940),
    [anon_sym___attribute] = ACTIONS(1940),
    [anon_sym_COLON_COLON] = ACTIONS(1942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1942),
    [anon_sym___declspec] = ACTIONS(1940),
    [anon_sym___based] = ACTIONS(1940),
    [anon_sym_RBRACE] = ACTIONS(1942),
    [anon_sym_signed] = ACTIONS(1940),
    [anon_sym_unsigned] = ACTIONS(1940),
    [anon_sym_long] = ACTIONS(1940),
    [anon_sym_short] = ACTIONS(1940),
    [anon_sym_LBRACK] = ACTIONS(1940),
    [anon_sym_static] = ACTIONS(1940),
    [anon_sym_register] = ACTIONS(1940),
    [anon_sym_inline] = ACTIONS(1940),
    [anon_sym___inline] = ACTIONS(1940),
    [anon_sym___inline__] = ACTIONS(1940),
    [anon_sym___forceinline] = ACTIONS(1940),
    [anon_sym_thread_local] = ACTIONS(1940),
    [anon_sym___thread] = ACTIONS(1940),
    [anon_sym_const] = ACTIONS(1940),
    [anon_sym_constexpr] = ACTIONS(1940),
    [anon_sym_volatile] = ACTIONS(1940),
    [anon_sym_restrict] = ACTIONS(1940),
    [anon_sym___restrict__] = ACTIONS(1940),
    [anon_sym__Atomic] = ACTIONS(1940),
    [anon_sym__Noreturn] = ACTIONS(1940),
    [anon_sym_noreturn] = ACTIONS(1940),
    [anon_sym__Nonnull] = ACTIONS(1940),
    [anon_sym_mutable] = ACTIONS(1940),
    [anon_sym_constinit] = ACTIONS(1940),
    [anon_sym_consteval] = ACTIONS(1940),
    [anon_sym___shared__] = ACTIONS(1940),
    [anon_sym___local__] = ACTIONS(1940),
    [anon_sym___constant__] = ACTIONS(1940),
    [anon_sym___managed__] = ACTIONS(1940),
    [anon_sym___grid_constant__] = ACTIONS(1940),
    [anon_sym_alignas] = ACTIONS(1940),
    [anon_sym__Alignas] = ACTIONS(1940),
    [sym_primitive_type] = ACTIONS(1940),
    [anon_sym_enum] = ACTIONS(1940),
    [anon_sym_class] = ACTIONS(1940),
    [anon_sym_struct] = ACTIONS(1940),
    [anon_sym_union] = ACTIONS(1940),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1940),
    [anon_sym_decltype] = ACTIONS(1940),
    [anon_sym_explicit] = ACTIONS(1940),
    [anon_sym_typename] = ACTIONS(1940),
    [anon_sym_template] = ACTIONS(1940),
    [anon_sym_operator] = ACTIONS(1940),
    [anon_sym_friend] = ACTIONS(1940),
    [anon_sym_public] = ACTIONS(1940),
    [anon_sym_private] = ACTIONS(1940),
    [anon_sym_protected] = ACTIONS(1940),
    [anon_sym_using] = ACTIONS(1940),
    [anon_sym_static_assert] = ACTIONS(1940),
    [anon_sym_catch] = ACTIONS(5623),
    [anon_sym___launch_bounds__] = ACTIONS(1940),
  },
  [STATE(1869)] = {
    [sym_catch_clause] = STATE(1868),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1868),
    [sym_identifier] = ACTIONS(1992),
    [aux_sym_preproc_def_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1992),
    [sym_preproc_directive] = ACTIONS(1992),
    [anon_sym_LPAREN2] = ACTIONS(1994),
    [anon_sym_TILDE] = ACTIONS(1994),
    [anon_sym_STAR] = ACTIONS(1994),
    [anon_sym_AMP_AMP] = ACTIONS(1994),
    [anon_sym_AMP] = ACTIONS(1992),
    [anon_sym_SEMI] = ACTIONS(1994),
    [anon_sym___extension__] = ACTIONS(1992),
    [anon_sym_typedef] = ACTIONS(1992),
    [anon_sym___device__] = ACTIONS(1992),
    [anon_sym___host__] = ACTIONS(1992),
    [anon_sym___global__] = ACTIONS(1992),
    [anon_sym___forceinline__] = ACTIONS(1992),
    [anon_sym___noinline__] = ACTIONS(1992),
    [anon_sym_virtual] = ACTIONS(1992),
    [anon_sym_extern] = ACTIONS(1992),
    [anon_sym___attribute__] = ACTIONS(1992),
    [anon_sym___attribute] = ACTIONS(1992),
    [anon_sym_COLON_COLON] = ACTIONS(1994),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1994),
    [anon_sym___declspec] = ACTIONS(1992),
    [anon_sym___based] = ACTIONS(1992),
    [anon_sym_RBRACE] = ACTIONS(1994),
    [anon_sym_signed] = ACTIONS(1992),
    [anon_sym_unsigned] = ACTIONS(1992),
    [anon_sym_long] = ACTIONS(1992),
    [anon_sym_short] = ACTIONS(1992),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_static] = ACTIONS(1992),
    [anon_sym_register] = ACTIONS(1992),
    [anon_sym_inline] = ACTIONS(1992),
    [anon_sym___inline] = ACTIONS(1992),
    [anon_sym___inline__] = ACTIONS(1992),
    [anon_sym___forceinline] = ACTIONS(1992),
    [anon_sym_thread_local] = ACTIONS(1992),
    [anon_sym___thread] = ACTIONS(1992),
    [anon_sym_const] = ACTIONS(1992),
    [anon_sym_constexpr] = ACTIONS(1992),
    [anon_sym_volatile] = ACTIONS(1992),
    [anon_sym_restrict] = ACTIONS(1992),
    [anon_sym___restrict__] = ACTIONS(1992),
    [anon_sym__Atomic] = ACTIONS(1992),
    [anon_sym__Noreturn] = ACTIONS(1992),
    [anon_sym_noreturn] = ACTIONS(1992),
    [anon_sym__Nonnull] = ACTIONS(1992),
    [anon_sym_mutable] = ACTIONS(1992),
    [anon_sym_constinit] = ACTIONS(1992),
    [anon_sym_consteval] = ACTIONS(1992),
    [anon_sym___shared__] = ACTIONS(1992),
    [anon_sym___local__] = ACTIONS(1992),
    [anon_sym___constant__] = ACTIONS(1992),
    [anon_sym___managed__] = ACTIONS(1992),
    [anon_sym___grid_constant__] = ACTIONS(1992),
    [anon_sym_alignas] = ACTIONS(1992),
    [anon_sym__Alignas] = ACTIONS(1992),
    [sym_primitive_type] = ACTIONS(1992),
    [anon_sym_enum] = ACTIONS(1992),
    [anon_sym_class] = ACTIONS(1992),
    [anon_sym_struct] = ACTIONS(1992),
    [anon_sym_union] = ACTIONS(1992),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1992),
    [anon_sym_decltype] = ACTIONS(1992),
    [anon_sym_explicit] = ACTIONS(1992),
    [anon_sym_typename] = ACTIONS(1992),
    [anon_sym_template] = ACTIONS(1992),
    [anon_sym_operator] = ACTIONS(1992),
    [anon_sym_friend] = ACTIONS(1992),
    [anon_sym_public] = ACTIONS(1992),
    [anon_sym_private] = ACTIONS(1992),
    [anon_sym_protected] = ACTIONS(1992),
    [anon_sym_using] = ACTIONS(1992),
    [anon_sym_static_assert] = ACTIONS(1992),
    [anon_sym_catch] = ACTIONS(5626),
    [anon_sym___launch_bounds__] = ACTIONS(1992),
  },
  [STATE(1870)] = {
    [sym_identifier] = ACTIONS(5628),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5630),
    [anon_sym_COMMA] = ACTIONS(5630),
    [anon_sym_RPAREN] = ACTIONS(5630),
    [anon_sym_LPAREN2] = ACTIONS(5630),
    [anon_sym_TILDE] = ACTIONS(5630),
    [anon_sym_STAR] = ACTIONS(5630),
    [anon_sym_AMP_AMP] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5628),
    [anon_sym_SEMI] = ACTIONS(5630),
    [anon_sym___extension__] = ACTIONS(5628),
    [anon_sym___device__] = ACTIONS(5628),
    [anon_sym___host__] = ACTIONS(5628),
    [anon_sym___global__] = ACTIONS(5628),
    [anon_sym___forceinline__] = ACTIONS(5628),
    [anon_sym___noinline__] = ACTIONS(5628),
    [anon_sym_virtual] = ACTIONS(5628),
    [anon_sym_extern] = ACTIONS(5628),
    [anon_sym___attribute__] = ACTIONS(5628),
    [anon_sym___attribute] = ACTIONS(5628),
    [anon_sym_COLON_COLON] = ACTIONS(5630),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5630),
    [anon_sym___declspec] = ACTIONS(5628),
    [anon_sym___based] = ACTIONS(5628),
    [anon_sym_LBRACE] = ACTIONS(5630),
    [anon_sym_signed] = ACTIONS(5628),
    [anon_sym_unsigned] = ACTIONS(5628),
    [anon_sym_long] = ACTIONS(5628),
    [anon_sym_short] = ACTIONS(5628),
    [anon_sym_LBRACK] = ACTIONS(5628),
    [anon_sym_static] = ACTIONS(5628),
    [anon_sym_EQ] = ACTIONS(5630),
    [anon_sym_register] = ACTIONS(5628),
    [anon_sym_inline] = ACTIONS(5628),
    [anon_sym___inline] = ACTIONS(5628),
    [anon_sym___inline__] = ACTIONS(5628),
    [anon_sym___forceinline] = ACTIONS(5628),
    [anon_sym_thread_local] = ACTIONS(5628),
    [anon_sym___thread] = ACTIONS(5628),
    [anon_sym_const] = ACTIONS(5628),
    [anon_sym_constexpr] = ACTIONS(5628),
    [anon_sym_volatile] = ACTIONS(5628),
    [anon_sym_restrict] = ACTIONS(5628),
    [anon_sym___restrict__] = ACTIONS(5628),
    [anon_sym__Atomic] = ACTIONS(5628),
    [anon_sym__Noreturn] = ACTIONS(5628),
    [anon_sym_noreturn] = ACTIONS(5628),
    [anon_sym__Nonnull] = ACTIONS(5628),
    [anon_sym_mutable] = ACTIONS(5628),
    [anon_sym_constinit] = ACTIONS(5628),
    [anon_sym_consteval] = ACTIONS(5628),
    [anon_sym___shared__] = ACTIONS(5628),
    [anon_sym___local__] = ACTIONS(5628),
    [anon_sym___constant__] = ACTIONS(5628),
    [anon_sym___managed__] = ACTIONS(5628),
    [anon_sym___grid_constant__] = ACTIONS(5628),
    [anon_sym_alignas] = ACTIONS(5628),
    [anon_sym__Alignas] = ACTIONS(5628),
    [sym_primitive_type] = ACTIONS(5628),
    [anon_sym_enum] = ACTIONS(5628),
    [anon_sym_class] = ACTIONS(5628),
    [anon_sym_struct] = ACTIONS(5628),
    [anon_sym_union] = ACTIONS(5628),
    [anon_sym_asm] = ACTIONS(5628),
    [anon_sym___asm__] = ACTIONS(5628),
    [anon_sym___asm] = ACTIONS(5628),
    [anon_sym_DASH_GT] = ACTIONS(5630),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5628),
    [anon_sym_decltype] = ACTIONS(5628),
    [anon_sym_final] = ACTIONS(5628),
    [anon_sym_override] = ACTIONS(5628),
    [anon_sym_explicit] = ACTIONS(5628),
    [anon_sym_typename] = ACTIONS(5628),
    [anon_sym_template] = ACTIONS(5628),
    [anon_sym_GT2] = ACTIONS(5630),
    [anon_sym_operator] = ACTIONS(5628),
    [anon_sym_try] = ACTIONS(5628),
    [anon_sym_noexcept] = ACTIONS(5628),
    [anon_sym_throw] = ACTIONS(5628),
    [anon_sym_requires] = ACTIONS(5628),
    [anon_sym___launch_bounds__] = ACTIONS(5628),
  },
  [STATE(1871)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4402),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4402),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4402),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4402),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4402),
    [anon_sym___extension__] = ACTIONS(4404),
    [anon_sym___global__] = ACTIONS(4404),
    [anon_sym___attribute__] = ACTIONS(4404),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_EQ] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4404),
    [anon_sym_volatile] = ACTIONS(4404),
    [anon_sym_restrict] = ACTIONS(4404),
    [anon_sym___restrict__] = ACTIONS(4404),
    [anon_sym__Atomic] = ACTIONS(4404),
    [anon_sym__Noreturn] = ACTIONS(4404),
    [anon_sym_noreturn] = ACTIONS(4404),
    [anon_sym__Nonnull] = ACTIONS(4404),
    [anon_sym_mutable] = ACTIONS(4404),
    [anon_sym_constinit] = ACTIONS(4404),
    [anon_sym_consteval] = ACTIONS(4404),
    [anon_sym___shared__] = ACTIONS(4404),
    [anon_sym___local__] = ACTIONS(4404),
    [anon_sym___constant__] = ACTIONS(4404),
    [anon_sym___managed__] = ACTIONS(4404),
    [anon_sym___grid_constant__] = ACTIONS(4404),
    [anon_sym_alignas] = ACTIONS(4404),
    [anon_sym__Alignas] = ACTIONS(4404),
    [anon_sym_COLON] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_STAR_EQ] = ACTIONS(4404),
    [anon_sym_SLASH_EQ] = ACTIONS(4404),
    [anon_sym_PERCENT_EQ] = ACTIONS(4404),
    [anon_sym_PLUS_EQ] = ACTIONS(4404),
    [anon_sym_DASH_EQ] = ACTIONS(4404),
    [anon_sym_LT_LT_EQ] = ACTIONS(4404),
    [anon_sym_GT_GT_EQ] = ACTIONS(4402),
    [anon_sym_AMP_EQ] = ACTIONS(4404),
    [anon_sym_CARET_EQ] = ACTIONS(4404),
    [anon_sym_PIPE_EQ] = ACTIONS(4404),
    [anon_sym_and_eq] = ACTIONS(4404),
    [anon_sym_or_eq] = ACTIONS(4404),
    [anon_sym_xor_eq] = ACTIONS(4404),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_bitor] = ACTIONS(4404),
    [anon_sym_xor] = ACTIONS(4402),
    [anon_sym_bitand] = ACTIONS(4404),
    [anon_sym_not_eq] = ACTIONS(4404),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4404),
    [anon_sym_decltype] = ACTIONS(4404),
    [anon_sym_final] = ACTIONS(4404),
    [anon_sym_override] = ACTIONS(4404),
    [anon_sym_GT2] = ACTIONS(4404),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
  },
  [STATE(1872)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4408),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4408),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4408),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4408),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4408),
    [anon_sym___extension__] = ACTIONS(4410),
    [anon_sym___global__] = ACTIONS(4410),
    [anon_sym___attribute__] = ACTIONS(4410),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4410),
    [anon_sym_EQ] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4410),
    [anon_sym_volatile] = ACTIONS(4410),
    [anon_sym_restrict] = ACTIONS(4410),
    [anon_sym___restrict__] = ACTIONS(4410),
    [anon_sym__Atomic] = ACTIONS(4410),
    [anon_sym__Noreturn] = ACTIONS(4410),
    [anon_sym_noreturn] = ACTIONS(4410),
    [anon_sym__Nonnull] = ACTIONS(4410),
    [anon_sym_mutable] = ACTIONS(4410),
    [anon_sym_constinit] = ACTIONS(4410),
    [anon_sym_consteval] = ACTIONS(4410),
    [anon_sym___shared__] = ACTIONS(4410),
    [anon_sym___local__] = ACTIONS(4410),
    [anon_sym___constant__] = ACTIONS(4410),
    [anon_sym___managed__] = ACTIONS(4410),
    [anon_sym___grid_constant__] = ACTIONS(4410),
    [anon_sym_alignas] = ACTIONS(4410),
    [anon_sym__Alignas] = ACTIONS(4410),
    [anon_sym_COLON] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_STAR_EQ] = ACTIONS(4410),
    [anon_sym_SLASH_EQ] = ACTIONS(4410),
    [anon_sym_PERCENT_EQ] = ACTIONS(4410),
    [anon_sym_PLUS_EQ] = ACTIONS(4410),
    [anon_sym_DASH_EQ] = ACTIONS(4410),
    [anon_sym_LT_LT_EQ] = ACTIONS(4410),
    [anon_sym_GT_GT_EQ] = ACTIONS(4408),
    [anon_sym_AMP_EQ] = ACTIONS(4410),
    [anon_sym_CARET_EQ] = ACTIONS(4410),
    [anon_sym_PIPE_EQ] = ACTIONS(4410),
    [anon_sym_and_eq] = ACTIONS(4410),
    [anon_sym_or_eq] = ACTIONS(4410),
    [anon_sym_xor_eq] = ACTIONS(4410),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_bitor] = ACTIONS(4410),
    [anon_sym_xor] = ACTIONS(4408),
    [anon_sym_bitand] = ACTIONS(4410),
    [anon_sym_not_eq] = ACTIONS(4410),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4410),
    [anon_sym_decltype] = ACTIONS(4410),
    [anon_sym_final] = ACTIONS(4410),
    [anon_sym_override] = ACTIONS(4410),
    [anon_sym_GT2] = ACTIONS(4410),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
  },
  [STATE(1873)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_RPAREN] = ACTIONS(1959),
    [aux_sym_preproc_if_token2] = ACTIONS(1959),
    [aux_sym_preproc_else_token1] = ACTIONS(1959),
    [aux_sym_preproc_elif_token1] = ACTIONS(1969),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1959),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1959),
    [anon_sym_PIPE_PIPE] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1959),
    [anon_sym_BANG_EQ] = ACTIONS(1959),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1959),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_RBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_RBRACK] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(1959),
    [anon_sym_LT_EQ_GT] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1959),
    [anon_sym_DASH_GT] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1959),
  },
  [STATE(1874)] = {
    [sym_catch_clause] = STATE(1882),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1882),
    [sym_identifier] = ACTIONS(1996),
    [aux_sym_preproc_def_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token2] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1996),
    [sym_preproc_directive] = ACTIONS(1996),
    [anon_sym_LPAREN2] = ACTIONS(1998),
    [anon_sym_TILDE] = ACTIONS(1998),
    [anon_sym_STAR] = ACTIONS(1998),
    [anon_sym_AMP_AMP] = ACTIONS(1998),
    [anon_sym_AMP] = ACTIONS(1996),
    [anon_sym_SEMI] = ACTIONS(1998),
    [anon_sym___extension__] = ACTIONS(1996),
    [anon_sym_typedef] = ACTIONS(1996),
    [anon_sym___device__] = ACTIONS(1996),
    [anon_sym___host__] = ACTIONS(1996),
    [anon_sym___global__] = ACTIONS(1996),
    [anon_sym___forceinline__] = ACTIONS(1996),
    [anon_sym___noinline__] = ACTIONS(1996),
    [anon_sym_virtual] = ACTIONS(1996),
    [anon_sym_extern] = ACTIONS(1996),
    [anon_sym___attribute__] = ACTIONS(1996),
    [anon_sym___attribute] = ACTIONS(1996),
    [anon_sym_COLON_COLON] = ACTIONS(1998),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1998),
    [anon_sym___declspec] = ACTIONS(1996),
    [anon_sym___based] = ACTIONS(1996),
    [anon_sym_signed] = ACTIONS(1996),
    [anon_sym_unsigned] = ACTIONS(1996),
    [anon_sym_long] = ACTIONS(1996),
    [anon_sym_short] = ACTIONS(1996),
    [anon_sym_LBRACK] = ACTIONS(1996),
    [anon_sym_static] = ACTIONS(1996),
    [anon_sym_register] = ACTIONS(1996),
    [anon_sym_inline] = ACTIONS(1996),
    [anon_sym___inline] = ACTIONS(1996),
    [anon_sym___inline__] = ACTIONS(1996),
    [anon_sym___forceinline] = ACTIONS(1996),
    [anon_sym_thread_local] = ACTIONS(1996),
    [anon_sym___thread] = ACTIONS(1996),
    [anon_sym_const] = ACTIONS(1996),
    [anon_sym_constexpr] = ACTIONS(1996),
    [anon_sym_volatile] = ACTIONS(1996),
    [anon_sym_restrict] = ACTIONS(1996),
    [anon_sym___restrict__] = ACTIONS(1996),
    [anon_sym__Atomic] = ACTIONS(1996),
    [anon_sym__Noreturn] = ACTIONS(1996),
    [anon_sym_noreturn] = ACTIONS(1996),
    [anon_sym__Nonnull] = ACTIONS(1996),
    [anon_sym_mutable] = ACTIONS(1996),
    [anon_sym_constinit] = ACTIONS(1996),
    [anon_sym_consteval] = ACTIONS(1996),
    [anon_sym___shared__] = ACTIONS(1996),
    [anon_sym___local__] = ACTIONS(1996),
    [anon_sym___constant__] = ACTIONS(1996),
    [anon_sym___managed__] = ACTIONS(1996),
    [anon_sym___grid_constant__] = ACTIONS(1996),
    [anon_sym_alignas] = ACTIONS(1996),
    [anon_sym__Alignas] = ACTIONS(1996),
    [sym_primitive_type] = ACTIONS(1996),
    [anon_sym_enum] = ACTIONS(1996),
    [anon_sym_class] = ACTIONS(1996),
    [anon_sym_struct] = ACTIONS(1996),
    [anon_sym_union] = ACTIONS(1996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1996),
    [anon_sym_decltype] = ACTIONS(1996),
    [anon_sym_explicit] = ACTIONS(1996),
    [anon_sym_typename] = ACTIONS(1996),
    [anon_sym_template] = ACTIONS(1996),
    [anon_sym_operator] = ACTIONS(1996),
    [anon_sym_friend] = ACTIONS(1996),
    [anon_sym_public] = ACTIONS(1996),
    [anon_sym_private] = ACTIONS(1996),
    [anon_sym_protected] = ACTIONS(1996),
    [anon_sym_using] = ACTIONS(1996),
    [anon_sym_static_assert] = ACTIONS(1996),
    [anon_sym_catch] = ACTIONS(5632),
    [anon_sym___launch_bounds__] = ACTIONS(1996),
  },
  [STATE(1875)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4350),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4350),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4350),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4350),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4350),
    [anon_sym___extension__] = ACTIONS(4352),
    [anon_sym___global__] = ACTIONS(4352),
    [anon_sym___attribute__] = ACTIONS(4352),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4352),
    [anon_sym_EQ] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4352),
    [anon_sym_volatile] = ACTIONS(4352),
    [anon_sym_restrict] = ACTIONS(4352),
    [anon_sym___restrict__] = ACTIONS(4352),
    [anon_sym__Atomic] = ACTIONS(4352),
    [anon_sym__Noreturn] = ACTIONS(4352),
    [anon_sym_noreturn] = ACTIONS(4352),
    [anon_sym__Nonnull] = ACTIONS(4352),
    [anon_sym_mutable] = ACTIONS(4352),
    [anon_sym_constinit] = ACTIONS(4352),
    [anon_sym_consteval] = ACTIONS(4352),
    [anon_sym___shared__] = ACTIONS(4352),
    [anon_sym___local__] = ACTIONS(4352),
    [anon_sym___constant__] = ACTIONS(4352),
    [anon_sym___managed__] = ACTIONS(4352),
    [anon_sym___grid_constant__] = ACTIONS(4352),
    [anon_sym_alignas] = ACTIONS(4352),
    [anon_sym__Alignas] = ACTIONS(4352),
    [anon_sym_COLON] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_STAR_EQ] = ACTIONS(4352),
    [anon_sym_SLASH_EQ] = ACTIONS(4352),
    [anon_sym_PERCENT_EQ] = ACTIONS(4352),
    [anon_sym_PLUS_EQ] = ACTIONS(4352),
    [anon_sym_DASH_EQ] = ACTIONS(4352),
    [anon_sym_LT_LT_EQ] = ACTIONS(4352),
    [anon_sym_GT_GT_EQ] = ACTIONS(4350),
    [anon_sym_AMP_EQ] = ACTIONS(4352),
    [anon_sym_CARET_EQ] = ACTIONS(4352),
    [anon_sym_PIPE_EQ] = ACTIONS(4352),
    [anon_sym_and_eq] = ACTIONS(4352),
    [anon_sym_or_eq] = ACTIONS(4352),
    [anon_sym_xor_eq] = ACTIONS(4352),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_bitor] = ACTIONS(4352),
    [anon_sym_xor] = ACTIONS(4350),
    [anon_sym_bitand] = ACTIONS(4352),
    [anon_sym_not_eq] = ACTIONS(4352),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4352),
    [anon_sym_decltype] = ACTIONS(4352),
    [anon_sym_final] = ACTIONS(4352),
    [anon_sym_override] = ACTIONS(4352),
    [anon_sym_GT2] = ACTIONS(4352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
  },
  [STATE(1876)] = {
    [sym_catch_clause] = STATE(1868),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1868),
    [sym_identifier] = ACTIONS(1996),
    [aux_sym_preproc_def_token1] = ACTIONS(1996),
    [aux_sym_preproc_if_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1996),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1996),
    [sym_preproc_directive] = ACTIONS(1996),
    [anon_sym_LPAREN2] = ACTIONS(1998),
    [anon_sym_TILDE] = ACTIONS(1998),
    [anon_sym_STAR] = ACTIONS(1998),
    [anon_sym_AMP_AMP] = ACTIONS(1998),
    [anon_sym_AMP] = ACTIONS(1996),
    [anon_sym_SEMI] = ACTIONS(1998),
    [anon_sym___extension__] = ACTIONS(1996),
    [anon_sym_typedef] = ACTIONS(1996),
    [anon_sym___device__] = ACTIONS(1996),
    [anon_sym___host__] = ACTIONS(1996),
    [anon_sym___global__] = ACTIONS(1996),
    [anon_sym___forceinline__] = ACTIONS(1996),
    [anon_sym___noinline__] = ACTIONS(1996),
    [anon_sym_virtual] = ACTIONS(1996),
    [anon_sym_extern] = ACTIONS(1996),
    [anon_sym___attribute__] = ACTIONS(1996),
    [anon_sym___attribute] = ACTIONS(1996),
    [anon_sym_COLON_COLON] = ACTIONS(1998),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1998),
    [anon_sym___declspec] = ACTIONS(1996),
    [anon_sym___based] = ACTIONS(1996),
    [anon_sym_RBRACE] = ACTIONS(1998),
    [anon_sym_signed] = ACTIONS(1996),
    [anon_sym_unsigned] = ACTIONS(1996),
    [anon_sym_long] = ACTIONS(1996),
    [anon_sym_short] = ACTIONS(1996),
    [anon_sym_LBRACK] = ACTIONS(1996),
    [anon_sym_static] = ACTIONS(1996),
    [anon_sym_register] = ACTIONS(1996),
    [anon_sym_inline] = ACTIONS(1996),
    [anon_sym___inline] = ACTIONS(1996),
    [anon_sym___inline__] = ACTIONS(1996),
    [anon_sym___forceinline] = ACTIONS(1996),
    [anon_sym_thread_local] = ACTIONS(1996),
    [anon_sym___thread] = ACTIONS(1996),
    [anon_sym_const] = ACTIONS(1996),
    [anon_sym_constexpr] = ACTIONS(1996),
    [anon_sym_volatile] = ACTIONS(1996),
    [anon_sym_restrict] = ACTIONS(1996),
    [anon_sym___restrict__] = ACTIONS(1996),
    [anon_sym__Atomic] = ACTIONS(1996),
    [anon_sym__Noreturn] = ACTIONS(1996),
    [anon_sym_noreturn] = ACTIONS(1996),
    [anon_sym__Nonnull] = ACTIONS(1996),
    [anon_sym_mutable] = ACTIONS(1996),
    [anon_sym_constinit] = ACTIONS(1996),
    [anon_sym_consteval] = ACTIONS(1996),
    [anon_sym___shared__] = ACTIONS(1996),
    [anon_sym___local__] = ACTIONS(1996),
    [anon_sym___constant__] = ACTIONS(1996),
    [anon_sym___managed__] = ACTIONS(1996),
    [anon_sym___grid_constant__] = ACTIONS(1996),
    [anon_sym_alignas] = ACTIONS(1996),
    [anon_sym__Alignas] = ACTIONS(1996),
    [sym_primitive_type] = ACTIONS(1996),
    [anon_sym_enum] = ACTIONS(1996),
    [anon_sym_class] = ACTIONS(1996),
    [anon_sym_struct] = ACTIONS(1996),
    [anon_sym_union] = ACTIONS(1996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1996),
    [anon_sym_decltype] = ACTIONS(1996),
    [anon_sym_explicit] = ACTIONS(1996),
    [anon_sym_typename] = ACTIONS(1996),
    [anon_sym_template] = ACTIONS(1996),
    [anon_sym_operator] = ACTIONS(1996),
    [anon_sym_friend] = ACTIONS(1996),
    [anon_sym_public] = ACTIONS(1996),
    [anon_sym_private] = ACTIONS(1996),
    [anon_sym_protected] = ACTIONS(1996),
    [anon_sym_using] = ACTIONS(1996),
    [anon_sym_static_assert] = ACTIONS(1996),
    [anon_sym_catch] = ACTIONS(5626),
    [anon_sym___launch_bounds__] = ACTIONS(1996),
  },
  [STATE(1877)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_RPAREN] = ACTIONS(5145),
    [aux_sym_preproc_if_token2] = ACTIONS(5145),
    [aux_sym_preproc_else_token1] = ACTIONS(5145),
    [aux_sym_preproc_elif_token1] = ACTIONS(5143),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5145),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5145),
    [anon_sym_SLASH] = ACTIONS(5143),
    [anon_sym_PERCENT] = ACTIONS(5145),
    [anon_sym_PIPE_PIPE] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_PIPE] = ACTIONS(5143),
    [anon_sym_CARET] = ACTIONS(5145),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_GT] = ACTIONS(5143),
    [anon_sym_GT_EQ] = ACTIONS(5145),
    [anon_sym_LT_EQ] = ACTIONS(5143),
    [anon_sym_LT] = ACTIONS(5143),
    [anon_sym_LT_LT] = ACTIONS(5143),
    [anon_sym_GT_GT] = ACTIONS(5145),
    [anon_sym_SEMI] = ACTIONS(5145),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_RBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_RBRACK] = ACTIONS(5145),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_COLON] = ACTIONS(5145),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_LT_EQ_GT] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5143),
    [anon_sym_and] = ACTIONS(5143),
    [anon_sym_bitor] = ACTIONS(5143),
    [anon_sym_xor] = ACTIONS(5143),
    [anon_sym_bitand] = ACTIONS(5143),
    [anon_sym_not_eq] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5143),
    [anon_sym_DOT_STAR] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [anon_sym_final] = ACTIONS(5143),
    [anon_sym_override] = ACTIONS(5143),
    [anon_sym_requires] = ACTIONS(5143),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5145),
  },
  [STATE(1878)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4366),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4366),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4366),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4366),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4366),
    [anon_sym___extension__] = ACTIONS(4368),
    [anon_sym___global__] = ACTIONS(4368),
    [anon_sym___attribute__] = ACTIONS(4368),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4368),
    [anon_sym_EQ] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4368),
    [anon_sym_volatile] = ACTIONS(4368),
    [anon_sym_restrict] = ACTIONS(4368),
    [anon_sym___restrict__] = ACTIONS(4368),
    [anon_sym__Atomic] = ACTIONS(4368),
    [anon_sym__Noreturn] = ACTIONS(4368),
    [anon_sym_noreturn] = ACTIONS(4368),
    [anon_sym__Nonnull] = ACTIONS(4368),
    [anon_sym_mutable] = ACTIONS(4368),
    [anon_sym_constinit] = ACTIONS(4368),
    [anon_sym_consteval] = ACTIONS(4368),
    [anon_sym___shared__] = ACTIONS(4368),
    [anon_sym___local__] = ACTIONS(4368),
    [anon_sym___constant__] = ACTIONS(4368),
    [anon_sym___managed__] = ACTIONS(4368),
    [anon_sym___grid_constant__] = ACTIONS(4368),
    [anon_sym_alignas] = ACTIONS(4368),
    [anon_sym__Alignas] = ACTIONS(4368),
    [anon_sym_COLON] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_STAR_EQ] = ACTIONS(4368),
    [anon_sym_SLASH_EQ] = ACTIONS(4368),
    [anon_sym_PERCENT_EQ] = ACTIONS(4368),
    [anon_sym_PLUS_EQ] = ACTIONS(4368),
    [anon_sym_DASH_EQ] = ACTIONS(4368),
    [anon_sym_LT_LT_EQ] = ACTIONS(4368),
    [anon_sym_GT_GT_EQ] = ACTIONS(4366),
    [anon_sym_AMP_EQ] = ACTIONS(4368),
    [anon_sym_CARET_EQ] = ACTIONS(4368),
    [anon_sym_PIPE_EQ] = ACTIONS(4368),
    [anon_sym_and_eq] = ACTIONS(4368),
    [anon_sym_or_eq] = ACTIONS(4368),
    [anon_sym_xor_eq] = ACTIONS(4368),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_bitor] = ACTIONS(4368),
    [anon_sym_xor] = ACTIONS(4366),
    [anon_sym_bitand] = ACTIONS(4368),
    [anon_sym_not_eq] = ACTIONS(4368),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4368),
    [anon_sym_decltype] = ACTIONS(4368),
    [anon_sym_final] = ACTIONS(4368),
    [anon_sym_override] = ACTIONS(4368),
    [anon_sym_GT2] = ACTIONS(4368),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
  },
  [STATE(1879)] = {
    [sym_catch_clause] = STATE(1882),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1882),
    [sym_identifier] = ACTIONS(1992),
    [aux_sym_preproc_def_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token1] = ACTIONS(1992),
    [aux_sym_preproc_if_token2] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1992),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1992),
    [sym_preproc_directive] = ACTIONS(1992),
    [anon_sym_LPAREN2] = ACTIONS(1994),
    [anon_sym_TILDE] = ACTIONS(1994),
    [anon_sym_STAR] = ACTIONS(1994),
    [anon_sym_AMP_AMP] = ACTIONS(1994),
    [anon_sym_AMP] = ACTIONS(1992),
    [anon_sym_SEMI] = ACTIONS(1994),
    [anon_sym___extension__] = ACTIONS(1992),
    [anon_sym_typedef] = ACTIONS(1992),
    [anon_sym___device__] = ACTIONS(1992),
    [anon_sym___host__] = ACTIONS(1992),
    [anon_sym___global__] = ACTIONS(1992),
    [anon_sym___forceinline__] = ACTIONS(1992),
    [anon_sym___noinline__] = ACTIONS(1992),
    [anon_sym_virtual] = ACTIONS(1992),
    [anon_sym_extern] = ACTIONS(1992),
    [anon_sym___attribute__] = ACTIONS(1992),
    [anon_sym___attribute] = ACTIONS(1992),
    [anon_sym_COLON_COLON] = ACTIONS(1994),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1994),
    [anon_sym___declspec] = ACTIONS(1992),
    [anon_sym___based] = ACTIONS(1992),
    [anon_sym_signed] = ACTIONS(1992),
    [anon_sym_unsigned] = ACTIONS(1992),
    [anon_sym_long] = ACTIONS(1992),
    [anon_sym_short] = ACTIONS(1992),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_static] = ACTIONS(1992),
    [anon_sym_register] = ACTIONS(1992),
    [anon_sym_inline] = ACTIONS(1992),
    [anon_sym___inline] = ACTIONS(1992),
    [anon_sym___inline__] = ACTIONS(1992),
    [anon_sym___forceinline] = ACTIONS(1992),
    [anon_sym_thread_local] = ACTIONS(1992),
    [anon_sym___thread] = ACTIONS(1992),
    [anon_sym_const] = ACTIONS(1992),
    [anon_sym_constexpr] = ACTIONS(1992),
    [anon_sym_volatile] = ACTIONS(1992),
    [anon_sym_restrict] = ACTIONS(1992),
    [anon_sym___restrict__] = ACTIONS(1992),
    [anon_sym__Atomic] = ACTIONS(1992),
    [anon_sym__Noreturn] = ACTIONS(1992),
    [anon_sym_noreturn] = ACTIONS(1992),
    [anon_sym__Nonnull] = ACTIONS(1992),
    [anon_sym_mutable] = ACTIONS(1992),
    [anon_sym_constinit] = ACTIONS(1992),
    [anon_sym_consteval] = ACTIONS(1992),
    [anon_sym___shared__] = ACTIONS(1992),
    [anon_sym___local__] = ACTIONS(1992),
    [anon_sym___constant__] = ACTIONS(1992),
    [anon_sym___managed__] = ACTIONS(1992),
    [anon_sym___grid_constant__] = ACTIONS(1992),
    [anon_sym_alignas] = ACTIONS(1992),
    [anon_sym__Alignas] = ACTIONS(1992),
    [sym_primitive_type] = ACTIONS(1992),
    [anon_sym_enum] = ACTIONS(1992),
    [anon_sym_class] = ACTIONS(1992),
    [anon_sym_struct] = ACTIONS(1992),
    [anon_sym_union] = ACTIONS(1992),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1992),
    [anon_sym_decltype] = ACTIONS(1992),
    [anon_sym_explicit] = ACTIONS(1992),
    [anon_sym_typename] = ACTIONS(1992),
    [anon_sym_template] = ACTIONS(1992),
    [anon_sym_operator] = ACTIONS(1992),
    [anon_sym_friend] = ACTIONS(1992),
    [anon_sym_public] = ACTIONS(1992),
    [anon_sym_private] = ACTIONS(1992),
    [anon_sym_protected] = ACTIONS(1992),
    [anon_sym_using] = ACTIONS(1992),
    [anon_sym_static_assert] = ACTIONS(1992),
    [anon_sym_catch] = ACTIONS(5632),
    [anon_sym___launch_bounds__] = ACTIONS(1992),
  },
  [STATE(1880)] = {
    [sym_catch_clause] = STATE(1882),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1882),
    [sym_identifier] = ACTIONS(1934),
    [aux_sym_preproc_def_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token2] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1934),
    [sym_preproc_directive] = ACTIONS(1934),
    [anon_sym_LPAREN2] = ACTIONS(1936),
    [anon_sym_TILDE] = ACTIONS(1936),
    [anon_sym_STAR] = ACTIONS(1936),
    [anon_sym_AMP_AMP] = ACTIONS(1936),
    [anon_sym_AMP] = ACTIONS(1934),
    [anon_sym_SEMI] = ACTIONS(1936),
    [anon_sym___extension__] = ACTIONS(1934),
    [anon_sym_typedef] = ACTIONS(1934),
    [anon_sym___device__] = ACTIONS(1934),
    [anon_sym___host__] = ACTIONS(1934),
    [anon_sym___global__] = ACTIONS(1934),
    [anon_sym___forceinline__] = ACTIONS(1934),
    [anon_sym___noinline__] = ACTIONS(1934),
    [anon_sym_virtual] = ACTIONS(1934),
    [anon_sym_extern] = ACTIONS(1934),
    [anon_sym___attribute__] = ACTIONS(1934),
    [anon_sym___attribute] = ACTIONS(1934),
    [anon_sym_COLON_COLON] = ACTIONS(1936),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1936),
    [anon_sym___declspec] = ACTIONS(1934),
    [anon_sym___based] = ACTIONS(1934),
    [anon_sym_signed] = ACTIONS(1934),
    [anon_sym_unsigned] = ACTIONS(1934),
    [anon_sym_long] = ACTIONS(1934),
    [anon_sym_short] = ACTIONS(1934),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [anon_sym_static] = ACTIONS(1934),
    [anon_sym_register] = ACTIONS(1934),
    [anon_sym_inline] = ACTIONS(1934),
    [anon_sym___inline] = ACTIONS(1934),
    [anon_sym___inline__] = ACTIONS(1934),
    [anon_sym___forceinline] = ACTIONS(1934),
    [anon_sym_thread_local] = ACTIONS(1934),
    [anon_sym___thread] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1934),
    [anon_sym_constexpr] = ACTIONS(1934),
    [anon_sym_volatile] = ACTIONS(1934),
    [anon_sym_restrict] = ACTIONS(1934),
    [anon_sym___restrict__] = ACTIONS(1934),
    [anon_sym__Atomic] = ACTIONS(1934),
    [anon_sym__Noreturn] = ACTIONS(1934),
    [anon_sym_noreturn] = ACTIONS(1934),
    [anon_sym__Nonnull] = ACTIONS(1934),
    [anon_sym_mutable] = ACTIONS(1934),
    [anon_sym_constinit] = ACTIONS(1934),
    [anon_sym_consteval] = ACTIONS(1934),
    [anon_sym___shared__] = ACTIONS(1934),
    [anon_sym___local__] = ACTIONS(1934),
    [anon_sym___constant__] = ACTIONS(1934),
    [anon_sym___managed__] = ACTIONS(1934),
    [anon_sym___grid_constant__] = ACTIONS(1934),
    [anon_sym_alignas] = ACTIONS(1934),
    [anon_sym__Alignas] = ACTIONS(1934),
    [sym_primitive_type] = ACTIONS(1934),
    [anon_sym_enum] = ACTIONS(1934),
    [anon_sym_class] = ACTIONS(1934),
    [anon_sym_struct] = ACTIONS(1934),
    [anon_sym_union] = ACTIONS(1934),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1934),
    [anon_sym_decltype] = ACTIONS(1934),
    [anon_sym_explicit] = ACTIONS(1934),
    [anon_sym_typename] = ACTIONS(1934),
    [anon_sym_template] = ACTIONS(1934),
    [anon_sym_operator] = ACTIONS(1934),
    [anon_sym_friend] = ACTIONS(1934),
    [anon_sym_public] = ACTIONS(1934),
    [anon_sym_private] = ACTIONS(1934),
    [anon_sym_protected] = ACTIONS(1934),
    [anon_sym_using] = ACTIONS(1934),
    [anon_sym_static_assert] = ACTIONS(1934),
    [anon_sym_catch] = ACTIONS(5632),
    [anon_sym___launch_bounds__] = ACTIONS(1934),
  },
  [STATE(1881)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4330),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4330),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4330),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4330),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4330),
    [anon_sym___extension__] = ACTIONS(4332),
    [anon_sym___global__] = ACTIONS(4332),
    [anon_sym___attribute__] = ACTIONS(4332),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4332),
    [anon_sym_EQ] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4332),
    [anon_sym_volatile] = ACTIONS(4332),
    [anon_sym_restrict] = ACTIONS(4332),
    [anon_sym___restrict__] = ACTIONS(4332),
    [anon_sym__Atomic] = ACTIONS(4332),
    [anon_sym__Noreturn] = ACTIONS(4332),
    [anon_sym_noreturn] = ACTIONS(4332),
    [anon_sym__Nonnull] = ACTIONS(4332),
    [anon_sym_mutable] = ACTIONS(4332),
    [anon_sym_constinit] = ACTIONS(4332),
    [anon_sym_consteval] = ACTIONS(4332),
    [anon_sym___shared__] = ACTIONS(4332),
    [anon_sym___local__] = ACTIONS(4332),
    [anon_sym___constant__] = ACTIONS(4332),
    [anon_sym___managed__] = ACTIONS(4332),
    [anon_sym___grid_constant__] = ACTIONS(4332),
    [anon_sym_alignas] = ACTIONS(4332),
    [anon_sym__Alignas] = ACTIONS(4332),
    [anon_sym_COLON] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_STAR_EQ] = ACTIONS(4332),
    [anon_sym_SLASH_EQ] = ACTIONS(4332),
    [anon_sym_PERCENT_EQ] = ACTIONS(4332),
    [anon_sym_PLUS_EQ] = ACTIONS(4332),
    [anon_sym_DASH_EQ] = ACTIONS(4332),
    [anon_sym_LT_LT_EQ] = ACTIONS(4332),
    [anon_sym_GT_GT_EQ] = ACTIONS(4330),
    [anon_sym_AMP_EQ] = ACTIONS(4332),
    [anon_sym_CARET_EQ] = ACTIONS(4332),
    [anon_sym_PIPE_EQ] = ACTIONS(4332),
    [anon_sym_and_eq] = ACTIONS(4332),
    [anon_sym_or_eq] = ACTIONS(4332),
    [anon_sym_xor_eq] = ACTIONS(4332),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_bitor] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4330),
    [anon_sym_bitand] = ACTIONS(4332),
    [anon_sym_not_eq] = ACTIONS(4332),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4332),
    [anon_sym_decltype] = ACTIONS(4332),
    [anon_sym_final] = ACTIONS(4332),
    [anon_sym_override] = ACTIONS(4332),
    [anon_sym_GT2] = ACTIONS(4332),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
  },
  [STATE(1882)] = {
    [sym_catch_clause] = STATE(1882),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1882),
    [sym_identifier] = ACTIONS(1940),
    [aux_sym_preproc_def_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token1] = ACTIONS(1940),
    [aux_sym_preproc_if_token2] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1940),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1940),
    [sym_preproc_directive] = ACTIONS(1940),
    [anon_sym_LPAREN2] = ACTIONS(1942),
    [anon_sym_TILDE] = ACTIONS(1942),
    [anon_sym_STAR] = ACTIONS(1942),
    [anon_sym_AMP_AMP] = ACTIONS(1942),
    [anon_sym_AMP] = ACTIONS(1940),
    [anon_sym_SEMI] = ACTIONS(1942),
    [anon_sym___extension__] = ACTIONS(1940),
    [anon_sym_typedef] = ACTIONS(1940),
    [anon_sym___device__] = ACTIONS(1940),
    [anon_sym___host__] = ACTIONS(1940),
    [anon_sym___global__] = ACTIONS(1940),
    [anon_sym___forceinline__] = ACTIONS(1940),
    [anon_sym___noinline__] = ACTIONS(1940),
    [anon_sym_virtual] = ACTIONS(1940),
    [anon_sym_extern] = ACTIONS(1940),
    [anon_sym___attribute__] = ACTIONS(1940),
    [anon_sym___attribute] = ACTIONS(1940),
    [anon_sym_COLON_COLON] = ACTIONS(1942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1942),
    [anon_sym___declspec] = ACTIONS(1940),
    [anon_sym___based] = ACTIONS(1940),
    [anon_sym_signed] = ACTIONS(1940),
    [anon_sym_unsigned] = ACTIONS(1940),
    [anon_sym_long] = ACTIONS(1940),
    [anon_sym_short] = ACTIONS(1940),
    [anon_sym_LBRACK] = ACTIONS(1940),
    [anon_sym_static] = ACTIONS(1940),
    [anon_sym_register] = ACTIONS(1940),
    [anon_sym_inline] = ACTIONS(1940),
    [anon_sym___inline] = ACTIONS(1940),
    [anon_sym___inline__] = ACTIONS(1940),
    [anon_sym___forceinline] = ACTIONS(1940),
    [anon_sym_thread_local] = ACTIONS(1940),
    [anon_sym___thread] = ACTIONS(1940),
    [anon_sym_const] = ACTIONS(1940),
    [anon_sym_constexpr] = ACTIONS(1940),
    [anon_sym_volatile] = ACTIONS(1940),
    [anon_sym_restrict] = ACTIONS(1940),
    [anon_sym___restrict__] = ACTIONS(1940),
    [anon_sym__Atomic] = ACTIONS(1940),
    [anon_sym__Noreturn] = ACTIONS(1940),
    [anon_sym_noreturn] = ACTIONS(1940),
    [anon_sym__Nonnull] = ACTIONS(1940),
    [anon_sym_mutable] = ACTIONS(1940),
    [anon_sym_constinit] = ACTIONS(1940),
    [anon_sym_consteval] = ACTIONS(1940),
    [anon_sym___shared__] = ACTIONS(1940),
    [anon_sym___local__] = ACTIONS(1940),
    [anon_sym___constant__] = ACTIONS(1940),
    [anon_sym___managed__] = ACTIONS(1940),
    [anon_sym___grid_constant__] = ACTIONS(1940),
    [anon_sym_alignas] = ACTIONS(1940),
    [anon_sym__Alignas] = ACTIONS(1940),
    [sym_primitive_type] = ACTIONS(1940),
    [anon_sym_enum] = ACTIONS(1940),
    [anon_sym_class] = ACTIONS(1940),
    [anon_sym_struct] = ACTIONS(1940),
    [anon_sym_union] = ACTIONS(1940),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1940),
    [anon_sym_decltype] = ACTIONS(1940),
    [anon_sym_explicit] = ACTIONS(1940),
    [anon_sym_typename] = ACTIONS(1940),
    [anon_sym_template] = ACTIONS(1940),
    [anon_sym_operator] = ACTIONS(1940),
    [anon_sym_friend] = ACTIONS(1940),
    [anon_sym_public] = ACTIONS(1940),
    [anon_sym_private] = ACTIONS(1940),
    [anon_sym_protected] = ACTIONS(1940),
    [anon_sym_using] = ACTIONS(1940),
    [anon_sym_static_assert] = ACTIONS(1940),
    [anon_sym_catch] = ACTIONS(5634),
    [anon_sym___launch_bounds__] = ACTIONS(1940),
  },
  [STATE(1883)] = {
    [sym_catch_clause] = STATE(1868),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1868),
    [sym_identifier] = ACTIONS(1934),
    [aux_sym_preproc_def_token1] = ACTIONS(1934),
    [aux_sym_preproc_if_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1934),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1934),
    [sym_preproc_directive] = ACTIONS(1934),
    [anon_sym_LPAREN2] = ACTIONS(1936),
    [anon_sym_TILDE] = ACTIONS(1936),
    [anon_sym_STAR] = ACTIONS(1936),
    [anon_sym_AMP_AMP] = ACTIONS(1936),
    [anon_sym_AMP] = ACTIONS(1934),
    [anon_sym_SEMI] = ACTIONS(1936),
    [anon_sym___extension__] = ACTIONS(1934),
    [anon_sym_typedef] = ACTIONS(1934),
    [anon_sym___device__] = ACTIONS(1934),
    [anon_sym___host__] = ACTIONS(1934),
    [anon_sym___global__] = ACTIONS(1934),
    [anon_sym___forceinline__] = ACTIONS(1934),
    [anon_sym___noinline__] = ACTIONS(1934),
    [anon_sym_virtual] = ACTIONS(1934),
    [anon_sym_extern] = ACTIONS(1934),
    [anon_sym___attribute__] = ACTIONS(1934),
    [anon_sym___attribute] = ACTIONS(1934),
    [anon_sym_COLON_COLON] = ACTIONS(1936),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1936),
    [anon_sym___declspec] = ACTIONS(1934),
    [anon_sym___based] = ACTIONS(1934),
    [anon_sym_RBRACE] = ACTIONS(1936),
    [anon_sym_signed] = ACTIONS(1934),
    [anon_sym_unsigned] = ACTIONS(1934),
    [anon_sym_long] = ACTIONS(1934),
    [anon_sym_short] = ACTIONS(1934),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [anon_sym_static] = ACTIONS(1934),
    [anon_sym_register] = ACTIONS(1934),
    [anon_sym_inline] = ACTIONS(1934),
    [anon_sym___inline] = ACTIONS(1934),
    [anon_sym___inline__] = ACTIONS(1934),
    [anon_sym___forceinline] = ACTIONS(1934),
    [anon_sym_thread_local] = ACTIONS(1934),
    [anon_sym___thread] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1934),
    [anon_sym_constexpr] = ACTIONS(1934),
    [anon_sym_volatile] = ACTIONS(1934),
    [anon_sym_restrict] = ACTIONS(1934),
    [anon_sym___restrict__] = ACTIONS(1934),
    [anon_sym__Atomic] = ACTIONS(1934),
    [anon_sym__Noreturn] = ACTIONS(1934),
    [anon_sym_noreturn] = ACTIONS(1934),
    [anon_sym__Nonnull] = ACTIONS(1934),
    [anon_sym_mutable] = ACTIONS(1934),
    [anon_sym_constinit] = ACTIONS(1934),
    [anon_sym_consteval] = ACTIONS(1934),
    [anon_sym___shared__] = ACTIONS(1934),
    [anon_sym___local__] = ACTIONS(1934),
    [anon_sym___constant__] = ACTIONS(1934),
    [anon_sym___managed__] = ACTIONS(1934),
    [anon_sym___grid_constant__] = ACTIONS(1934),
    [anon_sym_alignas] = ACTIONS(1934),
    [anon_sym__Alignas] = ACTIONS(1934),
    [sym_primitive_type] = ACTIONS(1934),
    [anon_sym_enum] = ACTIONS(1934),
    [anon_sym_class] = ACTIONS(1934),
    [anon_sym_struct] = ACTIONS(1934),
    [anon_sym_union] = ACTIONS(1934),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1934),
    [anon_sym_decltype] = ACTIONS(1934),
    [anon_sym_explicit] = ACTIONS(1934),
    [anon_sym_typename] = ACTIONS(1934),
    [anon_sym_template] = ACTIONS(1934),
    [anon_sym_operator] = ACTIONS(1934),
    [anon_sym_friend] = ACTIONS(1934),
    [anon_sym_public] = ACTIONS(1934),
    [anon_sym_private] = ACTIONS(1934),
    [anon_sym_protected] = ACTIONS(1934),
    [anon_sym_using] = ACTIONS(1934),
    [anon_sym_static_assert] = ACTIONS(1934),
    [anon_sym_catch] = ACTIONS(5626),
    [anon_sym___launch_bounds__] = ACTIONS(1934),
  },
  [STATE(1884)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4396),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4396),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4396),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4396),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4396),
    [anon_sym___extension__] = ACTIONS(4398),
    [anon_sym___global__] = ACTIONS(4398),
    [anon_sym___attribute__] = ACTIONS(4398),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4398),
    [anon_sym_EQ] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4398),
    [anon_sym_volatile] = ACTIONS(4398),
    [anon_sym_restrict] = ACTIONS(4398),
    [anon_sym___restrict__] = ACTIONS(4398),
    [anon_sym__Atomic] = ACTIONS(4398),
    [anon_sym__Noreturn] = ACTIONS(4398),
    [anon_sym_noreturn] = ACTIONS(4398),
    [anon_sym__Nonnull] = ACTIONS(4398),
    [anon_sym_mutable] = ACTIONS(4398),
    [anon_sym_constinit] = ACTIONS(4398),
    [anon_sym_consteval] = ACTIONS(4398),
    [anon_sym___shared__] = ACTIONS(4398),
    [anon_sym___local__] = ACTIONS(4398),
    [anon_sym___constant__] = ACTIONS(4398),
    [anon_sym___managed__] = ACTIONS(4398),
    [anon_sym___grid_constant__] = ACTIONS(4398),
    [anon_sym_alignas] = ACTIONS(4398),
    [anon_sym__Alignas] = ACTIONS(4398),
    [anon_sym_COLON] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_STAR_EQ] = ACTIONS(4398),
    [anon_sym_SLASH_EQ] = ACTIONS(4398),
    [anon_sym_PERCENT_EQ] = ACTIONS(4398),
    [anon_sym_PLUS_EQ] = ACTIONS(4398),
    [anon_sym_DASH_EQ] = ACTIONS(4398),
    [anon_sym_LT_LT_EQ] = ACTIONS(4398),
    [anon_sym_GT_GT_EQ] = ACTIONS(4396),
    [anon_sym_AMP_EQ] = ACTIONS(4398),
    [anon_sym_CARET_EQ] = ACTIONS(4398),
    [anon_sym_PIPE_EQ] = ACTIONS(4398),
    [anon_sym_and_eq] = ACTIONS(4398),
    [anon_sym_or_eq] = ACTIONS(4398),
    [anon_sym_xor_eq] = ACTIONS(4398),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_bitor] = ACTIONS(4398),
    [anon_sym_xor] = ACTIONS(4396),
    [anon_sym_bitand] = ACTIONS(4398),
    [anon_sym_not_eq] = ACTIONS(4398),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4398),
    [anon_sym_decltype] = ACTIONS(4398),
    [anon_sym_final] = ACTIONS(4398),
    [anon_sym_override] = ACTIONS(4398),
    [anon_sym_GT2] = ACTIONS(4398),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
  },
  [STATE(1885)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4356),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4356),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4356),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4356),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4356),
    [anon_sym___extension__] = ACTIONS(4358),
    [anon_sym___global__] = ACTIONS(4358),
    [anon_sym___attribute__] = ACTIONS(4358),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4358),
    [anon_sym_EQ] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4358),
    [anon_sym_volatile] = ACTIONS(4358),
    [anon_sym_restrict] = ACTIONS(4358),
    [anon_sym___restrict__] = ACTIONS(4358),
    [anon_sym__Atomic] = ACTIONS(4358),
    [anon_sym__Noreturn] = ACTIONS(4358),
    [anon_sym_noreturn] = ACTIONS(4358),
    [anon_sym__Nonnull] = ACTIONS(4358),
    [anon_sym_mutable] = ACTIONS(4358),
    [anon_sym_constinit] = ACTIONS(4358),
    [anon_sym_consteval] = ACTIONS(4358),
    [anon_sym___shared__] = ACTIONS(4358),
    [anon_sym___local__] = ACTIONS(4358),
    [anon_sym___constant__] = ACTIONS(4358),
    [anon_sym___managed__] = ACTIONS(4358),
    [anon_sym___grid_constant__] = ACTIONS(4358),
    [anon_sym_alignas] = ACTIONS(4358),
    [anon_sym__Alignas] = ACTIONS(4358),
    [anon_sym_COLON] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_STAR_EQ] = ACTIONS(4358),
    [anon_sym_SLASH_EQ] = ACTIONS(4358),
    [anon_sym_PERCENT_EQ] = ACTIONS(4358),
    [anon_sym_PLUS_EQ] = ACTIONS(4358),
    [anon_sym_DASH_EQ] = ACTIONS(4358),
    [anon_sym_LT_LT_EQ] = ACTIONS(4358),
    [anon_sym_GT_GT_EQ] = ACTIONS(4356),
    [anon_sym_AMP_EQ] = ACTIONS(4358),
    [anon_sym_CARET_EQ] = ACTIONS(4358),
    [anon_sym_PIPE_EQ] = ACTIONS(4358),
    [anon_sym_and_eq] = ACTIONS(4358),
    [anon_sym_or_eq] = ACTIONS(4358),
    [anon_sym_xor_eq] = ACTIONS(4358),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_bitor] = ACTIONS(4358),
    [anon_sym_xor] = ACTIONS(4356),
    [anon_sym_bitand] = ACTIONS(4358),
    [anon_sym_not_eq] = ACTIONS(4358),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4358),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4358),
    [anon_sym_decltype] = ACTIONS(4358),
    [anon_sym_final] = ACTIONS(4358),
    [anon_sym_override] = ACTIONS(4358),
    [anon_sym_GT2] = ACTIONS(4358),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
  },
  [STATE(1886)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_RPAREN] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1969),
    [anon_sym_PIPE_PIPE] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1959),
    [anon_sym_BANG_EQ] = ACTIONS(1959),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1959),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(1959),
    [anon_sym_STAR_EQ] = ACTIONS(1959),
    [anon_sym_SLASH_EQ] = ACTIONS(1959),
    [anon_sym_PERCENT_EQ] = ACTIONS(1959),
    [anon_sym_PLUS_EQ] = ACTIONS(1959),
    [anon_sym_DASH_EQ] = ACTIONS(1959),
    [anon_sym_LT_LT_EQ] = ACTIONS(1959),
    [anon_sym_GT_GT_EQ] = ACTIONS(1959),
    [anon_sym_AMP_EQ] = ACTIONS(1959),
    [anon_sym_CARET_EQ] = ACTIONS(1959),
    [anon_sym_PIPE_EQ] = ACTIONS(1959),
    [anon_sym_LT_EQ_GT] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1959),
    [anon_sym_DASH_GT] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1959),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1959),
  },
  [STATE(1887)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5872),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1888)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5550),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1889)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5557),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1890)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5554),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1891)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5548),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1892)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5549),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1893)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5545),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1894)] = {
    [sym__declaration_modifiers] = STATE(1909),
    [sym__declaration_specifiers] = STATE(5555),
    [sym_attribute_specifier] = STATE(1909),
    [sym_attribute_declaration] = STATE(1909),
    [sym_ms_declspec_modifier] = STATE(1909),
    [sym_storage_class_specifier] = STATE(1909),
    [sym_type_qualifier] = STATE(1909),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2194),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(1909),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1909),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(1245),
    [anon_sym___host__] = ACTIONS(1245),
    [anon_sym___global__] = ACTIONS(1245),
    [anon_sym___forceinline__] = ACTIONS(1245),
    [anon_sym___noinline__] = ACTIONS(1245),
    [anon_sym_virtual] = ACTIONS(1245),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1895)] = {
    [sym_type_qualifier] = STATE(1895),
    [sym_alignas_qualifier] = STATE(2171),
    [aux_sym_array_declarator_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(5637),
    [anon_sym_LPAREN2] = ACTIONS(5639),
    [anon_sym_BANG] = ACTIONS(5639),
    [anon_sym_TILDE] = ACTIONS(5639),
    [anon_sym_DASH] = ACTIONS(5637),
    [anon_sym_PLUS] = ACTIONS(5637),
    [anon_sym_STAR] = ACTIONS(5639),
    [anon_sym_AMP] = ACTIONS(5639),
    [anon_sym___extension__] = ACTIONS(5641),
    [anon_sym___global__] = ACTIONS(5641),
    [anon_sym_COLON_COLON] = ACTIONS(5639),
    [anon_sym_LBRACK] = ACTIONS(5639),
    [anon_sym_static] = ACTIONS(5644),
    [anon_sym_RBRACK] = ACTIONS(5639),
    [anon_sym_const] = ACTIONS(5641),
    [anon_sym_constexpr] = ACTIONS(5641),
    [anon_sym_volatile] = ACTIONS(5641),
    [anon_sym_restrict] = ACTIONS(5641),
    [anon_sym___restrict__] = ACTIONS(5641),
    [anon_sym__Atomic] = ACTIONS(5641),
    [anon_sym__Noreturn] = ACTIONS(5641),
    [anon_sym_noreturn] = ACTIONS(5641),
    [anon_sym__Nonnull] = ACTIONS(5641),
    [anon_sym_mutable] = ACTIONS(5641),
    [anon_sym_constinit] = ACTIONS(5641),
    [anon_sym_consteval] = ACTIONS(5641),
    [anon_sym___shared__] = ACTIONS(5641),
    [anon_sym___local__] = ACTIONS(5641),
    [anon_sym___constant__] = ACTIONS(5641),
    [anon_sym___managed__] = ACTIONS(5641),
    [anon_sym___grid_constant__] = ACTIONS(5641),
    [anon_sym_alignas] = ACTIONS(5647),
    [anon_sym__Alignas] = ACTIONS(5647),
    [sym_primitive_type] = ACTIONS(5637),
    [anon_sym_not] = ACTIONS(5637),
    [anon_sym_compl] = ACTIONS(5637),
    [anon_sym_DASH_DASH] = ACTIONS(5639),
    [anon_sym_PLUS_PLUS] = ACTIONS(5639),
    [anon_sym_sizeof] = ACTIONS(5637),
    [anon_sym___alignof__] = ACTIONS(5637),
    [anon_sym___alignof] = ACTIONS(5637),
    [anon_sym__alignof] = ACTIONS(5637),
    [anon_sym_alignof] = ACTIONS(5637),
    [anon_sym__Alignof] = ACTIONS(5637),
    [anon_sym_offsetof] = ACTIONS(5637),
    [anon_sym__Generic] = ACTIONS(5637),
    [anon_sym_asm] = ACTIONS(5637),
    [anon_sym___asm__] = ACTIONS(5637),
    [anon_sym___asm] = ACTIONS(5637),
    [sym_number_literal] = ACTIONS(5639),
    [anon_sym_L_SQUOTE] = ACTIONS(5639),
    [anon_sym_u_SQUOTE] = ACTIONS(5639),
    [anon_sym_U_SQUOTE] = ACTIONS(5639),
    [anon_sym_u8_SQUOTE] = ACTIONS(5639),
    [anon_sym_SQUOTE] = ACTIONS(5639),
    [anon_sym_L_DQUOTE] = ACTIONS(5639),
    [anon_sym_u_DQUOTE] = ACTIONS(5639),
    [anon_sym_U_DQUOTE] = ACTIONS(5639),
    [anon_sym_u8_DQUOTE] = ACTIONS(5639),
    [anon_sym_DQUOTE] = ACTIONS(5639),
    [sym_true] = ACTIONS(5637),
    [sym_false] = ACTIONS(5637),
    [anon_sym_NULL] = ACTIONS(5637),
    [anon_sym_nullptr] = ACTIONS(5637),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5637),
    [anon_sym_template] = ACTIONS(5637),
    [anon_sym_delete] = ACTIONS(5637),
    [anon_sym_R_DQUOTE] = ACTIONS(5639),
    [anon_sym_LR_DQUOTE] = ACTIONS(5639),
    [anon_sym_uR_DQUOTE] = ACTIONS(5639),
    [anon_sym_UR_DQUOTE] = ACTIONS(5639),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5639),
    [anon_sym_co_await] = ACTIONS(5637),
    [anon_sym_new] = ACTIONS(5637),
    [anon_sym_requires] = ACTIONS(5637),
    [sym_this] = ACTIONS(5637),
  },
  [STATE(1896)] = {
    [sym_identifier] = ACTIONS(1928),
    [aux_sym_preproc_def_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1928),
    [sym_preproc_directive] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_AMP_AMP] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1928),
    [anon_sym_SEMI] = ACTIONS(1926),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym_typedef] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym___based] = ACTIONS(1928),
    [anon_sym_RBRACE] = ACTIONS(1926),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_explicit] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_operator] = ACTIONS(1928),
    [anon_sym_friend] = ACTIONS(1928),
    [anon_sym_public] = ACTIONS(1928),
    [anon_sym_private] = ACTIONS(1928),
    [anon_sym_protected] = ACTIONS(1928),
    [anon_sym_using] = ACTIONS(1928),
    [anon_sym_static_assert] = ACTIONS(1928),
    [anon_sym_catch] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(1897)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_RBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1898)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1899)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(5503),
    [anon_sym___attribute] = ACTIONS(5503),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_RBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1900)] = {
    [sym_template_argument_list] = STATE(1905),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4514),
    [anon_sym_COMMA] = ACTIONS(4514),
    [anon_sym_RPAREN] = ACTIONS(4516),
    [anon_sym_LPAREN2] = ACTIONS(4516),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4523),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4516),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4523),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4514),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4675),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym___extension__] = ACTIONS(4519),
    [anon_sym___global__] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4514),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4523),
    [anon_sym_EQ] = ACTIONS(4521),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4519),
    [anon_sym_volatile] = ACTIONS(4519),
    [anon_sym_restrict] = ACTIONS(4519),
    [anon_sym___restrict__] = ACTIONS(4519),
    [anon_sym__Atomic] = ACTIONS(4519),
    [anon_sym__Noreturn] = ACTIONS(4519),
    [anon_sym_noreturn] = ACTIONS(4519),
    [anon_sym__Nonnull] = ACTIONS(4519),
    [anon_sym_mutable] = ACTIONS(4519),
    [anon_sym_constinit] = ACTIONS(4519),
    [anon_sym_consteval] = ACTIONS(4519),
    [anon_sym___shared__] = ACTIONS(4519),
    [anon_sym___local__] = ACTIONS(4519),
    [anon_sym___constant__] = ACTIONS(4519),
    [anon_sym___managed__] = ACTIONS(4519),
    [anon_sym___grid_constant__] = ACTIONS(4519),
    [anon_sym_alignas] = ACTIONS(4519),
    [anon_sym__Alignas] = ACTIONS(4519),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4514),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4514),
    [anon_sym_or_eq] = ACTIONS(4514),
    [anon_sym_xor_eq] = ACTIONS(4514),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4514),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4514),
    [anon_sym_not_eq] = ACTIONS(4514),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4519),
    [anon_sym_decltype] = ACTIONS(4519),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4514),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
  },
  [STATE(1901)] = {
    [sym_identifier] = ACTIONS(2006),
    [aux_sym_preproc_def_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2006),
    [sym_preproc_directive] = ACTIONS(2006),
    [anon_sym_LPAREN2] = ACTIONS(2008),
    [anon_sym_TILDE] = ACTIONS(2008),
    [anon_sym_STAR] = ACTIONS(2008),
    [anon_sym_AMP_AMP] = ACTIONS(2008),
    [anon_sym_AMP] = ACTIONS(2006),
    [anon_sym_SEMI] = ACTIONS(2008),
    [anon_sym___extension__] = ACTIONS(2006),
    [anon_sym_typedef] = ACTIONS(2006),
    [anon_sym___device__] = ACTIONS(2006),
    [anon_sym___host__] = ACTIONS(2006),
    [anon_sym___global__] = ACTIONS(2006),
    [anon_sym___forceinline__] = ACTIONS(2006),
    [anon_sym___noinline__] = ACTIONS(2006),
    [anon_sym_virtual] = ACTIONS(2006),
    [anon_sym_extern] = ACTIONS(2006),
    [anon_sym___attribute__] = ACTIONS(2006),
    [anon_sym___attribute] = ACTIONS(2006),
    [anon_sym_COLON_COLON] = ACTIONS(2008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2008),
    [anon_sym___declspec] = ACTIONS(2006),
    [anon_sym___based] = ACTIONS(2006),
    [anon_sym_RBRACE] = ACTIONS(2008),
    [anon_sym_signed] = ACTIONS(2006),
    [anon_sym_unsigned] = ACTIONS(2006),
    [anon_sym_long] = ACTIONS(2006),
    [anon_sym_short] = ACTIONS(2006),
    [anon_sym_LBRACK] = ACTIONS(2006),
    [anon_sym_static] = ACTIONS(2006),
    [anon_sym_register] = ACTIONS(2006),
    [anon_sym_inline] = ACTIONS(2006),
    [anon_sym___inline] = ACTIONS(2006),
    [anon_sym___inline__] = ACTIONS(2006),
    [anon_sym___forceinline] = ACTIONS(2006),
    [anon_sym_thread_local] = ACTIONS(2006),
    [anon_sym___thread] = ACTIONS(2006),
    [anon_sym_const] = ACTIONS(2006),
    [anon_sym_constexpr] = ACTIONS(2006),
    [anon_sym_volatile] = ACTIONS(2006),
    [anon_sym_restrict] = ACTIONS(2006),
    [anon_sym___restrict__] = ACTIONS(2006),
    [anon_sym__Atomic] = ACTIONS(2006),
    [anon_sym__Noreturn] = ACTIONS(2006),
    [anon_sym_noreturn] = ACTIONS(2006),
    [anon_sym__Nonnull] = ACTIONS(2006),
    [anon_sym_mutable] = ACTIONS(2006),
    [anon_sym_constinit] = ACTIONS(2006),
    [anon_sym_consteval] = ACTIONS(2006),
    [anon_sym___shared__] = ACTIONS(2006),
    [anon_sym___local__] = ACTIONS(2006),
    [anon_sym___constant__] = ACTIONS(2006),
    [anon_sym___managed__] = ACTIONS(2006),
    [anon_sym___grid_constant__] = ACTIONS(2006),
    [anon_sym_alignas] = ACTIONS(2006),
    [anon_sym__Alignas] = ACTIONS(2006),
    [sym_primitive_type] = ACTIONS(2006),
    [anon_sym_enum] = ACTIONS(2006),
    [anon_sym_class] = ACTIONS(2006),
    [anon_sym_struct] = ACTIONS(2006),
    [anon_sym_union] = ACTIONS(2006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2006),
    [anon_sym_decltype] = ACTIONS(2006),
    [anon_sym_explicit] = ACTIONS(2006),
    [anon_sym_typename] = ACTIONS(2006),
    [anon_sym_template] = ACTIONS(2006),
    [anon_sym_operator] = ACTIONS(2006),
    [anon_sym_friend] = ACTIONS(2006),
    [anon_sym_public] = ACTIONS(2006),
    [anon_sym_private] = ACTIONS(2006),
    [anon_sym_protected] = ACTIONS(2006),
    [anon_sym_using] = ACTIONS(2006),
    [anon_sym_static_assert] = ACTIONS(2006),
    [anon_sym_catch] = ACTIONS(2006),
    [anon_sym___launch_bounds__] = ACTIONS(2006),
  },
  [STATE(1902)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_TILDE] = ACTIONS(5135),
    [anon_sym_STAR] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___device__] = ACTIONS(5133),
    [anon_sym___host__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___forceinline__] = ACTIONS(5133),
    [anon_sym___noinline__] = ACTIONS(5133),
    [anon_sym_virtual] = ACTIONS(5133),
    [anon_sym_extern] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_COLON_COLON] = ACTIONS(5135),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5135),
    [anon_sym___declspec] = ACTIONS(5133),
    [anon_sym___based] = ACTIONS(5133),
    [anon_sym___cdecl] = ACTIONS(5133),
    [anon_sym___clrcall] = ACTIONS(5133),
    [anon_sym___stdcall] = ACTIONS(5133),
    [anon_sym___fastcall] = ACTIONS(5133),
    [anon_sym___thiscall] = ACTIONS(5133),
    [anon_sym___vectorcall] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(5650),
    [anon_sym_unsigned] = ACTIONS(5650),
    [anon_sym_long] = ACTIONS(5650),
    [anon_sym_short] = ACTIONS(5650),
    [anon_sym_LBRACK] = ACTIONS(5133),
    [anon_sym_static] = ACTIONS(5133),
    [anon_sym_EQ] = ACTIONS(5135),
    [anon_sym_register] = ACTIONS(5133),
    [anon_sym_inline] = ACTIONS(5133),
    [anon_sym___inline] = ACTIONS(5133),
    [anon_sym___inline__] = ACTIONS(5133),
    [anon_sym___forceinline] = ACTIONS(5133),
    [anon_sym_thread_local] = ACTIONS(5133),
    [anon_sym___thread] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_asm] = ACTIONS(5133),
    [anon_sym___asm__] = ACTIONS(5133),
    [anon_sym___asm] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_final] = ACTIONS(5133),
    [anon_sym_override] = ACTIONS(5133),
    [anon_sym_template] = ACTIONS(5133),
    [anon_sym_GT2] = ACTIONS(5135),
    [anon_sym_operator] = ACTIONS(5133),
    [anon_sym_try] = ACTIONS(5133),
    [anon_sym_requires] = ACTIONS(5133),
    [anon_sym___launch_bounds__] = ACTIONS(5133),
  },
  [STATE(1903)] = {
    [sym__declaration_modifiers] = STATE(2730),
    [sym_attribute_specifier] = STATE(2730),
    [sym_attribute_declaration] = STATE(2730),
    [sym_ms_declspec_modifier] = STATE(2730),
    [sym_storage_class_specifier] = STATE(2730),
    [sym_type_qualifier] = STATE(2730),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2198),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(2730),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2730),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(5653),
    [anon_sym___host__] = ACTIONS(5653),
    [anon_sym___global__] = ACTIONS(5653),
    [anon_sym___forceinline__] = ACTIONS(5653),
    [anon_sym___noinline__] = ACTIONS(5653),
    [anon_sym_virtual] = ACTIONS(5653),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2278),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2282),
    [anon_sym_union] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2286),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1904)] = {
    [sym_identifier] = ACTIONS(2006),
    [aux_sym_preproc_def_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token1] = ACTIONS(2006),
    [aux_sym_preproc_if_token2] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2006),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2006),
    [sym_preproc_directive] = ACTIONS(2006),
    [anon_sym_LPAREN2] = ACTIONS(2008),
    [anon_sym_TILDE] = ACTIONS(2008),
    [anon_sym_STAR] = ACTIONS(2008),
    [anon_sym_AMP_AMP] = ACTIONS(2008),
    [anon_sym_AMP] = ACTIONS(2006),
    [anon_sym_SEMI] = ACTIONS(2008),
    [anon_sym___extension__] = ACTIONS(2006),
    [anon_sym_typedef] = ACTIONS(2006),
    [anon_sym___device__] = ACTIONS(2006),
    [anon_sym___host__] = ACTIONS(2006),
    [anon_sym___global__] = ACTIONS(2006),
    [anon_sym___forceinline__] = ACTIONS(2006),
    [anon_sym___noinline__] = ACTIONS(2006),
    [anon_sym_virtual] = ACTIONS(2006),
    [anon_sym_extern] = ACTIONS(2006),
    [anon_sym___attribute__] = ACTIONS(2006),
    [anon_sym___attribute] = ACTIONS(2006),
    [anon_sym_COLON_COLON] = ACTIONS(2008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2008),
    [anon_sym___declspec] = ACTIONS(2006),
    [anon_sym___based] = ACTIONS(2006),
    [anon_sym_signed] = ACTIONS(2006),
    [anon_sym_unsigned] = ACTIONS(2006),
    [anon_sym_long] = ACTIONS(2006),
    [anon_sym_short] = ACTIONS(2006),
    [anon_sym_LBRACK] = ACTIONS(2006),
    [anon_sym_static] = ACTIONS(2006),
    [anon_sym_register] = ACTIONS(2006),
    [anon_sym_inline] = ACTIONS(2006),
    [anon_sym___inline] = ACTIONS(2006),
    [anon_sym___inline__] = ACTIONS(2006),
    [anon_sym___forceinline] = ACTIONS(2006),
    [anon_sym_thread_local] = ACTIONS(2006),
    [anon_sym___thread] = ACTIONS(2006),
    [anon_sym_const] = ACTIONS(2006),
    [anon_sym_constexpr] = ACTIONS(2006),
    [anon_sym_volatile] = ACTIONS(2006),
    [anon_sym_restrict] = ACTIONS(2006),
    [anon_sym___restrict__] = ACTIONS(2006),
    [anon_sym__Atomic] = ACTIONS(2006),
    [anon_sym__Noreturn] = ACTIONS(2006),
    [anon_sym_noreturn] = ACTIONS(2006),
    [anon_sym__Nonnull] = ACTIONS(2006),
    [anon_sym_mutable] = ACTIONS(2006),
    [anon_sym_constinit] = ACTIONS(2006),
    [anon_sym_consteval] = ACTIONS(2006),
    [anon_sym___shared__] = ACTIONS(2006),
    [anon_sym___local__] = ACTIONS(2006),
    [anon_sym___constant__] = ACTIONS(2006),
    [anon_sym___managed__] = ACTIONS(2006),
    [anon_sym___grid_constant__] = ACTIONS(2006),
    [anon_sym_alignas] = ACTIONS(2006),
    [anon_sym__Alignas] = ACTIONS(2006),
    [sym_primitive_type] = ACTIONS(2006),
    [anon_sym_enum] = ACTIONS(2006),
    [anon_sym_class] = ACTIONS(2006),
    [anon_sym_struct] = ACTIONS(2006),
    [anon_sym_union] = ACTIONS(2006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2006),
    [anon_sym_decltype] = ACTIONS(2006),
    [anon_sym_explicit] = ACTIONS(2006),
    [anon_sym_typename] = ACTIONS(2006),
    [anon_sym_template] = ACTIONS(2006),
    [anon_sym_operator] = ACTIONS(2006),
    [anon_sym_friend] = ACTIONS(2006),
    [anon_sym_public] = ACTIONS(2006),
    [anon_sym_private] = ACTIONS(2006),
    [anon_sym_protected] = ACTIONS(2006),
    [anon_sym_using] = ACTIONS(2006),
    [anon_sym_static_assert] = ACTIONS(2006),
    [anon_sym_catch] = ACTIONS(2006),
    [anon_sym___launch_bounds__] = ACTIONS(2006),
  },
  [STATE(1905)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4555),
    [anon_sym_COMMA] = ACTIONS(4555),
    [anon_sym_RPAREN] = ACTIONS(4557),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym_SEMI] = ACTIONS(4555),
    [anon_sym___extension__] = ACTIONS(4560),
    [anon_sym___global__] = ACTIONS(4560),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4555),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_EQ] = ACTIONS(4562),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4560),
    [anon_sym_volatile] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym___restrict__] = ACTIONS(4560),
    [anon_sym__Atomic] = ACTIONS(4560),
    [anon_sym__Noreturn] = ACTIONS(4560),
    [anon_sym_noreturn] = ACTIONS(4560),
    [anon_sym__Nonnull] = ACTIONS(4560),
    [anon_sym_mutable] = ACTIONS(4560),
    [anon_sym_constinit] = ACTIONS(4560),
    [anon_sym_consteval] = ACTIONS(4560),
    [anon_sym___shared__] = ACTIONS(4560),
    [anon_sym___local__] = ACTIONS(4560),
    [anon_sym___constant__] = ACTIONS(4560),
    [anon_sym___managed__] = ACTIONS(4560),
    [anon_sym___grid_constant__] = ACTIONS(4560),
    [anon_sym_alignas] = ACTIONS(4560),
    [anon_sym__Alignas] = ACTIONS(4560),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4555),
    [anon_sym_or_eq] = ACTIONS(4555),
    [anon_sym_xor_eq] = ACTIONS(4555),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4555),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4555),
    [anon_sym_not_eq] = ACTIONS(4555),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4562),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4560),
    [anon_sym_decltype] = ACTIONS(4560),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4555),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
  },
  [STATE(1906)] = {
    [sym__declaration_modifiers] = STATE(2730),
    [sym_attribute_specifier] = STATE(2730),
    [sym_attribute_declaration] = STATE(2730),
    [sym_ms_declspec_modifier] = STATE(2730),
    [sym_storage_class_specifier] = STATE(2730),
    [sym_type_qualifier] = STATE(2730),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(3191),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7232),
    [sym_qualified_type_identifier] = STATE(2374),
    [sym_launch_bounds] = STATE(2730),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2730),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2354),
    [sym_identifier] = ACTIONS(3736),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(5653),
    [anon_sym___host__] = ACTIONS(5653),
    [anon_sym___global__] = ACTIONS(5653),
    [anon_sym___forceinline__] = ACTIONS(5653),
    [anon_sym___noinline__] = ACTIONS(5653),
    [anon_sym_virtual] = ACTIONS(5653),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(3744),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(3746),
    [anon_sym_unsigned] = ACTIONS(3746),
    [anon_sym_long] = ACTIONS(3746),
    [anon_sym_short] = ACTIONS(3746),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(3748),
    [anon_sym_enum] = ACTIONS(3750),
    [anon_sym_class] = ACTIONS(3752),
    [anon_sym_struct] = ACTIONS(3754),
    [anon_sym_union] = ACTIONS(3756),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(3758),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1907)] = {
    [sym__declaration_modifiers] = STATE(2730),
    [sym_attribute_specifier] = STATE(2730),
    [sym_attribute_declaration] = STATE(2730),
    [sym_ms_declspec_modifier] = STATE(2730),
    [sym_storage_class_specifier] = STATE(2730),
    [sym_type_qualifier] = STATE(2730),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2198),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7199),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(2730),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2730),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(4601),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(5653),
    [anon_sym___host__] = ACTIONS(5653),
    [anon_sym___global__] = ACTIONS(5653),
    [anon_sym___forceinline__] = ACTIONS(5653),
    [anon_sym___noinline__] = ACTIONS(5653),
    [anon_sym_virtual] = ACTIONS(5653),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(4611),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(1802),
    [anon_sym_class] = ACTIONS(1804),
    [anon_sym_struct] = ACTIONS(1806),
    [anon_sym_union] = ACTIONS(1808),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(1832),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1908)] = {
    [sym_identifier] = ACTIONS(1928),
    [aux_sym_preproc_def_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token1] = ACTIONS(1928),
    [aux_sym_preproc_if_token2] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1928),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1928),
    [sym_preproc_directive] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_AMP_AMP] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1928),
    [anon_sym_SEMI] = ACTIONS(1926),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym_typedef] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym___based] = ACTIONS(1928),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_explicit] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_operator] = ACTIONS(1928),
    [anon_sym_friend] = ACTIONS(1928),
    [anon_sym_public] = ACTIONS(1928),
    [anon_sym_private] = ACTIONS(1928),
    [anon_sym_protected] = ACTIONS(1928),
    [anon_sym_using] = ACTIONS(1928),
    [anon_sym_static_assert] = ACTIONS(1928),
    [anon_sym_catch] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(1909)] = {
    [sym__declaration_modifiers] = STATE(2730),
    [sym_attribute_specifier] = STATE(2730),
    [sym_attribute_declaration] = STATE(2730),
    [sym_ms_declspec_modifier] = STATE(2730),
    [sym_storage_class_specifier] = STATE(2730),
    [sym_type_qualifier] = STATE(2730),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_type_specifier] = STATE(2198),
    [sym_sized_type_specifier] = STATE(2264),
    [sym_enum_specifier] = STATE(2264),
    [sym_struct_specifier] = STATE(2264),
    [sym_union_specifier] = STATE(2264),
    [sym_placeholder_type_specifier] = STATE(2264),
    [sym_decltype_auto] = STATE(2243),
    [sym_decltype] = STATE(2212),
    [sym_class_specifier] = STATE(2264),
    [sym_dependent_type] = STATE(2264),
    [sym_template_type] = STATE(2212),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(7200),
    [sym_qualified_type_identifier] = STATE(2625),
    [sym_launch_bounds] = STATE(2730),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2730),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2190),
    [sym_identifier] = ACTIONS(5147),
    [anon_sym___extension__] = ACTIONS(65),
    [anon_sym___device__] = ACTIONS(5653),
    [anon_sym___host__] = ACTIONS(5653),
    [anon_sym___global__] = ACTIONS(5653),
    [anon_sym___forceinline__] = ACTIONS(5653),
    [anon_sym___noinline__] = ACTIONS(5653),
    [anon_sym_virtual] = ACTIONS(5653),
    [anon_sym_extern] = ACTIONS(61),
    [anon_sym___attribute__] = ACTIONS(43),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_COLON_COLON] = ACTIONS(5149),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1774),
    [anon_sym___declspec] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(57),
    [anon_sym_unsigned] = ACTIONS(57),
    [anon_sym_long] = ACTIONS(57),
    [anon_sym_short] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(61),
    [anon_sym_register] = ACTIONS(61),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(61),
    [anon_sym___inline__] = ACTIONS(61),
    [anon_sym___forceinline] = ACTIONS(61),
    [anon_sym_thread_local] = ACTIONS(61),
    [anon_sym___thread] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_constexpr] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_restrict] = ACTIONS(65),
    [anon_sym___restrict__] = ACTIONS(65),
    [anon_sym__Atomic] = ACTIONS(65),
    [anon_sym__Noreturn] = ACTIONS(65),
    [anon_sym_noreturn] = ACTIONS(65),
    [anon_sym__Nonnull] = ACTIONS(65),
    [anon_sym_mutable] = ACTIONS(65),
    [anon_sym_constinit] = ACTIONS(65),
    [anon_sym_consteval] = ACTIONS(65),
    [anon_sym___shared__] = ACTIONS(65),
    [anon_sym___local__] = ACTIONS(65),
    [anon_sym___constant__] = ACTIONS(65),
    [anon_sym___managed__] = ACTIONS(65),
    [anon_sym___grid_constant__] = ACTIONS(65),
    [anon_sym_alignas] = ACTIONS(67),
    [anon_sym__Alignas] = ACTIONS(67),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(71),
    [anon_sym_class] = ACTIONS(73),
    [anon_sym_struct] = ACTIONS(75),
    [anon_sym_union] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(123),
    [anon_sym_decltype] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(129),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym___launch_bounds__] = ACTIONS(161),
  },
  [STATE(1910)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_catch] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1911)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [anon_sym_COMMA] = ACTIONS(2060),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token2] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(2060),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(5503),
    [anon_sym___attribute] = ACTIONS(5503),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1912)] = {
    [sym_identifier] = ACTIONS(1932),
    [aux_sym_preproc_def_token1] = ACTIONS(1932),
    [aux_sym_preproc_if_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1932),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1932),
    [sym_preproc_directive] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym_SEMI] = ACTIONS(1930),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym_typedef] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym_RBRACE] = ACTIONS(1930),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_public] = ACTIONS(1932),
    [anon_sym_private] = ACTIONS(1932),
    [anon_sym_protected] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_static_assert] = ACTIONS(1932),
    [anon_sym_catch] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(1913)] = {
    [sym_identifier] = ACTIONS(2533),
    [aux_sym_preproc_def_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2533),
    [sym_preproc_directive] = ACTIONS(2533),
    [anon_sym_LPAREN2] = ACTIONS(2535),
    [anon_sym_TILDE] = ACTIONS(2535),
    [anon_sym_STAR] = ACTIONS(2535),
    [anon_sym_AMP_AMP] = ACTIONS(2535),
    [anon_sym_AMP] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym___extension__] = ACTIONS(2533),
    [anon_sym_typedef] = ACTIONS(2533),
    [anon_sym___device__] = ACTIONS(2533),
    [anon_sym___host__] = ACTIONS(2533),
    [anon_sym___global__] = ACTIONS(2533),
    [anon_sym___forceinline__] = ACTIONS(2533),
    [anon_sym___noinline__] = ACTIONS(2533),
    [anon_sym_virtual] = ACTIONS(2533),
    [anon_sym_extern] = ACTIONS(2533),
    [anon_sym___attribute__] = ACTIONS(2533),
    [anon_sym___attribute] = ACTIONS(2533),
    [anon_sym_COLON_COLON] = ACTIONS(2535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2535),
    [anon_sym___declspec] = ACTIONS(2533),
    [anon_sym___based] = ACTIONS(2533),
    [anon_sym_RBRACE] = ACTIONS(2535),
    [anon_sym_signed] = ACTIONS(2533),
    [anon_sym_unsigned] = ACTIONS(2533),
    [anon_sym_long] = ACTIONS(2533),
    [anon_sym_short] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2533),
    [anon_sym_static] = ACTIONS(2533),
    [anon_sym_register] = ACTIONS(2533),
    [anon_sym_inline] = ACTIONS(2533),
    [anon_sym___inline] = ACTIONS(2533),
    [anon_sym___inline__] = ACTIONS(2533),
    [anon_sym___forceinline] = ACTIONS(2533),
    [anon_sym_thread_local] = ACTIONS(2533),
    [anon_sym___thread] = ACTIONS(2533),
    [anon_sym_const] = ACTIONS(2533),
    [anon_sym_constexpr] = ACTIONS(2533),
    [anon_sym_volatile] = ACTIONS(2533),
    [anon_sym_restrict] = ACTIONS(2533),
    [anon_sym___restrict__] = ACTIONS(2533),
    [anon_sym__Atomic] = ACTIONS(2533),
    [anon_sym__Noreturn] = ACTIONS(2533),
    [anon_sym_noreturn] = ACTIONS(2533),
    [anon_sym__Nonnull] = ACTIONS(2533),
    [anon_sym_mutable] = ACTIONS(2533),
    [anon_sym_constinit] = ACTIONS(2533),
    [anon_sym_consteval] = ACTIONS(2533),
    [anon_sym___shared__] = ACTIONS(2533),
    [anon_sym___local__] = ACTIONS(2533),
    [anon_sym___constant__] = ACTIONS(2533),
    [anon_sym___managed__] = ACTIONS(2533),
    [anon_sym___grid_constant__] = ACTIONS(2533),
    [anon_sym_alignas] = ACTIONS(2533),
    [anon_sym__Alignas] = ACTIONS(2533),
    [sym_primitive_type] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_class] = ACTIONS(2533),
    [anon_sym_struct] = ACTIONS(2533),
    [anon_sym_union] = ACTIONS(2533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2533),
    [anon_sym_decltype] = ACTIONS(2533),
    [anon_sym_explicit] = ACTIONS(2533),
    [anon_sym_typename] = ACTIONS(2533),
    [anon_sym_template] = ACTIONS(2533),
    [anon_sym_operator] = ACTIONS(2533),
    [anon_sym_friend] = ACTIONS(2533),
    [anon_sym_public] = ACTIONS(2533),
    [anon_sym_private] = ACTIONS(2533),
    [anon_sym_protected] = ACTIONS(2533),
    [anon_sym_using] = ACTIONS(2533),
    [anon_sym_static_assert] = ACTIONS(2533),
    [anon_sym___launch_bounds__] = ACTIONS(2533),
  },
  [STATE(1914)] = {
    [sym_identifier] = ACTIONS(2595),
    [aux_sym_preproc_def_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token2] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2595),
    [sym_preproc_directive] = ACTIONS(2595),
    [anon_sym_LPAREN2] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_AMP_AMP] = ACTIONS(2597),
    [anon_sym_AMP] = ACTIONS(2595),
    [anon_sym_SEMI] = ACTIONS(2597),
    [anon_sym___extension__] = ACTIONS(2595),
    [anon_sym_typedef] = ACTIONS(2595),
    [anon_sym___device__] = ACTIONS(2595),
    [anon_sym___host__] = ACTIONS(2595),
    [anon_sym___global__] = ACTIONS(2595),
    [anon_sym___forceinline__] = ACTIONS(2595),
    [anon_sym___noinline__] = ACTIONS(2595),
    [anon_sym_virtual] = ACTIONS(2595),
    [anon_sym_extern] = ACTIONS(2595),
    [anon_sym___attribute__] = ACTIONS(2595),
    [anon_sym___attribute] = ACTIONS(2595),
    [anon_sym_COLON_COLON] = ACTIONS(2597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2597),
    [anon_sym___declspec] = ACTIONS(2595),
    [anon_sym___based] = ACTIONS(2595),
    [anon_sym_signed] = ACTIONS(2595),
    [anon_sym_unsigned] = ACTIONS(2595),
    [anon_sym_long] = ACTIONS(2595),
    [anon_sym_short] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_register] = ACTIONS(2595),
    [anon_sym_inline] = ACTIONS(2595),
    [anon_sym___inline] = ACTIONS(2595),
    [anon_sym___inline__] = ACTIONS(2595),
    [anon_sym___forceinline] = ACTIONS(2595),
    [anon_sym_thread_local] = ACTIONS(2595),
    [anon_sym___thread] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_constexpr] = ACTIONS(2595),
    [anon_sym_volatile] = ACTIONS(2595),
    [anon_sym_restrict] = ACTIONS(2595),
    [anon_sym___restrict__] = ACTIONS(2595),
    [anon_sym__Atomic] = ACTIONS(2595),
    [anon_sym__Noreturn] = ACTIONS(2595),
    [anon_sym_noreturn] = ACTIONS(2595),
    [anon_sym__Nonnull] = ACTIONS(2595),
    [anon_sym_mutable] = ACTIONS(2595),
    [anon_sym_constinit] = ACTIONS(2595),
    [anon_sym_consteval] = ACTIONS(2595),
    [anon_sym___shared__] = ACTIONS(2595),
    [anon_sym___local__] = ACTIONS(2595),
    [anon_sym___constant__] = ACTIONS(2595),
    [anon_sym___managed__] = ACTIONS(2595),
    [anon_sym___grid_constant__] = ACTIONS(2595),
    [anon_sym_alignas] = ACTIONS(2595),
    [anon_sym__Alignas] = ACTIONS(2595),
    [sym_primitive_type] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_struct] = ACTIONS(2595),
    [anon_sym_union] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2595),
    [anon_sym_decltype] = ACTIONS(2595),
    [anon_sym_explicit] = ACTIONS(2595),
    [anon_sym_typename] = ACTIONS(2595),
    [anon_sym_template] = ACTIONS(2595),
    [anon_sym_operator] = ACTIONS(2595),
    [anon_sym_friend] = ACTIONS(2595),
    [anon_sym_public] = ACTIONS(2595),
    [anon_sym_private] = ACTIONS(2595),
    [anon_sym_protected] = ACTIONS(2595),
    [anon_sym_using] = ACTIONS(2595),
    [anon_sym_static_assert] = ACTIONS(2595),
    [anon_sym___launch_bounds__] = ACTIONS(2595),
  },
  [STATE(1915)] = {
    [sym_identifier] = ACTIONS(2617),
    [aux_sym_preproc_def_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2617),
    [sym_preproc_directive] = ACTIONS(2617),
    [anon_sym_LPAREN2] = ACTIONS(2619),
    [anon_sym_TILDE] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_AMP_AMP] = ACTIONS(2619),
    [anon_sym_AMP] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2619),
    [anon_sym___extension__] = ACTIONS(2617),
    [anon_sym_typedef] = ACTIONS(2617),
    [anon_sym___device__] = ACTIONS(2617),
    [anon_sym___host__] = ACTIONS(2617),
    [anon_sym___global__] = ACTIONS(2617),
    [anon_sym___forceinline__] = ACTIONS(2617),
    [anon_sym___noinline__] = ACTIONS(2617),
    [anon_sym_virtual] = ACTIONS(2617),
    [anon_sym_extern] = ACTIONS(2617),
    [anon_sym___attribute__] = ACTIONS(2617),
    [anon_sym___attribute] = ACTIONS(2617),
    [anon_sym_COLON_COLON] = ACTIONS(2619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2619),
    [anon_sym___declspec] = ACTIONS(2617),
    [anon_sym___based] = ACTIONS(2617),
    [anon_sym_RBRACE] = ACTIONS(2619),
    [anon_sym_signed] = ACTIONS(2617),
    [anon_sym_unsigned] = ACTIONS(2617),
    [anon_sym_long] = ACTIONS(2617),
    [anon_sym_short] = ACTIONS(2617),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2617),
    [anon_sym_register] = ACTIONS(2617),
    [anon_sym_inline] = ACTIONS(2617),
    [anon_sym___inline] = ACTIONS(2617),
    [anon_sym___inline__] = ACTIONS(2617),
    [anon_sym___forceinline] = ACTIONS(2617),
    [anon_sym_thread_local] = ACTIONS(2617),
    [anon_sym___thread] = ACTIONS(2617),
    [anon_sym_const] = ACTIONS(2617),
    [anon_sym_constexpr] = ACTIONS(2617),
    [anon_sym_volatile] = ACTIONS(2617),
    [anon_sym_restrict] = ACTIONS(2617),
    [anon_sym___restrict__] = ACTIONS(2617),
    [anon_sym__Atomic] = ACTIONS(2617),
    [anon_sym__Noreturn] = ACTIONS(2617),
    [anon_sym_noreturn] = ACTIONS(2617),
    [anon_sym__Nonnull] = ACTIONS(2617),
    [anon_sym_mutable] = ACTIONS(2617),
    [anon_sym_constinit] = ACTIONS(2617),
    [anon_sym_consteval] = ACTIONS(2617),
    [anon_sym___shared__] = ACTIONS(2617),
    [anon_sym___local__] = ACTIONS(2617),
    [anon_sym___constant__] = ACTIONS(2617),
    [anon_sym___managed__] = ACTIONS(2617),
    [anon_sym___grid_constant__] = ACTIONS(2617),
    [anon_sym_alignas] = ACTIONS(2617),
    [anon_sym__Alignas] = ACTIONS(2617),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2617),
    [anon_sym_struct] = ACTIONS(2617),
    [anon_sym_union] = ACTIONS(2617),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2617),
    [anon_sym_decltype] = ACTIONS(2617),
    [anon_sym_explicit] = ACTIONS(2617),
    [anon_sym_typename] = ACTIONS(2617),
    [anon_sym_template] = ACTIONS(2617),
    [anon_sym_operator] = ACTIONS(2617),
    [anon_sym_friend] = ACTIONS(2617),
    [anon_sym_public] = ACTIONS(2617),
    [anon_sym_private] = ACTIONS(2617),
    [anon_sym_protected] = ACTIONS(2617),
    [anon_sym_using] = ACTIONS(2617),
    [anon_sym_static_assert] = ACTIONS(2617),
    [anon_sym___launch_bounds__] = ACTIONS(2617),
  },
  [STATE(1916)] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym___device__] = ACTIONS(2328),
    [anon_sym___host__] = ACTIONS(2328),
    [anon_sym___global__] = ACTIONS(2328),
    [anon_sym___forceinline__] = ACTIONS(2328),
    [anon_sym___noinline__] = ACTIONS(2328),
    [anon_sym_virtual] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym___attribute] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym_RBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym__Nonnull] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym___shared__] = ACTIONS(2328),
    [anon_sym___local__] = ACTIONS(2328),
    [anon_sym___constant__] = ACTIONS(2328),
    [anon_sym___managed__] = ACTIONS(2328),
    [anon_sym___grid_constant__] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_friend] = ACTIONS(2328),
    [anon_sym_public] = ACTIONS(2328),
    [anon_sym_private] = ACTIONS(2328),
    [anon_sym_protected] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym___launch_bounds__] = ACTIONS(2328),
  },
  [STATE(1917)] = {
    [sym_identifier] = ACTIONS(2230),
    [aux_sym_preproc_def_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2230),
    [sym_preproc_directive] = ACTIONS(2230),
    [anon_sym_LPAREN2] = ACTIONS(2232),
    [anon_sym_TILDE] = ACTIONS(2232),
    [anon_sym_STAR] = ACTIONS(2232),
    [anon_sym_AMP_AMP] = ACTIONS(2232),
    [anon_sym_AMP] = ACTIONS(2230),
    [anon_sym_SEMI] = ACTIONS(2232),
    [anon_sym___extension__] = ACTIONS(2230),
    [anon_sym_typedef] = ACTIONS(2230),
    [anon_sym___device__] = ACTIONS(2230),
    [anon_sym___host__] = ACTIONS(2230),
    [anon_sym___global__] = ACTIONS(2230),
    [anon_sym___forceinline__] = ACTIONS(2230),
    [anon_sym___noinline__] = ACTIONS(2230),
    [anon_sym_virtual] = ACTIONS(2230),
    [anon_sym_extern] = ACTIONS(2230),
    [anon_sym___attribute__] = ACTIONS(2230),
    [anon_sym___attribute] = ACTIONS(2230),
    [anon_sym_COLON_COLON] = ACTIONS(2232),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2232),
    [anon_sym___declspec] = ACTIONS(2230),
    [anon_sym___based] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(2232),
    [anon_sym_signed] = ACTIONS(2230),
    [anon_sym_unsigned] = ACTIONS(2230),
    [anon_sym_long] = ACTIONS(2230),
    [anon_sym_short] = ACTIONS(2230),
    [anon_sym_LBRACK] = ACTIONS(2230),
    [anon_sym_static] = ACTIONS(2230),
    [anon_sym_register] = ACTIONS(2230),
    [anon_sym_inline] = ACTIONS(2230),
    [anon_sym___inline] = ACTIONS(2230),
    [anon_sym___inline__] = ACTIONS(2230),
    [anon_sym___forceinline] = ACTIONS(2230),
    [anon_sym_thread_local] = ACTIONS(2230),
    [anon_sym___thread] = ACTIONS(2230),
    [anon_sym_const] = ACTIONS(2230),
    [anon_sym_constexpr] = ACTIONS(2230),
    [anon_sym_volatile] = ACTIONS(2230),
    [anon_sym_restrict] = ACTIONS(2230),
    [anon_sym___restrict__] = ACTIONS(2230),
    [anon_sym__Atomic] = ACTIONS(2230),
    [anon_sym__Noreturn] = ACTIONS(2230),
    [anon_sym_noreturn] = ACTIONS(2230),
    [anon_sym__Nonnull] = ACTIONS(2230),
    [anon_sym_mutable] = ACTIONS(2230),
    [anon_sym_constinit] = ACTIONS(2230),
    [anon_sym_consteval] = ACTIONS(2230),
    [anon_sym___shared__] = ACTIONS(2230),
    [anon_sym___local__] = ACTIONS(2230),
    [anon_sym___constant__] = ACTIONS(2230),
    [anon_sym___managed__] = ACTIONS(2230),
    [anon_sym___grid_constant__] = ACTIONS(2230),
    [anon_sym_alignas] = ACTIONS(2230),
    [anon_sym__Alignas] = ACTIONS(2230),
    [sym_primitive_type] = ACTIONS(2230),
    [anon_sym_enum] = ACTIONS(2230),
    [anon_sym_class] = ACTIONS(2230),
    [anon_sym_struct] = ACTIONS(2230),
    [anon_sym_union] = ACTIONS(2230),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2230),
    [anon_sym_decltype] = ACTIONS(2230),
    [anon_sym_explicit] = ACTIONS(2230),
    [anon_sym_typename] = ACTIONS(2230),
    [anon_sym_template] = ACTIONS(2230),
    [anon_sym_operator] = ACTIONS(2230),
    [anon_sym_friend] = ACTIONS(2230),
    [anon_sym_public] = ACTIONS(2230),
    [anon_sym_private] = ACTIONS(2230),
    [anon_sym_protected] = ACTIONS(2230),
    [anon_sym_using] = ACTIONS(2230),
    [anon_sym_static_assert] = ACTIONS(2230),
    [anon_sym___launch_bounds__] = ACTIONS(2230),
  },
  [STATE(1918)] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym___device__] = ACTIONS(2316),
    [anon_sym___host__] = ACTIONS(2316),
    [anon_sym___global__] = ACTIONS(2316),
    [anon_sym___forceinline__] = ACTIONS(2316),
    [anon_sym___noinline__] = ACTIONS(2316),
    [anon_sym_virtual] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym___attribute] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym_RBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym__Nonnull] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym___shared__] = ACTIONS(2316),
    [anon_sym___local__] = ACTIONS(2316),
    [anon_sym___constant__] = ACTIONS(2316),
    [anon_sym___managed__] = ACTIONS(2316),
    [anon_sym___grid_constant__] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_friend] = ACTIONS(2316),
    [anon_sym_public] = ACTIONS(2316),
    [anon_sym_private] = ACTIONS(2316),
    [anon_sym_protected] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym___launch_bounds__] = ACTIONS(2316),
  },
  [STATE(1919)] = {
    [sym_identifier] = ACTIONS(5517),
    [aux_sym_preproc_def_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token1] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5517),
    [sym_preproc_directive] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5519),
    [anon_sym_TILDE] = ACTIONS(5519),
    [anon_sym_STAR] = ACTIONS(5519),
    [anon_sym_AMP_AMP] = ACTIONS(5519),
    [anon_sym_AMP] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym___extension__] = ACTIONS(5517),
    [anon_sym_typedef] = ACTIONS(5517),
    [anon_sym___device__] = ACTIONS(5517),
    [anon_sym___host__] = ACTIONS(5517),
    [anon_sym___global__] = ACTIONS(5517),
    [anon_sym___forceinline__] = ACTIONS(5517),
    [anon_sym___noinline__] = ACTIONS(5517),
    [anon_sym_virtual] = ACTIONS(5517),
    [anon_sym_extern] = ACTIONS(5517),
    [anon_sym___attribute__] = ACTIONS(5517),
    [anon_sym___attribute] = ACTIONS(5517),
    [anon_sym_COLON_COLON] = ACTIONS(5519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5519),
    [anon_sym___declspec] = ACTIONS(5517),
    [anon_sym___based] = ACTIONS(5517),
    [anon_sym_RBRACE] = ACTIONS(5519),
    [anon_sym_signed] = ACTIONS(5517),
    [anon_sym_unsigned] = ACTIONS(5517),
    [anon_sym_long] = ACTIONS(5517),
    [anon_sym_short] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5517),
    [anon_sym_static] = ACTIONS(5517),
    [anon_sym_register] = ACTIONS(5517),
    [anon_sym_inline] = ACTIONS(5517),
    [anon_sym___inline] = ACTIONS(5517),
    [anon_sym___inline__] = ACTIONS(5517),
    [anon_sym___forceinline] = ACTIONS(5517),
    [anon_sym_thread_local] = ACTIONS(5517),
    [anon_sym___thread] = ACTIONS(5517),
    [anon_sym_const] = ACTIONS(5517),
    [anon_sym_constexpr] = ACTIONS(5517),
    [anon_sym_volatile] = ACTIONS(5517),
    [anon_sym_restrict] = ACTIONS(5517),
    [anon_sym___restrict__] = ACTIONS(5517),
    [anon_sym__Atomic] = ACTIONS(5517),
    [anon_sym__Noreturn] = ACTIONS(5517),
    [anon_sym_noreturn] = ACTIONS(5517),
    [anon_sym__Nonnull] = ACTIONS(5517),
    [anon_sym_mutable] = ACTIONS(5517),
    [anon_sym_constinit] = ACTIONS(5517),
    [anon_sym_consteval] = ACTIONS(5517),
    [anon_sym___shared__] = ACTIONS(5517),
    [anon_sym___local__] = ACTIONS(5517),
    [anon_sym___constant__] = ACTIONS(5517),
    [anon_sym___managed__] = ACTIONS(5517),
    [anon_sym___grid_constant__] = ACTIONS(5517),
    [anon_sym_alignas] = ACTIONS(5517),
    [anon_sym__Alignas] = ACTIONS(5517),
    [sym_primitive_type] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_class] = ACTIONS(5517),
    [anon_sym_struct] = ACTIONS(5517),
    [anon_sym_union] = ACTIONS(5517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5517),
    [anon_sym_decltype] = ACTIONS(5517),
    [anon_sym_explicit] = ACTIONS(5517),
    [anon_sym_typename] = ACTIONS(5517),
    [anon_sym_template] = ACTIONS(5517),
    [anon_sym_operator] = ACTIONS(5517),
    [anon_sym_friend] = ACTIONS(5517),
    [anon_sym_public] = ACTIONS(5517),
    [anon_sym_private] = ACTIONS(5517),
    [anon_sym_protected] = ACTIONS(5517),
    [anon_sym_using] = ACTIONS(5517),
    [anon_sym_static_assert] = ACTIONS(5517),
    [anon_sym___launch_bounds__] = ACTIONS(5517),
  },
  [STATE(1920)] = {
    [sym_identifier] = ACTIONS(2431),
    [aux_sym_preproc_def_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2431),
    [sym_preproc_directive] = ACTIONS(2431),
    [anon_sym_LPAREN2] = ACTIONS(2433),
    [anon_sym_TILDE] = ACTIONS(2433),
    [anon_sym_STAR] = ACTIONS(2433),
    [anon_sym_AMP_AMP] = ACTIONS(2433),
    [anon_sym_AMP] = ACTIONS(2431),
    [anon_sym_SEMI] = ACTIONS(2433),
    [anon_sym___extension__] = ACTIONS(2431),
    [anon_sym_typedef] = ACTIONS(2431),
    [anon_sym___device__] = ACTIONS(2431),
    [anon_sym___host__] = ACTIONS(2431),
    [anon_sym___global__] = ACTIONS(2431),
    [anon_sym___forceinline__] = ACTIONS(2431),
    [anon_sym___noinline__] = ACTIONS(2431),
    [anon_sym_virtual] = ACTIONS(2431),
    [anon_sym_extern] = ACTIONS(2431),
    [anon_sym___attribute__] = ACTIONS(2431),
    [anon_sym___attribute] = ACTIONS(2431),
    [anon_sym_COLON_COLON] = ACTIONS(2433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2433),
    [anon_sym___declspec] = ACTIONS(2431),
    [anon_sym___based] = ACTIONS(2431),
    [anon_sym_RBRACE] = ACTIONS(2433),
    [anon_sym_signed] = ACTIONS(2431),
    [anon_sym_unsigned] = ACTIONS(2431),
    [anon_sym_long] = ACTIONS(2431),
    [anon_sym_short] = ACTIONS(2431),
    [anon_sym_LBRACK] = ACTIONS(2431),
    [anon_sym_static] = ACTIONS(2431),
    [anon_sym_register] = ACTIONS(2431),
    [anon_sym_inline] = ACTIONS(2431),
    [anon_sym___inline] = ACTIONS(2431),
    [anon_sym___inline__] = ACTIONS(2431),
    [anon_sym___forceinline] = ACTIONS(2431),
    [anon_sym_thread_local] = ACTIONS(2431),
    [anon_sym___thread] = ACTIONS(2431),
    [anon_sym_const] = ACTIONS(2431),
    [anon_sym_constexpr] = ACTIONS(2431),
    [anon_sym_volatile] = ACTIONS(2431),
    [anon_sym_restrict] = ACTIONS(2431),
    [anon_sym___restrict__] = ACTIONS(2431),
    [anon_sym__Atomic] = ACTIONS(2431),
    [anon_sym__Noreturn] = ACTIONS(2431),
    [anon_sym_noreturn] = ACTIONS(2431),
    [anon_sym__Nonnull] = ACTIONS(2431),
    [anon_sym_mutable] = ACTIONS(2431),
    [anon_sym_constinit] = ACTIONS(2431),
    [anon_sym_consteval] = ACTIONS(2431),
    [anon_sym___shared__] = ACTIONS(2431),
    [anon_sym___local__] = ACTIONS(2431),
    [anon_sym___constant__] = ACTIONS(2431),
    [anon_sym___managed__] = ACTIONS(2431),
    [anon_sym___grid_constant__] = ACTIONS(2431),
    [anon_sym_alignas] = ACTIONS(2431),
    [anon_sym__Alignas] = ACTIONS(2431),
    [sym_primitive_type] = ACTIONS(2431),
    [anon_sym_enum] = ACTIONS(2431),
    [anon_sym_class] = ACTIONS(2431),
    [anon_sym_struct] = ACTIONS(2431),
    [anon_sym_union] = ACTIONS(2431),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2431),
    [anon_sym_decltype] = ACTIONS(2431),
    [anon_sym_explicit] = ACTIONS(2431),
    [anon_sym_typename] = ACTIONS(2431),
    [anon_sym_template] = ACTIONS(2431),
    [anon_sym_operator] = ACTIONS(2431),
    [anon_sym_friend] = ACTIONS(2431),
    [anon_sym_public] = ACTIONS(2431),
    [anon_sym_private] = ACTIONS(2431),
    [anon_sym_protected] = ACTIONS(2431),
    [anon_sym_using] = ACTIONS(2431),
    [anon_sym_static_assert] = ACTIONS(2431),
    [anon_sym___launch_bounds__] = ACTIONS(2431),
  },
  [STATE(1921)] = {
    [sym_identifier] = ACTIONS(2373),
    [aux_sym_preproc_def_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2373),
    [sym_preproc_directive] = ACTIONS(2373),
    [anon_sym_LPAREN2] = ACTIONS(2375),
    [anon_sym_TILDE] = ACTIONS(2375),
    [anon_sym_STAR] = ACTIONS(2375),
    [anon_sym_AMP_AMP] = ACTIONS(2375),
    [anon_sym_AMP] = ACTIONS(2373),
    [anon_sym_SEMI] = ACTIONS(2375),
    [anon_sym___extension__] = ACTIONS(2373),
    [anon_sym_typedef] = ACTIONS(2373),
    [anon_sym___device__] = ACTIONS(2373),
    [anon_sym___host__] = ACTIONS(2373),
    [anon_sym___global__] = ACTIONS(2373),
    [anon_sym___forceinline__] = ACTIONS(2373),
    [anon_sym___noinline__] = ACTIONS(2373),
    [anon_sym_virtual] = ACTIONS(2373),
    [anon_sym_extern] = ACTIONS(2373),
    [anon_sym___attribute__] = ACTIONS(2373),
    [anon_sym___attribute] = ACTIONS(2373),
    [anon_sym_COLON_COLON] = ACTIONS(2375),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2375),
    [anon_sym___declspec] = ACTIONS(2373),
    [anon_sym___based] = ACTIONS(2373),
    [anon_sym_RBRACE] = ACTIONS(2375),
    [anon_sym_signed] = ACTIONS(2373),
    [anon_sym_unsigned] = ACTIONS(2373),
    [anon_sym_long] = ACTIONS(2373),
    [anon_sym_short] = ACTIONS(2373),
    [anon_sym_LBRACK] = ACTIONS(2373),
    [anon_sym_static] = ACTIONS(2373),
    [anon_sym_register] = ACTIONS(2373),
    [anon_sym_inline] = ACTIONS(2373),
    [anon_sym___inline] = ACTIONS(2373),
    [anon_sym___inline__] = ACTIONS(2373),
    [anon_sym___forceinline] = ACTIONS(2373),
    [anon_sym_thread_local] = ACTIONS(2373),
    [anon_sym___thread] = ACTIONS(2373),
    [anon_sym_const] = ACTIONS(2373),
    [anon_sym_constexpr] = ACTIONS(2373),
    [anon_sym_volatile] = ACTIONS(2373),
    [anon_sym_restrict] = ACTIONS(2373),
    [anon_sym___restrict__] = ACTIONS(2373),
    [anon_sym__Atomic] = ACTIONS(2373),
    [anon_sym__Noreturn] = ACTIONS(2373),
    [anon_sym_noreturn] = ACTIONS(2373),
    [anon_sym__Nonnull] = ACTIONS(2373),
    [anon_sym_mutable] = ACTIONS(2373),
    [anon_sym_constinit] = ACTIONS(2373),
    [anon_sym_consteval] = ACTIONS(2373),
    [anon_sym___shared__] = ACTIONS(2373),
    [anon_sym___local__] = ACTIONS(2373),
    [anon_sym___constant__] = ACTIONS(2373),
    [anon_sym___managed__] = ACTIONS(2373),
    [anon_sym___grid_constant__] = ACTIONS(2373),
    [anon_sym_alignas] = ACTIONS(2373),
    [anon_sym__Alignas] = ACTIONS(2373),
    [sym_primitive_type] = ACTIONS(2373),
    [anon_sym_enum] = ACTIONS(2373),
    [anon_sym_class] = ACTIONS(2373),
    [anon_sym_struct] = ACTIONS(2373),
    [anon_sym_union] = ACTIONS(2373),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2373),
    [anon_sym_decltype] = ACTIONS(2373),
    [anon_sym_explicit] = ACTIONS(2373),
    [anon_sym_typename] = ACTIONS(2373),
    [anon_sym_template] = ACTIONS(2373),
    [anon_sym_operator] = ACTIONS(2373),
    [anon_sym_friend] = ACTIONS(2373),
    [anon_sym_public] = ACTIONS(2373),
    [anon_sym_private] = ACTIONS(2373),
    [anon_sym_protected] = ACTIONS(2373),
    [anon_sym_using] = ACTIONS(2373),
    [anon_sym_static_assert] = ACTIONS(2373),
    [anon_sym___launch_bounds__] = ACTIONS(2373),
  },
  [STATE(1922)] = {
    [sym_identifier] = ACTIONS(2447),
    [aux_sym_preproc_def_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2447),
    [sym_preproc_directive] = ACTIONS(2447),
    [anon_sym_LPAREN2] = ACTIONS(2449),
    [anon_sym_TILDE] = ACTIONS(2449),
    [anon_sym_STAR] = ACTIONS(2449),
    [anon_sym_AMP_AMP] = ACTIONS(2449),
    [anon_sym_AMP] = ACTIONS(2447),
    [anon_sym_SEMI] = ACTIONS(2449),
    [anon_sym___extension__] = ACTIONS(2447),
    [anon_sym_typedef] = ACTIONS(2447),
    [anon_sym___device__] = ACTIONS(2447),
    [anon_sym___host__] = ACTIONS(2447),
    [anon_sym___global__] = ACTIONS(2447),
    [anon_sym___forceinline__] = ACTIONS(2447),
    [anon_sym___noinline__] = ACTIONS(2447),
    [anon_sym_virtual] = ACTIONS(2447),
    [anon_sym_extern] = ACTIONS(2447),
    [anon_sym___attribute__] = ACTIONS(2447),
    [anon_sym___attribute] = ACTIONS(2447),
    [anon_sym_COLON_COLON] = ACTIONS(2449),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2449),
    [anon_sym___declspec] = ACTIONS(2447),
    [anon_sym___based] = ACTIONS(2447),
    [anon_sym_RBRACE] = ACTIONS(2449),
    [anon_sym_signed] = ACTIONS(2447),
    [anon_sym_unsigned] = ACTIONS(2447),
    [anon_sym_long] = ACTIONS(2447),
    [anon_sym_short] = ACTIONS(2447),
    [anon_sym_LBRACK] = ACTIONS(2447),
    [anon_sym_static] = ACTIONS(2447),
    [anon_sym_register] = ACTIONS(2447),
    [anon_sym_inline] = ACTIONS(2447),
    [anon_sym___inline] = ACTIONS(2447),
    [anon_sym___inline__] = ACTIONS(2447),
    [anon_sym___forceinline] = ACTIONS(2447),
    [anon_sym_thread_local] = ACTIONS(2447),
    [anon_sym___thread] = ACTIONS(2447),
    [anon_sym_const] = ACTIONS(2447),
    [anon_sym_constexpr] = ACTIONS(2447),
    [anon_sym_volatile] = ACTIONS(2447),
    [anon_sym_restrict] = ACTIONS(2447),
    [anon_sym___restrict__] = ACTIONS(2447),
    [anon_sym__Atomic] = ACTIONS(2447),
    [anon_sym__Noreturn] = ACTIONS(2447),
    [anon_sym_noreturn] = ACTIONS(2447),
    [anon_sym__Nonnull] = ACTIONS(2447),
    [anon_sym_mutable] = ACTIONS(2447),
    [anon_sym_constinit] = ACTIONS(2447),
    [anon_sym_consteval] = ACTIONS(2447),
    [anon_sym___shared__] = ACTIONS(2447),
    [anon_sym___local__] = ACTIONS(2447),
    [anon_sym___constant__] = ACTIONS(2447),
    [anon_sym___managed__] = ACTIONS(2447),
    [anon_sym___grid_constant__] = ACTIONS(2447),
    [anon_sym_alignas] = ACTIONS(2447),
    [anon_sym__Alignas] = ACTIONS(2447),
    [sym_primitive_type] = ACTIONS(2447),
    [anon_sym_enum] = ACTIONS(2447),
    [anon_sym_class] = ACTIONS(2447),
    [anon_sym_struct] = ACTIONS(2447),
    [anon_sym_union] = ACTIONS(2447),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2447),
    [anon_sym_decltype] = ACTIONS(2447),
    [anon_sym_explicit] = ACTIONS(2447),
    [anon_sym_typename] = ACTIONS(2447),
    [anon_sym_template] = ACTIONS(2447),
    [anon_sym_operator] = ACTIONS(2447),
    [anon_sym_friend] = ACTIONS(2447),
    [anon_sym_public] = ACTIONS(2447),
    [anon_sym_private] = ACTIONS(2447),
    [anon_sym_protected] = ACTIONS(2447),
    [anon_sym_using] = ACTIONS(2447),
    [anon_sym_static_assert] = ACTIONS(2447),
    [anon_sym___launch_bounds__] = ACTIONS(2447),
  },
  [STATE(1923)] = {
    [sym_identifier] = ACTIONS(5565),
    [aux_sym_preproc_def_token1] = ACTIONS(5565),
    [aux_sym_preproc_if_token1] = ACTIONS(5565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5565),
    [sym_preproc_directive] = ACTIONS(5565),
    [anon_sym_LPAREN2] = ACTIONS(5567),
    [anon_sym_TILDE] = ACTIONS(5567),
    [anon_sym_STAR] = ACTIONS(5567),
    [anon_sym_AMP_AMP] = ACTIONS(5567),
    [anon_sym_AMP] = ACTIONS(5565),
    [anon_sym_SEMI] = ACTIONS(5567),
    [anon_sym___extension__] = ACTIONS(5565),
    [anon_sym_typedef] = ACTIONS(5565),
    [anon_sym___device__] = ACTIONS(5565),
    [anon_sym___host__] = ACTIONS(5565),
    [anon_sym___global__] = ACTIONS(5565),
    [anon_sym___forceinline__] = ACTIONS(5565),
    [anon_sym___noinline__] = ACTIONS(5565),
    [anon_sym_virtual] = ACTIONS(5565),
    [anon_sym_extern] = ACTIONS(5565),
    [anon_sym___attribute__] = ACTIONS(5565),
    [anon_sym___attribute] = ACTIONS(5565),
    [anon_sym_COLON_COLON] = ACTIONS(5567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5567),
    [anon_sym___declspec] = ACTIONS(5565),
    [anon_sym___based] = ACTIONS(5565),
    [anon_sym_RBRACE] = ACTIONS(5567),
    [anon_sym_signed] = ACTIONS(5565),
    [anon_sym_unsigned] = ACTIONS(5565),
    [anon_sym_long] = ACTIONS(5565),
    [anon_sym_short] = ACTIONS(5565),
    [anon_sym_LBRACK] = ACTIONS(5565),
    [anon_sym_static] = ACTIONS(5565),
    [anon_sym_register] = ACTIONS(5565),
    [anon_sym_inline] = ACTIONS(5565),
    [anon_sym___inline] = ACTIONS(5565),
    [anon_sym___inline__] = ACTIONS(5565),
    [anon_sym___forceinline] = ACTIONS(5565),
    [anon_sym_thread_local] = ACTIONS(5565),
    [anon_sym___thread] = ACTIONS(5565),
    [anon_sym_const] = ACTIONS(5565),
    [anon_sym_constexpr] = ACTIONS(5565),
    [anon_sym_volatile] = ACTIONS(5565),
    [anon_sym_restrict] = ACTIONS(5565),
    [anon_sym___restrict__] = ACTIONS(5565),
    [anon_sym__Atomic] = ACTIONS(5565),
    [anon_sym__Noreturn] = ACTIONS(5565),
    [anon_sym_noreturn] = ACTIONS(5565),
    [anon_sym__Nonnull] = ACTIONS(5565),
    [anon_sym_mutable] = ACTIONS(5565),
    [anon_sym_constinit] = ACTIONS(5565),
    [anon_sym_consteval] = ACTIONS(5565),
    [anon_sym___shared__] = ACTIONS(5565),
    [anon_sym___local__] = ACTIONS(5565),
    [anon_sym___constant__] = ACTIONS(5565),
    [anon_sym___managed__] = ACTIONS(5565),
    [anon_sym___grid_constant__] = ACTIONS(5565),
    [anon_sym_alignas] = ACTIONS(5565),
    [anon_sym__Alignas] = ACTIONS(5565),
    [sym_primitive_type] = ACTIONS(5565),
    [anon_sym_enum] = ACTIONS(5565),
    [anon_sym_class] = ACTIONS(5565),
    [anon_sym_struct] = ACTIONS(5565),
    [anon_sym_union] = ACTIONS(5565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5565),
    [anon_sym_decltype] = ACTIONS(5565),
    [anon_sym_explicit] = ACTIONS(5565),
    [anon_sym_typename] = ACTIONS(5565),
    [anon_sym_template] = ACTIONS(5565),
    [anon_sym_operator] = ACTIONS(5565),
    [anon_sym_friend] = ACTIONS(5565),
    [anon_sym_public] = ACTIONS(5565),
    [anon_sym_private] = ACTIONS(5565),
    [anon_sym_protected] = ACTIONS(5565),
    [anon_sym_using] = ACTIONS(5565),
    [anon_sym_static_assert] = ACTIONS(5565),
    [anon_sym___launch_bounds__] = ACTIONS(5565),
  },
  [STATE(1924)] = {
    [sym_identifier] = ACTIONS(5569),
    [aux_sym_preproc_def_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token1] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5569),
    [sym_preproc_directive] = ACTIONS(5569),
    [anon_sym_LPAREN2] = ACTIONS(5571),
    [anon_sym_TILDE] = ACTIONS(5571),
    [anon_sym_STAR] = ACTIONS(5571),
    [anon_sym_AMP_AMP] = ACTIONS(5571),
    [anon_sym_AMP] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym___extension__] = ACTIONS(5569),
    [anon_sym_typedef] = ACTIONS(5569),
    [anon_sym___device__] = ACTIONS(5569),
    [anon_sym___host__] = ACTIONS(5569),
    [anon_sym___global__] = ACTIONS(5569),
    [anon_sym___forceinline__] = ACTIONS(5569),
    [anon_sym___noinline__] = ACTIONS(5569),
    [anon_sym_virtual] = ACTIONS(5569),
    [anon_sym_extern] = ACTIONS(5569),
    [anon_sym___attribute__] = ACTIONS(5569),
    [anon_sym___attribute] = ACTIONS(5569),
    [anon_sym_COLON_COLON] = ACTIONS(5571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5571),
    [anon_sym___declspec] = ACTIONS(5569),
    [anon_sym___based] = ACTIONS(5569),
    [anon_sym_RBRACE] = ACTIONS(5571),
    [anon_sym_signed] = ACTIONS(5569),
    [anon_sym_unsigned] = ACTIONS(5569),
    [anon_sym_long] = ACTIONS(5569),
    [anon_sym_short] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5569),
    [anon_sym_static] = ACTIONS(5569),
    [anon_sym_register] = ACTIONS(5569),
    [anon_sym_inline] = ACTIONS(5569),
    [anon_sym___inline] = ACTIONS(5569),
    [anon_sym___inline__] = ACTIONS(5569),
    [anon_sym___forceinline] = ACTIONS(5569),
    [anon_sym_thread_local] = ACTIONS(5569),
    [anon_sym___thread] = ACTIONS(5569),
    [anon_sym_const] = ACTIONS(5569),
    [anon_sym_constexpr] = ACTIONS(5569),
    [anon_sym_volatile] = ACTIONS(5569),
    [anon_sym_restrict] = ACTIONS(5569),
    [anon_sym___restrict__] = ACTIONS(5569),
    [anon_sym__Atomic] = ACTIONS(5569),
    [anon_sym__Noreturn] = ACTIONS(5569),
    [anon_sym_noreturn] = ACTIONS(5569),
    [anon_sym__Nonnull] = ACTIONS(5569),
    [anon_sym_mutable] = ACTIONS(5569),
    [anon_sym_constinit] = ACTIONS(5569),
    [anon_sym_consteval] = ACTIONS(5569),
    [anon_sym___shared__] = ACTIONS(5569),
    [anon_sym___local__] = ACTIONS(5569),
    [anon_sym___constant__] = ACTIONS(5569),
    [anon_sym___managed__] = ACTIONS(5569),
    [anon_sym___grid_constant__] = ACTIONS(5569),
    [anon_sym_alignas] = ACTIONS(5569),
    [anon_sym__Alignas] = ACTIONS(5569),
    [sym_primitive_type] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_class] = ACTIONS(5569),
    [anon_sym_struct] = ACTIONS(5569),
    [anon_sym_union] = ACTIONS(5569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5569),
    [anon_sym_decltype] = ACTIONS(5569),
    [anon_sym_explicit] = ACTIONS(5569),
    [anon_sym_typename] = ACTIONS(5569),
    [anon_sym_template] = ACTIONS(5569),
    [anon_sym_operator] = ACTIONS(5569),
    [anon_sym_friend] = ACTIONS(5569),
    [anon_sym_public] = ACTIONS(5569),
    [anon_sym_private] = ACTIONS(5569),
    [anon_sym_protected] = ACTIONS(5569),
    [anon_sym_using] = ACTIONS(5569),
    [anon_sym_static_assert] = ACTIONS(5569),
    [anon_sym___launch_bounds__] = ACTIONS(5569),
  },
  [STATE(1925)] = {
    [sym_identifier] = ACTIONS(2218),
    [aux_sym_preproc_def_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2218),
    [sym_preproc_directive] = ACTIONS(2218),
    [anon_sym_LPAREN2] = ACTIONS(2220),
    [anon_sym_TILDE] = ACTIONS(2220),
    [anon_sym_STAR] = ACTIONS(2220),
    [anon_sym_AMP_AMP] = ACTIONS(2220),
    [anon_sym_AMP] = ACTIONS(2218),
    [anon_sym_SEMI] = ACTIONS(2220),
    [anon_sym___extension__] = ACTIONS(2218),
    [anon_sym_typedef] = ACTIONS(2218),
    [anon_sym___device__] = ACTIONS(2218),
    [anon_sym___host__] = ACTIONS(2218),
    [anon_sym___global__] = ACTIONS(2218),
    [anon_sym___forceinline__] = ACTIONS(2218),
    [anon_sym___noinline__] = ACTIONS(2218),
    [anon_sym_virtual] = ACTIONS(2218),
    [anon_sym_extern] = ACTIONS(2218),
    [anon_sym___attribute__] = ACTIONS(2218),
    [anon_sym___attribute] = ACTIONS(2218),
    [anon_sym_COLON_COLON] = ACTIONS(2220),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2220),
    [anon_sym___declspec] = ACTIONS(2218),
    [anon_sym___based] = ACTIONS(2218),
    [anon_sym_RBRACE] = ACTIONS(2220),
    [anon_sym_signed] = ACTIONS(2218),
    [anon_sym_unsigned] = ACTIONS(2218),
    [anon_sym_long] = ACTIONS(2218),
    [anon_sym_short] = ACTIONS(2218),
    [anon_sym_LBRACK] = ACTIONS(2218),
    [anon_sym_static] = ACTIONS(2218),
    [anon_sym_register] = ACTIONS(2218),
    [anon_sym_inline] = ACTIONS(2218),
    [anon_sym___inline] = ACTIONS(2218),
    [anon_sym___inline__] = ACTIONS(2218),
    [anon_sym___forceinline] = ACTIONS(2218),
    [anon_sym_thread_local] = ACTIONS(2218),
    [anon_sym___thread] = ACTIONS(2218),
    [anon_sym_const] = ACTIONS(2218),
    [anon_sym_constexpr] = ACTIONS(2218),
    [anon_sym_volatile] = ACTIONS(2218),
    [anon_sym_restrict] = ACTIONS(2218),
    [anon_sym___restrict__] = ACTIONS(2218),
    [anon_sym__Atomic] = ACTIONS(2218),
    [anon_sym__Noreturn] = ACTIONS(2218),
    [anon_sym_noreturn] = ACTIONS(2218),
    [anon_sym__Nonnull] = ACTIONS(2218),
    [anon_sym_mutable] = ACTIONS(2218),
    [anon_sym_constinit] = ACTIONS(2218),
    [anon_sym_consteval] = ACTIONS(2218),
    [anon_sym___shared__] = ACTIONS(2218),
    [anon_sym___local__] = ACTIONS(2218),
    [anon_sym___constant__] = ACTIONS(2218),
    [anon_sym___managed__] = ACTIONS(2218),
    [anon_sym___grid_constant__] = ACTIONS(2218),
    [anon_sym_alignas] = ACTIONS(2218),
    [anon_sym__Alignas] = ACTIONS(2218),
    [sym_primitive_type] = ACTIONS(2218),
    [anon_sym_enum] = ACTIONS(2218),
    [anon_sym_class] = ACTIONS(2218),
    [anon_sym_struct] = ACTIONS(2218),
    [anon_sym_union] = ACTIONS(2218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2218),
    [anon_sym_decltype] = ACTIONS(2218),
    [anon_sym_explicit] = ACTIONS(2218),
    [anon_sym_typename] = ACTIONS(2218),
    [anon_sym_template] = ACTIONS(2218),
    [anon_sym_operator] = ACTIONS(2218),
    [anon_sym_friend] = ACTIONS(2218),
    [anon_sym_public] = ACTIONS(2218),
    [anon_sym_private] = ACTIONS(2218),
    [anon_sym_protected] = ACTIONS(2218),
    [anon_sym_using] = ACTIONS(2218),
    [anon_sym_static_assert] = ACTIONS(2218),
    [anon_sym___launch_bounds__] = ACTIONS(2218),
  },
  [STATE(1926)] = {
    [sym_identifier] = ACTIONS(2044),
    [aux_sym_preproc_def_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2044),
    [sym_preproc_directive] = ACTIONS(2044),
    [anon_sym_LPAREN2] = ACTIONS(2046),
    [anon_sym_TILDE] = ACTIONS(2046),
    [anon_sym_STAR] = ACTIONS(2046),
    [anon_sym_AMP_AMP] = ACTIONS(2046),
    [anon_sym_AMP] = ACTIONS(2044),
    [anon_sym_SEMI] = ACTIONS(2046),
    [anon_sym___extension__] = ACTIONS(2044),
    [anon_sym_typedef] = ACTIONS(2044),
    [anon_sym___device__] = ACTIONS(2044),
    [anon_sym___host__] = ACTIONS(2044),
    [anon_sym___global__] = ACTIONS(2044),
    [anon_sym___forceinline__] = ACTIONS(2044),
    [anon_sym___noinline__] = ACTIONS(2044),
    [anon_sym_virtual] = ACTIONS(2044),
    [anon_sym_extern] = ACTIONS(2044),
    [anon_sym___attribute__] = ACTIONS(2044),
    [anon_sym___attribute] = ACTIONS(2044),
    [anon_sym_COLON_COLON] = ACTIONS(2046),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2046),
    [anon_sym___declspec] = ACTIONS(2044),
    [anon_sym___based] = ACTIONS(2044),
    [anon_sym_RBRACE] = ACTIONS(2046),
    [anon_sym_signed] = ACTIONS(2044),
    [anon_sym_unsigned] = ACTIONS(2044),
    [anon_sym_long] = ACTIONS(2044),
    [anon_sym_short] = ACTIONS(2044),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_static] = ACTIONS(2044),
    [anon_sym_register] = ACTIONS(2044),
    [anon_sym_inline] = ACTIONS(2044),
    [anon_sym___inline] = ACTIONS(2044),
    [anon_sym___inline__] = ACTIONS(2044),
    [anon_sym___forceinline] = ACTIONS(2044),
    [anon_sym_thread_local] = ACTIONS(2044),
    [anon_sym___thread] = ACTIONS(2044),
    [anon_sym_const] = ACTIONS(2044),
    [anon_sym_constexpr] = ACTIONS(2044),
    [anon_sym_volatile] = ACTIONS(2044),
    [anon_sym_restrict] = ACTIONS(2044),
    [anon_sym___restrict__] = ACTIONS(2044),
    [anon_sym__Atomic] = ACTIONS(2044),
    [anon_sym__Noreturn] = ACTIONS(2044),
    [anon_sym_noreturn] = ACTIONS(2044),
    [anon_sym__Nonnull] = ACTIONS(2044),
    [anon_sym_mutable] = ACTIONS(2044),
    [anon_sym_constinit] = ACTIONS(2044),
    [anon_sym_consteval] = ACTIONS(2044),
    [anon_sym___shared__] = ACTIONS(2044),
    [anon_sym___local__] = ACTIONS(2044),
    [anon_sym___constant__] = ACTIONS(2044),
    [anon_sym___managed__] = ACTIONS(2044),
    [anon_sym___grid_constant__] = ACTIONS(2044),
    [anon_sym_alignas] = ACTIONS(2044),
    [anon_sym__Alignas] = ACTIONS(2044),
    [sym_primitive_type] = ACTIONS(2044),
    [anon_sym_enum] = ACTIONS(2044),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2044),
    [anon_sym_union] = ACTIONS(2044),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2044),
    [anon_sym_decltype] = ACTIONS(2044),
    [anon_sym_explicit] = ACTIONS(2044),
    [anon_sym_typename] = ACTIONS(2044),
    [anon_sym_template] = ACTIONS(2044),
    [anon_sym_operator] = ACTIONS(2044),
    [anon_sym_friend] = ACTIONS(2044),
    [anon_sym_public] = ACTIONS(2044),
    [anon_sym_private] = ACTIONS(2044),
    [anon_sym_protected] = ACTIONS(2044),
    [anon_sym_using] = ACTIONS(2044),
    [anon_sym_static_assert] = ACTIONS(2044),
    [anon_sym___launch_bounds__] = ACTIONS(2044),
  },
  [STATE(1927)] = {
    [sym_identifier] = ACTIONS(5589),
    [aux_sym_preproc_def_token1] = ACTIONS(5589),
    [aux_sym_preproc_if_token1] = ACTIONS(5589),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5589),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5589),
    [sym_preproc_directive] = ACTIONS(5589),
    [anon_sym_LPAREN2] = ACTIONS(5591),
    [anon_sym_TILDE] = ACTIONS(5591),
    [anon_sym_STAR] = ACTIONS(5591),
    [anon_sym_AMP_AMP] = ACTIONS(5591),
    [anon_sym_AMP] = ACTIONS(5589),
    [anon_sym_SEMI] = ACTIONS(5591),
    [anon_sym___extension__] = ACTIONS(5589),
    [anon_sym_typedef] = ACTIONS(5589),
    [anon_sym___device__] = ACTIONS(5589),
    [anon_sym___host__] = ACTIONS(5589),
    [anon_sym___global__] = ACTIONS(5589),
    [anon_sym___forceinline__] = ACTIONS(5589),
    [anon_sym___noinline__] = ACTIONS(5589),
    [anon_sym_virtual] = ACTIONS(5589),
    [anon_sym_extern] = ACTIONS(5589),
    [anon_sym___attribute__] = ACTIONS(5589),
    [anon_sym___attribute] = ACTIONS(5589),
    [anon_sym_COLON_COLON] = ACTIONS(5591),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5591),
    [anon_sym___declspec] = ACTIONS(5589),
    [anon_sym___based] = ACTIONS(5589),
    [anon_sym_RBRACE] = ACTIONS(5591),
    [anon_sym_signed] = ACTIONS(5589),
    [anon_sym_unsigned] = ACTIONS(5589),
    [anon_sym_long] = ACTIONS(5589),
    [anon_sym_short] = ACTIONS(5589),
    [anon_sym_LBRACK] = ACTIONS(5589),
    [anon_sym_static] = ACTIONS(5589),
    [anon_sym_register] = ACTIONS(5589),
    [anon_sym_inline] = ACTIONS(5589),
    [anon_sym___inline] = ACTIONS(5589),
    [anon_sym___inline__] = ACTIONS(5589),
    [anon_sym___forceinline] = ACTIONS(5589),
    [anon_sym_thread_local] = ACTIONS(5589),
    [anon_sym___thread] = ACTIONS(5589),
    [anon_sym_const] = ACTIONS(5589),
    [anon_sym_constexpr] = ACTIONS(5589),
    [anon_sym_volatile] = ACTIONS(5589),
    [anon_sym_restrict] = ACTIONS(5589),
    [anon_sym___restrict__] = ACTIONS(5589),
    [anon_sym__Atomic] = ACTIONS(5589),
    [anon_sym__Noreturn] = ACTIONS(5589),
    [anon_sym_noreturn] = ACTIONS(5589),
    [anon_sym__Nonnull] = ACTIONS(5589),
    [anon_sym_mutable] = ACTIONS(5589),
    [anon_sym_constinit] = ACTIONS(5589),
    [anon_sym_consteval] = ACTIONS(5589),
    [anon_sym___shared__] = ACTIONS(5589),
    [anon_sym___local__] = ACTIONS(5589),
    [anon_sym___constant__] = ACTIONS(5589),
    [anon_sym___managed__] = ACTIONS(5589),
    [anon_sym___grid_constant__] = ACTIONS(5589),
    [anon_sym_alignas] = ACTIONS(5589),
    [anon_sym__Alignas] = ACTIONS(5589),
    [sym_primitive_type] = ACTIONS(5589),
    [anon_sym_enum] = ACTIONS(5589),
    [anon_sym_class] = ACTIONS(5589),
    [anon_sym_struct] = ACTIONS(5589),
    [anon_sym_union] = ACTIONS(5589),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5589),
    [anon_sym_decltype] = ACTIONS(5589),
    [anon_sym_explicit] = ACTIONS(5589),
    [anon_sym_typename] = ACTIONS(5589),
    [anon_sym_template] = ACTIONS(5589),
    [anon_sym_operator] = ACTIONS(5589),
    [anon_sym_friend] = ACTIONS(5589),
    [anon_sym_public] = ACTIONS(5589),
    [anon_sym_private] = ACTIONS(5589),
    [anon_sym_protected] = ACTIONS(5589),
    [anon_sym_using] = ACTIONS(5589),
    [anon_sym_static_assert] = ACTIONS(5589),
    [anon_sym___launch_bounds__] = ACTIONS(5589),
  },
  [STATE(1928)] = {
    [sym_identifier] = ACTIONS(5505),
    [aux_sym_preproc_def_token1] = ACTIONS(5505),
    [aux_sym_preproc_if_token1] = ACTIONS(5505),
    [aux_sym_preproc_if_token2] = ACTIONS(5505),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5505),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5505),
    [sym_preproc_directive] = ACTIONS(5505),
    [anon_sym_LPAREN2] = ACTIONS(5507),
    [anon_sym_TILDE] = ACTIONS(5507),
    [anon_sym_STAR] = ACTIONS(5507),
    [anon_sym_AMP_AMP] = ACTIONS(5507),
    [anon_sym_AMP] = ACTIONS(5505),
    [anon_sym_SEMI] = ACTIONS(5507),
    [anon_sym___extension__] = ACTIONS(5505),
    [anon_sym_typedef] = ACTIONS(5505),
    [anon_sym___device__] = ACTIONS(5505),
    [anon_sym___host__] = ACTIONS(5505),
    [anon_sym___global__] = ACTIONS(5505),
    [anon_sym___forceinline__] = ACTIONS(5505),
    [anon_sym___noinline__] = ACTIONS(5505),
    [anon_sym_virtual] = ACTIONS(5505),
    [anon_sym_extern] = ACTIONS(5505),
    [anon_sym___attribute__] = ACTIONS(5505),
    [anon_sym___attribute] = ACTIONS(5505),
    [anon_sym_COLON_COLON] = ACTIONS(5507),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5507),
    [anon_sym___declspec] = ACTIONS(5505),
    [anon_sym___based] = ACTIONS(5505),
    [anon_sym_signed] = ACTIONS(5505),
    [anon_sym_unsigned] = ACTIONS(5505),
    [anon_sym_long] = ACTIONS(5505),
    [anon_sym_short] = ACTIONS(5505),
    [anon_sym_LBRACK] = ACTIONS(5505),
    [anon_sym_static] = ACTIONS(5505),
    [anon_sym_register] = ACTIONS(5505),
    [anon_sym_inline] = ACTIONS(5505),
    [anon_sym___inline] = ACTIONS(5505),
    [anon_sym___inline__] = ACTIONS(5505),
    [anon_sym___forceinline] = ACTIONS(5505),
    [anon_sym_thread_local] = ACTIONS(5505),
    [anon_sym___thread] = ACTIONS(5505),
    [anon_sym_const] = ACTIONS(5505),
    [anon_sym_constexpr] = ACTIONS(5505),
    [anon_sym_volatile] = ACTIONS(5505),
    [anon_sym_restrict] = ACTIONS(5505),
    [anon_sym___restrict__] = ACTIONS(5505),
    [anon_sym__Atomic] = ACTIONS(5505),
    [anon_sym__Noreturn] = ACTIONS(5505),
    [anon_sym_noreturn] = ACTIONS(5505),
    [anon_sym__Nonnull] = ACTIONS(5505),
    [anon_sym_mutable] = ACTIONS(5505),
    [anon_sym_constinit] = ACTIONS(5505),
    [anon_sym_consteval] = ACTIONS(5505),
    [anon_sym___shared__] = ACTIONS(5505),
    [anon_sym___local__] = ACTIONS(5505),
    [anon_sym___constant__] = ACTIONS(5505),
    [anon_sym___managed__] = ACTIONS(5505),
    [anon_sym___grid_constant__] = ACTIONS(5505),
    [anon_sym_alignas] = ACTIONS(5505),
    [anon_sym__Alignas] = ACTIONS(5505),
    [sym_primitive_type] = ACTIONS(5505),
    [anon_sym_enum] = ACTIONS(5505),
    [anon_sym_class] = ACTIONS(5505),
    [anon_sym_struct] = ACTIONS(5505),
    [anon_sym_union] = ACTIONS(5505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5505),
    [anon_sym_decltype] = ACTIONS(5505),
    [anon_sym_explicit] = ACTIONS(5505),
    [anon_sym_typename] = ACTIONS(5505),
    [anon_sym_template] = ACTIONS(5505),
    [anon_sym_operator] = ACTIONS(5505),
    [anon_sym_friend] = ACTIONS(5505),
    [anon_sym_public] = ACTIONS(5505),
    [anon_sym_private] = ACTIONS(5505),
    [anon_sym_protected] = ACTIONS(5505),
    [anon_sym_using] = ACTIONS(5505),
    [anon_sym_static_assert] = ACTIONS(5505),
    [anon_sym___launch_bounds__] = ACTIONS(5505),
  },
  [STATE(1929)] = {
    [sym_identifier] = ACTIONS(5509),
    [aux_sym_preproc_def_token1] = ACTIONS(5509),
    [aux_sym_preproc_if_token1] = ACTIONS(5509),
    [aux_sym_preproc_if_token2] = ACTIONS(5509),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5509),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5509),
    [sym_preproc_directive] = ACTIONS(5509),
    [anon_sym_LPAREN2] = ACTIONS(5511),
    [anon_sym_TILDE] = ACTIONS(5511),
    [anon_sym_STAR] = ACTIONS(5511),
    [anon_sym_AMP_AMP] = ACTIONS(5511),
    [anon_sym_AMP] = ACTIONS(5509),
    [anon_sym_SEMI] = ACTIONS(5511),
    [anon_sym___extension__] = ACTIONS(5509),
    [anon_sym_typedef] = ACTIONS(5509),
    [anon_sym___device__] = ACTIONS(5509),
    [anon_sym___host__] = ACTIONS(5509),
    [anon_sym___global__] = ACTIONS(5509),
    [anon_sym___forceinline__] = ACTIONS(5509),
    [anon_sym___noinline__] = ACTIONS(5509),
    [anon_sym_virtual] = ACTIONS(5509),
    [anon_sym_extern] = ACTIONS(5509),
    [anon_sym___attribute__] = ACTIONS(5509),
    [anon_sym___attribute] = ACTIONS(5509),
    [anon_sym_COLON_COLON] = ACTIONS(5511),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5511),
    [anon_sym___declspec] = ACTIONS(5509),
    [anon_sym___based] = ACTIONS(5509),
    [anon_sym_signed] = ACTIONS(5509),
    [anon_sym_unsigned] = ACTIONS(5509),
    [anon_sym_long] = ACTIONS(5509),
    [anon_sym_short] = ACTIONS(5509),
    [anon_sym_LBRACK] = ACTIONS(5509),
    [anon_sym_static] = ACTIONS(5509),
    [anon_sym_register] = ACTIONS(5509),
    [anon_sym_inline] = ACTIONS(5509),
    [anon_sym___inline] = ACTIONS(5509),
    [anon_sym___inline__] = ACTIONS(5509),
    [anon_sym___forceinline] = ACTIONS(5509),
    [anon_sym_thread_local] = ACTIONS(5509),
    [anon_sym___thread] = ACTIONS(5509),
    [anon_sym_const] = ACTIONS(5509),
    [anon_sym_constexpr] = ACTIONS(5509),
    [anon_sym_volatile] = ACTIONS(5509),
    [anon_sym_restrict] = ACTIONS(5509),
    [anon_sym___restrict__] = ACTIONS(5509),
    [anon_sym__Atomic] = ACTIONS(5509),
    [anon_sym__Noreturn] = ACTIONS(5509),
    [anon_sym_noreturn] = ACTIONS(5509),
    [anon_sym__Nonnull] = ACTIONS(5509),
    [anon_sym_mutable] = ACTIONS(5509),
    [anon_sym_constinit] = ACTIONS(5509),
    [anon_sym_consteval] = ACTIONS(5509),
    [anon_sym___shared__] = ACTIONS(5509),
    [anon_sym___local__] = ACTIONS(5509),
    [anon_sym___constant__] = ACTIONS(5509),
    [anon_sym___managed__] = ACTIONS(5509),
    [anon_sym___grid_constant__] = ACTIONS(5509),
    [anon_sym_alignas] = ACTIONS(5509),
    [anon_sym__Alignas] = ACTIONS(5509),
    [sym_primitive_type] = ACTIONS(5509),
    [anon_sym_enum] = ACTIONS(5509),
    [anon_sym_class] = ACTIONS(5509),
    [anon_sym_struct] = ACTIONS(5509),
    [anon_sym_union] = ACTIONS(5509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5509),
    [anon_sym_decltype] = ACTIONS(5509),
    [anon_sym_explicit] = ACTIONS(5509),
    [anon_sym_typename] = ACTIONS(5509),
    [anon_sym_template] = ACTIONS(5509),
    [anon_sym_operator] = ACTIONS(5509),
    [anon_sym_friend] = ACTIONS(5509),
    [anon_sym_public] = ACTIONS(5509),
    [anon_sym_private] = ACTIONS(5509),
    [anon_sym_protected] = ACTIONS(5509),
    [anon_sym_using] = ACTIONS(5509),
    [anon_sym_static_assert] = ACTIONS(5509),
    [anon_sym___launch_bounds__] = ACTIONS(5509),
  },
  [STATE(1930)] = {
    [sym_identifier] = ACTIONS(5513),
    [aux_sym_preproc_def_token1] = ACTIONS(5513),
    [aux_sym_preproc_if_token1] = ACTIONS(5513),
    [aux_sym_preproc_if_token2] = ACTIONS(5513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5513),
    [sym_preproc_directive] = ACTIONS(5513),
    [anon_sym_LPAREN2] = ACTIONS(5515),
    [anon_sym_TILDE] = ACTIONS(5515),
    [anon_sym_STAR] = ACTIONS(5515),
    [anon_sym_AMP_AMP] = ACTIONS(5515),
    [anon_sym_AMP] = ACTIONS(5513),
    [anon_sym_SEMI] = ACTIONS(5515),
    [anon_sym___extension__] = ACTIONS(5513),
    [anon_sym_typedef] = ACTIONS(5513),
    [anon_sym___device__] = ACTIONS(5513),
    [anon_sym___host__] = ACTIONS(5513),
    [anon_sym___global__] = ACTIONS(5513),
    [anon_sym___forceinline__] = ACTIONS(5513),
    [anon_sym___noinline__] = ACTIONS(5513),
    [anon_sym_virtual] = ACTIONS(5513),
    [anon_sym_extern] = ACTIONS(5513),
    [anon_sym___attribute__] = ACTIONS(5513),
    [anon_sym___attribute] = ACTIONS(5513),
    [anon_sym_COLON_COLON] = ACTIONS(5515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5515),
    [anon_sym___declspec] = ACTIONS(5513),
    [anon_sym___based] = ACTIONS(5513),
    [anon_sym_signed] = ACTIONS(5513),
    [anon_sym_unsigned] = ACTIONS(5513),
    [anon_sym_long] = ACTIONS(5513),
    [anon_sym_short] = ACTIONS(5513),
    [anon_sym_LBRACK] = ACTIONS(5513),
    [anon_sym_static] = ACTIONS(5513),
    [anon_sym_register] = ACTIONS(5513),
    [anon_sym_inline] = ACTIONS(5513),
    [anon_sym___inline] = ACTIONS(5513),
    [anon_sym___inline__] = ACTIONS(5513),
    [anon_sym___forceinline] = ACTIONS(5513),
    [anon_sym_thread_local] = ACTIONS(5513),
    [anon_sym___thread] = ACTIONS(5513),
    [anon_sym_const] = ACTIONS(5513),
    [anon_sym_constexpr] = ACTIONS(5513),
    [anon_sym_volatile] = ACTIONS(5513),
    [anon_sym_restrict] = ACTIONS(5513),
    [anon_sym___restrict__] = ACTIONS(5513),
    [anon_sym__Atomic] = ACTIONS(5513),
    [anon_sym__Noreturn] = ACTIONS(5513),
    [anon_sym_noreturn] = ACTIONS(5513),
    [anon_sym__Nonnull] = ACTIONS(5513),
    [anon_sym_mutable] = ACTIONS(5513),
    [anon_sym_constinit] = ACTIONS(5513),
    [anon_sym_consteval] = ACTIONS(5513),
    [anon_sym___shared__] = ACTIONS(5513),
    [anon_sym___local__] = ACTIONS(5513),
    [anon_sym___constant__] = ACTIONS(5513),
    [anon_sym___managed__] = ACTIONS(5513),
    [anon_sym___grid_constant__] = ACTIONS(5513),
    [anon_sym_alignas] = ACTIONS(5513),
    [anon_sym__Alignas] = ACTIONS(5513),
    [sym_primitive_type] = ACTIONS(5513),
    [anon_sym_enum] = ACTIONS(5513),
    [anon_sym_class] = ACTIONS(5513),
    [anon_sym_struct] = ACTIONS(5513),
    [anon_sym_union] = ACTIONS(5513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5513),
    [anon_sym_decltype] = ACTIONS(5513),
    [anon_sym_explicit] = ACTIONS(5513),
    [anon_sym_typename] = ACTIONS(5513),
    [anon_sym_template] = ACTIONS(5513),
    [anon_sym_operator] = ACTIONS(5513),
    [anon_sym_friend] = ACTIONS(5513),
    [anon_sym_public] = ACTIONS(5513),
    [anon_sym_private] = ACTIONS(5513),
    [anon_sym_protected] = ACTIONS(5513),
    [anon_sym_using] = ACTIONS(5513),
    [anon_sym_static_assert] = ACTIONS(5513),
    [anon_sym___launch_bounds__] = ACTIONS(5513),
  },
  [STATE(1931)] = {
    [sym_identifier] = ACTIONS(2467),
    [aux_sym_preproc_def_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2467),
    [sym_preproc_directive] = ACTIONS(2467),
    [anon_sym_LPAREN2] = ACTIONS(2469),
    [anon_sym_TILDE] = ACTIONS(2469),
    [anon_sym_STAR] = ACTIONS(2469),
    [anon_sym_AMP_AMP] = ACTIONS(2469),
    [anon_sym_AMP] = ACTIONS(2467),
    [anon_sym_SEMI] = ACTIONS(2469),
    [anon_sym___extension__] = ACTIONS(2467),
    [anon_sym_typedef] = ACTIONS(2467),
    [anon_sym___device__] = ACTIONS(2467),
    [anon_sym___host__] = ACTIONS(2467),
    [anon_sym___global__] = ACTIONS(2467),
    [anon_sym___forceinline__] = ACTIONS(2467),
    [anon_sym___noinline__] = ACTIONS(2467),
    [anon_sym_virtual] = ACTIONS(2467),
    [anon_sym_extern] = ACTIONS(2467),
    [anon_sym___attribute__] = ACTIONS(2467),
    [anon_sym___attribute] = ACTIONS(2467),
    [anon_sym_COLON_COLON] = ACTIONS(2469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2469),
    [anon_sym___declspec] = ACTIONS(2467),
    [anon_sym___based] = ACTIONS(2467),
    [anon_sym_RBRACE] = ACTIONS(2469),
    [anon_sym_signed] = ACTIONS(2467),
    [anon_sym_unsigned] = ACTIONS(2467),
    [anon_sym_long] = ACTIONS(2467),
    [anon_sym_short] = ACTIONS(2467),
    [anon_sym_LBRACK] = ACTIONS(2467),
    [anon_sym_static] = ACTIONS(2467),
    [anon_sym_register] = ACTIONS(2467),
    [anon_sym_inline] = ACTIONS(2467),
    [anon_sym___inline] = ACTIONS(2467),
    [anon_sym___inline__] = ACTIONS(2467),
    [anon_sym___forceinline] = ACTIONS(2467),
    [anon_sym_thread_local] = ACTIONS(2467),
    [anon_sym___thread] = ACTIONS(2467),
    [anon_sym_const] = ACTIONS(2467),
    [anon_sym_constexpr] = ACTIONS(2467),
    [anon_sym_volatile] = ACTIONS(2467),
    [anon_sym_restrict] = ACTIONS(2467),
    [anon_sym___restrict__] = ACTIONS(2467),
    [anon_sym__Atomic] = ACTIONS(2467),
    [anon_sym__Noreturn] = ACTIONS(2467),
    [anon_sym_noreturn] = ACTIONS(2467),
    [anon_sym__Nonnull] = ACTIONS(2467),
    [anon_sym_mutable] = ACTIONS(2467),
    [anon_sym_constinit] = ACTIONS(2467),
    [anon_sym_consteval] = ACTIONS(2467),
    [anon_sym___shared__] = ACTIONS(2467),
    [anon_sym___local__] = ACTIONS(2467),
    [anon_sym___constant__] = ACTIONS(2467),
    [anon_sym___managed__] = ACTIONS(2467),
    [anon_sym___grid_constant__] = ACTIONS(2467),
    [anon_sym_alignas] = ACTIONS(2467),
    [anon_sym__Alignas] = ACTIONS(2467),
    [sym_primitive_type] = ACTIONS(2467),
    [anon_sym_enum] = ACTIONS(2467),
    [anon_sym_class] = ACTIONS(2467),
    [anon_sym_struct] = ACTIONS(2467),
    [anon_sym_union] = ACTIONS(2467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2467),
    [anon_sym_decltype] = ACTIONS(2467),
    [anon_sym_explicit] = ACTIONS(2467),
    [anon_sym_typename] = ACTIONS(2467),
    [anon_sym_template] = ACTIONS(2467),
    [anon_sym_operator] = ACTIONS(2467),
    [anon_sym_friend] = ACTIONS(2467),
    [anon_sym_public] = ACTIONS(2467),
    [anon_sym_private] = ACTIONS(2467),
    [anon_sym_protected] = ACTIONS(2467),
    [anon_sym_using] = ACTIONS(2467),
    [anon_sym_static_assert] = ACTIONS(2467),
    [anon_sym___launch_bounds__] = ACTIONS(2467),
  },
  [STATE(1932)] = {
    [sym_identifier] = ACTIONS(5593),
    [aux_sym_preproc_def_token1] = ACTIONS(5593),
    [aux_sym_preproc_if_token1] = ACTIONS(5593),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5593),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5593),
    [sym_preproc_directive] = ACTIONS(5593),
    [anon_sym_LPAREN2] = ACTIONS(5595),
    [anon_sym_TILDE] = ACTIONS(5595),
    [anon_sym_STAR] = ACTIONS(5595),
    [anon_sym_AMP_AMP] = ACTIONS(5595),
    [anon_sym_AMP] = ACTIONS(5593),
    [anon_sym_SEMI] = ACTIONS(5595),
    [anon_sym___extension__] = ACTIONS(5593),
    [anon_sym_typedef] = ACTIONS(5593),
    [anon_sym___device__] = ACTIONS(5593),
    [anon_sym___host__] = ACTIONS(5593),
    [anon_sym___global__] = ACTIONS(5593),
    [anon_sym___forceinline__] = ACTIONS(5593),
    [anon_sym___noinline__] = ACTIONS(5593),
    [anon_sym_virtual] = ACTIONS(5593),
    [anon_sym_extern] = ACTIONS(5593),
    [anon_sym___attribute__] = ACTIONS(5593),
    [anon_sym___attribute] = ACTIONS(5593),
    [anon_sym_COLON_COLON] = ACTIONS(5595),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5595),
    [anon_sym___declspec] = ACTIONS(5593),
    [anon_sym___based] = ACTIONS(5593),
    [anon_sym_RBRACE] = ACTIONS(5595),
    [anon_sym_signed] = ACTIONS(5593),
    [anon_sym_unsigned] = ACTIONS(5593),
    [anon_sym_long] = ACTIONS(5593),
    [anon_sym_short] = ACTIONS(5593),
    [anon_sym_LBRACK] = ACTIONS(5593),
    [anon_sym_static] = ACTIONS(5593),
    [anon_sym_register] = ACTIONS(5593),
    [anon_sym_inline] = ACTIONS(5593),
    [anon_sym___inline] = ACTIONS(5593),
    [anon_sym___inline__] = ACTIONS(5593),
    [anon_sym___forceinline] = ACTIONS(5593),
    [anon_sym_thread_local] = ACTIONS(5593),
    [anon_sym___thread] = ACTIONS(5593),
    [anon_sym_const] = ACTIONS(5593),
    [anon_sym_constexpr] = ACTIONS(5593),
    [anon_sym_volatile] = ACTIONS(5593),
    [anon_sym_restrict] = ACTIONS(5593),
    [anon_sym___restrict__] = ACTIONS(5593),
    [anon_sym__Atomic] = ACTIONS(5593),
    [anon_sym__Noreturn] = ACTIONS(5593),
    [anon_sym_noreturn] = ACTIONS(5593),
    [anon_sym__Nonnull] = ACTIONS(5593),
    [anon_sym_mutable] = ACTIONS(5593),
    [anon_sym_constinit] = ACTIONS(5593),
    [anon_sym_consteval] = ACTIONS(5593),
    [anon_sym___shared__] = ACTIONS(5593),
    [anon_sym___local__] = ACTIONS(5593),
    [anon_sym___constant__] = ACTIONS(5593),
    [anon_sym___managed__] = ACTIONS(5593),
    [anon_sym___grid_constant__] = ACTIONS(5593),
    [anon_sym_alignas] = ACTIONS(5593),
    [anon_sym__Alignas] = ACTIONS(5593),
    [sym_primitive_type] = ACTIONS(5593),
    [anon_sym_enum] = ACTIONS(5593),
    [anon_sym_class] = ACTIONS(5593),
    [anon_sym_struct] = ACTIONS(5593),
    [anon_sym_union] = ACTIONS(5593),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5593),
    [anon_sym_decltype] = ACTIONS(5593),
    [anon_sym_explicit] = ACTIONS(5593),
    [anon_sym_typename] = ACTIONS(5593),
    [anon_sym_template] = ACTIONS(5593),
    [anon_sym_operator] = ACTIONS(5593),
    [anon_sym_friend] = ACTIONS(5593),
    [anon_sym_public] = ACTIONS(5593),
    [anon_sym_private] = ACTIONS(5593),
    [anon_sym_protected] = ACTIONS(5593),
    [anon_sym_using] = ACTIONS(5593),
    [anon_sym_static_assert] = ACTIONS(5593),
    [anon_sym___launch_bounds__] = ACTIONS(5593),
  },
  [STATE(1933)] = {
    [sym_identifier] = ACTIONS(2613),
    [aux_sym_preproc_def_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2613),
    [sym_preproc_directive] = ACTIONS(2613),
    [anon_sym_LPAREN2] = ACTIONS(2615),
    [anon_sym_TILDE] = ACTIONS(2615),
    [anon_sym_STAR] = ACTIONS(2615),
    [anon_sym_AMP_AMP] = ACTIONS(2615),
    [anon_sym_AMP] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym___extension__] = ACTIONS(2613),
    [anon_sym_typedef] = ACTIONS(2613),
    [anon_sym___device__] = ACTIONS(2613),
    [anon_sym___host__] = ACTIONS(2613),
    [anon_sym___global__] = ACTIONS(2613),
    [anon_sym___forceinline__] = ACTIONS(2613),
    [anon_sym___noinline__] = ACTIONS(2613),
    [anon_sym_virtual] = ACTIONS(2613),
    [anon_sym_extern] = ACTIONS(2613),
    [anon_sym___attribute__] = ACTIONS(2613),
    [anon_sym___attribute] = ACTIONS(2613),
    [anon_sym_COLON_COLON] = ACTIONS(2615),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2615),
    [anon_sym___declspec] = ACTIONS(2613),
    [anon_sym___based] = ACTIONS(2613),
    [anon_sym_RBRACE] = ACTIONS(2615),
    [anon_sym_signed] = ACTIONS(2613),
    [anon_sym_unsigned] = ACTIONS(2613),
    [anon_sym_long] = ACTIONS(2613),
    [anon_sym_short] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2613),
    [anon_sym_static] = ACTIONS(2613),
    [anon_sym_register] = ACTIONS(2613),
    [anon_sym_inline] = ACTIONS(2613),
    [anon_sym___inline] = ACTIONS(2613),
    [anon_sym___inline__] = ACTIONS(2613),
    [anon_sym___forceinline] = ACTIONS(2613),
    [anon_sym_thread_local] = ACTIONS(2613),
    [anon_sym___thread] = ACTIONS(2613),
    [anon_sym_const] = ACTIONS(2613),
    [anon_sym_constexpr] = ACTIONS(2613),
    [anon_sym_volatile] = ACTIONS(2613),
    [anon_sym_restrict] = ACTIONS(2613),
    [anon_sym___restrict__] = ACTIONS(2613),
    [anon_sym__Atomic] = ACTIONS(2613),
    [anon_sym__Noreturn] = ACTIONS(2613),
    [anon_sym_noreturn] = ACTIONS(2613),
    [anon_sym__Nonnull] = ACTIONS(2613),
    [anon_sym_mutable] = ACTIONS(2613),
    [anon_sym_constinit] = ACTIONS(2613),
    [anon_sym_consteval] = ACTIONS(2613),
    [anon_sym___shared__] = ACTIONS(2613),
    [anon_sym___local__] = ACTIONS(2613),
    [anon_sym___constant__] = ACTIONS(2613),
    [anon_sym___managed__] = ACTIONS(2613),
    [anon_sym___grid_constant__] = ACTIONS(2613),
    [anon_sym_alignas] = ACTIONS(2613),
    [anon_sym__Alignas] = ACTIONS(2613),
    [sym_primitive_type] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_class] = ACTIONS(2613),
    [anon_sym_struct] = ACTIONS(2613),
    [anon_sym_union] = ACTIONS(2613),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2613),
    [anon_sym_decltype] = ACTIONS(2613),
    [anon_sym_explicit] = ACTIONS(2613),
    [anon_sym_typename] = ACTIONS(2613),
    [anon_sym_template] = ACTIONS(2613),
    [anon_sym_operator] = ACTIONS(2613),
    [anon_sym_friend] = ACTIONS(2613),
    [anon_sym_public] = ACTIONS(2613),
    [anon_sym_private] = ACTIONS(2613),
    [anon_sym_protected] = ACTIONS(2613),
    [anon_sym_using] = ACTIONS(2613),
    [anon_sym_static_assert] = ACTIONS(2613),
    [anon_sym___launch_bounds__] = ACTIONS(2613),
  },
  [STATE(1934)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym_RBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_friend] = ACTIONS(2234),
    [anon_sym_public] = ACTIONS(2234),
    [anon_sym_private] = ACTIONS(2234),
    [anon_sym_protected] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(1935)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym_RBRACE] = ACTIONS(2236),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_friend] = ACTIONS(2234),
    [anon_sym_public] = ACTIONS(2234),
    [anon_sym_private] = ACTIONS(2234),
    [anon_sym_protected] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(1936)] = {
    [sym_identifier] = ACTIONS(5573),
    [aux_sym_preproc_def_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token1] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5573),
    [sym_preproc_directive] = ACTIONS(5573),
    [anon_sym_LPAREN2] = ACTIONS(5575),
    [anon_sym_TILDE] = ACTIONS(5575),
    [anon_sym_STAR] = ACTIONS(5575),
    [anon_sym_AMP_AMP] = ACTIONS(5575),
    [anon_sym_AMP] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym___extension__] = ACTIONS(5573),
    [anon_sym_typedef] = ACTIONS(5573),
    [anon_sym___device__] = ACTIONS(5573),
    [anon_sym___host__] = ACTIONS(5573),
    [anon_sym___global__] = ACTIONS(5573),
    [anon_sym___forceinline__] = ACTIONS(5573),
    [anon_sym___noinline__] = ACTIONS(5573),
    [anon_sym_virtual] = ACTIONS(5573),
    [anon_sym_extern] = ACTIONS(5573),
    [anon_sym___attribute__] = ACTIONS(5573),
    [anon_sym___attribute] = ACTIONS(5573),
    [anon_sym_COLON_COLON] = ACTIONS(5575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5575),
    [anon_sym___declspec] = ACTIONS(5573),
    [anon_sym___based] = ACTIONS(5573),
    [anon_sym_RBRACE] = ACTIONS(5575),
    [anon_sym_signed] = ACTIONS(5573),
    [anon_sym_unsigned] = ACTIONS(5573),
    [anon_sym_long] = ACTIONS(5573),
    [anon_sym_short] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5573),
    [anon_sym_static] = ACTIONS(5573),
    [anon_sym_register] = ACTIONS(5573),
    [anon_sym_inline] = ACTIONS(5573),
    [anon_sym___inline] = ACTIONS(5573),
    [anon_sym___inline__] = ACTIONS(5573),
    [anon_sym___forceinline] = ACTIONS(5573),
    [anon_sym_thread_local] = ACTIONS(5573),
    [anon_sym___thread] = ACTIONS(5573),
    [anon_sym_const] = ACTIONS(5573),
    [anon_sym_constexpr] = ACTIONS(5573),
    [anon_sym_volatile] = ACTIONS(5573),
    [anon_sym_restrict] = ACTIONS(5573),
    [anon_sym___restrict__] = ACTIONS(5573),
    [anon_sym__Atomic] = ACTIONS(5573),
    [anon_sym__Noreturn] = ACTIONS(5573),
    [anon_sym_noreturn] = ACTIONS(5573),
    [anon_sym__Nonnull] = ACTIONS(5573),
    [anon_sym_mutable] = ACTIONS(5573),
    [anon_sym_constinit] = ACTIONS(5573),
    [anon_sym_consteval] = ACTIONS(5573),
    [anon_sym___shared__] = ACTIONS(5573),
    [anon_sym___local__] = ACTIONS(5573),
    [anon_sym___constant__] = ACTIONS(5573),
    [anon_sym___managed__] = ACTIONS(5573),
    [anon_sym___grid_constant__] = ACTIONS(5573),
    [anon_sym_alignas] = ACTIONS(5573),
    [anon_sym__Alignas] = ACTIONS(5573),
    [sym_primitive_type] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_class] = ACTIONS(5573),
    [anon_sym_struct] = ACTIONS(5573),
    [anon_sym_union] = ACTIONS(5573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5573),
    [anon_sym_decltype] = ACTIONS(5573),
    [anon_sym_explicit] = ACTIONS(5573),
    [anon_sym_typename] = ACTIONS(5573),
    [anon_sym_template] = ACTIONS(5573),
    [anon_sym_operator] = ACTIONS(5573),
    [anon_sym_friend] = ACTIONS(5573),
    [anon_sym_public] = ACTIONS(5573),
    [anon_sym_private] = ACTIONS(5573),
    [anon_sym_protected] = ACTIONS(5573),
    [anon_sym_using] = ACTIONS(5573),
    [anon_sym_static_assert] = ACTIONS(5573),
    [anon_sym___launch_bounds__] = ACTIONS(5573),
  },
  [STATE(1937)] = {
    [sym_identifier] = ACTIONS(5517),
    [aux_sym_preproc_def_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token2] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5517),
    [sym_preproc_directive] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5519),
    [anon_sym_TILDE] = ACTIONS(5519),
    [anon_sym_STAR] = ACTIONS(5519),
    [anon_sym_AMP_AMP] = ACTIONS(5519),
    [anon_sym_AMP] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym___extension__] = ACTIONS(5517),
    [anon_sym_typedef] = ACTIONS(5517),
    [anon_sym___device__] = ACTIONS(5517),
    [anon_sym___host__] = ACTIONS(5517),
    [anon_sym___global__] = ACTIONS(5517),
    [anon_sym___forceinline__] = ACTIONS(5517),
    [anon_sym___noinline__] = ACTIONS(5517),
    [anon_sym_virtual] = ACTIONS(5517),
    [anon_sym_extern] = ACTIONS(5517),
    [anon_sym___attribute__] = ACTIONS(5517),
    [anon_sym___attribute] = ACTIONS(5517),
    [anon_sym_COLON_COLON] = ACTIONS(5519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5519),
    [anon_sym___declspec] = ACTIONS(5517),
    [anon_sym___based] = ACTIONS(5517),
    [anon_sym_signed] = ACTIONS(5517),
    [anon_sym_unsigned] = ACTIONS(5517),
    [anon_sym_long] = ACTIONS(5517),
    [anon_sym_short] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5517),
    [anon_sym_static] = ACTIONS(5517),
    [anon_sym_register] = ACTIONS(5517),
    [anon_sym_inline] = ACTIONS(5517),
    [anon_sym___inline] = ACTIONS(5517),
    [anon_sym___inline__] = ACTIONS(5517),
    [anon_sym___forceinline] = ACTIONS(5517),
    [anon_sym_thread_local] = ACTIONS(5517),
    [anon_sym___thread] = ACTIONS(5517),
    [anon_sym_const] = ACTIONS(5517),
    [anon_sym_constexpr] = ACTIONS(5517),
    [anon_sym_volatile] = ACTIONS(5517),
    [anon_sym_restrict] = ACTIONS(5517),
    [anon_sym___restrict__] = ACTIONS(5517),
    [anon_sym__Atomic] = ACTIONS(5517),
    [anon_sym__Noreturn] = ACTIONS(5517),
    [anon_sym_noreturn] = ACTIONS(5517),
    [anon_sym__Nonnull] = ACTIONS(5517),
    [anon_sym_mutable] = ACTIONS(5517),
    [anon_sym_constinit] = ACTIONS(5517),
    [anon_sym_consteval] = ACTIONS(5517),
    [anon_sym___shared__] = ACTIONS(5517),
    [anon_sym___local__] = ACTIONS(5517),
    [anon_sym___constant__] = ACTIONS(5517),
    [anon_sym___managed__] = ACTIONS(5517),
    [anon_sym___grid_constant__] = ACTIONS(5517),
    [anon_sym_alignas] = ACTIONS(5517),
    [anon_sym__Alignas] = ACTIONS(5517),
    [sym_primitive_type] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_class] = ACTIONS(5517),
    [anon_sym_struct] = ACTIONS(5517),
    [anon_sym_union] = ACTIONS(5517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5517),
    [anon_sym_decltype] = ACTIONS(5517),
    [anon_sym_explicit] = ACTIONS(5517),
    [anon_sym_typename] = ACTIONS(5517),
    [anon_sym_template] = ACTIONS(5517),
    [anon_sym_operator] = ACTIONS(5517),
    [anon_sym_friend] = ACTIONS(5517),
    [anon_sym_public] = ACTIONS(5517),
    [anon_sym_private] = ACTIONS(5517),
    [anon_sym_protected] = ACTIONS(5517),
    [anon_sym_using] = ACTIONS(5517),
    [anon_sym_static_assert] = ACTIONS(5517),
    [anon_sym___launch_bounds__] = ACTIONS(5517),
  },
  [STATE(1938)] = {
    [sym_identifier] = ACTIONS(5577),
    [aux_sym_preproc_def_token1] = ACTIONS(5577),
    [aux_sym_preproc_if_token1] = ACTIONS(5577),
    [aux_sym_preproc_if_token2] = ACTIONS(5577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5577),
    [sym_preproc_directive] = ACTIONS(5577),
    [anon_sym_LPAREN2] = ACTIONS(5579),
    [anon_sym_TILDE] = ACTIONS(5579),
    [anon_sym_STAR] = ACTIONS(5579),
    [anon_sym_AMP_AMP] = ACTIONS(5579),
    [anon_sym_AMP] = ACTIONS(5577),
    [anon_sym_SEMI] = ACTIONS(5579),
    [anon_sym___extension__] = ACTIONS(5577),
    [anon_sym_typedef] = ACTIONS(5577),
    [anon_sym___device__] = ACTIONS(5577),
    [anon_sym___host__] = ACTIONS(5577),
    [anon_sym___global__] = ACTIONS(5577),
    [anon_sym___forceinline__] = ACTIONS(5577),
    [anon_sym___noinline__] = ACTIONS(5577),
    [anon_sym_virtual] = ACTIONS(5577),
    [anon_sym_extern] = ACTIONS(5577),
    [anon_sym___attribute__] = ACTIONS(5577),
    [anon_sym___attribute] = ACTIONS(5577),
    [anon_sym_COLON_COLON] = ACTIONS(5579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5579),
    [anon_sym___declspec] = ACTIONS(5577),
    [anon_sym___based] = ACTIONS(5577),
    [anon_sym_signed] = ACTIONS(5577),
    [anon_sym_unsigned] = ACTIONS(5577),
    [anon_sym_long] = ACTIONS(5577),
    [anon_sym_short] = ACTIONS(5577),
    [anon_sym_LBRACK] = ACTIONS(5577),
    [anon_sym_static] = ACTIONS(5577),
    [anon_sym_register] = ACTIONS(5577),
    [anon_sym_inline] = ACTIONS(5577),
    [anon_sym___inline] = ACTIONS(5577),
    [anon_sym___inline__] = ACTIONS(5577),
    [anon_sym___forceinline] = ACTIONS(5577),
    [anon_sym_thread_local] = ACTIONS(5577),
    [anon_sym___thread] = ACTIONS(5577),
    [anon_sym_const] = ACTIONS(5577),
    [anon_sym_constexpr] = ACTIONS(5577),
    [anon_sym_volatile] = ACTIONS(5577),
    [anon_sym_restrict] = ACTIONS(5577),
    [anon_sym___restrict__] = ACTIONS(5577),
    [anon_sym__Atomic] = ACTIONS(5577),
    [anon_sym__Noreturn] = ACTIONS(5577),
    [anon_sym_noreturn] = ACTIONS(5577),
    [anon_sym__Nonnull] = ACTIONS(5577),
    [anon_sym_mutable] = ACTIONS(5577),
    [anon_sym_constinit] = ACTIONS(5577),
    [anon_sym_consteval] = ACTIONS(5577),
    [anon_sym___shared__] = ACTIONS(5577),
    [anon_sym___local__] = ACTIONS(5577),
    [anon_sym___constant__] = ACTIONS(5577),
    [anon_sym___managed__] = ACTIONS(5577),
    [anon_sym___grid_constant__] = ACTIONS(5577),
    [anon_sym_alignas] = ACTIONS(5577),
    [anon_sym__Alignas] = ACTIONS(5577),
    [sym_primitive_type] = ACTIONS(5577),
    [anon_sym_enum] = ACTIONS(5577),
    [anon_sym_class] = ACTIONS(5577),
    [anon_sym_struct] = ACTIONS(5577),
    [anon_sym_union] = ACTIONS(5577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5577),
    [anon_sym_decltype] = ACTIONS(5577),
    [anon_sym_explicit] = ACTIONS(5577),
    [anon_sym_typename] = ACTIONS(5577),
    [anon_sym_template] = ACTIONS(5577),
    [anon_sym_operator] = ACTIONS(5577),
    [anon_sym_friend] = ACTIONS(5577),
    [anon_sym_public] = ACTIONS(5577),
    [anon_sym_private] = ACTIONS(5577),
    [anon_sym_protected] = ACTIONS(5577),
    [anon_sym_using] = ACTIONS(5577),
    [anon_sym_static_assert] = ACTIONS(5577),
    [anon_sym___launch_bounds__] = ACTIONS(5577),
  },
  [STATE(1939)] = {
    [sym_identifier] = ACTIONS(5581),
    [aux_sym_preproc_def_token1] = ACTIONS(5581),
    [aux_sym_preproc_if_token1] = ACTIONS(5581),
    [aux_sym_preproc_if_token2] = ACTIONS(5581),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5581),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5581),
    [sym_preproc_directive] = ACTIONS(5581),
    [anon_sym_LPAREN2] = ACTIONS(5583),
    [anon_sym_TILDE] = ACTIONS(5583),
    [anon_sym_STAR] = ACTIONS(5583),
    [anon_sym_AMP_AMP] = ACTIONS(5583),
    [anon_sym_AMP] = ACTIONS(5581),
    [anon_sym_SEMI] = ACTIONS(5583),
    [anon_sym___extension__] = ACTIONS(5581),
    [anon_sym_typedef] = ACTIONS(5581),
    [anon_sym___device__] = ACTIONS(5581),
    [anon_sym___host__] = ACTIONS(5581),
    [anon_sym___global__] = ACTIONS(5581),
    [anon_sym___forceinline__] = ACTIONS(5581),
    [anon_sym___noinline__] = ACTIONS(5581),
    [anon_sym_virtual] = ACTIONS(5581),
    [anon_sym_extern] = ACTIONS(5581),
    [anon_sym___attribute__] = ACTIONS(5581),
    [anon_sym___attribute] = ACTIONS(5581),
    [anon_sym_COLON_COLON] = ACTIONS(5583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5583),
    [anon_sym___declspec] = ACTIONS(5581),
    [anon_sym___based] = ACTIONS(5581),
    [anon_sym_signed] = ACTIONS(5581),
    [anon_sym_unsigned] = ACTIONS(5581),
    [anon_sym_long] = ACTIONS(5581),
    [anon_sym_short] = ACTIONS(5581),
    [anon_sym_LBRACK] = ACTIONS(5581),
    [anon_sym_static] = ACTIONS(5581),
    [anon_sym_register] = ACTIONS(5581),
    [anon_sym_inline] = ACTIONS(5581),
    [anon_sym___inline] = ACTIONS(5581),
    [anon_sym___inline__] = ACTIONS(5581),
    [anon_sym___forceinline] = ACTIONS(5581),
    [anon_sym_thread_local] = ACTIONS(5581),
    [anon_sym___thread] = ACTIONS(5581),
    [anon_sym_const] = ACTIONS(5581),
    [anon_sym_constexpr] = ACTIONS(5581),
    [anon_sym_volatile] = ACTIONS(5581),
    [anon_sym_restrict] = ACTIONS(5581),
    [anon_sym___restrict__] = ACTIONS(5581),
    [anon_sym__Atomic] = ACTIONS(5581),
    [anon_sym__Noreturn] = ACTIONS(5581),
    [anon_sym_noreturn] = ACTIONS(5581),
    [anon_sym__Nonnull] = ACTIONS(5581),
    [anon_sym_mutable] = ACTIONS(5581),
    [anon_sym_constinit] = ACTIONS(5581),
    [anon_sym_consteval] = ACTIONS(5581),
    [anon_sym___shared__] = ACTIONS(5581),
    [anon_sym___local__] = ACTIONS(5581),
    [anon_sym___constant__] = ACTIONS(5581),
    [anon_sym___managed__] = ACTIONS(5581),
    [anon_sym___grid_constant__] = ACTIONS(5581),
    [anon_sym_alignas] = ACTIONS(5581),
    [anon_sym__Alignas] = ACTIONS(5581),
    [sym_primitive_type] = ACTIONS(5581),
    [anon_sym_enum] = ACTIONS(5581),
    [anon_sym_class] = ACTIONS(5581),
    [anon_sym_struct] = ACTIONS(5581),
    [anon_sym_union] = ACTIONS(5581),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5581),
    [anon_sym_decltype] = ACTIONS(5581),
    [anon_sym_explicit] = ACTIONS(5581),
    [anon_sym_typename] = ACTIONS(5581),
    [anon_sym_template] = ACTIONS(5581),
    [anon_sym_operator] = ACTIONS(5581),
    [anon_sym_friend] = ACTIONS(5581),
    [anon_sym_public] = ACTIONS(5581),
    [anon_sym_private] = ACTIONS(5581),
    [anon_sym_protected] = ACTIONS(5581),
    [anon_sym_using] = ACTIONS(5581),
    [anon_sym_static_assert] = ACTIONS(5581),
    [anon_sym___launch_bounds__] = ACTIONS(5581),
  },
  [STATE(1940)] = {
    [sym_identifier] = ACTIONS(5517),
    [aux_sym_preproc_def_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token2] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5517),
    [sym_preproc_directive] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5519),
    [anon_sym_TILDE] = ACTIONS(5519),
    [anon_sym_STAR] = ACTIONS(5519),
    [anon_sym_AMP_AMP] = ACTIONS(5519),
    [anon_sym_AMP] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym___extension__] = ACTIONS(5517),
    [anon_sym_typedef] = ACTIONS(5517),
    [anon_sym___device__] = ACTIONS(5517),
    [anon_sym___host__] = ACTIONS(5517),
    [anon_sym___global__] = ACTIONS(5517),
    [anon_sym___forceinline__] = ACTIONS(5517),
    [anon_sym___noinline__] = ACTIONS(5517),
    [anon_sym_virtual] = ACTIONS(5517),
    [anon_sym_extern] = ACTIONS(5517),
    [anon_sym___attribute__] = ACTIONS(5517),
    [anon_sym___attribute] = ACTIONS(5517),
    [anon_sym_COLON_COLON] = ACTIONS(5519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5519),
    [anon_sym___declspec] = ACTIONS(5517),
    [anon_sym___based] = ACTIONS(5517),
    [anon_sym_signed] = ACTIONS(5517),
    [anon_sym_unsigned] = ACTIONS(5517),
    [anon_sym_long] = ACTIONS(5517),
    [anon_sym_short] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5517),
    [anon_sym_static] = ACTIONS(5517),
    [anon_sym_register] = ACTIONS(5517),
    [anon_sym_inline] = ACTIONS(5517),
    [anon_sym___inline] = ACTIONS(5517),
    [anon_sym___inline__] = ACTIONS(5517),
    [anon_sym___forceinline] = ACTIONS(5517),
    [anon_sym_thread_local] = ACTIONS(5517),
    [anon_sym___thread] = ACTIONS(5517),
    [anon_sym_const] = ACTIONS(5517),
    [anon_sym_constexpr] = ACTIONS(5517),
    [anon_sym_volatile] = ACTIONS(5517),
    [anon_sym_restrict] = ACTIONS(5517),
    [anon_sym___restrict__] = ACTIONS(5517),
    [anon_sym__Atomic] = ACTIONS(5517),
    [anon_sym__Noreturn] = ACTIONS(5517),
    [anon_sym_noreturn] = ACTIONS(5517),
    [anon_sym__Nonnull] = ACTIONS(5517),
    [anon_sym_mutable] = ACTIONS(5517),
    [anon_sym_constinit] = ACTIONS(5517),
    [anon_sym_consteval] = ACTIONS(5517),
    [anon_sym___shared__] = ACTIONS(5517),
    [anon_sym___local__] = ACTIONS(5517),
    [anon_sym___constant__] = ACTIONS(5517),
    [anon_sym___managed__] = ACTIONS(5517),
    [anon_sym___grid_constant__] = ACTIONS(5517),
    [anon_sym_alignas] = ACTIONS(5517),
    [anon_sym__Alignas] = ACTIONS(5517),
    [sym_primitive_type] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_class] = ACTIONS(5517),
    [anon_sym_struct] = ACTIONS(5517),
    [anon_sym_union] = ACTIONS(5517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5517),
    [anon_sym_decltype] = ACTIONS(5517),
    [anon_sym_explicit] = ACTIONS(5517),
    [anon_sym_typename] = ACTIONS(5517),
    [anon_sym_template] = ACTIONS(5517),
    [anon_sym_operator] = ACTIONS(5517),
    [anon_sym_friend] = ACTIONS(5517),
    [anon_sym_public] = ACTIONS(5517),
    [anon_sym_private] = ACTIONS(5517),
    [anon_sym_protected] = ACTIONS(5517),
    [anon_sym_using] = ACTIONS(5517),
    [anon_sym_static_assert] = ACTIONS(5517),
    [anon_sym___launch_bounds__] = ACTIONS(5517),
  },
  [STATE(1941)] = {
    [sym_identifier] = ACTIONS(5521),
    [aux_sym_preproc_def_token1] = ACTIONS(5521),
    [aux_sym_preproc_if_token1] = ACTIONS(5521),
    [aux_sym_preproc_if_token2] = ACTIONS(5521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5521),
    [sym_preproc_directive] = ACTIONS(5521),
    [anon_sym_LPAREN2] = ACTIONS(5523),
    [anon_sym_TILDE] = ACTIONS(5523),
    [anon_sym_STAR] = ACTIONS(5523),
    [anon_sym_AMP_AMP] = ACTIONS(5523),
    [anon_sym_AMP] = ACTIONS(5521),
    [anon_sym_SEMI] = ACTIONS(5523),
    [anon_sym___extension__] = ACTIONS(5521),
    [anon_sym_typedef] = ACTIONS(5521),
    [anon_sym___device__] = ACTIONS(5521),
    [anon_sym___host__] = ACTIONS(5521),
    [anon_sym___global__] = ACTIONS(5521),
    [anon_sym___forceinline__] = ACTIONS(5521),
    [anon_sym___noinline__] = ACTIONS(5521),
    [anon_sym_virtual] = ACTIONS(5521),
    [anon_sym_extern] = ACTIONS(5521),
    [anon_sym___attribute__] = ACTIONS(5521),
    [anon_sym___attribute] = ACTIONS(5521),
    [anon_sym_COLON_COLON] = ACTIONS(5523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5523),
    [anon_sym___declspec] = ACTIONS(5521),
    [anon_sym___based] = ACTIONS(5521),
    [anon_sym_signed] = ACTIONS(5521),
    [anon_sym_unsigned] = ACTIONS(5521),
    [anon_sym_long] = ACTIONS(5521),
    [anon_sym_short] = ACTIONS(5521),
    [anon_sym_LBRACK] = ACTIONS(5521),
    [anon_sym_static] = ACTIONS(5521),
    [anon_sym_register] = ACTIONS(5521),
    [anon_sym_inline] = ACTIONS(5521),
    [anon_sym___inline] = ACTIONS(5521),
    [anon_sym___inline__] = ACTIONS(5521),
    [anon_sym___forceinline] = ACTIONS(5521),
    [anon_sym_thread_local] = ACTIONS(5521),
    [anon_sym___thread] = ACTIONS(5521),
    [anon_sym_const] = ACTIONS(5521),
    [anon_sym_constexpr] = ACTIONS(5521),
    [anon_sym_volatile] = ACTIONS(5521),
    [anon_sym_restrict] = ACTIONS(5521),
    [anon_sym___restrict__] = ACTIONS(5521),
    [anon_sym__Atomic] = ACTIONS(5521),
    [anon_sym__Noreturn] = ACTIONS(5521),
    [anon_sym_noreturn] = ACTIONS(5521),
    [anon_sym__Nonnull] = ACTIONS(5521),
    [anon_sym_mutable] = ACTIONS(5521),
    [anon_sym_constinit] = ACTIONS(5521),
    [anon_sym_consteval] = ACTIONS(5521),
    [anon_sym___shared__] = ACTIONS(5521),
    [anon_sym___local__] = ACTIONS(5521),
    [anon_sym___constant__] = ACTIONS(5521),
    [anon_sym___managed__] = ACTIONS(5521),
    [anon_sym___grid_constant__] = ACTIONS(5521),
    [anon_sym_alignas] = ACTIONS(5521),
    [anon_sym__Alignas] = ACTIONS(5521),
    [sym_primitive_type] = ACTIONS(5521),
    [anon_sym_enum] = ACTIONS(5521),
    [anon_sym_class] = ACTIONS(5521),
    [anon_sym_struct] = ACTIONS(5521),
    [anon_sym_union] = ACTIONS(5521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5521),
    [anon_sym_decltype] = ACTIONS(5521),
    [anon_sym_explicit] = ACTIONS(5521),
    [anon_sym_typename] = ACTIONS(5521),
    [anon_sym_template] = ACTIONS(5521),
    [anon_sym_operator] = ACTIONS(5521),
    [anon_sym_friend] = ACTIONS(5521),
    [anon_sym_public] = ACTIONS(5521),
    [anon_sym_private] = ACTIONS(5521),
    [anon_sym_protected] = ACTIONS(5521),
    [anon_sym_using] = ACTIONS(5521),
    [anon_sym_static_assert] = ACTIONS(5521),
    [anon_sym___launch_bounds__] = ACTIONS(5521),
  },
  [STATE(1942)] = {
    [sym_identifier] = ACTIONS(5585),
    [aux_sym_preproc_def_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token2] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5585),
    [sym_preproc_directive] = ACTIONS(5585),
    [anon_sym_LPAREN2] = ACTIONS(5587),
    [anon_sym_TILDE] = ACTIONS(5587),
    [anon_sym_STAR] = ACTIONS(5587),
    [anon_sym_AMP_AMP] = ACTIONS(5587),
    [anon_sym_AMP] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym___extension__] = ACTIONS(5585),
    [anon_sym_typedef] = ACTIONS(5585),
    [anon_sym___device__] = ACTIONS(5585),
    [anon_sym___host__] = ACTIONS(5585),
    [anon_sym___global__] = ACTIONS(5585),
    [anon_sym___forceinline__] = ACTIONS(5585),
    [anon_sym___noinline__] = ACTIONS(5585),
    [anon_sym_virtual] = ACTIONS(5585),
    [anon_sym_extern] = ACTIONS(5585),
    [anon_sym___attribute__] = ACTIONS(5585),
    [anon_sym___attribute] = ACTIONS(5585),
    [anon_sym_COLON_COLON] = ACTIONS(5587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5587),
    [anon_sym___declspec] = ACTIONS(5585),
    [anon_sym___based] = ACTIONS(5585),
    [anon_sym_signed] = ACTIONS(5585),
    [anon_sym_unsigned] = ACTIONS(5585),
    [anon_sym_long] = ACTIONS(5585),
    [anon_sym_short] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5585),
    [anon_sym_static] = ACTIONS(5585),
    [anon_sym_register] = ACTIONS(5585),
    [anon_sym_inline] = ACTIONS(5585),
    [anon_sym___inline] = ACTIONS(5585),
    [anon_sym___inline__] = ACTIONS(5585),
    [anon_sym___forceinline] = ACTIONS(5585),
    [anon_sym_thread_local] = ACTIONS(5585),
    [anon_sym___thread] = ACTIONS(5585),
    [anon_sym_const] = ACTIONS(5585),
    [anon_sym_constexpr] = ACTIONS(5585),
    [anon_sym_volatile] = ACTIONS(5585),
    [anon_sym_restrict] = ACTIONS(5585),
    [anon_sym___restrict__] = ACTIONS(5585),
    [anon_sym__Atomic] = ACTIONS(5585),
    [anon_sym__Noreturn] = ACTIONS(5585),
    [anon_sym_noreturn] = ACTIONS(5585),
    [anon_sym__Nonnull] = ACTIONS(5585),
    [anon_sym_mutable] = ACTIONS(5585),
    [anon_sym_constinit] = ACTIONS(5585),
    [anon_sym_consteval] = ACTIONS(5585),
    [anon_sym___shared__] = ACTIONS(5585),
    [anon_sym___local__] = ACTIONS(5585),
    [anon_sym___constant__] = ACTIONS(5585),
    [anon_sym___managed__] = ACTIONS(5585),
    [anon_sym___grid_constant__] = ACTIONS(5585),
    [anon_sym_alignas] = ACTIONS(5585),
    [anon_sym__Alignas] = ACTIONS(5585),
    [sym_primitive_type] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_struct] = ACTIONS(5585),
    [anon_sym_union] = ACTIONS(5585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5585),
    [anon_sym_decltype] = ACTIONS(5585),
    [anon_sym_explicit] = ACTIONS(5585),
    [anon_sym_typename] = ACTIONS(5585),
    [anon_sym_template] = ACTIONS(5585),
    [anon_sym_operator] = ACTIONS(5585),
    [anon_sym_friend] = ACTIONS(5585),
    [anon_sym_public] = ACTIONS(5585),
    [anon_sym_private] = ACTIONS(5585),
    [anon_sym_protected] = ACTIONS(5585),
    [anon_sym_using] = ACTIONS(5585),
    [anon_sym_static_assert] = ACTIONS(5585),
    [anon_sym___launch_bounds__] = ACTIONS(5585),
  },
  [STATE(1943)] = {
    [sym_identifier] = ACTIONS(2028),
    [aux_sym_preproc_def_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token2] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2028),
    [sym_preproc_directive] = ACTIONS(2028),
    [anon_sym_LPAREN2] = ACTIONS(2030),
    [anon_sym_TILDE] = ACTIONS(2030),
    [anon_sym_STAR] = ACTIONS(2030),
    [anon_sym_AMP_AMP] = ACTIONS(2030),
    [anon_sym_AMP] = ACTIONS(2028),
    [anon_sym_SEMI] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(2028),
    [anon_sym_typedef] = ACTIONS(2028),
    [anon_sym___device__] = ACTIONS(2028),
    [anon_sym___host__] = ACTIONS(2028),
    [anon_sym___global__] = ACTIONS(2028),
    [anon_sym___forceinline__] = ACTIONS(2028),
    [anon_sym___noinline__] = ACTIONS(2028),
    [anon_sym_virtual] = ACTIONS(2028),
    [anon_sym_extern] = ACTIONS(2028),
    [anon_sym___attribute__] = ACTIONS(2028),
    [anon_sym___attribute] = ACTIONS(2028),
    [anon_sym_COLON_COLON] = ACTIONS(2030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2030),
    [anon_sym___declspec] = ACTIONS(2028),
    [anon_sym___based] = ACTIONS(2028),
    [anon_sym_signed] = ACTIONS(2028),
    [anon_sym_unsigned] = ACTIONS(2028),
    [anon_sym_long] = ACTIONS(2028),
    [anon_sym_short] = ACTIONS(2028),
    [anon_sym_LBRACK] = ACTIONS(2028),
    [anon_sym_static] = ACTIONS(2028),
    [anon_sym_register] = ACTIONS(2028),
    [anon_sym_inline] = ACTIONS(2028),
    [anon_sym___inline] = ACTIONS(2028),
    [anon_sym___inline__] = ACTIONS(2028),
    [anon_sym___forceinline] = ACTIONS(2028),
    [anon_sym_thread_local] = ACTIONS(2028),
    [anon_sym___thread] = ACTIONS(2028),
    [anon_sym_const] = ACTIONS(2028),
    [anon_sym_constexpr] = ACTIONS(2028),
    [anon_sym_volatile] = ACTIONS(2028),
    [anon_sym_restrict] = ACTIONS(2028),
    [anon_sym___restrict__] = ACTIONS(2028),
    [anon_sym__Atomic] = ACTIONS(2028),
    [anon_sym__Noreturn] = ACTIONS(2028),
    [anon_sym_noreturn] = ACTIONS(2028),
    [anon_sym__Nonnull] = ACTIONS(2028),
    [anon_sym_mutable] = ACTIONS(2028),
    [anon_sym_constinit] = ACTIONS(2028),
    [anon_sym_consteval] = ACTIONS(2028),
    [anon_sym___shared__] = ACTIONS(2028),
    [anon_sym___local__] = ACTIONS(2028),
    [anon_sym___constant__] = ACTIONS(2028),
    [anon_sym___managed__] = ACTIONS(2028),
    [anon_sym___grid_constant__] = ACTIONS(2028),
    [anon_sym_alignas] = ACTIONS(2028),
    [anon_sym__Alignas] = ACTIONS(2028),
    [sym_primitive_type] = ACTIONS(2028),
    [anon_sym_enum] = ACTIONS(2028),
    [anon_sym_class] = ACTIONS(2028),
    [anon_sym_struct] = ACTIONS(2028),
    [anon_sym_union] = ACTIONS(2028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2028),
    [anon_sym_decltype] = ACTIONS(2028),
    [anon_sym_explicit] = ACTIONS(2028),
    [anon_sym_typename] = ACTIONS(2028),
    [anon_sym_template] = ACTIONS(2028),
    [anon_sym_operator] = ACTIONS(2028),
    [anon_sym_friend] = ACTIONS(2028),
    [anon_sym_public] = ACTIONS(2028),
    [anon_sym_private] = ACTIONS(2028),
    [anon_sym_protected] = ACTIONS(2028),
    [anon_sym_using] = ACTIONS(2028),
    [anon_sym_static_assert] = ACTIONS(2028),
    [anon_sym___launch_bounds__] = ACTIONS(2028),
  },
  [STATE(1944)] = {
    [sym_identifier] = ACTIONS(5655),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5657),
    [anon_sym_COMMA] = ACTIONS(5657),
    [anon_sym_RPAREN] = ACTIONS(5657),
    [anon_sym_LPAREN2] = ACTIONS(5657),
    [anon_sym_DASH] = ACTIONS(5655),
    [anon_sym_PLUS] = ACTIONS(5655),
    [anon_sym_STAR] = ACTIONS(5657),
    [anon_sym_SLASH] = ACTIONS(5655),
    [anon_sym_PERCENT] = ACTIONS(5657),
    [anon_sym_PIPE_PIPE] = ACTIONS(5657),
    [anon_sym_AMP_AMP] = ACTIONS(5657),
    [anon_sym_PIPE] = ACTIONS(5655),
    [anon_sym_CARET] = ACTIONS(5657),
    [anon_sym_AMP] = ACTIONS(5655),
    [anon_sym_EQ_EQ] = ACTIONS(5657),
    [anon_sym_BANG_EQ] = ACTIONS(5657),
    [anon_sym_GT] = ACTIONS(5655),
    [anon_sym_GT_EQ] = ACTIONS(5657),
    [anon_sym_LT_EQ] = ACTIONS(5655),
    [anon_sym_LT] = ACTIONS(5655),
    [anon_sym_LT_LT] = ACTIONS(5655),
    [anon_sym_GT_GT] = ACTIONS(5657),
    [anon_sym_SEMI] = ACTIONS(5657),
    [anon_sym___extension__] = ACTIONS(5655),
    [anon_sym___global__] = ACTIONS(5655),
    [anon_sym___attribute__] = ACTIONS(5655),
    [anon_sym___attribute] = ACTIONS(5655),
    [anon_sym_COLON_COLON] = ACTIONS(5657),
    [anon_sym___based] = ACTIONS(5655),
    [anon_sym_LBRACE] = ACTIONS(5657),
    [anon_sym_RBRACE] = ACTIONS(5657),
    [anon_sym_signed] = ACTIONS(5655),
    [anon_sym_unsigned] = ACTIONS(5655),
    [anon_sym_long] = ACTIONS(5655),
    [anon_sym_short] = ACTIONS(5655),
    [anon_sym_LBRACK] = ACTIONS(5657),
    [anon_sym_RBRACK] = ACTIONS(5657),
    [anon_sym_const] = ACTIONS(5655),
    [anon_sym_constexpr] = ACTIONS(5655),
    [anon_sym_volatile] = ACTIONS(5655),
    [anon_sym_restrict] = ACTIONS(5655),
    [anon_sym___restrict__] = ACTIONS(5655),
    [anon_sym__Atomic] = ACTIONS(5655),
    [anon_sym__Noreturn] = ACTIONS(5655),
    [anon_sym_noreturn] = ACTIONS(5655),
    [anon_sym__Nonnull] = ACTIONS(5655),
    [anon_sym_mutable] = ACTIONS(5655),
    [anon_sym_constinit] = ACTIONS(5655),
    [anon_sym_consteval] = ACTIONS(5655),
    [anon_sym___shared__] = ACTIONS(5655),
    [anon_sym___local__] = ACTIONS(5655),
    [anon_sym___constant__] = ACTIONS(5655),
    [anon_sym___managed__] = ACTIONS(5655),
    [anon_sym___grid_constant__] = ACTIONS(5655),
    [anon_sym_alignas] = ACTIONS(5655),
    [anon_sym__Alignas] = ACTIONS(5655),
    [sym_primitive_type] = ACTIONS(5655),
    [anon_sym_COLON] = ACTIONS(5655),
    [anon_sym_QMARK] = ACTIONS(5657),
    [anon_sym_LT_EQ_GT] = ACTIONS(5657),
    [anon_sym_or] = ACTIONS(5655),
    [anon_sym_and] = ACTIONS(5655),
    [anon_sym_bitor] = ACTIONS(5655),
    [anon_sym_xor] = ACTIONS(5655),
    [anon_sym_bitand] = ACTIONS(5655),
    [anon_sym_not_eq] = ACTIONS(5655),
    [anon_sym_DASH_DASH] = ACTIONS(5657),
    [anon_sym_PLUS_PLUS] = ACTIONS(5657),
    [anon_sym_DOT] = ACTIONS(5655),
    [anon_sym_DOT_STAR] = ACTIONS(5657),
    [anon_sym_DASH_GT] = ACTIONS(5657),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5655),
    [anon_sym_decltype] = ACTIONS(5655),
    [anon_sym_final] = ACTIONS(5655),
    [anon_sym_override] = ACTIONS(5655),
    [anon_sym_requires] = ACTIONS(5655),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5657),
  },
  [STATE(1945)] = {
    [sym_identifier] = ACTIONS(5525),
    [aux_sym_preproc_def_token1] = ACTIONS(5525),
    [aux_sym_preproc_if_token1] = ACTIONS(5525),
    [aux_sym_preproc_if_token2] = ACTIONS(5525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5525),
    [sym_preproc_directive] = ACTIONS(5525),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_TILDE] = ACTIONS(5527),
    [anon_sym_STAR] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___extension__] = ACTIONS(5525),
    [anon_sym_typedef] = ACTIONS(5525),
    [anon_sym___device__] = ACTIONS(5525),
    [anon_sym___host__] = ACTIONS(5525),
    [anon_sym___global__] = ACTIONS(5525),
    [anon_sym___forceinline__] = ACTIONS(5525),
    [anon_sym___noinline__] = ACTIONS(5525),
    [anon_sym_virtual] = ACTIONS(5525),
    [anon_sym_extern] = ACTIONS(5525),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym___attribute] = ACTIONS(5525),
    [anon_sym_COLON_COLON] = ACTIONS(5527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5527),
    [anon_sym___declspec] = ACTIONS(5525),
    [anon_sym___based] = ACTIONS(5525),
    [anon_sym_signed] = ACTIONS(5525),
    [anon_sym_unsigned] = ACTIONS(5525),
    [anon_sym_long] = ACTIONS(5525),
    [anon_sym_short] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5525),
    [anon_sym_static] = ACTIONS(5525),
    [anon_sym_register] = ACTIONS(5525),
    [anon_sym_inline] = ACTIONS(5525),
    [anon_sym___inline] = ACTIONS(5525),
    [anon_sym___inline__] = ACTIONS(5525),
    [anon_sym___forceinline] = ACTIONS(5525),
    [anon_sym_thread_local] = ACTIONS(5525),
    [anon_sym___thread] = ACTIONS(5525),
    [anon_sym_const] = ACTIONS(5525),
    [anon_sym_constexpr] = ACTIONS(5525),
    [anon_sym_volatile] = ACTIONS(5525),
    [anon_sym_restrict] = ACTIONS(5525),
    [anon_sym___restrict__] = ACTIONS(5525),
    [anon_sym__Atomic] = ACTIONS(5525),
    [anon_sym__Noreturn] = ACTIONS(5525),
    [anon_sym_noreturn] = ACTIONS(5525),
    [anon_sym__Nonnull] = ACTIONS(5525),
    [anon_sym_mutable] = ACTIONS(5525),
    [anon_sym_constinit] = ACTIONS(5525),
    [anon_sym_consteval] = ACTIONS(5525),
    [anon_sym___shared__] = ACTIONS(5525),
    [anon_sym___local__] = ACTIONS(5525),
    [anon_sym___constant__] = ACTIONS(5525),
    [anon_sym___managed__] = ACTIONS(5525),
    [anon_sym___grid_constant__] = ACTIONS(5525),
    [anon_sym_alignas] = ACTIONS(5525),
    [anon_sym__Alignas] = ACTIONS(5525),
    [sym_primitive_type] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_class] = ACTIONS(5525),
    [anon_sym_struct] = ACTIONS(5525),
    [anon_sym_union] = ACTIONS(5525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
    [anon_sym_explicit] = ACTIONS(5525),
    [anon_sym_typename] = ACTIONS(5525),
    [anon_sym_template] = ACTIONS(5525),
    [anon_sym_operator] = ACTIONS(5525),
    [anon_sym_friend] = ACTIONS(5525),
    [anon_sym_public] = ACTIONS(5525),
    [anon_sym_private] = ACTIONS(5525),
    [anon_sym_protected] = ACTIONS(5525),
    [anon_sym_using] = ACTIONS(5525),
    [anon_sym_static_assert] = ACTIONS(5525),
    [anon_sym___launch_bounds__] = ACTIONS(5525),
  },
  [STATE(1946)] = {
    [sym_identifier] = ACTIONS(5585),
    [aux_sym_preproc_def_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token2] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5585),
    [sym_preproc_directive] = ACTIONS(5585),
    [anon_sym_LPAREN2] = ACTIONS(5587),
    [anon_sym_TILDE] = ACTIONS(5587),
    [anon_sym_STAR] = ACTIONS(5587),
    [anon_sym_AMP_AMP] = ACTIONS(5587),
    [anon_sym_AMP] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym___extension__] = ACTIONS(5585),
    [anon_sym_typedef] = ACTIONS(5585),
    [anon_sym___device__] = ACTIONS(5585),
    [anon_sym___host__] = ACTIONS(5585),
    [anon_sym___global__] = ACTIONS(5585),
    [anon_sym___forceinline__] = ACTIONS(5585),
    [anon_sym___noinline__] = ACTIONS(5585),
    [anon_sym_virtual] = ACTIONS(5585),
    [anon_sym_extern] = ACTIONS(5585),
    [anon_sym___attribute__] = ACTIONS(5585),
    [anon_sym___attribute] = ACTIONS(5585),
    [anon_sym_COLON_COLON] = ACTIONS(5587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5587),
    [anon_sym___declspec] = ACTIONS(5585),
    [anon_sym___based] = ACTIONS(5585),
    [anon_sym_signed] = ACTIONS(5585),
    [anon_sym_unsigned] = ACTIONS(5585),
    [anon_sym_long] = ACTIONS(5585),
    [anon_sym_short] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5585),
    [anon_sym_static] = ACTIONS(5585),
    [anon_sym_register] = ACTIONS(5585),
    [anon_sym_inline] = ACTIONS(5585),
    [anon_sym___inline] = ACTIONS(5585),
    [anon_sym___inline__] = ACTIONS(5585),
    [anon_sym___forceinline] = ACTIONS(5585),
    [anon_sym_thread_local] = ACTIONS(5585),
    [anon_sym___thread] = ACTIONS(5585),
    [anon_sym_const] = ACTIONS(5585),
    [anon_sym_constexpr] = ACTIONS(5585),
    [anon_sym_volatile] = ACTIONS(5585),
    [anon_sym_restrict] = ACTIONS(5585),
    [anon_sym___restrict__] = ACTIONS(5585),
    [anon_sym__Atomic] = ACTIONS(5585),
    [anon_sym__Noreturn] = ACTIONS(5585),
    [anon_sym_noreturn] = ACTIONS(5585),
    [anon_sym__Nonnull] = ACTIONS(5585),
    [anon_sym_mutable] = ACTIONS(5585),
    [anon_sym_constinit] = ACTIONS(5585),
    [anon_sym_consteval] = ACTIONS(5585),
    [anon_sym___shared__] = ACTIONS(5585),
    [anon_sym___local__] = ACTIONS(5585),
    [anon_sym___constant__] = ACTIONS(5585),
    [anon_sym___managed__] = ACTIONS(5585),
    [anon_sym___grid_constant__] = ACTIONS(5585),
    [anon_sym_alignas] = ACTIONS(5585),
    [anon_sym__Alignas] = ACTIONS(5585),
    [sym_primitive_type] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_struct] = ACTIONS(5585),
    [anon_sym_union] = ACTIONS(5585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5585),
    [anon_sym_decltype] = ACTIONS(5585),
    [anon_sym_explicit] = ACTIONS(5585),
    [anon_sym_typename] = ACTIONS(5585),
    [anon_sym_template] = ACTIONS(5585),
    [anon_sym_operator] = ACTIONS(5585),
    [anon_sym_friend] = ACTIONS(5585),
    [anon_sym_public] = ACTIONS(5585),
    [anon_sym_private] = ACTIONS(5585),
    [anon_sym_protected] = ACTIONS(5585),
    [anon_sym_using] = ACTIONS(5585),
    [anon_sym_static_assert] = ACTIONS(5585),
    [anon_sym___launch_bounds__] = ACTIONS(5585),
  },
  [STATE(1947)] = {
    [sym_identifier] = ACTIONS(5569),
    [aux_sym_preproc_def_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token1] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5569),
    [sym_preproc_directive] = ACTIONS(5569),
    [anon_sym_LPAREN2] = ACTIONS(5571),
    [anon_sym_TILDE] = ACTIONS(5571),
    [anon_sym_STAR] = ACTIONS(5571),
    [anon_sym_AMP_AMP] = ACTIONS(5571),
    [anon_sym_AMP] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym___extension__] = ACTIONS(5569),
    [anon_sym_typedef] = ACTIONS(5569),
    [anon_sym___device__] = ACTIONS(5569),
    [anon_sym___host__] = ACTIONS(5569),
    [anon_sym___global__] = ACTIONS(5569),
    [anon_sym___forceinline__] = ACTIONS(5569),
    [anon_sym___noinline__] = ACTIONS(5569),
    [anon_sym_virtual] = ACTIONS(5569),
    [anon_sym_extern] = ACTIONS(5569),
    [anon_sym___attribute__] = ACTIONS(5569),
    [anon_sym___attribute] = ACTIONS(5569),
    [anon_sym_COLON_COLON] = ACTIONS(5571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5571),
    [anon_sym___declspec] = ACTIONS(5569),
    [anon_sym___based] = ACTIONS(5569),
    [anon_sym_RBRACE] = ACTIONS(5571),
    [anon_sym_signed] = ACTIONS(5569),
    [anon_sym_unsigned] = ACTIONS(5569),
    [anon_sym_long] = ACTIONS(5569),
    [anon_sym_short] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5569),
    [anon_sym_static] = ACTIONS(5569),
    [anon_sym_register] = ACTIONS(5569),
    [anon_sym_inline] = ACTIONS(5569),
    [anon_sym___inline] = ACTIONS(5569),
    [anon_sym___inline__] = ACTIONS(5569),
    [anon_sym___forceinline] = ACTIONS(5569),
    [anon_sym_thread_local] = ACTIONS(5569),
    [anon_sym___thread] = ACTIONS(5569),
    [anon_sym_const] = ACTIONS(5569),
    [anon_sym_constexpr] = ACTIONS(5569),
    [anon_sym_volatile] = ACTIONS(5569),
    [anon_sym_restrict] = ACTIONS(5569),
    [anon_sym___restrict__] = ACTIONS(5569),
    [anon_sym__Atomic] = ACTIONS(5569),
    [anon_sym__Noreturn] = ACTIONS(5569),
    [anon_sym_noreturn] = ACTIONS(5569),
    [anon_sym__Nonnull] = ACTIONS(5569),
    [anon_sym_mutable] = ACTIONS(5569),
    [anon_sym_constinit] = ACTIONS(5569),
    [anon_sym_consteval] = ACTIONS(5569),
    [anon_sym___shared__] = ACTIONS(5569),
    [anon_sym___local__] = ACTIONS(5569),
    [anon_sym___constant__] = ACTIONS(5569),
    [anon_sym___managed__] = ACTIONS(5569),
    [anon_sym___grid_constant__] = ACTIONS(5569),
    [anon_sym_alignas] = ACTIONS(5569),
    [anon_sym__Alignas] = ACTIONS(5569),
    [sym_primitive_type] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_class] = ACTIONS(5569),
    [anon_sym_struct] = ACTIONS(5569),
    [anon_sym_union] = ACTIONS(5569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5569),
    [anon_sym_decltype] = ACTIONS(5569),
    [anon_sym_explicit] = ACTIONS(5569),
    [anon_sym_typename] = ACTIONS(5569),
    [anon_sym_template] = ACTIONS(5569),
    [anon_sym_operator] = ACTIONS(5569),
    [anon_sym_friend] = ACTIONS(5569),
    [anon_sym_public] = ACTIONS(5569),
    [anon_sym_private] = ACTIONS(5569),
    [anon_sym_protected] = ACTIONS(5569),
    [anon_sym_using] = ACTIONS(5569),
    [anon_sym_static_assert] = ACTIONS(5569),
    [anon_sym___launch_bounds__] = ACTIONS(5569),
  },
  [STATE(1948)] = {
    [sym_identifier] = ACTIONS(2032),
    [aux_sym_preproc_def_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2032),
    [sym_preproc_directive] = ACTIONS(2032),
    [anon_sym_LPAREN2] = ACTIONS(2034),
    [anon_sym_TILDE] = ACTIONS(2034),
    [anon_sym_STAR] = ACTIONS(2034),
    [anon_sym_AMP_AMP] = ACTIONS(2034),
    [anon_sym_AMP] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(2034),
    [anon_sym___extension__] = ACTIONS(2032),
    [anon_sym_typedef] = ACTIONS(2032),
    [anon_sym___device__] = ACTIONS(2032),
    [anon_sym___host__] = ACTIONS(2032),
    [anon_sym___global__] = ACTIONS(2032),
    [anon_sym___forceinline__] = ACTIONS(2032),
    [anon_sym___noinline__] = ACTIONS(2032),
    [anon_sym_virtual] = ACTIONS(2032),
    [anon_sym_extern] = ACTIONS(2032),
    [anon_sym___attribute__] = ACTIONS(2032),
    [anon_sym___attribute] = ACTIONS(2032),
    [anon_sym_COLON_COLON] = ACTIONS(2034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2034),
    [anon_sym___declspec] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(2032),
    [anon_sym_RBRACE] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2032),
    [anon_sym_unsigned] = ACTIONS(2032),
    [anon_sym_long] = ACTIONS(2032),
    [anon_sym_short] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(2032),
    [anon_sym_static] = ACTIONS(2032),
    [anon_sym_register] = ACTIONS(2032),
    [anon_sym_inline] = ACTIONS(2032),
    [anon_sym___inline] = ACTIONS(2032),
    [anon_sym___inline__] = ACTIONS(2032),
    [anon_sym___forceinline] = ACTIONS(2032),
    [anon_sym_thread_local] = ACTIONS(2032),
    [anon_sym___thread] = ACTIONS(2032),
    [anon_sym_const] = ACTIONS(2032),
    [anon_sym_constexpr] = ACTIONS(2032),
    [anon_sym_volatile] = ACTIONS(2032),
    [anon_sym_restrict] = ACTIONS(2032),
    [anon_sym___restrict__] = ACTIONS(2032),
    [anon_sym__Atomic] = ACTIONS(2032),
    [anon_sym__Noreturn] = ACTIONS(2032),
    [anon_sym_noreturn] = ACTIONS(2032),
    [anon_sym__Nonnull] = ACTIONS(2032),
    [anon_sym_mutable] = ACTIONS(2032),
    [anon_sym_constinit] = ACTIONS(2032),
    [anon_sym_consteval] = ACTIONS(2032),
    [anon_sym___shared__] = ACTIONS(2032),
    [anon_sym___local__] = ACTIONS(2032),
    [anon_sym___constant__] = ACTIONS(2032),
    [anon_sym___managed__] = ACTIONS(2032),
    [anon_sym___grid_constant__] = ACTIONS(2032),
    [anon_sym_alignas] = ACTIONS(2032),
    [anon_sym__Alignas] = ACTIONS(2032),
    [sym_primitive_type] = ACTIONS(2032),
    [anon_sym_enum] = ACTIONS(2032),
    [anon_sym_class] = ACTIONS(2032),
    [anon_sym_struct] = ACTIONS(2032),
    [anon_sym_union] = ACTIONS(2032),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2032),
    [anon_sym_decltype] = ACTIONS(2032),
    [anon_sym_explicit] = ACTIONS(2032),
    [anon_sym_typename] = ACTIONS(2032),
    [anon_sym_template] = ACTIONS(2032),
    [anon_sym_operator] = ACTIONS(2032),
    [anon_sym_friend] = ACTIONS(2032),
    [anon_sym_public] = ACTIONS(2032),
    [anon_sym_private] = ACTIONS(2032),
    [anon_sym_protected] = ACTIONS(2032),
    [anon_sym_using] = ACTIONS(2032),
    [anon_sym_static_assert] = ACTIONS(2032),
    [anon_sym___launch_bounds__] = ACTIONS(2032),
  },
  [STATE(1949)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5661),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_RBRACE] = ACTIONS(5661),
    [anon_sym_signed] = ACTIONS(5659),
    [anon_sym_unsigned] = ACTIONS(5659),
    [anon_sym_long] = ACTIONS(5659),
    [anon_sym_short] = ACTIONS(5659),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_RBRACK] = ACTIONS(5661),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [sym_primitive_type] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_bitor] = ACTIONS(5659),
    [anon_sym_xor] = ACTIONS(5659),
    [anon_sym_bitand] = ACTIONS(5659),
    [anon_sym_not_eq] = ACTIONS(5659),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [anon_sym_requires] = ACTIONS(5659),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(1950)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5661),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_RBRACE] = ACTIONS(5661),
    [anon_sym_signed] = ACTIONS(5659),
    [anon_sym_unsigned] = ACTIONS(5659),
    [anon_sym_long] = ACTIONS(5659),
    [anon_sym_short] = ACTIONS(5659),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_RBRACK] = ACTIONS(5661),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [sym_primitive_type] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_bitor] = ACTIONS(5659),
    [anon_sym_xor] = ACTIONS(5659),
    [anon_sym_bitand] = ACTIONS(5659),
    [anon_sym_not_eq] = ACTIONS(5659),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [anon_sym_requires] = ACTIONS(5659),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(1951)] = {
    [sym_identifier] = ACTIONS(2595),
    [aux_sym_preproc_def_token1] = ACTIONS(2595),
    [aux_sym_preproc_if_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2595),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2595),
    [sym_preproc_directive] = ACTIONS(2595),
    [anon_sym_LPAREN2] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_STAR] = ACTIONS(2597),
    [anon_sym_AMP_AMP] = ACTIONS(2597),
    [anon_sym_AMP] = ACTIONS(2595),
    [anon_sym_SEMI] = ACTIONS(2597),
    [anon_sym___extension__] = ACTIONS(2595),
    [anon_sym_typedef] = ACTIONS(2595),
    [anon_sym___device__] = ACTIONS(2595),
    [anon_sym___host__] = ACTIONS(2595),
    [anon_sym___global__] = ACTIONS(2595),
    [anon_sym___forceinline__] = ACTIONS(2595),
    [anon_sym___noinline__] = ACTIONS(2595),
    [anon_sym_virtual] = ACTIONS(2595),
    [anon_sym_extern] = ACTIONS(2595),
    [anon_sym___attribute__] = ACTIONS(2595),
    [anon_sym___attribute] = ACTIONS(2595),
    [anon_sym_COLON_COLON] = ACTIONS(2597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2597),
    [anon_sym___declspec] = ACTIONS(2595),
    [anon_sym___based] = ACTIONS(2595),
    [anon_sym_RBRACE] = ACTIONS(2597),
    [anon_sym_signed] = ACTIONS(2595),
    [anon_sym_unsigned] = ACTIONS(2595),
    [anon_sym_long] = ACTIONS(2595),
    [anon_sym_short] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2595),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_register] = ACTIONS(2595),
    [anon_sym_inline] = ACTIONS(2595),
    [anon_sym___inline] = ACTIONS(2595),
    [anon_sym___inline__] = ACTIONS(2595),
    [anon_sym___forceinline] = ACTIONS(2595),
    [anon_sym_thread_local] = ACTIONS(2595),
    [anon_sym___thread] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_constexpr] = ACTIONS(2595),
    [anon_sym_volatile] = ACTIONS(2595),
    [anon_sym_restrict] = ACTIONS(2595),
    [anon_sym___restrict__] = ACTIONS(2595),
    [anon_sym__Atomic] = ACTIONS(2595),
    [anon_sym__Noreturn] = ACTIONS(2595),
    [anon_sym_noreturn] = ACTIONS(2595),
    [anon_sym__Nonnull] = ACTIONS(2595),
    [anon_sym_mutable] = ACTIONS(2595),
    [anon_sym_constinit] = ACTIONS(2595),
    [anon_sym_consteval] = ACTIONS(2595),
    [anon_sym___shared__] = ACTIONS(2595),
    [anon_sym___local__] = ACTIONS(2595),
    [anon_sym___constant__] = ACTIONS(2595),
    [anon_sym___managed__] = ACTIONS(2595),
    [anon_sym___grid_constant__] = ACTIONS(2595),
    [anon_sym_alignas] = ACTIONS(2595),
    [anon_sym__Alignas] = ACTIONS(2595),
    [sym_primitive_type] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_struct] = ACTIONS(2595),
    [anon_sym_union] = ACTIONS(2595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2595),
    [anon_sym_decltype] = ACTIONS(2595),
    [anon_sym_explicit] = ACTIONS(2595),
    [anon_sym_typename] = ACTIONS(2595),
    [anon_sym_template] = ACTIONS(2595),
    [anon_sym_operator] = ACTIONS(2595),
    [anon_sym_friend] = ACTIONS(2595),
    [anon_sym_public] = ACTIONS(2595),
    [anon_sym_private] = ACTIONS(2595),
    [anon_sym_protected] = ACTIONS(2595),
    [anon_sym_using] = ACTIONS(2595),
    [anon_sym_static_assert] = ACTIONS(2595),
    [anon_sym___launch_bounds__] = ACTIONS(2595),
  },
  [STATE(1952)] = {
    [sym_identifier] = ACTIONS(2605),
    [aux_sym_preproc_def_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2605),
    [sym_preproc_directive] = ACTIONS(2605),
    [anon_sym_LPAREN2] = ACTIONS(2607),
    [anon_sym_TILDE] = ACTIONS(2607),
    [anon_sym_STAR] = ACTIONS(2607),
    [anon_sym_AMP_AMP] = ACTIONS(2607),
    [anon_sym_AMP] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2605),
    [anon_sym_typedef] = ACTIONS(2605),
    [anon_sym___device__] = ACTIONS(2605),
    [anon_sym___host__] = ACTIONS(2605),
    [anon_sym___global__] = ACTIONS(2605),
    [anon_sym___forceinline__] = ACTIONS(2605),
    [anon_sym___noinline__] = ACTIONS(2605),
    [anon_sym_virtual] = ACTIONS(2605),
    [anon_sym_extern] = ACTIONS(2605),
    [anon_sym___attribute__] = ACTIONS(2605),
    [anon_sym___attribute] = ACTIONS(2605),
    [anon_sym_COLON_COLON] = ACTIONS(2607),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2607),
    [anon_sym___declspec] = ACTIONS(2605),
    [anon_sym___based] = ACTIONS(2605),
    [anon_sym_RBRACE] = ACTIONS(2607),
    [anon_sym_signed] = ACTIONS(2605),
    [anon_sym_unsigned] = ACTIONS(2605),
    [anon_sym_long] = ACTIONS(2605),
    [anon_sym_short] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2605),
    [anon_sym_static] = ACTIONS(2605),
    [anon_sym_register] = ACTIONS(2605),
    [anon_sym_inline] = ACTIONS(2605),
    [anon_sym___inline] = ACTIONS(2605),
    [anon_sym___inline__] = ACTIONS(2605),
    [anon_sym___forceinline] = ACTIONS(2605),
    [anon_sym_thread_local] = ACTIONS(2605),
    [anon_sym___thread] = ACTIONS(2605),
    [anon_sym_const] = ACTIONS(2605),
    [anon_sym_constexpr] = ACTIONS(2605),
    [anon_sym_volatile] = ACTIONS(2605),
    [anon_sym_restrict] = ACTIONS(2605),
    [anon_sym___restrict__] = ACTIONS(2605),
    [anon_sym__Atomic] = ACTIONS(2605),
    [anon_sym__Noreturn] = ACTIONS(2605),
    [anon_sym_noreturn] = ACTIONS(2605),
    [anon_sym__Nonnull] = ACTIONS(2605),
    [anon_sym_mutable] = ACTIONS(2605),
    [anon_sym_constinit] = ACTIONS(2605),
    [anon_sym_consteval] = ACTIONS(2605),
    [anon_sym___shared__] = ACTIONS(2605),
    [anon_sym___local__] = ACTIONS(2605),
    [anon_sym___constant__] = ACTIONS(2605),
    [anon_sym___managed__] = ACTIONS(2605),
    [anon_sym___grid_constant__] = ACTIONS(2605),
    [anon_sym_alignas] = ACTIONS(2605),
    [anon_sym__Alignas] = ACTIONS(2605),
    [sym_primitive_type] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_class] = ACTIONS(2605),
    [anon_sym_struct] = ACTIONS(2605),
    [anon_sym_union] = ACTIONS(2605),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2605),
    [anon_sym_decltype] = ACTIONS(2605),
    [anon_sym_explicit] = ACTIONS(2605),
    [anon_sym_typename] = ACTIONS(2605),
    [anon_sym_template] = ACTIONS(2605),
    [anon_sym_operator] = ACTIONS(2605),
    [anon_sym_friend] = ACTIONS(2605),
    [anon_sym_public] = ACTIONS(2605),
    [anon_sym_private] = ACTIONS(2605),
    [anon_sym_protected] = ACTIONS(2605),
    [anon_sym_using] = ACTIONS(2605),
    [anon_sym_static_assert] = ACTIONS(2605),
    [anon_sym___launch_bounds__] = ACTIONS(2605),
  },
  [STATE(1953)] = {
    [sym_identifier] = ACTIONS(5521),
    [aux_sym_preproc_def_token1] = ACTIONS(5521),
    [aux_sym_preproc_if_token1] = ACTIONS(5521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5521),
    [sym_preproc_directive] = ACTIONS(5521),
    [anon_sym_LPAREN2] = ACTIONS(5523),
    [anon_sym_TILDE] = ACTIONS(5523),
    [anon_sym_STAR] = ACTIONS(5523),
    [anon_sym_AMP_AMP] = ACTIONS(5523),
    [anon_sym_AMP] = ACTIONS(5521),
    [anon_sym_SEMI] = ACTIONS(5523),
    [anon_sym___extension__] = ACTIONS(5521),
    [anon_sym_typedef] = ACTIONS(5521),
    [anon_sym___device__] = ACTIONS(5521),
    [anon_sym___host__] = ACTIONS(5521),
    [anon_sym___global__] = ACTIONS(5521),
    [anon_sym___forceinline__] = ACTIONS(5521),
    [anon_sym___noinline__] = ACTIONS(5521),
    [anon_sym_virtual] = ACTIONS(5521),
    [anon_sym_extern] = ACTIONS(5521),
    [anon_sym___attribute__] = ACTIONS(5521),
    [anon_sym___attribute] = ACTIONS(5521),
    [anon_sym_COLON_COLON] = ACTIONS(5523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5523),
    [anon_sym___declspec] = ACTIONS(5521),
    [anon_sym___based] = ACTIONS(5521),
    [anon_sym_RBRACE] = ACTIONS(5523),
    [anon_sym_signed] = ACTIONS(5521),
    [anon_sym_unsigned] = ACTIONS(5521),
    [anon_sym_long] = ACTIONS(5521),
    [anon_sym_short] = ACTIONS(5521),
    [anon_sym_LBRACK] = ACTIONS(5521),
    [anon_sym_static] = ACTIONS(5521),
    [anon_sym_register] = ACTIONS(5521),
    [anon_sym_inline] = ACTIONS(5521),
    [anon_sym___inline] = ACTIONS(5521),
    [anon_sym___inline__] = ACTIONS(5521),
    [anon_sym___forceinline] = ACTIONS(5521),
    [anon_sym_thread_local] = ACTIONS(5521),
    [anon_sym___thread] = ACTIONS(5521),
    [anon_sym_const] = ACTIONS(5521),
    [anon_sym_constexpr] = ACTIONS(5521),
    [anon_sym_volatile] = ACTIONS(5521),
    [anon_sym_restrict] = ACTIONS(5521),
    [anon_sym___restrict__] = ACTIONS(5521),
    [anon_sym__Atomic] = ACTIONS(5521),
    [anon_sym__Noreturn] = ACTIONS(5521),
    [anon_sym_noreturn] = ACTIONS(5521),
    [anon_sym__Nonnull] = ACTIONS(5521),
    [anon_sym_mutable] = ACTIONS(5521),
    [anon_sym_constinit] = ACTIONS(5521),
    [anon_sym_consteval] = ACTIONS(5521),
    [anon_sym___shared__] = ACTIONS(5521),
    [anon_sym___local__] = ACTIONS(5521),
    [anon_sym___constant__] = ACTIONS(5521),
    [anon_sym___managed__] = ACTIONS(5521),
    [anon_sym___grid_constant__] = ACTIONS(5521),
    [anon_sym_alignas] = ACTIONS(5521),
    [anon_sym__Alignas] = ACTIONS(5521),
    [sym_primitive_type] = ACTIONS(5521),
    [anon_sym_enum] = ACTIONS(5521),
    [anon_sym_class] = ACTIONS(5521),
    [anon_sym_struct] = ACTIONS(5521),
    [anon_sym_union] = ACTIONS(5521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5521),
    [anon_sym_decltype] = ACTIONS(5521),
    [anon_sym_explicit] = ACTIONS(5521),
    [anon_sym_typename] = ACTIONS(5521),
    [anon_sym_template] = ACTIONS(5521),
    [anon_sym_operator] = ACTIONS(5521),
    [anon_sym_friend] = ACTIONS(5521),
    [anon_sym_public] = ACTIONS(5521),
    [anon_sym_private] = ACTIONS(5521),
    [anon_sym_protected] = ACTIONS(5521),
    [anon_sym_using] = ACTIONS(5521),
    [anon_sym_static_assert] = ACTIONS(5521),
    [anon_sym___launch_bounds__] = ACTIONS(5521),
  },
  [STATE(1954)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym_RBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_friend] = ACTIONS(2178),
    [anon_sym_public] = ACTIONS(2178),
    [anon_sym_private] = ACTIONS(2178),
    [anon_sym_protected] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(1955)] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token2] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2385),
    [anon_sym_TILDE] = ACTIONS(2385),
    [anon_sym_STAR] = ACTIONS(2385),
    [anon_sym_AMP_AMP] = ACTIONS(2385),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym___device__] = ACTIONS(2383),
    [anon_sym___host__] = ACTIONS(2383),
    [anon_sym___global__] = ACTIONS(2383),
    [anon_sym___forceinline__] = ACTIONS(2383),
    [anon_sym___noinline__] = ACTIONS(2383),
    [anon_sym_virtual] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym___attribute] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2385),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2385),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym__Nonnull] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym___shared__] = ACTIONS(2383),
    [anon_sym___local__] = ACTIONS(2383),
    [anon_sym___constant__] = ACTIONS(2383),
    [anon_sym___managed__] = ACTIONS(2383),
    [anon_sym___grid_constant__] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_friend] = ACTIONS(2383),
    [anon_sym_public] = ACTIONS(2383),
    [anon_sym_private] = ACTIONS(2383),
    [anon_sym_protected] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym___launch_bounds__] = ACTIONS(2383),
  },
  [STATE(1956)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym_RBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_friend] = ACTIONS(2178),
    [anon_sym_public] = ACTIONS(2178),
    [anon_sym_private] = ACTIONS(2178),
    [anon_sym_protected] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(1957)] = {
    [sym_identifier] = ACTIONS(5603),
    [aux_sym_preproc_def_token1] = ACTIONS(5603),
    [aux_sym_preproc_if_token1] = ACTIONS(5603),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5603),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5603),
    [sym_preproc_directive] = ACTIONS(5603),
    [anon_sym_LPAREN2] = ACTIONS(5605),
    [anon_sym_TILDE] = ACTIONS(5605),
    [anon_sym_STAR] = ACTIONS(5605),
    [anon_sym_AMP_AMP] = ACTIONS(5605),
    [anon_sym_AMP] = ACTIONS(5603),
    [anon_sym_SEMI] = ACTIONS(5605),
    [anon_sym___extension__] = ACTIONS(5603),
    [anon_sym_typedef] = ACTIONS(5603),
    [anon_sym___device__] = ACTIONS(5603),
    [anon_sym___host__] = ACTIONS(5603),
    [anon_sym___global__] = ACTIONS(5603),
    [anon_sym___forceinline__] = ACTIONS(5603),
    [anon_sym___noinline__] = ACTIONS(5603),
    [anon_sym_virtual] = ACTIONS(5603),
    [anon_sym_extern] = ACTIONS(5603),
    [anon_sym___attribute__] = ACTIONS(5603),
    [anon_sym___attribute] = ACTIONS(5603),
    [anon_sym_COLON_COLON] = ACTIONS(5605),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5605),
    [anon_sym___declspec] = ACTIONS(5603),
    [anon_sym___based] = ACTIONS(5603),
    [anon_sym_RBRACE] = ACTIONS(5605),
    [anon_sym_signed] = ACTIONS(5603),
    [anon_sym_unsigned] = ACTIONS(5603),
    [anon_sym_long] = ACTIONS(5603),
    [anon_sym_short] = ACTIONS(5603),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [anon_sym_static] = ACTIONS(5603),
    [anon_sym_register] = ACTIONS(5603),
    [anon_sym_inline] = ACTIONS(5603),
    [anon_sym___inline] = ACTIONS(5603),
    [anon_sym___inline__] = ACTIONS(5603),
    [anon_sym___forceinline] = ACTIONS(5603),
    [anon_sym_thread_local] = ACTIONS(5603),
    [anon_sym___thread] = ACTIONS(5603),
    [anon_sym_const] = ACTIONS(5603),
    [anon_sym_constexpr] = ACTIONS(5603),
    [anon_sym_volatile] = ACTIONS(5603),
    [anon_sym_restrict] = ACTIONS(5603),
    [anon_sym___restrict__] = ACTIONS(5603),
    [anon_sym__Atomic] = ACTIONS(5603),
    [anon_sym__Noreturn] = ACTIONS(5603),
    [anon_sym_noreturn] = ACTIONS(5603),
    [anon_sym__Nonnull] = ACTIONS(5603),
    [anon_sym_mutable] = ACTIONS(5603),
    [anon_sym_constinit] = ACTIONS(5603),
    [anon_sym_consteval] = ACTIONS(5603),
    [anon_sym___shared__] = ACTIONS(5603),
    [anon_sym___local__] = ACTIONS(5603),
    [anon_sym___constant__] = ACTIONS(5603),
    [anon_sym___managed__] = ACTIONS(5603),
    [anon_sym___grid_constant__] = ACTIONS(5603),
    [anon_sym_alignas] = ACTIONS(5603),
    [anon_sym__Alignas] = ACTIONS(5603),
    [sym_primitive_type] = ACTIONS(5603),
    [anon_sym_enum] = ACTIONS(5603),
    [anon_sym_class] = ACTIONS(5603),
    [anon_sym_struct] = ACTIONS(5603),
    [anon_sym_union] = ACTIONS(5603),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5603),
    [anon_sym_decltype] = ACTIONS(5603),
    [anon_sym_explicit] = ACTIONS(5603),
    [anon_sym_typename] = ACTIONS(5603),
    [anon_sym_template] = ACTIONS(5603),
    [anon_sym_operator] = ACTIONS(5603),
    [anon_sym_friend] = ACTIONS(5603),
    [anon_sym_public] = ACTIONS(5603),
    [anon_sym_private] = ACTIONS(5603),
    [anon_sym_protected] = ACTIONS(5603),
    [anon_sym_using] = ACTIONS(5603),
    [anon_sym_static_assert] = ACTIONS(5603),
    [anon_sym___launch_bounds__] = ACTIONS(5603),
  },
  [STATE(1958)] = {
    [sym_identifier] = ACTIONS(2489),
    [aux_sym_preproc_def_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2489),
    [sym_preproc_directive] = ACTIONS(2489),
    [anon_sym_LPAREN2] = ACTIONS(2491),
    [anon_sym_TILDE] = ACTIONS(2491),
    [anon_sym_STAR] = ACTIONS(2491),
    [anon_sym_AMP_AMP] = ACTIONS(2491),
    [anon_sym_AMP] = ACTIONS(2489),
    [anon_sym_SEMI] = ACTIONS(2491),
    [anon_sym___extension__] = ACTIONS(2489),
    [anon_sym_typedef] = ACTIONS(2489),
    [anon_sym___device__] = ACTIONS(2489),
    [anon_sym___host__] = ACTIONS(2489),
    [anon_sym___global__] = ACTIONS(2489),
    [anon_sym___forceinline__] = ACTIONS(2489),
    [anon_sym___noinline__] = ACTIONS(2489),
    [anon_sym_virtual] = ACTIONS(2489),
    [anon_sym_extern] = ACTIONS(2489),
    [anon_sym___attribute__] = ACTIONS(2489),
    [anon_sym___attribute] = ACTIONS(2489),
    [anon_sym_COLON_COLON] = ACTIONS(2491),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2491),
    [anon_sym___declspec] = ACTIONS(2489),
    [anon_sym___based] = ACTIONS(2489),
    [anon_sym_RBRACE] = ACTIONS(2491),
    [anon_sym_signed] = ACTIONS(2489),
    [anon_sym_unsigned] = ACTIONS(2489),
    [anon_sym_long] = ACTIONS(2489),
    [anon_sym_short] = ACTIONS(2489),
    [anon_sym_LBRACK] = ACTIONS(2489),
    [anon_sym_static] = ACTIONS(2489),
    [anon_sym_register] = ACTIONS(2489),
    [anon_sym_inline] = ACTIONS(2489),
    [anon_sym___inline] = ACTIONS(2489),
    [anon_sym___inline__] = ACTIONS(2489),
    [anon_sym___forceinline] = ACTIONS(2489),
    [anon_sym_thread_local] = ACTIONS(2489),
    [anon_sym___thread] = ACTIONS(2489),
    [anon_sym_const] = ACTIONS(2489),
    [anon_sym_constexpr] = ACTIONS(2489),
    [anon_sym_volatile] = ACTIONS(2489),
    [anon_sym_restrict] = ACTIONS(2489),
    [anon_sym___restrict__] = ACTIONS(2489),
    [anon_sym__Atomic] = ACTIONS(2489),
    [anon_sym__Noreturn] = ACTIONS(2489),
    [anon_sym_noreturn] = ACTIONS(2489),
    [anon_sym__Nonnull] = ACTIONS(2489),
    [anon_sym_mutable] = ACTIONS(2489),
    [anon_sym_constinit] = ACTIONS(2489),
    [anon_sym_consteval] = ACTIONS(2489),
    [anon_sym___shared__] = ACTIONS(2489),
    [anon_sym___local__] = ACTIONS(2489),
    [anon_sym___constant__] = ACTIONS(2489),
    [anon_sym___managed__] = ACTIONS(2489),
    [anon_sym___grid_constant__] = ACTIONS(2489),
    [anon_sym_alignas] = ACTIONS(2489),
    [anon_sym__Alignas] = ACTIONS(2489),
    [sym_primitive_type] = ACTIONS(2489),
    [anon_sym_enum] = ACTIONS(2489),
    [anon_sym_class] = ACTIONS(2489),
    [anon_sym_struct] = ACTIONS(2489),
    [anon_sym_union] = ACTIONS(2489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2489),
    [anon_sym_decltype] = ACTIONS(2489),
    [anon_sym_explicit] = ACTIONS(2489),
    [anon_sym_typename] = ACTIONS(2489),
    [anon_sym_template] = ACTIONS(2489),
    [anon_sym_operator] = ACTIONS(2489),
    [anon_sym_friend] = ACTIONS(2489),
    [anon_sym_public] = ACTIONS(2489),
    [anon_sym_private] = ACTIONS(2489),
    [anon_sym_protected] = ACTIONS(2489),
    [anon_sym_using] = ACTIONS(2489),
    [anon_sym_static_assert] = ACTIONS(2489),
    [anon_sym___launch_bounds__] = ACTIONS(2489),
  },
  [STATE(1959)] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym___device__] = ACTIONS(2320),
    [anon_sym___host__] = ACTIONS(2320),
    [anon_sym___global__] = ACTIONS(2320),
    [anon_sym___forceinline__] = ACTIONS(2320),
    [anon_sym___noinline__] = ACTIONS(2320),
    [anon_sym_virtual] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym___attribute] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym_RBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym__Nonnull] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym___shared__] = ACTIONS(2320),
    [anon_sym___local__] = ACTIONS(2320),
    [anon_sym___constant__] = ACTIONS(2320),
    [anon_sym___managed__] = ACTIONS(2320),
    [anon_sym___grid_constant__] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_friend] = ACTIONS(2320),
    [anon_sym_public] = ACTIONS(2320),
    [anon_sym_private] = ACTIONS(2320),
    [anon_sym_protected] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym___launch_bounds__] = ACTIONS(2320),
  },
  [STATE(1960)] = {
    [sym_identifier] = ACTIONS(2028),
    [aux_sym_preproc_def_token1] = ACTIONS(2028),
    [aux_sym_preproc_if_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2028),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2028),
    [sym_preproc_directive] = ACTIONS(2028),
    [anon_sym_LPAREN2] = ACTIONS(2030),
    [anon_sym_TILDE] = ACTIONS(2030),
    [anon_sym_STAR] = ACTIONS(2030),
    [anon_sym_AMP_AMP] = ACTIONS(2030),
    [anon_sym_AMP] = ACTIONS(2028),
    [anon_sym_SEMI] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(2028),
    [anon_sym_typedef] = ACTIONS(2028),
    [anon_sym___device__] = ACTIONS(2028),
    [anon_sym___host__] = ACTIONS(2028),
    [anon_sym___global__] = ACTIONS(2028),
    [anon_sym___forceinline__] = ACTIONS(2028),
    [anon_sym___noinline__] = ACTIONS(2028),
    [anon_sym_virtual] = ACTIONS(2028),
    [anon_sym_extern] = ACTIONS(2028),
    [anon_sym___attribute__] = ACTIONS(2028),
    [anon_sym___attribute] = ACTIONS(2028),
    [anon_sym_COLON_COLON] = ACTIONS(2030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2030),
    [anon_sym___declspec] = ACTIONS(2028),
    [anon_sym___based] = ACTIONS(2028),
    [anon_sym_RBRACE] = ACTIONS(2030),
    [anon_sym_signed] = ACTIONS(2028),
    [anon_sym_unsigned] = ACTIONS(2028),
    [anon_sym_long] = ACTIONS(2028),
    [anon_sym_short] = ACTIONS(2028),
    [anon_sym_LBRACK] = ACTIONS(2028),
    [anon_sym_static] = ACTIONS(2028),
    [anon_sym_register] = ACTIONS(2028),
    [anon_sym_inline] = ACTIONS(2028),
    [anon_sym___inline] = ACTIONS(2028),
    [anon_sym___inline__] = ACTIONS(2028),
    [anon_sym___forceinline] = ACTIONS(2028),
    [anon_sym_thread_local] = ACTIONS(2028),
    [anon_sym___thread] = ACTIONS(2028),
    [anon_sym_const] = ACTIONS(2028),
    [anon_sym_constexpr] = ACTIONS(2028),
    [anon_sym_volatile] = ACTIONS(2028),
    [anon_sym_restrict] = ACTIONS(2028),
    [anon_sym___restrict__] = ACTIONS(2028),
    [anon_sym__Atomic] = ACTIONS(2028),
    [anon_sym__Noreturn] = ACTIONS(2028),
    [anon_sym_noreturn] = ACTIONS(2028),
    [anon_sym__Nonnull] = ACTIONS(2028),
    [anon_sym_mutable] = ACTIONS(2028),
    [anon_sym_constinit] = ACTIONS(2028),
    [anon_sym_consteval] = ACTIONS(2028),
    [anon_sym___shared__] = ACTIONS(2028),
    [anon_sym___local__] = ACTIONS(2028),
    [anon_sym___constant__] = ACTIONS(2028),
    [anon_sym___managed__] = ACTIONS(2028),
    [anon_sym___grid_constant__] = ACTIONS(2028),
    [anon_sym_alignas] = ACTIONS(2028),
    [anon_sym__Alignas] = ACTIONS(2028),
    [sym_primitive_type] = ACTIONS(2028),
    [anon_sym_enum] = ACTIONS(2028),
    [anon_sym_class] = ACTIONS(2028),
    [anon_sym_struct] = ACTIONS(2028),
    [anon_sym_union] = ACTIONS(2028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2028),
    [anon_sym_decltype] = ACTIONS(2028),
    [anon_sym_explicit] = ACTIONS(2028),
    [anon_sym_typename] = ACTIONS(2028),
    [anon_sym_template] = ACTIONS(2028),
    [anon_sym_operator] = ACTIONS(2028),
    [anon_sym_friend] = ACTIONS(2028),
    [anon_sym_public] = ACTIONS(2028),
    [anon_sym_private] = ACTIONS(2028),
    [anon_sym_protected] = ACTIONS(2028),
    [anon_sym_using] = ACTIONS(2028),
    [anon_sym_static_assert] = ACTIONS(2028),
    [anon_sym___launch_bounds__] = ACTIONS(2028),
  },
  [STATE(1961)] = {
    [sym_identifier] = ACTIONS(5529),
    [aux_sym_preproc_def_token1] = ACTIONS(5529),
    [aux_sym_preproc_if_token1] = ACTIONS(5529),
    [aux_sym_preproc_if_token2] = ACTIONS(5529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5529),
    [sym_preproc_directive] = ACTIONS(5529),
    [anon_sym_LPAREN2] = ACTIONS(5531),
    [anon_sym_TILDE] = ACTIONS(5531),
    [anon_sym_STAR] = ACTIONS(5531),
    [anon_sym_AMP_AMP] = ACTIONS(5531),
    [anon_sym_AMP] = ACTIONS(5529),
    [anon_sym_SEMI] = ACTIONS(5531),
    [anon_sym___extension__] = ACTIONS(5529),
    [anon_sym_typedef] = ACTIONS(5529),
    [anon_sym___device__] = ACTIONS(5529),
    [anon_sym___host__] = ACTIONS(5529),
    [anon_sym___global__] = ACTIONS(5529),
    [anon_sym___forceinline__] = ACTIONS(5529),
    [anon_sym___noinline__] = ACTIONS(5529),
    [anon_sym_virtual] = ACTIONS(5529),
    [anon_sym_extern] = ACTIONS(5529),
    [anon_sym___attribute__] = ACTIONS(5529),
    [anon_sym___attribute] = ACTIONS(5529),
    [anon_sym_COLON_COLON] = ACTIONS(5531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5531),
    [anon_sym___declspec] = ACTIONS(5529),
    [anon_sym___based] = ACTIONS(5529),
    [anon_sym_signed] = ACTIONS(5529),
    [anon_sym_unsigned] = ACTIONS(5529),
    [anon_sym_long] = ACTIONS(5529),
    [anon_sym_short] = ACTIONS(5529),
    [anon_sym_LBRACK] = ACTIONS(5529),
    [anon_sym_static] = ACTIONS(5529),
    [anon_sym_register] = ACTIONS(5529),
    [anon_sym_inline] = ACTIONS(5529),
    [anon_sym___inline] = ACTIONS(5529),
    [anon_sym___inline__] = ACTIONS(5529),
    [anon_sym___forceinline] = ACTIONS(5529),
    [anon_sym_thread_local] = ACTIONS(5529),
    [anon_sym___thread] = ACTIONS(5529),
    [anon_sym_const] = ACTIONS(5529),
    [anon_sym_constexpr] = ACTIONS(5529),
    [anon_sym_volatile] = ACTIONS(5529),
    [anon_sym_restrict] = ACTIONS(5529),
    [anon_sym___restrict__] = ACTIONS(5529),
    [anon_sym__Atomic] = ACTIONS(5529),
    [anon_sym__Noreturn] = ACTIONS(5529),
    [anon_sym_noreturn] = ACTIONS(5529),
    [anon_sym__Nonnull] = ACTIONS(5529),
    [anon_sym_mutable] = ACTIONS(5529),
    [anon_sym_constinit] = ACTIONS(5529),
    [anon_sym_consteval] = ACTIONS(5529),
    [anon_sym___shared__] = ACTIONS(5529),
    [anon_sym___local__] = ACTIONS(5529),
    [anon_sym___constant__] = ACTIONS(5529),
    [anon_sym___managed__] = ACTIONS(5529),
    [anon_sym___grid_constant__] = ACTIONS(5529),
    [anon_sym_alignas] = ACTIONS(5529),
    [anon_sym__Alignas] = ACTIONS(5529),
    [sym_primitive_type] = ACTIONS(5529),
    [anon_sym_enum] = ACTIONS(5529),
    [anon_sym_class] = ACTIONS(5529),
    [anon_sym_struct] = ACTIONS(5529),
    [anon_sym_union] = ACTIONS(5529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5529),
    [anon_sym_decltype] = ACTIONS(5529),
    [anon_sym_explicit] = ACTIONS(5529),
    [anon_sym_typename] = ACTIONS(5529),
    [anon_sym_template] = ACTIONS(5529),
    [anon_sym_operator] = ACTIONS(5529),
    [anon_sym_friend] = ACTIONS(5529),
    [anon_sym_public] = ACTIONS(5529),
    [anon_sym_private] = ACTIONS(5529),
    [anon_sym_protected] = ACTIONS(5529),
    [anon_sym_using] = ACTIONS(5529),
    [anon_sym_static_assert] = ACTIONS(5529),
    [anon_sym___launch_bounds__] = ACTIONS(5529),
  },
  [STATE(1962)] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2385),
    [anon_sym_TILDE] = ACTIONS(2385),
    [anon_sym_STAR] = ACTIONS(2385),
    [anon_sym_AMP_AMP] = ACTIONS(2385),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2385),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym___device__] = ACTIONS(2383),
    [anon_sym___host__] = ACTIONS(2383),
    [anon_sym___global__] = ACTIONS(2383),
    [anon_sym___forceinline__] = ACTIONS(2383),
    [anon_sym___noinline__] = ACTIONS(2383),
    [anon_sym_virtual] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym___attribute] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2385),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2385),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym_RBRACE] = ACTIONS(2385),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym__Nonnull] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym___shared__] = ACTIONS(2383),
    [anon_sym___local__] = ACTIONS(2383),
    [anon_sym___constant__] = ACTIONS(2383),
    [anon_sym___managed__] = ACTIONS(2383),
    [anon_sym___grid_constant__] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_friend] = ACTIONS(2383),
    [anon_sym_public] = ACTIONS(2383),
    [anon_sym_private] = ACTIONS(2383),
    [anon_sym_protected] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym___launch_bounds__] = ACTIONS(2383),
  },
  [STATE(1963)] = {
    [sym_identifier] = ACTIONS(2415),
    [aux_sym_preproc_def_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2415),
    [sym_preproc_directive] = ACTIONS(2415),
    [anon_sym_LPAREN2] = ACTIONS(2417),
    [anon_sym_TILDE] = ACTIONS(2417),
    [anon_sym_STAR] = ACTIONS(2417),
    [anon_sym_AMP_AMP] = ACTIONS(2417),
    [anon_sym_AMP] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(2417),
    [anon_sym___extension__] = ACTIONS(2415),
    [anon_sym_typedef] = ACTIONS(2415),
    [anon_sym___device__] = ACTIONS(2415),
    [anon_sym___host__] = ACTIONS(2415),
    [anon_sym___global__] = ACTIONS(2415),
    [anon_sym___forceinline__] = ACTIONS(2415),
    [anon_sym___noinline__] = ACTIONS(2415),
    [anon_sym_virtual] = ACTIONS(2415),
    [anon_sym_extern] = ACTIONS(2415),
    [anon_sym___attribute__] = ACTIONS(2415),
    [anon_sym___attribute] = ACTIONS(2415),
    [anon_sym_COLON_COLON] = ACTIONS(2417),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2417),
    [anon_sym___declspec] = ACTIONS(2415),
    [anon_sym___based] = ACTIONS(2415),
    [anon_sym_RBRACE] = ACTIONS(2417),
    [anon_sym_signed] = ACTIONS(2415),
    [anon_sym_unsigned] = ACTIONS(2415),
    [anon_sym_long] = ACTIONS(2415),
    [anon_sym_short] = ACTIONS(2415),
    [anon_sym_LBRACK] = ACTIONS(2415),
    [anon_sym_static] = ACTIONS(2415),
    [anon_sym_register] = ACTIONS(2415),
    [anon_sym_inline] = ACTIONS(2415),
    [anon_sym___inline] = ACTIONS(2415),
    [anon_sym___inline__] = ACTIONS(2415),
    [anon_sym___forceinline] = ACTIONS(2415),
    [anon_sym_thread_local] = ACTIONS(2415),
    [anon_sym___thread] = ACTIONS(2415),
    [anon_sym_const] = ACTIONS(2415),
    [anon_sym_constexpr] = ACTIONS(2415),
    [anon_sym_volatile] = ACTIONS(2415),
    [anon_sym_restrict] = ACTIONS(2415),
    [anon_sym___restrict__] = ACTIONS(2415),
    [anon_sym__Atomic] = ACTIONS(2415),
    [anon_sym__Noreturn] = ACTIONS(2415),
    [anon_sym_noreturn] = ACTIONS(2415),
    [anon_sym__Nonnull] = ACTIONS(2415),
    [anon_sym_mutable] = ACTIONS(2415),
    [anon_sym_constinit] = ACTIONS(2415),
    [anon_sym_consteval] = ACTIONS(2415),
    [anon_sym___shared__] = ACTIONS(2415),
    [anon_sym___local__] = ACTIONS(2415),
    [anon_sym___constant__] = ACTIONS(2415),
    [anon_sym___managed__] = ACTIONS(2415),
    [anon_sym___grid_constant__] = ACTIONS(2415),
    [anon_sym_alignas] = ACTIONS(2415),
    [anon_sym__Alignas] = ACTIONS(2415),
    [sym_primitive_type] = ACTIONS(2415),
    [anon_sym_enum] = ACTIONS(2415),
    [anon_sym_class] = ACTIONS(2415),
    [anon_sym_struct] = ACTIONS(2415),
    [anon_sym_union] = ACTIONS(2415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2415),
    [anon_sym_decltype] = ACTIONS(2415),
    [anon_sym_explicit] = ACTIONS(2415),
    [anon_sym_typename] = ACTIONS(2415),
    [anon_sym_template] = ACTIONS(2415),
    [anon_sym_operator] = ACTIONS(2415),
    [anon_sym_friend] = ACTIONS(2415),
    [anon_sym_public] = ACTIONS(2415),
    [anon_sym_private] = ACTIONS(2415),
    [anon_sym_protected] = ACTIONS(2415),
    [anon_sym_using] = ACTIONS(2415),
    [anon_sym_static_assert] = ACTIONS(2415),
    [anon_sym___launch_bounds__] = ACTIONS(2415),
  },
  [STATE(1964)] = {
    [sym_identifier] = ACTIONS(5533),
    [aux_sym_preproc_def_token1] = ACTIONS(5533),
    [aux_sym_preproc_if_token1] = ACTIONS(5533),
    [aux_sym_preproc_if_token2] = ACTIONS(5533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5533),
    [sym_preproc_directive] = ACTIONS(5533),
    [anon_sym_LPAREN2] = ACTIONS(5535),
    [anon_sym_TILDE] = ACTIONS(5535),
    [anon_sym_STAR] = ACTIONS(5535),
    [anon_sym_AMP_AMP] = ACTIONS(5535),
    [anon_sym_AMP] = ACTIONS(5533),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym___extension__] = ACTIONS(5533),
    [anon_sym_typedef] = ACTIONS(5533),
    [anon_sym___device__] = ACTIONS(5533),
    [anon_sym___host__] = ACTIONS(5533),
    [anon_sym___global__] = ACTIONS(5533),
    [anon_sym___forceinline__] = ACTIONS(5533),
    [anon_sym___noinline__] = ACTIONS(5533),
    [anon_sym_virtual] = ACTIONS(5533),
    [anon_sym_extern] = ACTIONS(5533),
    [anon_sym___attribute__] = ACTIONS(5533),
    [anon_sym___attribute] = ACTIONS(5533),
    [anon_sym_COLON_COLON] = ACTIONS(5535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5535),
    [anon_sym___declspec] = ACTIONS(5533),
    [anon_sym___based] = ACTIONS(5533),
    [anon_sym_signed] = ACTIONS(5533),
    [anon_sym_unsigned] = ACTIONS(5533),
    [anon_sym_long] = ACTIONS(5533),
    [anon_sym_short] = ACTIONS(5533),
    [anon_sym_LBRACK] = ACTIONS(5533),
    [anon_sym_static] = ACTIONS(5533),
    [anon_sym_register] = ACTIONS(5533),
    [anon_sym_inline] = ACTIONS(5533),
    [anon_sym___inline] = ACTIONS(5533),
    [anon_sym___inline__] = ACTIONS(5533),
    [anon_sym___forceinline] = ACTIONS(5533),
    [anon_sym_thread_local] = ACTIONS(5533),
    [anon_sym___thread] = ACTIONS(5533),
    [anon_sym_const] = ACTIONS(5533),
    [anon_sym_constexpr] = ACTIONS(5533),
    [anon_sym_volatile] = ACTIONS(5533),
    [anon_sym_restrict] = ACTIONS(5533),
    [anon_sym___restrict__] = ACTIONS(5533),
    [anon_sym__Atomic] = ACTIONS(5533),
    [anon_sym__Noreturn] = ACTIONS(5533),
    [anon_sym_noreturn] = ACTIONS(5533),
    [anon_sym__Nonnull] = ACTIONS(5533),
    [anon_sym_mutable] = ACTIONS(5533),
    [anon_sym_constinit] = ACTIONS(5533),
    [anon_sym_consteval] = ACTIONS(5533),
    [anon_sym___shared__] = ACTIONS(5533),
    [anon_sym___local__] = ACTIONS(5533),
    [anon_sym___constant__] = ACTIONS(5533),
    [anon_sym___managed__] = ACTIONS(5533),
    [anon_sym___grid_constant__] = ACTIONS(5533),
    [anon_sym_alignas] = ACTIONS(5533),
    [anon_sym__Alignas] = ACTIONS(5533),
    [sym_primitive_type] = ACTIONS(5533),
    [anon_sym_enum] = ACTIONS(5533),
    [anon_sym_class] = ACTIONS(5533),
    [anon_sym_struct] = ACTIONS(5533),
    [anon_sym_union] = ACTIONS(5533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5533),
    [anon_sym_decltype] = ACTIONS(5533),
    [anon_sym_explicit] = ACTIONS(5533),
    [anon_sym_typename] = ACTIONS(5533),
    [anon_sym_template] = ACTIONS(5533),
    [anon_sym_operator] = ACTIONS(5533),
    [anon_sym_friend] = ACTIONS(5533),
    [anon_sym_public] = ACTIONS(5533),
    [anon_sym_private] = ACTIONS(5533),
    [anon_sym_protected] = ACTIONS(5533),
    [anon_sym_using] = ACTIONS(5533),
    [anon_sym_static_assert] = ACTIONS(5533),
    [anon_sym___launch_bounds__] = ACTIONS(5533),
  },
  [STATE(1965)] = {
    [sym_identifier] = ACTIONS(5537),
    [aux_sym_preproc_def_token1] = ACTIONS(5537),
    [aux_sym_preproc_if_token1] = ACTIONS(5537),
    [aux_sym_preproc_if_token2] = ACTIONS(5537),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5537),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5537),
    [sym_preproc_directive] = ACTIONS(5537),
    [anon_sym_LPAREN2] = ACTIONS(5539),
    [anon_sym_TILDE] = ACTIONS(5539),
    [anon_sym_STAR] = ACTIONS(5539),
    [anon_sym_AMP_AMP] = ACTIONS(5539),
    [anon_sym_AMP] = ACTIONS(5537),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym___extension__] = ACTIONS(5537),
    [anon_sym_typedef] = ACTIONS(5537),
    [anon_sym___device__] = ACTIONS(5537),
    [anon_sym___host__] = ACTIONS(5537),
    [anon_sym___global__] = ACTIONS(5537),
    [anon_sym___forceinline__] = ACTIONS(5537),
    [anon_sym___noinline__] = ACTIONS(5537),
    [anon_sym_virtual] = ACTIONS(5537),
    [anon_sym_extern] = ACTIONS(5537),
    [anon_sym___attribute__] = ACTIONS(5537),
    [anon_sym___attribute] = ACTIONS(5537),
    [anon_sym_COLON_COLON] = ACTIONS(5539),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5539),
    [anon_sym___declspec] = ACTIONS(5537),
    [anon_sym___based] = ACTIONS(5537),
    [anon_sym_signed] = ACTIONS(5537),
    [anon_sym_unsigned] = ACTIONS(5537),
    [anon_sym_long] = ACTIONS(5537),
    [anon_sym_short] = ACTIONS(5537),
    [anon_sym_LBRACK] = ACTIONS(5537),
    [anon_sym_static] = ACTIONS(5537),
    [anon_sym_register] = ACTIONS(5537),
    [anon_sym_inline] = ACTIONS(5537),
    [anon_sym___inline] = ACTIONS(5537),
    [anon_sym___inline__] = ACTIONS(5537),
    [anon_sym___forceinline] = ACTIONS(5537),
    [anon_sym_thread_local] = ACTIONS(5537),
    [anon_sym___thread] = ACTIONS(5537),
    [anon_sym_const] = ACTIONS(5537),
    [anon_sym_constexpr] = ACTIONS(5537),
    [anon_sym_volatile] = ACTIONS(5537),
    [anon_sym_restrict] = ACTIONS(5537),
    [anon_sym___restrict__] = ACTIONS(5537),
    [anon_sym__Atomic] = ACTIONS(5537),
    [anon_sym__Noreturn] = ACTIONS(5537),
    [anon_sym_noreturn] = ACTIONS(5537),
    [anon_sym__Nonnull] = ACTIONS(5537),
    [anon_sym_mutable] = ACTIONS(5537),
    [anon_sym_constinit] = ACTIONS(5537),
    [anon_sym_consteval] = ACTIONS(5537),
    [anon_sym___shared__] = ACTIONS(5537),
    [anon_sym___local__] = ACTIONS(5537),
    [anon_sym___constant__] = ACTIONS(5537),
    [anon_sym___managed__] = ACTIONS(5537),
    [anon_sym___grid_constant__] = ACTIONS(5537),
    [anon_sym_alignas] = ACTIONS(5537),
    [anon_sym__Alignas] = ACTIONS(5537),
    [sym_primitive_type] = ACTIONS(5537),
    [anon_sym_enum] = ACTIONS(5537),
    [anon_sym_class] = ACTIONS(5537),
    [anon_sym_struct] = ACTIONS(5537),
    [anon_sym_union] = ACTIONS(5537),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5537),
    [anon_sym_decltype] = ACTIONS(5537),
    [anon_sym_explicit] = ACTIONS(5537),
    [anon_sym_typename] = ACTIONS(5537),
    [anon_sym_template] = ACTIONS(5537),
    [anon_sym_operator] = ACTIONS(5537),
    [anon_sym_friend] = ACTIONS(5537),
    [anon_sym_public] = ACTIONS(5537),
    [anon_sym_private] = ACTIONS(5537),
    [anon_sym_protected] = ACTIONS(5537),
    [anon_sym_using] = ACTIONS(5537),
    [anon_sym_static_assert] = ACTIONS(5537),
    [anon_sym___launch_bounds__] = ACTIONS(5537),
  },
  [STATE(1966)] = {
    [sym_identifier] = ACTIONS(5665),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5667),
    [anon_sym_COMMA] = ACTIONS(5667),
    [anon_sym_RPAREN] = ACTIONS(5667),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5665),
    [anon_sym_PLUS] = ACTIONS(5665),
    [anon_sym_STAR] = ACTIONS(5667),
    [anon_sym_SLASH] = ACTIONS(5665),
    [anon_sym_PERCENT] = ACTIONS(5667),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_PIPE] = ACTIONS(5665),
    [anon_sym_CARET] = ACTIONS(5667),
    [anon_sym_AMP] = ACTIONS(5665),
    [anon_sym_EQ_EQ] = ACTIONS(5667),
    [anon_sym_BANG_EQ] = ACTIONS(5667),
    [anon_sym_GT] = ACTIONS(5665),
    [anon_sym_GT_EQ] = ACTIONS(5667),
    [anon_sym_LT_EQ] = ACTIONS(5665),
    [anon_sym_LT] = ACTIONS(5665),
    [anon_sym_LT_LT] = ACTIONS(5665),
    [anon_sym_GT_GT] = ACTIONS(5667),
    [anon_sym_SEMI] = ACTIONS(5667),
    [anon_sym___extension__] = ACTIONS(5665),
    [anon_sym___global__] = ACTIONS(5665),
    [anon_sym___attribute__] = ACTIONS(5665),
    [anon_sym___attribute] = ACTIONS(5665),
    [anon_sym_COLON_COLON] = ACTIONS(5667),
    [anon_sym___based] = ACTIONS(5665),
    [anon_sym_LBRACE] = ACTIONS(5667),
    [anon_sym_RBRACE] = ACTIONS(5667),
    [anon_sym_signed] = ACTIONS(5665),
    [anon_sym_unsigned] = ACTIONS(5665),
    [anon_sym_long] = ACTIONS(5665),
    [anon_sym_short] = ACTIONS(5665),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [anon_sym_RBRACK] = ACTIONS(5667),
    [anon_sym_const] = ACTIONS(5665),
    [anon_sym_constexpr] = ACTIONS(5665),
    [anon_sym_volatile] = ACTIONS(5665),
    [anon_sym_restrict] = ACTIONS(5665),
    [anon_sym___restrict__] = ACTIONS(5665),
    [anon_sym__Atomic] = ACTIONS(5665),
    [anon_sym__Noreturn] = ACTIONS(5665),
    [anon_sym_noreturn] = ACTIONS(5665),
    [anon_sym__Nonnull] = ACTIONS(5665),
    [anon_sym_mutable] = ACTIONS(5665),
    [anon_sym_constinit] = ACTIONS(5665),
    [anon_sym_consteval] = ACTIONS(5665),
    [anon_sym___shared__] = ACTIONS(5665),
    [anon_sym___local__] = ACTIONS(5665),
    [anon_sym___constant__] = ACTIONS(5665),
    [anon_sym___managed__] = ACTIONS(5665),
    [anon_sym___grid_constant__] = ACTIONS(5665),
    [anon_sym_alignas] = ACTIONS(5665),
    [anon_sym__Alignas] = ACTIONS(5665),
    [sym_primitive_type] = ACTIONS(5665),
    [anon_sym_COLON] = ACTIONS(5665),
    [anon_sym_QMARK] = ACTIONS(5667),
    [anon_sym_LT_EQ_GT] = ACTIONS(5667),
    [anon_sym_or] = ACTIONS(5665),
    [anon_sym_and] = ACTIONS(5665),
    [anon_sym_bitor] = ACTIONS(5665),
    [anon_sym_xor] = ACTIONS(5665),
    [anon_sym_bitand] = ACTIONS(5665),
    [anon_sym_not_eq] = ACTIONS(5665),
    [anon_sym_DASH_DASH] = ACTIONS(5667),
    [anon_sym_PLUS_PLUS] = ACTIONS(5667),
    [anon_sym_DOT] = ACTIONS(5665),
    [anon_sym_DOT_STAR] = ACTIONS(5667),
    [anon_sym_DASH_GT] = ACTIONS(5667),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5665),
    [anon_sym_decltype] = ACTIONS(5665),
    [anon_sym_final] = ACTIONS(5665),
    [anon_sym_override] = ACTIONS(5665),
    [anon_sym_requires] = ACTIONS(5665),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5667),
  },
  [STATE(1967)] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym___device__] = ACTIONS(2190),
    [anon_sym___host__] = ACTIONS(2190),
    [anon_sym___global__] = ACTIONS(2190),
    [anon_sym___forceinline__] = ACTIONS(2190),
    [anon_sym___noinline__] = ACTIONS(2190),
    [anon_sym_virtual] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym___attribute] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym_RBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym__Nonnull] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym___shared__] = ACTIONS(2190),
    [anon_sym___local__] = ACTIONS(2190),
    [anon_sym___constant__] = ACTIONS(2190),
    [anon_sym___managed__] = ACTIONS(2190),
    [anon_sym___grid_constant__] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_friend] = ACTIONS(2190),
    [anon_sym_public] = ACTIONS(2190),
    [anon_sym_private] = ACTIONS(2190),
    [anon_sym_protected] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym___launch_bounds__] = ACTIONS(2190),
  },
  [STATE(1968)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym_RBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_friend] = ACTIONS(2182),
    [anon_sym_public] = ACTIONS(2182),
    [anon_sym_private] = ACTIONS(2182),
    [anon_sym_protected] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(1969)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym_RBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_friend] = ACTIONS(2182),
    [anon_sym_public] = ACTIONS(2182),
    [anon_sym_private] = ACTIONS(2182),
    [anon_sym_protected] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(1970)] = {
    [sym_identifier] = ACTIONS(5573),
    [aux_sym_preproc_def_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token1] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5573),
    [sym_preproc_directive] = ACTIONS(5573),
    [anon_sym_LPAREN2] = ACTIONS(5575),
    [anon_sym_TILDE] = ACTIONS(5575),
    [anon_sym_STAR] = ACTIONS(5575),
    [anon_sym_AMP_AMP] = ACTIONS(5575),
    [anon_sym_AMP] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym___extension__] = ACTIONS(5573),
    [anon_sym_typedef] = ACTIONS(5573),
    [anon_sym___device__] = ACTIONS(5573),
    [anon_sym___host__] = ACTIONS(5573),
    [anon_sym___global__] = ACTIONS(5573),
    [anon_sym___forceinline__] = ACTIONS(5573),
    [anon_sym___noinline__] = ACTIONS(5573),
    [anon_sym_virtual] = ACTIONS(5573),
    [anon_sym_extern] = ACTIONS(5573),
    [anon_sym___attribute__] = ACTIONS(5573),
    [anon_sym___attribute] = ACTIONS(5573),
    [anon_sym_COLON_COLON] = ACTIONS(5575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5575),
    [anon_sym___declspec] = ACTIONS(5573),
    [anon_sym___based] = ACTIONS(5573),
    [anon_sym_RBRACE] = ACTIONS(5575),
    [anon_sym_signed] = ACTIONS(5573),
    [anon_sym_unsigned] = ACTIONS(5573),
    [anon_sym_long] = ACTIONS(5573),
    [anon_sym_short] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5573),
    [anon_sym_static] = ACTIONS(5573),
    [anon_sym_register] = ACTIONS(5573),
    [anon_sym_inline] = ACTIONS(5573),
    [anon_sym___inline] = ACTIONS(5573),
    [anon_sym___inline__] = ACTIONS(5573),
    [anon_sym___forceinline] = ACTIONS(5573),
    [anon_sym_thread_local] = ACTIONS(5573),
    [anon_sym___thread] = ACTIONS(5573),
    [anon_sym_const] = ACTIONS(5573),
    [anon_sym_constexpr] = ACTIONS(5573),
    [anon_sym_volatile] = ACTIONS(5573),
    [anon_sym_restrict] = ACTIONS(5573),
    [anon_sym___restrict__] = ACTIONS(5573),
    [anon_sym__Atomic] = ACTIONS(5573),
    [anon_sym__Noreturn] = ACTIONS(5573),
    [anon_sym_noreturn] = ACTIONS(5573),
    [anon_sym__Nonnull] = ACTIONS(5573),
    [anon_sym_mutable] = ACTIONS(5573),
    [anon_sym_constinit] = ACTIONS(5573),
    [anon_sym_consteval] = ACTIONS(5573),
    [anon_sym___shared__] = ACTIONS(5573),
    [anon_sym___local__] = ACTIONS(5573),
    [anon_sym___constant__] = ACTIONS(5573),
    [anon_sym___managed__] = ACTIONS(5573),
    [anon_sym___grid_constant__] = ACTIONS(5573),
    [anon_sym_alignas] = ACTIONS(5573),
    [anon_sym__Alignas] = ACTIONS(5573),
    [sym_primitive_type] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_class] = ACTIONS(5573),
    [anon_sym_struct] = ACTIONS(5573),
    [anon_sym_union] = ACTIONS(5573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5573),
    [anon_sym_decltype] = ACTIONS(5573),
    [anon_sym_explicit] = ACTIONS(5573),
    [anon_sym_typename] = ACTIONS(5573),
    [anon_sym_template] = ACTIONS(5573),
    [anon_sym_operator] = ACTIONS(5573),
    [anon_sym_friend] = ACTIONS(5573),
    [anon_sym_public] = ACTIONS(5573),
    [anon_sym_private] = ACTIONS(5573),
    [anon_sym_protected] = ACTIONS(5573),
    [anon_sym_using] = ACTIONS(5573),
    [anon_sym_static_assert] = ACTIONS(5573),
    [anon_sym___launch_bounds__] = ACTIONS(5573),
  },
  [STATE(1971)] = {
    [sym_identifier] = ACTIONS(2521),
    [aux_sym_preproc_def_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2521),
    [sym_preproc_directive] = ACTIONS(2521),
    [anon_sym_LPAREN2] = ACTIONS(2523),
    [anon_sym_TILDE] = ACTIONS(2523),
    [anon_sym_STAR] = ACTIONS(2523),
    [anon_sym_AMP_AMP] = ACTIONS(2523),
    [anon_sym_AMP] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym___extension__] = ACTIONS(2521),
    [anon_sym_typedef] = ACTIONS(2521),
    [anon_sym___device__] = ACTIONS(2521),
    [anon_sym___host__] = ACTIONS(2521),
    [anon_sym___global__] = ACTIONS(2521),
    [anon_sym___forceinline__] = ACTIONS(2521),
    [anon_sym___noinline__] = ACTIONS(2521),
    [anon_sym_virtual] = ACTIONS(2521),
    [anon_sym_extern] = ACTIONS(2521),
    [anon_sym___attribute__] = ACTIONS(2521),
    [anon_sym___attribute] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2523),
    [anon_sym___declspec] = ACTIONS(2521),
    [anon_sym___based] = ACTIONS(2521),
    [anon_sym_RBRACE] = ACTIONS(2523),
    [anon_sym_signed] = ACTIONS(2521),
    [anon_sym_unsigned] = ACTIONS(2521),
    [anon_sym_long] = ACTIONS(2521),
    [anon_sym_short] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2521),
    [anon_sym_static] = ACTIONS(2521),
    [anon_sym_register] = ACTIONS(2521),
    [anon_sym_inline] = ACTIONS(2521),
    [anon_sym___inline] = ACTIONS(2521),
    [anon_sym___inline__] = ACTIONS(2521),
    [anon_sym___forceinline] = ACTIONS(2521),
    [anon_sym_thread_local] = ACTIONS(2521),
    [anon_sym___thread] = ACTIONS(2521),
    [anon_sym_const] = ACTIONS(2521),
    [anon_sym_constexpr] = ACTIONS(2521),
    [anon_sym_volatile] = ACTIONS(2521),
    [anon_sym_restrict] = ACTIONS(2521),
    [anon_sym___restrict__] = ACTIONS(2521),
    [anon_sym__Atomic] = ACTIONS(2521),
    [anon_sym__Noreturn] = ACTIONS(2521),
    [anon_sym_noreturn] = ACTIONS(2521),
    [anon_sym__Nonnull] = ACTIONS(2521),
    [anon_sym_mutable] = ACTIONS(2521),
    [anon_sym_constinit] = ACTIONS(2521),
    [anon_sym_consteval] = ACTIONS(2521),
    [anon_sym___shared__] = ACTIONS(2521),
    [anon_sym___local__] = ACTIONS(2521),
    [anon_sym___constant__] = ACTIONS(2521),
    [anon_sym___managed__] = ACTIONS(2521),
    [anon_sym___grid_constant__] = ACTIONS(2521),
    [anon_sym_alignas] = ACTIONS(2521),
    [anon_sym__Alignas] = ACTIONS(2521),
    [sym_primitive_type] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_class] = ACTIONS(2521),
    [anon_sym_struct] = ACTIONS(2521),
    [anon_sym_union] = ACTIONS(2521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2521),
    [anon_sym_decltype] = ACTIONS(2521),
    [anon_sym_explicit] = ACTIONS(2521),
    [anon_sym_typename] = ACTIONS(2521),
    [anon_sym_template] = ACTIONS(2521),
    [anon_sym_operator] = ACTIONS(2521),
    [anon_sym_friend] = ACTIONS(2521),
    [anon_sym_public] = ACTIONS(2521),
    [anon_sym_private] = ACTIONS(2521),
    [anon_sym_protected] = ACTIONS(2521),
    [anon_sym_using] = ACTIONS(2521),
    [anon_sym_static_assert] = ACTIONS(2521),
    [anon_sym___launch_bounds__] = ACTIONS(2521),
  },
  [STATE(1972)] = {
    [sym_identifier] = ACTIONS(5541),
    [aux_sym_preproc_def_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token2] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5541),
    [sym_preproc_directive] = ACTIONS(5541),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_TILDE] = ACTIONS(5543),
    [anon_sym_STAR] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___extension__] = ACTIONS(5541),
    [anon_sym_typedef] = ACTIONS(5541),
    [anon_sym___device__] = ACTIONS(5541),
    [anon_sym___host__] = ACTIONS(5541),
    [anon_sym___global__] = ACTIONS(5541),
    [anon_sym___forceinline__] = ACTIONS(5541),
    [anon_sym___noinline__] = ACTIONS(5541),
    [anon_sym_virtual] = ACTIONS(5541),
    [anon_sym_extern] = ACTIONS(5541),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym___attribute] = ACTIONS(5541),
    [anon_sym_COLON_COLON] = ACTIONS(5543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5543),
    [anon_sym___declspec] = ACTIONS(5541),
    [anon_sym___based] = ACTIONS(5541),
    [anon_sym_signed] = ACTIONS(5541),
    [anon_sym_unsigned] = ACTIONS(5541),
    [anon_sym_long] = ACTIONS(5541),
    [anon_sym_short] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5541),
    [anon_sym_static] = ACTIONS(5541),
    [anon_sym_register] = ACTIONS(5541),
    [anon_sym_inline] = ACTIONS(5541),
    [anon_sym___inline] = ACTIONS(5541),
    [anon_sym___inline__] = ACTIONS(5541),
    [anon_sym___forceinline] = ACTIONS(5541),
    [anon_sym_thread_local] = ACTIONS(5541),
    [anon_sym___thread] = ACTIONS(5541),
    [anon_sym_const] = ACTIONS(5541),
    [anon_sym_constexpr] = ACTIONS(5541),
    [anon_sym_volatile] = ACTIONS(5541),
    [anon_sym_restrict] = ACTIONS(5541),
    [anon_sym___restrict__] = ACTIONS(5541),
    [anon_sym__Atomic] = ACTIONS(5541),
    [anon_sym__Noreturn] = ACTIONS(5541),
    [anon_sym_noreturn] = ACTIONS(5541),
    [anon_sym__Nonnull] = ACTIONS(5541),
    [anon_sym_mutable] = ACTIONS(5541),
    [anon_sym_constinit] = ACTIONS(5541),
    [anon_sym_consteval] = ACTIONS(5541),
    [anon_sym___shared__] = ACTIONS(5541),
    [anon_sym___local__] = ACTIONS(5541),
    [anon_sym___constant__] = ACTIONS(5541),
    [anon_sym___managed__] = ACTIONS(5541),
    [anon_sym___grid_constant__] = ACTIONS(5541),
    [anon_sym_alignas] = ACTIONS(5541),
    [anon_sym__Alignas] = ACTIONS(5541),
    [sym_primitive_type] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_class] = ACTIONS(5541),
    [anon_sym_struct] = ACTIONS(5541),
    [anon_sym_union] = ACTIONS(5541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
    [anon_sym_explicit] = ACTIONS(5541),
    [anon_sym_typename] = ACTIONS(5541),
    [anon_sym_template] = ACTIONS(5541),
    [anon_sym_operator] = ACTIONS(5541),
    [anon_sym_friend] = ACTIONS(5541),
    [anon_sym_public] = ACTIONS(5541),
    [anon_sym_private] = ACTIONS(5541),
    [anon_sym_protected] = ACTIONS(5541),
    [anon_sym_using] = ACTIONS(5541),
    [anon_sym_static_assert] = ACTIONS(5541),
    [anon_sym___launch_bounds__] = ACTIONS(5541),
  },
  [STATE(1973)] = {
    [sym_identifier] = ACTIONS(5581),
    [aux_sym_preproc_def_token1] = ACTIONS(5581),
    [aux_sym_preproc_if_token1] = ACTIONS(5581),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5581),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5581),
    [sym_preproc_directive] = ACTIONS(5581),
    [anon_sym_LPAREN2] = ACTIONS(5583),
    [anon_sym_TILDE] = ACTIONS(5583),
    [anon_sym_STAR] = ACTIONS(5583),
    [anon_sym_AMP_AMP] = ACTIONS(5583),
    [anon_sym_AMP] = ACTIONS(5581),
    [anon_sym_SEMI] = ACTIONS(5583),
    [anon_sym___extension__] = ACTIONS(5581),
    [anon_sym_typedef] = ACTIONS(5581),
    [anon_sym___device__] = ACTIONS(5581),
    [anon_sym___host__] = ACTIONS(5581),
    [anon_sym___global__] = ACTIONS(5581),
    [anon_sym___forceinline__] = ACTIONS(5581),
    [anon_sym___noinline__] = ACTIONS(5581),
    [anon_sym_virtual] = ACTIONS(5581),
    [anon_sym_extern] = ACTIONS(5581),
    [anon_sym___attribute__] = ACTIONS(5581),
    [anon_sym___attribute] = ACTIONS(5581),
    [anon_sym_COLON_COLON] = ACTIONS(5583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5583),
    [anon_sym___declspec] = ACTIONS(5581),
    [anon_sym___based] = ACTIONS(5581),
    [anon_sym_RBRACE] = ACTIONS(5583),
    [anon_sym_signed] = ACTIONS(5581),
    [anon_sym_unsigned] = ACTIONS(5581),
    [anon_sym_long] = ACTIONS(5581),
    [anon_sym_short] = ACTIONS(5581),
    [anon_sym_LBRACK] = ACTIONS(5581),
    [anon_sym_static] = ACTIONS(5581),
    [anon_sym_register] = ACTIONS(5581),
    [anon_sym_inline] = ACTIONS(5581),
    [anon_sym___inline] = ACTIONS(5581),
    [anon_sym___inline__] = ACTIONS(5581),
    [anon_sym___forceinline] = ACTIONS(5581),
    [anon_sym_thread_local] = ACTIONS(5581),
    [anon_sym___thread] = ACTIONS(5581),
    [anon_sym_const] = ACTIONS(5581),
    [anon_sym_constexpr] = ACTIONS(5581),
    [anon_sym_volatile] = ACTIONS(5581),
    [anon_sym_restrict] = ACTIONS(5581),
    [anon_sym___restrict__] = ACTIONS(5581),
    [anon_sym__Atomic] = ACTIONS(5581),
    [anon_sym__Noreturn] = ACTIONS(5581),
    [anon_sym_noreturn] = ACTIONS(5581),
    [anon_sym__Nonnull] = ACTIONS(5581),
    [anon_sym_mutable] = ACTIONS(5581),
    [anon_sym_constinit] = ACTIONS(5581),
    [anon_sym_consteval] = ACTIONS(5581),
    [anon_sym___shared__] = ACTIONS(5581),
    [anon_sym___local__] = ACTIONS(5581),
    [anon_sym___constant__] = ACTIONS(5581),
    [anon_sym___managed__] = ACTIONS(5581),
    [anon_sym___grid_constant__] = ACTIONS(5581),
    [anon_sym_alignas] = ACTIONS(5581),
    [anon_sym__Alignas] = ACTIONS(5581),
    [sym_primitive_type] = ACTIONS(5581),
    [anon_sym_enum] = ACTIONS(5581),
    [anon_sym_class] = ACTIONS(5581),
    [anon_sym_struct] = ACTIONS(5581),
    [anon_sym_union] = ACTIONS(5581),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5581),
    [anon_sym_decltype] = ACTIONS(5581),
    [anon_sym_explicit] = ACTIONS(5581),
    [anon_sym_typename] = ACTIONS(5581),
    [anon_sym_template] = ACTIONS(5581),
    [anon_sym_operator] = ACTIONS(5581),
    [anon_sym_friend] = ACTIONS(5581),
    [anon_sym_public] = ACTIONS(5581),
    [anon_sym_private] = ACTIONS(5581),
    [anon_sym_protected] = ACTIONS(5581),
    [anon_sym_using] = ACTIONS(5581),
    [anon_sym_static_assert] = ACTIONS(5581),
    [anon_sym___launch_bounds__] = ACTIONS(5581),
  },
  [STATE(1974)] = {
    [sym_identifier] = ACTIONS(5541),
    [aux_sym_preproc_def_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token2] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5541),
    [sym_preproc_directive] = ACTIONS(5541),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_TILDE] = ACTIONS(5543),
    [anon_sym_STAR] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___extension__] = ACTIONS(5541),
    [anon_sym_typedef] = ACTIONS(5541),
    [anon_sym___device__] = ACTIONS(5541),
    [anon_sym___host__] = ACTIONS(5541),
    [anon_sym___global__] = ACTIONS(5541),
    [anon_sym___forceinline__] = ACTIONS(5541),
    [anon_sym___noinline__] = ACTIONS(5541),
    [anon_sym_virtual] = ACTIONS(5541),
    [anon_sym_extern] = ACTIONS(5541),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym___attribute] = ACTIONS(5541),
    [anon_sym_COLON_COLON] = ACTIONS(5543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5543),
    [anon_sym___declspec] = ACTIONS(5541),
    [anon_sym___based] = ACTIONS(5541),
    [anon_sym_signed] = ACTIONS(5541),
    [anon_sym_unsigned] = ACTIONS(5541),
    [anon_sym_long] = ACTIONS(5541),
    [anon_sym_short] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5541),
    [anon_sym_static] = ACTIONS(5541),
    [anon_sym_register] = ACTIONS(5541),
    [anon_sym_inline] = ACTIONS(5541),
    [anon_sym___inline] = ACTIONS(5541),
    [anon_sym___inline__] = ACTIONS(5541),
    [anon_sym___forceinline] = ACTIONS(5541),
    [anon_sym_thread_local] = ACTIONS(5541),
    [anon_sym___thread] = ACTIONS(5541),
    [anon_sym_const] = ACTIONS(5541),
    [anon_sym_constexpr] = ACTIONS(5541),
    [anon_sym_volatile] = ACTIONS(5541),
    [anon_sym_restrict] = ACTIONS(5541),
    [anon_sym___restrict__] = ACTIONS(5541),
    [anon_sym__Atomic] = ACTIONS(5541),
    [anon_sym__Noreturn] = ACTIONS(5541),
    [anon_sym_noreturn] = ACTIONS(5541),
    [anon_sym__Nonnull] = ACTIONS(5541),
    [anon_sym_mutable] = ACTIONS(5541),
    [anon_sym_constinit] = ACTIONS(5541),
    [anon_sym_consteval] = ACTIONS(5541),
    [anon_sym___shared__] = ACTIONS(5541),
    [anon_sym___local__] = ACTIONS(5541),
    [anon_sym___constant__] = ACTIONS(5541),
    [anon_sym___managed__] = ACTIONS(5541),
    [anon_sym___grid_constant__] = ACTIONS(5541),
    [anon_sym_alignas] = ACTIONS(5541),
    [anon_sym__Alignas] = ACTIONS(5541),
    [sym_primitive_type] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_class] = ACTIONS(5541),
    [anon_sym_struct] = ACTIONS(5541),
    [anon_sym_union] = ACTIONS(5541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
    [anon_sym_explicit] = ACTIONS(5541),
    [anon_sym_typename] = ACTIONS(5541),
    [anon_sym_template] = ACTIONS(5541),
    [anon_sym_operator] = ACTIONS(5541),
    [anon_sym_friend] = ACTIONS(5541),
    [anon_sym_public] = ACTIONS(5541),
    [anon_sym_private] = ACTIONS(5541),
    [anon_sym_protected] = ACTIONS(5541),
    [anon_sym_using] = ACTIONS(5541),
    [anon_sym_static_assert] = ACTIONS(5541),
    [anon_sym___launch_bounds__] = ACTIONS(5541),
  },
  [STATE(1975)] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym___device__] = ACTIONS(2134),
    [anon_sym___host__] = ACTIONS(2134),
    [anon_sym___global__] = ACTIONS(2134),
    [anon_sym___forceinline__] = ACTIONS(2134),
    [anon_sym___noinline__] = ACTIONS(2134),
    [anon_sym_virtual] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym___attribute] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym_RBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym__Nonnull] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym___shared__] = ACTIONS(2134),
    [anon_sym___local__] = ACTIONS(2134),
    [anon_sym___constant__] = ACTIONS(2134),
    [anon_sym___managed__] = ACTIONS(2134),
    [anon_sym___grid_constant__] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_friend] = ACTIONS(2134),
    [anon_sym_public] = ACTIONS(2134),
    [anon_sym_private] = ACTIONS(2134),
    [anon_sym_protected] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym___launch_bounds__] = ACTIONS(2134),
  },
  [STATE(1976)] = {
    [sym_identifier] = ACTIONS(5545),
    [aux_sym_preproc_def_token1] = ACTIONS(5545),
    [aux_sym_preproc_if_token1] = ACTIONS(5545),
    [aux_sym_preproc_if_token2] = ACTIONS(5545),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5545),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5545),
    [sym_preproc_directive] = ACTIONS(5545),
    [anon_sym_LPAREN2] = ACTIONS(5547),
    [anon_sym_TILDE] = ACTIONS(5547),
    [anon_sym_STAR] = ACTIONS(5547),
    [anon_sym_AMP_AMP] = ACTIONS(5547),
    [anon_sym_AMP] = ACTIONS(5545),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym___extension__] = ACTIONS(5545),
    [anon_sym_typedef] = ACTIONS(5545),
    [anon_sym___device__] = ACTIONS(5545),
    [anon_sym___host__] = ACTIONS(5545),
    [anon_sym___global__] = ACTIONS(5545),
    [anon_sym___forceinline__] = ACTIONS(5545),
    [anon_sym___noinline__] = ACTIONS(5545),
    [anon_sym_virtual] = ACTIONS(5545),
    [anon_sym_extern] = ACTIONS(5545),
    [anon_sym___attribute__] = ACTIONS(5545),
    [anon_sym___attribute] = ACTIONS(5545),
    [anon_sym_COLON_COLON] = ACTIONS(5547),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5547),
    [anon_sym___declspec] = ACTIONS(5545),
    [anon_sym___based] = ACTIONS(5545),
    [anon_sym_signed] = ACTIONS(5545),
    [anon_sym_unsigned] = ACTIONS(5545),
    [anon_sym_long] = ACTIONS(5545),
    [anon_sym_short] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5545),
    [anon_sym_static] = ACTIONS(5545),
    [anon_sym_register] = ACTIONS(5545),
    [anon_sym_inline] = ACTIONS(5545),
    [anon_sym___inline] = ACTIONS(5545),
    [anon_sym___inline__] = ACTIONS(5545),
    [anon_sym___forceinline] = ACTIONS(5545),
    [anon_sym_thread_local] = ACTIONS(5545),
    [anon_sym___thread] = ACTIONS(5545),
    [anon_sym_const] = ACTIONS(5545),
    [anon_sym_constexpr] = ACTIONS(5545),
    [anon_sym_volatile] = ACTIONS(5545),
    [anon_sym_restrict] = ACTIONS(5545),
    [anon_sym___restrict__] = ACTIONS(5545),
    [anon_sym__Atomic] = ACTIONS(5545),
    [anon_sym__Noreturn] = ACTIONS(5545),
    [anon_sym_noreturn] = ACTIONS(5545),
    [anon_sym__Nonnull] = ACTIONS(5545),
    [anon_sym_mutable] = ACTIONS(5545),
    [anon_sym_constinit] = ACTIONS(5545),
    [anon_sym_consteval] = ACTIONS(5545),
    [anon_sym___shared__] = ACTIONS(5545),
    [anon_sym___local__] = ACTIONS(5545),
    [anon_sym___constant__] = ACTIONS(5545),
    [anon_sym___managed__] = ACTIONS(5545),
    [anon_sym___grid_constant__] = ACTIONS(5545),
    [anon_sym_alignas] = ACTIONS(5545),
    [anon_sym__Alignas] = ACTIONS(5545),
    [sym_primitive_type] = ACTIONS(5545),
    [anon_sym_enum] = ACTIONS(5545),
    [anon_sym_class] = ACTIONS(5545),
    [anon_sym_struct] = ACTIONS(5545),
    [anon_sym_union] = ACTIONS(5545),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5545),
    [anon_sym_decltype] = ACTIONS(5545),
    [anon_sym_explicit] = ACTIONS(5545),
    [anon_sym_typename] = ACTIONS(5545),
    [anon_sym_template] = ACTIONS(5545),
    [anon_sym_operator] = ACTIONS(5545),
    [anon_sym_friend] = ACTIONS(5545),
    [anon_sym_public] = ACTIONS(5545),
    [anon_sym_private] = ACTIONS(5545),
    [anon_sym_protected] = ACTIONS(5545),
    [anon_sym_using] = ACTIONS(5545),
    [anon_sym_static_assert] = ACTIONS(5545),
    [anon_sym___launch_bounds__] = ACTIONS(5545),
  },
  [STATE(1977)] = {
    [sym_identifier] = ACTIONS(5525),
    [aux_sym_preproc_def_token1] = ACTIONS(5525),
    [aux_sym_preproc_if_token1] = ACTIONS(5525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5525),
    [sym_preproc_directive] = ACTIONS(5525),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_TILDE] = ACTIONS(5527),
    [anon_sym_STAR] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___extension__] = ACTIONS(5525),
    [anon_sym_typedef] = ACTIONS(5525),
    [anon_sym___device__] = ACTIONS(5525),
    [anon_sym___host__] = ACTIONS(5525),
    [anon_sym___global__] = ACTIONS(5525),
    [anon_sym___forceinline__] = ACTIONS(5525),
    [anon_sym___noinline__] = ACTIONS(5525),
    [anon_sym_virtual] = ACTIONS(5525),
    [anon_sym_extern] = ACTIONS(5525),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym___attribute] = ACTIONS(5525),
    [anon_sym_COLON_COLON] = ACTIONS(5527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5527),
    [anon_sym___declspec] = ACTIONS(5525),
    [anon_sym___based] = ACTIONS(5525),
    [anon_sym_RBRACE] = ACTIONS(5527),
    [anon_sym_signed] = ACTIONS(5525),
    [anon_sym_unsigned] = ACTIONS(5525),
    [anon_sym_long] = ACTIONS(5525),
    [anon_sym_short] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5525),
    [anon_sym_static] = ACTIONS(5525),
    [anon_sym_register] = ACTIONS(5525),
    [anon_sym_inline] = ACTIONS(5525),
    [anon_sym___inline] = ACTIONS(5525),
    [anon_sym___inline__] = ACTIONS(5525),
    [anon_sym___forceinline] = ACTIONS(5525),
    [anon_sym_thread_local] = ACTIONS(5525),
    [anon_sym___thread] = ACTIONS(5525),
    [anon_sym_const] = ACTIONS(5525),
    [anon_sym_constexpr] = ACTIONS(5525),
    [anon_sym_volatile] = ACTIONS(5525),
    [anon_sym_restrict] = ACTIONS(5525),
    [anon_sym___restrict__] = ACTIONS(5525),
    [anon_sym__Atomic] = ACTIONS(5525),
    [anon_sym__Noreturn] = ACTIONS(5525),
    [anon_sym_noreturn] = ACTIONS(5525),
    [anon_sym__Nonnull] = ACTIONS(5525),
    [anon_sym_mutable] = ACTIONS(5525),
    [anon_sym_constinit] = ACTIONS(5525),
    [anon_sym_consteval] = ACTIONS(5525),
    [anon_sym___shared__] = ACTIONS(5525),
    [anon_sym___local__] = ACTIONS(5525),
    [anon_sym___constant__] = ACTIONS(5525),
    [anon_sym___managed__] = ACTIONS(5525),
    [anon_sym___grid_constant__] = ACTIONS(5525),
    [anon_sym_alignas] = ACTIONS(5525),
    [anon_sym__Alignas] = ACTIONS(5525),
    [sym_primitive_type] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_class] = ACTIONS(5525),
    [anon_sym_struct] = ACTIONS(5525),
    [anon_sym_union] = ACTIONS(5525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
    [anon_sym_explicit] = ACTIONS(5525),
    [anon_sym_typename] = ACTIONS(5525),
    [anon_sym_template] = ACTIONS(5525),
    [anon_sym_operator] = ACTIONS(5525),
    [anon_sym_friend] = ACTIONS(5525),
    [anon_sym_public] = ACTIONS(5525),
    [anon_sym_private] = ACTIONS(5525),
    [anon_sym_protected] = ACTIONS(5525),
    [anon_sym_using] = ACTIONS(5525),
    [anon_sym_static_assert] = ACTIONS(5525),
    [anon_sym___launch_bounds__] = ACTIONS(5525),
  },
  [STATE(1978)] = {
    [sym_identifier] = ACTIONS(2485),
    [aux_sym_preproc_def_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2485),
    [sym_preproc_directive] = ACTIONS(2485),
    [anon_sym_LPAREN2] = ACTIONS(2487),
    [anon_sym_TILDE] = ACTIONS(2487),
    [anon_sym_STAR] = ACTIONS(2487),
    [anon_sym_AMP_AMP] = ACTIONS(2487),
    [anon_sym_AMP] = ACTIONS(2485),
    [anon_sym_SEMI] = ACTIONS(2487),
    [anon_sym___extension__] = ACTIONS(2485),
    [anon_sym_typedef] = ACTIONS(2485),
    [anon_sym___device__] = ACTIONS(2485),
    [anon_sym___host__] = ACTIONS(2485),
    [anon_sym___global__] = ACTIONS(2485),
    [anon_sym___forceinline__] = ACTIONS(2485),
    [anon_sym___noinline__] = ACTIONS(2485),
    [anon_sym_virtual] = ACTIONS(2485),
    [anon_sym_extern] = ACTIONS(2485),
    [anon_sym___attribute__] = ACTIONS(2485),
    [anon_sym___attribute] = ACTIONS(2485),
    [anon_sym_COLON_COLON] = ACTIONS(2487),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2487),
    [anon_sym___declspec] = ACTIONS(2485),
    [anon_sym___based] = ACTIONS(2485),
    [anon_sym_RBRACE] = ACTIONS(2487),
    [anon_sym_signed] = ACTIONS(2485),
    [anon_sym_unsigned] = ACTIONS(2485),
    [anon_sym_long] = ACTIONS(2485),
    [anon_sym_short] = ACTIONS(2485),
    [anon_sym_LBRACK] = ACTIONS(2485),
    [anon_sym_static] = ACTIONS(2485),
    [anon_sym_register] = ACTIONS(2485),
    [anon_sym_inline] = ACTIONS(2485),
    [anon_sym___inline] = ACTIONS(2485),
    [anon_sym___inline__] = ACTIONS(2485),
    [anon_sym___forceinline] = ACTIONS(2485),
    [anon_sym_thread_local] = ACTIONS(2485),
    [anon_sym___thread] = ACTIONS(2485),
    [anon_sym_const] = ACTIONS(2485),
    [anon_sym_constexpr] = ACTIONS(2485),
    [anon_sym_volatile] = ACTIONS(2485),
    [anon_sym_restrict] = ACTIONS(2485),
    [anon_sym___restrict__] = ACTIONS(2485),
    [anon_sym__Atomic] = ACTIONS(2485),
    [anon_sym__Noreturn] = ACTIONS(2485),
    [anon_sym_noreturn] = ACTIONS(2485),
    [anon_sym__Nonnull] = ACTIONS(2485),
    [anon_sym_mutable] = ACTIONS(2485),
    [anon_sym_constinit] = ACTIONS(2485),
    [anon_sym_consteval] = ACTIONS(2485),
    [anon_sym___shared__] = ACTIONS(2485),
    [anon_sym___local__] = ACTIONS(2485),
    [anon_sym___constant__] = ACTIONS(2485),
    [anon_sym___managed__] = ACTIONS(2485),
    [anon_sym___grid_constant__] = ACTIONS(2485),
    [anon_sym_alignas] = ACTIONS(2485),
    [anon_sym__Alignas] = ACTIONS(2485),
    [sym_primitive_type] = ACTIONS(2485),
    [anon_sym_enum] = ACTIONS(2485),
    [anon_sym_class] = ACTIONS(2485),
    [anon_sym_struct] = ACTIONS(2485),
    [anon_sym_union] = ACTIONS(2485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2485),
    [anon_sym_decltype] = ACTIONS(2485),
    [anon_sym_explicit] = ACTIONS(2485),
    [anon_sym_typename] = ACTIONS(2485),
    [anon_sym_template] = ACTIONS(2485),
    [anon_sym_operator] = ACTIONS(2485),
    [anon_sym_friend] = ACTIONS(2485),
    [anon_sym_public] = ACTIONS(2485),
    [anon_sym_private] = ACTIONS(2485),
    [anon_sym_protected] = ACTIONS(2485),
    [anon_sym_using] = ACTIONS(2485),
    [anon_sym_static_assert] = ACTIONS(2485),
    [anon_sym___launch_bounds__] = ACTIONS(2485),
  },
  [STATE(1979)] = {
    [sym_identifier] = ACTIONS(5607),
    [aux_sym_preproc_def_token1] = ACTIONS(5607),
    [aux_sym_preproc_if_token1] = ACTIONS(5607),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5607),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5607),
    [sym_preproc_directive] = ACTIONS(5607),
    [anon_sym_LPAREN2] = ACTIONS(5609),
    [anon_sym_TILDE] = ACTIONS(5609),
    [anon_sym_STAR] = ACTIONS(5609),
    [anon_sym_AMP_AMP] = ACTIONS(5609),
    [anon_sym_AMP] = ACTIONS(5607),
    [anon_sym_SEMI] = ACTIONS(5609),
    [anon_sym___extension__] = ACTIONS(5607),
    [anon_sym_typedef] = ACTIONS(5607),
    [anon_sym___device__] = ACTIONS(5607),
    [anon_sym___host__] = ACTIONS(5607),
    [anon_sym___global__] = ACTIONS(5607),
    [anon_sym___forceinline__] = ACTIONS(5607),
    [anon_sym___noinline__] = ACTIONS(5607),
    [anon_sym_virtual] = ACTIONS(5607),
    [anon_sym_extern] = ACTIONS(5607),
    [anon_sym___attribute__] = ACTIONS(5607),
    [anon_sym___attribute] = ACTIONS(5607),
    [anon_sym_COLON_COLON] = ACTIONS(5609),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5609),
    [anon_sym___declspec] = ACTIONS(5607),
    [anon_sym___based] = ACTIONS(5607),
    [anon_sym_RBRACE] = ACTIONS(5609),
    [anon_sym_signed] = ACTIONS(5607),
    [anon_sym_unsigned] = ACTIONS(5607),
    [anon_sym_long] = ACTIONS(5607),
    [anon_sym_short] = ACTIONS(5607),
    [anon_sym_LBRACK] = ACTIONS(5607),
    [anon_sym_static] = ACTIONS(5607),
    [anon_sym_register] = ACTIONS(5607),
    [anon_sym_inline] = ACTIONS(5607),
    [anon_sym___inline] = ACTIONS(5607),
    [anon_sym___inline__] = ACTIONS(5607),
    [anon_sym___forceinline] = ACTIONS(5607),
    [anon_sym_thread_local] = ACTIONS(5607),
    [anon_sym___thread] = ACTIONS(5607),
    [anon_sym_const] = ACTIONS(5607),
    [anon_sym_constexpr] = ACTIONS(5607),
    [anon_sym_volatile] = ACTIONS(5607),
    [anon_sym_restrict] = ACTIONS(5607),
    [anon_sym___restrict__] = ACTIONS(5607),
    [anon_sym__Atomic] = ACTIONS(5607),
    [anon_sym__Noreturn] = ACTIONS(5607),
    [anon_sym_noreturn] = ACTIONS(5607),
    [anon_sym__Nonnull] = ACTIONS(5607),
    [anon_sym_mutable] = ACTIONS(5607),
    [anon_sym_constinit] = ACTIONS(5607),
    [anon_sym_consteval] = ACTIONS(5607),
    [anon_sym___shared__] = ACTIONS(5607),
    [anon_sym___local__] = ACTIONS(5607),
    [anon_sym___constant__] = ACTIONS(5607),
    [anon_sym___managed__] = ACTIONS(5607),
    [anon_sym___grid_constant__] = ACTIONS(5607),
    [anon_sym_alignas] = ACTIONS(5607),
    [anon_sym__Alignas] = ACTIONS(5607),
    [sym_primitive_type] = ACTIONS(5607),
    [anon_sym_enum] = ACTIONS(5607),
    [anon_sym_class] = ACTIONS(5607),
    [anon_sym_struct] = ACTIONS(5607),
    [anon_sym_union] = ACTIONS(5607),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5607),
    [anon_sym_decltype] = ACTIONS(5607),
    [anon_sym_explicit] = ACTIONS(5607),
    [anon_sym_typename] = ACTIONS(5607),
    [anon_sym_template] = ACTIONS(5607),
    [anon_sym_operator] = ACTIONS(5607),
    [anon_sym_friend] = ACTIONS(5607),
    [anon_sym_public] = ACTIONS(5607),
    [anon_sym_private] = ACTIONS(5607),
    [anon_sym_protected] = ACTIONS(5607),
    [anon_sym_using] = ACTIONS(5607),
    [anon_sym_static_assert] = ACTIONS(5607),
    [anon_sym___launch_bounds__] = ACTIONS(5607),
  },
  [STATE(1980)] = {
    [sym_identifier] = ACTIONS(5611),
    [aux_sym_preproc_def_token1] = ACTIONS(5611),
    [aux_sym_preproc_if_token1] = ACTIONS(5611),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5611),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5611),
    [sym_preproc_directive] = ACTIONS(5611),
    [anon_sym_LPAREN2] = ACTIONS(5613),
    [anon_sym_TILDE] = ACTIONS(5613),
    [anon_sym_STAR] = ACTIONS(5613),
    [anon_sym_AMP_AMP] = ACTIONS(5613),
    [anon_sym_AMP] = ACTIONS(5611),
    [anon_sym_SEMI] = ACTIONS(5613),
    [anon_sym___extension__] = ACTIONS(5611),
    [anon_sym_typedef] = ACTIONS(5611),
    [anon_sym___device__] = ACTIONS(5611),
    [anon_sym___host__] = ACTIONS(5611),
    [anon_sym___global__] = ACTIONS(5611),
    [anon_sym___forceinline__] = ACTIONS(5611),
    [anon_sym___noinline__] = ACTIONS(5611),
    [anon_sym_virtual] = ACTIONS(5611),
    [anon_sym_extern] = ACTIONS(5611),
    [anon_sym___attribute__] = ACTIONS(5611),
    [anon_sym___attribute] = ACTIONS(5611),
    [anon_sym_COLON_COLON] = ACTIONS(5613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5613),
    [anon_sym___declspec] = ACTIONS(5611),
    [anon_sym___based] = ACTIONS(5611),
    [anon_sym_RBRACE] = ACTIONS(5613),
    [anon_sym_signed] = ACTIONS(5611),
    [anon_sym_unsigned] = ACTIONS(5611),
    [anon_sym_long] = ACTIONS(5611),
    [anon_sym_short] = ACTIONS(5611),
    [anon_sym_LBRACK] = ACTIONS(5611),
    [anon_sym_static] = ACTIONS(5611),
    [anon_sym_register] = ACTIONS(5611),
    [anon_sym_inline] = ACTIONS(5611),
    [anon_sym___inline] = ACTIONS(5611),
    [anon_sym___inline__] = ACTIONS(5611),
    [anon_sym___forceinline] = ACTIONS(5611),
    [anon_sym_thread_local] = ACTIONS(5611),
    [anon_sym___thread] = ACTIONS(5611),
    [anon_sym_const] = ACTIONS(5611),
    [anon_sym_constexpr] = ACTIONS(5611),
    [anon_sym_volatile] = ACTIONS(5611),
    [anon_sym_restrict] = ACTIONS(5611),
    [anon_sym___restrict__] = ACTIONS(5611),
    [anon_sym__Atomic] = ACTIONS(5611),
    [anon_sym__Noreturn] = ACTIONS(5611),
    [anon_sym_noreturn] = ACTIONS(5611),
    [anon_sym__Nonnull] = ACTIONS(5611),
    [anon_sym_mutable] = ACTIONS(5611),
    [anon_sym_constinit] = ACTIONS(5611),
    [anon_sym_consteval] = ACTIONS(5611),
    [anon_sym___shared__] = ACTIONS(5611),
    [anon_sym___local__] = ACTIONS(5611),
    [anon_sym___constant__] = ACTIONS(5611),
    [anon_sym___managed__] = ACTIONS(5611),
    [anon_sym___grid_constant__] = ACTIONS(5611),
    [anon_sym_alignas] = ACTIONS(5611),
    [anon_sym__Alignas] = ACTIONS(5611),
    [sym_primitive_type] = ACTIONS(5611),
    [anon_sym_enum] = ACTIONS(5611),
    [anon_sym_class] = ACTIONS(5611),
    [anon_sym_struct] = ACTIONS(5611),
    [anon_sym_union] = ACTIONS(5611),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5611),
    [anon_sym_decltype] = ACTIONS(5611),
    [anon_sym_explicit] = ACTIONS(5611),
    [anon_sym_typename] = ACTIONS(5611),
    [anon_sym_template] = ACTIONS(5611),
    [anon_sym_operator] = ACTIONS(5611),
    [anon_sym_friend] = ACTIONS(5611),
    [anon_sym_public] = ACTIONS(5611),
    [anon_sym_private] = ACTIONS(5611),
    [anon_sym_protected] = ACTIONS(5611),
    [anon_sym_using] = ACTIONS(5611),
    [anon_sym_static_assert] = ACTIONS(5611),
    [anon_sym___launch_bounds__] = ACTIONS(5611),
  },
  [STATE(1981)] = {
    [sym_identifier] = ACTIONS(5549),
    [aux_sym_preproc_def_token1] = ACTIONS(5549),
    [aux_sym_preproc_if_token1] = ACTIONS(5549),
    [aux_sym_preproc_if_token2] = ACTIONS(5549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5549),
    [sym_preproc_directive] = ACTIONS(5549),
    [anon_sym_LPAREN2] = ACTIONS(5551),
    [anon_sym_TILDE] = ACTIONS(5551),
    [anon_sym_STAR] = ACTIONS(5551),
    [anon_sym_AMP_AMP] = ACTIONS(5551),
    [anon_sym_AMP] = ACTIONS(5549),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym___extension__] = ACTIONS(5549),
    [anon_sym_typedef] = ACTIONS(5549),
    [anon_sym___device__] = ACTIONS(5549),
    [anon_sym___host__] = ACTIONS(5549),
    [anon_sym___global__] = ACTIONS(5549),
    [anon_sym___forceinline__] = ACTIONS(5549),
    [anon_sym___noinline__] = ACTIONS(5549),
    [anon_sym_virtual] = ACTIONS(5549),
    [anon_sym_extern] = ACTIONS(5549),
    [anon_sym___attribute__] = ACTIONS(5549),
    [anon_sym___attribute] = ACTIONS(5549),
    [anon_sym_COLON_COLON] = ACTIONS(5551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5551),
    [anon_sym___declspec] = ACTIONS(5549),
    [anon_sym___based] = ACTIONS(5549),
    [anon_sym_signed] = ACTIONS(5549),
    [anon_sym_unsigned] = ACTIONS(5549),
    [anon_sym_long] = ACTIONS(5549),
    [anon_sym_short] = ACTIONS(5549),
    [anon_sym_LBRACK] = ACTIONS(5549),
    [anon_sym_static] = ACTIONS(5549),
    [anon_sym_register] = ACTIONS(5549),
    [anon_sym_inline] = ACTIONS(5549),
    [anon_sym___inline] = ACTIONS(5549),
    [anon_sym___inline__] = ACTIONS(5549),
    [anon_sym___forceinline] = ACTIONS(5549),
    [anon_sym_thread_local] = ACTIONS(5549),
    [anon_sym___thread] = ACTIONS(5549),
    [anon_sym_const] = ACTIONS(5549),
    [anon_sym_constexpr] = ACTIONS(5549),
    [anon_sym_volatile] = ACTIONS(5549),
    [anon_sym_restrict] = ACTIONS(5549),
    [anon_sym___restrict__] = ACTIONS(5549),
    [anon_sym__Atomic] = ACTIONS(5549),
    [anon_sym__Noreturn] = ACTIONS(5549),
    [anon_sym_noreturn] = ACTIONS(5549),
    [anon_sym__Nonnull] = ACTIONS(5549),
    [anon_sym_mutable] = ACTIONS(5549),
    [anon_sym_constinit] = ACTIONS(5549),
    [anon_sym_consteval] = ACTIONS(5549),
    [anon_sym___shared__] = ACTIONS(5549),
    [anon_sym___local__] = ACTIONS(5549),
    [anon_sym___constant__] = ACTIONS(5549),
    [anon_sym___managed__] = ACTIONS(5549),
    [anon_sym___grid_constant__] = ACTIONS(5549),
    [anon_sym_alignas] = ACTIONS(5549),
    [anon_sym__Alignas] = ACTIONS(5549),
    [sym_primitive_type] = ACTIONS(5549),
    [anon_sym_enum] = ACTIONS(5549),
    [anon_sym_class] = ACTIONS(5549),
    [anon_sym_struct] = ACTIONS(5549),
    [anon_sym_union] = ACTIONS(5549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5549),
    [anon_sym_decltype] = ACTIONS(5549),
    [anon_sym_explicit] = ACTIONS(5549),
    [anon_sym_typename] = ACTIONS(5549),
    [anon_sym_template] = ACTIONS(5549),
    [anon_sym_operator] = ACTIONS(5549),
    [anon_sym_friend] = ACTIONS(5549),
    [anon_sym_public] = ACTIONS(5549),
    [anon_sym_private] = ACTIONS(5549),
    [anon_sym_protected] = ACTIONS(5549),
    [anon_sym_using] = ACTIONS(5549),
    [anon_sym_static_assert] = ACTIONS(5549),
    [anon_sym___launch_bounds__] = ACTIONS(5549),
  },
  [STATE(1982)] = {
    [sym_identifier] = ACTIONS(5603),
    [aux_sym_preproc_def_token1] = ACTIONS(5603),
    [aux_sym_preproc_if_token1] = ACTIONS(5603),
    [aux_sym_preproc_if_token2] = ACTIONS(5603),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5603),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5603),
    [sym_preproc_directive] = ACTIONS(5603),
    [anon_sym_LPAREN2] = ACTIONS(5605),
    [anon_sym_TILDE] = ACTIONS(5605),
    [anon_sym_STAR] = ACTIONS(5605),
    [anon_sym_AMP_AMP] = ACTIONS(5605),
    [anon_sym_AMP] = ACTIONS(5603),
    [anon_sym_SEMI] = ACTIONS(5605),
    [anon_sym___extension__] = ACTIONS(5603),
    [anon_sym_typedef] = ACTIONS(5603),
    [anon_sym___device__] = ACTIONS(5603),
    [anon_sym___host__] = ACTIONS(5603),
    [anon_sym___global__] = ACTIONS(5603),
    [anon_sym___forceinline__] = ACTIONS(5603),
    [anon_sym___noinline__] = ACTIONS(5603),
    [anon_sym_virtual] = ACTIONS(5603),
    [anon_sym_extern] = ACTIONS(5603),
    [anon_sym___attribute__] = ACTIONS(5603),
    [anon_sym___attribute] = ACTIONS(5603),
    [anon_sym_COLON_COLON] = ACTIONS(5605),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5605),
    [anon_sym___declspec] = ACTIONS(5603),
    [anon_sym___based] = ACTIONS(5603),
    [anon_sym_signed] = ACTIONS(5603),
    [anon_sym_unsigned] = ACTIONS(5603),
    [anon_sym_long] = ACTIONS(5603),
    [anon_sym_short] = ACTIONS(5603),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [anon_sym_static] = ACTIONS(5603),
    [anon_sym_register] = ACTIONS(5603),
    [anon_sym_inline] = ACTIONS(5603),
    [anon_sym___inline] = ACTIONS(5603),
    [anon_sym___inline__] = ACTIONS(5603),
    [anon_sym___forceinline] = ACTIONS(5603),
    [anon_sym_thread_local] = ACTIONS(5603),
    [anon_sym___thread] = ACTIONS(5603),
    [anon_sym_const] = ACTIONS(5603),
    [anon_sym_constexpr] = ACTIONS(5603),
    [anon_sym_volatile] = ACTIONS(5603),
    [anon_sym_restrict] = ACTIONS(5603),
    [anon_sym___restrict__] = ACTIONS(5603),
    [anon_sym__Atomic] = ACTIONS(5603),
    [anon_sym__Noreturn] = ACTIONS(5603),
    [anon_sym_noreturn] = ACTIONS(5603),
    [anon_sym__Nonnull] = ACTIONS(5603),
    [anon_sym_mutable] = ACTIONS(5603),
    [anon_sym_constinit] = ACTIONS(5603),
    [anon_sym_consteval] = ACTIONS(5603),
    [anon_sym___shared__] = ACTIONS(5603),
    [anon_sym___local__] = ACTIONS(5603),
    [anon_sym___constant__] = ACTIONS(5603),
    [anon_sym___managed__] = ACTIONS(5603),
    [anon_sym___grid_constant__] = ACTIONS(5603),
    [anon_sym_alignas] = ACTIONS(5603),
    [anon_sym__Alignas] = ACTIONS(5603),
    [sym_primitive_type] = ACTIONS(5603),
    [anon_sym_enum] = ACTIONS(5603),
    [anon_sym_class] = ACTIONS(5603),
    [anon_sym_struct] = ACTIONS(5603),
    [anon_sym_union] = ACTIONS(5603),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5603),
    [anon_sym_decltype] = ACTIONS(5603),
    [anon_sym_explicit] = ACTIONS(5603),
    [anon_sym_typename] = ACTIONS(5603),
    [anon_sym_template] = ACTIONS(5603),
    [anon_sym_operator] = ACTIONS(5603),
    [anon_sym_friend] = ACTIONS(5603),
    [anon_sym_public] = ACTIONS(5603),
    [anon_sym_private] = ACTIONS(5603),
    [anon_sym_protected] = ACTIONS(5603),
    [anon_sym_using] = ACTIONS(5603),
    [anon_sym_static_assert] = ACTIONS(5603),
    [anon_sym___launch_bounds__] = ACTIONS(5603),
  },
  [STATE(1983)] = {
    [sym_identifier] = ACTIONS(2489),
    [aux_sym_preproc_def_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token1] = ACTIONS(2489),
    [aux_sym_preproc_if_token2] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2489),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2489),
    [sym_preproc_directive] = ACTIONS(2489),
    [anon_sym_LPAREN2] = ACTIONS(2491),
    [anon_sym_TILDE] = ACTIONS(2491),
    [anon_sym_STAR] = ACTIONS(2491),
    [anon_sym_AMP_AMP] = ACTIONS(2491),
    [anon_sym_AMP] = ACTIONS(2489),
    [anon_sym_SEMI] = ACTIONS(2491),
    [anon_sym___extension__] = ACTIONS(2489),
    [anon_sym_typedef] = ACTIONS(2489),
    [anon_sym___device__] = ACTIONS(2489),
    [anon_sym___host__] = ACTIONS(2489),
    [anon_sym___global__] = ACTIONS(2489),
    [anon_sym___forceinline__] = ACTIONS(2489),
    [anon_sym___noinline__] = ACTIONS(2489),
    [anon_sym_virtual] = ACTIONS(2489),
    [anon_sym_extern] = ACTIONS(2489),
    [anon_sym___attribute__] = ACTIONS(2489),
    [anon_sym___attribute] = ACTIONS(2489),
    [anon_sym_COLON_COLON] = ACTIONS(2491),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2491),
    [anon_sym___declspec] = ACTIONS(2489),
    [anon_sym___based] = ACTIONS(2489),
    [anon_sym_signed] = ACTIONS(2489),
    [anon_sym_unsigned] = ACTIONS(2489),
    [anon_sym_long] = ACTIONS(2489),
    [anon_sym_short] = ACTIONS(2489),
    [anon_sym_LBRACK] = ACTIONS(2489),
    [anon_sym_static] = ACTIONS(2489),
    [anon_sym_register] = ACTIONS(2489),
    [anon_sym_inline] = ACTIONS(2489),
    [anon_sym___inline] = ACTIONS(2489),
    [anon_sym___inline__] = ACTIONS(2489),
    [anon_sym___forceinline] = ACTIONS(2489),
    [anon_sym_thread_local] = ACTIONS(2489),
    [anon_sym___thread] = ACTIONS(2489),
    [anon_sym_const] = ACTIONS(2489),
    [anon_sym_constexpr] = ACTIONS(2489),
    [anon_sym_volatile] = ACTIONS(2489),
    [anon_sym_restrict] = ACTIONS(2489),
    [anon_sym___restrict__] = ACTIONS(2489),
    [anon_sym__Atomic] = ACTIONS(2489),
    [anon_sym__Noreturn] = ACTIONS(2489),
    [anon_sym_noreturn] = ACTIONS(2489),
    [anon_sym__Nonnull] = ACTIONS(2489),
    [anon_sym_mutable] = ACTIONS(2489),
    [anon_sym_constinit] = ACTIONS(2489),
    [anon_sym_consteval] = ACTIONS(2489),
    [anon_sym___shared__] = ACTIONS(2489),
    [anon_sym___local__] = ACTIONS(2489),
    [anon_sym___constant__] = ACTIONS(2489),
    [anon_sym___managed__] = ACTIONS(2489),
    [anon_sym___grid_constant__] = ACTIONS(2489),
    [anon_sym_alignas] = ACTIONS(2489),
    [anon_sym__Alignas] = ACTIONS(2489),
    [sym_primitive_type] = ACTIONS(2489),
    [anon_sym_enum] = ACTIONS(2489),
    [anon_sym_class] = ACTIONS(2489),
    [anon_sym_struct] = ACTIONS(2489),
    [anon_sym_union] = ACTIONS(2489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2489),
    [anon_sym_decltype] = ACTIONS(2489),
    [anon_sym_explicit] = ACTIONS(2489),
    [anon_sym_typename] = ACTIONS(2489),
    [anon_sym_template] = ACTIONS(2489),
    [anon_sym_operator] = ACTIONS(2489),
    [anon_sym_friend] = ACTIONS(2489),
    [anon_sym_public] = ACTIONS(2489),
    [anon_sym_private] = ACTIONS(2489),
    [anon_sym_protected] = ACTIONS(2489),
    [anon_sym_using] = ACTIONS(2489),
    [anon_sym_static_assert] = ACTIONS(2489),
    [anon_sym___launch_bounds__] = ACTIONS(2489),
  },
  [STATE(1984)] = {
    [sym_identifier] = ACTIONS(5615),
    [aux_sym_preproc_def_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token1] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5615),
    [sym_preproc_directive] = ACTIONS(5615),
    [anon_sym_LPAREN2] = ACTIONS(5617),
    [anon_sym_TILDE] = ACTIONS(5617),
    [anon_sym_STAR] = ACTIONS(5617),
    [anon_sym_AMP_AMP] = ACTIONS(5617),
    [anon_sym_AMP] = ACTIONS(5615),
    [anon_sym_SEMI] = ACTIONS(5617),
    [anon_sym___extension__] = ACTIONS(5615),
    [anon_sym_typedef] = ACTIONS(5615),
    [anon_sym___device__] = ACTIONS(5615),
    [anon_sym___host__] = ACTIONS(5615),
    [anon_sym___global__] = ACTIONS(5615),
    [anon_sym___forceinline__] = ACTIONS(5615),
    [anon_sym___noinline__] = ACTIONS(5615),
    [anon_sym_virtual] = ACTIONS(5615),
    [anon_sym_extern] = ACTIONS(5615),
    [anon_sym___attribute__] = ACTIONS(5615),
    [anon_sym___attribute] = ACTIONS(5615),
    [anon_sym_COLON_COLON] = ACTIONS(5617),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5617),
    [anon_sym___declspec] = ACTIONS(5615),
    [anon_sym___based] = ACTIONS(5615),
    [anon_sym_RBRACE] = ACTIONS(5617),
    [anon_sym_signed] = ACTIONS(5615),
    [anon_sym_unsigned] = ACTIONS(5615),
    [anon_sym_long] = ACTIONS(5615),
    [anon_sym_short] = ACTIONS(5615),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [anon_sym_static] = ACTIONS(5615),
    [anon_sym_register] = ACTIONS(5615),
    [anon_sym_inline] = ACTIONS(5615),
    [anon_sym___inline] = ACTIONS(5615),
    [anon_sym___inline__] = ACTIONS(5615),
    [anon_sym___forceinline] = ACTIONS(5615),
    [anon_sym_thread_local] = ACTIONS(5615),
    [anon_sym___thread] = ACTIONS(5615),
    [anon_sym_const] = ACTIONS(5615),
    [anon_sym_constexpr] = ACTIONS(5615),
    [anon_sym_volatile] = ACTIONS(5615),
    [anon_sym_restrict] = ACTIONS(5615),
    [anon_sym___restrict__] = ACTIONS(5615),
    [anon_sym__Atomic] = ACTIONS(5615),
    [anon_sym__Noreturn] = ACTIONS(5615),
    [anon_sym_noreturn] = ACTIONS(5615),
    [anon_sym__Nonnull] = ACTIONS(5615),
    [anon_sym_mutable] = ACTIONS(5615),
    [anon_sym_constinit] = ACTIONS(5615),
    [anon_sym_consteval] = ACTIONS(5615),
    [anon_sym___shared__] = ACTIONS(5615),
    [anon_sym___local__] = ACTIONS(5615),
    [anon_sym___constant__] = ACTIONS(5615),
    [anon_sym___managed__] = ACTIONS(5615),
    [anon_sym___grid_constant__] = ACTIONS(5615),
    [anon_sym_alignas] = ACTIONS(5615),
    [anon_sym__Alignas] = ACTIONS(5615),
    [sym_primitive_type] = ACTIONS(5615),
    [anon_sym_enum] = ACTIONS(5615),
    [anon_sym_class] = ACTIONS(5615),
    [anon_sym_struct] = ACTIONS(5615),
    [anon_sym_union] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5615),
    [anon_sym_decltype] = ACTIONS(5615),
    [anon_sym_explicit] = ACTIONS(5615),
    [anon_sym_typename] = ACTIONS(5615),
    [anon_sym_template] = ACTIONS(5615),
    [anon_sym_operator] = ACTIONS(5615),
    [anon_sym_friend] = ACTIONS(5615),
    [anon_sym_public] = ACTIONS(5615),
    [anon_sym_private] = ACTIONS(5615),
    [anon_sym_protected] = ACTIONS(5615),
    [anon_sym_using] = ACTIONS(5615),
    [anon_sym_static_assert] = ACTIONS(5615),
    [anon_sym___launch_bounds__] = ACTIONS(5615),
  },
  [STATE(1985)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_RBRACE] = ACTIONS(5621),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(1986)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_RBRACE] = ACTIONS(5621),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(1987)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_RBRACE] = ACTIONS(5621),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(1988)] = {
    [sym_identifier] = ACTIONS(5615),
    [aux_sym_preproc_def_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token1] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5615),
    [sym_preproc_directive] = ACTIONS(5615),
    [anon_sym_LPAREN2] = ACTIONS(5617),
    [anon_sym_TILDE] = ACTIONS(5617),
    [anon_sym_STAR] = ACTIONS(5617),
    [anon_sym_AMP_AMP] = ACTIONS(5617),
    [anon_sym_AMP] = ACTIONS(5615),
    [anon_sym_SEMI] = ACTIONS(5617),
    [anon_sym___extension__] = ACTIONS(5615),
    [anon_sym_typedef] = ACTIONS(5615),
    [anon_sym___device__] = ACTIONS(5615),
    [anon_sym___host__] = ACTIONS(5615),
    [anon_sym___global__] = ACTIONS(5615),
    [anon_sym___forceinline__] = ACTIONS(5615),
    [anon_sym___noinline__] = ACTIONS(5615),
    [anon_sym_virtual] = ACTIONS(5615),
    [anon_sym_extern] = ACTIONS(5615),
    [anon_sym___attribute__] = ACTIONS(5615),
    [anon_sym___attribute] = ACTIONS(5615),
    [anon_sym_COLON_COLON] = ACTIONS(5617),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5617),
    [anon_sym___declspec] = ACTIONS(5615),
    [anon_sym___based] = ACTIONS(5615),
    [anon_sym_RBRACE] = ACTIONS(5617),
    [anon_sym_signed] = ACTIONS(5615),
    [anon_sym_unsigned] = ACTIONS(5615),
    [anon_sym_long] = ACTIONS(5615),
    [anon_sym_short] = ACTIONS(5615),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [anon_sym_static] = ACTIONS(5615),
    [anon_sym_register] = ACTIONS(5615),
    [anon_sym_inline] = ACTIONS(5615),
    [anon_sym___inline] = ACTIONS(5615),
    [anon_sym___inline__] = ACTIONS(5615),
    [anon_sym___forceinline] = ACTIONS(5615),
    [anon_sym_thread_local] = ACTIONS(5615),
    [anon_sym___thread] = ACTIONS(5615),
    [anon_sym_const] = ACTIONS(5615),
    [anon_sym_constexpr] = ACTIONS(5615),
    [anon_sym_volatile] = ACTIONS(5615),
    [anon_sym_restrict] = ACTIONS(5615),
    [anon_sym___restrict__] = ACTIONS(5615),
    [anon_sym__Atomic] = ACTIONS(5615),
    [anon_sym__Noreturn] = ACTIONS(5615),
    [anon_sym_noreturn] = ACTIONS(5615),
    [anon_sym__Nonnull] = ACTIONS(5615),
    [anon_sym_mutable] = ACTIONS(5615),
    [anon_sym_constinit] = ACTIONS(5615),
    [anon_sym_consteval] = ACTIONS(5615),
    [anon_sym___shared__] = ACTIONS(5615),
    [anon_sym___local__] = ACTIONS(5615),
    [anon_sym___constant__] = ACTIONS(5615),
    [anon_sym___managed__] = ACTIONS(5615),
    [anon_sym___grid_constant__] = ACTIONS(5615),
    [anon_sym_alignas] = ACTIONS(5615),
    [anon_sym__Alignas] = ACTIONS(5615),
    [sym_primitive_type] = ACTIONS(5615),
    [anon_sym_enum] = ACTIONS(5615),
    [anon_sym_class] = ACTIONS(5615),
    [anon_sym_struct] = ACTIONS(5615),
    [anon_sym_union] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5615),
    [anon_sym_decltype] = ACTIONS(5615),
    [anon_sym_explicit] = ACTIONS(5615),
    [anon_sym_typename] = ACTIONS(5615),
    [anon_sym_template] = ACTIONS(5615),
    [anon_sym_operator] = ACTIONS(5615),
    [anon_sym_friend] = ACTIONS(5615),
    [anon_sym_public] = ACTIONS(5615),
    [anon_sym_private] = ACTIONS(5615),
    [anon_sym_protected] = ACTIONS(5615),
    [anon_sym_using] = ACTIONS(5615),
    [anon_sym_static_assert] = ACTIONS(5615),
    [anon_sym___launch_bounds__] = ACTIONS(5615),
  },
  [STATE(1989)] = {
    [sym_identifier] = ACTIONS(2493),
    [aux_sym_preproc_def_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2493),
    [sym_preproc_directive] = ACTIONS(2493),
    [anon_sym_LPAREN2] = ACTIONS(2495),
    [anon_sym_TILDE] = ACTIONS(2495),
    [anon_sym_STAR] = ACTIONS(2495),
    [anon_sym_AMP_AMP] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(2493),
    [anon_sym_SEMI] = ACTIONS(2495),
    [anon_sym___extension__] = ACTIONS(2493),
    [anon_sym_typedef] = ACTIONS(2493),
    [anon_sym___device__] = ACTIONS(2493),
    [anon_sym___host__] = ACTIONS(2493),
    [anon_sym___global__] = ACTIONS(2493),
    [anon_sym___forceinline__] = ACTIONS(2493),
    [anon_sym___noinline__] = ACTIONS(2493),
    [anon_sym_virtual] = ACTIONS(2493),
    [anon_sym_extern] = ACTIONS(2493),
    [anon_sym___attribute__] = ACTIONS(2493),
    [anon_sym___attribute] = ACTIONS(2493),
    [anon_sym_COLON_COLON] = ACTIONS(2495),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2495),
    [anon_sym___declspec] = ACTIONS(2493),
    [anon_sym___based] = ACTIONS(2493),
    [anon_sym_RBRACE] = ACTIONS(2495),
    [anon_sym_signed] = ACTIONS(2493),
    [anon_sym_unsigned] = ACTIONS(2493),
    [anon_sym_long] = ACTIONS(2493),
    [anon_sym_short] = ACTIONS(2493),
    [anon_sym_LBRACK] = ACTIONS(2493),
    [anon_sym_static] = ACTIONS(2493),
    [anon_sym_register] = ACTIONS(2493),
    [anon_sym_inline] = ACTIONS(2493),
    [anon_sym___inline] = ACTIONS(2493),
    [anon_sym___inline__] = ACTIONS(2493),
    [anon_sym___forceinline] = ACTIONS(2493),
    [anon_sym_thread_local] = ACTIONS(2493),
    [anon_sym___thread] = ACTIONS(2493),
    [anon_sym_const] = ACTIONS(2493),
    [anon_sym_constexpr] = ACTIONS(2493),
    [anon_sym_volatile] = ACTIONS(2493),
    [anon_sym_restrict] = ACTIONS(2493),
    [anon_sym___restrict__] = ACTIONS(2493),
    [anon_sym__Atomic] = ACTIONS(2493),
    [anon_sym__Noreturn] = ACTIONS(2493),
    [anon_sym_noreturn] = ACTIONS(2493),
    [anon_sym__Nonnull] = ACTIONS(2493),
    [anon_sym_mutable] = ACTIONS(2493),
    [anon_sym_constinit] = ACTIONS(2493),
    [anon_sym_consteval] = ACTIONS(2493),
    [anon_sym___shared__] = ACTIONS(2493),
    [anon_sym___local__] = ACTIONS(2493),
    [anon_sym___constant__] = ACTIONS(2493),
    [anon_sym___managed__] = ACTIONS(2493),
    [anon_sym___grid_constant__] = ACTIONS(2493),
    [anon_sym_alignas] = ACTIONS(2493),
    [anon_sym__Alignas] = ACTIONS(2493),
    [sym_primitive_type] = ACTIONS(2493),
    [anon_sym_enum] = ACTIONS(2493),
    [anon_sym_class] = ACTIONS(2493),
    [anon_sym_struct] = ACTIONS(2493),
    [anon_sym_union] = ACTIONS(2493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2493),
    [anon_sym_decltype] = ACTIONS(2493),
    [anon_sym_explicit] = ACTIONS(2493),
    [anon_sym_typename] = ACTIONS(2493),
    [anon_sym_template] = ACTIONS(2493),
    [anon_sym_operator] = ACTIONS(2493),
    [anon_sym_friend] = ACTIONS(2493),
    [anon_sym_public] = ACTIONS(2493),
    [anon_sym_private] = ACTIONS(2493),
    [anon_sym_protected] = ACTIONS(2493),
    [anon_sym_using] = ACTIONS(2493),
    [anon_sym_static_assert] = ACTIONS(2493),
    [anon_sym___launch_bounds__] = ACTIONS(2493),
  },
  [STATE(1990)] = {
    [sym_identifier] = ACTIONS(5585),
    [aux_sym_preproc_def_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token1] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5585),
    [sym_preproc_directive] = ACTIONS(5585),
    [anon_sym_LPAREN2] = ACTIONS(5587),
    [anon_sym_TILDE] = ACTIONS(5587),
    [anon_sym_STAR] = ACTIONS(5587),
    [anon_sym_AMP_AMP] = ACTIONS(5587),
    [anon_sym_AMP] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym___extension__] = ACTIONS(5585),
    [anon_sym_typedef] = ACTIONS(5585),
    [anon_sym___device__] = ACTIONS(5585),
    [anon_sym___host__] = ACTIONS(5585),
    [anon_sym___global__] = ACTIONS(5585),
    [anon_sym___forceinline__] = ACTIONS(5585),
    [anon_sym___noinline__] = ACTIONS(5585),
    [anon_sym_virtual] = ACTIONS(5585),
    [anon_sym_extern] = ACTIONS(5585),
    [anon_sym___attribute__] = ACTIONS(5585),
    [anon_sym___attribute] = ACTIONS(5585),
    [anon_sym_COLON_COLON] = ACTIONS(5587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5587),
    [anon_sym___declspec] = ACTIONS(5585),
    [anon_sym___based] = ACTIONS(5585),
    [anon_sym_RBRACE] = ACTIONS(5587),
    [anon_sym_signed] = ACTIONS(5585),
    [anon_sym_unsigned] = ACTIONS(5585),
    [anon_sym_long] = ACTIONS(5585),
    [anon_sym_short] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5585),
    [anon_sym_static] = ACTIONS(5585),
    [anon_sym_register] = ACTIONS(5585),
    [anon_sym_inline] = ACTIONS(5585),
    [anon_sym___inline] = ACTIONS(5585),
    [anon_sym___inline__] = ACTIONS(5585),
    [anon_sym___forceinline] = ACTIONS(5585),
    [anon_sym_thread_local] = ACTIONS(5585),
    [anon_sym___thread] = ACTIONS(5585),
    [anon_sym_const] = ACTIONS(5585),
    [anon_sym_constexpr] = ACTIONS(5585),
    [anon_sym_volatile] = ACTIONS(5585),
    [anon_sym_restrict] = ACTIONS(5585),
    [anon_sym___restrict__] = ACTIONS(5585),
    [anon_sym__Atomic] = ACTIONS(5585),
    [anon_sym__Noreturn] = ACTIONS(5585),
    [anon_sym_noreturn] = ACTIONS(5585),
    [anon_sym__Nonnull] = ACTIONS(5585),
    [anon_sym_mutable] = ACTIONS(5585),
    [anon_sym_constinit] = ACTIONS(5585),
    [anon_sym_consteval] = ACTIONS(5585),
    [anon_sym___shared__] = ACTIONS(5585),
    [anon_sym___local__] = ACTIONS(5585),
    [anon_sym___constant__] = ACTIONS(5585),
    [anon_sym___managed__] = ACTIONS(5585),
    [anon_sym___grid_constant__] = ACTIONS(5585),
    [anon_sym_alignas] = ACTIONS(5585),
    [anon_sym__Alignas] = ACTIONS(5585),
    [sym_primitive_type] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_struct] = ACTIONS(5585),
    [anon_sym_union] = ACTIONS(5585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5585),
    [anon_sym_decltype] = ACTIONS(5585),
    [anon_sym_explicit] = ACTIONS(5585),
    [anon_sym_typename] = ACTIONS(5585),
    [anon_sym_template] = ACTIONS(5585),
    [anon_sym_operator] = ACTIONS(5585),
    [anon_sym_friend] = ACTIONS(5585),
    [anon_sym_public] = ACTIONS(5585),
    [anon_sym_private] = ACTIONS(5585),
    [anon_sym_protected] = ACTIONS(5585),
    [anon_sym_using] = ACTIONS(5585),
    [anon_sym_static_assert] = ACTIONS(5585),
    [anon_sym___launch_bounds__] = ACTIONS(5585),
  },
  [STATE(1991)] = {
    [sym_identifier] = ACTIONS(5553),
    [aux_sym_preproc_def_token1] = ACTIONS(5553),
    [aux_sym_preproc_if_token1] = ACTIONS(5553),
    [aux_sym_preproc_if_token2] = ACTIONS(5553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5553),
    [sym_preproc_directive] = ACTIONS(5553),
    [anon_sym_LPAREN2] = ACTIONS(5555),
    [anon_sym_TILDE] = ACTIONS(5555),
    [anon_sym_STAR] = ACTIONS(5555),
    [anon_sym_AMP_AMP] = ACTIONS(5555),
    [anon_sym_AMP] = ACTIONS(5553),
    [anon_sym_SEMI] = ACTIONS(5555),
    [anon_sym___extension__] = ACTIONS(5553),
    [anon_sym_typedef] = ACTIONS(5553),
    [anon_sym___device__] = ACTIONS(5553),
    [anon_sym___host__] = ACTIONS(5553),
    [anon_sym___global__] = ACTIONS(5553),
    [anon_sym___forceinline__] = ACTIONS(5553),
    [anon_sym___noinline__] = ACTIONS(5553),
    [anon_sym_virtual] = ACTIONS(5553),
    [anon_sym_extern] = ACTIONS(5553),
    [anon_sym___attribute__] = ACTIONS(5553),
    [anon_sym___attribute] = ACTIONS(5553),
    [anon_sym_COLON_COLON] = ACTIONS(5555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5555),
    [anon_sym___declspec] = ACTIONS(5553),
    [anon_sym___based] = ACTIONS(5553),
    [anon_sym_signed] = ACTIONS(5553),
    [anon_sym_unsigned] = ACTIONS(5553),
    [anon_sym_long] = ACTIONS(5553),
    [anon_sym_short] = ACTIONS(5553),
    [anon_sym_LBRACK] = ACTIONS(5553),
    [anon_sym_static] = ACTIONS(5553),
    [anon_sym_register] = ACTIONS(5553),
    [anon_sym_inline] = ACTIONS(5553),
    [anon_sym___inline] = ACTIONS(5553),
    [anon_sym___inline__] = ACTIONS(5553),
    [anon_sym___forceinline] = ACTIONS(5553),
    [anon_sym_thread_local] = ACTIONS(5553),
    [anon_sym___thread] = ACTIONS(5553),
    [anon_sym_const] = ACTIONS(5553),
    [anon_sym_constexpr] = ACTIONS(5553),
    [anon_sym_volatile] = ACTIONS(5553),
    [anon_sym_restrict] = ACTIONS(5553),
    [anon_sym___restrict__] = ACTIONS(5553),
    [anon_sym__Atomic] = ACTIONS(5553),
    [anon_sym__Noreturn] = ACTIONS(5553),
    [anon_sym_noreturn] = ACTIONS(5553),
    [anon_sym__Nonnull] = ACTIONS(5553),
    [anon_sym_mutable] = ACTIONS(5553),
    [anon_sym_constinit] = ACTIONS(5553),
    [anon_sym_consteval] = ACTIONS(5553),
    [anon_sym___shared__] = ACTIONS(5553),
    [anon_sym___local__] = ACTIONS(5553),
    [anon_sym___constant__] = ACTIONS(5553),
    [anon_sym___managed__] = ACTIONS(5553),
    [anon_sym___grid_constant__] = ACTIONS(5553),
    [anon_sym_alignas] = ACTIONS(5553),
    [anon_sym__Alignas] = ACTIONS(5553),
    [sym_primitive_type] = ACTIONS(5553),
    [anon_sym_enum] = ACTIONS(5553),
    [anon_sym_class] = ACTIONS(5553),
    [anon_sym_struct] = ACTIONS(5553),
    [anon_sym_union] = ACTIONS(5553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5553),
    [anon_sym_decltype] = ACTIONS(5553),
    [anon_sym_explicit] = ACTIONS(5553),
    [anon_sym_typename] = ACTIONS(5553),
    [anon_sym_template] = ACTIONS(5553),
    [anon_sym_operator] = ACTIONS(5553),
    [anon_sym_friend] = ACTIONS(5553),
    [anon_sym_public] = ACTIONS(5553),
    [anon_sym_private] = ACTIONS(5553),
    [anon_sym_protected] = ACTIONS(5553),
    [anon_sym_using] = ACTIONS(5553),
    [anon_sym_static_assert] = ACTIONS(5553),
    [anon_sym___launch_bounds__] = ACTIONS(5553),
  },
  [STATE(1992)] = {
    [sym_template_argument_list] = STATE(1659),
    [sym_identifier] = ACTIONS(5669),
    [anon_sym_LPAREN2] = ACTIONS(4028),
    [anon_sym_TILDE] = ACTIONS(4028),
    [anon_sym_STAR] = ACTIONS(4028),
    [anon_sym_PIPE_PIPE] = ACTIONS(4028),
    [anon_sym_AMP_AMP] = ACTIONS(4028),
    [anon_sym_AMP] = ACTIONS(5669),
    [anon_sym_LT] = ACTIONS(5671),
    [anon_sym___extension__] = ACTIONS(5669),
    [anon_sym___device__] = ACTIONS(5669),
    [anon_sym___host__] = ACTIONS(5669),
    [anon_sym___global__] = ACTIONS(5669),
    [anon_sym___forceinline__] = ACTIONS(5669),
    [anon_sym___noinline__] = ACTIONS(5669),
    [anon_sym_virtual] = ACTIONS(5669),
    [anon_sym_extern] = ACTIONS(5669),
    [anon_sym___attribute__] = ACTIONS(5669),
    [anon_sym___attribute] = ACTIONS(5669),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4028),
    [anon_sym___declspec] = ACTIONS(5669),
    [anon_sym___based] = ACTIONS(5669),
    [anon_sym___cdecl] = ACTIONS(5669),
    [anon_sym___clrcall] = ACTIONS(5669),
    [anon_sym___stdcall] = ACTIONS(5669),
    [anon_sym___fastcall] = ACTIONS(5669),
    [anon_sym___thiscall] = ACTIONS(5669),
    [anon_sym___vectorcall] = ACTIONS(5669),
    [anon_sym_signed] = ACTIONS(5669),
    [anon_sym_unsigned] = ACTIONS(5669),
    [anon_sym_long] = ACTIONS(5669),
    [anon_sym_short] = ACTIONS(5669),
    [anon_sym_LBRACK] = ACTIONS(5669),
    [anon_sym_static] = ACTIONS(5669),
    [anon_sym_register] = ACTIONS(5669),
    [anon_sym_inline] = ACTIONS(5669),
    [anon_sym___inline] = ACTIONS(5669),
    [anon_sym___inline__] = ACTIONS(5669),
    [anon_sym___forceinline] = ACTIONS(5669),
    [anon_sym_thread_local] = ACTIONS(5669),
    [anon_sym___thread] = ACTIONS(5669),
    [anon_sym_const] = ACTIONS(5669),
    [anon_sym_constexpr] = ACTIONS(5669),
    [anon_sym_volatile] = ACTIONS(5669),
    [anon_sym_restrict] = ACTIONS(5669),
    [anon_sym___restrict__] = ACTIONS(5669),
    [anon_sym__Atomic] = ACTIONS(5669),
    [anon_sym__Noreturn] = ACTIONS(5669),
    [anon_sym_noreturn] = ACTIONS(5669),
    [anon_sym__Nonnull] = ACTIONS(5669),
    [anon_sym_mutable] = ACTIONS(5669),
    [anon_sym_constinit] = ACTIONS(5669),
    [anon_sym_consteval] = ACTIONS(5669),
    [anon_sym___shared__] = ACTIONS(5669),
    [anon_sym___local__] = ACTIONS(5669),
    [anon_sym___constant__] = ACTIONS(5669),
    [anon_sym___managed__] = ACTIONS(5669),
    [anon_sym___grid_constant__] = ACTIONS(5669),
    [anon_sym_alignas] = ACTIONS(5669),
    [anon_sym__Alignas] = ACTIONS(5669),
    [sym_primitive_type] = ACTIONS(5669),
    [anon_sym_enum] = ACTIONS(5669),
    [anon_sym_class] = ACTIONS(5669),
    [anon_sym_struct] = ACTIONS(5669),
    [anon_sym_union] = ACTIONS(5669),
    [anon_sym_or] = ACTIONS(5669),
    [anon_sym_and] = ACTIONS(5669),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5669),
    [anon_sym_decltype] = ACTIONS(5669),
    [anon_sym_explicit] = ACTIONS(5669),
    [anon_sym_typename] = ACTIONS(5669),
    [anon_sym_template] = ACTIONS(5669),
    [anon_sym_operator] = ACTIONS(5669),
    [anon_sym_friend] = ACTIONS(5669),
    [anon_sym_using] = ACTIONS(5669),
    [anon_sym_concept] = ACTIONS(5669),
    [anon_sym___launch_bounds__] = ACTIONS(5669),
  },
  [STATE(1993)] = {
    [sym_identifier] = ACTIONS(2513),
    [aux_sym_preproc_def_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token2] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2513),
    [sym_preproc_directive] = ACTIONS(2513),
    [anon_sym_LPAREN2] = ACTIONS(2515),
    [anon_sym_TILDE] = ACTIONS(2515),
    [anon_sym_STAR] = ACTIONS(2515),
    [anon_sym_AMP_AMP] = ACTIONS(2515),
    [anon_sym_AMP] = ACTIONS(2513),
    [anon_sym_SEMI] = ACTIONS(2515),
    [anon_sym___extension__] = ACTIONS(2513),
    [anon_sym_typedef] = ACTIONS(2513),
    [anon_sym___device__] = ACTIONS(2513),
    [anon_sym___host__] = ACTIONS(2513),
    [anon_sym___global__] = ACTIONS(2513),
    [anon_sym___forceinline__] = ACTIONS(2513),
    [anon_sym___noinline__] = ACTIONS(2513),
    [anon_sym_virtual] = ACTIONS(2513),
    [anon_sym_extern] = ACTIONS(2513),
    [anon_sym___attribute__] = ACTIONS(2513),
    [anon_sym___attribute] = ACTIONS(2513),
    [anon_sym_COLON_COLON] = ACTIONS(2515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2515),
    [anon_sym___declspec] = ACTIONS(2513),
    [anon_sym___based] = ACTIONS(2513),
    [anon_sym_signed] = ACTIONS(2513),
    [anon_sym_unsigned] = ACTIONS(2513),
    [anon_sym_long] = ACTIONS(2513),
    [anon_sym_short] = ACTIONS(2513),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_static] = ACTIONS(2513),
    [anon_sym_register] = ACTIONS(2513),
    [anon_sym_inline] = ACTIONS(2513),
    [anon_sym___inline] = ACTIONS(2513),
    [anon_sym___inline__] = ACTIONS(2513),
    [anon_sym___forceinline] = ACTIONS(2513),
    [anon_sym_thread_local] = ACTIONS(2513),
    [anon_sym___thread] = ACTIONS(2513),
    [anon_sym_const] = ACTIONS(2513),
    [anon_sym_constexpr] = ACTIONS(2513),
    [anon_sym_volatile] = ACTIONS(2513),
    [anon_sym_restrict] = ACTIONS(2513),
    [anon_sym___restrict__] = ACTIONS(2513),
    [anon_sym__Atomic] = ACTIONS(2513),
    [anon_sym__Noreturn] = ACTIONS(2513),
    [anon_sym_noreturn] = ACTIONS(2513),
    [anon_sym__Nonnull] = ACTIONS(2513),
    [anon_sym_mutable] = ACTIONS(2513),
    [anon_sym_constinit] = ACTIONS(2513),
    [anon_sym_consteval] = ACTIONS(2513),
    [anon_sym___shared__] = ACTIONS(2513),
    [anon_sym___local__] = ACTIONS(2513),
    [anon_sym___constant__] = ACTIONS(2513),
    [anon_sym___managed__] = ACTIONS(2513),
    [anon_sym___grid_constant__] = ACTIONS(2513),
    [anon_sym_alignas] = ACTIONS(2513),
    [anon_sym__Alignas] = ACTIONS(2513),
    [sym_primitive_type] = ACTIONS(2513),
    [anon_sym_enum] = ACTIONS(2513),
    [anon_sym_class] = ACTIONS(2513),
    [anon_sym_struct] = ACTIONS(2513),
    [anon_sym_union] = ACTIONS(2513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2513),
    [anon_sym_decltype] = ACTIONS(2513),
    [anon_sym_explicit] = ACTIONS(2513),
    [anon_sym_typename] = ACTIONS(2513),
    [anon_sym_template] = ACTIONS(2513),
    [anon_sym_operator] = ACTIONS(2513),
    [anon_sym_friend] = ACTIONS(2513),
    [anon_sym_public] = ACTIONS(2513),
    [anon_sym_private] = ACTIONS(2513),
    [anon_sym_protected] = ACTIONS(2513),
    [anon_sym_using] = ACTIONS(2513),
    [anon_sym_static_assert] = ACTIONS(2513),
    [anon_sym___launch_bounds__] = ACTIONS(2513),
  },
  [STATE(1994)] = {
    [sym_identifier] = ACTIONS(2517),
    [aux_sym_preproc_def_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token2] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2517),
    [sym_preproc_directive] = ACTIONS(2517),
    [anon_sym_LPAREN2] = ACTIONS(2519),
    [anon_sym_TILDE] = ACTIONS(2519),
    [anon_sym_STAR] = ACTIONS(2519),
    [anon_sym_AMP_AMP] = ACTIONS(2519),
    [anon_sym_AMP] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym___extension__] = ACTIONS(2517),
    [anon_sym_typedef] = ACTIONS(2517),
    [anon_sym___device__] = ACTIONS(2517),
    [anon_sym___host__] = ACTIONS(2517),
    [anon_sym___global__] = ACTIONS(2517),
    [anon_sym___forceinline__] = ACTIONS(2517),
    [anon_sym___noinline__] = ACTIONS(2517),
    [anon_sym_virtual] = ACTIONS(2517),
    [anon_sym_extern] = ACTIONS(2517),
    [anon_sym___attribute__] = ACTIONS(2517),
    [anon_sym___attribute] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2519),
    [anon_sym___declspec] = ACTIONS(2517),
    [anon_sym___based] = ACTIONS(2517),
    [anon_sym_signed] = ACTIONS(2517),
    [anon_sym_unsigned] = ACTIONS(2517),
    [anon_sym_long] = ACTIONS(2517),
    [anon_sym_short] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2517),
    [anon_sym_static] = ACTIONS(2517),
    [anon_sym_register] = ACTIONS(2517),
    [anon_sym_inline] = ACTIONS(2517),
    [anon_sym___inline] = ACTIONS(2517),
    [anon_sym___inline__] = ACTIONS(2517),
    [anon_sym___forceinline] = ACTIONS(2517),
    [anon_sym_thread_local] = ACTIONS(2517),
    [anon_sym___thread] = ACTIONS(2517),
    [anon_sym_const] = ACTIONS(2517),
    [anon_sym_constexpr] = ACTIONS(2517),
    [anon_sym_volatile] = ACTIONS(2517),
    [anon_sym_restrict] = ACTIONS(2517),
    [anon_sym___restrict__] = ACTIONS(2517),
    [anon_sym__Atomic] = ACTIONS(2517),
    [anon_sym__Noreturn] = ACTIONS(2517),
    [anon_sym_noreturn] = ACTIONS(2517),
    [anon_sym__Nonnull] = ACTIONS(2517),
    [anon_sym_mutable] = ACTIONS(2517),
    [anon_sym_constinit] = ACTIONS(2517),
    [anon_sym_consteval] = ACTIONS(2517),
    [anon_sym___shared__] = ACTIONS(2517),
    [anon_sym___local__] = ACTIONS(2517),
    [anon_sym___constant__] = ACTIONS(2517),
    [anon_sym___managed__] = ACTIONS(2517),
    [anon_sym___grid_constant__] = ACTIONS(2517),
    [anon_sym_alignas] = ACTIONS(2517),
    [anon_sym__Alignas] = ACTIONS(2517),
    [sym_primitive_type] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_class] = ACTIONS(2517),
    [anon_sym_struct] = ACTIONS(2517),
    [anon_sym_union] = ACTIONS(2517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2517),
    [anon_sym_decltype] = ACTIONS(2517),
    [anon_sym_explicit] = ACTIONS(2517),
    [anon_sym_typename] = ACTIONS(2517),
    [anon_sym_template] = ACTIONS(2517),
    [anon_sym_operator] = ACTIONS(2517),
    [anon_sym_friend] = ACTIONS(2517),
    [anon_sym_public] = ACTIONS(2517),
    [anon_sym_private] = ACTIONS(2517),
    [anon_sym_protected] = ACTIONS(2517),
    [anon_sym_using] = ACTIONS(2517),
    [anon_sym_static_assert] = ACTIONS(2517),
    [anon_sym___launch_bounds__] = ACTIONS(2517),
  },
  [STATE(1995)] = {
    [sym_identifier] = ACTIONS(2521),
    [aux_sym_preproc_def_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token1] = ACTIONS(2521),
    [aux_sym_preproc_if_token2] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2521),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2521),
    [sym_preproc_directive] = ACTIONS(2521),
    [anon_sym_LPAREN2] = ACTIONS(2523),
    [anon_sym_TILDE] = ACTIONS(2523),
    [anon_sym_STAR] = ACTIONS(2523),
    [anon_sym_AMP_AMP] = ACTIONS(2523),
    [anon_sym_AMP] = ACTIONS(2521),
    [anon_sym_SEMI] = ACTIONS(2523),
    [anon_sym___extension__] = ACTIONS(2521),
    [anon_sym_typedef] = ACTIONS(2521),
    [anon_sym___device__] = ACTIONS(2521),
    [anon_sym___host__] = ACTIONS(2521),
    [anon_sym___global__] = ACTIONS(2521),
    [anon_sym___forceinline__] = ACTIONS(2521),
    [anon_sym___noinline__] = ACTIONS(2521),
    [anon_sym_virtual] = ACTIONS(2521),
    [anon_sym_extern] = ACTIONS(2521),
    [anon_sym___attribute__] = ACTIONS(2521),
    [anon_sym___attribute] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(2523),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2523),
    [anon_sym___declspec] = ACTIONS(2521),
    [anon_sym___based] = ACTIONS(2521),
    [anon_sym_signed] = ACTIONS(2521),
    [anon_sym_unsigned] = ACTIONS(2521),
    [anon_sym_long] = ACTIONS(2521),
    [anon_sym_short] = ACTIONS(2521),
    [anon_sym_LBRACK] = ACTIONS(2521),
    [anon_sym_static] = ACTIONS(2521),
    [anon_sym_register] = ACTIONS(2521),
    [anon_sym_inline] = ACTIONS(2521),
    [anon_sym___inline] = ACTIONS(2521),
    [anon_sym___inline__] = ACTIONS(2521),
    [anon_sym___forceinline] = ACTIONS(2521),
    [anon_sym_thread_local] = ACTIONS(2521),
    [anon_sym___thread] = ACTIONS(2521),
    [anon_sym_const] = ACTIONS(2521),
    [anon_sym_constexpr] = ACTIONS(2521),
    [anon_sym_volatile] = ACTIONS(2521),
    [anon_sym_restrict] = ACTIONS(2521),
    [anon_sym___restrict__] = ACTIONS(2521),
    [anon_sym__Atomic] = ACTIONS(2521),
    [anon_sym__Noreturn] = ACTIONS(2521),
    [anon_sym_noreturn] = ACTIONS(2521),
    [anon_sym__Nonnull] = ACTIONS(2521),
    [anon_sym_mutable] = ACTIONS(2521),
    [anon_sym_constinit] = ACTIONS(2521),
    [anon_sym_consteval] = ACTIONS(2521),
    [anon_sym___shared__] = ACTIONS(2521),
    [anon_sym___local__] = ACTIONS(2521),
    [anon_sym___constant__] = ACTIONS(2521),
    [anon_sym___managed__] = ACTIONS(2521),
    [anon_sym___grid_constant__] = ACTIONS(2521),
    [anon_sym_alignas] = ACTIONS(2521),
    [anon_sym__Alignas] = ACTIONS(2521),
    [sym_primitive_type] = ACTIONS(2521),
    [anon_sym_enum] = ACTIONS(2521),
    [anon_sym_class] = ACTIONS(2521),
    [anon_sym_struct] = ACTIONS(2521),
    [anon_sym_union] = ACTIONS(2521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2521),
    [anon_sym_decltype] = ACTIONS(2521),
    [anon_sym_explicit] = ACTIONS(2521),
    [anon_sym_typename] = ACTIONS(2521),
    [anon_sym_template] = ACTIONS(2521),
    [anon_sym_operator] = ACTIONS(2521),
    [anon_sym_friend] = ACTIONS(2521),
    [anon_sym_public] = ACTIONS(2521),
    [anon_sym_private] = ACTIONS(2521),
    [anon_sym_protected] = ACTIONS(2521),
    [anon_sym_using] = ACTIONS(2521),
    [anon_sym_static_assert] = ACTIONS(2521),
    [anon_sym___launch_bounds__] = ACTIONS(2521),
  },
  [STATE(1996)] = {
    [sym_identifier] = ACTIONS(5585),
    [aux_sym_preproc_def_token1] = ACTIONS(5585),
    [aux_sym_preproc_if_token1] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5585),
    [sym_preproc_directive] = ACTIONS(5585),
    [anon_sym_LPAREN2] = ACTIONS(5587),
    [anon_sym_TILDE] = ACTIONS(5587),
    [anon_sym_STAR] = ACTIONS(5587),
    [anon_sym_AMP_AMP] = ACTIONS(5587),
    [anon_sym_AMP] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym___extension__] = ACTIONS(5585),
    [anon_sym_typedef] = ACTIONS(5585),
    [anon_sym___device__] = ACTIONS(5585),
    [anon_sym___host__] = ACTIONS(5585),
    [anon_sym___global__] = ACTIONS(5585),
    [anon_sym___forceinline__] = ACTIONS(5585),
    [anon_sym___noinline__] = ACTIONS(5585),
    [anon_sym_virtual] = ACTIONS(5585),
    [anon_sym_extern] = ACTIONS(5585),
    [anon_sym___attribute__] = ACTIONS(5585),
    [anon_sym___attribute] = ACTIONS(5585),
    [anon_sym_COLON_COLON] = ACTIONS(5587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5587),
    [anon_sym___declspec] = ACTIONS(5585),
    [anon_sym___based] = ACTIONS(5585),
    [anon_sym_RBRACE] = ACTIONS(5587),
    [anon_sym_signed] = ACTIONS(5585),
    [anon_sym_unsigned] = ACTIONS(5585),
    [anon_sym_long] = ACTIONS(5585),
    [anon_sym_short] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5585),
    [anon_sym_static] = ACTIONS(5585),
    [anon_sym_register] = ACTIONS(5585),
    [anon_sym_inline] = ACTIONS(5585),
    [anon_sym___inline] = ACTIONS(5585),
    [anon_sym___inline__] = ACTIONS(5585),
    [anon_sym___forceinline] = ACTIONS(5585),
    [anon_sym_thread_local] = ACTIONS(5585),
    [anon_sym___thread] = ACTIONS(5585),
    [anon_sym_const] = ACTIONS(5585),
    [anon_sym_constexpr] = ACTIONS(5585),
    [anon_sym_volatile] = ACTIONS(5585),
    [anon_sym_restrict] = ACTIONS(5585),
    [anon_sym___restrict__] = ACTIONS(5585),
    [anon_sym__Atomic] = ACTIONS(5585),
    [anon_sym__Noreturn] = ACTIONS(5585),
    [anon_sym_noreturn] = ACTIONS(5585),
    [anon_sym__Nonnull] = ACTIONS(5585),
    [anon_sym_mutable] = ACTIONS(5585),
    [anon_sym_constinit] = ACTIONS(5585),
    [anon_sym_consteval] = ACTIONS(5585),
    [anon_sym___shared__] = ACTIONS(5585),
    [anon_sym___local__] = ACTIONS(5585),
    [anon_sym___constant__] = ACTIONS(5585),
    [anon_sym___managed__] = ACTIONS(5585),
    [anon_sym___grid_constant__] = ACTIONS(5585),
    [anon_sym_alignas] = ACTIONS(5585),
    [anon_sym__Alignas] = ACTIONS(5585),
    [sym_primitive_type] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_class] = ACTIONS(5585),
    [anon_sym_struct] = ACTIONS(5585),
    [anon_sym_union] = ACTIONS(5585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5585),
    [anon_sym_decltype] = ACTIONS(5585),
    [anon_sym_explicit] = ACTIONS(5585),
    [anon_sym_typename] = ACTIONS(5585),
    [anon_sym_template] = ACTIONS(5585),
    [anon_sym_operator] = ACTIONS(5585),
    [anon_sym_friend] = ACTIONS(5585),
    [anon_sym_public] = ACTIONS(5585),
    [anon_sym_private] = ACTIONS(5585),
    [anon_sym_protected] = ACTIONS(5585),
    [anon_sym_using] = ACTIONS(5585),
    [anon_sym_static_assert] = ACTIONS(5585),
    [anon_sym___launch_bounds__] = ACTIONS(5585),
  },
  [STATE(1997)] = {
    [sym_identifier] = ACTIONS(2525),
    [aux_sym_preproc_def_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token2] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2525),
    [sym_preproc_directive] = ACTIONS(2525),
    [anon_sym_LPAREN2] = ACTIONS(2527),
    [anon_sym_TILDE] = ACTIONS(2527),
    [anon_sym_STAR] = ACTIONS(2527),
    [anon_sym_AMP_AMP] = ACTIONS(2527),
    [anon_sym_AMP] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym___extension__] = ACTIONS(2525),
    [anon_sym_typedef] = ACTIONS(2525),
    [anon_sym___device__] = ACTIONS(2525),
    [anon_sym___host__] = ACTIONS(2525),
    [anon_sym___global__] = ACTIONS(2525),
    [anon_sym___forceinline__] = ACTIONS(2525),
    [anon_sym___noinline__] = ACTIONS(2525),
    [anon_sym_virtual] = ACTIONS(2525),
    [anon_sym_extern] = ACTIONS(2525),
    [anon_sym___attribute__] = ACTIONS(2525),
    [anon_sym___attribute] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2527),
    [anon_sym___declspec] = ACTIONS(2525),
    [anon_sym___based] = ACTIONS(2525),
    [anon_sym_signed] = ACTIONS(2525),
    [anon_sym_unsigned] = ACTIONS(2525),
    [anon_sym_long] = ACTIONS(2525),
    [anon_sym_short] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2525),
    [anon_sym_static] = ACTIONS(2525),
    [anon_sym_register] = ACTIONS(2525),
    [anon_sym_inline] = ACTIONS(2525),
    [anon_sym___inline] = ACTIONS(2525),
    [anon_sym___inline__] = ACTIONS(2525),
    [anon_sym___forceinline] = ACTIONS(2525),
    [anon_sym_thread_local] = ACTIONS(2525),
    [anon_sym___thread] = ACTIONS(2525),
    [anon_sym_const] = ACTIONS(2525),
    [anon_sym_constexpr] = ACTIONS(2525),
    [anon_sym_volatile] = ACTIONS(2525),
    [anon_sym_restrict] = ACTIONS(2525),
    [anon_sym___restrict__] = ACTIONS(2525),
    [anon_sym__Atomic] = ACTIONS(2525),
    [anon_sym__Noreturn] = ACTIONS(2525),
    [anon_sym_noreturn] = ACTIONS(2525),
    [anon_sym__Nonnull] = ACTIONS(2525),
    [anon_sym_mutable] = ACTIONS(2525),
    [anon_sym_constinit] = ACTIONS(2525),
    [anon_sym_consteval] = ACTIONS(2525),
    [anon_sym___shared__] = ACTIONS(2525),
    [anon_sym___local__] = ACTIONS(2525),
    [anon_sym___constant__] = ACTIONS(2525),
    [anon_sym___managed__] = ACTIONS(2525),
    [anon_sym___grid_constant__] = ACTIONS(2525),
    [anon_sym_alignas] = ACTIONS(2525),
    [anon_sym__Alignas] = ACTIONS(2525),
    [sym_primitive_type] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_class] = ACTIONS(2525),
    [anon_sym_struct] = ACTIONS(2525),
    [anon_sym_union] = ACTIONS(2525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2525),
    [anon_sym_decltype] = ACTIONS(2525),
    [anon_sym_explicit] = ACTIONS(2525),
    [anon_sym_typename] = ACTIONS(2525),
    [anon_sym_template] = ACTIONS(2525),
    [anon_sym_operator] = ACTIONS(2525),
    [anon_sym_friend] = ACTIONS(2525),
    [anon_sym_public] = ACTIONS(2525),
    [anon_sym_private] = ACTIONS(2525),
    [anon_sym_protected] = ACTIONS(2525),
    [anon_sym_using] = ACTIONS(2525),
    [anon_sym_static_assert] = ACTIONS(2525),
    [anon_sym___launch_bounds__] = ACTIONS(2525),
  },
  [STATE(1998)] = {
    [sym_identifier] = ACTIONS(2529),
    [aux_sym_preproc_def_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token2] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2529),
    [sym_preproc_directive] = ACTIONS(2529),
    [anon_sym_LPAREN2] = ACTIONS(2531),
    [anon_sym_TILDE] = ACTIONS(2531),
    [anon_sym_STAR] = ACTIONS(2531),
    [anon_sym_AMP_AMP] = ACTIONS(2531),
    [anon_sym_AMP] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym___extension__] = ACTIONS(2529),
    [anon_sym_typedef] = ACTIONS(2529),
    [anon_sym___device__] = ACTIONS(2529),
    [anon_sym___host__] = ACTIONS(2529),
    [anon_sym___global__] = ACTIONS(2529),
    [anon_sym___forceinline__] = ACTIONS(2529),
    [anon_sym___noinline__] = ACTIONS(2529),
    [anon_sym_virtual] = ACTIONS(2529),
    [anon_sym_extern] = ACTIONS(2529),
    [anon_sym___attribute__] = ACTIONS(2529),
    [anon_sym___attribute] = ACTIONS(2529),
    [anon_sym_COLON_COLON] = ACTIONS(2531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2531),
    [anon_sym___declspec] = ACTIONS(2529),
    [anon_sym___based] = ACTIONS(2529),
    [anon_sym_signed] = ACTIONS(2529),
    [anon_sym_unsigned] = ACTIONS(2529),
    [anon_sym_long] = ACTIONS(2529),
    [anon_sym_short] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2529),
    [anon_sym_register] = ACTIONS(2529),
    [anon_sym_inline] = ACTIONS(2529),
    [anon_sym___inline] = ACTIONS(2529),
    [anon_sym___inline__] = ACTIONS(2529),
    [anon_sym___forceinline] = ACTIONS(2529),
    [anon_sym_thread_local] = ACTIONS(2529),
    [anon_sym___thread] = ACTIONS(2529),
    [anon_sym_const] = ACTIONS(2529),
    [anon_sym_constexpr] = ACTIONS(2529),
    [anon_sym_volatile] = ACTIONS(2529),
    [anon_sym_restrict] = ACTIONS(2529),
    [anon_sym___restrict__] = ACTIONS(2529),
    [anon_sym__Atomic] = ACTIONS(2529),
    [anon_sym__Noreturn] = ACTIONS(2529),
    [anon_sym_noreturn] = ACTIONS(2529),
    [anon_sym__Nonnull] = ACTIONS(2529),
    [anon_sym_mutable] = ACTIONS(2529),
    [anon_sym_constinit] = ACTIONS(2529),
    [anon_sym_consteval] = ACTIONS(2529),
    [anon_sym___shared__] = ACTIONS(2529),
    [anon_sym___local__] = ACTIONS(2529),
    [anon_sym___constant__] = ACTIONS(2529),
    [anon_sym___managed__] = ACTIONS(2529),
    [anon_sym___grid_constant__] = ACTIONS(2529),
    [anon_sym_alignas] = ACTIONS(2529),
    [anon_sym__Alignas] = ACTIONS(2529),
    [sym_primitive_type] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2529),
    [anon_sym_struct] = ACTIONS(2529),
    [anon_sym_union] = ACTIONS(2529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2529),
    [anon_sym_decltype] = ACTIONS(2529),
    [anon_sym_explicit] = ACTIONS(2529),
    [anon_sym_typename] = ACTIONS(2529),
    [anon_sym_template] = ACTIONS(2529),
    [anon_sym_operator] = ACTIONS(2529),
    [anon_sym_friend] = ACTIONS(2529),
    [anon_sym_public] = ACTIONS(2529),
    [anon_sym_private] = ACTIONS(2529),
    [anon_sym_protected] = ACTIONS(2529),
    [anon_sym_using] = ACTIONS(2529),
    [anon_sym_static_assert] = ACTIONS(2529),
    [anon_sym___launch_bounds__] = ACTIONS(2529),
  },
  [STATE(1999)] = {
    [sym_identifier] = ACTIONS(4330),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_RPAREN] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4332),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4332),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4332),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4332),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4332),
    [anon_sym_SEMI] = ACTIONS(4332),
    [anon_sym___extension__] = ACTIONS(4330),
    [anon_sym___global__] = ACTIONS(4330),
    [anon_sym___attribute__] = ACTIONS(4330),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym___based] = ACTIONS(4330),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_RBRACE] = ACTIONS(4332),
    [anon_sym_signed] = ACTIONS(4330),
    [anon_sym_unsigned] = ACTIONS(4330),
    [anon_sym_long] = ACTIONS(4330),
    [anon_sym_short] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4332),
    [anon_sym_RBRACK] = ACTIONS(4332),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4330),
    [anon_sym_volatile] = ACTIONS(4330),
    [anon_sym_restrict] = ACTIONS(4330),
    [anon_sym___restrict__] = ACTIONS(4330),
    [anon_sym__Atomic] = ACTIONS(4330),
    [anon_sym__Noreturn] = ACTIONS(4330),
    [anon_sym_noreturn] = ACTIONS(4330),
    [anon_sym__Nonnull] = ACTIONS(4330),
    [anon_sym_mutable] = ACTIONS(4330),
    [anon_sym_constinit] = ACTIONS(4330),
    [anon_sym_consteval] = ACTIONS(4330),
    [anon_sym___shared__] = ACTIONS(4330),
    [anon_sym___local__] = ACTIONS(4330),
    [anon_sym___constant__] = ACTIONS(4330),
    [anon_sym___managed__] = ACTIONS(4330),
    [anon_sym___grid_constant__] = ACTIONS(4330),
    [anon_sym_alignas] = ACTIONS(4330),
    [anon_sym__Alignas] = ACTIONS(4330),
    [sym_primitive_type] = ACTIONS(4330),
    [anon_sym_COLON] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_bitor] = ACTIONS(4330),
    [anon_sym_xor] = ACTIONS(4330),
    [anon_sym_bitand] = ACTIONS(4330),
    [anon_sym_not_eq] = ACTIONS(4330),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4330),
    [anon_sym_decltype] = ACTIONS(4330),
    [anon_sym_final] = ACTIONS(4330),
    [anon_sym_override] = ACTIONS(4330),
    [anon_sym_requires] = ACTIONS(4330),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
  },
  [STATE(2000)] = {
    [sym_identifier] = ACTIONS(5529),
    [aux_sym_preproc_def_token1] = ACTIONS(5529),
    [aux_sym_preproc_if_token1] = ACTIONS(5529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5529),
    [sym_preproc_directive] = ACTIONS(5529),
    [anon_sym_LPAREN2] = ACTIONS(5531),
    [anon_sym_TILDE] = ACTIONS(5531),
    [anon_sym_STAR] = ACTIONS(5531),
    [anon_sym_AMP_AMP] = ACTIONS(5531),
    [anon_sym_AMP] = ACTIONS(5529),
    [anon_sym_SEMI] = ACTIONS(5531),
    [anon_sym___extension__] = ACTIONS(5529),
    [anon_sym_typedef] = ACTIONS(5529),
    [anon_sym___device__] = ACTIONS(5529),
    [anon_sym___host__] = ACTIONS(5529),
    [anon_sym___global__] = ACTIONS(5529),
    [anon_sym___forceinline__] = ACTIONS(5529),
    [anon_sym___noinline__] = ACTIONS(5529),
    [anon_sym_virtual] = ACTIONS(5529),
    [anon_sym_extern] = ACTIONS(5529),
    [anon_sym___attribute__] = ACTIONS(5529),
    [anon_sym___attribute] = ACTIONS(5529),
    [anon_sym_COLON_COLON] = ACTIONS(5531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5531),
    [anon_sym___declspec] = ACTIONS(5529),
    [anon_sym___based] = ACTIONS(5529),
    [anon_sym_RBRACE] = ACTIONS(5531),
    [anon_sym_signed] = ACTIONS(5529),
    [anon_sym_unsigned] = ACTIONS(5529),
    [anon_sym_long] = ACTIONS(5529),
    [anon_sym_short] = ACTIONS(5529),
    [anon_sym_LBRACK] = ACTIONS(5529),
    [anon_sym_static] = ACTIONS(5529),
    [anon_sym_register] = ACTIONS(5529),
    [anon_sym_inline] = ACTIONS(5529),
    [anon_sym___inline] = ACTIONS(5529),
    [anon_sym___inline__] = ACTIONS(5529),
    [anon_sym___forceinline] = ACTIONS(5529),
    [anon_sym_thread_local] = ACTIONS(5529),
    [anon_sym___thread] = ACTIONS(5529),
    [anon_sym_const] = ACTIONS(5529),
    [anon_sym_constexpr] = ACTIONS(5529),
    [anon_sym_volatile] = ACTIONS(5529),
    [anon_sym_restrict] = ACTIONS(5529),
    [anon_sym___restrict__] = ACTIONS(5529),
    [anon_sym__Atomic] = ACTIONS(5529),
    [anon_sym__Noreturn] = ACTIONS(5529),
    [anon_sym_noreturn] = ACTIONS(5529),
    [anon_sym__Nonnull] = ACTIONS(5529),
    [anon_sym_mutable] = ACTIONS(5529),
    [anon_sym_constinit] = ACTIONS(5529),
    [anon_sym_consteval] = ACTIONS(5529),
    [anon_sym___shared__] = ACTIONS(5529),
    [anon_sym___local__] = ACTIONS(5529),
    [anon_sym___constant__] = ACTIONS(5529),
    [anon_sym___managed__] = ACTIONS(5529),
    [anon_sym___grid_constant__] = ACTIONS(5529),
    [anon_sym_alignas] = ACTIONS(5529),
    [anon_sym__Alignas] = ACTIONS(5529),
    [sym_primitive_type] = ACTIONS(5529),
    [anon_sym_enum] = ACTIONS(5529),
    [anon_sym_class] = ACTIONS(5529),
    [anon_sym_struct] = ACTIONS(5529),
    [anon_sym_union] = ACTIONS(5529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5529),
    [anon_sym_decltype] = ACTIONS(5529),
    [anon_sym_explicit] = ACTIONS(5529),
    [anon_sym_typename] = ACTIONS(5529),
    [anon_sym_template] = ACTIONS(5529),
    [anon_sym_operator] = ACTIONS(5529),
    [anon_sym_friend] = ACTIONS(5529),
    [anon_sym_public] = ACTIONS(5529),
    [anon_sym_private] = ACTIONS(5529),
    [anon_sym_protected] = ACTIONS(5529),
    [anon_sym_using] = ACTIONS(5529),
    [anon_sym_static_assert] = ACTIONS(5529),
    [anon_sym___launch_bounds__] = ACTIONS(5529),
  },
  [STATE(2001)] = {
    [sym_identifier] = ACTIONS(2541),
    [aux_sym_preproc_def_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token2] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2541),
    [sym_preproc_directive] = ACTIONS(2541),
    [anon_sym_LPAREN2] = ACTIONS(2543),
    [anon_sym_TILDE] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_AMP_AMP] = ACTIONS(2543),
    [anon_sym_AMP] = ACTIONS(2541),
    [anon_sym_SEMI] = ACTIONS(2543),
    [anon_sym___extension__] = ACTIONS(2541),
    [anon_sym_typedef] = ACTIONS(2541),
    [anon_sym___device__] = ACTIONS(2541),
    [anon_sym___host__] = ACTIONS(2541),
    [anon_sym___global__] = ACTIONS(2541),
    [anon_sym___forceinline__] = ACTIONS(2541),
    [anon_sym___noinline__] = ACTIONS(2541),
    [anon_sym_virtual] = ACTIONS(2541),
    [anon_sym_extern] = ACTIONS(2541),
    [anon_sym___attribute__] = ACTIONS(2541),
    [anon_sym___attribute] = ACTIONS(2541),
    [anon_sym_COLON_COLON] = ACTIONS(2543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2543),
    [anon_sym___declspec] = ACTIONS(2541),
    [anon_sym___based] = ACTIONS(2541),
    [anon_sym_signed] = ACTIONS(2541),
    [anon_sym_unsigned] = ACTIONS(2541),
    [anon_sym_long] = ACTIONS(2541),
    [anon_sym_short] = ACTIONS(2541),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [anon_sym_static] = ACTIONS(2541),
    [anon_sym_register] = ACTIONS(2541),
    [anon_sym_inline] = ACTIONS(2541),
    [anon_sym___inline] = ACTIONS(2541),
    [anon_sym___inline__] = ACTIONS(2541),
    [anon_sym___forceinline] = ACTIONS(2541),
    [anon_sym_thread_local] = ACTIONS(2541),
    [anon_sym___thread] = ACTIONS(2541),
    [anon_sym_const] = ACTIONS(2541),
    [anon_sym_constexpr] = ACTIONS(2541),
    [anon_sym_volatile] = ACTIONS(2541),
    [anon_sym_restrict] = ACTIONS(2541),
    [anon_sym___restrict__] = ACTIONS(2541),
    [anon_sym__Atomic] = ACTIONS(2541),
    [anon_sym__Noreturn] = ACTIONS(2541),
    [anon_sym_noreturn] = ACTIONS(2541),
    [anon_sym__Nonnull] = ACTIONS(2541),
    [anon_sym_mutable] = ACTIONS(2541),
    [anon_sym_constinit] = ACTIONS(2541),
    [anon_sym_consteval] = ACTIONS(2541),
    [anon_sym___shared__] = ACTIONS(2541),
    [anon_sym___local__] = ACTIONS(2541),
    [anon_sym___constant__] = ACTIONS(2541),
    [anon_sym___managed__] = ACTIONS(2541),
    [anon_sym___grid_constant__] = ACTIONS(2541),
    [anon_sym_alignas] = ACTIONS(2541),
    [anon_sym__Alignas] = ACTIONS(2541),
    [sym_primitive_type] = ACTIONS(2541),
    [anon_sym_enum] = ACTIONS(2541),
    [anon_sym_class] = ACTIONS(2541),
    [anon_sym_struct] = ACTIONS(2541),
    [anon_sym_union] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2541),
    [anon_sym_decltype] = ACTIONS(2541),
    [anon_sym_explicit] = ACTIONS(2541),
    [anon_sym_typename] = ACTIONS(2541),
    [anon_sym_template] = ACTIONS(2541),
    [anon_sym_operator] = ACTIONS(2541),
    [anon_sym_friend] = ACTIONS(2541),
    [anon_sym_public] = ACTIONS(2541),
    [anon_sym_private] = ACTIONS(2541),
    [anon_sym_protected] = ACTIONS(2541),
    [anon_sym_using] = ACTIONS(2541),
    [anon_sym_static_assert] = ACTIONS(2541),
    [anon_sym___launch_bounds__] = ACTIONS(2541),
  },
  [STATE(2002)] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token2] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym___device__] = ACTIONS(2549),
    [anon_sym___host__] = ACTIONS(2549),
    [anon_sym___global__] = ACTIONS(2549),
    [anon_sym___forceinline__] = ACTIONS(2549),
    [anon_sym___noinline__] = ACTIONS(2549),
    [anon_sym_virtual] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym___attribute] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym__Nonnull] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym___shared__] = ACTIONS(2549),
    [anon_sym___local__] = ACTIONS(2549),
    [anon_sym___constant__] = ACTIONS(2549),
    [anon_sym___managed__] = ACTIONS(2549),
    [anon_sym___grid_constant__] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_friend] = ACTIONS(2549),
    [anon_sym_public] = ACTIONS(2549),
    [anon_sym_private] = ACTIONS(2549),
    [anon_sym_protected] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym___launch_bounds__] = ACTIONS(2549),
  },
  [STATE(2003)] = {
    [sym_identifier] = ACTIONS(5607),
    [aux_sym_preproc_def_token1] = ACTIONS(5607),
    [aux_sym_preproc_if_token1] = ACTIONS(5607),
    [aux_sym_preproc_if_token2] = ACTIONS(5607),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5607),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5607),
    [sym_preproc_directive] = ACTIONS(5607),
    [anon_sym_LPAREN2] = ACTIONS(5609),
    [anon_sym_TILDE] = ACTIONS(5609),
    [anon_sym_STAR] = ACTIONS(5609),
    [anon_sym_AMP_AMP] = ACTIONS(5609),
    [anon_sym_AMP] = ACTIONS(5607),
    [anon_sym_SEMI] = ACTIONS(5609),
    [anon_sym___extension__] = ACTIONS(5607),
    [anon_sym_typedef] = ACTIONS(5607),
    [anon_sym___device__] = ACTIONS(5607),
    [anon_sym___host__] = ACTIONS(5607),
    [anon_sym___global__] = ACTIONS(5607),
    [anon_sym___forceinline__] = ACTIONS(5607),
    [anon_sym___noinline__] = ACTIONS(5607),
    [anon_sym_virtual] = ACTIONS(5607),
    [anon_sym_extern] = ACTIONS(5607),
    [anon_sym___attribute__] = ACTIONS(5607),
    [anon_sym___attribute] = ACTIONS(5607),
    [anon_sym_COLON_COLON] = ACTIONS(5609),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5609),
    [anon_sym___declspec] = ACTIONS(5607),
    [anon_sym___based] = ACTIONS(5607),
    [anon_sym_signed] = ACTIONS(5607),
    [anon_sym_unsigned] = ACTIONS(5607),
    [anon_sym_long] = ACTIONS(5607),
    [anon_sym_short] = ACTIONS(5607),
    [anon_sym_LBRACK] = ACTIONS(5607),
    [anon_sym_static] = ACTIONS(5607),
    [anon_sym_register] = ACTIONS(5607),
    [anon_sym_inline] = ACTIONS(5607),
    [anon_sym___inline] = ACTIONS(5607),
    [anon_sym___inline__] = ACTIONS(5607),
    [anon_sym___forceinline] = ACTIONS(5607),
    [anon_sym_thread_local] = ACTIONS(5607),
    [anon_sym___thread] = ACTIONS(5607),
    [anon_sym_const] = ACTIONS(5607),
    [anon_sym_constexpr] = ACTIONS(5607),
    [anon_sym_volatile] = ACTIONS(5607),
    [anon_sym_restrict] = ACTIONS(5607),
    [anon_sym___restrict__] = ACTIONS(5607),
    [anon_sym__Atomic] = ACTIONS(5607),
    [anon_sym__Noreturn] = ACTIONS(5607),
    [anon_sym_noreturn] = ACTIONS(5607),
    [anon_sym__Nonnull] = ACTIONS(5607),
    [anon_sym_mutable] = ACTIONS(5607),
    [anon_sym_constinit] = ACTIONS(5607),
    [anon_sym_consteval] = ACTIONS(5607),
    [anon_sym___shared__] = ACTIONS(5607),
    [anon_sym___local__] = ACTIONS(5607),
    [anon_sym___constant__] = ACTIONS(5607),
    [anon_sym___managed__] = ACTIONS(5607),
    [anon_sym___grid_constant__] = ACTIONS(5607),
    [anon_sym_alignas] = ACTIONS(5607),
    [anon_sym__Alignas] = ACTIONS(5607),
    [sym_primitive_type] = ACTIONS(5607),
    [anon_sym_enum] = ACTIONS(5607),
    [anon_sym_class] = ACTIONS(5607),
    [anon_sym_struct] = ACTIONS(5607),
    [anon_sym_union] = ACTIONS(5607),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5607),
    [anon_sym_decltype] = ACTIONS(5607),
    [anon_sym_explicit] = ACTIONS(5607),
    [anon_sym_typename] = ACTIONS(5607),
    [anon_sym_template] = ACTIONS(5607),
    [anon_sym_operator] = ACTIONS(5607),
    [anon_sym_friend] = ACTIONS(5607),
    [anon_sym_public] = ACTIONS(5607),
    [anon_sym_private] = ACTIONS(5607),
    [anon_sym_protected] = ACTIONS(5607),
    [anon_sym_using] = ACTIONS(5607),
    [anon_sym_static_assert] = ACTIONS(5607),
    [anon_sym___launch_bounds__] = ACTIONS(5607),
  },
  [STATE(2004)] = {
    [sym_identifier] = ACTIONS(3826),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3828),
    [anon_sym_COMMA] = ACTIONS(3828),
    [anon_sym_RPAREN] = ACTIONS(3828),
    [anon_sym_LPAREN2] = ACTIONS(3828),
    [anon_sym_TILDE] = ACTIONS(3828),
    [anon_sym_STAR] = ACTIONS(3828),
    [anon_sym_AMP_AMP] = ACTIONS(3828),
    [anon_sym_AMP] = ACTIONS(3826),
    [anon_sym_SEMI] = ACTIONS(3828),
    [anon_sym___extension__] = ACTIONS(3826),
    [anon_sym___device__] = ACTIONS(3826),
    [anon_sym___host__] = ACTIONS(3826),
    [anon_sym___global__] = ACTIONS(3826),
    [anon_sym___forceinline__] = ACTIONS(3826),
    [anon_sym___noinline__] = ACTIONS(3826),
    [anon_sym_virtual] = ACTIONS(3826),
    [anon_sym_extern] = ACTIONS(3826),
    [anon_sym___attribute__] = ACTIONS(3826),
    [anon_sym___attribute] = ACTIONS(3826),
    [anon_sym_COLON_COLON] = ACTIONS(3828),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3828),
    [anon_sym___declspec] = ACTIONS(3826),
    [anon_sym___based] = ACTIONS(3826),
    [anon_sym___cdecl] = ACTIONS(3826),
    [anon_sym___clrcall] = ACTIONS(3826),
    [anon_sym___stdcall] = ACTIONS(3826),
    [anon_sym___fastcall] = ACTIONS(3826),
    [anon_sym___thiscall] = ACTIONS(3826),
    [anon_sym___vectorcall] = ACTIONS(3826),
    [anon_sym_LBRACE] = ACTIONS(3828),
    [anon_sym_LBRACK] = ACTIONS(3826),
    [anon_sym_static] = ACTIONS(3826),
    [anon_sym_EQ] = ACTIONS(3828),
    [anon_sym_register] = ACTIONS(3826),
    [anon_sym_inline] = ACTIONS(3826),
    [anon_sym___inline] = ACTIONS(3826),
    [anon_sym___inline__] = ACTIONS(3826),
    [anon_sym___forceinline] = ACTIONS(3826),
    [anon_sym_thread_local] = ACTIONS(3826),
    [anon_sym___thread] = ACTIONS(3826),
    [anon_sym_const] = ACTIONS(3826),
    [anon_sym_constexpr] = ACTIONS(3826),
    [anon_sym_volatile] = ACTIONS(3826),
    [anon_sym_restrict] = ACTIONS(3826),
    [anon_sym___restrict__] = ACTIONS(3826),
    [anon_sym__Atomic] = ACTIONS(3826),
    [anon_sym__Noreturn] = ACTIONS(3826),
    [anon_sym_noreturn] = ACTIONS(3826),
    [anon_sym__Nonnull] = ACTIONS(3826),
    [anon_sym_mutable] = ACTIONS(3826),
    [anon_sym_constinit] = ACTIONS(3826),
    [anon_sym_consteval] = ACTIONS(3826),
    [anon_sym___shared__] = ACTIONS(3826),
    [anon_sym___local__] = ACTIONS(3826),
    [anon_sym___constant__] = ACTIONS(3826),
    [anon_sym___managed__] = ACTIONS(3826),
    [anon_sym___grid_constant__] = ACTIONS(3826),
    [anon_sym_alignas] = ACTIONS(3826),
    [anon_sym__Alignas] = ACTIONS(3826),
    [anon_sym_COLON] = ACTIONS(3826),
    [anon_sym_asm] = ACTIONS(3826),
    [anon_sym___asm__] = ACTIONS(3826),
    [anon_sym___asm] = ACTIONS(3826),
    [anon_sym_DASH_GT] = ACTIONS(3828),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3826),
    [anon_sym_final] = ACTIONS(3826),
    [anon_sym_override] = ACTIONS(3826),
    [anon_sym_explicit] = ACTIONS(3826),
    [anon_sym_template] = ACTIONS(3826),
    [anon_sym_GT2] = ACTIONS(3828),
    [anon_sym_operator] = ACTIONS(3826),
    [anon_sym_try] = ACTIONS(3826),
    [anon_sym_public] = ACTIONS(3826),
    [anon_sym_private] = ACTIONS(3826),
    [anon_sym_protected] = ACTIONS(3826),
    [anon_sym_requires] = ACTIONS(3826),
    [anon_sym___launch_bounds__] = ACTIONS(3826),
  },
  [STATE(2005)] = {
    [sym_identifier] = ACTIONS(5611),
    [aux_sym_preproc_def_token1] = ACTIONS(5611),
    [aux_sym_preproc_if_token1] = ACTIONS(5611),
    [aux_sym_preproc_if_token2] = ACTIONS(5611),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5611),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5611),
    [sym_preproc_directive] = ACTIONS(5611),
    [anon_sym_LPAREN2] = ACTIONS(5613),
    [anon_sym_TILDE] = ACTIONS(5613),
    [anon_sym_STAR] = ACTIONS(5613),
    [anon_sym_AMP_AMP] = ACTIONS(5613),
    [anon_sym_AMP] = ACTIONS(5611),
    [anon_sym_SEMI] = ACTIONS(5613),
    [anon_sym___extension__] = ACTIONS(5611),
    [anon_sym_typedef] = ACTIONS(5611),
    [anon_sym___device__] = ACTIONS(5611),
    [anon_sym___host__] = ACTIONS(5611),
    [anon_sym___global__] = ACTIONS(5611),
    [anon_sym___forceinline__] = ACTIONS(5611),
    [anon_sym___noinline__] = ACTIONS(5611),
    [anon_sym_virtual] = ACTIONS(5611),
    [anon_sym_extern] = ACTIONS(5611),
    [anon_sym___attribute__] = ACTIONS(5611),
    [anon_sym___attribute] = ACTIONS(5611),
    [anon_sym_COLON_COLON] = ACTIONS(5613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5613),
    [anon_sym___declspec] = ACTIONS(5611),
    [anon_sym___based] = ACTIONS(5611),
    [anon_sym_signed] = ACTIONS(5611),
    [anon_sym_unsigned] = ACTIONS(5611),
    [anon_sym_long] = ACTIONS(5611),
    [anon_sym_short] = ACTIONS(5611),
    [anon_sym_LBRACK] = ACTIONS(5611),
    [anon_sym_static] = ACTIONS(5611),
    [anon_sym_register] = ACTIONS(5611),
    [anon_sym_inline] = ACTIONS(5611),
    [anon_sym___inline] = ACTIONS(5611),
    [anon_sym___inline__] = ACTIONS(5611),
    [anon_sym___forceinline] = ACTIONS(5611),
    [anon_sym_thread_local] = ACTIONS(5611),
    [anon_sym___thread] = ACTIONS(5611),
    [anon_sym_const] = ACTIONS(5611),
    [anon_sym_constexpr] = ACTIONS(5611),
    [anon_sym_volatile] = ACTIONS(5611),
    [anon_sym_restrict] = ACTIONS(5611),
    [anon_sym___restrict__] = ACTIONS(5611),
    [anon_sym__Atomic] = ACTIONS(5611),
    [anon_sym__Noreturn] = ACTIONS(5611),
    [anon_sym_noreturn] = ACTIONS(5611),
    [anon_sym__Nonnull] = ACTIONS(5611),
    [anon_sym_mutable] = ACTIONS(5611),
    [anon_sym_constinit] = ACTIONS(5611),
    [anon_sym_consteval] = ACTIONS(5611),
    [anon_sym___shared__] = ACTIONS(5611),
    [anon_sym___local__] = ACTIONS(5611),
    [anon_sym___constant__] = ACTIONS(5611),
    [anon_sym___managed__] = ACTIONS(5611),
    [anon_sym___grid_constant__] = ACTIONS(5611),
    [anon_sym_alignas] = ACTIONS(5611),
    [anon_sym__Alignas] = ACTIONS(5611),
    [sym_primitive_type] = ACTIONS(5611),
    [anon_sym_enum] = ACTIONS(5611),
    [anon_sym_class] = ACTIONS(5611),
    [anon_sym_struct] = ACTIONS(5611),
    [anon_sym_union] = ACTIONS(5611),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5611),
    [anon_sym_decltype] = ACTIONS(5611),
    [anon_sym_explicit] = ACTIONS(5611),
    [anon_sym_typename] = ACTIONS(5611),
    [anon_sym_template] = ACTIONS(5611),
    [anon_sym_operator] = ACTIONS(5611),
    [anon_sym_friend] = ACTIONS(5611),
    [anon_sym_public] = ACTIONS(5611),
    [anon_sym_private] = ACTIONS(5611),
    [anon_sym_protected] = ACTIONS(5611),
    [anon_sym_using] = ACTIONS(5611),
    [anon_sym_static_assert] = ACTIONS(5611),
    [anon_sym___launch_bounds__] = ACTIONS(5611),
  },
  [STATE(2006)] = {
    [sym_identifier] = ACTIONS(2533),
    [aux_sym_preproc_def_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token1] = ACTIONS(2533),
    [aux_sym_preproc_if_token2] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2533),
    [sym_preproc_directive] = ACTIONS(2533),
    [anon_sym_LPAREN2] = ACTIONS(2535),
    [anon_sym_TILDE] = ACTIONS(2535),
    [anon_sym_STAR] = ACTIONS(2535),
    [anon_sym_AMP_AMP] = ACTIONS(2535),
    [anon_sym_AMP] = ACTIONS(2533),
    [anon_sym_SEMI] = ACTIONS(2535),
    [anon_sym___extension__] = ACTIONS(2533),
    [anon_sym_typedef] = ACTIONS(2533),
    [anon_sym___device__] = ACTIONS(2533),
    [anon_sym___host__] = ACTIONS(2533),
    [anon_sym___global__] = ACTIONS(2533),
    [anon_sym___forceinline__] = ACTIONS(2533),
    [anon_sym___noinline__] = ACTIONS(2533),
    [anon_sym_virtual] = ACTIONS(2533),
    [anon_sym_extern] = ACTIONS(2533),
    [anon_sym___attribute__] = ACTIONS(2533),
    [anon_sym___attribute] = ACTIONS(2533),
    [anon_sym_COLON_COLON] = ACTIONS(2535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2535),
    [anon_sym___declspec] = ACTIONS(2533),
    [anon_sym___based] = ACTIONS(2533),
    [anon_sym_signed] = ACTIONS(2533),
    [anon_sym_unsigned] = ACTIONS(2533),
    [anon_sym_long] = ACTIONS(2533),
    [anon_sym_short] = ACTIONS(2533),
    [anon_sym_LBRACK] = ACTIONS(2533),
    [anon_sym_static] = ACTIONS(2533),
    [anon_sym_register] = ACTIONS(2533),
    [anon_sym_inline] = ACTIONS(2533),
    [anon_sym___inline] = ACTIONS(2533),
    [anon_sym___inline__] = ACTIONS(2533),
    [anon_sym___forceinline] = ACTIONS(2533),
    [anon_sym_thread_local] = ACTIONS(2533),
    [anon_sym___thread] = ACTIONS(2533),
    [anon_sym_const] = ACTIONS(2533),
    [anon_sym_constexpr] = ACTIONS(2533),
    [anon_sym_volatile] = ACTIONS(2533),
    [anon_sym_restrict] = ACTIONS(2533),
    [anon_sym___restrict__] = ACTIONS(2533),
    [anon_sym__Atomic] = ACTIONS(2533),
    [anon_sym__Noreturn] = ACTIONS(2533),
    [anon_sym_noreturn] = ACTIONS(2533),
    [anon_sym__Nonnull] = ACTIONS(2533),
    [anon_sym_mutable] = ACTIONS(2533),
    [anon_sym_constinit] = ACTIONS(2533),
    [anon_sym_consteval] = ACTIONS(2533),
    [anon_sym___shared__] = ACTIONS(2533),
    [anon_sym___local__] = ACTIONS(2533),
    [anon_sym___constant__] = ACTIONS(2533),
    [anon_sym___managed__] = ACTIONS(2533),
    [anon_sym___grid_constant__] = ACTIONS(2533),
    [anon_sym_alignas] = ACTIONS(2533),
    [anon_sym__Alignas] = ACTIONS(2533),
    [sym_primitive_type] = ACTIONS(2533),
    [anon_sym_enum] = ACTIONS(2533),
    [anon_sym_class] = ACTIONS(2533),
    [anon_sym_struct] = ACTIONS(2533),
    [anon_sym_union] = ACTIONS(2533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2533),
    [anon_sym_decltype] = ACTIONS(2533),
    [anon_sym_explicit] = ACTIONS(2533),
    [anon_sym_typename] = ACTIONS(2533),
    [anon_sym_template] = ACTIONS(2533),
    [anon_sym_operator] = ACTIONS(2533),
    [anon_sym_friend] = ACTIONS(2533),
    [anon_sym_public] = ACTIONS(2533),
    [anon_sym_private] = ACTIONS(2533),
    [anon_sym_protected] = ACTIONS(2533),
    [anon_sym_using] = ACTIONS(2533),
    [anon_sym_static_assert] = ACTIONS(2533),
    [anon_sym___launch_bounds__] = ACTIONS(2533),
  },
  [STATE(2007)] = {
    [sym_identifier] = ACTIONS(2463),
    [aux_sym_preproc_def_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token2] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2463),
    [sym_preproc_directive] = ACTIONS(2463),
    [anon_sym_LPAREN2] = ACTIONS(2465),
    [anon_sym_TILDE] = ACTIONS(2465),
    [anon_sym_STAR] = ACTIONS(2465),
    [anon_sym_AMP_AMP] = ACTIONS(2465),
    [anon_sym_AMP] = ACTIONS(2463),
    [anon_sym_SEMI] = ACTIONS(2465),
    [anon_sym___extension__] = ACTIONS(2463),
    [anon_sym_typedef] = ACTIONS(2463),
    [anon_sym___device__] = ACTIONS(2463),
    [anon_sym___host__] = ACTIONS(2463),
    [anon_sym___global__] = ACTIONS(2463),
    [anon_sym___forceinline__] = ACTIONS(2463),
    [anon_sym___noinline__] = ACTIONS(2463),
    [anon_sym_virtual] = ACTIONS(2463),
    [anon_sym_extern] = ACTIONS(2463),
    [anon_sym___attribute__] = ACTIONS(2463),
    [anon_sym___attribute] = ACTIONS(2463),
    [anon_sym_COLON_COLON] = ACTIONS(2465),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2465),
    [anon_sym___declspec] = ACTIONS(2463),
    [anon_sym___based] = ACTIONS(2463),
    [anon_sym_signed] = ACTIONS(2463),
    [anon_sym_unsigned] = ACTIONS(2463),
    [anon_sym_long] = ACTIONS(2463),
    [anon_sym_short] = ACTIONS(2463),
    [anon_sym_LBRACK] = ACTIONS(2463),
    [anon_sym_static] = ACTIONS(2463),
    [anon_sym_register] = ACTIONS(2463),
    [anon_sym_inline] = ACTIONS(2463),
    [anon_sym___inline] = ACTIONS(2463),
    [anon_sym___inline__] = ACTIONS(2463),
    [anon_sym___forceinline] = ACTIONS(2463),
    [anon_sym_thread_local] = ACTIONS(2463),
    [anon_sym___thread] = ACTIONS(2463),
    [anon_sym_const] = ACTIONS(2463),
    [anon_sym_constexpr] = ACTIONS(2463),
    [anon_sym_volatile] = ACTIONS(2463),
    [anon_sym_restrict] = ACTIONS(2463),
    [anon_sym___restrict__] = ACTIONS(2463),
    [anon_sym__Atomic] = ACTIONS(2463),
    [anon_sym__Noreturn] = ACTIONS(2463),
    [anon_sym_noreturn] = ACTIONS(2463),
    [anon_sym__Nonnull] = ACTIONS(2463),
    [anon_sym_mutable] = ACTIONS(2463),
    [anon_sym_constinit] = ACTIONS(2463),
    [anon_sym_consteval] = ACTIONS(2463),
    [anon_sym___shared__] = ACTIONS(2463),
    [anon_sym___local__] = ACTIONS(2463),
    [anon_sym___constant__] = ACTIONS(2463),
    [anon_sym___managed__] = ACTIONS(2463),
    [anon_sym___grid_constant__] = ACTIONS(2463),
    [anon_sym_alignas] = ACTIONS(2463),
    [anon_sym__Alignas] = ACTIONS(2463),
    [sym_primitive_type] = ACTIONS(2463),
    [anon_sym_enum] = ACTIONS(2463),
    [anon_sym_class] = ACTIONS(2463),
    [anon_sym_struct] = ACTIONS(2463),
    [anon_sym_union] = ACTIONS(2463),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2463),
    [anon_sym_decltype] = ACTIONS(2463),
    [anon_sym_explicit] = ACTIONS(2463),
    [anon_sym_typename] = ACTIONS(2463),
    [anon_sym_template] = ACTIONS(2463),
    [anon_sym_operator] = ACTIONS(2463),
    [anon_sym_friend] = ACTIONS(2463),
    [anon_sym_public] = ACTIONS(2463),
    [anon_sym_private] = ACTIONS(2463),
    [anon_sym_protected] = ACTIONS(2463),
    [anon_sym_using] = ACTIONS(2463),
    [anon_sym_static_assert] = ACTIONS(2463),
    [anon_sym___launch_bounds__] = ACTIONS(2463),
  },
  [STATE(2008)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(2009)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(2010)] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym___device__] = ACTIONS(2332),
    [anon_sym___host__] = ACTIONS(2332),
    [anon_sym___global__] = ACTIONS(2332),
    [anon_sym___forceinline__] = ACTIONS(2332),
    [anon_sym___noinline__] = ACTIONS(2332),
    [anon_sym_virtual] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym___attribute] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym__Nonnull] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym___shared__] = ACTIONS(2332),
    [anon_sym___local__] = ACTIONS(2332),
    [anon_sym___constant__] = ACTIONS(2332),
    [anon_sym___managed__] = ACTIONS(2332),
    [anon_sym___grid_constant__] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym___launch_bounds__] = ACTIONS(2332),
  },
  [STATE(2011)] = {
    [sym_identifier] = ACTIONS(2339),
    [aux_sym_preproc_def_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token2] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2339),
    [sym_preproc_directive] = ACTIONS(2339),
    [anon_sym_LPAREN2] = ACTIONS(2341),
    [anon_sym_TILDE] = ACTIONS(2341),
    [anon_sym_STAR] = ACTIONS(2341),
    [anon_sym_AMP_AMP] = ACTIONS(2341),
    [anon_sym_AMP] = ACTIONS(2339),
    [anon_sym_SEMI] = ACTIONS(2341),
    [anon_sym___extension__] = ACTIONS(2339),
    [anon_sym_typedef] = ACTIONS(2339),
    [anon_sym___device__] = ACTIONS(2339),
    [anon_sym___host__] = ACTIONS(2339),
    [anon_sym___global__] = ACTIONS(2339),
    [anon_sym___forceinline__] = ACTIONS(2339),
    [anon_sym___noinline__] = ACTIONS(2339),
    [anon_sym_virtual] = ACTIONS(2339),
    [anon_sym_extern] = ACTIONS(2339),
    [anon_sym___attribute__] = ACTIONS(2339),
    [anon_sym___attribute] = ACTIONS(2339),
    [anon_sym_COLON_COLON] = ACTIONS(2341),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2341),
    [anon_sym___declspec] = ACTIONS(2339),
    [anon_sym___based] = ACTIONS(2339),
    [anon_sym_signed] = ACTIONS(2339),
    [anon_sym_unsigned] = ACTIONS(2339),
    [anon_sym_long] = ACTIONS(2339),
    [anon_sym_short] = ACTIONS(2339),
    [anon_sym_LBRACK] = ACTIONS(2339),
    [anon_sym_static] = ACTIONS(2339),
    [anon_sym_register] = ACTIONS(2339),
    [anon_sym_inline] = ACTIONS(2339),
    [anon_sym___inline] = ACTIONS(2339),
    [anon_sym___inline__] = ACTIONS(2339),
    [anon_sym___forceinline] = ACTIONS(2339),
    [anon_sym_thread_local] = ACTIONS(2339),
    [anon_sym___thread] = ACTIONS(2339),
    [anon_sym_const] = ACTIONS(2339),
    [anon_sym_constexpr] = ACTIONS(2339),
    [anon_sym_volatile] = ACTIONS(2339),
    [anon_sym_restrict] = ACTIONS(2339),
    [anon_sym___restrict__] = ACTIONS(2339),
    [anon_sym__Atomic] = ACTIONS(2339),
    [anon_sym__Noreturn] = ACTIONS(2339),
    [anon_sym_noreturn] = ACTIONS(2339),
    [anon_sym__Nonnull] = ACTIONS(2339),
    [anon_sym_mutable] = ACTIONS(2339),
    [anon_sym_constinit] = ACTIONS(2339),
    [anon_sym_consteval] = ACTIONS(2339),
    [anon_sym___shared__] = ACTIONS(2339),
    [anon_sym___local__] = ACTIONS(2339),
    [anon_sym___constant__] = ACTIONS(2339),
    [anon_sym___managed__] = ACTIONS(2339),
    [anon_sym___grid_constant__] = ACTIONS(2339),
    [anon_sym_alignas] = ACTIONS(2339),
    [anon_sym__Alignas] = ACTIONS(2339),
    [sym_primitive_type] = ACTIONS(2339),
    [anon_sym_enum] = ACTIONS(2339),
    [anon_sym_class] = ACTIONS(2339),
    [anon_sym_struct] = ACTIONS(2339),
    [anon_sym_union] = ACTIONS(2339),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2339),
    [anon_sym_decltype] = ACTIONS(2339),
    [anon_sym_explicit] = ACTIONS(2339),
    [anon_sym_typename] = ACTIONS(2339),
    [anon_sym_template] = ACTIONS(2339),
    [anon_sym_operator] = ACTIONS(2339),
    [anon_sym_friend] = ACTIONS(2339),
    [anon_sym_public] = ACTIONS(2339),
    [anon_sym_private] = ACTIONS(2339),
    [anon_sym_protected] = ACTIONS(2339),
    [anon_sym_using] = ACTIONS(2339),
    [anon_sym_static_assert] = ACTIONS(2339),
    [anon_sym___launch_bounds__] = ACTIONS(2339),
  },
  [STATE(2012)] = {
    [sym_identifier] = ACTIONS(2343),
    [aux_sym_preproc_def_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token2] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2343),
    [sym_preproc_directive] = ACTIONS(2343),
    [anon_sym_LPAREN2] = ACTIONS(2345),
    [anon_sym_TILDE] = ACTIONS(2345),
    [anon_sym_STAR] = ACTIONS(2345),
    [anon_sym_AMP_AMP] = ACTIONS(2345),
    [anon_sym_AMP] = ACTIONS(2343),
    [anon_sym_SEMI] = ACTIONS(2345),
    [anon_sym___extension__] = ACTIONS(2343),
    [anon_sym_typedef] = ACTIONS(2343),
    [anon_sym___device__] = ACTIONS(2343),
    [anon_sym___host__] = ACTIONS(2343),
    [anon_sym___global__] = ACTIONS(2343),
    [anon_sym___forceinline__] = ACTIONS(2343),
    [anon_sym___noinline__] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2343),
    [anon_sym_extern] = ACTIONS(2343),
    [anon_sym___attribute__] = ACTIONS(2343),
    [anon_sym___attribute] = ACTIONS(2343),
    [anon_sym_COLON_COLON] = ACTIONS(2345),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2345),
    [anon_sym___declspec] = ACTIONS(2343),
    [anon_sym___based] = ACTIONS(2343),
    [anon_sym_signed] = ACTIONS(2343),
    [anon_sym_unsigned] = ACTIONS(2343),
    [anon_sym_long] = ACTIONS(2343),
    [anon_sym_short] = ACTIONS(2343),
    [anon_sym_LBRACK] = ACTIONS(2343),
    [anon_sym_static] = ACTIONS(2343),
    [anon_sym_register] = ACTIONS(2343),
    [anon_sym_inline] = ACTIONS(2343),
    [anon_sym___inline] = ACTIONS(2343),
    [anon_sym___inline__] = ACTIONS(2343),
    [anon_sym___forceinline] = ACTIONS(2343),
    [anon_sym_thread_local] = ACTIONS(2343),
    [anon_sym___thread] = ACTIONS(2343),
    [anon_sym_const] = ACTIONS(2343),
    [anon_sym_constexpr] = ACTIONS(2343),
    [anon_sym_volatile] = ACTIONS(2343),
    [anon_sym_restrict] = ACTIONS(2343),
    [anon_sym___restrict__] = ACTIONS(2343),
    [anon_sym__Atomic] = ACTIONS(2343),
    [anon_sym__Noreturn] = ACTIONS(2343),
    [anon_sym_noreturn] = ACTIONS(2343),
    [anon_sym__Nonnull] = ACTIONS(2343),
    [anon_sym_mutable] = ACTIONS(2343),
    [anon_sym_constinit] = ACTIONS(2343),
    [anon_sym_consteval] = ACTIONS(2343),
    [anon_sym___shared__] = ACTIONS(2343),
    [anon_sym___local__] = ACTIONS(2343),
    [anon_sym___constant__] = ACTIONS(2343),
    [anon_sym___managed__] = ACTIONS(2343),
    [anon_sym___grid_constant__] = ACTIONS(2343),
    [anon_sym_alignas] = ACTIONS(2343),
    [anon_sym__Alignas] = ACTIONS(2343),
    [sym_primitive_type] = ACTIONS(2343),
    [anon_sym_enum] = ACTIONS(2343),
    [anon_sym_class] = ACTIONS(2343),
    [anon_sym_struct] = ACTIONS(2343),
    [anon_sym_union] = ACTIONS(2343),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2343),
    [anon_sym_decltype] = ACTIONS(2343),
    [anon_sym_explicit] = ACTIONS(2343),
    [anon_sym_typename] = ACTIONS(2343),
    [anon_sym_template] = ACTIONS(2343),
    [anon_sym_operator] = ACTIONS(2343),
    [anon_sym_friend] = ACTIONS(2343),
    [anon_sym_public] = ACTIONS(2343),
    [anon_sym_private] = ACTIONS(2343),
    [anon_sym_protected] = ACTIONS(2343),
    [anon_sym_using] = ACTIONS(2343),
    [anon_sym_static_assert] = ACTIONS(2343),
    [anon_sym___launch_bounds__] = ACTIONS(2343),
  },
  [STATE(2013)] = {
    [sym_identifier] = ACTIONS(2347),
    [aux_sym_preproc_def_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token2] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2347),
    [sym_preproc_directive] = ACTIONS(2347),
    [anon_sym_LPAREN2] = ACTIONS(2349),
    [anon_sym_TILDE] = ACTIONS(2349),
    [anon_sym_STAR] = ACTIONS(2349),
    [anon_sym_AMP_AMP] = ACTIONS(2349),
    [anon_sym_AMP] = ACTIONS(2347),
    [anon_sym_SEMI] = ACTIONS(2349),
    [anon_sym___extension__] = ACTIONS(2347),
    [anon_sym_typedef] = ACTIONS(2347),
    [anon_sym___device__] = ACTIONS(2347),
    [anon_sym___host__] = ACTIONS(2347),
    [anon_sym___global__] = ACTIONS(2347),
    [anon_sym___forceinline__] = ACTIONS(2347),
    [anon_sym___noinline__] = ACTIONS(2347),
    [anon_sym_virtual] = ACTIONS(2347),
    [anon_sym_extern] = ACTIONS(2347),
    [anon_sym___attribute__] = ACTIONS(2347),
    [anon_sym___attribute] = ACTIONS(2347),
    [anon_sym_COLON_COLON] = ACTIONS(2349),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2349),
    [anon_sym___declspec] = ACTIONS(2347),
    [anon_sym___based] = ACTIONS(2347),
    [anon_sym_signed] = ACTIONS(2347),
    [anon_sym_unsigned] = ACTIONS(2347),
    [anon_sym_long] = ACTIONS(2347),
    [anon_sym_short] = ACTIONS(2347),
    [anon_sym_LBRACK] = ACTIONS(2347),
    [anon_sym_static] = ACTIONS(2347),
    [anon_sym_register] = ACTIONS(2347),
    [anon_sym_inline] = ACTIONS(2347),
    [anon_sym___inline] = ACTIONS(2347),
    [anon_sym___inline__] = ACTIONS(2347),
    [anon_sym___forceinline] = ACTIONS(2347),
    [anon_sym_thread_local] = ACTIONS(2347),
    [anon_sym___thread] = ACTIONS(2347),
    [anon_sym_const] = ACTIONS(2347),
    [anon_sym_constexpr] = ACTIONS(2347),
    [anon_sym_volatile] = ACTIONS(2347),
    [anon_sym_restrict] = ACTIONS(2347),
    [anon_sym___restrict__] = ACTIONS(2347),
    [anon_sym__Atomic] = ACTIONS(2347),
    [anon_sym__Noreturn] = ACTIONS(2347),
    [anon_sym_noreturn] = ACTIONS(2347),
    [anon_sym__Nonnull] = ACTIONS(2347),
    [anon_sym_mutable] = ACTIONS(2347),
    [anon_sym_constinit] = ACTIONS(2347),
    [anon_sym_consteval] = ACTIONS(2347),
    [anon_sym___shared__] = ACTIONS(2347),
    [anon_sym___local__] = ACTIONS(2347),
    [anon_sym___constant__] = ACTIONS(2347),
    [anon_sym___managed__] = ACTIONS(2347),
    [anon_sym___grid_constant__] = ACTIONS(2347),
    [anon_sym_alignas] = ACTIONS(2347),
    [anon_sym__Alignas] = ACTIONS(2347),
    [sym_primitive_type] = ACTIONS(2347),
    [anon_sym_enum] = ACTIONS(2347),
    [anon_sym_class] = ACTIONS(2347),
    [anon_sym_struct] = ACTIONS(2347),
    [anon_sym_union] = ACTIONS(2347),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2347),
    [anon_sym_decltype] = ACTIONS(2347),
    [anon_sym_explicit] = ACTIONS(2347),
    [anon_sym_typename] = ACTIONS(2347),
    [anon_sym_template] = ACTIONS(2347),
    [anon_sym_operator] = ACTIONS(2347),
    [anon_sym_friend] = ACTIONS(2347),
    [anon_sym_public] = ACTIONS(2347),
    [anon_sym_private] = ACTIONS(2347),
    [anon_sym_protected] = ACTIONS(2347),
    [anon_sym_using] = ACTIONS(2347),
    [anon_sym_static_assert] = ACTIONS(2347),
    [anon_sym___launch_bounds__] = ACTIONS(2347),
  },
  [STATE(2014)] = {
    [sym_identifier] = ACTIONS(2351),
    [aux_sym_preproc_def_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token2] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2351),
    [sym_preproc_directive] = ACTIONS(2351),
    [anon_sym_LPAREN2] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(2353),
    [anon_sym_STAR] = ACTIONS(2353),
    [anon_sym_AMP_AMP] = ACTIONS(2353),
    [anon_sym_AMP] = ACTIONS(2351),
    [anon_sym_SEMI] = ACTIONS(2353),
    [anon_sym___extension__] = ACTIONS(2351),
    [anon_sym_typedef] = ACTIONS(2351),
    [anon_sym___device__] = ACTIONS(2351),
    [anon_sym___host__] = ACTIONS(2351),
    [anon_sym___global__] = ACTIONS(2351),
    [anon_sym___forceinline__] = ACTIONS(2351),
    [anon_sym___noinline__] = ACTIONS(2351),
    [anon_sym_virtual] = ACTIONS(2351),
    [anon_sym_extern] = ACTIONS(2351),
    [anon_sym___attribute__] = ACTIONS(2351),
    [anon_sym___attribute] = ACTIONS(2351),
    [anon_sym_COLON_COLON] = ACTIONS(2353),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2353),
    [anon_sym___declspec] = ACTIONS(2351),
    [anon_sym___based] = ACTIONS(2351),
    [anon_sym_signed] = ACTIONS(2351),
    [anon_sym_unsigned] = ACTIONS(2351),
    [anon_sym_long] = ACTIONS(2351),
    [anon_sym_short] = ACTIONS(2351),
    [anon_sym_LBRACK] = ACTIONS(2351),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_register] = ACTIONS(2351),
    [anon_sym_inline] = ACTIONS(2351),
    [anon_sym___inline] = ACTIONS(2351),
    [anon_sym___inline__] = ACTIONS(2351),
    [anon_sym___forceinline] = ACTIONS(2351),
    [anon_sym_thread_local] = ACTIONS(2351),
    [anon_sym___thread] = ACTIONS(2351),
    [anon_sym_const] = ACTIONS(2351),
    [anon_sym_constexpr] = ACTIONS(2351),
    [anon_sym_volatile] = ACTIONS(2351),
    [anon_sym_restrict] = ACTIONS(2351),
    [anon_sym___restrict__] = ACTIONS(2351),
    [anon_sym__Atomic] = ACTIONS(2351),
    [anon_sym__Noreturn] = ACTIONS(2351),
    [anon_sym_noreturn] = ACTIONS(2351),
    [anon_sym__Nonnull] = ACTIONS(2351),
    [anon_sym_mutable] = ACTIONS(2351),
    [anon_sym_constinit] = ACTIONS(2351),
    [anon_sym_consteval] = ACTIONS(2351),
    [anon_sym___shared__] = ACTIONS(2351),
    [anon_sym___local__] = ACTIONS(2351),
    [anon_sym___constant__] = ACTIONS(2351),
    [anon_sym___managed__] = ACTIONS(2351),
    [anon_sym___grid_constant__] = ACTIONS(2351),
    [anon_sym_alignas] = ACTIONS(2351),
    [anon_sym__Alignas] = ACTIONS(2351),
    [sym_primitive_type] = ACTIONS(2351),
    [anon_sym_enum] = ACTIONS(2351),
    [anon_sym_class] = ACTIONS(2351),
    [anon_sym_struct] = ACTIONS(2351),
    [anon_sym_union] = ACTIONS(2351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2351),
    [anon_sym_decltype] = ACTIONS(2351),
    [anon_sym_explicit] = ACTIONS(2351),
    [anon_sym_typename] = ACTIONS(2351),
    [anon_sym_template] = ACTIONS(2351),
    [anon_sym_operator] = ACTIONS(2351),
    [anon_sym_friend] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_using] = ACTIONS(2351),
    [anon_sym_static_assert] = ACTIONS(2351),
    [anon_sym___launch_bounds__] = ACTIONS(2351),
  },
  [STATE(2015)] = {
    [sym_identifier] = ACTIONS(2373),
    [aux_sym_preproc_def_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token1] = ACTIONS(2373),
    [aux_sym_preproc_if_token2] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2373),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2373),
    [sym_preproc_directive] = ACTIONS(2373),
    [anon_sym_LPAREN2] = ACTIONS(2375),
    [anon_sym_TILDE] = ACTIONS(2375),
    [anon_sym_STAR] = ACTIONS(2375),
    [anon_sym_AMP_AMP] = ACTIONS(2375),
    [anon_sym_AMP] = ACTIONS(2373),
    [anon_sym_SEMI] = ACTIONS(2375),
    [anon_sym___extension__] = ACTIONS(2373),
    [anon_sym_typedef] = ACTIONS(2373),
    [anon_sym___device__] = ACTIONS(2373),
    [anon_sym___host__] = ACTIONS(2373),
    [anon_sym___global__] = ACTIONS(2373),
    [anon_sym___forceinline__] = ACTIONS(2373),
    [anon_sym___noinline__] = ACTIONS(2373),
    [anon_sym_virtual] = ACTIONS(2373),
    [anon_sym_extern] = ACTIONS(2373),
    [anon_sym___attribute__] = ACTIONS(2373),
    [anon_sym___attribute] = ACTIONS(2373),
    [anon_sym_COLON_COLON] = ACTIONS(2375),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2375),
    [anon_sym___declspec] = ACTIONS(2373),
    [anon_sym___based] = ACTIONS(2373),
    [anon_sym_signed] = ACTIONS(2373),
    [anon_sym_unsigned] = ACTIONS(2373),
    [anon_sym_long] = ACTIONS(2373),
    [anon_sym_short] = ACTIONS(2373),
    [anon_sym_LBRACK] = ACTIONS(2373),
    [anon_sym_static] = ACTIONS(2373),
    [anon_sym_register] = ACTIONS(2373),
    [anon_sym_inline] = ACTIONS(2373),
    [anon_sym___inline] = ACTIONS(2373),
    [anon_sym___inline__] = ACTIONS(2373),
    [anon_sym___forceinline] = ACTIONS(2373),
    [anon_sym_thread_local] = ACTIONS(2373),
    [anon_sym___thread] = ACTIONS(2373),
    [anon_sym_const] = ACTIONS(2373),
    [anon_sym_constexpr] = ACTIONS(2373),
    [anon_sym_volatile] = ACTIONS(2373),
    [anon_sym_restrict] = ACTIONS(2373),
    [anon_sym___restrict__] = ACTIONS(2373),
    [anon_sym__Atomic] = ACTIONS(2373),
    [anon_sym__Noreturn] = ACTIONS(2373),
    [anon_sym_noreturn] = ACTIONS(2373),
    [anon_sym__Nonnull] = ACTIONS(2373),
    [anon_sym_mutable] = ACTIONS(2373),
    [anon_sym_constinit] = ACTIONS(2373),
    [anon_sym_consteval] = ACTIONS(2373),
    [anon_sym___shared__] = ACTIONS(2373),
    [anon_sym___local__] = ACTIONS(2373),
    [anon_sym___constant__] = ACTIONS(2373),
    [anon_sym___managed__] = ACTIONS(2373),
    [anon_sym___grid_constant__] = ACTIONS(2373),
    [anon_sym_alignas] = ACTIONS(2373),
    [anon_sym__Alignas] = ACTIONS(2373),
    [sym_primitive_type] = ACTIONS(2373),
    [anon_sym_enum] = ACTIONS(2373),
    [anon_sym_class] = ACTIONS(2373),
    [anon_sym_struct] = ACTIONS(2373),
    [anon_sym_union] = ACTIONS(2373),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2373),
    [anon_sym_decltype] = ACTIONS(2373),
    [anon_sym_explicit] = ACTIONS(2373),
    [anon_sym_typename] = ACTIONS(2373),
    [anon_sym_template] = ACTIONS(2373),
    [anon_sym_operator] = ACTIONS(2373),
    [anon_sym_friend] = ACTIONS(2373),
    [anon_sym_public] = ACTIONS(2373),
    [anon_sym_private] = ACTIONS(2373),
    [anon_sym_protected] = ACTIONS(2373),
    [anon_sym_using] = ACTIONS(2373),
    [anon_sym_static_assert] = ACTIONS(2373),
    [anon_sym___launch_bounds__] = ACTIONS(2373),
  },
  [STATE(2016)] = {
    [sym_identifier] = ACTIONS(2387),
    [aux_sym_preproc_def_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token2] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2387),
    [sym_preproc_directive] = ACTIONS(2387),
    [anon_sym_LPAREN2] = ACTIONS(2389),
    [anon_sym_TILDE] = ACTIONS(2389),
    [anon_sym_STAR] = ACTIONS(2389),
    [anon_sym_AMP_AMP] = ACTIONS(2389),
    [anon_sym_AMP] = ACTIONS(2387),
    [anon_sym_SEMI] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2387),
    [anon_sym_typedef] = ACTIONS(2387),
    [anon_sym___device__] = ACTIONS(2387),
    [anon_sym___host__] = ACTIONS(2387),
    [anon_sym___global__] = ACTIONS(2387),
    [anon_sym___forceinline__] = ACTIONS(2387),
    [anon_sym___noinline__] = ACTIONS(2387),
    [anon_sym_virtual] = ACTIONS(2387),
    [anon_sym_extern] = ACTIONS(2387),
    [anon_sym___attribute__] = ACTIONS(2387),
    [anon_sym___attribute] = ACTIONS(2387),
    [anon_sym_COLON_COLON] = ACTIONS(2389),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2389),
    [anon_sym___declspec] = ACTIONS(2387),
    [anon_sym___based] = ACTIONS(2387),
    [anon_sym_signed] = ACTIONS(2387),
    [anon_sym_unsigned] = ACTIONS(2387),
    [anon_sym_long] = ACTIONS(2387),
    [anon_sym_short] = ACTIONS(2387),
    [anon_sym_LBRACK] = ACTIONS(2387),
    [anon_sym_static] = ACTIONS(2387),
    [anon_sym_register] = ACTIONS(2387),
    [anon_sym_inline] = ACTIONS(2387),
    [anon_sym___inline] = ACTIONS(2387),
    [anon_sym___inline__] = ACTIONS(2387),
    [anon_sym___forceinline] = ACTIONS(2387),
    [anon_sym_thread_local] = ACTIONS(2387),
    [anon_sym___thread] = ACTIONS(2387),
    [anon_sym_const] = ACTIONS(2387),
    [anon_sym_constexpr] = ACTIONS(2387),
    [anon_sym_volatile] = ACTIONS(2387),
    [anon_sym_restrict] = ACTIONS(2387),
    [anon_sym___restrict__] = ACTIONS(2387),
    [anon_sym__Atomic] = ACTIONS(2387),
    [anon_sym__Noreturn] = ACTIONS(2387),
    [anon_sym_noreturn] = ACTIONS(2387),
    [anon_sym__Nonnull] = ACTIONS(2387),
    [anon_sym_mutable] = ACTIONS(2387),
    [anon_sym_constinit] = ACTIONS(2387),
    [anon_sym_consteval] = ACTIONS(2387),
    [anon_sym___shared__] = ACTIONS(2387),
    [anon_sym___local__] = ACTIONS(2387),
    [anon_sym___constant__] = ACTIONS(2387),
    [anon_sym___managed__] = ACTIONS(2387),
    [anon_sym___grid_constant__] = ACTIONS(2387),
    [anon_sym_alignas] = ACTIONS(2387),
    [anon_sym__Alignas] = ACTIONS(2387),
    [sym_primitive_type] = ACTIONS(2387),
    [anon_sym_enum] = ACTIONS(2387),
    [anon_sym_class] = ACTIONS(2387),
    [anon_sym_struct] = ACTIONS(2387),
    [anon_sym_union] = ACTIONS(2387),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2387),
    [anon_sym_decltype] = ACTIONS(2387),
    [anon_sym_explicit] = ACTIONS(2387),
    [anon_sym_typename] = ACTIONS(2387),
    [anon_sym_template] = ACTIONS(2387),
    [anon_sym_operator] = ACTIONS(2387),
    [anon_sym_friend] = ACTIONS(2387),
    [anon_sym_public] = ACTIONS(2387),
    [anon_sym_private] = ACTIONS(2387),
    [anon_sym_protected] = ACTIONS(2387),
    [anon_sym_using] = ACTIONS(2387),
    [anon_sym_static_assert] = ACTIONS(2387),
    [anon_sym___launch_bounds__] = ACTIONS(2387),
  },
  [STATE(2017)] = {
    [sym_identifier] = ACTIONS(2617),
    [aux_sym_preproc_def_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token1] = ACTIONS(2617),
    [aux_sym_preproc_if_token2] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2617),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2617),
    [sym_preproc_directive] = ACTIONS(2617),
    [anon_sym_LPAREN2] = ACTIONS(2619),
    [anon_sym_TILDE] = ACTIONS(2619),
    [anon_sym_STAR] = ACTIONS(2619),
    [anon_sym_AMP_AMP] = ACTIONS(2619),
    [anon_sym_AMP] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2619),
    [anon_sym___extension__] = ACTIONS(2617),
    [anon_sym_typedef] = ACTIONS(2617),
    [anon_sym___device__] = ACTIONS(2617),
    [anon_sym___host__] = ACTIONS(2617),
    [anon_sym___global__] = ACTIONS(2617),
    [anon_sym___forceinline__] = ACTIONS(2617),
    [anon_sym___noinline__] = ACTIONS(2617),
    [anon_sym_virtual] = ACTIONS(2617),
    [anon_sym_extern] = ACTIONS(2617),
    [anon_sym___attribute__] = ACTIONS(2617),
    [anon_sym___attribute] = ACTIONS(2617),
    [anon_sym_COLON_COLON] = ACTIONS(2619),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2619),
    [anon_sym___declspec] = ACTIONS(2617),
    [anon_sym___based] = ACTIONS(2617),
    [anon_sym_signed] = ACTIONS(2617),
    [anon_sym_unsigned] = ACTIONS(2617),
    [anon_sym_long] = ACTIONS(2617),
    [anon_sym_short] = ACTIONS(2617),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2617),
    [anon_sym_register] = ACTIONS(2617),
    [anon_sym_inline] = ACTIONS(2617),
    [anon_sym___inline] = ACTIONS(2617),
    [anon_sym___inline__] = ACTIONS(2617),
    [anon_sym___forceinline] = ACTIONS(2617),
    [anon_sym_thread_local] = ACTIONS(2617),
    [anon_sym___thread] = ACTIONS(2617),
    [anon_sym_const] = ACTIONS(2617),
    [anon_sym_constexpr] = ACTIONS(2617),
    [anon_sym_volatile] = ACTIONS(2617),
    [anon_sym_restrict] = ACTIONS(2617),
    [anon_sym___restrict__] = ACTIONS(2617),
    [anon_sym__Atomic] = ACTIONS(2617),
    [anon_sym__Noreturn] = ACTIONS(2617),
    [anon_sym_noreturn] = ACTIONS(2617),
    [anon_sym__Nonnull] = ACTIONS(2617),
    [anon_sym_mutable] = ACTIONS(2617),
    [anon_sym_constinit] = ACTIONS(2617),
    [anon_sym_consteval] = ACTIONS(2617),
    [anon_sym___shared__] = ACTIONS(2617),
    [anon_sym___local__] = ACTIONS(2617),
    [anon_sym___constant__] = ACTIONS(2617),
    [anon_sym___managed__] = ACTIONS(2617),
    [anon_sym___grid_constant__] = ACTIONS(2617),
    [anon_sym_alignas] = ACTIONS(2617),
    [anon_sym__Alignas] = ACTIONS(2617),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2617),
    [anon_sym_struct] = ACTIONS(2617),
    [anon_sym_union] = ACTIONS(2617),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2617),
    [anon_sym_decltype] = ACTIONS(2617),
    [anon_sym_explicit] = ACTIONS(2617),
    [anon_sym_typename] = ACTIONS(2617),
    [anon_sym_template] = ACTIONS(2617),
    [anon_sym_operator] = ACTIONS(2617),
    [anon_sym_friend] = ACTIONS(2617),
    [anon_sym_public] = ACTIONS(2617),
    [anon_sym_private] = ACTIONS(2617),
    [anon_sym_protected] = ACTIONS(2617),
    [anon_sym_using] = ACTIONS(2617),
    [anon_sym_static_assert] = ACTIONS(2617),
    [anon_sym___launch_bounds__] = ACTIONS(2617),
  },
  [STATE(2018)] = {
    [sym_template_argument_list] = STATE(1659),
    [sym_identifier] = ACTIONS(4512),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_TILDE] = ACTIONS(4519),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_PIPE_PIPE] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4512),
    [anon_sym_LT] = ACTIONS(5671),
    [anon_sym___extension__] = ACTIONS(4512),
    [anon_sym___device__] = ACTIONS(4512),
    [anon_sym___host__] = ACTIONS(4512),
    [anon_sym___global__] = ACTIONS(4512),
    [anon_sym___forceinline__] = ACTIONS(4512),
    [anon_sym___noinline__] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym___attribute__] = ACTIONS(4512),
    [anon_sym___attribute] = ACTIONS(4512),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4519),
    [anon_sym___declspec] = ACTIONS(4512),
    [anon_sym___based] = ACTIONS(4512),
    [anon_sym___cdecl] = ACTIONS(4512),
    [anon_sym___clrcall] = ACTIONS(4512),
    [anon_sym___stdcall] = ACTIONS(4512),
    [anon_sym___fastcall] = ACTIONS(4512),
    [anon_sym___thiscall] = ACTIONS(4512),
    [anon_sym___vectorcall] = ACTIONS(4512),
    [anon_sym_signed] = ACTIONS(4512),
    [anon_sym_unsigned] = ACTIONS(4512),
    [anon_sym_long] = ACTIONS(4512),
    [anon_sym_short] = ACTIONS(4512),
    [anon_sym_LBRACK] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_register] = ACTIONS(4512),
    [anon_sym_inline] = ACTIONS(4512),
    [anon_sym___inline] = ACTIONS(4512),
    [anon_sym___inline__] = ACTIONS(4512),
    [anon_sym___forceinline] = ACTIONS(4512),
    [anon_sym_thread_local] = ACTIONS(4512),
    [anon_sym___thread] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4512),
    [anon_sym_volatile] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym___restrict__] = ACTIONS(4512),
    [anon_sym__Atomic] = ACTIONS(4512),
    [anon_sym__Noreturn] = ACTIONS(4512),
    [anon_sym_noreturn] = ACTIONS(4512),
    [anon_sym__Nonnull] = ACTIONS(4512),
    [anon_sym_mutable] = ACTIONS(4512),
    [anon_sym_constinit] = ACTIONS(4512),
    [anon_sym_consteval] = ACTIONS(4512),
    [anon_sym___shared__] = ACTIONS(4512),
    [anon_sym___local__] = ACTIONS(4512),
    [anon_sym___constant__] = ACTIONS(4512),
    [anon_sym___managed__] = ACTIONS(4512),
    [anon_sym___grid_constant__] = ACTIONS(4512),
    [anon_sym_alignas] = ACTIONS(4512),
    [anon_sym__Alignas] = ACTIONS(4512),
    [sym_primitive_type] = ACTIONS(4512),
    [anon_sym_enum] = ACTIONS(4512),
    [anon_sym_class] = ACTIONS(4512),
    [anon_sym_struct] = ACTIONS(4512),
    [anon_sym_union] = ACTIONS(4512),
    [anon_sym_or] = ACTIONS(4512),
    [anon_sym_and] = ACTIONS(4512),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4512),
    [anon_sym_decltype] = ACTIONS(4512),
    [anon_sym_explicit] = ACTIONS(4512),
    [anon_sym_typename] = ACTIONS(4512),
    [anon_sym_template] = ACTIONS(4512),
    [anon_sym_operator] = ACTIONS(4512),
    [anon_sym_friend] = ACTIONS(4512),
    [anon_sym_using] = ACTIONS(4512),
    [anon_sym_concept] = ACTIONS(4512),
    [anon_sym___launch_bounds__] = ACTIONS(4512),
  },
  [STATE(2019)] = {
    [sym_identifier] = ACTIONS(5557),
    [aux_sym_preproc_def_token1] = ACTIONS(5557),
    [aux_sym_preproc_if_token1] = ACTIONS(5557),
    [aux_sym_preproc_if_token2] = ACTIONS(5557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5557),
    [sym_preproc_directive] = ACTIONS(5557),
    [anon_sym_LPAREN2] = ACTIONS(5559),
    [anon_sym_TILDE] = ACTIONS(5559),
    [anon_sym_STAR] = ACTIONS(5559),
    [anon_sym_AMP_AMP] = ACTIONS(5559),
    [anon_sym_AMP] = ACTIONS(5557),
    [anon_sym_SEMI] = ACTIONS(5559),
    [anon_sym___extension__] = ACTIONS(5557),
    [anon_sym_typedef] = ACTIONS(5557),
    [anon_sym___device__] = ACTIONS(5557),
    [anon_sym___host__] = ACTIONS(5557),
    [anon_sym___global__] = ACTIONS(5557),
    [anon_sym___forceinline__] = ACTIONS(5557),
    [anon_sym___noinline__] = ACTIONS(5557),
    [anon_sym_virtual] = ACTIONS(5557),
    [anon_sym_extern] = ACTIONS(5557),
    [anon_sym___attribute__] = ACTIONS(5557),
    [anon_sym___attribute] = ACTIONS(5557),
    [anon_sym_COLON_COLON] = ACTIONS(5559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5559),
    [anon_sym___declspec] = ACTIONS(5557),
    [anon_sym___based] = ACTIONS(5557),
    [anon_sym_signed] = ACTIONS(5557),
    [anon_sym_unsigned] = ACTIONS(5557),
    [anon_sym_long] = ACTIONS(5557),
    [anon_sym_short] = ACTIONS(5557),
    [anon_sym_LBRACK] = ACTIONS(5557),
    [anon_sym_static] = ACTIONS(5557),
    [anon_sym_register] = ACTIONS(5557),
    [anon_sym_inline] = ACTIONS(5557),
    [anon_sym___inline] = ACTIONS(5557),
    [anon_sym___inline__] = ACTIONS(5557),
    [anon_sym___forceinline] = ACTIONS(5557),
    [anon_sym_thread_local] = ACTIONS(5557),
    [anon_sym___thread] = ACTIONS(5557),
    [anon_sym_const] = ACTIONS(5557),
    [anon_sym_constexpr] = ACTIONS(5557),
    [anon_sym_volatile] = ACTIONS(5557),
    [anon_sym_restrict] = ACTIONS(5557),
    [anon_sym___restrict__] = ACTIONS(5557),
    [anon_sym__Atomic] = ACTIONS(5557),
    [anon_sym__Noreturn] = ACTIONS(5557),
    [anon_sym_noreturn] = ACTIONS(5557),
    [anon_sym__Nonnull] = ACTIONS(5557),
    [anon_sym_mutable] = ACTIONS(5557),
    [anon_sym_constinit] = ACTIONS(5557),
    [anon_sym_consteval] = ACTIONS(5557),
    [anon_sym___shared__] = ACTIONS(5557),
    [anon_sym___local__] = ACTIONS(5557),
    [anon_sym___constant__] = ACTIONS(5557),
    [anon_sym___managed__] = ACTIONS(5557),
    [anon_sym___grid_constant__] = ACTIONS(5557),
    [anon_sym_alignas] = ACTIONS(5557),
    [anon_sym__Alignas] = ACTIONS(5557),
    [sym_primitive_type] = ACTIONS(5557),
    [anon_sym_enum] = ACTIONS(5557),
    [anon_sym_class] = ACTIONS(5557),
    [anon_sym_struct] = ACTIONS(5557),
    [anon_sym_union] = ACTIONS(5557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5557),
    [anon_sym_decltype] = ACTIONS(5557),
    [anon_sym_explicit] = ACTIONS(5557),
    [anon_sym_typename] = ACTIONS(5557),
    [anon_sym_template] = ACTIONS(5557),
    [anon_sym_operator] = ACTIONS(5557),
    [anon_sym_friend] = ACTIONS(5557),
    [anon_sym_public] = ACTIONS(5557),
    [anon_sym_private] = ACTIONS(5557),
    [anon_sym_protected] = ACTIONS(5557),
    [anon_sym_using] = ACTIONS(5557),
    [anon_sym_static_assert] = ACTIONS(5557),
    [anon_sym___launch_bounds__] = ACTIONS(5557),
  },
  [STATE(2020)] = {
    [sym_identifier] = ACTIONS(2467),
    [aux_sym_preproc_def_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token1] = ACTIONS(2467),
    [aux_sym_preproc_if_token2] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2467),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2467),
    [sym_preproc_directive] = ACTIONS(2467),
    [anon_sym_LPAREN2] = ACTIONS(2469),
    [anon_sym_TILDE] = ACTIONS(2469),
    [anon_sym_STAR] = ACTIONS(2469),
    [anon_sym_AMP_AMP] = ACTIONS(2469),
    [anon_sym_AMP] = ACTIONS(2467),
    [anon_sym_SEMI] = ACTIONS(2469),
    [anon_sym___extension__] = ACTIONS(2467),
    [anon_sym_typedef] = ACTIONS(2467),
    [anon_sym___device__] = ACTIONS(2467),
    [anon_sym___host__] = ACTIONS(2467),
    [anon_sym___global__] = ACTIONS(2467),
    [anon_sym___forceinline__] = ACTIONS(2467),
    [anon_sym___noinline__] = ACTIONS(2467),
    [anon_sym_virtual] = ACTIONS(2467),
    [anon_sym_extern] = ACTIONS(2467),
    [anon_sym___attribute__] = ACTIONS(2467),
    [anon_sym___attribute] = ACTIONS(2467),
    [anon_sym_COLON_COLON] = ACTIONS(2469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2469),
    [anon_sym___declspec] = ACTIONS(2467),
    [anon_sym___based] = ACTIONS(2467),
    [anon_sym_signed] = ACTIONS(2467),
    [anon_sym_unsigned] = ACTIONS(2467),
    [anon_sym_long] = ACTIONS(2467),
    [anon_sym_short] = ACTIONS(2467),
    [anon_sym_LBRACK] = ACTIONS(2467),
    [anon_sym_static] = ACTIONS(2467),
    [anon_sym_register] = ACTIONS(2467),
    [anon_sym_inline] = ACTIONS(2467),
    [anon_sym___inline] = ACTIONS(2467),
    [anon_sym___inline__] = ACTIONS(2467),
    [anon_sym___forceinline] = ACTIONS(2467),
    [anon_sym_thread_local] = ACTIONS(2467),
    [anon_sym___thread] = ACTIONS(2467),
    [anon_sym_const] = ACTIONS(2467),
    [anon_sym_constexpr] = ACTIONS(2467),
    [anon_sym_volatile] = ACTIONS(2467),
    [anon_sym_restrict] = ACTIONS(2467),
    [anon_sym___restrict__] = ACTIONS(2467),
    [anon_sym__Atomic] = ACTIONS(2467),
    [anon_sym__Noreturn] = ACTIONS(2467),
    [anon_sym_noreturn] = ACTIONS(2467),
    [anon_sym__Nonnull] = ACTIONS(2467),
    [anon_sym_mutable] = ACTIONS(2467),
    [anon_sym_constinit] = ACTIONS(2467),
    [anon_sym_consteval] = ACTIONS(2467),
    [anon_sym___shared__] = ACTIONS(2467),
    [anon_sym___local__] = ACTIONS(2467),
    [anon_sym___constant__] = ACTIONS(2467),
    [anon_sym___managed__] = ACTIONS(2467),
    [anon_sym___grid_constant__] = ACTIONS(2467),
    [anon_sym_alignas] = ACTIONS(2467),
    [anon_sym__Alignas] = ACTIONS(2467),
    [sym_primitive_type] = ACTIONS(2467),
    [anon_sym_enum] = ACTIONS(2467),
    [anon_sym_class] = ACTIONS(2467),
    [anon_sym_struct] = ACTIONS(2467),
    [anon_sym_union] = ACTIONS(2467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2467),
    [anon_sym_decltype] = ACTIONS(2467),
    [anon_sym_explicit] = ACTIONS(2467),
    [anon_sym_typename] = ACTIONS(2467),
    [anon_sym_template] = ACTIONS(2467),
    [anon_sym_operator] = ACTIONS(2467),
    [anon_sym_friend] = ACTIONS(2467),
    [anon_sym_public] = ACTIONS(2467),
    [anon_sym_private] = ACTIONS(2467),
    [anon_sym_protected] = ACTIONS(2467),
    [anon_sym_using] = ACTIONS(2467),
    [anon_sym_static_assert] = ACTIONS(2467),
    [anon_sym___launch_bounds__] = ACTIONS(2467),
  },
  [STATE(2021)] = {
    [sym_identifier] = ACTIONS(5615),
    [aux_sym_preproc_def_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token2] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5615),
    [sym_preproc_directive] = ACTIONS(5615),
    [anon_sym_LPAREN2] = ACTIONS(5617),
    [anon_sym_TILDE] = ACTIONS(5617),
    [anon_sym_STAR] = ACTIONS(5617),
    [anon_sym_AMP_AMP] = ACTIONS(5617),
    [anon_sym_AMP] = ACTIONS(5615),
    [anon_sym_SEMI] = ACTIONS(5617),
    [anon_sym___extension__] = ACTIONS(5615),
    [anon_sym_typedef] = ACTIONS(5615),
    [anon_sym___device__] = ACTIONS(5615),
    [anon_sym___host__] = ACTIONS(5615),
    [anon_sym___global__] = ACTIONS(5615),
    [anon_sym___forceinline__] = ACTIONS(5615),
    [anon_sym___noinline__] = ACTIONS(5615),
    [anon_sym_virtual] = ACTIONS(5615),
    [anon_sym_extern] = ACTIONS(5615),
    [anon_sym___attribute__] = ACTIONS(5615),
    [anon_sym___attribute] = ACTIONS(5615),
    [anon_sym_COLON_COLON] = ACTIONS(5617),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5617),
    [anon_sym___declspec] = ACTIONS(5615),
    [anon_sym___based] = ACTIONS(5615),
    [anon_sym_signed] = ACTIONS(5615),
    [anon_sym_unsigned] = ACTIONS(5615),
    [anon_sym_long] = ACTIONS(5615),
    [anon_sym_short] = ACTIONS(5615),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [anon_sym_static] = ACTIONS(5615),
    [anon_sym_register] = ACTIONS(5615),
    [anon_sym_inline] = ACTIONS(5615),
    [anon_sym___inline] = ACTIONS(5615),
    [anon_sym___inline__] = ACTIONS(5615),
    [anon_sym___forceinline] = ACTIONS(5615),
    [anon_sym_thread_local] = ACTIONS(5615),
    [anon_sym___thread] = ACTIONS(5615),
    [anon_sym_const] = ACTIONS(5615),
    [anon_sym_constexpr] = ACTIONS(5615),
    [anon_sym_volatile] = ACTIONS(5615),
    [anon_sym_restrict] = ACTIONS(5615),
    [anon_sym___restrict__] = ACTIONS(5615),
    [anon_sym__Atomic] = ACTIONS(5615),
    [anon_sym__Noreturn] = ACTIONS(5615),
    [anon_sym_noreturn] = ACTIONS(5615),
    [anon_sym__Nonnull] = ACTIONS(5615),
    [anon_sym_mutable] = ACTIONS(5615),
    [anon_sym_constinit] = ACTIONS(5615),
    [anon_sym_consteval] = ACTIONS(5615),
    [anon_sym___shared__] = ACTIONS(5615),
    [anon_sym___local__] = ACTIONS(5615),
    [anon_sym___constant__] = ACTIONS(5615),
    [anon_sym___managed__] = ACTIONS(5615),
    [anon_sym___grid_constant__] = ACTIONS(5615),
    [anon_sym_alignas] = ACTIONS(5615),
    [anon_sym__Alignas] = ACTIONS(5615),
    [sym_primitive_type] = ACTIONS(5615),
    [anon_sym_enum] = ACTIONS(5615),
    [anon_sym_class] = ACTIONS(5615),
    [anon_sym_struct] = ACTIONS(5615),
    [anon_sym_union] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5615),
    [anon_sym_decltype] = ACTIONS(5615),
    [anon_sym_explicit] = ACTIONS(5615),
    [anon_sym_typename] = ACTIONS(5615),
    [anon_sym_template] = ACTIONS(5615),
    [anon_sym_operator] = ACTIONS(5615),
    [anon_sym_friend] = ACTIONS(5615),
    [anon_sym_public] = ACTIONS(5615),
    [anon_sym_private] = ACTIONS(5615),
    [anon_sym_protected] = ACTIONS(5615),
    [anon_sym_using] = ACTIONS(5615),
    [anon_sym_static_assert] = ACTIONS(5615),
    [anon_sym___launch_bounds__] = ACTIONS(5615),
  },
  [STATE(2022)] = {
    [sym_identifier] = ACTIONS(2513),
    [aux_sym_preproc_def_token1] = ACTIONS(2513),
    [aux_sym_preproc_if_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2513),
    [sym_preproc_directive] = ACTIONS(2513),
    [anon_sym_LPAREN2] = ACTIONS(2515),
    [anon_sym_TILDE] = ACTIONS(2515),
    [anon_sym_STAR] = ACTIONS(2515),
    [anon_sym_AMP_AMP] = ACTIONS(2515),
    [anon_sym_AMP] = ACTIONS(2513),
    [anon_sym_SEMI] = ACTIONS(2515),
    [anon_sym___extension__] = ACTIONS(2513),
    [anon_sym_typedef] = ACTIONS(2513),
    [anon_sym___device__] = ACTIONS(2513),
    [anon_sym___host__] = ACTIONS(2513),
    [anon_sym___global__] = ACTIONS(2513),
    [anon_sym___forceinline__] = ACTIONS(2513),
    [anon_sym___noinline__] = ACTIONS(2513),
    [anon_sym_virtual] = ACTIONS(2513),
    [anon_sym_extern] = ACTIONS(2513),
    [anon_sym___attribute__] = ACTIONS(2513),
    [anon_sym___attribute] = ACTIONS(2513),
    [anon_sym_COLON_COLON] = ACTIONS(2515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2515),
    [anon_sym___declspec] = ACTIONS(2513),
    [anon_sym___based] = ACTIONS(2513),
    [anon_sym_RBRACE] = ACTIONS(2515),
    [anon_sym_signed] = ACTIONS(2513),
    [anon_sym_unsigned] = ACTIONS(2513),
    [anon_sym_long] = ACTIONS(2513),
    [anon_sym_short] = ACTIONS(2513),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_static] = ACTIONS(2513),
    [anon_sym_register] = ACTIONS(2513),
    [anon_sym_inline] = ACTIONS(2513),
    [anon_sym___inline] = ACTIONS(2513),
    [anon_sym___inline__] = ACTIONS(2513),
    [anon_sym___forceinline] = ACTIONS(2513),
    [anon_sym_thread_local] = ACTIONS(2513),
    [anon_sym___thread] = ACTIONS(2513),
    [anon_sym_const] = ACTIONS(2513),
    [anon_sym_constexpr] = ACTIONS(2513),
    [anon_sym_volatile] = ACTIONS(2513),
    [anon_sym_restrict] = ACTIONS(2513),
    [anon_sym___restrict__] = ACTIONS(2513),
    [anon_sym__Atomic] = ACTIONS(2513),
    [anon_sym__Noreturn] = ACTIONS(2513),
    [anon_sym_noreturn] = ACTIONS(2513),
    [anon_sym__Nonnull] = ACTIONS(2513),
    [anon_sym_mutable] = ACTIONS(2513),
    [anon_sym_constinit] = ACTIONS(2513),
    [anon_sym_consteval] = ACTIONS(2513),
    [anon_sym___shared__] = ACTIONS(2513),
    [anon_sym___local__] = ACTIONS(2513),
    [anon_sym___constant__] = ACTIONS(2513),
    [anon_sym___managed__] = ACTIONS(2513),
    [anon_sym___grid_constant__] = ACTIONS(2513),
    [anon_sym_alignas] = ACTIONS(2513),
    [anon_sym__Alignas] = ACTIONS(2513),
    [sym_primitive_type] = ACTIONS(2513),
    [anon_sym_enum] = ACTIONS(2513),
    [anon_sym_class] = ACTIONS(2513),
    [anon_sym_struct] = ACTIONS(2513),
    [anon_sym_union] = ACTIONS(2513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2513),
    [anon_sym_decltype] = ACTIONS(2513),
    [anon_sym_explicit] = ACTIONS(2513),
    [anon_sym_typename] = ACTIONS(2513),
    [anon_sym_template] = ACTIONS(2513),
    [anon_sym_operator] = ACTIONS(2513),
    [anon_sym_friend] = ACTIONS(2513),
    [anon_sym_public] = ACTIONS(2513),
    [anon_sym_private] = ACTIONS(2513),
    [anon_sym_protected] = ACTIONS(2513),
    [anon_sym_using] = ACTIONS(2513),
    [anon_sym_static_assert] = ACTIONS(2513),
    [anon_sym___launch_bounds__] = ACTIONS(2513),
  },
  [STATE(2023)] = {
    [sym_identifier] = ACTIONS(2517),
    [aux_sym_preproc_def_token1] = ACTIONS(2517),
    [aux_sym_preproc_if_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2517),
    [sym_preproc_directive] = ACTIONS(2517),
    [anon_sym_LPAREN2] = ACTIONS(2519),
    [anon_sym_TILDE] = ACTIONS(2519),
    [anon_sym_STAR] = ACTIONS(2519),
    [anon_sym_AMP_AMP] = ACTIONS(2519),
    [anon_sym_AMP] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(2519),
    [anon_sym___extension__] = ACTIONS(2517),
    [anon_sym_typedef] = ACTIONS(2517),
    [anon_sym___device__] = ACTIONS(2517),
    [anon_sym___host__] = ACTIONS(2517),
    [anon_sym___global__] = ACTIONS(2517),
    [anon_sym___forceinline__] = ACTIONS(2517),
    [anon_sym___noinline__] = ACTIONS(2517),
    [anon_sym_virtual] = ACTIONS(2517),
    [anon_sym_extern] = ACTIONS(2517),
    [anon_sym___attribute__] = ACTIONS(2517),
    [anon_sym___attribute] = ACTIONS(2517),
    [anon_sym_COLON_COLON] = ACTIONS(2519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2519),
    [anon_sym___declspec] = ACTIONS(2517),
    [anon_sym___based] = ACTIONS(2517),
    [anon_sym_RBRACE] = ACTIONS(2519),
    [anon_sym_signed] = ACTIONS(2517),
    [anon_sym_unsigned] = ACTIONS(2517),
    [anon_sym_long] = ACTIONS(2517),
    [anon_sym_short] = ACTIONS(2517),
    [anon_sym_LBRACK] = ACTIONS(2517),
    [anon_sym_static] = ACTIONS(2517),
    [anon_sym_register] = ACTIONS(2517),
    [anon_sym_inline] = ACTIONS(2517),
    [anon_sym___inline] = ACTIONS(2517),
    [anon_sym___inline__] = ACTIONS(2517),
    [anon_sym___forceinline] = ACTIONS(2517),
    [anon_sym_thread_local] = ACTIONS(2517),
    [anon_sym___thread] = ACTIONS(2517),
    [anon_sym_const] = ACTIONS(2517),
    [anon_sym_constexpr] = ACTIONS(2517),
    [anon_sym_volatile] = ACTIONS(2517),
    [anon_sym_restrict] = ACTIONS(2517),
    [anon_sym___restrict__] = ACTIONS(2517),
    [anon_sym__Atomic] = ACTIONS(2517),
    [anon_sym__Noreturn] = ACTIONS(2517),
    [anon_sym_noreturn] = ACTIONS(2517),
    [anon_sym__Nonnull] = ACTIONS(2517),
    [anon_sym_mutable] = ACTIONS(2517),
    [anon_sym_constinit] = ACTIONS(2517),
    [anon_sym_consteval] = ACTIONS(2517),
    [anon_sym___shared__] = ACTIONS(2517),
    [anon_sym___local__] = ACTIONS(2517),
    [anon_sym___constant__] = ACTIONS(2517),
    [anon_sym___managed__] = ACTIONS(2517),
    [anon_sym___grid_constant__] = ACTIONS(2517),
    [anon_sym_alignas] = ACTIONS(2517),
    [anon_sym__Alignas] = ACTIONS(2517),
    [sym_primitive_type] = ACTIONS(2517),
    [anon_sym_enum] = ACTIONS(2517),
    [anon_sym_class] = ACTIONS(2517),
    [anon_sym_struct] = ACTIONS(2517),
    [anon_sym_union] = ACTIONS(2517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2517),
    [anon_sym_decltype] = ACTIONS(2517),
    [anon_sym_explicit] = ACTIONS(2517),
    [anon_sym_typename] = ACTIONS(2517),
    [anon_sym_template] = ACTIONS(2517),
    [anon_sym_operator] = ACTIONS(2517),
    [anon_sym_friend] = ACTIONS(2517),
    [anon_sym_public] = ACTIONS(2517),
    [anon_sym_private] = ACTIONS(2517),
    [anon_sym_protected] = ACTIONS(2517),
    [anon_sym_using] = ACTIONS(2517),
    [anon_sym_static_assert] = ACTIONS(2517),
    [anon_sym___launch_bounds__] = ACTIONS(2517),
  },
  [STATE(2024)] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token2] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym___device__] = ACTIONS(2565),
    [anon_sym___host__] = ACTIONS(2565),
    [anon_sym___global__] = ACTIONS(2565),
    [anon_sym___forceinline__] = ACTIONS(2565),
    [anon_sym___noinline__] = ACTIONS(2565),
    [anon_sym_virtual] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym___attribute] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym__Nonnull] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym___shared__] = ACTIONS(2565),
    [anon_sym___local__] = ACTIONS(2565),
    [anon_sym___constant__] = ACTIONS(2565),
    [anon_sym___managed__] = ACTIONS(2565),
    [anon_sym___grid_constant__] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_friend] = ACTIONS(2565),
    [anon_sym_public] = ACTIONS(2565),
    [anon_sym_private] = ACTIONS(2565),
    [anon_sym_protected] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym___launch_bounds__] = ACTIONS(2565),
  },
  [STATE(2025)] = {
    [sym_identifier] = ACTIONS(2226),
    [aux_sym_preproc_def_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token2] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2226),
    [sym_preproc_directive] = ACTIONS(2226),
    [anon_sym_LPAREN2] = ACTIONS(2228),
    [anon_sym_TILDE] = ACTIONS(2228),
    [anon_sym_STAR] = ACTIONS(2228),
    [anon_sym_AMP_AMP] = ACTIONS(2228),
    [anon_sym_AMP] = ACTIONS(2226),
    [anon_sym_SEMI] = ACTIONS(2228),
    [anon_sym___extension__] = ACTIONS(2226),
    [anon_sym_typedef] = ACTIONS(2226),
    [anon_sym___device__] = ACTIONS(2226),
    [anon_sym___host__] = ACTIONS(2226),
    [anon_sym___global__] = ACTIONS(2226),
    [anon_sym___forceinline__] = ACTIONS(2226),
    [anon_sym___noinline__] = ACTIONS(2226),
    [anon_sym_virtual] = ACTIONS(2226),
    [anon_sym_extern] = ACTIONS(2226),
    [anon_sym___attribute__] = ACTIONS(2226),
    [anon_sym___attribute] = ACTIONS(2226),
    [anon_sym_COLON_COLON] = ACTIONS(2228),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2228),
    [anon_sym___declspec] = ACTIONS(2226),
    [anon_sym___based] = ACTIONS(2226),
    [anon_sym_signed] = ACTIONS(2226),
    [anon_sym_unsigned] = ACTIONS(2226),
    [anon_sym_long] = ACTIONS(2226),
    [anon_sym_short] = ACTIONS(2226),
    [anon_sym_LBRACK] = ACTIONS(2226),
    [anon_sym_static] = ACTIONS(2226),
    [anon_sym_register] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(2226),
    [anon_sym___inline] = ACTIONS(2226),
    [anon_sym___inline__] = ACTIONS(2226),
    [anon_sym___forceinline] = ACTIONS(2226),
    [anon_sym_thread_local] = ACTIONS(2226),
    [anon_sym___thread] = ACTIONS(2226),
    [anon_sym_const] = ACTIONS(2226),
    [anon_sym_constexpr] = ACTIONS(2226),
    [anon_sym_volatile] = ACTIONS(2226),
    [anon_sym_restrict] = ACTIONS(2226),
    [anon_sym___restrict__] = ACTIONS(2226),
    [anon_sym__Atomic] = ACTIONS(2226),
    [anon_sym__Noreturn] = ACTIONS(2226),
    [anon_sym_noreturn] = ACTIONS(2226),
    [anon_sym__Nonnull] = ACTIONS(2226),
    [anon_sym_mutable] = ACTIONS(2226),
    [anon_sym_constinit] = ACTIONS(2226),
    [anon_sym_consteval] = ACTIONS(2226),
    [anon_sym___shared__] = ACTIONS(2226),
    [anon_sym___local__] = ACTIONS(2226),
    [anon_sym___constant__] = ACTIONS(2226),
    [anon_sym___managed__] = ACTIONS(2226),
    [anon_sym___grid_constant__] = ACTIONS(2226),
    [anon_sym_alignas] = ACTIONS(2226),
    [anon_sym__Alignas] = ACTIONS(2226),
    [sym_primitive_type] = ACTIONS(2226),
    [anon_sym_enum] = ACTIONS(2226),
    [anon_sym_class] = ACTIONS(2226),
    [anon_sym_struct] = ACTIONS(2226),
    [anon_sym_union] = ACTIONS(2226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2226),
    [anon_sym_decltype] = ACTIONS(2226),
    [anon_sym_explicit] = ACTIONS(2226),
    [anon_sym_typename] = ACTIONS(2226),
    [anon_sym_template] = ACTIONS(2226),
    [anon_sym_operator] = ACTIONS(2226),
    [anon_sym_friend] = ACTIONS(2226),
    [anon_sym_public] = ACTIONS(2226),
    [anon_sym_private] = ACTIONS(2226),
    [anon_sym_protected] = ACTIONS(2226),
    [anon_sym_using] = ACTIONS(2226),
    [anon_sym_static_assert] = ACTIONS(2226),
    [anon_sym___launch_bounds__] = ACTIONS(2226),
  },
  [STATE(2026)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token2] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_friend] = ACTIONS(2585),
    [anon_sym_public] = ACTIONS(2585),
    [anon_sym_private] = ACTIONS(2585),
    [anon_sym_protected] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(2027)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token2] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_friend] = ACTIONS(2585),
    [anon_sym_public] = ACTIONS(2585),
    [anon_sym_private] = ACTIONS(2585),
    [anon_sym_protected] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(2028)] = {
    [sym_identifier] = ACTIONS(5561),
    [aux_sym_preproc_def_token1] = ACTIONS(5561),
    [aux_sym_preproc_if_token1] = ACTIONS(5561),
    [aux_sym_preproc_if_token2] = ACTIONS(5561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5561),
    [sym_preproc_directive] = ACTIONS(5561),
    [anon_sym_LPAREN2] = ACTIONS(5563),
    [anon_sym_TILDE] = ACTIONS(5563),
    [anon_sym_STAR] = ACTIONS(5563),
    [anon_sym_AMP_AMP] = ACTIONS(5563),
    [anon_sym_AMP] = ACTIONS(5561),
    [anon_sym_SEMI] = ACTIONS(5563),
    [anon_sym___extension__] = ACTIONS(5561),
    [anon_sym_typedef] = ACTIONS(5561),
    [anon_sym___device__] = ACTIONS(5561),
    [anon_sym___host__] = ACTIONS(5561),
    [anon_sym___global__] = ACTIONS(5561),
    [anon_sym___forceinline__] = ACTIONS(5561),
    [anon_sym___noinline__] = ACTIONS(5561),
    [anon_sym_virtual] = ACTIONS(5561),
    [anon_sym_extern] = ACTIONS(5561),
    [anon_sym___attribute__] = ACTIONS(5561),
    [anon_sym___attribute] = ACTIONS(5561),
    [anon_sym_COLON_COLON] = ACTIONS(5563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5563),
    [anon_sym___declspec] = ACTIONS(5561),
    [anon_sym___based] = ACTIONS(5561),
    [anon_sym_signed] = ACTIONS(5561),
    [anon_sym_unsigned] = ACTIONS(5561),
    [anon_sym_long] = ACTIONS(5561),
    [anon_sym_short] = ACTIONS(5561),
    [anon_sym_LBRACK] = ACTIONS(5561),
    [anon_sym_static] = ACTIONS(5561),
    [anon_sym_register] = ACTIONS(5561),
    [anon_sym_inline] = ACTIONS(5561),
    [anon_sym___inline] = ACTIONS(5561),
    [anon_sym___inline__] = ACTIONS(5561),
    [anon_sym___forceinline] = ACTIONS(5561),
    [anon_sym_thread_local] = ACTIONS(5561),
    [anon_sym___thread] = ACTIONS(5561),
    [anon_sym_const] = ACTIONS(5561),
    [anon_sym_constexpr] = ACTIONS(5561),
    [anon_sym_volatile] = ACTIONS(5561),
    [anon_sym_restrict] = ACTIONS(5561),
    [anon_sym___restrict__] = ACTIONS(5561),
    [anon_sym__Atomic] = ACTIONS(5561),
    [anon_sym__Noreturn] = ACTIONS(5561),
    [anon_sym_noreturn] = ACTIONS(5561),
    [anon_sym__Nonnull] = ACTIONS(5561),
    [anon_sym_mutable] = ACTIONS(5561),
    [anon_sym_constinit] = ACTIONS(5561),
    [anon_sym_consteval] = ACTIONS(5561),
    [anon_sym___shared__] = ACTIONS(5561),
    [anon_sym___local__] = ACTIONS(5561),
    [anon_sym___constant__] = ACTIONS(5561),
    [anon_sym___managed__] = ACTIONS(5561),
    [anon_sym___grid_constant__] = ACTIONS(5561),
    [anon_sym_alignas] = ACTIONS(5561),
    [anon_sym__Alignas] = ACTIONS(5561),
    [sym_primitive_type] = ACTIONS(5561),
    [anon_sym_enum] = ACTIONS(5561),
    [anon_sym_class] = ACTIONS(5561),
    [anon_sym_struct] = ACTIONS(5561),
    [anon_sym_union] = ACTIONS(5561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5561),
    [anon_sym_decltype] = ACTIONS(5561),
    [anon_sym_explicit] = ACTIONS(5561),
    [anon_sym_typename] = ACTIONS(5561),
    [anon_sym_template] = ACTIONS(5561),
    [anon_sym_operator] = ACTIONS(5561),
    [anon_sym_friend] = ACTIONS(5561),
    [anon_sym_public] = ACTIONS(5561),
    [anon_sym_private] = ACTIONS(5561),
    [anon_sym_protected] = ACTIONS(5561),
    [anon_sym_using] = ACTIONS(5561),
    [anon_sym_static_assert] = ACTIONS(5561),
    [anon_sym___launch_bounds__] = ACTIONS(5561),
  },
  [STATE(2029)] = {
    [sym_identifier] = ACTIONS(5577),
    [aux_sym_preproc_def_token1] = ACTIONS(5577),
    [aux_sym_preproc_if_token1] = ACTIONS(5577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5577),
    [sym_preproc_directive] = ACTIONS(5577),
    [anon_sym_LPAREN2] = ACTIONS(5579),
    [anon_sym_TILDE] = ACTIONS(5579),
    [anon_sym_STAR] = ACTIONS(5579),
    [anon_sym_AMP_AMP] = ACTIONS(5579),
    [anon_sym_AMP] = ACTIONS(5577),
    [anon_sym_SEMI] = ACTIONS(5579),
    [anon_sym___extension__] = ACTIONS(5577),
    [anon_sym_typedef] = ACTIONS(5577),
    [anon_sym___device__] = ACTIONS(5577),
    [anon_sym___host__] = ACTIONS(5577),
    [anon_sym___global__] = ACTIONS(5577),
    [anon_sym___forceinline__] = ACTIONS(5577),
    [anon_sym___noinline__] = ACTIONS(5577),
    [anon_sym_virtual] = ACTIONS(5577),
    [anon_sym_extern] = ACTIONS(5577),
    [anon_sym___attribute__] = ACTIONS(5577),
    [anon_sym___attribute] = ACTIONS(5577),
    [anon_sym_COLON_COLON] = ACTIONS(5579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5579),
    [anon_sym___declspec] = ACTIONS(5577),
    [anon_sym___based] = ACTIONS(5577),
    [anon_sym_RBRACE] = ACTIONS(5579),
    [anon_sym_signed] = ACTIONS(5577),
    [anon_sym_unsigned] = ACTIONS(5577),
    [anon_sym_long] = ACTIONS(5577),
    [anon_sym_short] = ACTIONS(5577),
    [anon_sym_LBRACK] = ACTIONS(5577),
    [anon_sym_static] = ACTIONS(5577),
    [anon_sym_register] = ACTIONS(5577),
    [anon_sym_inline] = ACTIONS(5577),
    [anon_sym___inline] = ACTIONS(5577),
    [anon_sym___inline__] = ACTIONS(5577),
    [anon_sym___forceinline] = ACTIONS(5577),
    [anon_sym_thread_local] = ACTIONS(5577),
    [anon_sym___thread] = ACTIONS(5577),
    [anon_sym_const] = ACTIONS(5577),
    [anon_sym_constexpr] = ACTIONS(5577),
    [anon_sym_volatile] = ACTIONS(5577),
    [anon_sym_restrict] = ACTIONS(5577),
    [anon_sym___restrict__] = ACTIONS(5577),
    [anon_sym__Atomic] = ACTIONS(5577),
    [anon_sym__Noreturn] = ACTIONS(5577),
    [anon_sym_noreturn] = ACTIONS(5577),
    [anon_sym__Nonnull] = ACTIONS(5577),
    [anon_sym_mutable] = ACTIONS(5577),
    [anon_sym_constinit] = ACTIONS(5577),
    [anon_sym_consteval] = ACTIONS(5577),
    [anon_sym___shared__] = ACTIONS(5577),
    [anon_sym___local__] = ACTIONS(5577),
    [anon_sym___constant__] = ACTIONS(5577),
    [anon_sym___managed__] = ACTIONS(5577),
    [anon_sym___grid_constant__] = ACTIONS(5577),
    [anon_sym_alignas] = ACTIONS(5577),
    [anon_sym__Alignas] = ACTIONS(5577),
    [sym_primitive_type] = ACTIONS(5577),
    [anon_sym_enum] = ACTIONS(5577),
    [anon_sym_class] = ACTIONS(5577),
    [anon_sym_struct] = ACTIONS(5577),
    [anon_sym_union] = ACTIONS(5577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5577),
    [anon_sym_decltype] = ACTIONS(5577),
    [anon_sym_explicit] = ACTIONS(5577),
    [anon_sym_typename] = ACTIONS(5577),
    [anon_sym_template] = ACTIONS(5577),
    [anon_sym_operator] = ACTIONS(5577),
    [anon_sym_friend] = ACTIONS(5577),
    [anon_sym_public] = ACTIONS(5577),
    [anon_sym_private] = ACTIONS(5577),
    [anon_sym_protected] = ACTIONS(5577),
    [anon_sym_using] = ACTIONS(5577),
    [anon_sym_static_assert] = ACTIONS(5577),
    [anon_sym___launch_bounds__] = ACTIONS(5577),
  },
  [STATE(2030)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_RBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(2031)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(2032)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(2033)] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token2] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym___device__] = ACTIONS(2328),
    [anon_sym___host__] = ACTIONS(2328),
    [anon_sym___global__] = ACTIONS(2328),
    [anon_sym___forceinline__] = ACTIONS(2328),
    [anon_sym___noinline__] = ACTIONS(2328),
    [anon_sym_virtual] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym___attribute] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym__Nonnull] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym___shared__] = ACTIONS(2328),
    [anon_sym___local__] = ACTIONS(2328),
    [anon_sym___constant__] = ACTIONS(2328),
    [anon_sym___managed__] = ACTIONS(2328),
    [anon_sym___grid_constant__] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_friend] = ACTIONS(2328),
    [anon_sym_public] = ACTIONS(2328),
    [anon_sym_private] = ACTIONS(2328),
    [anon_sym_protected] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym___launch_bounds__] = ACTIONS(2328),
  },
  [STATE(2034)] = {
    [sym_identifier] = ACTIONS(2230),
    [aux_sym_preproc_def_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token1] = ACTIONS(2230),
    [aux_sym_preproc_if_token2] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2230),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2230),
    [sym_preproc_directive] = ACTIONS(2230),
    [anon_sym_LPAREN2] = ACTIONS(2232),
    [anon_sym_TILDE] = ACTIONS(2232),
    [anon_sym_STAR] = ACTIONS(2232),
    [anon_sym_AMP_AMP] = ACTIONS(2232),
    [anon_sym_AMP] = ACTIONS(2230),
    [anon_sym_SEMI] = ACTIONS(2232),
    [anon_sym___extension__] = ACTIONS(2230),
    [anon_sym_typedef] = ACTIONS(2230),
    [anon_sym___device__] = ACTIONS(2230),
    [anon_sym___host__] = ACTIONS(2230),
    [anon_sym___global__] = ACTIONS(2230),
    [anon_sym___forceinline__] = ACTIONS(2230),
    [anon_sym___noinline__] = ACTIONS(2230),
    [anon_sym_virtual] = ACTIONS(2230),
    [anon_sym_extern] = ACTIONS(2230),
    [anon_sym___attribute__] = ACTIONS(2230),
    [anon_sym___attribute] = ACTIONS(2230),
    [anon_sym_COLON_COLON] = ACTIONS(2232),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2232),
    [anon_sym___declspec] = ACTIONS(2230),
    [anon_sym___based] = ACTIONS(2230),
    [anon_sym_signed] = ACTIONS(2230),
    [anon_sym_unsigned] = ACTIONS(2230),
    [anon_sym_long] = ACTIONS(2230),
    [anon_sym_short] = ACTIONS(2230),
    [anon_sym_LBRACK] = ACTIONS(2230),
    [anon_sym_static] = ACTIONS(2230),
    [anon_sym_register] = ACTIONS(2230),
    [anon_sym_inline] = ACTIONS(2230),
    [anon_sym___inline] = ACTIONS(2230),
    [anon_sym___inline__] = ACTIONS(2230),
    [anon_sym___forceinline] = ACTIONS(2230),
    [anon_sym_thread_local] = ACTIONS(2230),
    [anon_sym___thread] = ACTIONS(2230),
    [anon_sym_const] = ACTIONS(2230),
    [anon_sym_constexpr] = ACTIONS(2230),
    [anon_sym_volatile] = ACTIONS(2230),
    [anon_sym_restrict] = ACTIONS(2230),
    [anon_sym___restrict__] = ACTIONS(2230),
    [anon_sym__Atomic] = ACTIONS(2230),
    [anon_sym__Noreturn] = ACTIONS(2230),
    [anon_sym_noreturn] = ACTIONS(2230),
    [anon_sym__Nonnull] = ACTIONS(2230),
    [anon_sym_mutable] = ACTIONS(2230),
    [anon_sym_constinit] = ACTIONS(2230),
    [anon_sym_consteval] = ACTIONS(2230),
    [anon_sym___shared__] = ACTIONS(2230),
    [anon_sym___local__] = ACTIONS(2230),
    [anon_sym___constant__] = ACTIONS(2230),
    [anon_sym___managed__] = ACTIONS(2230),
    [anon_sym___grid_constant__] = ACTIONS(2230),
    [anon_sym_alignas] = ACTIONS(2230),
    [anon_sym__Alignas] = ACTIONS(2230),
    [sym_primitive_type] = ACTIONS(2230),
    [anon_sym_enum] = ACTIONS(2230),
    [anon_sym_class] = ACTIONS(2230),
    [anon_sym_struct] = ACTIONS(2230),
    [anon_sym_union] = ACTIONS(2230),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2230),
    [anon_sym_decltype] = ACTIONS(2230),
    [anon_sym_explicit] = ACTIONS(2230),
    [anon_sym_typename] = ACTIONS(2230),
    [anon_sym_template] = ACTIONS(2230),
    [anon_sym_operator] = ACTIONS(2230),
    [anon_sym_friend] = ACTIONS(2230),
    [anon_sym_public] = ACTIONS(2230),
    [anon_sym_private] = ACTIONS(2230),
    [anon_sym_protected] = ACTIONS(2230),
    [anon_sym_using] = ACTIONS(2230),
    [anon_sym_static_assert] = ACTIONS(2230),
    [anon_sym___launch_bounds__] = ACTIONS(2230),
  },
  [STATE(2035)] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token2] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym___device__] = ACTIONS(2316),
    [anon_sym___host__] = ACTIONS(2316),
    [anon_sym___global__] = ACTIONS(2316),
    [anon_sym___forceinline__] = ACTIONS(2316),
    [anon_sym___noinline__] = ACTIONS(2316),
    [anon_sym_virtual] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym___attribute] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym__Nonnull] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym___shared__] = ACTIONS(2316),
    [anon_sym___local__] = ACTIONS(2316),
    [anon_sym___constant__] = ACTIONS(2316),
    [anon_sym___managed__] = ACTIONS(2316),
    [anon_sym___grid_constant__] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_friend] = ACTIONS(2316),
    [anon_sym_public] = ACTIONS(2316),
    [anon_sym_private] = ACTIONS(2316),
    [anon_sym_protected] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym___launch_bounds__] = ACTIONS(2316),
  },
  [STATE(2036)] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym___device__] = ACTIONS(2312),
    [anon_sym___host__] = ACTIONS(2312),
    [anon_sym___global__] = ACTIONS(2312),
    [anon_sym___forceinline__] = ACTIONS(2312),
    [anon_sym___noinline__] = ACTIONS(2312),
    [anon_sym_virtual] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym___attribute] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_RBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym__Nonnull] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym___shared__] = ACTIONS(2312),
    [anon_sym___local__] = ACTIONS(2312),
    [anon_sym___constant__] = ACTIONS(2312),
    [anon_sym___managed__] = ACTIONS(2312),
    [anon_sym___grid_constant__] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym___launch_bounds__] = ACTIONS(2312),
  },
  [STATE(2037)] = {
    [sym_identifier] = ACTIONS(3830),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3832),
    [anon_sym_COMMA] = ACTIONS(3832),
    [anon_sym_RPAREN] = ACTIONS(3832),
    [anon_sym_LPAREN2] = ACTIONS(3832),
    [anon_sym_TILDE] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_AMP_AMP] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3830),
    [anon_sym_SEMI] = ACTIONS(3832),
    [anon_sym___extension__] = ACTIONS(3830),
    [anon_sym___device__] = ACTIONS(3830),
    [anon_sym___host__] = ACTIONS(3830),
    [anon_sym___global__] = ACTIONS(3830),
    [anon_sym___forceinline__] = ACTIONS(3830),
    [anon_sym___noinline__] = ACTIONS(3830),
    [anon_sym_virtual] = ACTIONS(3830),
    [anon_sym_extern] = ACTIONS(3830),
    [anon_sym___attribute__] = ACTIONS(3830),
    [anon_sym___attribute] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(3832),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3832),
    [anon_sym___declspec] = ACTIONS(3830),
    [anon_sym___based] = ACTIONS(3830),
    [anon_sym___cdecl] = ACTIONS(3830),
    [anon_sym___clrcall] = ACTIONS(3830),
    [anon_sym___stdcall] = ACTIONS(3830),
    [anon_sym___fastcall] = ACTIONS(3830),
    [anon_sym___thiscall] = ACTIONS(3830),
    [anon_sym___vectorcall] = ACTIONS(3830),
    [anon_sym_LBRACE] = ACTIONS(3832),
    [anon_sym_LBRACK] = ACTIONS(3830),
    [anon_sym_static] = ACTIONS(3830),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_register] = ACTIONS(3830),
    [anon_sym_inline] = ACTIONS(3830),
    [anon_sym___inline] = ACTIONS(3830),
    [anon_sym___inline__] = ACTIONS(3830),
    [anon_sym___forceinline] = ACTIONS(3830),
    [anon_sym_thread_local] = ACTIONS(3830),
    [anon_sym___thread] = ACTIONS(3830),
    [anon_sym_const] = ACTIONS(3830),
    [anon_sym_constexpr] = ACTIONS(3830),
    [anon_sym_volatile] = ACTIONS(3830),
    [anon_sym_restrict] = ACTIONS(3830),
    [anon_sym___restrict__] = ACTIONS(3830),
    [anon_sym__Atomic] = ACTIONS(3830),
    [anon_sym__Noreturn] = ACTIONS(3830),
    [anon_sym_noreturn] = ACTIONS(3830),
    [anon_sym__Nonnull] = ACTIONS(3830),
    [anon_sym_mutable] = ACTIONS(3830),
    [anon_sym_constinit] = ACTIONS(3830),
    [anon_sym_consteval] = ACTIONS(3830),
    [anon_sym___shared__] = ACTIONS(3830),
    [anon_sym___local__] = ACTIONS(3830),
    [anon_sym___constant__] = ACTIONS(3830),
    [anon_sym___managed__] = ACTIONS(3830),
    [anon_sym___grid_constant__] = ACTIONS(3830),
    [anon_sym_alignas] = ACTIONS(3830),
    [anon_sym__Alignas] = ACTIONS(3830),
    [anon_sym_COLON] = ACTIONS(3830),
    [anon_sym_asm] = ACTIONS(3830),
    [anon_sym___asm__] = ACTIONS(3830),
    [anon_sym___asm] = ACTIONS(3830),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3830),
    [anon_sym_final] = ACTIONS(3830),
    [anon_sym_override] = ACTIONS(3830),
    [anon_sym_explicit] = ACTIONS(3830),
    [anon_sym_template] = ACTIONS(3830),
    [anon_sym_GT2] = ACTIONS(3832),
    [anon_sym_operator] = ACTIONS(3830),
    [anon_sym_try] = ACTIONS(3830),
    [anon_sym_public] = ACTIONS(3830),
    [anon_sym_private] = ACTIONS(3830),
    [anon_sym_protected] = ACTIONS(3830),
    [anon_sym_requires] = ACTIONS(3830),
    [anon_sym___launch_bounds__] = ACTIONS(3830),
  },
  [STATE(2038)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token2] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(2039)] = {
    [sym_identifier] = ACTIONS(2431),
    [aux_sym_preproc_def_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token1] = ACTIONS(2431),
    [aux_sym_preproc_if_token2] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2431),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2431),
    [sym_preproc_directive] = ACTIONS(2431),
    [anon_sym_LPAREN2] = ACTIONS(2433),
    [anon_sym_TILDE] = ACTIONS(2433),
    [anon_sym_STAR] = ACTIONS(2433),
    [anon_sym_AMP_AMP] = ACTIONS(2433),
    [anon_sym_AMP] = ACTIONS(2431),
    [anon_sym_SEMI] = ACTIONS(2433),
    [anon_sym___extension__] = ACTIONS(2431),
    [anon_sym_typedef] = ACTIONS(2431),
    [anon_sym___device__] = ACTIONS(2431),
    [anon_sym___host__] = ACTIONS(2431),
    [anon_sym___global__] = ACTIONS(2431),
    [anon_sym___forceinline__] = ACTIONS(2431),
    [anon_sym___noinline__] = ACTIONS(2431),
    [anon_sym_virtual] = ACTIONS(2431),
    [anon_sym_extern] = ACTIONS(2431),
    [anon_sym___attribute__] = ACTIONS(2431),
    [anon_sym___attribute] = ACTIONS(2431),
    [anon_sym_COLON_COLON] = ACTIONS(2433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2433),
    [anon_sym___declspec] = ACTIONS(2431),
    [anon_sym___based] = ACTIONS(2431),
    [anon_sym_signed] = ACTIONS(2431),
    [anon_sym_unsigned] = ACTIONS(2431),
    [anon_sym_long] = ACTIONS(2431),
    [anon_sym_short] = ACTIONS(2431),
    [anon_sym_LBRACK] = ACTIONS(2431),
    [anon_sym_static] = ACTIONS(2431),
    [anon_sym_register] = ACTIONS(2431),
    [anon_sym_inline] = ACTIONS(2431),
    [anon_sym___inline] = ACTIONS(2431),
    [anon_sym___inline__] = ACTIONS(2431),
    [anon_sym___forceinline] = ACTIONS(2431),
    [anon_sym_thread_local] = ACTIONS(2431),
    [anon_sym___thread] = ACTIONS(2431),
    [anon_sym_const] = ACTIONS(2431),
    [anon_sym_constexpr] = ACTIONS(2431),
    [anon_sym_volatile] = ACTIONS(2431),
    [anon_sym_restrict] = ACTIONS(2431),
    [anon_sym___restrict__] = ACTIONS(2431),
    [anon_sym__Atomic] = ACTIONS(2431),
    [anon_sym__Noreturn] = ACTIONS(2431),
    [anon_sym_noreturn] = ACTIONS(2431),
    [anon_sym__Nonnull] = ACTIONS(2431),
    [anon_sym_mutable] = ACTIONS(2431),
    [anon_sym_constinit] = ACTIONS(2431),
    [anon_sym_consteval] = ACTIONS(2431),
    [anon_sym___shared__] = ACTIONS(2431),
    [anon_sym___local__] = ACTIONS(2431),
    [anon_sym___constant__] = ACTIONS(2431),
    [anon_sym___managed__] = ACTIONS(2431),
    [anon_sym___grid_constant__] = ACTIONS(2431),
    [anon_sym_alignas] = ACTIONS(2431),
    [anon_sym__Alignas] = ACTIONS(2431),
    [sym_primitive_type] = ACTIONS(2431),
    [anon_sym_enum] = ACTIONS(2431),
    [anon_sym_class] = ACTIONS(2431),
    [anon_sym_struct] = ACTIONS(2431),
    [anon_sym_union] = ACTIONS(2431),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2431),
    [anon_sym_decltype] = ACTIONS(2431),
    [anon_sym_explicit] = ACTIONS(2431),
    [anon_sym_typename] = ACTIONS(2431),
    [anon_sym_template] = ACTIONS(2431),
    [anon_sym_operator] = ACTIONS(2431),
    [anon_sym_friend] = ACTIONS(2431),
    [anon_sym_public] = ACTIONS(2431),
    [anon_sym_private] = ACTIONS(2431),
    [anon_sym_protected] = ACTIONS(2431),
    [anon_sym_using] = ACTIONS(2431),
    [anon_sym_static_assert] = ACTIONS(2431),
    [anon_sym___launch_bounds__] = ACTIONS(2431),
  },
  [STATE(2040)] = {
    [sym_identifier] = ACTIONS(5565),
    [aux_sym_preproc_def_token1] = ACTIONS(5565),
    [aux_sym_preproc_if_token1] = ACTIONS(5565),
    [aux_sym_preproc_if_token2] = ACTIONS(5565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5565),
    [sym_preproc_directive] = ACTIONS(5565),
    [anon_sym_LPAREN2] = ACTIONS(5567),
    [anon_sym_TILDE] = ACTIONS(5567),
    [anon_sym_STAR] = ACTIONS(5567),
    [anon_sym_AMP_AMP] = ACTIONS(5567),
    [anon_sym_AMP] = ACTIONS(5565),
    [anon_sym_SEMI] = ACTIONS(5567),
    [anon_sym___extension__] = ACTIONS(5565),
    [anon_sym_typedef] = ACTIONS(5565),
    [anon_sym___device__] = ACTIONS(5565),
    [anon_sym___host__] = ACTIONS(5565),
    [anon_sym___global__] = ACTIONS(5565),
    [anon_sym___forceinline__] = ACTIONS(5565),
    [anon_sym___noinline__] = ACTIONS(5565),
    [anon_sym_virtual] = ACTIONS(5565),
    [anon_sym_extern] = ACTIONS(5565),
    [anon_sym___attribute__] = ACTIONS(5565),
    [anon_sym___attribute] = ACTIONS(5565),
    [anon_sym_COLON_COLON] = ACTIONS(5567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5567),
    [anon_sym___declspec] = ACTIONS(5565),
    [anon_sym___based] = ACTIONS(5565),
    [anon_sym_signed] = ACTIONS(5565),
    [anon_sym_unsigned] = ACTIONS(5565),
    [anon_sym_long] = ACTIONS(5565),
    [anon_sym_short] = ACTIONS(5565),
    [anon_sym_LBRACK] = ACTIONS(5565),
    [anon_sym_static] = ACTIONS(5565),
    [anon_sym_register] = ACTIONS(5565),
    [anon_sym_inline] = ACTIONS(5565),
    [anon_sym___inline] = ACTIONS(5565),
    [anon_sym___inline__] = ACTIONS(5565),
    [anon_sym___forceinline] = ACTIONS(5565),
    [anon_sym_thread_local] = ACTIONS(5565),
    [anon_sym___thread] = ACTIONS(5565),
    [anon_sym_const] = ACTIONS(5565),
    [anon_sym_constexpr] = ACTIONS(5565),
    [anon_sym_volatile] = ACTIONS(5565),
    [anon_sym_restrict] = ACTIONS(5565),
    [anon_sym___restrict__] = ACTIONS(5565),
    [anon_sym__Atomic] = ACTIONS(5565),
    [anon_sym__Noreturn] = ACTIONS(5565),
    [anon_sym_noreturn] = ACTIONS(5565),
    [anon_sym__Nonnull] = ACTIONS(5565),
    [anon_sym_mutable] = ACTIONS(5565),
    [anon_sym_constinit] = ACTIONS(5565),
    [anon_sym_consteval] = ACTIONS(5565),
    [anon_sym___shared__] = ACTIONS(5565),
    [anon_sym___local__] = ACTIONS(5565),
    [anon_sym___constant__] = ACTIONS(5565),
    [anon_sym___managed__] = ACTIONS(5565),
    [anon_sym___grid_constant__] = ACTIONS(5565),
    [anon_sym_alignas] = ACTIONS(5565),
    [anon_sym__Alignas] = ACTIONS(5565),
    [sym_primitive_type] = ACTIONS(5565),
    [anon_sym_enum] = ACTIONS(5565),
    [anon_sym_class] = ACTIONS(5565),
    [anon_sym_struct] = ACTIONS(5565),
    [anon_sym_union] = ACTIONS(5565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5565),
    [anon_sym_decltype] = ACTIONS(5565),
    [anon_sym_explicit] = ACTIONS(5565),
    [anon_sym_typename] = ACTIONS(5565),
    [anon_sym_template] = ACTIONS(5565),
    [anon_sym_operator] = ACTIONS(5565),
    [anon_sym_friend] = ACTIONS(5565),
    [anon_sym_public] = ACTIONS(5565),
    [anon_sym_private] = ACTIONS(5565),
    [anon_sym_protected] = ACTIONS(5565),
    [anon_sym_using] = ACTIONS(5565),
    [anon_sym_static_assert] = ACTIONS(5565),
    [anon_sym___launch_bounds__] = ACTIONS(5565),
  },
  [STATE(2041)] = {
    [sym_identifier] = ACTIONS(2435),
    [aux_sym_preproc_def_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token2] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2435),
    [sym_preproc_directive] = ACTIONS(2435),
    [anon_sym_LPAREN2] = ACTIONS(2437),
    [anon_sym_TILDE] = ACTIONS(2437),
    [anon_sym_STAR] = ACTIONS(2437),
    [anon_sym_AMP_AMP] = ACTIONS(2437),
    [anon_sym_AMP] = ACTIONS(2435),
    [anon_sym_SEMI] = ACTIONS(2437),
    [anon_sym___extension__] = ACTIONS(2435),
    [anon_sym_typedef] = ACTIONS(2435),
    [anon_sym___device__] = ACTIONS(2435),
    [anon_sym___host__] = ACTIONS(2435),
    [anon_sym___global__] = ACTIONS(2435),
    [anon_sym___forceinline__] = ACTIONS(2435),
    [anon_sym___noinline__] = ACTIONS(2435),
    [anon_sym_virtual] = ACTIONS(2435),
    [anon_sym_extern] = ACTIONS(2435),
    [anon_sym___attribute__] = ACTIONS(2435),
    [anon_sym___attribute] = ACTIONS(2435),
    [anon_sym_COLON_COLON] = ACTIONS(2437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2437),
    [anon_sym___declspec] = ACTIONS(2435),
    [anon_sym___based] = ACTIONS(2435),
    [anon_sym_signed] = ACTIONS(2435),
    [anon_sym_unsigned] = ACTIONS(2435),
    [anon_sym_long] = ACTIONS(2435),
    [anon_sym_short] = ACTIONS(2435),
    [anon_sym_LBRACK] = ACTIONS(2435),
    [anon_sym_static] = ACTIONS(2435),
    [anon_sym_register] = ACTIONS(2435),
    [anon_sym_inline] = ACTIONS(2435),
    [anon_sym___inline] = ACTIONS(2435),
    [anon_sym___inline__] = ACTIONS(2435),
    [anon_sym___forceinline] = ACTIONS(2435),
    [anon_sym_thread_local] = ACTIONS(2435),
    [anon_sym___thread] = ACTIONS(2435),
    [anon_sym_const] = ACTIONS(2435),
    [anon_sym_constexpr] = ACTIONS(2435),
    [anon_sym_volatile] = ACTIONS(2435),
    [anon_sym_restrict] = ACTIONS(2435),
    [anon_sym___restrict__] = ACTIONS(2435),
    [anon_sym__Atomic] = ACTIONS(2435),
    [anon_sym__Noreturn] = ACTIONS(2435),
    [anon_sym_noreturn] = ACTIONS(2435),
    [anon_sym__Nonnull] = ACTIONS(2435),
    [anon_sym_mutable] = ACTIONS(2435),
    [anon_sym_constinit] = ACTIONS(2435),
    [anon_sym_consteval] = ACTIONS(2435),
    [anon_sym___shared__] = ACTIONS(2435),
    [anon_sym___local__] = ACTIONS(2435),
    [anon_sym___constant__] = ACTIONS(2435),
    [anon_sym___managed__] = ACTIONS(2435),
    [anon_sym___grid_constant__] = ACTIONS(2435),
    [anon_sym_alignas] = ACTIONS(2435),
    [anon_sym__Alignas] = ACTIONS(2435),
    [sym_primitive_type] = ACTIONS(2435),
    [anon_sym_enum] = ACTIONS(2435),
    [anon_sym_class] = ACTIONS(2435),
    [anon_sym_struct] = ACTIONS(2435),
    [anon_sym_union] = ACTIONS(2435),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2435),
    [anon_sym_decltype] = ACTIONS(2435),
    [anon_sym_explicit] = ACTIONS(2435),
    [anon_sym_typename] = ACTIONS(2435),
    [anon_sym_template] = ACTIONS(2435),
    [anon_sym_operator] = ACTIONS(2435),
    [anon_sym_friend] = ACTIONS(2435),
    [anon_sym_public] = ACTIONS(2435),
    [anon_sym_private] = ACTIONS(2435),
    [anon_sym_protected] = ACTIONS(2435),
    [anon_sym_using] = ACTIONS(2435),
    [anon_sym_static_assert] = ACTIONS(2435),
    [anon_sym___launch_bounds__] = ACTIONS(2435),
  },
  [STATE(2042)] = {
    [sym_identifier] = ACTIONS(2447),
    [aux_sym_preproc_def_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token1] = ACTIONS(2447),
    [aux_sym_preproc_if_token2] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2447),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2447),
    [sym_preproc_directive] = ACTIONS(2447),
    [anon_sym_LPAREN2] = ACTIONS(2449),
    [anon_sym_TILDE] = ACTIONS(2449),
    [anon_sym_STAR] = ACTIONS(2449),
    [anon_sym_AMP_AMP] = ACTIONS(2449),
    [anon_sym_AMP] = ACTIONS(2447),
    [anon_sym_SEMI] = ACTIONS(2449),
    [anon_sym___extension__] = ACTIONS(2447),
    [anon_sym_typedef] = ACTIONS(2447),
    [anon_sym___device__] = ACTIONS(2447),
    [anon_sym___host__] = ACTIONS(2447),
    [anon_sym___global__] = ACTIONS(2447),
    [anon_sym___forceinline__] = ACTIONS(2447),
    [anon_sym___noinline__] = ACTIONS(2447),
    [anon_sym_virtual] = ACTIONS(2447),
    [anon_sym_extern] = ACTIONS(2447),
    [anon_sym___attribute__] = ACTIONS(2447),
    [anon_sym___attribute] = ACTIONS(2447),
    [anon_sym_COLON_COLON] = ACTIONS(2449),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2449),
    [anon_sym___declspec] = ACTIONS(2447),
    [anon_sym___based] = ACTIONS(2447),
    [anon_sym_signed] = ACTIONS(2447),
    [anon_sym_unsigned] = ACTIONS(2447),
    [anon_sym_long] = ACTIONS(2447),
    [anon_sym_short] = ACTIONS(2447),
    [anon_sym_LBRACK] = ACTIONS(2447),
    [anon_sym_static] = ACTIONS(2447),
    [anon_sym_register] = ACTIONS(2447),
    [anon_sym_inline] = ACTIONS(2447),
    [anon_sym___inline] = ACTIONS(2447),
    [anon_sym___inline__] = ACTIONS(2447),
    [anon_sym___forceinline] = ACTIONS(2447),
    [anon_sym_thread_local] = ACTIONS(2447),
    [anon_sym___thread] = ACTIONS(2447),
    [anon_sym_const] = ACTIONS(2447),
    [anon_sym_constexpr] = ACTIONS(2447),
    [anon_sym_volatile] = ACTIONS(2447),
    [anon_sym_restrict] = ACTIONS(2447),
    [anon_sym___restrict__] = ACTIONS(2447),
    [anon_sym__Atomic] = ACTIONS(2447),
    [anon_sym__Noreturn] = ACTIONS(2447),
    [anon_sym_noreturn] = ACTIONS(2447),
    [anon_sym__Nonnull] = ACTIONS(2447),
    [anon_sym_mutable] = ACTIONS(2447),
    [anon_sym_constinit] = ACTIONS(2447),
    [anon_sym_consteval] = ACTIONS(2447),
    [anon_sym___shared__] = ACTIONS(2447),
    [anon_sym___local__] = ACTIONS(2447),
    [anon_sym___constant__] = ACTIONS(2447),
    [anon_sym___managed__] = ACTIONS(2447),
    [anon_sym___grid_constant__] = ACTIONS(2447),
    [anon_sym_alignas] = ACTIONS(2447),
    [anon_sym__Alignas] = ACTIONS(2447),
    [sym_primitive_type] = ACTIONS(2447),
    [anon_sym_enum] = ACTIONS(2447),
    [anon_sym_class] = ACTIONS(2447),
    [anon_sym_struct] = ACTIONS(2447),
    [anon_sym_union] = ACTIONS(2447),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2447),
    [anon_sym_decltype] = ACTIONS(2447),
    [anon_sym_explicit] = ACTIONS(2447),
    [anon_sym_typename] = ACTIONS(2447),
    [anon_sym_template] = ACTIONS(2447),
    [anon_sym_operator] = ACTIONS(2447),
    [anon_sym_friend] = ACTIONS(2447),
    [anon_sym_public] = ACTIONS(2447),
    [anon_sym_private] = ACTIONS(2447),
    [anon_sym_protected] = ACTIONS(2447),
    [anon_sym_using] = ACTIONS(2447),
    [anon_sym_static_assert] = ACTIONS(2447),
    [anon_sym___launch_bounds__] = ACTIONS(2447),
  },
  [STATE(2043)] = {
    [sym_identifier] = ACTIONS(2485),
    [aux_sym_preproc_def_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token1] = ACTIONS(2485),
    [aux_sym_preproc_if_token2] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2485),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2485),
    [sym_preproc_directive] = ACTIONS(2485),
    [anon_sym_LPAREN2] = ACTIONS(2487),
    [anon_sym_TILDE] = ACTIONS(2487),
    [anon_sym_STAR] = ACTIONS(2487),
    [anon_sym_AMP_AMP] = ACTIONS(2487),
    [anon_sym_AMP] = ACTIONS(2485),
    [anon_sym_SEMI] = ACTIONS(2487),
    [anon_sym___extension__] = ACTIONS(2485),
    [anon_sym_typedef] = ACTIONS(2485),
    [anon_sym___device__] = ACTIONS(2485),
    [anon_sym___host__] = ACTIONS(2485),
    [anon_sym___global__] = ACTIONS(2485),
    [anon_sym___forceinline__] = ACTIONS(2485),
    [anon_sym___noinline__] = ACTIONS(2485),
    [anon_sym_virtual] = ACTIONS(2485),
    [anon_sym_extern] = ACTIONS(2485),
    [anon_sym___attribute__] = ACTIONS(2485),
    [anon_sym___attribute] = ACTIONS(2485),
    [anon_sym_COLON_COLON] = ACTIONS(2487),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2487),
    [anon_sym___declspec] = ACTIONS(2485),
    [anon_sym___based] = ACTIONS(2485),
    [anon_sym_signed] = ACTIONS(2485),
    [anon_sym_unsigned] = ACTIONS(2485),
    [anon_sym_long] = ACTIONS(2485),
    [anon_sym_short] = ACTIONS(2485),
    [anon_sym_LBRACK] = ACTIONS(2485),
    [anon_sym_static] = ACTIONS(2485),
    [anon_sym_register] = ACTIONS(2485),
    [anon_sym_inline] = ACTIONS(2485),
    [anon_sym___inline] = ACTIONS(2485),
    [anon_sym___inline__] = ACTIONS(2485),
    [anon_sym___forceinline] = ACTIONS(2485),
    [anon_sym_thread_local] = ACTIONS(2485),
    [anon_sym___thread] = ACTIONS(2485),
    [anon_sym_const] = ACTIONS(2485),
    [anon_sym_constexpr] = ACTIONS(2485),
    [anon_sym_volatile] = ACTIONS(2485),
    [anon_sym_restrict] = ACTIONS(2485),
    [anon_sym___restrict__] = ACTIONS(2485),
    [anon_sym__Atomic] = ACTIONS(2485),
    [anon_sym__Noreturn] = ACTIONS(2485),
    [anon_sym_noreturn] = ACTIONS(2485),
    [anon_sym__Nonnull] = ACTIONS(2485),
    [anon_sym_mutable] = ACTIONS(2485),
    [anon_sym_constinit] = ACTIONS(2485),
    [anon_sym_consteval] = ACTIONS(2485),
    [anon_sym___shared__] = ACTIONS(2485),
    [anon_sym___local__] = ACTIONS(2485),
    [anon_sym___constant__] = ACTIONS(2485),
    [anon_sym___managed__] = ACTIONS(2485),
    [anon_sym___grid_constant__] = ACTIONS(2485),
    [anon_sym_alignas] = ACTIONS(2485),
    [anon_sym__Alignas] = ACTIONS(2485),
    [sym_primitive_type] = ACTIONS(2485),
    [anon_sym_enum] = ACTIONS(2485),
    [anon_sym_class] = ACTIONS(2485),
    [anon_sym_struct] = ACTIONS(2485),
    [anon_sym_union] = ACTIONS(2485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2485),
    [anon_sym_decltype] = ACTIONS(2485),
    [anon_sym_explicit] = ACTIONS(2485),
    [anon_sym_typename] = ACTIONS(2485),
    [anon_sym_template] = ACTIONS(2485),
    [anon_sym_operator] = ACTIONS(2485),
    [anon_sym_friend] = ACTIONS(2485),
    [anon_sym_public] = ACTIONS(2485),
    [anon_sym_private] = ACTIONS(2485),
    [anon_sym_protected] = ACTIONS(2485),
    [anon_sym_using] = ACTIONS(2485),
    [anon_sym_static_assert] = ACTIONS(2485),
    [anon_sym___launch_bounds__] = ACTIONS(2485),
  },
  [STATE(2044)] = {
    [sym_identifier] = ACTIONS(2493),
    [aux_sym_preproc_def_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token1] = ACTIONS(2493),
    [aux_sym_preproc_if_token2] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2493),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2493),
    [sym_preproc_directive] = ACTIONS(2493),
    [anon_sym_LPAREN2] = ACTIONS(2495),
    [anon_sym_TILDE] = ACTIONS(2495),
    [anon_sym_STAR] = ACTIONS(2495),
    [anon_sym_AMP_AMP] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(2493),
    [anon_sym_SEMI] = ACTIONS(2495),
    [anon_sym___extension__] = ACTIONS(2493),
    [anon_sym_typedef] = ACTIONS(2493),
    [anon_sym___device__] = ACTIONS(2493),
    [anon_sym___host__] = ACTIONS(2493),
    [anon_sym___global__] = ACTIONS(2493),
    [anon_sym___forceinline__] = ACTIONS(2493),
    [anon_sym___noinline__] = ACTIONS(2493),
    [anon_sym_virtual] = ACTIONS(2493),
    [anon_sym_extern] = ACTIONS(2493),
    [anon_sym___attribute__] = ACTIONS(2493),
    [anon_sym___attribute] = ACTIONS(2493),
    [anon_sym_COLON_COLON] = ACTIONS(2495),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2495),
    [anon_sym___declspec] = ACTIONS(2493),
    [anon_sym___based] = ACTIONS(2493),
    [anon_sym_signed] = ACTIONS(2493),
    [anon_sym_unsigned] = ACTIONS(2493),
    [anon_sym_long] = ACTIONS(2493),
    [anon_sym_short] = ACTIONS(2493),
    [anon_sym_LBRACK] = ACTIONS(2493),
    [anon_sym_static] = ACTIONS(2493),
    [anon_sym_register] = ACTIONS(2493),
    [anon_sym_inline] = ACTIONS(2493),
    [anon_sym___inline] = ACTIONS(2493),
    [anon_sym___inline__] = ACTIONS(2493),
    [anon_sym___forceinline] = ACTIONS(2493),
    [anon_sym_thread_local] = ACTIONS(2493),
    [anon_sym___thread] = ACTIONS(2493),
    [anon_sym_const] = ACTIONS(2493),
    [anon_sym_constexpr] = ACTIONS(2493),
    [anon_sym_volatile] = ACTIONS(2493),
    [anon_sym_restrict] = ACTIONS(2493),
    [anon_sym___restrict__] = ACTIONS(2493),
    [anon_sym__Atomic] = ACTIONS(2493),
    [anon_sym__Noreturn] = ACTIONS(2493),
    [anon_sym_noreturn] = ACTIONS(2493),
    [anon_sym__Nonnull] = ACTIONS(2493),
    [anon_sym_mutable] = ACTIONS(2493),
    [anon_sym_constinit] = ACTIONS(2493),
    [anon_sym_consteval] = ACTIONS(2493),
    [anon_sym___shared__] = ACTIONS(2493),
    [anon_sym___local__] = ACTIONS(2493),
    [anon_sym___constant__] = ACTIONS(2493),
    [anon_sym___managed__] = ACTIONS(2493),
    [anon_sym___grid_constant__] = ACTIONS(2493),
    [anon_sym_alignas] = ACTIONS(2493),
    [anon_sym__Alignas] = ACTIONS(2493),
    [sym_primitive_type] = ACTIONS(2493),
    [anon_sym_enum] = ACTIONS(2493),
    [anon_sym_class] = ACTIONS(2493),
    [anon_sym_struct] = ACTIONS(2493),
    [anon_sym_union] = ACTIONS(2493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2493),
    [anon_sym_decltype] = ACTIONS(2493),
    [anon_sym_explicit] = ACTIONS(2493),
    [anon_sym_typename] = ACTIONS(2493),
    [anon_sym_template] = ACTIONS(2493),
    [anon_sym_operator] = ACTIONS(2493),
    [anon_sym_friend] = ACTIONS(2493),
    [anon_sym_public] = ACTIONS(2493),
    [anon_sym_private] = ACTIONS(2493),
    [anon_sym_protected] = ACTIONS(2493),
    [anon_sym_using] = ACTIONS(2493),
    [anon_sym_static_assert] = ACTIONS(2493),
    [anon_sym___launch_bounds__] = ACTIONS(2493),
  },
  [STATE(2045)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token2] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(2046)] = {
    [sym_identifier] = ACTIONS(5619),
    [aux_sym_preproc_def_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token1] = ACTIONS(5619),
    [aux_sym_preproc_if_token2] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5619),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5619),
    [sym_preproc_directive] = ACTIONS(5619),
    [anon_sym_LPAREN2] = ACTIONS(5621),
    [anon_sym_TILDE] = ACTIONS(5621),
    [anon_sym_STAR] = ACTIONS(5621),
    [anon_sym_AMP_AMP] = ACTIONS(5621),
    [anon_sym_AMP] = ACTIONS(5619),
    [anon_sym_SEMI] = ACTIONS(5621),
    [anon_sym___extension__] = ACTIONS(5619),
    [anon_sym_typedef] = ACTIONS(5619),
    [anon_sym___device__] = ACTIONS(5619),
    [anon_sym___host__] = ACTIONS(5619),
    [anon_sym___global__] = ACTIONS(5619),
    [anon_sym___forceinline__] = ACTIONS(5619),
    [anon_sym___noinline__] = ACTIONS(5619),
    [anon_sym_virtual] = ACTIONS(5619),
    [anon_sym_extern] = ACTIONS(5619),
    [anon_sym___attribute__] = ACTIONS(5619),
    [anon_sym___attribute] = ACTIONS(5619),
    [anon_sym_COLON_COLON] = ACTIONS(5621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5621),
    [anon_sym___declspec] = ACTIONS(5619),
    [anon_sym___based] = ACTIONS(5619),
    [anon_sym_signed] = ACTIONS(5619),
    [anon_sym_unsigned] = ACTIONS(5619),
    [anon_sym_long] = ACTIONS(5619),
    [anon_sym_short] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [anon_sym_static] = ACTIONS(5619),
    [anon_sym_register] = ACTIONS(5619),
    [anon_sym_inline] = ACTIONS(5619),
    [anon_sym___inline] = ACTIONS(5619),
    [anon_sym___inline__] = ACTIONS(5619),
    [anon_sym___forceinline] = ACTIONS(5619),
    [anon_sym_thread_local] = ACTIONS(5619),
    [anon_sym___thread] = ACTIONS(5619),
    [anon_sym_const] = ACTIONS(5619),
    [anon_sym_constexpr] = ACTIONS(5619),
    [anon_sym_volatile] = ACTIONS(5619),
    [anon_sym_restrict] = ACTIONS(5619),
    [anon_sym___restrict__] = ACTIONS(5619),
    [anon_sym__Atomic] = ACTIONS(5619),
    [anon_sym__Noreturn] = ACTIONS(5619),
    [anon_sym_noreturn] = ACTIONS(5619),
    [anon_sym__Nonnull] = ACTIONS(5619),
    [anon_sym_mutable] = ACTIONS(5619),
    [anon_sym_constinit] = ACTIONS(5619),
    [anon_sym_consteval] = ACTIONS(5619),
    [anon_sym___shared__] = ACTIONS(5619),
    [anon_sym___local__] = ACTIONS(5619),
    [anon_sym___constant__] = ACTIONS(5619),
    [anon_sym___managed__] = ACTIONS(5619),
    [anon_sym___grid_constant__] = ACTIONS(5619),
    [anon_sym_alignas] = ACTIONS(5619),
    [anon_sym__Alignas] = ACTIONS(5619),
    [sym_primitive_type] = ACTIONS(5619),
    [anon_sym_enum] = ACTIONS(5619),
    [anon_sym_class] = ACTIONS(5619),
    [anon_sym_struct] = ACTIONS(5619),
    [anon_sym_union] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5619),
    [anon_sym_decltype] = ACTIONS(5619),
    [anon_sym_explicit] = ACTIONS(5619),
    [anon_sym_typename] = ACTIONS(5619),
    [anon_sym_template] = ACTIONS(5619),
    [anon_sym_operator] = ACTIONS(5619),
    [anon_sym_friend] = ACTIONS(5619),
    [anon_sym_public] = ACTIONS(5619),
    [anon_sym_private] = ACTIONS(5619),
    [anon_sym_protected] = ACTIONS(5619),
    [anon_sym_using] = ACTIONS(5619),
    [anon_sym_static_assert] = ACTIONS(5619),
    [anon_sym___launch_bounds__] = ACTIONS(5619),
  },
  [STATE(2047)] = {
    [sym_identifier] = ACTIONS(5615),
    [aux_sym_preproc_def_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token1] = ACTIONS(5615),
    [aux_sym_preproc_if_token2] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5615),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5615),
    [sym_preproc_directive] = ACTIONS(5615),
    [anon_sym_LPAREN2] = ACTIONS(5617),
    [anon_sym_TILDE] = ACTIONS(5617),
    [anon_sym_STAR] = ACTIONS(5617),
    [anon_sym_AMP_AMP] = ACTIONS(5617),
    [anon_sym_AMP] = ACTIONS(5615),
    [anon_sym_SEMI] = ACTIONS(5617),
    [anon_sym___extension__] = ACTIONS(5615),
    [anon_sym_typedef] = ACTIONS(5615),
    [anon_sym___device__] = ACTIONS(5615),
    [anon_sym___host__] = ACTIONS(5615),
    [anon_sym___global__] = ACTIONS(5615),
    [anon_sym___forceinline__] = ACTIONS(5615),
    [anon_sym___noinline__] = ACTIONS(5615),
    [anon_sym_virtual] = ACTIONS(5615),
    [anon_sym_extern] = ACTIONS(5615),
    [anon_sym___attribute__] = ACTIONS(5615),
    [anon_sym___attribute] = ACTIONS(5615),
    [anon_sym_COLON_COLON] = ACTIONS(5617),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5617),
    [anon_sym___declspec] = ACTIONS(5615),
    [anon_sym___based] = ACTIONS(5615),
    [anon_sym_signed] = ACTIONS(5615),
    [anon_sym_unsigned] = ACTIONS(5615),
    [anon_sym_long] = ACTIONS(5615),
    [anon_sym_short] = ACTIONS(5615),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [anon_sym_static] = ACTIONS(5615),
    [anon_sym_register] = ACTIONS(5615),
    [anon_sym_inline] = ACTIONS(5615),
    [anon_sym___inline] = ACTIONS(5615),
    [anon_sym___inline__] = ACTIONS(5615),
    [anon_sym___forceinline] = ACTIONS(5615),
    [anon_sym_thread_local] = ACTIONS(5615),
    [anon_sym___thread] = ACTIONS(5615),
    [anon_sym_const] = ACTIONS(5615),
    [anon_sym_constexpr] = ACTIONS(5615),
    [anon_sym_volatile] = ACTIONS(5615),
    [anon_sym_restrict] = ACTIONS(5615),
    [anon_sym___restrict__] = ACTIONS(5615),
    [anon_sym__Atomic] = ACTIONS(5615),
    [anon_sym__Noreturn] = ACTIONS(5615),
    [anon_sym_noreturn] = ACTIONS(5615),
    [anon_sym__Nonnull] = ACTIONS(5615),
    [anon_sym_mutable] = ACTIONS(5615),
    [anon_sym_constinit] = ACTIONS(5615),
    [anon_sym_consteval] = ACTIONS(5615),
    [anon_sym___shared__] = ACTIONS(5615),
    [anon_sym___local__] = ACTIONS(5615),
    [anon_sym___constant__] = ACTIONS(5615),
    [anon_sym___managed__] = ACTIONS(5615),
    [anon_sym___grid_constant__] = ACTIONS(5615),
    [anon_sym_alignas] = ACTIONS(5615),
    [anon_sym__Alignas] = ACTIONS(5615),
    [sym_primitive_type] = ACTIONS(5615),
    [anon_sym_enum] = ACTIONS(5615),
    [anon_sym_class] = ACTIONS(5615),
    [anon_sym_struct] = ACTIONS(5615),
    [anon_sym_union] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5615),
    [anon_sym_decltype] = ACTIONS(5615),
    [anon_sym_explicit] = ACTIONS(5615),
    [anon_sym_typename] = ACTIONS(5615),
    [anon_sym_template] = ACTIONS(5615),
    [anon_sym_operator] = ACTIONS(5615),
    [anon_sym_friend] = ACTIONS(5615),
    [anon_sym_public] = ACTIONS(5615),
    [anon_sym_private] = ACTIONS(5615),
    [anon_sym_protected] = ACTIONS(5615),
    [anon_sym_using] = ACTIONS(5615),
    [anon_sym_static_assert] = ACTIONS(5615),
    [anon_sym___launch_bounds__] = ACTIONS(5615),
  },
  [STATE(2048)] = {
    [sym_decltype_auto] = STATE(2160),
    [sym_identifier] = ACTIONS(5673),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5675),
    [anon_sym_COMMA] = ACTIONS(5675),
    [anon_sym_RPAREN] = ACTIONS(5675),
    [anon_sym_LPAREN2] = ACTIONS(5675),
    [anon_sym_DASH] = ACTIONS(5673),
    [anon_sym_PLUS] = ACTIONS(5673),
    [anon_sym_STAR] = ACTIONS(5675),
    [anon_sym_SLASH] = ACTIONS(5673),
    [anon_sym_PERCENT] = ACTIONS(5675),
    [anon_sym_PIPE_PIPE] = ACTIONS(5675),
    [anon_sym_AMP_AMP] = ACTIONS(5675),
    [anon_sym_PIPE] = ACTIONS(5673),
    [anon_sym_CARET] = ACTIONS(5675),
    [anon_sym_AMP] = ACTIONS(5673),
    [anon_sym_EQ_EQ] = ACTIONS(5675),
    [anon_sym_BANG_EQ] = ACTIONS(5675),
    [anon_sym_GT] = ACTIONS(5673),
    [anon_sym_GT_EQ] = ACTIONS(5675),
    [anon_sym_LT_EQ] = ACTIONS(5673),
    [anon_sym_LT] = ACTIONS(5673),
    [anon_sym_LT_LT] = ACTIONS(5673),
    [anon_sym_GT_GT] = ACTIONS(5675),
    [anon_sym_SEMI] = ACTIONS(5675),
    [anon_sym___extension__] = ACTIONS(5673),
    [anon_sym___global__] = ACTIONS(5673),
    [anon_sym___attribute__] = ACTIONS(5673),
    [anon_sym___attribute] = ACTIONS(5673),
    [anon_sym___based] = ACTIONS(5673),
    [anon_sym_LBRACE] = ACTIONS(5675),
    [anon_sym_RBRACE] = ACTIONS(5675),
    [anon_sym_signed] = ACTIONS(5673),
    [anon_sym_unsigned] = ACTIONS(5673),
    [anon_sym_long] = ACTIONS(5673),
    [anon_sym_short] = ACTIONS(5673),
    [anon_sym_LBRACK] = ACTIONS(5675),
    [anon_sym_RBRACK] = ACTIONS(5675),
    [anon_sym_const] = ACTIONS(5673),
    [anon_sym_constexpr] = ACTIONS(5673),
    [anon_sym_volatile] = ACTIONS(5673),
    [anon_sym_restrict] = ACTIONS(5673),
    [anon_sym___restrict__] = ACTIONS(5673),
    [anon_sym__Atomic] = ACTIONS(5673),
    [anon_sym__Noreturn] = ACTIONS(5673),
    [anon_sym_noreturn] = ACTIONS(5673),
    [anon_sym__Nonnull] = ACTIONS(5673),
    [anon_sym_mutable] = ACTIONS(5673),
    [anon_sym_constinit] = ACTIONS(5673),
    [anon_sym_consteval] = ACTIONS(5673),
    [anon_sym___shared__] = ACTIONS(5673),
    [anon_sym___local__] = ACTIONS(5673),
    [anon_sym___constant__] = ACTIONS(5673),
    [anon_sym___managed__] = ACTIONS(5673),
    [anon_sym___grid_constant__] = ACTIONS(5673),
    [anon_sym_alignas] = ACTIONS(5673),
    [anon_sym__Alignas] = ACTIONS(5673),
    [sym_primitive_type] = ACTIONS(5673),
    [anon_sym_COLON] = ACTIONS(5675),
    [anon_sym_QMARK] = ACTIONS(5675),
    [anon_sym_LT_EQ_GT] = ACTIONS(5675),
    [anon_sym_or] = ACTIONS(5673),
    [anon_sym_and] = ACTIONS(5673),
    [anon_sym_bitor] = ACTIONS(5673),
    [anon_sym_xor] = ACTIONS(5673),
    [anon_sym_bitand] = ACTIONS(5673),
    [anon_sym_not_eq] = ACTIONS(5673),
    [anon_sym_DASH_DASH] = ACTIONS(5675),
    [anon_sym_PLUS_PLUS] = ACTIONS(5675),
    [anon_sym_DOT] = ACTIONS(5673),
    [anon_sym_DOT_STAR] = ACTIONS(5675),
    [anon_sym_DASH_GT] = ACTIONS(5675),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5677),
    [anon_sym_decltype] = ACTIONS(5679),
    [anon_sym_final] = ACTIONS(5673),
    [anon_sym_override] = ACTIONS(5673),
    [anon_sym_requires] = ACTIONS(5673),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5675),
  },
  [STATE(2049)] = {
    [sym_identifier] = ACTIONS(2605),
    [aux_sym_preproc_def_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token1] = ACTIONS(2605),
    [aux_sym_preproc_if_token2] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2605),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2605),
    [sym_preproc_directive] = ACTIONS(2605),
    [anon_sym_LPAREN2] = ACTIONS(2607),
    [anon_sym_TILDE] = ACTIONS(2607),
    [anon_sym_STAR] = ACTIONS(2607),
    [anon_sym_AMP_AMP] = ACTIONS(2607),
    [anon_sym_AMP] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2605),
    [anon_sym_typedef] = ACTIONS(2605),
    [anon_sym___device__] = ACTIONS(2605),
    [anon_sym___host__] = ACTIONS(2605),
    [anon_sym___global__] = ACTIONS(2605),
    [anon_sym___forceinline__] = ACTIONS(2605),
    [anon_sym___noinline__] = ACTIONS(2605),
    [anon_sym_virtual] = ACTIONS(2605),
    [anon_sym_extern] = ACTIONS(2605),
    [anon_sym___attribute__] = ACTIONS(2605),
    [anon_sym___attribute] = ACTIONS(2605),
    [anon_sym_COLON_COLON] = ACTIONS(2607),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2607),
    [anon_sym___declspec] = ACTIONS(2605),
    [anon_sym___based] = ACTIONS(2605),
    [anon_sym_signed] = ACTIONS(2605),
    [anon_sym_unsigned] = ACTIONS(2605),
    [anon_sym_long] = ACTIONS(2605),
    [anon_sym_short] = ACTIONS(2605),
    [anon_sym_LBRACK] = ACTIONS(2605),
    [anon_sym_static] = ACTIONS(2605),
    [anon_sym_register] = ACTIONS(2605),
    [anon_sym_inline] = ACTIONS(2605),
    [anon_sym___inline] = ACTIONS(2605),
    [anon_sym___inline__] = ACTIONS(2605),
    [anon_sym___forceinline] = ACTIONS(2605),
    [anon_sym_thread_local] = ACTIONS(2605),
    [anon_sym___thread] = ACTIONS(2605),
    [anon_sym_const] = ACTIONS(2605),
    [anon_sym_constexpr] = ACTIONS(2605),
    [anon_sym_volatile] = ACTIONS(2605),
    [anon_sym_restrict] = ACTIONS(2605),
    [anon_sym___restrict__] = ACTIONS(2605),
    [anon_sym__Atomic] = ACTIONS(2605),
    [anon_sym__Noreturn] = ACTIONS(2605),
    [anon_sym_noreturn] = ACTIONS(2605),
    [anon_sym__Nonnull] = ACTIONS(2605),
    [anon_sym_mutable] = ACTIONS(2605),
    [anon_sym_constinit] = ACTIONS(2605),
    [anon_sym_consteval] = ACTIONS(2605),
    [anon_sym___shared__] = ACTIONS(2605),
    [anon_sym___local__] = ACTIONS(2605),
    [anon_sym___constant__] = ACTIONS(2605),
    [anon_sym___managed__] = ACTIONS(2605),
    [anon_sym___grid_constant__] = ACTIONS(2605),
    [anon_sym_alignas] = ACTIONS(2605),
    [anon_sym__Alignas] = ACTIONS(2605),
    [sym_primitive_type] = ACTIONS(2605),
    [anon_sym_enum] = ACTIONS(2605),
    [anon_sym_class] = ACTIONS(2605),
    [anon_sym_struct] = ACTIONS(2605),
    [anon_sym_union] = ACTIONS(2605),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2605),
    [anon_sym_decltype] = ACTIONS(2605),
    [anon_sym_explicit] = ACTIONS(2605),
    [anon_sym_typename] = ACTIONS(2605),
    [anon_sym_template] = ACTIONS(2605),
    [anon_sym_operator] = ACTIONS(2605),
    [anon_sym_friend] = ACTIONS(2605),
    [anon_sym_public] = ACTIONS(2605),
    [anon_sym_private] = ACTIONS(2605),
    [anon_sym_protected] = ACTIONS(2605),
    [anon_sym_using] = ACTIONS(2605),
    [anon_sym_static_assert] = ACTIONS(2605),
    [anon_sym___launch_bounds__] = ACTIONS(2605),
  },
  [STATE(2050)] = {
    [sym_identifier] = ACTIONS(2613),
    [aux_sym_preproc_def_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token1] = ACTIONS(2613),
    [aux_sym_preproc_if_token2] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2613),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2613),
    [sym_preproc_directive] = ACTIONS(2613),
    [anon_sym_LPAREN2] = ACTIONS(2615),
    [anon_sym_TILDE] = ACTIONS(2615),
    [anon_sym_STAR] = ACTIONS(2615),
    [anon_sym_AMP_AMP] = ACTIONS(2615),
    [anon_sym_AMP] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2615),
    [anon_sym___extension__] = ACTIONS(2613),
    [anon_sym_typedef] = ACTIONS(2613),
    [anon_sym___device__] = ACTIONS(2613),
    [anon_sym___host__] = ACTIONS(2613),
    [anon_sym___global__] = ACTIONS(2613),
    [anon_sym___forceinline__] = ACTIONS(2613),
    [anon_sym___noinline__] = ACTIONS(2613),
    [anon_sym_virtual] = ACTIONS(2613),
    [anon_sym_extern] = ACTIONS(2613),
    [anon_sym___attribute__] = ACTIONS(2613),
    [anon_sym___attribute] = ACTIONS(2613),
    [anon_sym_COLON_COLON] = ACTIONS(2615),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2615),
    [anon_sym___declspec] = ACTIONS(2613),
    [anon_sym___based] = ACTIONS(2613),
    [anon_sym_signed] = ACTIONS(2613),
    [anon_sym_unsigned] = ACTIONS(2613),
    [anon_sym_long] = ACTIONS(2613),
    [anon_sym_short] = ACTIONS(2613),
    [anon_sym_LBRACK] = ACTIONS(2613),
    [anon_sym_static] = ACTIONS(2613),
    [anon_sym_register] = ACTIONS(2613),
    [anon_sym_inline] = ACTIONS(2613),
    [anon_sym___inline] = ACTIONS(2613),
    [anon_sym___inline__] = ACTIONS(2613),
    [anon_sym___forceinline] = ACTIONS(2613),
    [anon_sym_thread_local] = ACTIONS(2613),
    [anon_sym___thread] = ACTIONS(2613),
    [anon_sym_const] = ACTIONS(2613),
    [anon_sym_constexpr] = ACTIONS(2613),
    [anon_sym_volatile] = ACTIONS(2613),
    [anon_sym_restrict] = ACTIONS(2613),
    [anon_sym___restrict__] = ACTIONS(2613),
    [anon_sym__Atomic] = ACTIONS(2613),
    [anon_sym__Noreturn] = ACTIONS(2613),
    [anon_sym_noreturn] = ACTIONS(2613),
    [anon_sym__Nonnull] = ACTIONS(2613),
    [anon_sym_mutable] = ACTIONS(2613),
    [anon_sym_constinit] = ACTIONS(2613),
    [anon_sym_consteval] = ACTIONS(2613),
    [anon_sym___shared__] = ACTIONS(2613),
    [anon_sym___local__] = ACTIONS(2613),
    [anon_sym___constant__] = ACTIONS(2613),
    [anon_sym___managed__] = ACTIONS(2613),
    [anon_sym___grid_constant__] = ACTIONS(2613),
    [anon_sym_alignas] = ACTIONS(2613),
    [anon_sym__Alignas] = ACTIONS(2613),
    [sym_primitive_type] = ACTIONS(2613),
    [anon_sym_enum] = ACTIONS(2613),
    [anon_sym_class] = ACTIONS(2613),
    [anon_sym_struct] = ACTIONS(2613),
    [anon_sym_union] = ACTIONS(2613),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2613),
    [anon_sym_decltype] = ACTIONS(2613),
    [anon_sym_explicit] = ACTIONS(2613),
    [anon_sym_typename] = ACTIONS(2613),
    [anon_sym_template] = ACTIONS(2613),
    [anon_sym_operator] = ACTIONS(2613),
    [anon_sym_friend] = ACTIONS(2613),
    [anon_sym_public] = ACTIONS(2613),
    [anon_sym_private] = ACTIONS(2613),
    [anon_sym_protected] = ACTIONS(2613),
    [anon_sym_using] = ACTIONS(2613),
    [anon_sym_static_assert] = ACTIONS(2613),
    [anon_sym___launch_bounds__] = ACTIONS(2613),
  },
  [STATE(2051)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token2] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_friend] = ACTIONS(2234),
    [anon_sym_public] = ACTIONS(2234),
    [anon_sym_private] = ACTIONS(2234),
    [anon_sym_protected] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(2052)] = {
    [sym_identifier] = ACTIONS(2234),
    [aux_sym_preproc_def_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token1] = ACTIONS(2234),
    [aux_sym_preproc_if_token2] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2234),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2234),
    [sym_preproc_directive] = ACTIONS(2234),
    [anon_sym_LPAREN2] = ACTIONS(2236),
    [anon_sym_TILDE] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2236),
    [anon_sym_AMP_AMP] = ACTIONS(2236),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2236),
    [anon_sym___extension__] = ACTIONS(2234),
    [anon_sym_typedef] = ACTIONS(2234),
    [anon_sym___device__] = ACTIONS(2234),
    [anon_sym___host__] = ACTIONS(2234),
    [anon_sym___global__] = ACTIONS(2234),
    [anon_sym___forceinline__] = ACTIONS(2234),
    [anon_sym___noinline__] = ACTIONS(2234),
    [anon_sym_virtual] = ACTIONS(2234),
    [anon_sym_extern] = ACTIONS(2234),
    [anon_sym___attribute__] = ACTIONS(2234),
    [anon_sym___attribute] = ACTIONS(2234),
    [anon_sym_COLON_COLON] = ACTIONS(2236),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2236),
    [anon_sym___declspec] = ACTIONS(2234),
    [anon_sym___based] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2234),
    [anon_sym_unsigned] = ACTIONS(2234),
    [anon_sym_long] = ACTIONS(2234),
    [anon_sym_short] = ACTIONS(2234),
    [anon_sym_LBRACK] = ACTIONS(2234),
    [anon_sym_static] = ACTIONS(2234),
    [anon_sym_register] = ACTIONS(2234),
    [anon_sym_inline] = ACTIONS(2234),
    [anon_sym___inline] = ACTIONS(2234),
    [anon_sym___inline__] = ACTIONS(2234),
    [anon_sym___forceinline] = ACTIONS(2234),
    [anon_sym_thread_local] = ACTIONS(2234),
    [anon_sym___thread] = ACTIONS(2234),
    [anon_sym_const] = ACTIONS(2234),
    [anon_sym_constexpr] = ACTIONS(2234),
    [anon_sym_volatile] = ACTIONS(2234),
    [anon_sym_restrict] = ACTIONS(2234),
    [anon_sym___restrict__] = ACTIONS(2234),
    [anon_sym__Atomic] = ACTIONS(2234),
    [anon_sym__Noreturn] = ACTIONS(2234),
    [anon_sym_noreturn] = ACTIONS(2234),
    [anon_sym__Nonnull] = ACTIONS(2234),
    [anon_sym_mutable] = ACTIONS(2234),
    [anon_sym_constinit] = ACTIONS(2234),
    [anon_sym_consteval] = ACTIONS(2234),
    [anon_sym___shared__] = ACTIONS(2234),
    [anon_sym___local__] = ACTIONS(2234),
    [anon_sym___constant__] = ACTIONS(2234),
    [anon_sym___managed__] = ACTIONS(2234),
    [anon_sym___grid_constant__] = ACTIONS(2234),
    [anon_sym_alignas] = ACTIONS(2234),
    [anon_sym__Alignas] = ACTIONS(2234),
    [sym_primitive_type] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2234),
    [anon_sym_class] = ACTIONS(2234),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_union] = ACTIONS(2234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2234),
    [anon_sym_decltype] = ACTIONS(2234),
    [anon_sym_explicit] = ACTIONS(2234),
    [anon_sym_typename] = ACTIONS(2234),
    [anon_sym_template] = ACTIONS(2234),
    [anon_sym_operator] = ACTIONS(2234),
    [anon_sym_friend] = ACTIONS(2234),
    [anon_sym_public] = ACTIONS(2234),
    [anon_sym_private] = ACTIONS(2234),
    [anon_sym_protected] = ACTIONS(2234),
    [anon_sym_using] = ACTIONS(2234),
    [anon_sym_static_assert] = ACTIONS(2234),
    [anon_sym___launch_bounds__] = ACTIONS(2234),
  },
  [STATE(2053)] = {
    [sym_identifier] = ACTIONS(2387),
    [aux_sym_preproc_def_token1] = ACTIONS(2387),
    [aux_sym_preproc_if_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2387),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2387),
    [sym_preproc_directive] = ACTIONS(2387),
    [anon_sym_LPAREN2] = ACTIONS(2389),
    [anon_sym_TILDE] = ACTIONS(2389),
    [anon_sym_STAR] = ACTIONS(2389),
    [anon_sym_AMP_AMP] = ACTIONS(2389),
    [anon_sym_AMP] = ACTIONS(2387),
    [anon_sym_SEMI] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2387),
    [anon_sym_typedef] = ACTIONS(2387),
    [anon_sym___device__] = ACTIONS(2387),
    [anon_sym___host__] = ACTIONS(2387),
    [anon_sym___global__] = ACTIONS(2387),
    [anon_sym___forceinline__] = ACTIONS(2387),
    [anon_sym___noinline__] = ACTIONS(2387),
    [anon_sym_virtual] = ACTIONS(2387),
    [anon_sym_extern] = ACTIONS(2387),
    [anon_sym___attribute__] = ACTIONS(2387),
    [anon_sym___attribute] = ACTIONS(2387),
    [anon_sym_COLON_COLON] = ACTIONS(2389),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2389),
    [anon_sym___declspec] = ACTIONS(2387),
    [anon_sym___based] = ACTIONS(2387),
    [anon_sym_RBRACE] = ACTIONS(2389),
    [anon_sym_signed] = ACTIONS(2387),
    [anon_sym_unsigned] = ACTIONS(2387),
    [anon_sym_long] = ACTIONS(2387),
    [anon_sym_short] = ACTIONS(2387),
    [anon_sym_LBRACK] = ACTIONS(2387),
    [anon_sym_static] = ACTIONS(2387),
    [anon_sym_register] = ACTIONS(2387),
    [anon_sym_inline] = ACTIONS(2387),
    [anon_sym___inline] = ACTIONS(2387),
    [anon_sym___inline__] = ACTIONS(2387),
    [anon_sym___forceinline] = ACTIONS(2387),
    [anon_sym_thread_local] = ACTIONS(2387),
    [anon_sym___thread] = ACTIONS(2387),
    [anon_sym_const] = ACTIONS(2387),
    [anon_sym_constexpr] = ACTIONS(2387),
    [anon_sym_volatile] = ACTIONS(2387),
    [anon_sym_restrict] = ACTIONS(2387),
    [anon_sym___restrict__] = ACTIONS(2387),
    [anon_sym__Atomic] = ACTIONS(2387),
    [anon_sym__Noreturn] = ACTIONS(2387),
    [anon_sym_noreturn] = ACTIONS(2387),
    [anon_sym__Nonnull] = ACTIONS(2387),
    [anon_sym_mutable] = ACTIONS(2387),
    [anon_sym_constinit] = ACTIONS(2387),
    [anon_sym_consteval] = ACTIONS(2387),
    [anon_sym___shared__] = ACTIONS(2387),
    [anon_sym___local__] = ACTIONS(2387),
    [anon_sym___constant__] = ACTIONS(2387),
    [anon_sym___managed__] = ACTIONS(2387),
    [anon_sym___grid_constant__] = ACTIONS(2387),
    [anon_sym_alignas] = ACTIONS(2387),
    [anon_sym__Alignas] = ACTIONS(2387),
    [sym_primitive_type] = ACTIONS(2387),
    [anon_sym_enum] = ACTIONS(2387),
    [anon_sym_class] = ACTIONS(2387),
    [anon_sym_struct] = ACTIONS(2387),
    [anon_sym_union] = ACTIONS(2387),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2387),
    [anon_sym_decltype] = ACTIONS(2387),
    [anon_sym_explicit] = ACTIONS(2387),
    [anon_sym_typename] = ACTIONS(2387),
    [anon_sym_template] = ACTIONS(2387),
    [anon_sym_operator] = ACTIONS(2387),
    [anon_sym_friend] = ACTIONS(2387),
    [anon_sym_public] = ACTIONS(2387),
    [anon_sym_private] = ACTIONS(2387),
    [anon_sym_protected] = ACTIONS(2387),
    [anon_sym_using] = ACTIONS(2387),
    [anon_sym_static_assert] = ACTIONS(2387),
    [anon_sym___launch_bounds__] = ACTIONS(2387),
  },
  [STATE(2054)] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token2] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym___device__] = ACTIONS(2320),
    [anon_sym___host__] = ACTIONS(2320),
    [anon_sym___global__] = ACTIONS(2320),
    [anon_sym___forceinline__] = ACTIONS(2320),
    [anon_sym___noinline__] = ACTIONS(2320),
    [anon_sym_virtual] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym___attribute] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym__Nonnull] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym___shared__] = ACTIONS(2320),
    [anon_sym___local__] = ACTIONS(2320),
    [anon_sym___constant__] = ACTIONS(2320),
    [anon_sym___managed__] = ACTIONS(2320),
    [anon_sym___grid_constant__] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_friend] = ACTIONS(2320),
    [anon_sym_public] = ACTIONS(2320),
    [anon_sym_private] = ACTIONS(2320),
    [anon_sym_protected] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym___launch_bounds__] = ACTIONS(2320),
  },
  [STATE(2055)] = {
    [sym_identifier] = ACTIONS(5533),
    [aux_sym_preproc_def_token1] = ACTIONS(5533),
    [aux_sym_preproc_if_token1] = ACTIONS(5533),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5533),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5533),
    [sym_preproc_directive] = ACTIONS(5533),
    [anon_sym_LPAREN2] = ACTIONS(5535),
    [anon_sym_TILDE] = ACTIONS(5535),
    [anon_sym_STAR] = ACTIONS(5535),
    [anon_sym_AMP_AMP] = ACTIONS(5535),
    [anon_sym_AMP] = ACTIONS(5533),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym___extension__] = ACTIONS(5533),
    [anon_sym_typedef] = ACTIONS(5533),
    [anon_sym___device__] = ACTIONS(5533),
    [anon_sym___host__] = ACTIONS(5533),
    [anon_sym___global__] = ACTIONS(5533),
    [anon_sym___forceinline__] = ACTIONS(5533),
    [anon_sym___noinline__] = ACTIONS(5533),
    [anon_sym_virtual] = ACTIONS(5533),
    [anon_sym_extern] = ACTIONS(5533),
    [anon_sym___attribute__] = ACTIONS(5533),
    [anon_sym___attribute] = ACTIONS(5533),
    [anon_sym_COLON_COLON] = ACTIONS(5535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5535),
    [anon_sym___declspec] = ACTIONS(5533),
    [anon_sym___based] = ACTIONS(5533),
    [anon_sym_RBRACE] = ACTIONS(5535),
    [anon_sym_signed] = ACTIONS(5533),
    [anon_sym_unsigned] = ACTIONS(5533),
    [anon_sym_long] = ACTIONS(5533),
    [anon_sym_short] = ACTIONS(5533),
    [anon_sym_LBRACK] = ACTIONS(5533),
    [anon_sym_static] = ACTIONS(5533),
    [anon_sym_register] = ACTIONS(5533),
    [anon_sym_inline] = ACTIONS(5533),
    [anon_sym___inline] = ACTIONS(5533),
    [anon_sym___inline__] = ACTIONS(5533),
    [anon_sym___forceinline] = ACTIONS(5533),
    [anon_sym_thread_local] = ACTIONS(5533),
    [anon_sym___thread] = ACTIONS(5533),
    [anon_sym_const] = ACTIONS(5533),
    [anon_sym_constexpr] = ACTIONS(5533),
    [anon_sym_volatile] = ACTIONS(5533),
    [anon_sym_restrict] = ACTIONS(5533),
    [anon_sym___restrict__] = ACTIONS(5533),
    [anon_sym__Atomic] = ACTIONS(5533),
    [anon_sym__Noreturn] = ACTIONS(5533),
    [anon_sym_noreturn] = ACTIONS(5533),
    [anon_sym__Nonnull] = ACTIONS(5533),
    [anon_sym_mutable] = ACTIONS(5533),
    [anon_sym_constinit] = ACTIONS(5533),
    [anon_sym_consteval] = ACTIONS(5533),
    [anon_sym___shared__] = ACTIONS(5533),
    [anon_sym___local__] = ACTIONS(5533),
    [anon_sym___constant__] = ACTIONS(5533),
    [anon_sym___managed__] = ACTIONS(5533),
    [anon_sym___grid_constant__] = ACTIONS(5533),
    [anon_sym_alignas] = ACTIONS(5533),
    [anon_sym__Alignas] = ACTIONS(5533),
    [sym_primitive_type] = ACTIONS(5533),
    [anon_sym_enum] = ACTIONS(5533),
    [anon_sym_class] = ACTIONS(5533),
    [anon_sym_struct] = ACTIONS(5533),
    [anon_sym_union] = ACTIONS(5533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5533),
    [anon_sym_decltype] = ACTIONS(5533),
    [anon_sym_explicit] = ACTIONS(5533),
    [anon_sym_typename] = ACTIONS(5533),
    [anon_sym_template] = ACTIONS(5533),
    [anon_sym_operator] = ACTIONS(5533),
    [anon_sym_friend] = ACTIONS(5533),
    [anon_sym_public] = ACTIONS(5533),
    [anon_sym_private] = ACTIONS(5533),
    [anon_sym_protected] = ACTIONS(5533),
    [anon_sym_using] = ACTIONS(5533),
    [anon_sym_static_assert] = ACTIONS(5533),
    [anon_sym___launch_bounds__] = ACTIONS(5533),
  },
  [STATE(2056)] = {
    [sym_identifier] = ACTIONS(2497),
    [aux_sym_preproc_def_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token2] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2497),
    [sym_preproc_directive] = ACTIONS(2497),
    [anon_sym_LPAREN2] = ACTIONS(2499),
    [anon_sym_TILDE] = ACTIONS(2499),
    [anon_sym_STAR] = ACTIONS(2499),
    [anon_sym_AMP_AMP] = ACTIONS(2499),
    [anon_sym_AMP] = ACTIONS(2497),
    [anon_sym_SEMI] = ACTIONS(2499),
    [anon_sym___extension__] = ACTIONS(2497),
    [anon_sym_typedef] = ACTIONS(2497),
    [anon_sym___device__] = ACTIONS(2497),
    [anon_sym___host__] = ACTIONS(2497),
    [anon_sym___global__] = ACTIONS(2497),
    [anon_sym___forceinline__] = ACTIONS(2497),
    [anon_sym___noinline__] = ACTIONS(2497),
    [anon_sym_virtual] = ACTIONS(2497),
    [anon_sym_extern] = ACTIONS(2497),
    [anon_sym___attribute__] = ACTIONS(2497),
    [anon_sym___attribute] = ACTIONS(2497),
    [anon_sym_COLON_COLON] = ACTIONS(2499),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2499),
    [anon_sym___declspec] = ACTIONS(2497),
    [anon_sym___based] = ACTIONS(2497),
    [anon_sym_signed] = ACTIONS(2497),
    [anon_sym_unsigned] = ACTIONS(2497),
    [anon_sym_long] = ACTIONS(2497),
    [anon_sym_short] = ACTIONS(2497),
    [anon_sym_LBRACK] = ACTIONS(2497),
    [anon_sym_static] = ACTIONS(2497),
    [anon_sym_register] = ACTIONS(2497),
    [anon_sym_inline] = ACTIONS(2497),
    [anon_sym___inline] = ACTIONS(2497),
    [anon_sym___inline__] = ACTIONS(2497),
    [anon_sym___forceinline] = ACTIONS(2497),
    [anon_sym_thread_local] = ACTIONS(2497),
    [anon_sym___thread] = ACTIONS(2497),
    [anon_sym_const] = ACTIONS(2497),
    [anon_sym_constexpr] = ACTIONS(2497),
    [anon_sym_volatile] = ACTIONS(2497),
    [anon_sym_restrict] = ACTIONS(2497),
    [anon_sym___restrict__] = ACTIONS(2497),
    [anon_sym__Atomic] = ACTIONS(2497),
    [anon_sym__Noreturn] = ACTIONS(2497),
    [anon_sym_noreturn] = ACTIONS(2497),
    [anon_sym__Nonnull] = ACTIONS(2497),
    [anon_sym_mutable] = ACTIONS(2497),
    [anon_sym_constinit] = ACTIONS(2497),
    [anon_sym_consteval] = ACTIONS(2497),
    [anon_sym___shared__] = ACTIONS(2497),
    [anon_sym___local__] = ACTIONS(2497),
    [anon_sym___constant__] = ACTIONS(2497),
    [anon_sym___managed__] = ACTIONS(2497),
    [anon_sym___grid_constant__] = ACTIONS(2497),
    [anon_sym_alignas] = ACTIONS(2497),
    [anon_sym__Alignas] = ACTIONS(2497),
    [sym_primitive_type] = ACTIONS(2497),
    [anon_sym_enum] = ACTIONS(2497),
    [anon_sym_class] = ACTIONS(2497),
    [anon_sym_struct] = ACTIONS(2497),
    [anon_sym_union] = ACTIONS(2497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2497),
    [anon_sym_decltype] = ACTIONS(2497),
    [anon_sym_explicit] = ACTIONS(2497),
    [anon_sym_typename] = ACTIONS(2497),
    [anon_sym_template] = ACTIONS(2497),
    [anon_sym_operator] = ACTIONS(2497),
    [anon_sym_friend] = ACTIONS(2497),
    [anon_sym_public] = ACTIONS(2497),
    [anon_sym_private] = ACTIONS(2497),
    [anon_sym_protected] = ACTIONS(2497),
    [anon_sym_using] = ACTIONS(2497),
    [anon_sym_static_assert] = ACTIONS(2497),
    [anon_sym___launch_bounds__] = ACTIONS(2497),
  },
  [STATE(2057)] = {
    [sym_identifier] = ACTIONS(2501),
    [aux_sym_preproc_def_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token2] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2501),
    [sym_preproc_directive] = ACTIONS(2501),
    [anon_sym_LPAREN2] = ACTIONS(2503),
    [anon_sym_TILDE] = ACTIONS(2503),
    [anon_sym_STAR] = ACTIONS(2503),
    [anon_sym_AMP_AMP] = ACTIONS(2503),
    [anon_sym_AMP] = ACTIONS(2501),
    [anon_sym_SEMI] = ACTIONS(2503),
    [anon_sym___extension__] = ACTIONS(2501),
    [anon_sym_typedef] = ACTIONS(2501),
    [anon_sym___device__] = ACTIONS(2501),
    [anon_sym___host__] = ACTIONS(2501),
    [anon_sym___global__] = ACTIONS(2501),
    [anon_sym___forceinline__] = ACTIONS(2501),
    [anon_sym___noinline__] = ACTIONS(2501),
    [anon_sym_virtual] = ACTIONS(2501),
    [anon_sym_extern] = ACTIONS(2501),
    [anon_sym___attribute__] = ACTIONS(2501),
    [anon_sym___attribute] = ACTIONS(2501),
    [anon_sym_COLON_COLON] = ACTIONS(2503),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2503),
    [anon_sym___declspec] = ACTIONS(2501),
    [anon_sym___based] = ACTIONS(2501),
    [anon_sym_signed] = ACTIONS(2501),
    [anon_sym_unsigned] = ACTIONS(2501),
    [anon_sym_long] = ACTIONS(2501),
    [anon_sym_short] = ACTIONS(2501),
    [anon_sym_LBRACK] = ACTIONS(2501),
    [anon_sym_static] = ACTIONS(2501),
    [anon_sym_register] = ACTIONS(2501),
    [anon_sym_inline] = ACTIONS(2501),
    [anon_sym___inline] = ACTIONS(2501),
    [anon_sym___inline__] = ACTIONS(2501),
    [anon_sym___forceinline] = ACTIONS(2501),
    [anon_sym_thread_local] = ACTIONS(2501),
    [anon_sym___thread] = ACTIONS(2501),
    [anon_sym_const] = ACTIONS(2501),
    [anon_sym_constexpr] = ACTIONS(2501),
    [anon_sym_volatile] = ACTIONS(2501),
    [anon_sym_restrict] = ACTIONS(2501),
    [anon_sym___restrict__] = ACTIONS(2501),
    [anon_sym__Atomic] = ACTIONS(2501),
    [anon_sym__Noreturn] = ACTIONS(2501),
    [anon_sym_noreturn] = ACTIONS(2501),
    [anon_sym__Nonnull] = ACTIONS(2501),
    [anon_sym_mutable] = ACTIONS(2501),
    [anon_sym_constinit] = ACTIONS(2501),
    [anon_sym_consteval] = ACTIONS(2501),
    [anon_sym___shared__] = ACTIONS(2501),
    [anon_sym___local__] = ACTIONS(2501),
    [anon_sym___constant__] = ACTIONS(2501),
    [anon_sym___managed__] = ACTIONS(2501),
    [anon_sym___grid_constant__] = ACTIONS(2501),
    [anon_sym_alignas] = ACTIONS(2501),
    [anon_sym__Alignas] = ACTIONS(2501),
    [sym_primitive_type] = ACTIONS(2501),
    [anon_sym_enum] = ACTIONS(2501),
    [anon_sym_class] = ACTIONS(2501),
    [anon_sym_struct] = ACTIONS(2501),
    [anon_sym_union] = ACTIONS(2501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2501),
    [anon_sym_decltype] = ACTIONS(2501),
    [anon_sym_explicit] = ACTIONS(2501),
    [anon_sym_typename] = ACTIONS(2501),
    [anon_sym_template] = ACTIONS(2501),
    [anon_sym_operator] = ACTIONS(2501),
    [anon_sym_friend] = ACTIONS(2501),
    [anon_sym_public] = ACTIONS(2501),
    [anon_sym_private] = ACTIONS(2501),
    [anon_sym_protected] = ACTIONS(2501),
    [anon_sym_using] = ACTIONS(2501),
    [anon_sym_static_assert] = ACTIONS(2501),
    [anon_sym___launch_bounds__] = ACTIONS(2501),
  },
  [STATE(2058)] = {
    [sym_identifier] = ACTIONS(2415),
    [aux_sym_preproc_def_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token1] = ACTIONS(2415),
    [aux_sym_preproc_if_token2] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2415),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2415),
    [sym_preproc_directive] = ACTIONS(2415),
    [anon_sym_LPAREN2] = ACTIONS(2417),
    [anon_sym_TILDE] = ACTIONS(2417),
    [anon_sym_STAR] = ACTIONS(2417),
    [anon_sym_AMP_AMP] = ACTIONS(2417),
    [anon_sym_AMP] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(2417),
    [anon_sym___extension__] = ACTIONS(2415),
    [anon_sym_typedef] = ACTIONS(2415),
    [anon_sym___device__] = ACTIONS(2415),
    [anon_sym___host__] = ACTIONS(2415),
    [anon_sym___global__] = ACTIONS(2415),
    [anon_sym___forceinline__] = ACTIONS(2415),
    [anon_sym___noinline__] = ACTIONS(2415),
    [anon_sym_virtual] = ACTIONS(2415),
    [anon_sym_extern] = ACTIONS(2415),
    [anon_sym___attribute__] = ACTIONS(2415),
    [anon_sym___attribute] = ACTIONS(2415),
    [anon_sym_COLON_COLON] = ACTIONS(2417),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2417),
    [anon_sym___declspec] = ACTIONS(2415),
    [anon_sym___based] = ACTIONS(2415),
    [anon_sym_signed] = ACTIONS(2415),
    [anon_sym_unsigned] = ACTIONS(2415),
    [anon_sym_long] = ACTIONS(2415),
    [anon_sym_short] = ACTIONS(2415),
    [anon_sym_LBRACK] = ACTIONS(2415),
    [anon_sym_static] = ACTIONS(2415),
    [anon_sym_register] = ACTIONS(2415),
    [anon_sym_inline] = ACTIONS(2415),
    [anon_sym___inline] = ACTIONS(2415),
    [anon_sym___inline__] = ACTIONS(2415),
    [anon_sym___forceinline] = ACTIONS(2415),
    [anon_sym_thread_local] = ACTIONS(2415),
    [anon_sym___thread] = ACTIONS(2415),
    [anon_sym_const] = ACTIONS(2415),
    [anon_sym_constexpr] = ACTIONS(2415),
    [anon_sym_volatile] = ACTIONS(2415),
    [anon_sym_restrict] = ACTIONS(2415),
    [anon_sym___restrict__] = ACTIONS(2415),
    [anon_sym__Atomic] = ACTIONS(2415),
    [anon_sym__Noreturn] = ACTIONS(2415),
    [anon_sym_noreturn] = ACTIONS(2415),
    [anon_sym__Nonnull] = ACTIONS(2415),
    [anon_sym_mutable] = ACTIONS(2415),
    [anon_sym_constinit] = ACTIONS(2415),
    [anon_sym_consteval] = ACTIONS(2415),
    [anon_sym___shared__] = ACTIONS(2415),
    [anon_sym___local__] = ACTIONS(2415),
    [anon_sym___constant__] = ACTIONS(2415),
    [anon_sym___managed__] = ACTIONS(2415),
    [anon_sym___grid_constant__] = ACTIONS(2415),
    [anon_sym_alignas] = ACTIONS(2415),
    [anon_sym__Alignas] = ACTIONS(2415),
    [sym_primitive_type] = ACTIONS(2415),
    [anon_sym_enum] = ACTIONS(2415),
    [anon_sym_class] = ACTIONS(2415),
    [anon_sym_struct] = ACTIONS(2415),
    [anon_sym_union] = ACTIONS(2415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2415),
    [anon_sym_decltype] = ACTIONS(2415),
    [anon_sym_explicit] = ACTIONS(2415),
    [anon_sym_typename] = ACTIONS(2415),
    [anon_sym_template] = ACTIONS(2415),
    [anon_sym_operator] = ACTIONS(2415),
    [anon_sym_friend] = ACTIONS(2415),
    [anon_sym_public] = ACTIONS(2415),
    [anon_sym_private] = ACTIONS(2415),
    [anon_sym_protected] = ACTIONS(2415),
    [anon_sym_using] = ACTIONS(2415),
    [anon_sym_static_assert] = ACTIONS(2415),
    [anon_sym___launch_bounds__] = ACTIONS(2415),
  },
  [STATE(2059)] = {
    [sym_identifier] = ACTIONS(5517),
    [aux_sym_preproc_def_token1] = ACTIONS(5517),
    [aux_sym_preproc_if_token1] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5517),
    [sym_preproc_directive] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5519),
    [anon_sym_TILDE] = ACTIONS(5519),
    [anon_sym_STAR] = ACTIONS(5519),
    [anon_sym_AMP_AMP] = ACTIONS(5519),
    [anon_sym_AMP] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym___extension__] = ACTIONS(5517),
    [anon_sym_typedef] = ACTIONS(5517),
    [anon_sym___device__] = ACTIONS(5517),
    [anon_sym___host__] = ACTIONS(5517),
    [anon_sym___global__] = ACTIONS(5517),
    [anon_sym___forceinline__] = ACTIONS(5517),
    [anon_sym___noinline__] = ACTIONS(5517),
    [anon_sym_virtual] = ACTIONS(5517),
    [anon_sym_extern] = ACTIONS(5517),
    [anon_sym___attribute__] = ACTIONS(5517),
    [anon_sym___attribute] = ACTIONS(5517),
    [anon_sym_COLON_COLON] = ACTIONS(5519),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5519),
    [anon_sym___declspec] = ACTIONS(5517),
    [anon_sym___based] = ACTIONS(5517),
    [anon_sym_RBRACE] = ACTIONS(5519),
    [anon_sym_signed] = ACTIONS(5517),
    [anon_sym_unsigned] = ACTIONS(5517),
    [anon_sym_long] = ACTIONS(5517),
    [anon_sym_short] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5517),
    [anon_sym_static] = ACTIONS(5517),
    [anon_sym_register] = ACTIONS(5517),
    [anon_sym_inline] = ACTIONS(5517),
    [anon_sym___inline] = ACTIONS(5517),
    [anon_sym___inline__] = ACTIONS(5517),
    [anon_sym___forceinline] = ACTIONS(5517),
    [anon_sym_thread_local] = ACTIONS(5517),
    [anon_sym___thread] = ACTIONS(5517),
    [anon_sym_const] = ACTIONS(5517),
    [anon_sym_constexpr] = ACTIONS(5517),
    [anon_sym_volatile] = ACTIONS(5517),
    [anon_sym_restrict] = ACTIONS(5517),
    [anon_sym___restrict__] = ACTIONS(5517),
    [anon_sym__Atomic] = ACTIONS(5517),
    [anon_sym__Noreturn] = ACTIONS(5517),
    [anon_sym_noreturn] = ACTIONS(5517),
    [anon_sym__Nonnull] = ACTIONS(5517),
    [anon_sym_mutable] = ACTIONS(5517),
    [anon_sym_constinit] = ACTIONS(5517),
    [anon_sym_consteval] = ACTIONS(5517),
    [anon_sym___shared__] = ACTIONS(5517),
    [anon_sym___local__] = ACTIONS(5517),
    [anon_sym___constant__] = ACTIONS(5517),
    [anon_sym___managed__] = ACTIONS(5517),
    [anon_sym___grid_constant__] = ACTIONS(5517),
    [anon_sym_alignas] = ACTIONS(5517),
    [anon_sym__Alignas] = ACTIONS(5517),
    [sym_primitive_type] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_class] = ACTIONS(5517),
    [anon_sym_struct] = ACTIONS(5517),
    [anon_sym_union] = ACTIONS(5517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5517),
    [anon_sym_decltype] = ACTIONS(5517),
    [anon_sym_explicit] = ACTIONS(5517),
    [anon_sym_typename] = ACTIONS(5517),
    [anon_sym_template] = ACTIONS(5517),
    [anon_sym_operator] = ACTIONS(5517),
    [anon_sym_friend] = ACTIONS(5517),
    [anon_sym_public] = ACTIONS(5517),
    [anon_sym_private] = ACTIONS(5517),
    [anon_sym_protected] = ACTIONS(5517),
    [anon_sym_using] = ACTIONS(5517),
    [anon_sym_static_assert] = ACTIONS(5517),
    [anon_sym___launch_bounds__] = ACTIONS(5517),
  },
  [STATE(2060)] = {
    [sym_identifier] = ACTIONS(5537),
    [aux_sym_preproc_def_token1] = ACTIONS(5537),
    [aux_sym_preproc_if_token1] = ACTIONS(5537),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5537),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5537),
    [sym_preproc_directive] = ACTIONS(5537),
    [anon_sym_LPAREN2] = ACTIONS(5539),
    [anon_sym_TILDE] = ACTIONS(5539),
    [anon_sym_STAR] = ACTIONS(5539),
    [anon_sym_AMP_AMP] = ACTIONS(5539),
    [anon_sym_AMP] = ACTIONS(5537),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym___extension__] = ACTIONS(5537),
    [anon_sym_typedef] = ACTIONS(5537),
    [anon_sym___device__] = ACTIONS(5537),
    [anon_sym___host__] = ACTIONS(5537),
    [anon_sym___global__] = ACTIONS(5537),
    [anon_sym___forceinline__] = ACTIONS(5537),
    [anon_sym___noinline__] = ACTIONS(5537),
    [anon_sym_virtual] = ACTIONS(5537),
    [anon_sym_extern] = ACTIONS(5537),
    [anon_sym___attribute__] = ACTIONS(5537),
    [anon_sym___attribute] = ACTIONS(5537),
    [anon_sym_COLON_COLON] = ACTIONS(5539),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5539),
    [anon_sym___declspec] = ACTIONS(5537),
    [anon_sym___based] = ACTIONS(5537),
    [anon_sym_RBRACE] = ACTIONS(5539),
    [anon_sym_signed] = ACTIONS(5537),
    [anon_sym_unsigned] = ACTIONS(5537),
    [anon_sym_long] = ACTIONS(5537),
    [anon_sym_short] = ACTIONS(5537),
    [anon_sym_LBRACK] = ACTIONS(5537),
    [anon_sym_static] = ACTIONS(5537),
    [anon_sym_register] = ACTIONS(5537),
    [anon_sym_inline] = ACTIONS(5537),
    [anon_sym___inline] = ACTIONS(5537),
    [anon_sym___inline__] = ACTIONS(5537),
    [anon_sym___forceinline] = ACTIONS(5537),
    [anon_sym_thread_local] = ACTIONS(5537),
    [anon_sym___thread] = ACTIONS(5537),
    [anon_sym_const] = ACTIONS(5537),
    [anon_sym_constexpr] = ACTIONS(5537),
    [anon_sym_volatile] = ACTIONS(5537),
    [anon_sym_restrict] = ACTIONS(5537),
    [anon_sym___restrict__] = ACTIONS(5537),
    [anon_sym__Atomic] = ACTIONS(5537),
    [anon_sym__Noreturn] = ACTIONS(5537),
    [anon_sym_noreturn] = ACTIONS(5537),
    [anon_sym__Nonnull] = ACTIONS(5537),
    [anon_sym_mutable] = ACTIONS(5537),
    [anon_sym_constinit] = ACTIONS(5537),
    [anon_sym_consteval] = ACTIONS(5537),
    [anon_sym___shared__] = ACTIONS(5537),
    [anon_sym___local__] = ACTIONS(5537),
    [anon_sym___constant__] = ACTIONS(5537),
    [anon_sym___managed__] = ACTIONS(5537),
    [anon_sym___grid_constant__] = ACTIONS(5537),
    [anon_sym_alignas] = ACTIONS(5537),
    [anon_sym__Alignas] = ACTIONS(5537),
    [sym_primitive_type] = ACTIONS(5537),
    [anon_sym_enum] = ACTIONS(5537),
    [anon_sym_class] = ACTIONS(5537),
    [anon_sym_struct] = ACTIONS(5537),
    [anon_sym_union] = ACTIONS(5537),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5537),
    [anon_sym_decltype] = ACTIONS(5537),
    [anon_sym_explicit] = ACTIONS(5537),
    [anon_sym_typename] = ACTIONS(5537),
    [anon_sym_template] = ACTIONS(5537),
    [anon_sym_operator] = ACTIONS(5537),
    [anon_sym_friend] = ACTIONS(5537),
    [anon_sym_public] = ACTIONS(5537),
    [anon_sym_private] = ACTIONS(5537),
    [anon_sym_protected] = ACTIONS(5537),
    [anon_sym_using] = ACTIONS(5537),
    [anon_sym_static_assert] = ACTIONS(5537),
    [anon_sym___launch_bounds__] = ACTIONS(5537),
  },
  [STATE(2061)] = {
    [sym_identifier] = ACTIONS(2501),
    [aux_sym_preproc_def_token1] = ACTIONS(2501),
    [aux_sym_preproc_if_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2501),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2501),
    [sym_preproc_directive] = ACTIONS(2501),
    [anon_sym_LPAREN2] = ACTIONS(2503),
    [anon_sym_TILDE] = ACTIONS(2503),
    [anon_sym_STAR] = ACTIONS(2503),
    [anon_sym_AMP_AMP] = ACTIONS(2503),
    [anon_sym_AMP] = ACTIONS(2501),
    [anon_sym_SEMI] = ACTIONS(2503),
    [anon_sym___extension__] = ACTIONS(2501),
    [anon_sym_typedef] = ACTIONS(2501),
    [anon_sym___device__] = ACTIONS(2501),
    [anon_sym___host__] = ACTIONS(2501),
    [anon_sym___global__] = ACTIONS(2501),
    [anon_sym___forceinline__] = ACTIONS(2501),
    [anon_sym___noinline__] = ACTIONS(2501),
    [anon_sym_virtual] = ACTIONS(2501),
    [anon_sym_extern] = ACTIONS(2501),
    [anon_sym___attribute__] = ACTIONS(2501),
    [anon_sym___attribute] = ACTIONS(2501),
    [anon_sym_COLON_COLON] = ACTIONS(2503),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2503),
    [anon_sym___declspec] = ACTIONS(2501),
    [anon_sym___based] = ACTIONS(2501),
    [anon_sym_RBRACE] = ACTIONS(2503),
    [anon_sym_signed] = ACTIONS(2501),
    [anon_sym_unsigned] = ACTIONS(2501),
    [anon_sym_long] = ACTIONS(2501),
    [anon_sym_short] = ACTIONS(2501),
    [anon_sym_LBRACK] = ACTIONS(2501),
    [anon_sym_static] = ACTIONS(2501),
    [anon_sym_register] = ACTIONS(2501),
    [anon_sym_inline] = ACTIONS(2501),
    [anon_sym___inline] = ACTIONS(2501),
    [anon_sym___inline__] = ACTIONS(2501),
    [anon_sym___forceinline] = ACTIONS(2501),
    [anon_sym_thread_local] = ACTIONS(2501),
    [anon_sym___thread] = ACTIONS(2501),
    [anon_sym_const] = ACTIONS(2501),
    [anon_sym_constexpr] = ACTIONS(2501),
    [anon_sym_volatile] = ACTIONS(2501),
    [anon_sym_restrict] = ACTIONS(2501),
    [anon_sym___restrict__] = ACTIONS(2501),
    [anon_sym__Atomic] = ACTIONS(2501),
    [anon_sym__Noreturn] = ACTIONS(2501),
    [anon_sym_noreturn] = ACTIONS(2501),
    [anon_sym__Nonnull] = ACTIONS(2501),
    [anon_sym_mutable] = ACTIONS(2501),
    [anon_sym_constinit] = ACTIONS(2501),
    [anon_sym_consteval] = ACTIONS(2501),
    [anon_sym___shared__] = ACTIONS(2501),
    [anon_sym___local__] = ACTIONS(2501),
    [anon_sym___constant__] = ACTIONS(2501),
    [anon_sym___managed__] = ACTIONS(2501),
    [anon_sym___grid_constant__] = ACTIONS(2501),
    [anon_sym_alignas] = ACTIONS(2501),
    [anon_sym__Alignas] = ACTIONS(2501),
    [sym_primitive_type] = ACTIONS(2501),
    [anon_sym_enum] = ACTIONS(2501),
    [anon_sym_class] = ACTIONS(2501),
    [anon_sym_struct] = ACTIONS(2501),
    [anon_sym_union] = ACTIONS(2501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2501),
    [anon_sym_decltype] = ACTIONS(2501),
    [anon_sym_explicit] = ACTIONS(2501),
    [anon_sym_typename] = ACTIONS(2501),
    [anon_sym_template] = ACTIONS(2501),
    [anon_sym_operator] = ACTIONS(2501),
    [anon_sym_friend] = ACTIONS(2501),
    [anon_sym_public] = ACTIONS(2501),
    [anon_sym_private] = ACTIONS(2501),
    [anon_sym_protected] = ACTIONS(2501),
    [anon_sym_using] = ACTIONS(2501),
    [anon_sym_static_assert] = ACTIONS(2501),
    [anon_sym___launch_bounds__] = ACTIONS(2501),
  },
  [STATE(2062)] = {
    [sym_identifier] = ACTIONS(5589),
    [aux_sym_preproc_def_token1] = ACTIONS(5589),
    [aux_sym_preproc_if_token1] = ACTIONS(5589),
    [aux_sym_preproc_if_token2] = ACTIONS(5589),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5589),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5589),
    [sym_preproc_directive] = ACTIONS(5589),
    [anon_sym_LPAREN2] = ACTIONS(5591),
    [anon_sym_TILDE] = ACTIONS(5591),
    [anon_sym_STAR] = ACTIONS(5591),
    [anon_sym_AMP_AMP] = ACTIONS(5591),
    [anon_sym_AMP] = ACTIONS(5589),
    [anon_sym_SEMI] = ACTIONS(5591),
    [anon_sym___extension__] = ACTIONS(5589),
    [anon_sym_typedef] = ACTIONS(5589),
    [anon_sym___device__] = ACTIONS(5589),
    [anon_sym___host__] = ACTIONS(5589),
    [anon_sym___global__] = ACTIONS(5589),
    [anon_sym___forceinline__] = ACTIONS(5589),
    [anon_sym___noinline__] = ACTIONS(5589),
    [anon_sym_virtual] = ACTIONS(5589),
    [anon_sym_extern] = ACTIONS(5589),
    [anon_sym___attribute__] = ACTIONS(5589),
    [anon_sym___attribute] = ACTIONS(5589),
    [anon_sym_COLON_COLON] = ACTIONS(5591),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5591),
    [anon_sym___declspec] = ACTIONS(5589),
    [anon_sym___based] = ACTIONS(5589),
    [anon_sym_signed] = ACTIONS(5589),
    [anon_sym_unsigned] = ACTIONS(5589),
    [anon_sym_long] = ACTIONS(5589),
    [anon_sym_short] = ACTIONS(5589),
    [anon_sym_LBRACK] = ACTIONS(5589),
    [anon_sym_static] = ACTIONS(5589),
    [anon_sym_register] = ACTIONS(5589),
    [anon_sym_inline] = ACTIONS(5589),
    [anon_sym___inline] = ACTIONS(5589),
    [anon_sym___inline__] = ACTIONS(5589),
    [anon_sym___forceinline] = ACTIONS(5589),
    [anon_sym_thread_local] = ACTIONS(5589),
    [anon_sym___thread] = ACTIONS(5589),
    [anon_sym_const] = ACTIONS(5589),
    [anon_sym_constexpr] = ACTIONS(5589),
    [anon_sym_volatile] = ACTIONS(5589),
    [anon_sym_restrict] = ACTIONS(5589),
    [anon_sym___restrict__] = ACTIONS(5589),
    [anon_sym__Atomic] = ACTIONS(5589),
    [anon_sym__Noreturn] = ACTIONS(5589),
    [anon_sym_noreturn] = ACTIONS(5589),
    [anon_sym__Nonnull] = ACTIONS(5589),
    [anon_sym_mutable] = ACTIONS(5589),
    [anon_sym_constinit] = ACTIONS(5589),
    [anon_sym_consteval] = ACTIONS(5589),
    [anon_sym___shared__] = ACTIONS(5589),
    [anon_sym___local__] = ACTIONS(5589),
    [anon_sym___constant__] = ACTIONS(5589),
    [anon_sym___managed__] = ACTIONS(5589),
    [anon_sym___grid_constant__] = ACTIONS(5589),
    [anon_sym_alignas] = ACTIONS(5589),
    [anon_sym__Alignas] = ACTIONS(5589),
    [sym_primitive_type] = ACTIONS(5589),
    [anon_sym_enum] = ACTIONS(5589),
    [anon_sym_class] = ACTIONS(5589),
    [anon_sym_struct] = ACTIONS(5589),
    [anon_sym_union] = ACTIONS(5589),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5589),
    [anon_sym_decltype] = ACTIONS(5589),
    [anon_sym_explicit] = ACTIONS(5589),
    [anon_sym_typename] = ACTIONS(5589),
    [anon_sym_template] = ACTIONS(5589),
    [anon_sym_operator] = ACTIONS(5589),
    [anon_sym_friend] = ACTIONS(5589),
    [anon_sym_public] = ACTIONS(5589),
    [anon_sym_private] = ACTIONS(5589),
    [anon_sym_protected] = ACTIONS(5589),
    [anon_sym_using] = ACTIONS(5589),
    [anon_sym_static_assert] = ACTIONS(5589),
    [anon_sym___launch_bounds__] = ACTIONS(5589),
  },
  [STATE(2063)] = {
    [sym_identifier] = ACTIONS(5593),
    [aux_sym_preproc_def_token1] = ACTIONS(5593),
    [aux_sym_preproc_if_token1] = ACTIONS(5593),
    [aux_sym_preproc_if_token2] = ACTIONS(5593),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5593),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5593),
    [sym_preproc_directive] = ACTIONS(5593),
    [anon_sym_LPAREN2] = ACTIONS(5595),
    [anon_sym_TILDE] = ACTIONS(5595),
    [anon_sym_STAR] = ACTIONS(5595),
    [anon_sym_AMP_AMP] = ACTIONS(5595),
    [anon_sym_AMP] = ACTIONS(5593),
    [anon_sym_SEMI] = ACTIONS(5595),
    [anon_sym___extension__] = ACTIONS(5593),
    [anon_sym_typedef] = ACTIONS(5593),
    [anon_sym___device__] = ACTIONS(5593),
    [anon_sym___host__] = ACTIONS(5593),
    [anon_sym___global__] = ACTIONS(5593),
    [anon_sym___forceinline__] = ACTIONS(5593),
    [anon_sym___noinline__] = ACTIONS(5593),
    [anon_sym_virtual] = ACTIONS(5593),
    [anon_sym_extern] = ACTIONS(5593),
    [anon_sym___attribute__] = ACTIONS(5593),
    [anon_sym___attribute] = ACTIONS(5593),
    [anon_sym_COLON_COLON] = ACTIONS(5595),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5595),
    [anon_sym___declspec] = ACTIONS(5593),
    [anon_sym___based] = ACTIONS(5593),
    [anon_sym_signed] = ACTIONS(5593),
    [anon_sym_unsigned] = ACTIONS(5593),
    [anon_sym_long] = ACTIONS(5593),
    [anon_sym_short] = ACTIONS(5593),
    [anon_sym_LBRACK] = ACTIONS(5593),
    [anon_sym_static] = ACTIONS(5593),
    [anon_sym_register] = ACTIONS(5593),
    [anon_sym_inline] = ACTIONS(5593),
    [anon_sym___inline] = ACTIONS(5593),
    [anon_sym___inline__] = ACTIONS(5593),
    [anon_sym___forceinline] = ACTIONS(5593),
    [anon_sym_thread_local] = ACTIONS(5593),
    [anon_sym___thread] = ACTIONS(5593),
    [anon_sym_const] = ACTIONS(5593),
    [anon_sym_constexpr] = ACTIONS(5593),
    [anon_sym_volatile] = ACTIONS(5593),
    [anon_sym_restrict] = ACTIONS(5593),
    [anon_sym___restrict__] = ACTIONS(5593),
    [anon_sym__Atomic] = ACTIONS(5593),
    [anon_sym__Noreturn] = ACTIONS(5593),
    [anon_sym_noreturn] = ACTIONS(5593),
    [anon_sym__Nonnull] = ACTIONS(5593),
    [anon_sym_mutable] = ACTIONS(5593),
    [anon_sym_constinit] = ACTIONS(5593),
    [anon_sym_consteval] = ACTIONS(5593),
    [anon_sym___shared__] = ACTIONS(5593),
    [anon_sym___local__] = ACTIONS(5593),
    [anon_sym___constant__] = ACTIONS(5593),
    [anon_sym___managed__] = ACTIONS(5593),
    [anon_sym___grid_constant__] = ACTIONS(5593),
    [anon_sym_alignas] = ACTIONS(5593),
    [anon_sym__Alignas] = ACTIONS(5593),
    [sym_primitive_type] = ACTIONS(5593),
    [anon_sym_enum] = ACTIONS(5593),
    [anon_sym_class] = ACTIONS(5593),
    [anon_sym_struct] = ACTIONS(5593),
    [anon_sym_union] = ACTIONS(5593),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5593),
    [anon_sym_decltype] = ACTIONS(5593),
    [anon_sym_explicit] = ACTIONS(5593),
    [anon_sym_typename] = ACTIONS(5593),
    [anon_sym_template] = ACTIONS(5593),
    [anon_sym_operator] = ACTIONS(5593),
    [anon_sym_friend] = ACTIONS(5593),
    [anon_sym_public] = ACTIONS(5593),
    [anon_sym_private] = ACTIONS(5593),
    [anon_sym_protected] = ACTIONS(5593),
    [anon_sym_using] = ACTIONS(5593),
    [anon_sym_static_assert] = ACTIONS(5593),
    [anon_sym___launch_bounds__] = ACTIONS(5593),
  },
  [STATE(2064)] = {
    [sym_identifier] = ACTIONS(4350),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_RPAREN] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4352),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4352),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4352),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4352),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4352),
    [anon_sym_SEMI] = ACTIONS(4352),
    [anon_sym___extension__] = ACTIONS(4350),
    [anon_sym___global__] = ACTIONS(4350),
    [anon_sym___attribute__] = ACTIONS(4350),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym___based] = ACTIONS(4350),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_RBRACE] = ACTIONS(4352),
    [anon_sym_signed] = ACTIONS(4350),
    [anon_sym_unsigned] = ACTIONS(4350),
    [anon_sym_long] = ACTIONS(4350),
    [anon_sym_short] = ACTIONS(4350),
    [anon_sym_LBRACK] = ACTIONS(4352),
    [anon_sym_RBRACK] = ACTIONS(4352),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4350),
    [anon_sym_volatile] = ACTIONS(4350),
    [anon_sym_restrict] = ACTIONS(4350),
    [anon_sym___restrict__] = ACTIONS(4350),
    [anon_sym__Atomic] = ACTIONS(4350),
    [anon_sym__Noreturn] = ACTIONS(4350),
    [anon_sym_noreturn] = ACTIONS(4350),
    [anon_sym__Nonnull] = ACTIONS(4350),
    [anon_sym_mutable] = ACTIONS(4350),
    [anon_sym_constinit] = ACTIONS(4350),
    [anon_sym_consteval] = ACTIONS(4350),
    [anon_sym___shared__] = ACTIONS(4350),
    [anon_sym___local__] = ACTIONS(4350),
    [anon_sym___constant__] = ACTIONS(4350),
    [anon_sym___managed__] = ACTIONS(4350),
    [anon_sym___grid_constant__] = ACTIONS(4350),
    [anon_sym_alignas] = ACTIONS(4350),
    [anon_sym__Alignas] = ACTIONS(4350),
    [sym_primitive_type] = ACTIONS(4350),
    [anon_sym_COLON] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_bitor] = ACTIONS(4350),
    [anon_sym_xor] = ACTIONS(4350),
    [anon_sym_bitand] = ACTIONS(4350),
    [anon_sym_not_eq] = ACTIONS(4350),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4350),
    [anon_sym_decltype] = ACTIONS(4350),
    [anon_sym_final] = ACTIONS(4350),
    [anon_sym_override] = ACTIONS(4350),
    [anon_sym_requires] = ACTIONS(4350),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
  },
  [STATE(2065)] = {
    [sym_identifier] = ACTIONS(4356),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_RPAREN] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4358),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4358),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4358),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4358),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4358),
    [anon_sym_SEMI] = ACTIONS(4358),
    [anon_sym___extension__] = ACTIONS(4356),
    [anon_sym___global__] = ACTIONS(4356),
    [anon_sym___attribute__] = ACTIONS(4356),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym___based] = ACTIONS(4356),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_RBRACE] = ACTIONS(4358),
    [anon_sym_signed] = ACTIONS(4356),
    [anon_sym_unsigned] = ACTIONS(4356),
    [anon_sym_long] = ACTIONS(4356),
    [anon_sym_short] = ACTIONS(4356),
    [anon_sym_LBRACK] = ACTIONS(4358),
    [anon_sym_RBRACK] = ACTIONS(4358),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4356),
    [anon_sym_volatile] = ACTIONS(4356),
    [anon_sym_restrict] = ACTIONS(4356),
    [anon_sym___restrict__] = ACTIONS(4356),
    [anon_sym__Atomic] = ACTIONS(4356),
    [anon_sym__Noreturn] = ACTIONS(4356),
    [anon_sym_noreturn] = ACTIONS(4356),
    [anon_sym__Nonnull] = ACTIONS(4356),
    [anon_sym_mutable] = ACTIONS(4356),
    [anon_sym_constinit] = ACTIONS(4356),
    [anon_sym_consteval] = ACTIONS(4356),
    [anon_sym___shared__] = ACTIONS(4356),
    [anon_sym___local__] = ACTIONS(4356),
    [anon_sym___constant__] = ACTIONS(4356),
    [anon_sym___managed__] = ACTIONS(4356),
    [anon_sym___grid_constant__] = ACTIONS(4356),
    [anon_sym_alignas] = ACTIONS(4356),
    [anon_sym__Alignas] = ACTIONS(4356),
    [sym_primitive_type] = ACTIONS(4356),
    [anon_sym_COLON] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_bitor] = ACTIONS(4356),
    [anon_sym_xor] = ACTIONS(4356),
    [anon_sym_bitand] = ACTIONS(4356),
    [anon_sym_not_eq] = ACTIONS(4356),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4358),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4356),
    [anon_sym_decltype] = ACTIONS(4356),
    [anon_sym_final] = ACTIONS(4356),
    [anon_sym_override] = ACTIONS(4356),
    [anon_sym_requires] = ACTIONS(4356),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
  },
  [STATE(2066)] = {
    [sym_identifier] = ACTIONS(4366),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_RPAREN] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4368),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4368),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4368),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4368),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4368),
    [anon_sym_SEMI] = ACTIONS(4368),
    [anon_sym___extension__] = ACTIONS(4366),
    [anon_sym___global__] = ACTIONS(4366),
    [anon_sym___attribute__] = ACTIONS(4366),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym___based] = ACTIONS(4366),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_RBRACE] = ACTIONS(4368),
    [anon_sym_signed] = ACTIONS(4366),
    [anon_sym_unsigned] = ACTIONS(4366),
    [anon_sym_long] = ACTIONS(4366),
    [anon_sym_short] = ACTIONS(4366),
    [anon_sym_LBRACK] = ACTIONS(4368),
    [anon_sym_RBRACK] = ACTIONS(4368),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4366),
    [anon_sym_volatile] = ACTIONS(4366),
    [anon_sym_restrict] = ACTIONS(4366),
    [anon_sym___restrict__] = ACTIONS(4366),
    [anon_sym__Atomic] = ACTIONS(4366),
    [anon_sym__Noreturn] = ACTIONS(4366),
    [anon_sym_noreturn] = ACTIONS(4366),
    [anon_sym__Nonnull] = ACTIONS(4366),
    [anon_sym_mutable] = ACTIONS(4366),
    [anon_sym_constinit] = ACTIONS(4366),
    [anon_sym_consteval] = ACTIONS(4366),
    [anon_sym___shared__] = ACTIONS(4366),
    [anon_sym___local__] = ACTIONS(4366),
    [anon_sym___constant__] = ACTIONS(4366),
    [anon_sym___managed__] = ACTIONS(4366),
    [anon_sym___grid_constant__] = ACTIONS(4366),
    [anon_sym_alignas] = ACTIONS(4366),
    [anon_sym__Alignas] = ACTIONS(4366),
    [sym_primitive_type] = ACTIONS(4366),
    [anon_sym_COLON] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_bitor] = ACTIONS(4366),
    [anon_sym_xor] = ACTIONS(4366),
    [anon_sym_bitand] = ACTIONS(4366),
    [anon_sym_not_eq] = ACTIONS(4366),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4366),
    [anon_sym_decltype] = ACTIONS(4366),
    [anon_sym_final] = ACTIONS(4366),
    [anon_sym_override] = ACTIONS(4366),
    [anon_sym_requires] = ACTIONS(4366),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
  },
  [STATE(2067)] = {
    [sym_template_argument_list] = STATE(2147),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4514),
    [anon_sym_COMMA] = ACTIONS(4514),
    [anon_sym_RPAREN] = ACTIONS(4516),
    [anon_sym_LPAREN2] = ACTIONS(4516),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4523),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4516),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4523),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4514),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(5681),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym___extension__] = ACTIONS(4519),
    [anon_sym___global__] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_EQ] = ACTIONS(4521),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4519),
    [anon_sym_volatile] = ACTIONS(4519),
    [anon_sym_restrict] = ACTIONS(4519),
    [anon_sym___restrict__] = ACTIONS(4519),
    [anon_sym__Atomic] = ACTIONS(4519),
    [anon_sym__Noreturn] = ACTIONS(4519),
    [anon_sym_noreturn] = ACTIONS(4519),
    [anon_sym__Nonnull] = ACTIONS(4519),
    [anon_sym_mutable] = ACTIONS(4519),
    [anon_sym_constinit] = ACTIONS(4519),
    [anon_sym_consteval] = ACTIONS(4519),
    [anon_sym___shared__] = ACTIONS(4519),
    [anon_sym___local__] = ACTIONS(4519),
    [anon_sym___constant__] = ACTIONS(4519),
    [anon_sym___managed__] = ACTIONS(4519),
    [anon_sym___grid_constant__] = ACTIONS(4519),
    [anon_sym_alignas] = ACTIONS(4519),
    [anon_sym__Alignas] = ACTIONS(4519),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4514),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4514),
    [anon_sym_or_eq] = ACTIONS(4514),
    [anon_sym_xor_eq] = ACTIONS(4514),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4514),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4514),
    [anon_sym_not_eq] = ACTIONS(4514),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4519),
    [anon_sym_decltype] = ACTIONS(4519),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4514),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
  },
  [STATE(2068)] = {
    [sym_identifier] = ACTIONS(2525),
    [aux_sym_preproc_def_token1] = ACTIONS(2525),
    [aux_sym_preproc_if_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2525),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2525),
    [sym_preproc_directive] = ACTIONS(2525),
    [anon_sym_LPAREN2] = ACTIONS(2527),
    [anon_sym_TILDE] = ACTIONS(2527),
    [anon_sym_STAR] = ACTIONS(2527),
    [anon_sym_AMP_AMP] = ACTIONS(2527),
    [anon_sym_AMP] = ACTIONS(2525),
    [anon_sym_SEMI] = ACTIONS(2527),
    [anon_sym___extension__] = ACTIONS(2525),
    [anon_sym_typedef] = ACTIONS(2525),
    [anon_sym___device__] = ACTIONS(2525),
    [anon_sym___host__] = ACTIONS(2525),
    [anon_sym___global__] = ACTIONS(2525),
    [anon_sym___forceinline__] = ACTIONS(2525),
    [anon_sym___noinline__] = ACTIONS(2525),
    [anon_sym_virtual] = ACTIONS(2525),
    [anon_sym_extern] = ACTIONS(2525),
    [anon_sym___attribute__] = ACTIONS(2525),
    [anon_sym___attribute] = ACTIONS(2525),
    [anon_sym_COLON_COLON] = ACTIONS(2527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2527),
    [anon_sym___declspec] = ACTIONS(2525),
    [anon_sym___based] = ACTIONS(2525),
    [anon_sym_RBRACE] = ACTIONS(2527),
    [anon_sym_signed] = ACTIONS(2525),
    [anon_sym_unsigned] = ACTIONS(2525),
    [anon_sym_long] = ACTIONS(2525),
    [anon_sym_short] = ACTIONS(2525),
    [anon_sym_LBRACK] = ACTIONS(2525),
    [anon_sym_static] = ACTIONS(2525),
    [anon_sym_register] = ACTIONS(2525),
    [anon_sym_inline] = ACTIONS(2525),
    [anon_sym___inline] = ACTIONS(2525),
    [anon_sym___inline__] = ACTIONS(2525),
    [anon_sym___forceinline] = ACTIONS(2525),
    [anon_sym_thread_local] = ACTIONS(2525),
    [anon_sym___thread] = ACTIONS(2525),
    [anon_sym_const] = ACTIONS(2525),
    [anon_sym_constexpr] = ACTIONS(2525),
    [anon_sym_volatile] = ACTIONS(2525),
    [anon_sym_restrict] = ACTIONS(2525),
    [anon_sym___restrict__] = ACTIONS(2525),
    [anon_sym__Atomic] = ACTIONS(2525),
    [anon_sym__Noreturn] = ACTIONS(2525),
    [anon_sym_noreturn] = ACTIONS(2525),
    [anon_sym__Nonnull] = ACTIONS(2525),
    [anon_sym_mutable] = ACTIONS(2525),
    [anon_sym_constinit] = ACTIONS(2525),
    [anon_sym_consteval] = ACTIONS(2525),
    [anon_sym___shared__] = ACTIONS(2525),
    [anon_sym___local__] = ACTIONS(2525),
    [anon_sym___constant__] = ACTIONS(2525),
    [anon_sym___managed__] = ACTIONS(2525),
    [anon_sym___grid_constant__] = ACTIONS(2525),
    [anon_sym_alignas] = ACTIONS(2525),
    [anon_sym__Alignas] = ACTIONS(2525),
    [sym_primitive_type] = ACTIONS(2525),
    [anon_sym_enum] = ACTIONS(2525),
    [anon_sym_class] = ACTIONS(2525),
    [anon_sym_struct] = ACTIONS(2525),
    [anon_sym_union] = ACTIONS(2525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2525),
    [anon_sym_decltype] = ACTIONS(2525),
    [anon_sym_explicit] = ACTIONS(2525),
    [anon_sym_typename] = ACTIONS(2525),
    [anon_sym_template] = ACTIONS(2525),
    [anon_sym_operator] = ACTIONS(2525),
    [anon_sym_friend] = ACTIONS(2525),
    [anon_sym_public] = ACTIONS(2525),
    [anon_sym_private] = ACTIONS(2525),
    [anon_sym_protected] = ACTIONS(2525),
    [anon_sym_using] = ACTIONS(2525),
    [anon_sym_static_assert] = ACTIONS(2525),
    [anon_sym___launch_bounds__] = ACTIONS(2525),
  },
  [STATE(2069)] = {
    [sym_identifier] = ACTIONS(2529),
    [aux_sym_preproc_def_token1] = ACTIONS(2529),
    [aux_sym_preproc_if_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2529),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2529),
    [sym_preproc_directive] = ACTIONS(2529),
    [anon_sym_LPAREN2] = ACTIONS(2531),
    [anon_sym_TILDE] = ACTIONS(2531),
    [anon_sym_STAR] = ACTIONS(2531),
    [anon_sym_AMP_AMP] = ACTIONS(2531),
    [anon_sym_AMP] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2531),
    [anon_sym___extension__] = ACTIONS(2529),
    [anon_sym_typedef] = ACTIONS(2529),
    [anon_sym___device__] = ACTIONS(2529),
    [anon_sym___host__] = ACTIONS(2529),
    [anon_sym___global__] = ACTIONS(2529),
    [anon_sym___forceinline__] = ACTIONS(2529),
    [anon_sym___noinline__] = ACTIONS(2529),
    [anon_sym_virtual] = ACTIONS(2529),
    [anon_sym_extern] = ACTIONS(2529),
    [anon_sym___attribute__] = ACTIONS(2529),
    [anon_sym___attribute] = ACTIONS(2529),
    [anon_sym_COLON_COLON] = ACTIONS(2531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2531),
    [anon_sym___declspec] = ACTIONS(2529),
    [anon_sym___based] = ACTIONS(2529),
    [anon_sym_RBRACE] = ACTIONS(2531),
    [anon_sym_signed] = ACTIONS(2529),
    [anon_sym_unsigned] = ACTIONS(2529),
    [anon_sym_long] = ACTIONS(2529),
    [anon_sym_short] = ACTIONS(2529),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2529),
    [anon_sym_register] = ACTIONS(2529),
    [anon_sym_inline] = ACTIONS(2529),
    [anon_sym___inline] = ACTIONS(2529),
    [anon_sym___inline__] = ACTIONS(2529),
    [anon_sym___forceinline] = ACTIONS(2529),
    [anon_sym_thread_local] = ACTIONS(2529),
    [anon_sym___thread] = ACTIONS(2529),
    [anon_sym_const] = ACTIONS(2529),
    [anon_sym_constexpr] = ACTIONS(2529),
    [anon_sym_volatile] = ACTIONS(2529),
    [anon_sym_restrict] = ACTIONS(2529),
    [anon_sym___restrict__] = ACTIONS(2529),
    [anon_sym__Atomic] = ACTIONS(2529),
    [anon_sym__Noreturn] = ACTIONS(2529),
    [anon_sym_noreturn] = ACTIONS(2529),
    [anon_sym__Nonnull] = ACTIONS(2529),
    [anon_sym_mutable] = ACTIONS(2529),
    [anon_sym_constinit] = ACTIONS(2529),
    [anon_sym_consteval] = ACTIONS(2529),
    [anon_sym___shared__] = ACTIONS(2529),
    [anon_sym___local__] = ACTIONS(2529),
    [anon_sym___constant__] = ACTIONS(2529),
    [anon_sym___managed__] = ACTIONS(2529),
    [anon_sym___grid_constant__] = ACTIONS(2529),
    [anon_sym_alignas] = ACTIONS(2529),
    [anon_sym__Alignas] = ACTIONS(2529),
    [sym_primitive_type] = ACTIONS(2529),
    [anon_sym_enum] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2529),
    [anon_sym_struct] = ACTIONS(2529),
    [anon_sym_union] = ACTIONS(2529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2529),
    [anon_sym_decltype] = ACTIONS(2529),
    [anon_sym_explicit] = ACTIONS(2529),
    [anon_sym_typename] = ACTIONS(2529),
    [anon_sym_template] = ACTIONS(2529),
    [anon_sym_operator] = ACTIONS(2529),
    [anon_sym_friend] = ACTIONS(2529),
    [anon_sym_public] = ACTIONS(2529),
    [anon_sym_private] = ACTIONS(2529),
    [anon_sym_protected] = ACTIONS(2529),
    [anon_sym_using] = ACTIONS(2529),
    [anon_sym_static_assert] = ACTIONS(2529),
    [anon_sym___launch_bounds__] = ACTIONS(2529),
  },
  [STATE(2070)] = {
    [sym_identifier] = ACTIONS(2541),
    [aux_sym_preproc_def_token1] = ACTIONS(2541),
    [aux_sym_preproc_if_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2541),
    [sym_preproc_directive] = ACTIONS(2541),
    [anon_sym_LPAREN2] = ACTIONS(2543),
    [anon_sym_TILDE] = ACTIONS(2543),
    [anon_sym_STAR] = ACTIONS(2543),
    [anon_sym_AMP_AMP] = ACTIONS(2543),
    [anon_sym_AMP] = ACTIONS(2541),
    [anon_sym_SEMI] = ACTIONS(2543),
    [anon_sym___extension__] = ACTIONS(2541),
    [anon_sym_typedef] = ACTIONS(2541),
    [anon_sym___device__] = ACTIONS(2541),
    [anon_sym___host__] = ACTIONS(2541),
    [anon_sym___global__] = ACTIONS(2541),
    [anon_sym___forceinline__] = ACTIONS(2541),
    [anon_sym___noinline__] = ACTIONS(2541),
    [anon_sym_virtual] = ACTIONS(2541),
    [anon_sym_extern] = ACTIONS(2541),
    [anon_sym___attribute__] = ACTIONS(2541),
    [anon_sym___attribute] = ACTIONS(2541),
    [anon_sym_COLON_COLON] = ACTIONS(2543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2543),
    [anon_sym___declspec] = ACTIONS(2541),
    [anon_sym___based] = ACTIONS(2541),
    [anon_sym_RBRACE] = ACTIONS(2543),
    [anon_sym_signed] = ACTIONS(2541),
    [anon_sym_unsigned] = ACTIONS(2541),
    [anon_sym_long] = ACTIONS(2541),
    [anon_sym_short] = ACTIONS(2541),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [anon_sym_static] = ACTIONS(2541),
    [anon_sym_register] = ACTIONS(2541),
    [anon_sym_inline] = ACTIONS(2541),
    [anon_sym___inline] = ACTIONS(2541),
    [anon_sym___inline__] = ACTIONS(2541),
    [anon_sym___forceinline] = ACTIONS(2541),
    [anon_sym_thread_local] = ACTIONS(2541),
    [anon_sym___thread] = ACTIONS(2541),
    [anon_sym_const] = ACTIONS(2541),
    [anon_sym_constexpr] = ACTIONS(2541),
    [anon_sym_volatile] = ACTIONS(2541),
    [anon_sym_restrict] = ACTIONS(2541),
    [anon_sym___restrict__] = ACTIONS(2541),
    [anon_sym__Atomic] = ACTIONS(2541),
    [anon_sym__Noreturn] = ACTIONS(2541),
    [anon_sym_noreturn] = ACTIONS(2541),
    [anon_sym__Nonnull] = ACTIONS(2541),
    [anon_sym_mutable] = ACTIONS(2541),
    [anon_sym_constinit] = ACTIONS(2541),
    [anon_sym_consteval] = ACTIONS(2541),
    [anon_sym___shared__] = ACTIONS(2541),
    [anon_sym___local__] = ACTIONS(2541),
    [anon_sym___constant__] = ACTIONS(2541),
    [anon_sym___managed__] = ACTIONS(2541),
    [anon_sym___grid_constant__] = ACTIONS(2541),
    [anon_sym_alignas] = ACTIONS(2541),
    [anon_sym__Alignas] = ACTIONS(2541),
    [sym_primitive_type] = ACTIONS(2541),
    [anon_sym_enum] = ACTIONS(2541),
    [anon_sym_class] = ACTIONS(2541),
    [anon_sym_struct] = ACTIONS(2541),
    [anon_sym_union] = ACTIONS(2541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2541),
    [anon_sym_decltype] = ACTIONS(2541),
    [anon_sym_explicit] = ACTIONS(2541),
    [anon_sym_typename] = ACTIONS(2541),
    [anon_sym_template] = ACTIONS(2541),
    [anon_sym_operator] = ACTIONS(2541),
    [anon_sym_friend] = ACTIONS(2541),
    [anon_sym_public] = ACTIONS(2541),
    [anon_sym_private] = ACTIONS(2541),
    [anon_sym_protected] = ACTIONS(2541),
    [anon_sym_using] = ACTIONS(2541),
    [anon_sym_static_assert] = ACTIONS(2541),
    [anon_sym___launch_bounds__] = ACTIONS(2541),
  },
  [STATE(2071)] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym___device__] = ACTIONS(2549),
    [anon_sym___host__] = ACTIONS(2549),
    [anon_sym___global__] = ACTIONS(2549),
    [anon_sym___forceinline__] = ACTIONS(2549),
    [anon_sym___noinline__] = ACTIONS(2549),
    [anon_sym_virtual] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym___attribute] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym_RBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym__Nonnull] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym___shared__] = ACTIONS(2549),
    [anon_sym___local__] = ACTIONS(2549),
    [anon_sym___constant__] = ACTIONS(2549),
    [anon_sym___managed__] = ACTIONS(2549),
    [anon_sym___grid_constant__] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_friend] = ACTIONS(2549),
    [anon_sym_public] = ACTIONS(2549),
    [anon_sym_private] = ACTIONS(2549),
    [anon_sym_protected] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym___launch_bounds__] = ACTIONS(2549),
  },
  [STATE(2072)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5686),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_signed] = ACTIONS(5684),
    [anon_sym_unsigned] = ACTIONS(5684),
    [anon_sym_long] = ACTIONS(5684),
    [anon_sym_short] = ACTIONS(5684),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_primitive_type] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5684),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_and] = ACTIONS(5684),
    [anon_sym_bitor] = ACTIONS(5684),
    [anon_sym_xor] = ACTIONS(5684),
    [anon_sym_bitand] = ACTIONS(5684),
    [anon_sym_not_eq] = ACTIONS(5684),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_final] = ACTIONS(5684),
    [anon_sym_override] = ACTIONS(5684),
    [anon_sym_requires] = ACTIONS(5684),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2073)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_friend] = ACTIONS(2178),
    [anon_sym_public] = ACTIONS(2178),
    [anon_sym_private] = ACTIONS(2178),
    [anon_sym_protected] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(2074)] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym___device__] = ACTIONS(2178),
    [anon_sym___host__] = ACTIONS(2178),
    [anon_sym___global__] = ACTIONS(2178),
    [anon_sym___forceinline__] = ACTIONS(2178),
    [anon_sym___noinline__] = ACTIONS(2178),
    [anon_sym_virtual] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym___attribute] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym__Nonnull] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym___shared__] = ACTIONS(2178),
    [anon_sym___local__] = ACTIONS(2178),
    [anon_sym___constant__] = ACTIONS(2178),
    [anon_sym___managed__] = ACTIONS(2178),
    [anon_sym___grid_constant__] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_friend] = ACTIONS(2178),
    [anon_sym_public] = ACTIONS(2178),
    [anon_sym_private] = ACTIONS(2178),
    [anon_sym_protected] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym___launch_bounds__] = ACTIONS(2178),
  },
  [STATE(2075)] = {
    [sym_identifier] = ACTIONS(5541),
    [aux_sym_preproc_def_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token1] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5541),
    [sym_preproc_directive] = ACTIONS(5541),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_TILDE] = ACTIONS(5543),
    [anon_sym_STAR] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___extension__] = ACTIONS(5541),
    [anon_sym_typedef] = ACTIONS(5541),
    [anon_sym___device__] = ACTIONS(5541),
    [anon_sym___host__] = ACTIONS(5541),
    [anon_sym___global__] = ACTIONS(5541),
    [anon_sym___forceinline__] = ACTIONS(5541),
    [anon_sym___noinline__] = ACTIONS(5541),
    [anon_sym_virtual] = ACTIONS(5541),
    [anon_sym_extern] = ACTIONS(5541),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym___attribute] = ACTIONS(5541),
    [anon_sym_COLON_COLON] = ACTIONS(5543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5543),
    [anon_sym___declspec] = ACTIONS(5541),
    [anon_sym___based] = ACTIONS(5541),
    [anon_sym_RBRACE] = ACTIONS(5543),
    [anon_sym_signed] = ACTIONS(5541),
    [anon_sym_unsigned] = ACTIONS(5541),
    [anon_sym_long] = ACTIONS(5541),
    [anon_sym_short] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5541),
    [anon_sym_static] = ACTIONS(5541),
    [anon_sym_register] = ACTIONS(5541),
    [anon_sym_inline] = ACTIONS(5541),
    [anon_sym___inline] = ACTIONS(5541),
    [anon_sym___inline__] = ACTIONS(5541),
    [anon_sym___forceinline] = ACTIONS(5541),
    [anon_sym_thread_local] = ACTIONS(5541),
    [anon_sym___thread] = ACTIONS(5541),
    [anon_sym_const] = ACTIONS(5541),
    [anon_sym_constexpr] = ACTIONS(5541),
    [anon_sym_volatile] = ACTIONS(5541),
    [anon_sym_restrict] = ACTIONS(5541),
    [anon_sym___restrict__] = ACTIONS(5541),
    [anon_sym__Atomic] = ACTIONS(5541),
    [anon_sym__Noreturn] = ACTIONS(5541),
    [anon_sym_noreturn] = ACTIONS(5541),
    [anon_sym__Nonnull] = ACTIONS(5541),
    [anon_sym_mutable] = ACTIONS(5541),
    [anon_sym_constinit] = ACTIONS(5541),
    [anon_sym_consteval] = ACTIONS(5541),
    [anon_sym___shared__] = ACTIONS(5541),
    [anon_sym___local__] = ACTIONS(5541),
    [anon_sym___constant__] = ACTIONS(5541),
    [anon_sym___managed__] = ACTIONS(5541),
    [anon_sym___grid_constant__] = ACTIONS(5541),
    [anon_sym_alignas] = ACTIONS(5541),
    [anon_sym__Alignas] = ACTIONS(5541),
    [sym_primitive_type] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_class] = ACTIONS(5541),
    [anon_sym_struct] = ACTIONS(5541),
    [anon_sym_union] = ACTIONS(5541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
    [anon_sym_explicit] = ACTIONS(5541),
    [anon_sym_typename] = ACTIONS(5541),
    [anon_sym_template] = ACTIONS(5541),
    [anon_sym_operator] = ACTIONS(5541),
    [anon_sym_friend] = ACTIONS(5541),
    [anon_sym_public] = ACTIONS(5541),
    [anon_sym_private] = ACTIONS(5541),
    [anon_sym_protected] = ACTIONS(5541),
    [anon_sym_using] = ACTIONS(5541),
    [anon_sym_static_assert] = ACTIONS(5541),
    [anon_sym___launch_bounds__] = ACTIONS(5541),
  },
  [STATE(2076)] = {
    [sym_identifier] = ACTIONS(5541),
    [aux_sym_preproc_def_token1] = ACTIONS(5541),
    [aux_sym_preproc_if_token1] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5541),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5541),
    [sym_preproc_directive] = ACTIONS(5541),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_TILDE] = ACTIONS(5543),
    [anon_sym_STAR] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___extension__] = ACTIONS(5541),
    [anon_sym_typedef] = ACTIONS(5541),
    [anon_sym___device__] = ACTIONS(5541),
    [anon_sym___host__] = ACTIONS(5541),
    [anon_sym___global__] = ACTIONS(5541),
    [anon_sym___forceinline__] = ACTIONS(5541),
    [anon_sym___noinline__] = ACTIONS(5541),
    [anon_sym_virtual] = ACTIONS(5541),
    [anon_sym_extern] = ACTIONS(5541),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym___attribute] = ACTIONS(5541),
    [anon_sym_COLON_COLON] = ACTIONS(5543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5543),
    [anon_sym___declspec] = ACTIONS(5541),
    [anon_sym___based] = ACTIONS(5541),
    [anon_sym_RBRACE] = ACTIONS(5543),
    [anon_sym_signed] = ACTIONS(5541),
    [anon_sym_unsigned] = ACTIONS(5541),
    [anon_sym_long] = ACTIONS(5541),
    [anon_sym_short] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5541),
    [anon_sym_static] = ACTIONS(5541),
    [anon_sym_register] = ACTIONS(5541),
    [anon_sym_inline] = ACTIONS(5541),
    [anon_sym___inline] = ACTIONS(5541),
    [anon_sym___inline__] = ACTIONS(5541),
    [anon_sym___forceinline] = ACTIONS(5541),
    [anon_sym_thread_local] = ACTIONS(5541),
    [anon_sym___thread] = ACTIONS(5541),
    [anon_sym_const] = ACTIONS(5541),
    [anon_sym_constexpr] = ACTIONS(5541),
    [anon_sym_volatile] = ACTIONS(5541),
    [anon_sym_restrict] = ACTIONS(5541),
    [anon_sym___restrict__] = ACTIONS(5541),
    [anon_sym__Atomic] = ACTIONS(5541),
    [anon_sym__Noreturn] = ACTIONS(5541),
    [anon_sym_noreturn] = ACTIONS(5541),
    [anon_sym__Nonnull] = ACTIONS(5541),
    [anon_sym_mutable] = ACTIONS(5541),
    [anon_sym_constinit] = ACTIONS(5541),
    [anon_sym_consteval] = ACTIONS(5541),
    [anon_sym___shared__] = ACTIONS(5541),
    [anon_sym___local__] = ACTIONS(5541),
    [anon_sym___constant__] = ACTIONS(5541),
    [anon_sym___managed__] = ACTIONS(5541),
    [anon_sym___grid_constant__] = ACTIONS(5541),
    [anon_sym_alignas] = ACTIONS(5541),
    [anon_sym__Alignas] = ACTIONS(5541),
    [sym_primitive_type] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_class] = ACTIONS(5541),
    [anon_sym_struct] = ACTIONS(5541),
    [anon_sym_union] = ACTIONS(5541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
    [anon_sym_explicit] = ACTIONS(5541),
    [anon_sym_typename] = ACTIONS(5541),
    [anon_sym_template] = ACTIONS(5541),
    [anon_sym_operator] = ACTIONS(5541),
    [anon_sym_friend] = ACTIONS(5541),
    [anon_sym_public] = ACTIONS(5541),
    [anon_sym_private] = ACTIONS(5541),
    [anon_sym_protected] = ACTIONS(5541),
    [anon_sym_using] = ACTIONS(5541),
    [anon_sym_static_assert] = ACTIONS(5541),
    [anon_sym___launch_bounds__] = ACTIONS(5541),
  },
  [STATE(2077)] = {
    [sym_identifier] = ACTIONS(5545),
    [aux_sym_preproc_def_token1] = ACTIONS(5545),
    [aux_sym_preproc_if_token1] = ACTIONS(5545),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5545),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5545),
    [sym_preproc_directive] = ACTIONS(5545),
    [anon_sym_LPAREN2] = ACTIONS(5547),
    [anon_sym_TILDE] = ACTIONS(5547),
    [anon_sym_STAR] = ACTIONS(5547),
    [anon_sym_AMP_AMP] = ACTIONS(5547),
    [anon_sym_AMP] = ACTIONS(5545),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym___extension__] = ACTIONS(5545),
    [anon_sym_typedef] = ACTIONS(5545),
    [anon_sym___device__] = ACTIONS(5545),
    [anon_sym___host__] = ACTIONS(5545),
    [anon_sym___global__] = ACTIONS(5545),
    [anon_sym___forceinline__] = ACTIONS(5545),
    [anon_sym___noinline__] = ACTIONS(5545),
    [anon_sym_virtual] = ACTIONS(5545),
    [anon_sym_extern] = ACTIONS(5545),
    [anon_sym___attribute__] = ACTIONS(5545),
    [anon_sym___attribute] = ACTIONS(5545),
    [anon_sym_COLON_COLON] = ACTIONS(5547),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5547),
    [anon_sym___declspec] = ACTIONS(5545),
    [anon_sym___based] = ACTIONS(5545),
    [anon_sym_RBRACE] = ACTIONS(5547),
    [anon_sym_signed] = ACTIONS(5545),
    [anon_sym_unsigned] = ACTIONS(5545),
    [anon_sym_long] = ACTIONS(5545),
    [anon_sym_short] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5545),
    [anon_sym_static] = ACTIONS(5545),
    [anon_sym_register] = ACTIONS(5545),
    [anon_sym_inline] = ACTIONS(5545),
    [anon_sym___inline] = ACTIONS(5545),
    [anon_sym___inline__] = ACTIONS(5545),
    [anon_sym___forceinline] = ACTIONS(5545),
    [anon_sym_thread_local] = ACTIONS(5545),
    [anon_sym___thread] = ACTIONS(5545),
    [anon_sym_const] = ACTIONS(5545),
    [anon_sym_constexpr] = ACTIONS(5545),
    [anon_sym_volatile] = ACTIONS(5545),
    [anon_sym_restrict] = ACTIONS(5545),
    [anon_sym___restrict__] = ACTIONS(5545),
    [anon_sym__Atomic] = ACTIONS(5545),
    [anon_sym__Noreturn] = ACTIONS(5545),
    [anon_sym_noreturn] = ACTIONS(5545),
    [anon_sym__Nonnull] = ACTIONS(5545),
    [anon_sym_mutable] = ACTIONS(5545),
    [anon_sym_constinit] = ACTIONS(5545),
    [anon_sym_consteval] = ACTIONS(5545),
    [anon_sym___shared__] = ACTIONS(5545),
    [anon_sym___local__] = ACTIONS(5545),
    [anon_sym___constant__] = ACTIONS(5545),
    [anon_sym___managed__] = ACTIONS(5545),
    [anon_sym___grid_constant__] = ACTIONS(5545),
    [anon_sym_alignas] = ACTIONS(5545),
    [anon_sym__Alignas] = ACTIONS(5545),
    [sym_primitive_type] = ACTIONS(5545),
    [anon_sym_enum] = ACTIONS(5545),
    [anon_sym_class] = ACTIONS(5545),
    [anon_sym_struct] = ACTIONS(5545),
    [anon_sym_union] = ACTIONS(5545),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5545),
    [anon_sym_decltype] = ACTIONS(5545),
    [anon_sym_explicit] = ACTIONS(5545),
    [anon_sym_typename] = ACTIONS(5545),
    [anon_sym_template] = ACTIONS(5545),
    [anon_sym_operator] = ACTIONS(5545),
    [anon_sym_friend] = ACTIONS(5545),
    [anon_sym_public] = ACTIONS(5545),
    [anon_sym_private] = ACTIONS(5545),
    [anon_sym_protected] = ACTIONS(5545),
    [anon_sym_using] = ACTIONS(5545),
    [anon_sym_static_assert] = ACTIONS(5545),
    [anon_sym___launch_bounds__] = ACTIONS(5545),
  },
  [STATE(2078)] = {
    [sym_identifier] = ACTIONS(5549),
    [aux_sym_preproc_def_token1] = ACTIONS(5549),
    [aux_sym_preproc_if_token1] = ACTIONS(5549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5549),
    [sym_preproc_directive] = ACTIONS(5549),
    [anon_sym_LPAREN2] = ACTIONS(5551),
    [anon_sym_TILDE] = ACTIONS(5551),
    [anon_sym_STAR] = ACTIONS(5551),
    [anon_sym_AMP_AMP] = ACTIONS(5551),
    [anon_sym_AMP] = ACTIONS(5549),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym___extension__] = ACTIONS(5549),
    [anon_sym_typedef] = ACTIONS(5549),
    [anon_sym___device__] = ACTIONS(5549),
    [anon_sym___host__] = ACTIONS(5549),
    [anon_sym___global__] = ACTIONS(5549),
    [anon_sym___forceinline__] = ACTIONS(5549),
    [anon_sym___noinline__] = ACTIONS(5549),
    [anon_sym_virtual] = ACTIONS(5549),
    [anon_sym_extern] = ACTIONS(5549),
    [anon_sym___attribute__] = ACTIONS(5549),
    [anon_sym___attribute] = ACTIONS(5549),
    [anon_sym_COLON_COLON] = ACTIONS(5551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5551),
    [anon_sym___declspec] = ACTIONS(5549),
    [anon_sym___based] = ACTIONS(5549),
    [anon_sym_RBRACE] = ACTIONS(5551),
    [anon_sym_signed] = ACTIONS(5549),
    [anon_sym_unsigned] = ACTIONS(5549),
    [anon_sym_long] = ACTIONS(5549),
    [anon_sym_short] = ACTIONS(5549),
    [anon_sym_LBRACK] = ACTIONS(5549),
    [anon_sym_static] = ACTIONS(5549),
    [anon_sym_register] = ACTIONS(5549),
    [anon_sym_inline] = ACTIONS(5549),
    [anon_sym___inline] = ACTIONS(5549),
    [anon_sym___inline__] = ACTIONS(5549),
    [anon_sym___forceinline] = ACTIONS(5549),
    [anon_sym_thread_local] = ACTIONS(5549),
    [anon_sym___thread] = ACTIONS(5549),
    [anon_sym_const] = ACTIONS(5549),
    [anon_sym_constexpr] = ACTIONS(5549),
    [anon_sym_volatile] = ACTIONS(5549),
    [anon_sym_restrict] = ACTIONS(5549),
    [anon_sym___restrict__] = ACTIONS(5549),
    [anon_sym__Atomic] = ACTIONS(5549),
    [anon_sym__Noreturn] = ACTIONS(5549),
    [anon_sym_noreturn] = ACTIONS(5549),
    [anon_sym__Nonnull] = ACTIONS(5549),
    [anon_sym_mutable] = ACTIONS(5549),
    [anon_sym_constinit] = ACTIONS(5549),
    [anon_sym_consteval] = ACTIONS(5549),
    [anon_sym___shared__] = ACTIONS(5549),
    [anon_sym___local__] = ACTIONS(5549),
    [anon_sym___constant__] = ACTIONS(5549),
    [anon_sym___managed__] = ACTIONS(5549),
    [anon_sym___grid_constant__] = ACTIONS(5549),
    [anon_sym_alignas] = ACTIONS(5549),
    [anon_sym__Alignas] = ACTIONS(5549),
    [sym_primitive_type] = ACTIONS(5549),
    [anon_sym_enum] = ACTIONS(5549),
    [anon_sym_class] = ACTIONS(5549),
    [anon_sym_struct] = ACTIONS(5549),
    [anon_sym_union] = ACTIONS(5549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5549),
    [anon_sym_decltype] = ACTIONS(5549),
    [anon_sym_explicit] = ACTIONS(5549),
    [anon_sym_typename] = ACTIONS(5549),
    [anon_sym_template] = ACTIONS(5549),
    [anon_sym_operator] = ACTIONS(5549),
    [anon_sym_friend] = ACTIONS(5549),
    [anon_sym_public] = ACTIONS(5549),
    [anon_sym_private] = ACTIONS(5549),
    [anon_sym_protected] = ACTIONS(5549),
    [anon_sym_using] = ACTIONS(5549),
    [anon_sym_static_assert] = ACTIONS(5549),
    [anon_sym___launch_bounds__] = ACTIONS(5549),
  },
  [STATE(2079)] = {
    [sym_identifier] = ACTIONS(5505),
    [aux_sym_preproc_def_token1] = ACTIONS(5505),
    [aux_sym_preproc_if_token1] = ACTIONS(5505),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5505),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5505),
    [sym_preproc_directive] = ACTIONS(5505),
    [anon_sym_LPAREN2] = ACTIONS(5507),
    [anon_sym_TILDE] = ACTIONS(5507),
    [anon_sym_STAR] = ACTIONS(5507),
    [anon_sym_AMP_AMP] = ACTIONS(5507),
    [anon_sym_AMP] = ACTIONS(5505),
    [anon_sym_SEMI] = ACTIONS(5507),
    [anon_sym___extension__] = ACTIONS(5505),
    [anon_sym_typedef] = ACTIONS(5505),
    [anon_sym___device__] = ACTIONS(5505),
    [anon_sym___host__] = ACTIONS(5505),
    [anon_sym___global__] = ACTIONS(5505),
    [anon_sym___forceinline__] = ACTIONS(5505),
    [anon_sym___noinline__] = ACTIONS(5505),
    [anon_sym_virtual] = ACTIONS(5505),
    [anon_sym_extern] = ACTIONS(5505),
    [anon_sym___attribute__] = ACTIONS(5505),
    [anon_sym___attribute] = ACTIONS(5505),
    [anon_sym_COLON_COLON] = ACTIONS(5507),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5507),
    [anon_sym___declspec] = ACTIONS(5505),
    [anon_sym___based] = ACTIONS(5505),
    [anon_sym_RBRACE] = ACTIONS(5507),
    [anon_sym_signed] = ACTIONS(5505),
    [anon_sym_unsigned] = ACTIONS(5505),
    [anon_sym_long] = ACTIONS(5505),
    [anon_sym_short] = ACTIONS(5505),
    [anon_sym_LBRACK] = ACTIONS(5505),
    [anon_sym_static] = ACTIONS(5505),
    [anon_sym_register] = ACTIONS(5505),
    [anon_sym_inline] = ACTIONS(5505),
    [anon_sym___inline] = ACTIONS(5505),
    [anon_sym___inline__] = ACTIONS(5505),
    [anon_sym___forceinline] = ACTIONS(5505),
    [anon_sym_thread_local] = ACTIONS(5505),
    [anon_sym___thread] = ACTIONS(5505),
    [anon_sym_const] = ACTIONS(5505),
    [anon_sym_constexpr] = ACTIONS(5505),
    [anon_sym_volatile] = ACTIONS(5505),
    [anon_sym_restrict] = ACTIONS(5505),
    [anon_sym___restrict__] = ACTIONS(5505),
    [anon_sym__Atomic] = ACTIONS(5505),
    [anon_sym__Noreturn] = ACTIONS(5505),
    [anon_sym_noreturn] = ACTIONS(5505),
    [anon_sym__Nonnull] = ACTIONS(5505),
    [anon_sym_mutable] = ACTIONS(5505),
    [anon_sym_constinit] = ACTIONS(5505),
    [anon_sym_consteval] = ACTIONS(5505),
    [anon_sym___shared__] = ACTIONS(5505),
    [anon_sym___local__] = ACTIONS(5505),
    [anon_sym___constant__] = ACTIONS(5505),
    [anon_sym___managed__] = ACTIONS(5505),
    [anon_sym___grid_constant__] = ACTIONS(5505),
    [anon_sym_alignas] = ACTIONS(5505),
    [anon_sym__Alignas] = ACTIONS(5505),
    [sym_primitive_type] = ACTIONS(5505),
    [anon_sym_enum] = ACTIONS(5505),
    [anon_sym_class] = ACTIONS(5505),
    [anon_sym_struct] = ACTIONS(5505),
    [anon_sym_union] = ACTIONS(5505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5505),
    [anon_sym_decltype] = ACTIONS(5505),
    [anon_sym_explicit] = ACTIONS(5505),
    [anon_sym_typename] = ACTIONS(5505),
    [anon_sym_template] = ACTIONS(5505),
    [anon_sym_operator] = ACTIONS(5505),
    [anon_sym_friend] = ACTIONS(5505),
    [anon_sym_public] = ACTIONS(5505),
    [anon_sym_private] = ACTIONS(5505),
    [anon_sym_protected] = ACTIONS(5505),
    [anon_sym_using] = ACTIONS(5505),
    [anon_sym_static_assert] = ACTIONS(5505),
    [anon_sym___launch_bounds__] = ACTIONS(5505),
  },
  [STATE(2080)] = {
    [sym_identifier] = ACTIONS(5688),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5690),
    [anon_sym_COMMA] = ACTIONS(5690),
    [anon_sym_RPAREN] = ACTIONS(5690),
    [anon_sym_LPAREN2] = ACTIONS(5690),
    [anon_sym_DASH] = ACTIONS(5688),
    [anon_sym_PLUS] = ACTIONS(5688),
    [anon_sym_STAR] = ACTIONS(5690),
    [anon_sym_SLASH] = ACTIONS(5688),
    [anon_sym_PERCENT] = ACTIONS(5690),
    [anon_sym_PIPE_PIPE] = ACTIONS(5690),
    [anon_sym_AMP_AMP] = ACTIONS(5690),
    [anon_sym_PIPE] = ACTIONS(5688),
    [anon_sym_CARET] = ACTIONS(5690),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_EQ_EQ] = ACTIONS(5690),
    [anon_sym_BANG_EQ] = ACTIONS(5690),
    [anon_sym_GT] = ACTIONS(5688),
    [anon_sym_GT_EQ] = ACTIONS(5690),
    [anon_sym_LT_EQ] = ACTIONS(5688),
    [anon_sym_LT] = ACTIONS(5688),
    [anon_sym_LT_LT] = ACTIONS(5688),
    [anon_sym_GT_GT] = ACTIONS(5690),
    [anon_sym_SEMI] = ACTIONS(5690),
    [anon_sym___extension__] = ACTIONS(5688),
    [anon_sym___global__] = ACTIONS(5688),
    [anon_sym___attribute__] = ACTIONS(5688),
    [anon_sym___attribute] = ACTIONS(5688),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym___based] = ACTIONS(5688),
    [anon_sym_LBRACE] = ACTIONS(5690),
    [anon_sym_RBRACE] = ACTIONS(5690),
    [anon_sym_signed] = ACTIONS(5688),
    [anon_sym_unsigned] = ACTIONS(5688),
    [anon_sym_long] = ACTIONS(5688),
    [anon_sym_short] = ACTIONS(5688),
    [anon_sym_LBRACK] = ACTIONS(5690),
    [anon_sym_RBRACK] = ACTIONS(5690),
    [anon_sym_const] = ACTIONS(5688),
    [anon_sym_constexpr] = ACTIONS(5688),
    [anon_sym_volatile] = ACTIONS(5688),
    [anon_sym_restrict] = ACTIONS(5688),
    [anon_sym___restrict__] = ACTIONS(5688),
    [anon_sym__Atomic] = ACTIONS(5688),
    [anon_sym__Noreturn] = ACTIONS(5688),
    [anon_sym_noreturn] = ACTIONS(5688),
    [anon_sym__Nonnull] = ACTIONS(5688),
    [anon_sym_mutable] = ACTIONS(5688),
    [anon_sym_constinit] = ACTIONS(5688),
    [anon_sym_consteval] = ACTIONS(5688),
    [anon_sym___shared__] = ACTIONS(5688),
    [anon_sym___local__] = ACTIONS(5688),
    [anon_sym___constant__] = ACTIONS(5688),
    [anon_sym___managed__] = ACTIONS(5688),
    [anon_sym___grid_constant__] = ACTIONS(5688),
    [anon_sym_alignas] = ACTIONS(5688),
    [anon_sym__Alignas] = ACTIONS(5688),
    [sym_primitive_type] = ACTIONS(5688),
    [anon_sym_COLON] = ACTIONS(5688),
    [anon_sym_QMARK] = ACTIONS(5690),
    [anon_sym_LT_EQ_GT] = ACTIONS(5690),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_and] = ACTIONS(5688),
    [anon_sym_bitor] = ACTIONS(5688),
    [anon_sym_xor] = ACTIONS(5688),
    [anon_sym_bitand] = ACTIONS(5688),
    [anon_sym_not_eq] = ACTIONS(5688),
    [anon_sym_DASH_DASH] = ACTIONS(5690),
    [anon_sym_PLUS_PLUS] = ACTIONS(5690),
    [anon_sym_DOT] = ACTIONS(5688),
    [anon_sym_DOT_STAR] = ACTIONS(5690),
    [anon_sym_DASH_GT] = ACTIONS(5690),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5688),
    [anon_sym_decltype] = ACTIONS(5688),
    [anon_sym_final] = ACTIONS(5688),
    [anon_sym_override] = ACTIONS(5688),
    [anon_sym_requires] = ACTIONS(5688),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5690),
  },
  [STATE(2081)] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token2] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym___device__] = ACTIONS(2190),
    [anon_sym___host__] = ACTIONS(2190),
    [anon_sym___global__] = ACTIONS(2190),
    [anon_sym___forceinline__] = ACTIONS(2190),
    [anon_sym___noinline__] = ACTIONS(2190),
    [anon_sym_virtual] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym___attribute] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym__Nonnull] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym___shared__] = ACTIONS(2190),
    [anon_sym___local__] = ACTIONS(2190),
    [anon_sym___constant__] = ACTIONS(2190),
    [anon_sym___managed__] = ACTIONS(2190),
    [anon_sym___grid_constant__] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_friend] = ACTIONS(2190),
    [anon_sym_public] = ACTIONS(2190),
    [anon_sym_private] = ACTIONS(2190),
    [anon_sym_protected] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym___launch_bounds__] = ACTIONS(2190),
  },
  [STATE(2082)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_friend] = ACTIONS(2182),
    [anon_sym_public] = ACTIONS(2182),
    [anon_sym_private] = ACTIONS(2182),
    [anon_sym_protected] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(2083)] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym___device__] = ACTIONS(2565),
    [anon_sym___host__] = ACTIONS(2565),
    [anon_sym___global__] = ACTIONS(2565),
    [anon_sym___forceinline__] = ACTIONS(2565),
    [anon_sym___noinline__] = ACTIONS(2565),
    [anon_sym_virtual] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym___attribute] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym_RBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym__Nonnull] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym___shared__] = ACTIONS(2565),
    [anon_sym___local__] = ACTIONS(2565),
    [anon_sym___constant__] = ACTIONS(2565),
    [anon_sym___managed__] = ACTIONS(2565),
    [anon_sym___grid_constant__] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_friend] = ACTIONS(2565),
    [anon_sym_public] = ACTIONS(2565),
    [anon_sym_private] = ACTIONS(2565),
    [anon_sym_protected] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym___launch_bounds__] = ACTIONS(2565),
  },
  [STATE(2084)] = {
    [sym_identifier] = ACTIONS(4396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_RPAREN] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4398),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4398),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4398),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4398),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4398),
    [anon_sym_SEMI] = ACTIONS(4398),
    [anon_sym___extension__] = ACTIONS(4396),
    [anon_sym___global__] = ACTIONS(4396),
    [anon_sym___attribute__] = ACTIONS(4396),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym___based] = ACTIONS(4396),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_RBRACE] = ACTIONS(4398),
    [anon_sym_signed] = ACTIONS(4396),
    [anon_sym_unsigned] = ACTIONS(4396),
    [anon_sym_long] = ACTIONS(4396),
    [anon_sym_short] = ACTIONS(4396),
    [anon_sym_LBRACK] = ACTIONS(4398),
    [anon_sym_RBRACK] = ACTIONS(4398),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4396),
    [anon_sym_volatile] = ACTIONS(4396),
    [anon_sym_restrict] = ACTIONS(4396),
    [anon_sym___restrict__] = ACTIONS(4396),
    [anon_sym__Atomic] = ACTIONS(4396),
    [anon_sym__Noreturn] = ACTIONS(4396),
    [anon_sym_noreturn] = ACTIONS(4396),
    [anon_sym__Nonnull] = ACTIONS(4396),
    [anon_sym_mutable] = ACTIONS(4396),
    [anon_sym_constinit] = ACTIONS(4396),
    [anon_sym_consteval] = ACTIONS(4396),
    [anon_sym___shared__] = ACTIONS(4396),
    [anon_sym___local__] = ACTIONS(4396),
    [anon_sym___constant__] = ACTIONS(4396),
    [anon_sym___managed__] = ACTIONS(4396),
    [anon_sym___grid_constant__] = ACTIONS(4396),
    [anon_sym_alignas] = ACTIONS(4396),
    [anon_sym__Alignas] = ACTIONS(4396),
    [sym_primitive_type] = ACTIONS(4396),
    [anon_sym_COLON] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_bitor] = ACTIONS(4396),
    [anon_sym_xor] = ACTIONS(4396),
    [anon_sym_bitand] = ACTIONS(4396),
    [anon_sym_not_eq] = ACTIONS(4396),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4396),
    [anon_sym_decltype] = ACTIONS(4396),
    [anon_sym_final] = ACTIONS(4396),
    [anon_sym_override] = ACTIONS(4396),
    [anon_sym_requires] = ACTIONS(4396),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
  },
  [STATE(2085)] = {
    [sym_identifier] = ACTIONS(4402),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_RPAREN] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4404),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4404),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4404),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4404),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4404),
    [anon_sym_SEMI] = ACTIONS(4404),
    [anon_sym___extension__] = ACTIONS(4402),
    [anon_sym___global__] = ACTIONS(4402),
    [anon_sym___attribute__] = ACTIONS(4402),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym___based] = ACTIONS(4402),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_RBRACE] = ACTIONS(4404),
    [anon_sym_signed] = ACTIONS(4402),
    [anon_sym_unsigned] = ACTIONS(4402),
    [anon_sym_long] = ACTIONS(4402),
    [anon_sym_short] = ACTIONS(4402),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_RBRACK] = ACTIONS(4404),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4402),
    [anon_sym_volatile] = ACTIONS(4402),
    [anon_sym_restrict] = ACTIONS(4402),
    [anon_sym___restrict__] = ACTIONS(4402),
    [anon_sym__Atomic] = ACTIONS(4402),
    [anon_sym__Noreturn] = ACTIONS(4402),
    [anon_sym_noreturn] = ACTIONS(4402),
    [anon_sym__Nonnull] = ACTIONS(4402),
    [anon_sym_mutable] = ACTIONS(4402),
    [anon_sym_constinit] = ACTIONS(4402),
    [anon_sym_consteval] = ACTIONS(4402),
    [anon_sym___shared__] = ACTIONS(4402),
    [anon_sym___local__] = ACTIONS(4402),
    [anon_sym___constant__] = ACTIONS(4402),
    [anon_sym___managed__] = ACTIONS(4402),
    [anon_sym___grid_constant__] = ACTIONS(4402),
    [anon_sym_alignas] = ACTIONS(4402),
    [anon_sym__Alignas] = ACTIONS(4402),
    [sym_primitive_type] = ACTIONS(4402),
    [anon_sym_COLON] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_bitor] = ACTIONS(4402),
    [anon_sym_xor] = ACTIONS(4402),
    [anon_sym_bitand] = ACTIONS(4402),
    [anon_sym_not_eq] = ACTIONS(4402),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4402),
    [anon_sym_decltype] = ACTIONS(4402),
    [anon_sym_final] = ACTIONS(4402),
    [anon_sym_override] = ACTIONS(4402),
    [anon_sym_requires] = ACTIONS(4402),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
  },
  [STATE(2086)] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym___device__] = ACTIONS(2182),
    [anon_sym___host__] = ACTIONS(2182),
    [anon_sym___global__] = ACTIONS(2182),
    [anon_sym___forceinline__] = ACTIONS(2182),
    [anon_sym___noinline__] = ACTIONS(2182),
    [anon_sym_virtual] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym___attribute] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym__Nonnull] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym___shared__] = ACTIONS(2182),
    [anon_sym___local__] = ACTIONS(2182),
    [anon_sym___constant__] = ACTIONS(2182),
    [anon_sym___managed__] = ACTIONS(2182),
    [anon_sym___grid_constant__] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_friend] = ACTIONS(2182),
    [anon_sym_public] = ACTIONS(2182),
    [anon_sym_private] = ACTIONS(2182),
    [anon_sym_protected] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym___launch_bounds__] = ACTIONS(2182),
  },
  [STATE(2087)] = {
    [sym_identifier] = ACTIONS(4408),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_RPAREN] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4410),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4410),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4410),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4410),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4410),
    [anon_sym_SEMI] = ACTIONS(4410),
    [anon_sym___extension__] = ACTIONS(4408),
    [anon_sym___global__] = ACTIONS(4408),
    [anon_sym___attribute__] = ACTIONS(4408),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym___based] = ACTIONS(4408),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_RBRACE] = ACTIONS(4410),
    [anon_sym_signed] = ACTIONS(4408),
    [anon_sym_unsigned] = ACTIONS(4408),
    [anon_sym_long] = ACTIONS(4408),
    [anon_sym_short] = ACTIONS(4408),
    [anon_sym_LBRACK] = ACTIONS(4410),
    [anon_sym_RBRACK] = ACTIONS(4410),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4408),
    [anon_sym_volatile] = ACTIONS(4408),
    [anon_sym_restrict] = ACTIONS(4408),
    [anon_sym___restrict__] = ACTIONS(4408),
    [anon_sym__Atomic] = ACTIONS(4408),
    [anon_sym__Noreturn] = ACTIONS(4408),
    [anon_sym_noreturn] = ACTIONS(4408),
    [anon_sym__Nonnull] = ACTIONS(4408),
    [anon_sym_mutable] = ACTIONS(4408),
    [anon_sym_constinit] = ACTIONS(4408),
    [anon_sym_consteval] = ACTIONS(4408),
    [anon_sym___shared__] = ACTIONS(4408),
    [anon_sym___local__] = ACTIONS(4408),
    [anon_sym___constant__] = ACTIONS(4408),
    [anon_sym___managed__] = ACTIONS(4408),
    [anon_sym___grid_constant__] = ACTIONS(4408),
    [anon_sym_alignas] = ACTIONS(4408),
    [anon_sym__Alignas] = ACTIONS(4408),
    [sym_primitive_type] = ACTIONS(4408),
    [anon_sym_COLON] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_bitor] = ACTIONS(4408),
    [anon_sym_xor] = ACTIONS(4408),
    [anon_sym_bitand] = ACTIONS(4408),
    [anon_sym_not_eq] = ACTIONS(4408),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4408),
    [anon_sym_decltype] = ACTIONS(4408),
    [anon_sym_final] = ACTIONS(4408),
    [anon_sym_override] = ACTIONS(4408),
    [anon_sym_requires] = ACTIONS(4408),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
  },
  [STATE(2088)] = {
    [sym_identifier] = ACTIONS(5569),
    [aux_sym_preproc_def_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token2] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5569),
    [sym_preproc_directive] = ACTIONS(5569),
    [anon_sym_LPAREN2] = ACTIONS(5571),
    [anon_sym_TILDE] = ACTIONS(5571),
    [anon_sym_STAR] = ACTIONS(5571),
    [anon_sym_AMP_AMP] = ACTIONS(5571),
    [anon_sym_AMP] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym___extension__] = ACTIONS(5569),
    [anon_sym_typedef] = ACTIONS(5569),
    [anon_sym___device__] = ACTIONS(5569),
    [anon_sym___host__] = ACTIONS(5569),
    [anon_sym___global__] = ACTIONS(5569),
    [anon_sym___forceinline__] = ACTIONS(5569),
    [anon_sym___noinline__] = ACTIONS(5569),
    [anon_sym_virtual] = ACTIONS(5569),
    [anon_sym_extern] = ACTIONS(5569),
    [anon_sym___attribute__] = ACTIONS(5569),
    [anon_sym___attribute] = ACTIONS(5569),
    [anon_sym_COLON_COLON] = ACTIONS(5571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5571),
    [anon_sym___declspec] = ACTIONS(5569),
    [anon_sym___based] = ACTIONS(5569),
    [anon_sym_signed] = ACTIONS(5569),
    [anon_sym_unsigned] = ACTIONS(5569),
    [anon_sym_long] = ACTIONS(5569),
    [anon_sym_short] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5569),
    [anon_sym_static] = ACTIONS(5569),
    [anon_sym_register] = ACTIONS(5569),
    [anon_sym_inline] = ACTIONS(5569),
    [anon_sym___inline] = ACTIONS(5569),
    [anon_sym___inline__] = ACTIONS(5569),
    [anon_sym___forceinline] = ACTIONS(5569),
    [anon_sym_thread_local] = ACTIONS(5569),
    [anon_sym___thread] = ACTIONS(5569),
    [anon_sym_const] = ACTIONS(5569),
    [anon_sym_constexpr] = ACTIONS(5569),
    [anon_sym_volatile] = ACTIONS(5569),
    [anon_sym_restrict] = ACTIONS(5569),
    [anon_sym___restrict__] = ACTIONS(5569),
    [anon_sym__Atomic] = ACTIONS(5569),
    [anon_sym__Noreturn] = ACTIONS(5569),
    [anon_sym_noreturn] = ACTIONS(5569),
    [anon_sym__Nonnull] = ACTIONS(5569),
    [anon_sym_mutable] = ACTIONS(5569),
    [anon_sym_constinit] = ACTIONS(5569),
    [anon_sym_consteval] = ACTIONS(5569),
    [anon_sym___shared__] = ACTIONS(5569),
    [anon_sym___local__] = ACTIONS(5569),
    [anon_sym___constant__] = ACTIONS(5569),
    [anon_sym___managed__] = ACTIONS(5569),
    [anon_sym___grid_constant__] = ACTIONS(5569),
    [anon_sym_alignas] = ACTIONS(5569),
    [anon_sym__Alignas] = ACTIONS(5569),
    [sym_primitive_type] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_class] = ACTIONS(5569),
    [anon_sym_struct] = ACTIONS(5569),
    [anon_sym_union] = ACTIONS(5569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5569),
    [anon_sym_decltype] = ACTIONS(5569),
    [anon_sym_explicit] = ACTIONS(5569),
    [anon_sym_typename] = ACTIONS(5569),
    [anon_sym_template] = ACTIONS(5569),
    [anon_sym_operator] = ACTIONS(5569),
    [anon_sym_friend] = ACTIONS(5569),
    [anon_sym_public] = ACTIONS(5569),
    [anon_sym_private] = ACTIONS(5569),
    [anon_sym_protected] = ACTIONS(5569),
    [anon_sym_using] = ACTIONS(5569),
    [anon_sym_static_assert] = ACTIONS(5569),
    [anon_sym___launch_bounds__] = ACTIONS(5569),
  },
  [STATE(2089)] = {
    [sym_identifier] = ACTIONS(5553),
    [aux_sym_preproc_def_token1] = ACTIONS(5553),
    [aux_sym_preproc_if_token1] = ACTIONS(5553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5553),
    [sym_preproc_directive] = ACTIONS(5553),
    [anon_sym_LPAREN2] = ACTIONS(5555),
    [anon_sym_TILDE] = ACTIONS(5555),
    [anon_sym_STAR] = ACTIONS(5555),
    [anon_sym_AMP_AMP] = ACTIONS(5555),
    [anon_sym_AMP] = ACTIONS(5553),
    [anon_sym_SEMI] = ACTIONS(5555),
    [anon_sym___extension__] = ACTIONS(5553),
    [anon_sym_typedef] = ACTIONS(5553),
    [anon_sym___device__] = ACTIONS(5553),
    [anon_sym___host__] = ACTIONS(5553),
    [anon_sym___global__] = ACTIONS(5553),
    [anon_sym___forceinline__] = ACTIONS(5553),
    [anon_sym___noinline__] = ACTIONS(5553),
    [anon_sym_virtual] = ACTIONS(5553),
    [anon_sym_extern] = ACTIONS(5553),
    [anon_sym___attribute__] = ACTIONS(5553),
    [anon_sym___attribute] = ACTIONS(5553),
    [anon_sym_COLON_COLON] = ACTIONS(5555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5555),
    [anon_sym___declspec] = ACTIONS(5553),
    [anon_sym___based] = ACTIONS(5553),
    [anon_sym_RBRACE] = ACTIONS(5555),
    [anon_sym_signed] = ACTIONS(5553),
    [anon_sym_unsigned] = ACTIONS(5553),
    [anon_sym_long] = ACTIONS(5553),
    [anon_sym_short] = ACTIONS(5553),
    [anon_sym_LBRACK] = ACTIONS(5553),
    [anon_sym_static] = ACTIONS(5553),
    [anon_sym_register] = ACTIONS(5553),
    [anon_sym_inline] = ACTIONS(5553),
    [anon_sym___inline] = ACTIONS(5553),
    [anon_sym___inline__] = ACTIONS(5553),
    [anon_sym___forceinline] = ACTIONS(5553),
    [anon_sym_thread_local] = ACTIONS(5553),
    [anon_sym___thread] = ACTIONS(5553),
    [anon_sym_const] = ACTIONS(5553),
    [anon_sym_constexpr] = ACTIONS(5553),
    [anon_sym_volatile] = ACTIONS(5553),
    [anon_sym_restrict] = ACTIONS(5553),
    [anon_sym___restrict__] = ACTIONS(5553),
    [anon_sym__Atomic] = ACTIONS(5553),
    [anon_sym__Noreturn] = ACTIONS(5553),
    [anon_sym_noreturn] = ACTIONS(5553),
    [anon_sym__Nonnull] = ACTIONS(5553),
    [anon_sym_mutable] = ACTIONS(5553),
    [anon_sym_constinit] = ACTIONS(5553),
    [anon_sym_consteval] = ACTIONS(5553),
    [anon_sym___shared__] = ACTIONS(5553),
    [anon_sym___local__] = ACTIONS(5553),
    [anon_sym___constant__] = ACTIONS(5553),
    [anon_sym___managed__] = ACTIONS(5553),
    [anon_sym___grid_constant__] = ACTIONS(5553),
    [anon_sym_alignas] = ACTIONS(5553),
    [anon_sym__Alignas] = ACTIONS(5553),
    [sym_primitive_type] = ACTIONS(5553),
    [anon_sym_enum] = ACTIONS(5553),
    [anon_sym_class] = ACTIONS(5553),
    [anon_sym_struct] = ACTIONS(5553),
    [anon_sym_union] = ACTIONS(5553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5553),
    [anon_sym_decltype] = ACTIONS(5553),
    [anon_sym_explicit] = ACTIONS(5553),
    [anon_sym_typename] = ACTIONS(5553),
    [anon_sym_template] = ACTIONS(5553),
    [anon_sym_operator] = ACTIONS(5553),
    [anon_sym_friend] = ACTIONS(5553),
    [anon_sym_public] = ACTIONS(5553),
    [anon_sym_private] = ACTIONS(5553),
    [anon_sym_protected] = ACTIONS(5553),
    [anon_sym_using] = ACTIONS(5553),
    [anon_sym_static_assert] = ACTIONS(5553),
    [anon_sym___launch_bounds__] = ACTIONS(5553),
  },
  [STATE(2090)] = {
    [sym_identifier] = ACTIONS(5573),
    [aux_sym_preproc_def_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token2] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5573),
    [sym_preproc_directive] = ACTIONS(5573),
    [anon_sym_LPAREN2] = ACTIONS(5575),
    [anon_sym_TILDE] = ACTIONS(5575),
    [anon_sym_STAR] = ACTIONS(5575),
    [anon_sym_AMP_AMP] = ACTIONS(5575),
    [anon_sym_AMP] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym___extension__] = ACTIONS(5573),
    [anon_sym_typedef] = ACTIONS(5573),
    [anon_sym___device__] = ACTIONS(5573),
    [anon_sym___host__] = ACTIONS(5573),
    [anon_sym___global__] = ACTIONS(5573),
    [anon_sym___forceinline__] = ACTIONS(5573),
    [anon_sym___noinline__] = ACTIONS(5573),
    [anon_sym_virtual] = ACTIONS(5573),
    [anon_sym_extern] = ACTIONS(5573),
    [anon_sym___attribute__] = ACTIONS(5573),
    [anon_sym___attribute] = ACTIONS(5573),
    [anon_sym_COLON_COLON] = ACTIONS(5575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5575),
    [anon_sym___declspec] = ACTIONS(5573),
    [anon_sym___based] = ACTIONS(5573),
    [anon_sym_signed] = ACTIONS(5573),
    [anon_sym_unsigned] = ACTIONS(5573),
    [anon_sym_long] = ACTIONS(5573),
    [anon_sym_short] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5573),
    [anon_sym_static] = ACTIONS(5573),
    [anon_sym_register] = ACTIONS(5573),
    [anon_sym_inline] = ACTIONS(5573),
    [anon_sym___inline] = ACTIONS(5573),
    [anon_sym___inline__] = ACTIONS(5573),
    [anon_sym___forceinline] = ACTIONS(5573),
    [anon_sym_thread_local] = ACTIONS(5573),
    [anon_sym___thread] = ACTIONS(5573),
    [anon_sym_const] = ACTIONS(5573),
    [anon_sym_constexpr] = ACTIONS(5573),
    [anon_sym_volatile] = ACTIONS(5573),
    [anon_sym_restrict] = ACTIONS(5573),
    [anon_sym___restrict__] = ACTIONS(5573),
    [anon_sym__Atomic] = ACTIONS(5573),
    [anon_sym__Noreturn] = ACTIONS(5573),
    [anon_sym_noreturn] = ACTIONS(5573),
    [anon_sym__Nonnull] = ACTIONS(5573),
    [anon_sym_mutable] = ACTIONS(5573),
    [anon_sym_constinit] = ACTIONS(5573),
    [anon_sym_consteval] = ACTIONS(5573),
    [anon_sym___shared__] = ACTIONS(5573),
    [anon_sym___local__] = ACTIONS(5573),
    [anon_sym___constant__] = ACTIONS(5573),
    [anon_sym___managed__] = ACTIONS(5573),
    [anon_sym___grid_constant__] = ACTIONS(5573),
    [anon_sym_alignas] = ACTIONS(5573),
    [anon_sym__Alignas] = ACTIONS(5573),
    [sym_primitive_type] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_class] = ACTIONS(5573),
    [anon_sym_struct] = ACTIONS(5573),
    [anon_sym_union] = ACTIONS(5573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5573),
    [anon_sym_decltype] = ACTIONS(5573),
    [anon_sym_explicit] = ACTIONS(5573),
    [anon_sym_typename] = ACTIONS(5573),
    [anon_sym_template] = ACTIONS(5573),
    [anon_sym_operator] = ACTIONS(5573),
    [anon_sym_friend] = ACTIONS(5573),
    [anon_sym_public] = ACTIONS(5573),
    [anon_sym_private] = ACTIONS(5573),
    [anon_sym_protected] = ACTIONS(5573),
    [anon_sym_using] = ACTIONS(5573),
    [anon_sym_static_assert] = ACTIONS(5573),
    [anon_sym___launch_bounds__] = ACTIONS(5573),
  },
  [STATE(2091)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym_RBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_friend] = ACTIONS(2585),
    [anon_sym_public] = ACTIONS(2585),
    [anon_sym_private] = ACTIONS(2585),
    [anon_sym_protected] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(2092)] = {
    [sym_identifier] = ACTIONS(2585),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2585),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2585),
    [sym_preproc_directive] = ACTIONS(2585),
    [anon_sym_LPAREN2] = ACTIONS(2587),
    [anon_sym_TILDE] = ACTIONS(2587),
    [anon_sym_STAR] = ACTIONS(2587),
    [anon_sym_AMP_AMP] = ACTIONS(2587),
    [anon_sym_AMP] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2587),
    [anon_sym___extension__] = ACTIONS(2585),
    [anon_sym_typedef] = ACTIONS(2585),
    [anon_sym___device__] = ACTIONS(2585),
    [anon_sym___host__] = ACTIONS(2585),
    [anon_sym___global__] = ACTIONS(2585),
    [anon_sym___forceinline__] = ACTIONS(2585),
    [anon_sym___noinline__] = ACTIONS(2585),
    [anon_sym_virtual] = ACTIONS(2585),
    [anon_sym_extern] = ACTIONS(2585),
    [anon_sym___attribute__] = ACTIONS(2585),
    [anon_sym___attribute] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(2587),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2587),
    [anon_sym___declspec] = ACTIONS(2585),
    [anon_sym___based] = ACTIONS(2585),
    [anon_sym_RBRACE] = ACTIONS(2587),
    [anon_sym_signed] = ACTIONS(2585),
    [anon_sym_unsigned] = ACTIONS(2585),
    [anon_sym_long] = ACTIONS(2585),
    [anon_sym_short] = ACTIONS(2585),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2585),
    [anon_sym_register] = ACTIONS(2585),
    [anon_sym_inline] = ACTIONS(2585),
    [anon_sym___inline] = ACTIONS(2585),
    [anon_sym___inline__] = ACTIONS(2585),
    [anon_sym___forceinline] = ACTIONS(2585),
    [anon_sym_thread_local] = ACTIONS(2585),
    [anon_sym___thread] = ACTIONS(2585),
    [anon_sym_const] = ACTIONS(2585),
    [anon_sym_constexpr] = ACTIONS(2585),
    [anon_sym_volatile] = ACTIONS(2585),
    [anon_sym_restrict] = ACTIONS(2585),
    [anon_sym___restrict__] = ACTIONS(2585),
    [anon_sym__Atomic] = ACTIONS(2585),
    [anon_sym__Noreturn] = ACTIONS(2585),
    [anon_sym_noreturn] = ACTIONS(2585),
    [anon_sym__Nonnull] = ACTIONS(2585),
    [anon_sym_mutable] = ACTIONS(2585),
    [anon_sym_constinit] = ACTIONS(2585),
    [anon_sym_consteval] = ACTIONS(2585),
    [anon_sym___shared__] = ACTIONS(2585),
    [anon_sym___local__] = ACTIONS(2585),
    [anon_sym___constant__] = ACTIONS(2585),
    [anon_sym___managed__] = ACTIONS(2585),
    [anon_sym___grid_constant__] = ACTIONS(2585),
    [anon_sym_alignas] = ACTIONS(2585),
    [anon_sym__Alignas] = ACTIONS(2585),
    [sym_primitive_type] = ACTIONS(2585),
    [anon_sym_enum] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2585),
    [anon_sym_struct] = ACTIONS(2585),
    [anon_sym_union] = ACTIONS(2585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2585),
    [anon_sym_decltype] = ACTIONS(2585),
    [anon_sym_explicit] = ACTIONS(2585),
    [anon_sym_typename] = ACTIONS(2585),
    [anon_sym_template] = ACTIONS(2585),
    [anon_sym_operator] = ACTIONS(2585),
    [anon_sym_friend] = ACTIONS(2585),
    [anon_sym_public] = ACTIONS(2585),
    [anon_sym_private] = ACTIONS(2585),
    [anon_sym_protected] = ACTIONS(2585),
    [anon_sym_using] = ACTIONS(2585),
    [anon_sym_static_assert] = ACTIONS(2585),
    [anon_sym___launch_bounds__] = ACTIONS(2585),
  },
  [STATE(2093)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_RBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(2094)] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token2] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym___device__] = ACTIONS(2134),
    [anon_sym___host__] = ACTIONS(2134),
    [anon_sym___global__] = ACTIONS(2134),
    [anon_sym___forceinline__] = ACTIONS(2134),
    [anon_sym___noinline__] = ACTIONS(2134),
    [anon_sym_virtual] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym___attribute] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym__Nonnull] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym___shared__] = ACTIONS(2134),
    [anon_sym___local__] = ACTIONS(2134),
    [anon_sym___constant__] = ACTIONS(2134),
    [anon_sym___managed__] = ACTIONS(2134),
    [anon_sym___grid_constant__] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_friend] = ACTIONS(2134),
    [anon_sym_public] = ACTIONS(2134),
    [anon_sym_private] = ACTIONS(2134),
    [anon_sym_protected] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym___launch_bounds__] = ACTIONS(2134),
  },
  [STATE(2095)] = {
    [sym_identifier] = ACTIONS(2463),
    [aux_sym_preproc_def_token1] = ACTIONS(2463),
    [aux_sym_preproc_if_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2463),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2463),
    [sym_preproc_directive] = ACTIONS(2463),
    [anon_sym_LPAREN2] = ACTIONS(2465),
    [anon_sym_TILDE] = ACTIONS(2465),
    [anon_sym_STAR] = ACTIONS(2465),
    [anon_sym_AMP_AMP] = ACTIONS(2465),
    [anon_sym_AMP] = ACTIONS(2463),
    [anon_sym_SEMI] = ACTIONS(2465),
    [anon_sym___extension__] = ACTIONS(2463),
    [anon_sym_typedef] = ACTIONS(2463),
    [anon_sym___device__] = ACTIONS(2463),
    [anon_sym___host__] = ACTIONS(2463),
    [anon_sym___global__] = ACTIONS(2463),
    [anon_sym___forceinline__] = ACTIONS(2463),
    [anon_sym___noinline__] = ACTIONS(2463),
    [anon_sym_virtual] = ACTIONS(2463),
    [anon_sym_extern] = ACTIONS(2463),
    [anon_sym___attribute__] = ACTIONS(2463),
    [anon_sym___attribute] = ACTIONS(2463),
    [anon_sym_COLON_COLON] = ACTIONS(2465),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2465),
    [anon_sym___declspec] = ACTIONS(2463),
    [anon_sym___based] = ACTIONS(2463),
    [anon_sym_RBRACE] = ACTIONS(2465),
    [anon_sym_signed] = ACTIONS(2463),
    [anon_sym_unsigned] = ACTIONS(2463),
    [anon_sym_long] = ACTIONS(2463),
    [anon_sym_short] = ACTIONS(2463),
    [anon_sym_LBRACK] = ACTIONS(2463),
    [anon_sym_static] = ACTIONS(2463),
    [anon_sym_register] = ACTIONS(2463),
    [anon_sym_inline] = ACTIONS(2463),
    [anon_sym___inline] = ACTIONS(2463),
    [anon_sym___inline__] = ACTIONS(2463),
    [anon_sym___forceinline] = ACTIONS(2463),
    [anon_sym_thread_local] = ACTIONS(2463),
    [anon_sym___thread] = ACTIONS(2463),
    [anon_sym_const] = ACTIONS(2463),
    [anon_sym_constexpr] = ACTIONS(2463),
    [anon_sym_volatile] = ACTIONS(2463),
    [anon_sym_restrict] = ACTIONS(2463),
    [anon_sym___restrict__] = ACTIONS(2463),
    [anon_sym__Atomic] = ACTIONS(2463),
    [anon_sym__Noreturn] = ACTIONS(2463),
    [anon_sym_noreturn] = ACTIONS(2463),
    [anon_sym__Nonnull] = ACTIONS(2463),
    [anon_sym_mutable] = ACTIONS(2463),
    [anon_sym_constinit] = ACTIONS(2463),
    [anon_sym_consteval] = ACTIONS(2463),
    [anon_sym___shared__] = ACTIONS(2463),
    [anon_sym___local__] = ACTIONS(2463),
    [anon_sym___constant__] = ACTIONS(2463),
    [anon_sym___managed__] = ACTIONS(2463),
    [anon_sym___grid_constant__] = ACTIONS(2463),
    [anon_sym_alignas] = ACTIONS(2463),
    [anon_sym__Alignas] = ACTIONS(2463),
    [sym_primitive_type] = ACTIONS(2463),
    [anon_sym_enum] = ACTIONS(2463),
    [anon_sym_class] = ACTIONS(2463),
    [anon_sym_struct] = ACTIONS(2463),
    [anon_sym_union] = ACTIONS(2463),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2463),
    [anon_sym_decltype] = ACTIONS(2463),
    [anon_sym_explicit] = ACTIONS(2463),
    [anon_sym_typename] = ACTIONS(2463),
    [anon_sym_template] = ACTIONS(2463),
    [anon_sym_operator] = ACTIONS(2463),
    [anon_sym_friend] = ACTIONS(2463),
    [anon_sym_public] = ACTIONS(2463),
    [anon_sym_private] = ACTIONS(2463),
    [anon_sym_protected] = ACTIONS(2463),
    [anon_sym_using] = ACTIONS(2463),
    [anon_sym_static_assert] = ACTIONS(2463),
    [anon_sym___launch_bounds__] = ACTIONS(2463),
  },
  [STATE(2096)] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym___device__] = ACTIONS(2573),
    [anon_sym___host__] = ACTIONS(2573),
    [anon_sym___global__] = ACTIONS(2573),
    [anon_sym___forceinline__] = ACTIONS(2573),
    [anon_sym___noinline__] = ACTIONS(2573),
    [anon_sym_virtual] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym___attribute] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_RBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym__Nonnull] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym___shared__] = ACTIONS(2573),
    [anon_sym___local__] = ACTIONS(2573),
    [anon_sym___constant__] = ACTIONS(2573),
    [anon_sym___managed__] = ACTIONS(2573),
    [anon_sym___grid_constant__] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym___launch_bounds__] = ACTIONS(2573),
  },
  [STATE(2097)] = {
    [sym_identifier] = ACTIONS(5569),
    [aux_sym_preproc_def_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token1] = ACTIONS(5569),
    [aux_sym_preproc_if_token2] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5569),
    [sym_preproc_directive] = ACTIONS(5569),
    [anon_sym_LPAREN2] = ACTIONS(5571),
    [anon_sym_TILDE] = ACTIONS(5571),
    [anon_sym_STAR] = ACTIONS(5571),
    [anon_sym_AMP_AMP] = ACTIONS(5571),
    [anon_sym_AMP] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym___extension__] = ACTIONS(5569),
    [anon_sym_typedef] = ACTIONS(5569),
    [anon_sym___device__] = ACTIONS(5569),
    [anon_sym___host__] = ACTIONS(5569),
    [anon_sym___global__] = ACTIONS(5569),
    [anon_sym___forceinline__] = ACTIONS(5569),
    [anon_sym___noinline__] = ACTIONS(5569),
    [anon_sym_virtual] = ACTIONS(5569),
    [anon_sym_extern] = ACTIONS(5569),
    [anon_sym___attribute__] = ACTIONS(5569),
    [anon_sym___attribute] = ACTIONS(5569),
    [anon_sym_COLON_COLON] = ACTIONS(5571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5571),
    [anon_sym___declspec] = ACTIONS(5569),
    [anon_sym___based] = ACTIONS(5569),
    [anon_sym_signed] = ACTIONS(5569),
    [anon_sym_unsigned] = ACTIONS(5569),
    [anon_sym_long] = ACTIONS(5569),
    [anon_sym_short] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5569),
    [anon_sym_static] = ACTIONS(5569),
    [anon_sym_register] = ACTIONS(5569),
    [anon_sym_inline] = ACTIONS(5569),
    [anon_sym___inline] = ACTIONS(5569),
    [anon_sym___inline__] = ACTIONS(5569),
    [anon_sym___forceinline] = ACTIONS(5569),
    [anon_sym_thread_local] = ACTIONS(5569),
    [anon_sym___thread] = ACTIONS(5569),
    [anon_sym_const] = ACTIONS(5569),
    [anon_sym_constexpr] = ACTIONS(5569),
    [anon_sym_volatile] = ACTIONS(5569),
    [anon_sym_restrict] = ACTIONS(5569),
    [anon_sym___restrict__] = ACTIONS(5569),
    [anon_sym__Atomic] = ACTIONS(5569),
    [anon_sym__Noreturn] = ACTIONS(5569),
    [anon_sym_noreturn] = ACTIONS(5569),
    [anon_sym__Nonnull] = ACTIONS(5569),
    [anon_sym_mutable] = ACTIONS(5569),
    [anon_sym_constinit] = ACTIONS(5569),
    [anon_sym_consteval] = ACTIONS(5569),
    [anon_sym___shared__] = ACTIONS(5569),
    [anon_sym___local__] = ACTIONS(5569),
    [anon_sym___constant__] = ACTIONS(5569),
    [anon_sym___managed__] = ACTIONS(5569),
    [anon_sym___grid_constant__] = ACTIONS(5569),
    [anon_sym_alignas] = ACTIONS(5569),
    [anon_sym__Alignas] = ACTIONS(5569),
    [sym_primitive_type] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_class] = ACTIONS(5569),
    [anon_sym_struct] = ACTIONS(5569),
    [anon_sym_union] = ACTIONS(5569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5569),
    [anon_sym_decltype] = ACTIONS(5569),
    [anon_sym_explicit] = ACTIONS(5569),
    [anon_sym_typename] = ACTIONS(5569),
    [anon_sym_template] = ACTIONS(5569),
    [anon_sym_operator] = ACTIONS(5569),
    [anon_sym_friend] = ACTIONS(5569),
    [anon_sym_public] = ACTIONS(5569),
    [anon_sym_private] = ACTIONS(5569),
    [anon_sym_protected] = ACTIONS(5569),
    [anon_sym_using] = ACTIONS(5569),
    [anon_sym_static_assert] = ACTIONS(5569),
    [anon_sym___launch_bounds__] = ACTIONS(5569),
  },
  [STATE(2098)] = {
    [sym_identifier] = ACTIONS(2226),
    [aux_sym_preproc_def_token1] = ACTIONS(2226),
    [aux_sym_preproc_if_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2226),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2226),
    [sym_preproc_directive] = ACTIONS(2226),
    [anon_sym_LPAREN2] = ACTIONS(2228),
    [anon_sym_TILDE] = ACTIONS(2228),
    [anon_sym_STAR] = ACTIONS(2228),
    [anon_sym_AMP_AMP] = ACTIONS(2228),
    [anon_sym_AMP] = ACTIONS(2226),
    [anon_sym_SEMI] = ACTIONS(2228),
    [anon_sym___extension__] = ACTIONS(2226),
    [anon_sym_typedef] = ACTIONS(2226),
    [anon_sym___device__] = ACTIONS(2226),
    [anon_sym___host__] = ACTIONS(2226),
    [anon_sym___global__] = ACTIONS(2226),
    [anon_sym___forceinline__] = ACTIONS(2226),
    [anon_sym___noinline__] = ACTIONS(2226),
    [anon_sym_virtual] = ACTIONS(2226),
    [anon_sym_extern] = ACTIONS(2226),
    [anon_sym___attribute__] = ACTIONS(2226),
    [anon_sym___attribute] = ACTIONS(2226),
    [anon_sym_COLON_COLON] = ACTIONS(2228),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2228),
    [anon_sym___declspec] = ACTIONS(2226),
    [anon_sym___based] = ACTIONS(2226),
    [anon_sym_RBRACE] = ACTIONS(2228),
    [anon_sym_signed] = ACTIONS(2226),
    [anon_sym_unsigned] = ACTIONS(2226),
    [anon_sym_long] = ACTIONS(2226),
    [anon_sym_short] = ACTIONS(2226),
    [anon_sym_LBRACK] = ACTIONS(2226),
    [anon_sym_static] = ACTIONS(2226),
    [anon_sym_register] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(2226),
    [anon_sym___inline] = ACTIONS(2226),
    [anon_sym___inline__] = ACTIONS(2226),
    [anon_sym___forceinline] = ACTIONS(2226),
    [anon_sym_thread_local] = ACTIONS(2226),
    [anon_sym___thread] = ACTIONS(2226),
    [anon_sym_const] = ACTIONS(2226),
    [anon_sym_constexpr] = ACTIONS(2226),
    [anon_sym_volatile] = ACTIONS(2226),
    [anon_sym_restrict] = ACTIONS(2226),
    [anon_sym___restrict__] = ACTIONS(2226),
    [anon_sym__Atomic] = ACTIONS(2226),
    [anon_sym__Noreturn] = ACTIONS(2226),
    [anon_sym_noreturn] = ACTIONS(2226),
    [anon_sym__Nonnull] = ACTIONS(2226),
    [anon_sym_mutable] = ACTIONS(2226),
    [anon_sym_constinit] = ACTIONS(2226),
    [anon_sym_consteval] = ACTIONS(2226),
    [anon_sym___shared__] = ACTIONS(2226),
    [anon_sym___local__] = ACTIONS(2226),
    [anon_sym___constant__] = ACTIONS(2226),
    [anon_sym___managed__] = ACTIONS(2226),
    [anon_sym___grid_constant__] = ACTIONS(2226),
    [anon_sym_alignas] = ACTIONS(2226),
    [anon_sym__Alignas] = ACTIONS(2226),
    [sym_primitive_type] = ACTIONS(2226),
    [anon_sym_enum] = ACTIONS(2226),
    [anon_sym_class] = ACTIONS(2226),
    [anon_sym_struct] = ACTIONS(2226),
    [anon_sym_union] = ACTIONS(2226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2226),
    [anon_sym_decltype] = ACTIONS(2226),
    [anon_sym_explicit] = ACTIONS(2226),
    [anon_sym_typename] = ACTIONS(2226),
    [anon_sym_template] = ACTIONS(2226),
    [anon_sym_operator] = ACTIONS(2226),
    [anon_sym_friend] = ACTIONS(2226),
    [anon_sym_public] = ACTIONS(2226),
    [anon_sym_private] = ACTIONS(2226),
    [anon_sym_protected] = ACTIONS(2226),
    [anon_sym_using] = ACTIONS(2226),
    [anon_sym_static_assert] = ACTIONS(2226),
    [anon_sym___launch_bounds__] = ACTIONS(2226),
  },
  [STATE(2099)] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym___device__] = ACTIONS(2332),
    [anon_sym___host__] = ACTIONS(2332),
    [anon_sym___global__] = ACTIONS(2332),
    [anon_sym___forceinline__] = ACTIONS(2332),
    [anon_sym___noinline__] = ACTIONS(2332),
    [anon_sym_virtual] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym___attribute] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym__Nonnull] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym___shared__] = ACTIONS(2332),
    [anon_sym___local__] = ACTIONS(2332),
    [anon_sym___constant__] = ACTIONS(2332),
    [anon_sym___managed__] = ACTIONS(2332),
    [anon_sym___grid_constant__] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym___launch_bounds__] = ACTIONS(2332),
  },
  [STATE(2100)] = {
    [sym_identifier] = ACTIONS(2032),
    [aux_sym_preproc_def_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token1] = ACTIONS(2032),
    [aux_sym_preproc_if_token2] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2032),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2032),
    [sym_preproc_directive] = ACTIONS(2032),
    [anon_sym_LPAREN2] = ACTIONS(2034),
    [anon_sym_TILDE] = ACTIONS(2034),
    [anon_sym_STAR] = ACTIONS(2034),
    [anon_sym_AMP_AMP] = ACTIONS(2034),
    [anon_sym_AMP] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(2034),
    [anon_sym___extension__] = ACTIONS(2032),
    [anon_sym_typedef] = ACTIONS(2032),
    [anon_sym___device__] = ACTIONS(2032),
    [anon_sym___host__] = ACTIONS(2032),
    [anon_sym___global__] = ACTIONS(2032),
    [anon_sym___forceinline__] = ACTIONS(2032),
    [anon_sym___noinline__] = ACTIONS(2032),
    [anon_sym_virtual] = ACTIONS(2032),
    [anon_sym_extern] = ACTIONS(2032),
    [anon_sym___attribute__] = ACTIONS(2032),
    [anon_sym___attribute] = ACTIONS(2032),
    [anon_sym_COLON_COLON] = ACTIONS(2034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2034),
    [anon_sym___declspec] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2032),
    [anon_sym_unsigned] = ACTIONS(2032),
    [anon_sym_long] = ACTIONS(2032),
    [anon_sym_short] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(2032),
    [anon_sym_static] = ACTIONS(2032),
    [anon_sym_register] = ACTIONS(2032),
    [anon_sym_inline] = ACTIONS(2032),
    [anon_sym___inline] = ACTIONS(2032),
    [anon_sym___inline__] = ACTIONS(2032),
    [anon_sym___forceinline] = ACTIONS(2032),
    [anon_sym_thread_local] = ACTIONS(2032),
    [anon_sym___thread] = ACTIONS(2032),
    [anon_sym_const] = ACTIONS(2032),
    [anon_sym_constexpr] = ACTIONS(2032),
    [anon_sym_volatile] = ACTIONS(2032),
    [anon_sym_restrict] = ACTIONS(2032),
    [anon_sym___restrict__] = ACTIONS(2032),
    [anon_sym__Atomic] = ACTIONS(2032),
    [anon_sym__Noreturn] = ACTIONS(2032),
    [anon_sym_noreturn] = ACTIONS(2032),
    [anon_sym__Nonnull] = ACTIONS(2032),
    [anon_sym_mutable] = ACTIONS(2032),
    [anon_sym_constinit] = ACTIONS(2032),
    [anon_sym_consteval] = ACTIONS(2032),
    [anon_sym___shared__] = ACTIONS(2032),
    [anon_sym___local__] = ACTIONS(2032),
    [anon_sym___constant__] = ACTIONS(2032),
    [anon_sym___managed__] = ACTIONS(2032),
    [anon_sym___grid_constant__] = ACTIONS(2032),
    [anon_sym_alignas] = ACTIONS(2032),
    [anon_sym__Alignas] = ACTIONS(2032),
    [sym_primitive_type] = ACTIONS(2032),
    [anon_sym_enum] = ACTIONS(2032),
    [anon_sym_class] = ACTIONS(2032),
    [anon_sym_struct] = ACTIONS(2032),
    [anon_sym_union] = ACTIONS(2032),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2032),
    [anon_sym_decltype] = ACTIONS(2032),
    [anon_sym_explicit] = ACTIONS(2032),
    [anon_sym_typename] = ACTIONS(2032),
    [anon_sym_template] = ACTIONS(2032),
    [anon_sym_operator] = ACTIONS(2032),
    [anon_sym_friend] = ACTIONS(2032),
    [anon_sym_public] = ACTIONS(2032),
    [anon_sym_private] = ACTIONS(2032),
    [anon_sym_protected] = ACTIONS(2032),
    [anon_sym_using] = ACTIONS(2032),
    [anon_sym_static_assert] = ACTIONS(2032),
    [anon_sym___launch_bounds__] = ACTIONS(2032),
  },
  [STATE(2101)] = {
    [sym_identifier] = ACTIONS(5561),
    [aux_sym_preproc_def_token1] = ACTIONS(5561),
    [aux_sym_preproc_if_token1] = ACTIONS(5561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5561),
    [sym_preproc_directive] = ACTIONS(5561),
    [anon_sym_LPAREN2] = ACTIONS(5563),
    [anon_sym_TILDE] = ACTIONS(5563),
    [anon_sym_STAR] = ACTIONS(5563),
    [anon_sym_AMP_AMP] = ACTIONS(5563),
    [anon_sym_AMP] = ACTIONS(5561),
    [anon_sym_SEMI] = ACTIONS(5563),
    [anon_sym___extension__] = ACTIONS(5561),
    [anon_sym_typedef] = ACTIONS(5561),
    [anon_sym___device__] = ACTIONS(5561),
    [anon_sym___host__] = ACTIONS(5561),
    [anon_sym___global__] = ACTIONS(5561),
    [anon_sym___forceinline__] = ACTIONS(5561),
    [anon_sym___noinline__] = ACTIONS(5561),
    [anon_sym_virtual] = ACTIONS(5561),
    [anon_sym_extern] = ACTIONS(5561),
    [anon_sym___attribute__] = ACTIONS(5561),
    [anon_sym___attribute] = ACTIONS(5561),
    [anon_sym_COLON_COLON] = ACTIONS(5563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5563),
    [anon_sym___declspec] = ACTIONS(5561),
    [anon_sym___based] = ACTIONS(5561),
    [anon_sym_RBRACE] = ACTIONS(5563),
    [anon_sym_signed] = ACTIONS(5561),
    [anon_sym_unsigned] = ACTIONS(5561),
    [anon_sym_long] = ACTIONS(5561),
    [anon_sym_short] = ACTIONS(5561),
    [anon_sym_LBRACK] = ACTIONS(5561),
    [anon_sym_static] = ACTIONS(5561),
    [anon_sym_register] = ACTIONS(5561),
    [anon_sym_inline] = ACTIONS(5561),
    [anon_sym___inline] = ACTIONS(5561),
    [anon_sym___inline__] = ACTIONS(5561),
    [anon_sym___forceinline] = ACTIONS(5561),
    [anon_sym_thread_local] = ACTIONS(5561),
    [anon_sym___thread] = ACTIONS(5561),
    [anon_sym_const] = ACTIONS(5561),
    [anon_sym_constexpr] = ACTIONS(5561),
    [anon_sym_volatile] = ACTIONS(5561),
    [anon_sym_restrict] = ACTIONS(5561),
    [anon_sym___restrict__] = ACTIONS(5561),
    [anon_sym__Atomic] = ACTIONS(5561),
    [anon_sym__Noreturn] = ACTIONS(5561),
    [anon_sym_noreturn] = ACTIONS(5561),
    [anon_sym__Nonnull] = ACTIONS(5561),
    [anon_sym_mutable] = ACTIONS(5561),
    [anon_sym_constinit] = ACTIONS(5561),
    [anon_sym_consteval] = ACTIONS(5561),
    [anon_sym___shared__] = ACTIONS(5561),
    [anon_sym___local__] = ACTIONS(5561),
    [anon_sym___constant__] = ACTIONS(5561),
    [anon_sym___managed__] = ACTIONS(5561),
    [anon_sym___grid_constant__] = ACTIONS(5561),
    [anon_sym_alignas] = ACTIONS(5561),
    [anon_sym__Alignas] = ACTIONS(5561),
    [sym_primitive_type] = ACTIONS(5561),
    [anon_sym_enum] = ACTIONS(5561),
    [anon_sym_class] = ACTIONS(5561),
    [anon_sym_struct] = ACTIONS(5561),
    [anon_sym_union] = ACTIONS(5561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5561),
    [anon_sym_decltype] = ACTIONS(5561),
    [anon_sym_explicit] = ACTIONS(5561),
    [anon_sym_typename] = ACTIONS(5561),
    [anon_sym_template] = ACTIONS(5561),
    [anon_sym_operator] = ACTIONS(5561),
    [anon_sym_friend] = ACTIONS(5561),
    [anon_sym_public] = ACTIONS(5561),
    [anon_sym_private] = ACTIONS(5561),
    [anon_sym_protected] = ACTIONS(5561),
    [anon_sym_using] = ACTIONS(5561),
    [anon_sym_static_assert] = ACTIONS(5561),
    [anon_sym___launch_bounds__] = ACTIONS(5561),
  },
  [STATE(2102)] = {
    [sym_identifier] = ACTIONS(5509),
    [aux_sym_preproc_def_token1] = ACTIONS(5509),
    [aux_sym_preproc_if_token1] = ACTIONS(5509),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5509),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5509),
    [sym_preproc_directive] = ACTIONS(5509),
    [anon_sym_LPAREN2] = ACTIONS(5511),
    [anon_sym_TILDE] = ACTIONS(5511),
    [anon_sym_STAR] = ACTIONS(5511),
    [anon_sym_AMP_AMP] = ACTIONS(5511),
    [anon_sym_AMP] = ACTIONS(5509),
    [anon_sym_SEMI] = ACTIONS(5511),
    [anon_sym___extension__] = ACTIONS(5509),
    [anon_sym_typedef] = ACTIONS(5509),
    [anon_sym___device__] = ACTIONS(5509),
    [anon_sym___host__] = ACTIONS(5509),
    [anon_sym___global__] = ACTIONS(5509),
    [anon_sym___forceinline__] = ACTIONS(5509),
    [anon_sym___noinline__] = ACTIONS(5509),
    [anon_sym_virtual] = ACTIONS(5509),
    [anon_sym_extern] = ACTIONS(5509),
    [anon_sym___attribute__] = ACTIONS(5509),
    [anon_sym___attribute] = ACTIONS(5509),
    [anon_sym_COLON_COLON] = ACTIONS(5511),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5511),
    [anon_sym___declspec] = ACTIONS(5509),
    [anon_sym___based] = ACTIONS(5509),
    [anon_sym_RBRACE] = ACTIONS(5511),
    [anon_sym_signed] = ACTIONS(5509),
    [anon_sym_unsigned] = ACTIONS(5509),
    [anon_sym_long] = ACTIONS(5509),
    [anon_sym_short] = ACTIONS(5509),
    [anon_sym_LBRACK] = ACTIONS(5509),
    [anon_sym_static] = ACTIONS(5509),
    [anon_sym_register] = ACTIONS(5509),
    [anon_sym_inline] = ACTIONS(5509),
    [anon_sym___inline] = ACTIONS(5509),
    [anon_sym___inline__] = ACTIONS(5509),
    [anon_sym___forceinline] = ACTIONS(5509),
    [anon_sym_thread_local] = ACTIONS(5509),
    [anon_sym___thread] = ACTIONS(5509),
    [anon_sym_const] = ACTIONS(5509),
    [anon_sym_constexpr] = ACTIONS(5509),
    [anon_sym_volatile] = ACTIONS(5509),
    [anon_sym_restrict] = ACTIONS(5509),
    [anon_sym___restrict__] = ACTIONS(5509),
    [anon_sym__Atomic] = ACTIONS(5509),
    [anon_sym__Noreturn] = ACTIONS(5509),
    [anon_sym_noreturn] = ACTIONS(5509),
    [anon_sym__Nonnull] = ACTIONS(5509),
    [anon_sym_mutable] = ACTIONS(5509),
    [anon_sym_constinit] = ACTIONS(5509),
    [anon_sym_consteval] = ACTIONS(5509),
    [anon_sym___shared__] = ACTIONS(5509),
    [anon_sym___local__] = ACTIONS(5509),
    [anon_sym___constant__] = ACTIONS(5509),
    [anon_sym___managed__] = ACTIONS(5509),
    [anon_sym___grid_constant__] = ACTIONS(5509),
    [anon_sym_alignas] = ACTIONS(5509),
    [anon_sym__Alignas] = ACTIONS(5509),
    [sym_primitive_type] = ACTIONS(5509),
    [anon_sym_enum] = ACTIONS(5509),
    [anon_sym_class] = ACTIONS(5509),
    [anon_sym_struct] = ACTIONS(5509),
    [anon_sym_union] = ACTIONS(5509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5509),
    [anon_sym_decltype] = ACTIONS(5509),
    [anon_sym_explicit] = ACTIONS(5509),
    [anon_sym_typename] = ACTIONS(5509),
    [anon_sym_template] = ACTIONS(5509),
    [anon_sym_operator] = ACTIONS(5509),
    [anon_sym_friend] = ACTIONS(5509),
    [anon_sym_public] = ACTIONS(5509),
    [anon_sym_private] = ACTIONS(5509),
    [anon_sym_protected] = ACTIONS(5509),
    [anon_sym_using] = ACTIONS(5509),
    [anon_sym_static_assert] = ACTIONS(5509),
    [anon_sym___launch_bounds__] = ACTIONS(5509),
  },
  [STATE(2103)] = {
    [sym_identifier] = ACTIONS(5573),
    [aux_sym_preproc_def_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token1] = ACTIONS(5573),
    [aux_sym_preproc_if_token2] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5573),
    [sym_preproc_directive] = ACTIONS(5573),
    [anon_sym_LPAREN2] = ACTIONS(5575),
    [anon_sym_TILDE] = ACTIONS(5575),
    [anon_sym_STAR] = ACTIONS(5575),
    [anon_sym_AMP_AMP] = ACTIONS(5575),
    [anon_sym_AMP] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym___extension__] = ACTIONS(5573),
    [anon_sym_typedef] = ACTIONS(5573),
    [anon_sym___device__] = ACTIONS(5573),
    [anon_sym___host__] = ACTIONS(5573),
    [anon_sym___global__] = ACTIONS(5573),
    [anon_sym___forceinline__] = ACTIONS(5573),
    [anon_sym___noinline__] = ACTIONS(5573),
    [anon_sym_virtual] = ACTIONS(5573),
    [anon_sym_extern] = ACTIONS(5573),
    [anon_sym___attribute__] = ACTIONS(5573),
    [anon_sym___attribute] = ACTIONS(5573),
    [anon_sym_COLON_COLON] = ACTIONS(5575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5575),
    [anon_sym___declspec] = ACTIONS(5573),
    [anon_sym___based] = ACTIONS(5573),
    [anon_sym_signed] = ACTIONS(5573),
    [anon_sym_unsigned] = ACTIONS(5573),
    [anon_sym_long] = ACTIONS(5573),
    [anon_sym_short] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5573),
    [anon_sym_static] = ACTIONS(5573),
    [anon_sym_register] = ACTIONS(5573),
    [anon_sym_inline] = ACTIONS(5573),
    [anon_sym___inline] = ACTIONS(5573),
    [anon_sym___inline__] = ACTIONS(5573),
    [anon_sym___forceinline] = ACTIONS(5573),
    [anon_sym_thread_local] = ACTIONS(5573),
    [anon_sym___thread] = ACTIONS(5573),
    [anon_sym_const] = ACTIONS(5573),
    [anon_sym_constexpr] = ACTIONS(5573),
    [anon_sym_volatile] = ACTIONS(5573),
    [anon_sym_restrict] = ACTIONS(5573),
    [anon_sym___restrict__] = ACTIONS(5573),
    [anon_sym__Atomic] = ACTIONS(5573),
    [anon_sym__Noreturn] = ACTIONS(5573),
    [anon_sym_noreturn] = ACTIONS(5573),
    [anon_sym__Nonnull] = ACTIONS(5573),
    [anon_sym_mutable] = ACTIONS(5573),
    [anon_sym_constinit] = ACTIONS(5573),
    [anon_sym_consteval] = ACTIONS(5573),
    [anon_sym___shared__] = ACTIONS(5573),
    [anon_sym___local__] = ACTIONS(5573),
    [anon_sym___constant__] = ACTIONS(5573),
    [anon_sym___managed__] = ACTIONS(5573),
    [anon_sym___grid_constant__] = ACTIONS(5573),
    [anon_sym_alignas] = ACTIONS(5573),
    [anon_sym__Alignas] = ACTIONS(5573),
    [sym_primitive_type] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_class] = ACTIONS(5573),
    [anon_sym_struct] = ACTIONS(5573),
    [anon_sym_union] = ACTIONS(5573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5573),
    [anon_sym_decltype] = ACTIONS(5573),
    [anon_sym_explicit] = ACTIONS(5573),
    [anon_sym_typename] = ACTIONS(5573),
    [anon_sym_template] = ACTIONS(5573),
    [anon_sym_operator] = ACTIONS(5573),
    [anon_sym_friend] = ACTIONS(5573),
    [anon_sym_public] = ACTIONS(5573),
    [anon_sym_private] = ACTIONS(5573),
    [anon_sym_protected] = ACTIONS(5573),
    [anon_sym_using] = ACTIONS(5573),
    [anon_sym_static_assert] = ACTIONS(5573),
    [anon_sym___launch_bounds__] = ACTIONS(5573),
  },
  [STATE(2104)] = {
    [sym_identifier] = ACTIONS(5513),
    [aux_sym_preproc_def_token1] = ACTIONS(5513),
    [aux_sym_preproc_if_token1] = ACTIONS(5513),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5513),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5513),
    [sym_preproc_directive] = ACTIONS(5513),
    [anon_sym_LPAREN2] = ACTIONS(5515),
    [anon_sym_TILDE] = ACTIONS(5515),
    [anon_sym_STAR] = ACTIONS(5515),
    [anon_sym_AMP_AMP] = ACTIONS(5515),
    [anon_sym_AMP] = ACTIONS(5513),
    [anon_sym_SEMI] = ACTIONS(5515),
    [anon_sym___extension__] = ACTIONS(5513),
    [anon_sym_typedef] = ACTIONS(5513),
    [anon_sym___device__] = ACTIONS(5513),
    [anon_sym___host__] = ACTIONS(5513),
    [anon_sym___global__] = ACTIONS(5513),
    [anon_sym___forceinline__] = ACTIONS(5513),
    [anon_sym___noinline__] = ACTIONS(5513),
    [anon_sym_virtual] = ACTIONS(5513),
    [anon_sym_extern] = ACTIONS(5513),
    [anon_sym___attribute__] = ACTIONS(5513),
    [anon_sym___attribute] = ACTIONS(5513),
    [anon_sym_COLON_COLON] = ACTIONS(5515),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5515),
    [anon_sym___declspec] = ACTIONS(5513),
    [anon_sym___based] = ACTIONS(5513),
    [anon_sym_RBRACE] = ACTIONS(5515),
    [anon_sym_signed] = ACTIONS(5513),
    [anon_sym_unsigned] = ACTIONS(5513),
    [anon_sym_long] = ACTIONS(5513),
    [anon_sym_short] = ACTIONS(5513),
    [anon_sym_LBRACK] = ACTIONS(5513),
    [anon_sym_static] = ACTIONS(5513),
    [anon_sym_register] = ACTIONS(5513),
    [anon_sym_inline] = ACTIONS(5513),
    [anon_sym___inline] = ACTIONS(5513),
    [anon_sym___inline__] = ACTIONS(5513),
    [anon_sym___forceinline] = ACTIONS(5513),
    [anon_sym_thread_local] = ACTIONS(5513),
    [anon_sym___thread] = ACTIONS(5513),
    [anon_sym_const] = ACTIONS(5513),
    [anon_sym_constexpr] = ACTIONS(5513),
    [anon_sym_volatile] = ACTIONS(5513),
    [anon_sym_restrict] = ACTIONS(5513),
    [anon_sym___restrict__] = ACTIONS(5513),
    [anon_sym__Atomic] = ACTIONS(5513),
    [anon_sym__Noreturn] = ACTIONS(5513),
    [anon_sym_noreturn] = ACTIONS(5513),
    [anon_sym__Nonnull] = ACTIONS(5513),
    [anon_sym_mutable] = ACTIONS(5513),
    [anon_sym_constinit] = ACTIONS(5513),
    [anon_sym_consteval] = ACTIONS(5513),
    [anon_sym___shared__] = ACTIONS(5513),
    [anon_sym___local__] = ACTIONS(5513),
    [anon_sym___constant__] = ACTIONS(5513),
    [anon_sym___managed__] = ACTIONS(5513),
    [anon_sym___grid_constant__] = ACTIONS(5513),
    [anon_sym_alignas] = ACTIONS(5513),
    [anon_sym__Alignas] = ACTIONS(5513),
    [sym_primitive_type] = ACTIONS(5513),
    [anon_sym_enum] = ACTIONS(5513),
    [anon_sym_class] = ACTIONS(5513),
    [anon_sym_struct] = ACTIONS(5513),
    [anon_sym_union] = ACTIONS(5513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5513),
    [anon_sym_decltype] = ACTIONS(5513),
    [anon_sym_explicit] = ACTIONS(5513),
    [anon_sym_typename] = ACTIONS(5513),
    [anon_sym_template] = ACTIONS(5513),
    [anon_sym_operator] = ACTIONS(5513),
    [anon_sym_friend] = ACTIONS(5513),
    [anon_sym_public] = ACTIONS(5513),
    [anon_sym_private] = ACTIONS(5513),
    [anon_sym_protected] = ACTIONS(5513),
    [anon_sym_using] = ACTIONS(5513),
    [anon_sym_static_assert] = ACTIONS(5513),
    [anon_sym___launch_bounds__] = ACTIONS(5513),
  },
  [STATE(2105)] = {
    [sym_identifier] = ACTIONS(5557),
    [aux_sym_preproc_def_token1] = ACTIONS(5557),
    [aux_sym_preproc_if_token1] = ACTIONS(5557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5557),
    [sym_preproc_directive] = ACTIONS(5557),
    [anon_sym_LPAREN2] = ACTIONS(5559),
    [anon_sym_TILDE] = ACTIONS(5559),
    [anon_sym_STAR] = ACTIONS(5559),
    [anon_sym_AMP_AMP] = ACTIONS(5559),
    [anon_sym_AMP] = ACTIONS(5557),
    [anon_sym_SEMI] = ACTIONS(5559),
    [anon_sym___extension__] = ACTIONS(5557),
    [anon_sym_typedef] = ACTIONS(5557),
    [anon_sym___device__] = ACTIONS(5557),
    [anon_sym___host__] = ACTIONS(5557),
    [anon_sym___global__] = ACTIONS(5557),
    [anon_sym___forceinline__] = ACTIONS(5557),
    [anon_sym___noinline__] = ACTIONS(5557),
    [anon_sym_virtual] = ACTIONS(5557),
    [anon_sym_extern] = ACTIONS(5557),
    [anon_sym___attribute__] = ACTIONS(5557),
    [anon_sym___attribute] = ACTIONS(5557),
    [anon_sym_COLON_COLON] = ACTIONS(5559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5559),
    [anon_sym___declspec] = ACTIONS(5557),
    [anon_sym___based] = ACTIONS(5557),
    [anon_sym_RBRACE] = ACTIONS(5559),
    [anon_sym_signed] = ACTIONS(5557),
    [anon_sym_unsigned] = ACTIONS(5557),
    [anon_sym_long] = ACTIONS(5557),
    [anon_sym_short] = ACTIONS(5557),
    [anon_sym_LBRACK] = ACTIONS(5557),
    [anon_sym_static] = ACTIONS(5557),
    [anon_sym_register] = ACTIONS(5557),
    [anon_sym_inline] = ACTIONS(5557),
    [anon_sym___inline] = ACTIONS(5557),
    [anon_sym___inline__] = ACTIONS(5557),
    [anon_sym___forceinline] = ACTIONS(5557),
    [anon_sym_thread_local] = ACTIONS(5557),
    [anon_sym___thread] = ACTIONS(5557),
    [anon_sym_const] = ACTIONS(5557),
    [anon_sym_constexpr] = ACTIONS(5557),
    [anon_sym_volatile] = ACTIONS(5557),
    [anon_sym_restrict] = ACTIONS(5557),
    [anon_sym___restrict__] = ACTIONS(5557),
    [anon_sym__Atomic] = ACTIONS(5557),
    [anon_sym__Noreturn] = ACTIONS(5557),
    [anon_sym_noreturn] = ACTIONS(5557),
    [anon_sym__Nonnull] = ACTIONS(5557),
    [anon_sym_mutable] = ACTIONS(5557),
    [anon_sym_constinit] = ACTIONS(5557),
    [anon_sym_consteval] = ACTIONS(5557),
    [anon_sym___shared__] = ACTIONS(5557),
    [anon_sym___local__] = ACTIONS(5557),
    [anon_sym___constant__] = ACTIONS(5557),
    [anon_sym___managed__] = ACTIONS(5557),
    [anon_sym___grid_constant__] = ACTIONS(5557),
    [anon_sym_alignas] = ACTIONS(5557),
    [anon_sym__Alignas] = ACTIONS(5557),
    [sym_primitive_type] = ACTIONS(5557),
    [anon_sym_enum] = ACTIONS(5557),
    [anon_sym_class] = ACTIONS(5557),
    [anon_sym_struct] = ACTIONS(5557),
    [anon_sym_union] = ACTIONS(5557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5557),
    [anon_sym_decltype] = ACTIONS(5557),
    [anon_sym_explicit] = ACTIONS(5557),
    [anon_sym_typename] = ACTIONS(5557),
    [anon_sym_template] = ACTIONS(5557),
    [anon_sym_operator] = ACTIONS(5557),
    [anon_sym_friend] = ACTIONS(5557),
    [anon_sym_public] = ACTIONS(5557),
    [anon_sym_private] = ACTIONS(5557),
    [anon_sym_protected] = ACTIONS(5557),
    [anon_sym_using] = ACTIONS(5557),
    [anon_sym_static_assert] = ACTIONS(5557),
    [anon_sym___launch_bounds__] = ACTIONS(5557),
  },
  [STATE(2106)] = {
    [sym_identifier] = ACTIONS(2497),
    [aux_sym_preproc_def_token1] = ACTIONS(2497),
    [aux_sym_preproc_if_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2497),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2497),
    [sym_preproc_directive] = ACTIONS(2497),
    [anon_sym_LPAREN2] = ACTIONS(2499),
    [anon_sym_TILDE] = ACTIONS(2499),
    [anon_sym_STAR] = ACTIONS(2499),
    [anon_sym_AMP_AMP] = ACTIONS(2499),
    [anon_sym_AMP] = ACTIONS(2497),
    [anon_sym_SEMI] = ACTIONS(2499),
    [anon_sym___extension__] = ACTIONS(2497),
    [anon_sym_typedef] = ACTIONS(2497),
    [anon_sym___device__] = ACTIONS(2497),
    [anon_sym___host__] = ACTIONS(2497),
    [anon_sym___global__] = ACTIONS(2497),
    [anon_sym___forceinline__] = ACTIONS(2497),
    [anon_sym___noinline__] = ACTIONS(2497),
    [anon_sym_virtual] = ACTIONS(2497),
    [anon_sym_extern] = ACTIONS(2497),
    [anon_sym___attribute__] = ACTIONS(2497),
    [anon_sym___attribute] = ACTIONS(2497),
    [anon_sym_COLON_COLON] = ACTIONS(2499),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2499),
    [anon_sym___declspec] = ACTIONS(2497),
    [anon_sym___based] = ACTIONS(2497),
    [anon_sym_RBRACE] = ACTIONS(2499),
    [anon_sym_signed] = ACTIONS(2497),
    [anon_sym_unsigned] = ACTIONS(2497),
    [anon_sym_long] = ACTIONS(2497),
    [anon_sym_short] = ACTIONS(2497),
    [anon_sym_LBRACK] = ACTIONS(2497),
    [anon_sym_static] = ACTIONS(2497),
    [anon_sym_register] = ACTIONS(2497),
    [anon_sym_inline] = ACTIONS(2497),
    [anon_sym___inline] = ACTIONS(2497),
    [anon_sym___inline__] = ACTIONS(2497),
    [anon_sym___forceinline] = ACTIONS(2497),
    [anon_sym_thread_local] = ACTIONS(2497),
    [anon_sym___thread] = ACTIONS(2497),
    [anon_sym_const] = ACTIONS(2497),
    [anon_sym_constexpr] = ACTIONS(2497),
    [anon_sym_volatile] = ACTIONS(2497),
    [anon_sym_restrict] = ACTIONS(2497),
    [anon_sym___restrict__] = ACTIONS(2497),
    [anon_sym__Atomic] = ACTIONS(2497),
    [anon_sym__Noreturn] = ACTIONS(2497),
    [anon_sym_noreturn] = ACTIONS(2497),
    [anon_sym__Nonnull] = ACTIONS(2497),
    [anon_sym_mutable] = ACTIONS(2497),
    [anon_sym_constinit] = ACTIONS(2497),
    [anon_sym_consteval] = ACTIONS(2497),
    [anon_sym___shared__] = ACTIONS(2497),
    [anon_sym___local__] = ACTIONS(2497),
    [anon_sym___constant__] = ACTIONS(2497),
    [anon_sym___managed__] = ACTIONS(2497),
    [anon_sym___grid_constant__] = ACTIONS(2497),
    [anon_sym_alignas] = ACTIONS(2497),
    [anon_sym__Alignas] = ACTIONS(2497),
    [sym_primitive_type] = ACTIONS(2497),
    [anon_sym_enum] = ACTIONS(2497),
    [anon_sym_class] = ACTIONS(2497),
    [anon_sym_struct] = ACTIONS(2497),
    [anon_sym_union] = ACTIONS(2497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2497),
    [anon_sym_decltype] = ACTIONS(2497),
    [anon_sym_explicit] = ACTIONS(2497),
    [anon_sym_typename] = ACTIONS(2497),
    [anon_sym_template] = ACTIONS(2497),
    [anon_sym_operator] = ACTIONS(2497),
    [anon_sym_friend] = ACTIONS(2497),
    [anon_sym_public] = ACTIONS(2497),
    [anon_sym_private] = ACTIONS(2497),
    [anon_sym_protected] = ACTIONS(2497),
    [anon_sym_using] = ACTIONS(2497),
    [anon_sym_static_assert] = ACTIONS(2497),
    [anon_sym___launch_bounds__] = ACTIONS(2497),
  },
  [STATE(2107)] = {
    [sym_identifier] = ACTIONS(2339),
    [aux_sym_preproc_def_token1] = ACTIONS(2339),
    [aux_sym_preproc_if_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2339),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2339),
    [sym_preproc_directive] = ACTIONS(2339),
    [anon_sym_LPAREN2] = ACTIONS(2341),
    [anon_sym_TILDE] = ACTIONS(2341),
    [anon_sym_STAR] = ACTIONS(2341),
    [anon_sym_AMP_AMP] = ACTIONS(2341),
    [anon_sym_AMP] = ACTIONS(2339),
    [anon_sym_SEMI] = ACTIONS(2341),
    [anon_sym___extension__] = ACTIONS(2339),
    [anon_sym_typedef] = ACTIONS(2339),
    [anon_sym___device__] = ACTIONS(2339),
    [anon_sym___host__] = ACTIONS(2339),
    [anon_sym___global__] = ACTIONS(2339),
    [anon_sym___forceinline__] = ACTIONS(2339),
    [anon_sym___noinline__] = ACTIONS(2339),
    [anon_sym_virtual] = ACTIONS(2339),
    [anon_sym_extern] = ACTIONS(2339),
    [anon_sym___attribute__] = ACTIONS(2339),
    [anon_sym___attribute] = ACTIONS(2339),
    [anon_sym_COLON_COLON] = ACTIONS(2341),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2341),
    [anon_sym___declspec] = ACTIONS(2339),
    [anon_sym___based] = ACTIONS(2339),
    [anon_sym_RBRACE] = ACTIONS(2341),
    [anon_sym_signed] = ACTIONS(2339),
    [anon_sym_unsigned] = ACTIONS(2339),
    [anon_sym_long] = ACTIONS(2339),
    [anon_sym_short] = ACTIONS(2339),
    [anon_sym_LBRACK] = ACTIONS(2339),
    [anon_sym_static] = ACTIONS(2339),
    [anon_sym_register] = ACTIONS(2339),
    [anon_sym_inline] = ACTIONS(2339),
    [anon_sym___inline] = ACTIONS(2339),
    [anon_sym___inline__] = ACTIONS(2339),
    [anon_sym___forceinline] = ACTIONS(2339),
    [anon_sym_thread_local] = ACTIONS(2339),
    [anon_sym___thread] = ACTIONS(2339),
    [anon_sym_const] = ACTIONS(2339),
    [anon_sym_constexpr] = ACTIONS(2339),
    [anon_sym_volatile] = ACTIONS(2339),
    [anon_sym_restrict] = ACTIONS(2339),
    [anon_sym___restrict__] = ACTIONS(2339),
    [anon_sym__Atomic] = ACTIONS(2339),
    [anon_sym__Noreturn] = ACTIONS(2339),
    [anon_sym_noreturn] = ACTIONS(2339),
    [anon_sym__Nonnull] = ACTIONS(2339),
    [anon_sym_mutable] = ACTIONS(2339),
    [anon_sym_constinit] = ACTIONS(2339),
    [anon_sym_consteval] = ACTIONS(2339),
    [anon_sym___shared__] = ACTIONS(2339),
    [anon_sym___local__] = ACTIONS(2339),
    [anon_sym___constant__] = ACTIONS(2339),
    [anon_sym___managed__] = ACTIONS(2339),
    [anon_sym___grid_constant__] = ACTIONS(2339),
    [anon_sym_alignas] = ACTIONS(2339),
    [anon_sym__Alignas] = ACTIONS(2339),
    [sym_primitive_type] = ACTIONS(2339),
    [anon_sym_enum] = ACTIONS(2339),
    [anon_sym_class] = ACTIONS(2339),
    [anon_sym_struct] = ACTIONS(2339),
    [anon_sym_union] = ACTIONS(2339),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2339),
    [anon_sym_decltype] = ACTIONS(2339),
    [anon_sym_explicit] = ACTIONS(2339),
    [anon_sym_typename] = ACTIONS(2339),
    [anon_sym_template] = ACTIONS(2339),
    [anon_sym_operator] = ACTIONS(2339),
    [anon_sym_friend] = ACTIONS(2339),
    [anon_sym_public] = ACTIONS(2339),
    [anon_sym_private] = ACTIONS(2339),
    [anon_sym_protected] = ACTIONS(2339),
    [anon_sym_using] = ACTIONS(2339),
    [anon_sym_static_assert] = ACTIONS(2339),
    [anon_sym___launch_bounds__] = ACTIONS(2339),
  },
  [STATE(2108)] = {
    [sym_identifier] = ACTIONS(2343),
    [aux_sym_preproc_def_token1] = ACTIONS(2343),
    [aux_sym_preproc_if_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2343),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2343),
    [sym_preproc_directive] = ACTIONS(2343),
    [anon_sym_LPAREN2] = ACTIONS(2345),
    [anon_sym_TILDE] = ACTIONS(2345),
    [anon_sym_STAR] = ACTIONS(2345),
    [anon_sym_AMP_AMP] = ACTIONS(2345),
    [anon_sym_AMP] = ACTIONS(2343),
    [anon_sym_SEMI] = ACTIONS(2345),
    [anon_sym___extension__] = ACTIONS(2343),
    [anon_sym_typedef] = ACTIONS(2343),
    [anon_sym___device__] = ACTIONS(2343),
    [anon_sym___host__] = ACTIONS(2343),
    [anon_sym___global__] = ACTIONS(2343),
    [anon_sym___forceinline__] = ACTIONS(2343),
    [anon_sym___noinline__] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2343),
    [anon_sym_extern] = ACTIONS(2343),
    [anon_sym___attribute__] = ACTIONS(2343),
    [anon_sym___attribute] = ACTIONS(2343),
    [anon_sym_COLON_COLON] = ACTIONS(2345),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2345),
    [anon_sym___declspec] = ACTIONS(2343),
    [anon_sym___based] = ACTIONS(2343),
    [anon_sym_RBRACE] = ACTIONS(2345),
    [anon_sym_signed] = ACTIONS(2343),
    [anon_sym_unsigned] = ACTIONS(2343),
    [anon_sym_long] = ACTIONS(2343),
    [anon_sym_short] = ACTIONS(2343),
    [anon_sym_LBRACK] = ACTIONS(2343),
    [anon_sym_static] = ACTIONS(2343),
    [anon_sym_register] = ACTIONS(2343),
    [anon_sym_inline] = ACTIONS(2343),
    [anon_sym___inline] = ACTIONS(2343),
    [anon_sym___inline__] = ACTIONS(2343),
    [anon_sym___forceinline] = ACTIONS(2343),
    [anon_sym_thread_local] = ACTIONS(2343),
    [anon_sym___thread] = ACTIONS(2343),
    [anon_sym_const] = ACTIONS(2343),
    [anon_sym_constexpr] = ACTIONS(2343),
    [anon_sym_volatile] = ACTIONS(2343),
    [anon_sym_restrict] = ACTIONS(2343),
    [anon_sym___restrict__] = ACTIONS(2343),
    [anon_sym__Atomic] = ACTIONS(2343),
    [anon_sym__Noreturn] = ACTIONS(2343),
    [anon_sym_noreturn] = ACTIONS(2343),
    [anon_sym__Nonnull] = ACTIONS(2343),
    [anon_sym_mutable] = ACTIONS(2343),
    [anon_sym_constinit] = ACTIONS(2343),
    [anon_sym_consteval] = ACTIONS(2343),
    [anon_sym___shared__] = ACTIONS(2343),
    [anon_sym___local__] = ACTIONS(2343),
    [anon_sym___constant__] = ACTIONS(2343),
    [anon_sym___managed__] = ACTIONS(2343),
    [anon_sym___grid_constant__] = ACTIONS(2343),
    [anon_sym_alignas] = ACTIONS(2343),
    [anon_sym__Alignas] = ACTIONS(2343),
    [sym_primitive_type] = ACTIONS(2343),
    [anon_sym_enum] = ACTIONS(2343),
    [anon_sym_class] = ACTIONS(2343),
    [anon_sym_struct] = ACTIONS(2343),
    [anon_sym_union] = ACTIONS(2343),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2343),
    [anon_sym_decltype] = ACTIONS(2343),
    [anon_sym_explicit] = ACTIONS(2343),
    [anon_sym_typename] = ACTIONS(2343),
    [anon_sym_template] = ACTIONS(2343),
    [anon_sym_operator] = ACTIONS(2343),
    [anon_sym_friend] = ACTIONS(2343),
    [anon_sym_public] = ACTIONS(2343),
    [anon_sym_private] = ACTIONS(2343),
    [anon_sym_protected] = ACTIONS(2343),
    [anon_sym_using] = ACTIONS(2343),
    [anon_sym_static_assert] = ACTIONS(2343),
    [anon_sym___launch_bounds__] = ACTIONS(2343),
  },
  [STATE(2109)] = {
    [sym_identifier] = ACTIONS(2347),
    [aux_sym_preproc_def_token1] = ACTIONS(2347),
    [aux_sym_preproc_if_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2347),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2347),
    [sym_preproc_directive] = ACTIONS(2347),
    [anon_sym_LPAREN2] = ACTIONS(2349),
    [anon_sym_TILDE] = ACTIONS(2349),
    [anon_sym_STAR] = ACTIONS(2349),
    [anon_sym_AMP_AMP] = ACTIONS(2349),
    [anon_sym_AMP] = ACTIONS(2347),
    [anon_sym_SEMI] = ACTIONS(2349),
    [anon_sym___extension__] = ACTIONS(2347),
    [anon_sym_typedef] = ACTIONS(2347),
    [anon_sym___device__] = ACTIONS(2347),
    [anon_sym___host__] = ACTIONS(2347),
    [anon_sym___global__] = ACTIONS(2347),
    [anon_sym___forceinline__] = ACTIONS(2347),
    [anon_sym___noinline__] = ACTIONS(2347),
    [anon_sym_virtual] = ACTIONS(2347),
    [anon_sym_extern] = ACTIONS(2347),
    [anon_sym___attribute__] = ACTIONS(2347),
    [anon_sym___attribute] = ACTIONS(2347),
    [anon_sym_COLON_COLON] = ACTIONS(2349),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2349),
    [anon_sym___declspec] = ACTIONS(2347),
    [anon_sym___based] = ACTIONS(2347),
    [anon_sym_RBRACE] = ACTIONS(2349),
    [anon_sym_signed] = ACTIONS(2347),
    [anon_sym_unsigned] = ACTIONS(2347),
    [anon_sym_long] = ACTIONS(2347),
    [anon_sym_short] = ACTIONS(2347),
    [anon_sym_LBRACK] = ACTIONS(2347),
    [anon_sym_static] = ACTIONS(2347),
    [anon_sym_register] = ACTIONS(2347),
    [anon_sym_inline] = ACTIONS(2347),
    [anon_sym___inline] = ACTIONS(2347),
    [anon_sym___inline__] = ACTIONS(2347),
    [anon_sym___forceinline] = ACTIONS(2347),
    [anon_sym_thread_local] = ACTIONS(2347),
    [anon_sym___thread] = ACTIONS(2347),
    [anon_sym_const] = ACTIONS(2347),
    [anon_sym_constexpr] = ACTIONS(2347),
    [anon_sym_volatile] = ACTIONS(2347),
    [anon_sym_restrict] = ACTIONS(2347),
    [anon_sym___restrict__] = ACTIONS(2347),
    [anon_sym__Atomic] = ACTIONS(2347),
    [anon_sym__Noreturn] = ACTIONS(2347),
    [anon_sym_noreturn] = ACTIONS(2347),
    [anon_sym__Nonnull] = ACTIONS(2347),
    [anon_sym_mutable] = ACTIONS(2347),
    [anon_sym_constinit] = ACTIONS(2347),
    [anon_sym_consteval] = ACTIONS(2347),
    [anon_sym___shared__] = ACTIONS(2347),
    [anon_sym___local__] = ACTIONS(2347),
    [anon_sym___constant__] = ACTIONS(2347),
    [anon_sym___managed__] = ACTIONS(2347),
    [anon_sym___grid_constant__] = ACTIONS(2347),
    [anon_sym_alignas] = ACTIONS(2347),
    [anon_sym__Alignas] = ACTIONS(2347),
    [sym_primitive_type] = ACTIONS(2347),
    [anon_sym_enum] = ACTIONS(2347),
    [anon_sym_class] = ACTIONS(2347),
    [anon_sym_struct] = ACTIONS(2347),
    [anon_sym_union] = ACTIONS(2347),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2347),
    [anon_sym_decltype] = ACTIONS(2347),
    [anon_sym_explicit] = ACTIONS(2347),
    [anon_sym_typename] = ACTIONS(2347),
    [anon_sym_template] = ACTIONS(2347),
    [anon_sym_operator] = ACTIONS(2347),
    [anon_sym_friend] = ACTIONS(2347),
    [anon_sym_public] = ACTIONS(2347),
    [anon_sym_private] = ACTIONS(2347),
    [anon_sym_protected] = ACTIONS(2347),
    [anon_sym_using] = ACTIONS(2347),
    [anon_sym_static_assert] = ACTIONS(2347),
    [anon_sym___launch_bounds__] = ACTIONS(2347),
  },
  [STATE(2110)] = {
    [sym_identifier] = ACTIONS(2218),
    [aux_sym_preproc_def_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token1] = ACTIONS(2218),
    [aux_sym_preproc_if_token2] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2218),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2218),
    [sym_preproc_directive] = ACTIONS(2218),
    [anon_sym_LPAREN2] = ACTIONS(2220),
    [anon_sym_TILDE] = ACTIONS(2220),
    [anon_sym_STAR] = ACTIONS(2220),
    [anon_sym_AMP_AMP] = ACTIONS(2220),
    [anon_sym_AMP] = ACTIONS(2218),
    [anon_sym_SEMI] = ACTIONS(2220),
    [anon_sym___extension__] = ACTIONS(2218),
    [anon_sym_typedef] = ACTIONS(2218),
    [anon_sym___device__] = ACTIONS(2218),
    [anon_sym___host__] = ACTIONS(2218),
    [anon_sym___global__] = ACTIONS(2218),
    [anon_sym___forceinline__] = ACTIONS(2218),
    [anon_sym___noinline__] = ACTIONS(2218),
    [anon_sym_virtual] = ACTIONS(2218),
    [anon_sym_extern] = ACTIONS(2218),
    [anon_sym___attribute__] = ACTIONS(2218),
    [anon_sym___attribute] = ACTIONS(2218),
    [anon_sym_COLON_COLON] = ACTIONS(2220),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2220),
    [anon_sym___declspec] = ACTIONS(2218),
    [anon_sym___based] = ACTIONS(2218),
    [anon_sym_signed] = ACTIONS(2218),
    [anon_sym_unsigned] = ACTIONS(2218),
    [anon_sym_long] = ACTIONS(2218),
    [anon_sym_short] = ACTIONS(2218),
    [anon_sym_LBRACK] = ACTIONS(2218),
    [anon_sym_static] = ACTIONS(2218),
    [anon_sym_register] = ACTIONS(2218),
    [anon_sym_inline] = ACTIONS(2218),
    [anon_sym___inline] = ACTIONS(2218),
    [anon_sym___inline__] = ACTIONS(2218),
    [anon_sym___forceinline] = ACTIONS(2218),
    [anon_sym_thread_local] = ACTIONS(2218),
    [anon_sym___thread] = ACTIONS(2218),
    [anon_sym_const] = ACTIONS(2218),
    [anon_sym_constexpr] = ACTIONS(2218),
    [anon_sym_volatile] = ACTIONS(2218),
    [anon_sym_restrict] = ACTIONS(2218),
    [anon_sym___restrict__] = ACTIONS(2218),
    [anon_sym__Atomic] = ACTIONS(2218),
    [anon_sym__Noreturn] = ACTIONS(2218),
    [anon_sym_noreturn] = ACTIONS(2218),
    [anon_sym__Nonnull] = ACTIONS(2218),
    [anon_sym_mutable] = ACTIONS(2218),
    [anon_sym_constinit] = ACTIONS(2218),
    [anon_sym_consteval] = ACTIONS(2218),
    [anon_sym___shared__] = ACTIONS(2218),
    [anon_sym___local__] = ACTIONS(2218),
    [anon_sym___constant__] = ACTIONS(2218),
    [anon_sym___managed__] = ACTIONS(2218),
    [anon_sym___grid_constant__] = ACTIONS(2218),
    [anon_sym_alignas] = ACTIONS(2218),
    [anon_sym__Alignas] = ACTIONS(2218),
    [sym_primitive_type] = ACTIONS(2218),
    [anon_sym_enum] = ACTIONS(2218),
    [anon_sym_class] = ACTIONS(2218),
    [anon_sym_struct] = ACTIONS(2218),
    [anon_sym_union] = ACTIONS(2218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2218),
    [anon_sym_decltype] = ACTIONS(2218),
    [anon_sym_explicit] = ACTIONS(2218),
    [anon_sym_typename] = ACTIONS(2218),
    [anon_sym_template] = ACTIONS(2218),
    [anon_sym_operator] = ACTIONS(2218),
    [anon_sym_friend] = ACTIONS(2218),
    [anon_sym_public] = ACTIONS(2218),
    [anon_sym_private] = ACTIONS(2218),
    [anon_sym_protected] = ACTIONS(2218),
    [anon_sym_using] = ACTIONS(2218),
    [anon_sym_static_assert] = ACTIONS(2218),
    [anon_sym___launch_bounds__] = ACTIONS(2218),
  },
  [STATE(2111)] = {
    [sym_identifier] = ACTIONS(2044),
    [aux_sym_preproc_def_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token1] = ACTIONS(2044),
    [aux_sym_preproc_if_token2] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2044),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2044),
    [sym_preproc_directive] = ACTIONS(2044),
    [anon_sym_LPAREN2] = ACTIONS(2046),
    [anon_sym_TILDE] = ACTIONS(2046),
    [anon_sym_STAR] = ACTIONS(2046),
    [anon_sym_AMP_AMP] = ACTIONS(2046),
    [anon_sym_AMP] = ACTIONS(2044),
    [anon_sym_SEMI] = ACTIONS(2046),
    [anon_sym___extension__] = ACTIONS(2044),
    [anon_sym_typedef] = ACTIONS(2044),
    [anon_sym___device__] = ACTIONS(2044),
    [anon_sym___host__] = ACTIONS(2044),
    [anon_sym___global__] = ACTIONS(2044),
    [anon_sym___forceinline__] = ACTIONS(2044),
    [anon_sym___noinline__] = ACTIONS(2044),
    [anon_sym_virtual] = ACTIONS(2044),
    [anon_sym_extern] = ACTIONS(2044),
    [anon_sym___attribute__] = ACTIONS(2044),
    [anon_sym___attribute] = ACTIONS(2044),
    [anon_sym_COLON_COLON] = ACTIONS(2046),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2046),
    [anon_sym___declspec] = ACTIONS(2044),
    [anon_sym___based] = ACTIONS(2044),
    [anon_sym_signed] = ACTIONS(2044),
    [anon_sym_unsigned] = ACTIONS(2044),
    [anon_sym_long] = ACTIONS(2044),
    [anon_sym_short] = ACTIONS(2044),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_static] = ACTIONS(2044),
    [anon_sym_register] = ACTIONS(2044),
    [anon_sym_inline] = ACTIONS(2044),
    [anon_sym___inline] = ACTIONS(2044),
    [anon_sym___inline__] = ACTIONS(2044),
    [anon_sym___forceinline] = ACTIONS(2044),
    [anon_sym_thread_local] = ACTIONS(2044),
    [anon_sym___thread] = ACTIONS(2044),
    [anon_sym_const] = ACTIONS(2044),
    [anon_sym_constexpr] = ACTIONS(2044),
    [anon_sym_volatile] = ACTIONS(2044),
    [anon_sym_restrict] = ACTIONS(2044),
    [anon_sym___restrict__] = ACTIONS(2044),
    [anon_sym__Atomic] = ACTIONS(2044),
    [anon_sym__Noreturn] = ACTIONS(2044),
    [anon_sym_noreturn] = ACTIONS(2044),
    [anon_sym__Nonnull] = ACTIONS(2044),
    [anon_sym_mutable] = ACTIONS(2044),
    [anon_sym_constinit] = ACTIONS(2044),
    [anon_sym_consteval] = ACTIONS(2044),
    [anon_sym___shared__] = ACTIONS(2044),
    [anon_sym___local__] = ACTIONS(2044),
    [anon_sym___constant__] = ACTIONS(2044),
    [anon_sym___managed__] = ACTIONS(2044),
    [anon_sym___grid_constant__] = ACTIONS(2044),
    [anon_sym_alignas] = ACTIONS(2044),
    [anon_sym__Alignas] = ACTIONS(2044),
    [sym_primitive_type] = ACTIONS(2044),
    [anon_sym_enum] = ACTIONS(2044),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2044),
    [anon_sym_union] = ACTIONS(2044),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2044),
    [anon_sym_decltype] = ACTIONS(2044),
    [anon_sym_explicit] = ACTIONS(2044),
    [anon_sym_typename] = ACTIONS(2044),
    [anon_sym_template] = ACTIONS(2044),
    [anon_sym_operator] = ACTIONS(2044),
    [anon_sym_friend] = ACTIONS(2044),
    [anon_sym_public] = ACTIONS(2044),
    [anon_sym_private] = ACTIONS(2044),
    [anon_sym_protected] = ACTIONS(2044),
    [anon_sym_using] = ACTIONS(2044),
    [anon_sym_static_assert] = ACTIONS(2044),
    [anon_sym___launch_bounds__] = ACTIONS(2044),
  },
  [STATE(2112)] = {
    [sym_identifier] = ACTIONS(2351),
    [aux_sym_preproc_def_token1] = ACTIONS(2351),
    [aux_sym_preproc_if_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2351),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2351),
    [sym_preproc_directive] = ACTIONS(2351),
    [anon_sym_LPAREN2] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(2353),
    [anon_sym_STAR] = ACTIONS(2353),
    [anon_sym_AMP_AMP] = ACTIONS(2353),
    [anon_sym_AMP] = ACTIONS(2351),
    [anon_sym_SEMI] = ACTIONS(2353),
    [anon_sym___extension__] = ACTIONS(2351),
    [anon_sym_typedef] = ACTIONS(2351),
    [anon_sym___device__] = ACTIONS(2351),
    [anon_sym___host__] = ACTIONS(2351),
    [anon_sym___global__] = ACTIONS(2351),
    [anon_sym___forceinline__] = ACTIONS(2351),
    [anon_sym___noinline__] = ACTIONS(2351),
    [anon_sym_virtual] = ACTIONS(2351),
    [anon_sym_extern] = ACTIONS(2351),
    [anon_sym___attribute__] = ACTIONS(2351),
    [anon_sym___attribute] = ACTIONS(2351),
    [anon_sym_COLON_COLON] = ACTIONS(2353),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2353),
    [anon_sym___declspec] = ACTIONS(2351),
    [anon_sym___based] = ACTIONS(2351),
    [anon_sym_RBRACE] = ACTIONS(2353),
    [anon_sym_signed] = ACTIONS(2351),
    [anon_sym_unsigned] = ACTIONS(2351),
    [anon_sym_long] = ACTIONS(2351),
    [anon_sym_short] = ACTIONS(2351),
    [anon_sym_LBRACK] = ACTIONS(2351),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_register] = ACTIONS(2351),
    [anon_sym_inline] = ACTIONS(2351),
    [anon_sym___inline] = ACTIONS(2351),
    [anon_sym___inline__] = ACTIONS(2351),
    [anon_sym___forceinline] = ACTIONS(2351),
    [anon_sym_thread_local] = ACTIONS(2351),
    [anon_sym___thread] = ACTIONS(2351),
    [anon_sym_const] = ACTIONS(2351),
    [anon_sym_constexpr] = ACTIONS(2351),
    [anon_sym_volatile] = ACTIONS(2351),
    [anon_sym_restrict] = ACTIONS(2351),
    [anon_sym___restrict__] = ACTIONS(2351),
    [anon_sym__Atomic] = ACTIONS(2351),
    [anon_sym__Noreturn] = ACTIONS(2351),
    [anon_sym_noreturn] = ACTIONS(2351),
    [anon_sym__Nonnull] = ACTIONS(2351),
    [anon_sym_mutable] = ACTIONS(2351),
    [anon_sym_constinit] = ACTIONS(2351),
    [anon_sym_consteval] = ACTIONS(2351),
    [anon_sym___shared__] = ACTIONS(2351),
    [anon_sym___local__] = ACTIONS(2351),
    [anon_sym___constant__] = ACTIONS(2351),
    [anon_sym___managed__] = ACTIONS(2351),
    [anon_sym___grid_constant__] = ACTIONS(2351),
    [anon_sym_alignas] = ACTIONS(2351),
    [anon_sym__Alignas] = ACTIONS(2351),
    [sym_primitive_type] = ACTIONS(2351),
    [anon_sym_enum] = ACTIONS(2351),
    [anon_sym_class] = ACTIONS(2351),
    [anon_sym_struct] = ACTIONS(2351),
    [anon_sym_union] = ACTIONS(2351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2351),
    [anon_sym_decltype] = ACTIONS(2351),
    [anon_sym_explicit] = ACTIONS(2351),
    [anon_sym_typename] = ACTIONS(2351),
    [anon_sym_template] = ACTIONS(2351),
    [anon_sym_operator] = ACTIONS(2351),
    [anon_sym_friend] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_using] = ACTIONS(2351),
    [anon_sym_static_assert] = ACTIONS(2351),
    [anon_sym___launch_bounds__] = ACTIONS(2351),
  },
  [STATE(2113)] = {
    [sym_identifier] = ACTIONS(2435),
    [aux_sym_preproc_def_token1] = ACTIONS(2435),
    [aux_sym_preproc_if_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2435),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2435),
    [sym_preproc_directive] = ACTIONS(2435),
    [anon_sym_LPAREN2] = ACTIONS(2437),
    [anon_sym_TILDE] = ACTIONS(2437),
    [anon_sym_STAR] = ACTIONS(2437),
    [anon_sym_AMP_AMP] = ACTIONS(2437),
    [anon_sym_AMP] = ACTIONS(2435),
    [anon_sym_SEMI] = ACTIONS(2437),
    [anon_sym___extension__] = ACTIONS(2435),
    [anon_sym_typedef] = ACTIONS(2435),
    [anon_sym___device__] = ACTIONS(2435),
    [anon_sym___host__] = ACTIONS(2435),
    [anon_sym___global__] = ACTIONS(2435),
    [anon_sym___forceinline__] = ACTIONS(2435),
    [anon_sym___noinline__] = ACTIONS(2435),
    [anon_sym_virtual] = ACTIONS(2435),
    [anon_sym_extern] = ACTIONS(2435),
    [anon_sym___attribute__] = ACTIONS(2435),
    [anon_sym___attribute] = ACTIONS(2435),
    [anon_sym_COLON_COLON] = ACTIONS(2437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2437),
    [anon_sym___declspec] = ACTIONS(2435),
    [anon_sym___based] = ACTIONS(2435),
    [anon_sym_RBRACE] = ACTIONS(2437),
    [anon_sym_signed] = ACTIONS(2435),
    [anon_sym_unsigned] = ACTIONS(2435),
    [anon_sym_long] = ACTIONS(2435),
    [anon_sym_short] = ACTIONS(2435),
    [anon_sym_LBRACK] = ACTIONS(2435),
    [anon_sym_static] = ACTIONS(2435),
    [anon_sym_register] = ACTIONS(2435),
    [anon_sym_inline] = ACTIONS(2435),
    [anon_sym___inline] = ACTIONS(2435),
    [anon_sym___inline__] = ACTIONS(2435),
    [anon_sym___forceinline] = ACTIONS(2435),
    [anon_sym_thread_local] = ACTIONS(2435),
    [anon_sym___thread] = ACTIONS(2435),
    [anon_sym_const] = ACTIONS(2435),
    [anon_sym_constexpr] = ACTIONS(2435),
    [anon_sym_volatile] = ACTIONS(2435),
    [anon_sym_restrict] = ACTIONS(2435),
    [anon_sym___restrict__] = ACTIONS(2435),
    [anon_sym__Atomic] = ACTIONS(2435),
    [anon_sym__Noreturn] = ACTIONS(2435),
    [anon_sym_noreturn] = ACTIONS(2435),
    [anon_sym__Nonnull] = ACTIONS(2435),
    [anon_sym_mutable] = ACTIONS(2435),
    [anon_sym_constinit] = ACTIONS(2435),
    [anon_sym_consteval] = ACTIONS(2435),
    [anon_sym___shared__] = ACTIONS(2435),
    [anon_sym___local__] = ACTIONS(2435),
    [anon_sym___constant__] = ACTIONS(2435),
    [anon_sym___managed__] = ACTIONS(2435),
    [anon_sym___grid_constant__] = ACTIONS(2435),
    [anon_sym_alignas] = ACTIONS(2435),
    [anon_sym__Alignas] = ACTIONS(2435),
    [sym_primitive_type] = ACTIONS(2435),
    [anon_sym_enum] = ACTIONS(2435),
    [anon_sym_class] = ACTIONS(2435),
    [anon_sym_struct] = ACTIONS(2435),
    [anon_sym_union] = ACTIONS(2435),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2435),
    [anon_sym_decltype] = ACTIONS(2435),
    [anon_sym_explicit] = ACTIONS(2435),
    [anon_sym_typename] = ACTIONS(2435),
    [anon_sym_template] = ACTIONS(2435),
    [anon_sym_operator] = ACTIONS(2435),
    [anon_sym_friend] = ACTIONS(2435),
    [anon_sym_public] = ACTIONS(2435),
    [anon_sym_private] = ACTIONS(2435),
    [anon_sym_protected] = ACTIONS(2435),
    [anon_sym_using] = ACTIONS(2435),
    [anon_sym_static_assert] = ACTIONS(2435),
    [anon_sym___launch_bounds__] = ACTIONS(2435),
  },
  [STATE(2114)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_TILDE] = ACTIONS(5661),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___device__] = ACTIONS(5659),
    [anon_sym___host__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___forceinline__] = ACTIONS(5659),
    [anon_sym___noinline__] = ACTIONS(5659),
    [anon_sym_virtual] = ACTIONS(5659),
    [anon_sym_extern] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5661),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5661),
    [anon_sym___declspec] = ACTIONS(5659),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym___cdecl] = ACTIONS(5659),
    [anon_sym___clrcall] = ACTIONS(5659),
    [anon_sym___stdcall] = ACTIONS(5659),
    [anon_sym___fastcall] = ACTIONS(5659),
    [anon_sym___thiscall] = ACTIONS(5659),
    [anon_sym___vectorcall] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [anon_sym_static] = ACTIONS(5659),
    [anon_sym_EQ] = ACTIONS(5661),
    [anon_sym_register] = ACTIONS(5659),
    [anon_sym_inline] = ACTIONS(5659),
    [anon_sym___inline] = ACTIONS(5659),
    [anon_sym___inline__] = ACTIONS(5659),
    [anon_sym___forceinline] = ACTIONS(5659),
    [anon_sym_thread_local] = ACTIONS(5659),
    [anon_sym___thread] = ACTIONS(5659),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_asm] = ACTIONS(5659),
    [anon_sym___asm__] = ACTIONS(5659),
    [anon_sym___asm] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [anon_sym_template] = ACTIONS(5659),
    [anon_sym_GT2] = ACTIONS(5661),
    [anon_sym_operator] = ACTIONS(5659),
    [anon_sym_try] = ACTIONS(5659),
    [anon_sym_requires] = ACTIONS(5659),
    [anon_sym___launch_bounds__] = ACTIONS(5659),
  },
  [STATE(2115)] = {
    [sym_identifier] = ACTIONS(5692),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5694),
    [anon_sym_COMMA] = ACTIONS(5694),
    [anon_sym_RPAREN] = ACTIONS(5694),
    [anon_sym_LPAREN2] = ACTIONS(5694),
    [anon_sym_DASH] = ACTIONS(5692),
    [anon_sym_PLUS] = ACTIONS(5692),
    [anon_sym_STAR] = ACTIONS(5694),
    [anon_sym_SLASH] = ACTIONS(5692),
    [anon_sym_PERCENT] = ACTIONS(5694),
    [anon_sym_PIPE_PIPE] = ACTIONS(5694),
    [anon_sym_AMP_AMP] = ACTIONS(5694),
    [anon_sym_PIPE] = ACTIONS(5692),
    [anon_sym_CARET] = ACTIONS(5694),
    [anon_sym_AMP] = ACTIONS(5692),
    [anon_sym_EQ_EQ] = ACTIONS(5694),
    [anon_sym_BANG_EQ] = ACTIONS(5694),
    [anon_sym_GT] = ACTIONS(5692),
    [anon_sym_GT_EQ] = ACTIONS(5694),
    [anon_sym_LT_EQ] = ACTIONS(5692),
    [anon_sym_LT] = ACTIONS(5692),
    [anon_sym_LT_LT] = ACTIONS(5692),
    [anon_sym_GT_GT] = ACTIONS(5694),
    [anon_sym_SEMI] = ACTIONS(5694),
    [anon_sym___extension__] = ACTIONS(5692),
    [anon_sym___global__] = ACTIONS(5692),
    [anon_sym___attribute__] = ACTIONS(5692),
    [anon_sym___attribute] = ACTIONS(5692),
    [anon_sym___based] = ACTIONS(5692),
    [anon_sym_LBRACE] = ACTIONS(5694),
    [anon_sym_RBRACE] = ACTIONS(5694),
    [anon_sym_signed] = ACTIONS(5692),
    [anon_sym_unsigned] = ACTIONS(5692),
    [anon_sym_long] = ACTIONS(5692),
    [anon_sym_short] = ACTIONS(5692),
    [anon_sym_LBRACK] = ACTIONS(5694),
    [anon_sym_RBRACK] = ACTIONS(5694),
    [anon_sym_const] = ACTIONS(5692),
    [anon_sym_constexpr] = ACTIONS(5692),
    [anon_sym_volatile] = ACTIONS(5692),
    [anon_sym_restrict] = ACTIONS(5692),
    [anon_sym___restrict__] = ACTIONS(5692),
    [anon_sym__Atomic] = ACTIONS(5692),
    [anon_sym__Noreturn] = ACTIONS(5692),
    [anon_sym_noreturn] = ACTIONS(5692),
    [anon_sym__Nonnull] = ACTIONS(5692),
    [anon_sym_mutable] = ACTIONS(5692),
    [anon_sym_constinit] = ACTIONS(5692),
    [anon_sym_consteval] = ACTIONS(5692),
    [anon_sym___shared__] = ACTIONS(5692),
    [anon_sym___local__] = ACTIONS(5692),
    [anon_sym___constant__] = ACTIONS(5692),
    [anon_sym___managed__] = ACTIONS(5692),
    [anon_sym___grid_constant__] = ACTIONS(5692),
    [anon_sym_alignas] = ACTIONS(5692),
    [anon_sym__Alignas] = ACTIONS(5692),
    [sym_primitive_type] = ACTIONS(5692),
    [anon_sym_COLON] = ACTIONS(5694),
    [anon_sym_QMARK] = ACTIONS(5694),
    [anon_sym_LT_EQ_GT] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5692),
    [anon_sym_and] = ACTIONS(5692),
    [anon_sym_bitor] = ACTIONS(5692),
    [anon_sym_xor] = ACTIONS(5692),
    [anon_sym_bitand] = ACTIONS(5692),
    [anon_sym_not_eq] = ACTIONS(5692),
    [anon_sym_DASH_DASH] = ACTIONS(5694),
    [anon_sym_PLUS_PLUS] = ACTIONS(5694),
    [anon_sym_DOT] = ACTIONS(5692),
    [anon_sym_DOT_STAR] = ACTIONS(5694),
    [anon_sym_DASH_GT] = ACTIONS(5694),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5692),
    [anon_sym_decltype] = ACTIONS(5692),
    [anon_sym_final] = ACTIONS(5692),
    [anon_sym_override] = ACTIONS(5692),
    [anon_sym_requires] = ACTIONS(5692),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5694),
  },
  [STATE(2116)] = {
    [sym_identifier] = ACTIONS(5696),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5698),
    [anon_sym_COMMA] = ACTIONS(5698),
    [anon_sym_RPAREN] = ACTIONS(5698),
    [anon_sym_LPAREN2] = ACTIONS(5698),
    [anon_sym_DASH] = ACTIONS(5696),
    [anon_sym_PLUS] = ACTIONS(5696),
    [anon_sym_STAR] = ACTIONS(5698),
    [anon_sym_SLASH] = ACTIONS(5696),
    [anon_sym_PERCENT] = ACTIONS(5698),
    [anon_sym_PIPE_PIPE] = ACTIONS(5698),
    [anon_sym_AMP_AMP] = ACTIONS(5698),
    [anon_sym_PIPE] = ACTIONS(5696),
    [anon_sym_CARET] = ACTIONS(5698),
    [anon_sym_AMP] = ACTIONS(5696),
    [anon_sym_EQ_EQ] = ACTIONS(5698),
    [anon_sym_BANG_EQ] = ACTIONS(5698),
    [anon_sym_GT] = ACTIONS(5696),
    [anon_sym_GT_EQ] = ACTIONS(5698),
    [anon_sym_LT_EQ] = ACTIONS(5696),
    [anon_sym_LT] = ACTIONS(5696),
    [anon_sym_LT_LT] = ACTIONS(5696),
    [anon_sym_GT_GT] = ACTIONS(5698),
    [anon_sym_SEMI] = ACTIONS(5698),
    [anon_sym___extension__] = ACTIONS(5696),
    [anon_sym___global__] = ACTIONS(5696),
    [anon_sym___attribute__] = ACTIONS(5696),
    [anon_sym___attribute] = ACTIONS(5696),
    [anon_sym___based] = ACTIONS(5696),
    [anon_sym_LBRACE] = ACTIONS(5698),
    [anon_sym_RBRACE] = ACTIONS(5698),
    [anon_sym_signed] = ACTIONS(5696),
    [anon_sym_unsigned] = ACTIONS(5696),
    [anon_sym_long] = ACTIONS(5696),
    [anon_sym_short] = ACTIONS(5696),
    [anon_sym_LBRACK] = ACTIONS(5698),
    [anon_sym_RBRACK] = ACTIONS(5698),
    [anon_sym_const] = ACTIONS(5696),
    [anon_sym_constexpr] = ACTIONS(5696),
    [anon_sym_volatile] = ACTIONS(5696),
    [anon_sym_restrict] = ACTIONS(5696),
    [anon_sym___restrict__] = ACTIONS(5696),
    [anon_sym__Atomic] = ACTIONS(5696),
    [anon_sym__Noreturn] = ACTIONS(5696),
    [anon_sym_noreturn] = ACTIONS(5696),
    [anon_sym__Nonnull] = ACTIONS(5696),
    [anon_sym_mutable] = ACTIONS(5696),
    [anon_sym_constinit] = ACTIONS(5696),
    [anon_sym_consteval] = ACTIONS(5696),
    [anon_sym___shared__] = ACTIONS(5696),
    [anon_sym___local__] = ACTIONS(5696),
    [anon_sym___constant__] = ACTIONS(5696),
    [anon_sym___managed__] = ACTIONS(5696),
    [anon_sym___grid_constant__] = ACTIONS(5696),
    [anon_sym_alignas] = ACTIONS(5696),
    [anon_sym__Alignas] = ACTIONS(5696),
    [sym_primitive_type] = ACTIONS(5696),
    [anon_sym_COLON] = ACTIONS(5698),
    [anon_sym_QMARK] = ACTIONS(5698),
    [anon_sym_LT_EQ_GT] = ACTIONS(5698),
    [anon_sym_or] = ACTIONS(5696),
    [anon_sym_and] = ACTIONS(5696),
    [anon_sym_bitor] = ACTIONS(5696),
    [anon_sym_xor] = ACTIONS(5696),
    [anon_sym_bitand] = ACTIONS(5696),
    [anon_sym_not_eq] = ACTIONS(5696),
    [anon_sym_DASH_DASH] = ACTIONS(5698),
    [anon_sym_PLUS_PLUS] = ACTIONS(5698),
    [anon_sym_DOT] = ACTIONS(5696),
    [anon_sym_DOT_STAR] = ACTIONS(5698),
    [anon_sym_DASH_GT] = ACTIONS(5698),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5696),
    [anon_sym_decltype] = ACTIONS(5696),
    [anon_sym_final] = ACTIONS(5696),
    [anon_sym_override] = ACTIONS(5696),
    [anon_sym_requires] = ACTIONS(5696),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5698),
  },
  [STATE(2117)] = {
    [sym_type_qualifier] = STATE(1738),
    [sym_alignas_qualifier] = STATE(1873),
    [aux_sym__type_definition_type_repeat1] = STATE(1738),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2205),
    [sym_identifier] = ACTIONS(5700),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_RPAREN] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5173),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5173),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5173),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5173),
    [anon_sym_SEMI] = ACTIONS(5173),
    [anon_sym___extension__] = ACTIONS(5702),
    [anon_sym___global__] = ACTIONS(5702),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_RBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5704),
    [anon_sym_unsigned] = ACTIONS(5704),
    [anon_sym_long] = ACTIONS(5704),
    [anon_sym_short] = ACTIONS(5704),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_RBRACK] = ACTIONS(5173),
    [anon_sym_const] = ACTIONS(5702),
    [anon_sym_constexpr] = ACTIONS(5702),
    [anon_sym_volatile] = ACTIONS(5702),
    [anon_sym_restrict] = ACTIONS(5702),
    [anon_sym___restrict__] = ACTIONS(5702),
    [anon_sym__Atomic] = ACTIONS(5702),
    [anon_sym__Noreturn] = ACTIONS(5702),
    [anon_sym_noreturn] = ACTIONS(5702),
    [anon_sym__Nonnull] = ACTIONS(5702),
    [anon_sym_mutable] = ACTIONS(5702),
    [anon_sym_constinit] = ACTIONS(5702),
    [anon_sym_consteval] = ACTIONS(5702),
    [anon_sym___shared__] = ACTIONS(5702),
    [anon_sym___local__] = ACTIONS(5702),
    [anon_sym___constant__] = ACTIONS(5702),
    [anon_sym___managed__] = ACTIONS(5702),
    [anon_sym___grid_constant__] = ACTIONS(5702),
    [anon_sym_alignas] = ACTIONS(5706),
    [anon_sym__Alignas] = ACTIONS(5706),
    [sym_primitive_type] = ACTIONS(5708),
    [anon_sym_COLON] = ACTIONS(5173),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5173),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
  },
  [STATE(2118)] = {
    [sym_identifier] = ACTIONS(5710),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5712),
    [anon_sym_COMMA] = ACTIONS(5712),
    [anon_sym_RPAREN] = ACTIONS(5712),
    [anon_sym_LPAREN2] = ACTIONS(5712),
    [anon_sym_DASH] = ACTIONS(5710),
    [anon_sym_PLUS] = ACTIONS(5710),
    [anon_sym_STAR] = ACTIONS(5712),
    [anon_sym_SLASH] = ACTIONS(5710),
    [anon_sym_PERCENT] = ACTIONS(5712),
    [anon_sym_PIPE_PIPE] = ACTIONS(5712),
    [anon_sym_AMP_AMP] = ACTIONS(5712),
    [anon_sym_PIPE] = ACTIONS(5710),
    [anon_sym_CARET] = ACTIONS(5712),
    [anon_sym_AMP] = ACTIONS(5710),
    [anon_sym_EQ_EQ] = ACTIONS(5712),
    [anon_sym_BANG_EQ] = ACTIONS(5712),
    [anon_sym_GT] = ACTIONS(5710),
    [anon_sym_GT_EQ] = ACTIONS(5712),
    [anon_sym_LT_EQ] = ACTIONS(5710),
    [anon_sym_LT] = ACTIONS(5710),
    [anon_sym_LT_LT] = ACTIONS(5710),
    [anon_sym_GT_GT] = ACTIONS(5712),
    [anon_sym_SEMI] = ACTIONS(5712),
    [anon_sym___extension__] = ACTIONS(5710),
    [anon_sym___global__] = ACTIONS(5710),
    [anon_sym___attribute__] = ACTIONS(5710),
    [anon_sym___attribute] = ACTIONS(5710),
    [anon_sym___based] = ACTIONS(5710),
    [anon_sym_LBRACE] = ACTIONS(5712),
    [anon_sym_RBRACE] = ACTIONS(5712),
    [anon_sym_signed] = ACTIONS(5710),
    [anon_sym_unsigned] = ACTIONS(5710),
    [anon_sym_long] = ACTIONS(5710),
    [anon_sym_short] = ACTIONS(5710),
    [anon_sym_LBRACK] = ACTIONS(5712),
    [anon_sym_RBRACK] = ACTIONS(5712),
    [anon_sym_const] = ACTIONS(5710),
    [anon_sym_constexpr] = ACTIONS(5710),
    [anon_sym_volatile] = ACTIONS(5710),
    [anon_sym_restrict] = ACTIONS(5710),
    [anon_sym___restrict__] = ACTIONS(5710),
    [anon_sym__Atomic] = ACTIONS(5710),
    [anon_sym__Noreturn] = ACTIONS(5710),
    [anon_sym_noreturn] = ACTIONS(5710),
    [anon_sym__Nonnull] = ACTIONS(5710),
    [anon_sym_mutable] = ACTIONS(5710),
    [anon_sym_constinit] = ACTIONS(5710),
    [anon_sym_consteval] = ACTIONS(5710),
    [anon_sym___shared__] = ACTIONS(5710),
    [anon_sym___local__] = ACTIONS(5710),
    [anon_sym___constant__] = ACTIONS(5710),
    [anon_sym___managed__] = ACTIONS(5710),
    [anon_sym___grid_constant__] = ACTIONS(5710),
    [anon_sym_alignas] = ACTIONS(5710),
    [anon_sym__Alignas] = ACTIONS(5710),
    [sym_primitive_type] = ACTIONS(5710),
    [anon_sym_COLON] = ACTIONS(5712),
    [anon_sym_QMARK] = ACTIONS(5712),
    [anon_sym_LT_EQ_GT] = ACTIONS(5712),
    [anon_sym_or] = ACTIONS(5710),
    [anon_sym_and] = ACTIONS(5710),
    [anon_sym_bitor] = ACTIONS(5710),
    [anon_sym_xor] = ACTIONS(5710),
    [anon_sym_bitand] = ACTIONS(5710),
    [anon_sym_not_eq] = ACTIONS(5710),
    [anon_sym_DASH_DASH] = ACTIONS(5712),
    [anon_sym_PLUS_PLUS] = ACTIONS(5712),
    [anon_sym_DOT] = ACTIONS(5710),
    [anon_sym_DOT_STAR] = ACTIONS(5712),
    [anon_sym_DASH_GT] = ACTIONS(5712),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5710),
    [anon_sym_decltype] = ACTIONS(5710),
    [anon_sym_final] = ACTIONS(5710),
    [anon_sym_override] = ACTIONS(5710),
    [anon_sym_requires] = ACTIONS(5710),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5712),
  },
  [STATE(2119)] = {
    [sym_identifier] = ACTIONS(5714),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5716),
    [anon_sym_COMMA] = ACTIONS(5716),
    [anon_sym_RPAREN] = ACTIONS(5716),
    [anon_sym_LPAREN2] = ACTIONS(5716),
    [anon_sym_DASH] = ACTIONS(5714),
    [anon_sym_PLUS] = ACTIONS(5714),
    [anon_sym_STAR] = ACTIONS(5716),
    [anon_sym_SLASH] = ACTIONS(5714),
    [anon_sym_PERCENT] = ACTIONS(5716),
    [anon_sym_PIPE_PIPE] = ACTIONS(5716),
    [anon_sym_AMP_AMP] = ACTIONS(5716),
    [anon_sym_PIPE] = ACTIONS(5714),
    [anon_sym_CARET] = ACTIONS(5716),
    [anon_sym_AMP] = ACTIONS(5714),
    [anon_sym_EQ_EQ] = ACTIONS(5716),
    [anon_sym_BANG_EQ] = ACTIONS(5716),
    [anon_sym_GT] = ACTIONS(5714),
    [anon_sym_GT_EQ] = ACTIONS(5716),
    [anon_sym_LT_EQ] = ACTIONS(5714),
    [anon_sym_LT] = ACTIONS(5714),
    [anon_sym_LT_LT] = ACTIONS(5714),
    [anon_sym_GT_GT] = ACTIONS(5716),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym___extension__] = ACTIONS(5714),
    [anon_sym___global__] = ACTIONS(5714),
    [anon_sym___attribute__] = ACTIONS(5714),
    [anon_sym___attribute] = ACTIONS(5714),
    [anon_sym___based] = ACTIONS(5714),
    [anon_sym_LBRACE] = ACTIONS(5716),
    [anon_sym_RBRACE] = ACTIONS(5716),
    [anon_sym_signed] = ACTIONS(5714),
    [anon_sym_unsigned] = ACTIONS(5714),
    [anon_sym_long] = ACTIONS(5714),
    [anon_sym_short] = ACTIONS(5714),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_RBRACK] = ACTIONS(5716),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_constexpr] = ACTIONS(5714),
    [anon_sym_volatile] = ACTIONS(5714),
    [anon_sym_restrict] = ACTIONS(5714),
    [anon_sym___restrict__] = ACTIONS(5714),
    [anon_sym__Atomic] = ACTIONS(5714),
    [anon_sym__Noreturn] = ACTIONS(5714),
    [anon_sym_noreturn] = ACTIONS(5714),
    [anon_sym__Nonnull] = ACTIONS(5714),
    [anon_sym_mutable] = ACTIONS(5714),
    [anon_sym_constinit] = ACTIONS(5714),
    [anon_sym_consteval] = ACTIONS(5714),
    [anon_sym___shared__] = ACTIONS(5714),
    [anon_sym___local__] = ACTIONS(5714),
    [anon_sym___constant__] = ACTIONS(5714),
    [anon_sym___managed__] = ACTIONS(5714),
    [anon_sym___grid_constant__] = ACTIONS(5714),
    [anon_sym_alignas] = ACTIONS(5714),
    [anon_sym__Alignas] = ACTIONS(5714),
    [sym_primitive_type] = ACTIONS(5714),
    [anon_sym_COLON] = ACTIONS(5716),
    [anon_sym_QMARK] = ACTIONS(5716),
    [anon_sym_LT_EQ_GT] = ACTIONS(5716),
    [anon_sym_or] = ACTIONS(5714),
    [anon_sym_and] = ACTIONS(5714),
    [anon_sym_bitor] = ACTIONS(5714),
    [anon_sym_xor] = ACTIONS(5714),
    [anon_sym_bitand] = ACTIONS(5714),
    [anon_sym_not_eq] = ACTIONS(5714),
    [anon_sym_DASH_DASH] = ACTIONS(5716),
    [anon_sym_PLUS_PLUS] = ACTIONS(5716),
    [anon_sym_DOT] = ACTIONS(5714),
    [anon_sym_DOT_STAR] = ACTIONS(5716),
    [anon_sym_DASH_GT] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5714),
    [anon_sym_decltype] = ACTIONS(5714),
    [anon_sym_final] = ACTIONS(5714),
    [anon_sym_override] = ACTIONS(5714),
    [anon_sym_requires] = ACTIONS(5714),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5716),
  },
  [STATE(2120)] = {
    [sym_identifier] = ACTIONS(5718),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5720),
    [anon_sym_COMMA] = ACTIONS(5720),
    [anon_sym_RPAREN] = ACTIONS(5720),
    [anon_sym_LPAREN2] = ACTIONS(5720),
    [anon_sym_DASH] = ACTIONS(5718),
    [anon_sym_PLUS] = ACTIONS(5718),
    [anon_sym_STAR] = ACTIONS(5720),
    [anon_sym_SLASH] = ACTIONS(5718),
    [anon_sym_PERCENT] = ACTIONS(5720),
    [anon_sym_PIPE_PIPE] = ACTIONS(5720),
    [anon_sym_AMP_AMP] = ACTIONS(5720),
    [anon_sym_PIPE] = ACTIONS(5718),
    [anon_sym_CARET] = ACTIONS(5720),
    [anon_sym_AMP] = ACTIONS(5718),
    [anon_sym_EQ_EQ] = ACTIONS(5720),
    [anon_sym_BANG_EQ] = ACTIONS(5720),
    [anon_sym_GT] = ACTIONS(5718),
    [anon_sym_GT_EQ] = ACTIONS(5720),
    [anon_sym_LT_EQ] = ACTIONS(5718),
    [anon_sym_LT] = ACTIONS(5718),
    [anon_sym_LT_LT] = ACTIONS(5718),
    [anon_sym_GT_GT] = ACTIONS(5720),
    [anon_sym_SEMI] = ACTIONS(5720),
    [anon_sym___extension__] = ACTIONS(5718),
    [anon_sym___global__] = ACTIONS(5718),
    [anon_sym___attribute__] = ACTIONS(5718),
    [anon_sym___attribute] = ACTIONS(5718),
    [anon_sym___based] = ACTIONS(5718),
    [anon_sym_LBRACE] = ACTIONS(5720),
    [anon_sym_RBRACE] = ACTIONS(5720),
    [anon_sym_signed] = ACTIONS(5718),
    [anon_sym_unsigned] = ACTIONS(5718),
    [anon_sym_long] = ACTIONS(5718),
    [anon_sym_short] = ACTIONS(5718),
    [anon_sym_LBRACK] = ACTIONS(5720),
    [anon_sym_RBRACK] = ACTIONS(5720),
    [anon_sym_const] = ACTIONS(5718),
    [anon_sym_constexpr] = ACTIONS(5718),
    [anon_sym_volatile] = ACTIONS(5718),
    [anon_sym_restrict] = ACTIONS(5718),
    [anon_sym___restrict__] = ACTIONS(5718),
    [anon_sym__Atomic] = ACTIONS(5718),
    [anon_sym__Noreturn] = ACTIONS(5718),
    [anon_sym_noreturn] = ACTIONS(5718),
    [anon_sym__Nonnull] = ACTIONS(5718),
    [anon_sym_mutable] = ACTIONS(5718),
    [anon_sym_constinit] = ACTIONS(5718),
    [anon_sym_consteval] = ACTIONS(5718),
    [anon_sym___shared__] = ACTIONS(5718),
    [anon_sym___local__] = ACTIONS(5718),
    [anon_sym___constant__] = ACTIONS(5718),
    [anon_sym___managed__] = ACTIONS(5718),
    [anon_sym___grid_constant__] = ACTIONS(5718),
    [anon_sym_alignas] = ACTIONS(5718),
    [anon_sym__Alignas] = ACTIONS(5718),
    [sym_primitive_type] = ACTIONS(5718),
    [anon_sym_COLON] = ACTIONS(5720),
    [anon_sym_QMARK] = ACTIONS(5720),
    [anon_sym_LT_EQ_GT] = ACTIONS(5720),
    [anon_sym_or] = ACTIONS(5718),
    [anon_sym_and] = ACTIONS(5718),
    [anon_sym_bitor] = ACTIONS(5718),
    [anon_sym_xor] = ACTIONS(5718),
    [anon_sym_bitand] = ACTIONS(5718),
    [anon_sym_not_eq] = ACTIONS(5718),
    [anon_sym_DASH_DASH] = ACTIONS(5720),
    [anon_sym_PLUS_PLUS] = ACTIONS(5720),
    [anon_sym_DOT] = ACTIONS(5718),
    [anon_sym_DOT_STAR] = ACTIONS(5720),
    [anon_sym_DASH_GT] = ACTIONS(5720),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5718),
    [anon_sym_decltype] = ACTIONS(5718),
    [anon_sym_final] = ACTIONS(5718),
    [anon_sym_override] = ACTIONS(5718),
    [anon_sym_requires] = ACTIONS(5718),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5720),
  },
  [STATE(2121)] = {
    [sym_identifier] = ACTIONS(5722),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5724),
    [anon_sym_COMMA] = ACTIONS(5724),
    [anon_sym_RPAREN] = ACTIONS(5724),
    [anon_sym_LPAREN2] = ACTIONS(5724),
    [anon_sym_DASH] = ACTIONS(5722),
    [anon_sym_PLUS] = ACTIONS(5722),
    [anon_sym_STAR] = ACTIONS(5724),
    [anon_sym_SLASH] = ACTIONS(5722),
    [anon_sym_PERCENT] = ACTIONS(5724),
    [anon_sym_PIPE_PIPE] = ACTIONS(5724),
    [anon_sym_AMP_AMP] = ACTIONS(5724),
    [anon_sym_PIPE] = ACTIONS(5722),
    [anon_sym_CARET] = ACTIONS(5724),
    [anon_sym_AMP] = ACTIONS(5722),
    [anon_sym_EQ_EQ] = ACTIONS(5724),
    [anon_sym_BANG_EQ] = ACTIONS(5724),
    [anon_sym_GT] = ACTIONS(5722),
    [anon_sym_GT_EQ] = ACTIONS(5724),
    [anon_sym_LT_EQ] = ACTIONS(5722),
    [anon_sym_LT] = ACTIONS(5722),
    [anon_sym_LT_LT] = ACTIONS(5722),
    [anon_sym_GT_GT] = ACTIONS(5724),
    [anon_sym_SEMI] = ACTIONS(5724),
    [anon_sym___extension__] = ACTIONS(5722),
    [anon_sym___global__] = ACTIONS(5722),
    [anon_sym___attribute__] = ACTIONS(5722),
    [anon_sym___attribute] = ACTIONS(5722),
    [anon_sym___based] = ACTIONS(5722),
    [anon_sym_LBRACE] = ACTIONS(5724),
    [anon_sym_RBRACE] = ACTIONS(5724),
    [anon_sym_signed] = ACTIONS(5722),
    [anon_sym_unsigned] = ACTIONS(5722),
    [anon_sym_long] = ACTIONS(5722),
    [anon_sym_short] = ACTIONS(5722),
    [anon_sym_LBRACK] = ACTIONS(5724),
    [anon_sym_RBRACK] = ACTIONS(5724),
    [anon_sym_const] = ACTIONS(5722),
    [anon_sym_constexpr] = ACTIONS(5722),
    [anon_sym_volatile] = ACTIONS(5722),
    [anon_sym_restrict] = ACTIONS(5722),
    [anon_sym___restrict__] = ACTIONS(5722),
    [anon_sym__Atomic] = ACTIONS(5722),
    [anon_sym__Noreturn] = ACTIONS(5722),
    [anon_sym_noreturn] = ACTIONS(5722),
    [anon_sym__Nonnull] = ACTIONS(5722),
    [anon_sym_mutable] = ACTIONS(5722),
    [anon_sym_constinit] = ACTIONS(5722),
    [anon_sym_consteval] = ACTIONS(5722),
    [anon_sym___shared__] = ACTIONS(5722),
    [anon_sym___local__] = ACTIONS(5722),
    [anon_sym___constant__] = ACTIONS(5722),
    [anon_sym___managed__] = ACTIONS(5722),
    [anon_sym___grid_constant__] = ACTIONS(5722),
    [anon_sym_alignas] = ACTIONS(5722),
    [anon_sym__Alignas] = ACTIONS(5722),
    [sym_primitive_type] = ACTIONS(5722),
    [anon_sym_COLON] = ACTIONS(5724),
    [anon_sym_QMARK] = ACTIONS(5724),
    [anon_sym_LT_EQ_GT] = ACTIONS(5724),
    [anon_sym_or] = ACTIONS(5722),
    [anon_sym_and] = ACTIONS(5722),
    [anon_sym_bitor] = ACTIONS(5722),
    [anon_sym_xor] = ACTIONS(5722),
    [anon_sym_bitand] = ACTIONS(5722),
    [anon_sym_not_eq] = ACTIONS(5722),
    [anon_sym_DASH_DASH] = ACTIONS(5724),
    [anon_sym_PLUS_PLUS] = ACTIONS(5724),
    [anon_sym_DOT] = ACTIONS(5722),
    [anon_sym_DOT_STAR] = ACTIONS(5724),
    [anon_sym_DASH_GT] = ACTIONS(5724),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5722),
    [anon_sym_decltype] = ACTIONS(5722),
    [anon_sym_final] = ACTIONS(5722),
    [anon_sym_override] = ACTIONS(5722),
    [anon_sym_requires] = ACTIONS(5722),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5724),
  },
  [STATE(2122)] = {
    [sym_identifier] = ACTIONS(5726),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5728),
    [anon_sym_COMMA] = ACTIONS(5728),
    [anon_sym_RPAREN] = ACTIONS(5728),
    [anon_sym_LPAREN2] = ACTIONS(5728),
    [anon_sym_DASH] = ACTIONS(5726),
    [anon_sym_PLUS] = ACTIONS(5726),
    [anon_sym_STAR] = ACTIONS(5728),
    [anon_sym_SLASH] = ACTIONS(5726),
    [anon_sym_PERCENT] = ACTIONS(5728),
    [anon_sym_PIPE_PIPE] = ACTIONS(5728),
    [anon_sym_AMP_AMP] = ACTIONS(5728),
    [anon_sym_PIPE] = ACTIONS(5726),
    [anon_sym_CARET] = ACTIONS(5728),
    [anon_sym_AMP] = ACTIONS(5726),
    [anon_sym_EQ_EQ] = ACTIONS(5728),
    [anon_sym_BANG_EQ] = ACTIONS(5728),
    [anon_sym_GT] = ACTIONS(5726),
    [anon_sym_GT_EQ] = ACTIONS(5728),
    [anon_sym_LT_EQ] = ACTIONS(5726),
    [anon_sym_LT] = ACTIONS(5726),
    [anon_sym_LT_LT] = ACTIONS(5726),
    [anon_sym_GT_GT] = ACTIONS(5728),
    [anon_sym_SEMI] = ACTIONS(5728),
    [anon_sym___extension__] = ACTIONS(5726),
    [anon_sym___global__] = ACTIONS(5726),
    [anon_sym___attribute__] = ACTIONS(5726),
    [anon_sym___attribute] = ACTIONS(5726),
    [anon_sym___based] = ACTIONS(5726),
    [anon_sym_LBRACE] = ACTIONS(5728),
    [anon_sym_RBRACE] = ACTIONS(5728),
    [anon_sym_signed] = ACTIONS(5726),
    [anon_sym_unsigned] = ACTIONS(5726),
    [anon_sym_long] = ACTIONS(5726),
    [anon_sym_short] = ACTIONS(5726),
    [anon_sym_LBRACK] = ACTIONS(5728),
    [anon_sym_RBRACK] = ACTIONS(5728),
    [anon_sym_const] = ACTIONS(5726),
    [anon_sym_constexpr] = ACTIONS(5726),
    [anon_sym_volatile] = ACTIONS(5726),
    [anon_sym_restrict] = ACTIONS(5726),
    [anon_sym___restrict__] = ACTIONS(5726),
    [anon_sym__Atomic] = ACTIONS(5726),
    [anon_sym__Noreturn] = ACTIONS(5726),
    [anon_sym_noreturn] = ACTIONS(5726),
    [anon_sym__Nonnull] = ACTIONS(5726),
    [anon_sym_mutable] = ACTIONS(5726),
    [anon_sym_constinit] = ACTIONS(5726),
    [anon_sym_consteval] = ACTIONS(5726),
    [anon_sym___shared__] = ACTIONS(5726),
    [anon_sym___local__] = ACTIONS(5726),
    [anon_sym___constant__] = ACTIONS(5726),
    [anon_sym___managed__] = ACTIONS(5726),
    [anon_sym___grid_constant__] = ACTIONS(5726),
    [anon_sym_alignas] = ACTIONS(5726),
    [anon_sym__Alignas] = ACTIONS(5726),
    [sym_primitive_type] = ACTIONS(5726),
    [anon_sym_COLON] = ACTIONS(5728),
    [anon_sym_QMARK] = ACTIONS(5728),
    [anon_sym_LT_EQ_GT] = ACTIONS(5728),
    [anon_sym_or] = ACTIONS(5726),
    [anon_sym_and] = ACTIONS(5726),
    [anon_sym_bitor] = ACTIONS(5726),
    [anon_sym_xor] = ACTIONS(5726),
    [anon_sym_bitand] = ACTIONS(5726),
    [anon_sym_not_eq] = ACTIONS(5726),
    [anon_sym_DASH_DASH] = ACTIONS(5728),
    [anon_sym_PLUS_PLUS] = ACTIONS(5728),
    [anon_sym_DOT] = ACTIONS(5726),
    [anon_sym_DOT_STAR] = ACTIONS(5728),
    [anon_sym_DASH_GT] = ACTIONS(5728),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5726),
    [anon_sym_decltype] = ACTIONS(5726),
    [anon_sym_final] = ACTIONS(5726),
    [anon_sym_override] = ACTIONS(5726),
    [anon_sym_requires] = ACTIONS(5726),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5728),
  },
  [STATE(2123)] = {
    [sym_identifier] = ACTIONS(5730),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5732),
    [anon_sym_COMMA] = ACTIONS(5732),
    [anon_sym_RPAREN] = ACTIONS(5732),
    [anon_sym_LPAREN2] = ACTIONS(5732),
    [anon_sym_DASH] = ACTIONS(5730),
    [anon_sym_PLUS] = ACTIONS(5730),
    [anon_sym_STAR] = ACTIONS(5732),
    [anon_sym_SLASH] = ACTIONS(5730),
    [anon_sym_PERCENT] = ACTIONS(5732),
    [anon_sym_PIPE_PIPE] = ACTIONS(5732),
    [anon_sym_AMP_AMP] = ACTIONS(5732),
    [anon_sym_PIPE] = ACTIONS(5730),
    [anon_sym_CARET] = ACTIONS(5732),
    [anon_sym_AMP] = ACTIONS(5730),
    [anon_sym_EQ_EQ] = ACTIONS(5732),
    [anon_sym_BANG_EQ] = ACTIONS(5732),
    [anon_sym_GT] = ACTIONS(5730),
    [anon_sym_GT_EQ] = ACTIONS(5732),
    [anon_sym_LT_EQ] = ACTIONS(5730),
    [anon_sym_LT] = ACTIONS(5730),
    [anon_sym_LT_LT] = ACTIONS(5730),
    [anon_sym_GT_GT] = ACTIONS(5732),
    [anon_sym_SEMI] = ACTIONS(5732),
    [anon_sym___extension__] = ACTIONS(5730),
    [anon_sym___global__] = ACTIONS(5730),
    [anon_sym___attribute__] = ACTIONS(5730),
    [anon_sym___attribute] = ACTIONS(5730),
    [anon_sym___based] = ACTIONS(5730),
    [anon_sym_LBRACE] = ACTIONS(5732),
    [anon_sym_RBRACE] = ACTIONS(5732),
    [anon_sym_signed] = ACTIONS(5730),
    [anon_sym_unsigned] = ACTIONS(5730),
    [anon_sym_long] = ACTIONS(5730),
    [anon_sym_short] = ACTIONS(5730),
    [anon_sym_LBRACK] = ACTIONS(5732),
    [anon_sym_RBRACK] = ACTIONS(5732),
    [anon_sym_const] = ACTIONS(5730),
    [anon_sym_constexpr] = ACTIONS(5730),
    [anon_sym_volatile] = ACTIONS(5730),
    [anon_sym_restrict] = ACTIONS(5730),
    [anon_sym___restrict__] = ACTIONS(5730),
    [anon_sym__Atomic] = ACTIONS(5730),
    [anon_sym__Noreturn] = ACTIONS(5730),
    [anon_sym_noreturn] = ACTIONS(5730),
    [anon_sym__Nonnull] = ACTIONS(5730),
    [anon_sym_mutable] = ACTIONS(5730),
    [anon_sym_constinit] = ACTIONS(5730),
    [anon_sym_consteval] = ACTIONS(5730),
    [anon_sym___shared__] = ACTIONS(5730),
    [anon_sym___local__] = ACTIONS(5730),
    [anon_sym___constant__] = ACTIONS(5730),
    [anon_sym___managed__] = ACTIONS(5730),
    [anon_sym___grid_constant__] = ACTIONS(5730),
    [anon_sym_alignas] = ACTIONS(5730),
    [anon_sym__Alignas] = ACTIONS(5730),
    [sym_primitive_type] = ACTIONS(5730),
    [anon_sym_COLON] = ACTIONS(5732),
    [anon_sym_QMARK] = ACTIONS(5732),
    [anon_sym_LT_EQ_GT] = ACTIONS(5732),
    [anon_sym_or] = ACTIONS(5730),
    [anon_sym_and] = ACTIONS(5730),
    [anon_sym_bitor] = ACTIONS(5730),
    [anon_sym_xor] = ACTIONS(5730),
    [anon_sym_bitand] = ACTIONS(5730),
    [anon_sym_not_eq] = ACTIONS(5730),
    [anon_sym_DASH_DASH] = ACTIONS(5732),
    [anon_sym_PLUS_PLUS] = ACTIONS(5732),
    [anon_sym_DOT] = ACTIONS(5730),
    [anon_sym_DOT_STAR] = ACTIONS(5732),
    [anon_sym_DASH_GT] = ACTIONS(5732),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5730),
    [anon_sym_decltype] = ACTIONS(5730),
    [anon_sym_final] = ACTIONS(5730),
    [anon_sym_override] = ACTIONS(5730),
    [anon_sym_requires] = ACTIONS(5730),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5732),
  },
  [STATE(2124)] = {
    [sym_identifier] = ACTIONS(5734),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5736),
    [anon_sym_COMMA] = ACTIONS(5736),
    [anon_sym_RPAREN] = ACTIONS(5736),
    [anon_sym_LPAREN2] = ACTIONS(5736),
    [anon_sym_DASH] = ACTIONS(5734),
    [anon_sym_PLUS] = ACTIONS(5734),
    [anon_sym_STAR] = ACTIONS(5736),
    [anon_sym_SLASH] = ACTIONS(5734),
    [anon_sym_PERCENT] = ACTIONS(5736),
    [anon_sym_PIPE_PIPE] = ACTIONS(5736),
    [anon_sym_AMP_AMP] = ACTIONS(5736),
    [anon_sym_PIPE] = ACTIONS(5734),
    [anon_sym_CARET] = ACTIONS(5736),
    [anon_sym_AMP] = ACTIONS(5734),
    [anon_sym_EQ_EQ] = ACTIONS(5736),
    [anon_sym_BANG_EQ] = ACTIONS(5736),
    [anon_sym_GT] = ACTIONS(5734),
    [anon_sym_GT_EQ] = ACTIONS(5736),
    [anon_sym_LT_EQ] = ACTIONS(5734),
    [anon_sym_LT] = ACTIONS(5734),
    [anon_sym_LT_LT] = ACTIONS(5734),
    [anon_sym_GT_GT] = ACTIONS(5736),
    [anon_sym_SEMI] = ACTIONS(5736),
    [anon_sym___extension__] = ACTIONS(5734),
    [anon_sym___global__] = ACTIONS(5734),
    [anon_sym___attribute__] = ACTIONS(5734),
    [anon_sym___attribute] = ACTIONS(5734),
    [anon_sym___based] = ACTIONS(5734),
    [anon_sym_LBRACE] = ACTIONS(5736),
    [anon_sym_RBRACE] = ACTIONS(5736),
    [anon_sym_signed] = ACTIONS(5734),
    [anon_sym_unsigned] = ACTIONS(5734),
    [anon_sym_long] = ACTIONS(5734),
    [anon_sym_short] = ACTIONS(5734),
    [anon_sym_LBRACK] = ACTIONS(5736),
    [anon_sym_RBRACK] = ACTIONS(5736),
    [anon_sym_const] = ACTIONS(5734),
    [anon_sym_constexpr] = ACTIONS(5734),
    [anon_sym_volatile] = ACTIONS(5734),
    [anon_sym_restrict] = ACTIONS(5734),
    [anon_sym___restrict__] = ACTIONS(5734),
    [anon_sym__Atomic] = ACTIONS(5734),
    [anon_sym__Noreturn] = ACTIONS(5734),
    [anon_sym_noreturn] = ACTIONS(5734),
    [anon_sym__Nonnull] = ACTIONS(5734),
    [anon_sym_mutable] = ACTIONS(5734),
    [anon_sym_constinit] = ACTIONS(5734),
    [anon_sym_consteval] = ACTIONS(5734),
    [anon_sym___shared__] = ACTIONS(5734),
    [anon_sym___local__] = ACTIONS(5734),
    [anon_sym___constant__] = ACTIONS(5734),
    [anon_sym___managed__] = ACTIONS(5734),
    [anon_sym___grid_constant__] = ACTIONS(5734),
    [anon_sym_alignas] = ACTIONS(5734),
    [anon_sym__Alignas] = ACTIONS(5734),
    [sym_primitive_type] = ACTIONS(5734),
    [anon_sym_COLON] = ACTIONS(5736),
    [anon_sym_QMARK] = ACTIONS(5736),
    [anon_sym_LT_EQ_GT] = ACTIONS(5736),
    [anon_sym_or] = ACTIONS(5734),
    [anon_sym_and] = ACTIONS(5734),
    [anon_sym_bitor] = ACTIONS(5734),
    [anon_sym_xor] = ACTIONS(5734),
    [anon_sym_bitand] = ACTIONS(5734),
    [anon_sym_not_eq] = ACTIONS(5734),
    [anon_sym_DASH_DASH] = ACTIONS(5736),
    [anon_sym_PLUS_PLUS] = ACTIONS(5736),
    [anon_sym_DOT] = ACTIONS(5734),
    [anon_sym_DOT_STAR] = ACTIONS(5736),
    [anon_sym_DASH_GT] = ACTIONS(5736),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5734),
    [anon_sym_decltype] = ACTIONS(5734),
    [anon_sym_final] = ACTIONS(5734),
    [anon_sym_override] = ACTIONS(5734),
    [anon_sym_requires] = ACTIONS(5734),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5736),
  },
  [STATE(2125)] = {
    [sym_identifier] = ACTIONS(5738),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5740),
    [anon_sym_COMMA] = ACTIONS(5740),
    [anon_sym_RPAREN] = ACTIONS(5740),
    [anon_sym_LPAREN2] = ACTIONS(5740),
    [anon_sym_DASH] = ACTIONS(5738),
    [anon_sym_PLUS] = ACTIONS(5738),
    [anon_sym_STAR] = ACTIONS(5740),
    [anon_sym_SLASH] = ACTIONS(5738),
    [anon_sym_PERCENT] = ACTIONS(5740),
    [anon_sym_PIPE_PIPE] = ACTIONS(5740),
    [anon_sym_AMP_AMP] = ACTIONS(5740),
    [anon_sym_PIPE] = ACTIONS(5738),
    [anon_sym_CARET] = ACTIONS(5740),
    [anon_sym_AMP] = ACTIONS(5738),
    [anon_sym_EQ_EQ] = ACTIONS(5740),
    [anon_sym_BANG_EQ] = ACTIONS(5740),
    [anon_sym_GT] = ACTIONS(5738),
    [anon_sym_GT_EQ] = ACTIONS(5740),
    [anon_sym_LT_EQ] = ACTIONS(5738),
    [anon_sym_LT] = ACTIONS(5738),
    [anon_sym_LT_LT] = ACTIONS(5738),
    [anon_sym_GT_GT] = ACTIONS(5740),
    [anon_sym_SEMI] = ACTIONS(5740),
    [anon_sym___extension__] = ACTIONS(5738),
    [anon_sym___global__] = ACTIONS(5738),
    [anon_sym___attribute__] = ACTIONS(5738),
    [anon_sym___attribute] = ACTIONS(5738),
    [anon_sym___based] = ACTIONS(5738),
    [anon_sym_LBRACE] = ACTIONS(5740),
    [anon_sym_RBRACE] = ACTIONS(5740),
    [anon_sym_signed] = ACTIONS(5738),
    [anon_sym_unsigned] = ACTIONS(5738),
    [anon_sym_long] = ACTIONS(5738),
    [anon_sym_short] = ACTIONS(5738),
    [anon_sym_LBRACK] = ACTIONS(5740),
    [anon_sym_RBRACK] = ACTIONS(5740),
    [anon_sym_const] = ACTIONS(5738),
    [anon_sym_constexpr] = ACTIONS(5738),
    [anon_sym_volatile] = ACTIONS(5738),
    [anon_sym_restrict] = ACTIONS(5738),
    [anon_sym___restrict__] = ACTIONS(5738),
    [anon_sym__Atomic] = ACTIONS(5738),
    [anon_sym__Noreturn] = ACTIONS(5738),
    [anon_sym_noreturn] = ACTIONS(5738),
    [anon_sym__Nonnull] = ACTIONS(5738),
    [anon_sym_mutable] = ACTIONS(5738),
    [anon_sym_constinit] = ACTIONS(5738),
    [anon_sym_consteval] = ACTIONS(5738),
    [anon_sym___shared__] = ACTIONS(5738),
    [anon_sym___local__] = ACTIONS(5738),
    [anon_sym___constant__] = ACTIONS(5738),
    [anon_sym___managed__] = ACTIONS(5738),
    [anon_sym___grid_constant__] = ACTIONS(5738),
    [anon_sym_alignas] = ACTIONS(5738),
    [anon_sym__Alignas] = ACTIONS(5738),
    [sym_primitive_type] = ACTIONS(5738),
    [anon_sym_COLON] = ACTIONS(5740),
    [anon_sym_QMARK] = ACTIONS(5740),
    [anon_sym_LT_EQ_GT] = ACTIONS(5740),
    [anon_sym_or] = ACTIONS(5738),
    [anon_sym_and] = ACTIONS(5738),
    [anon_sym_bitor] = ACTIONS(5738),
    [anon_sym_xor] = ACTIONS(5738),
    [anon_sym_bitand] = ACTIONS(5738),
    [anon_sym_not_eq] = ACTIONS(5738),
    [anon_sym_DASH_DASH] = ACTIONS(5740),
    [anon_sym_PLUS_PLUS] = ACTIONS(5740),
    [anon_sym_DOT] = ACTIONS(5738),
    [anon_sym_DOT_STAR] = ACTIONS(5740),
    [anon_sym_DASH_GT] = ACTIONS(5740),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5738),
    [anon_sym_decltype] = ACTIONS(5738),
    [anon_sym_final] = ACTIONS(5738),
    [anon_sym_override] = ACTIONS(5738),
    [anon_sym_requires] = ACTIONS(5738),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5740),
  },
  [STATE(2126)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_TILDE] = ACTIONS(5661),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___device__] = ACTIONS(5659),
    [anon_sym___host__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___forceinline__] = ACTIONS(5659),
    [anon_sym___noinline__] = ACTIONS(5659),
    [anon_sym_virtual] = ACTIONS(5659),
    [anon_sym_extern] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5661),
    [anon_sym___declspec] = ACTIONS(5659),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym___cdecl] = ACTIONS(5659),
    [anon_sym___clrcall] = ACTIONS(5659),
    [anon_sym___stdcall] = ACTIONS(5659),
    [anon_sym___fastcall] = ACTIONS(5659),
    [anon_sym___thiscall] = ACTIONS(5659),
    [anon_sym___vectorcall] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [anon_sym_static] = ACTIONS(5659),
    [anon_sym_EQ] = ACTIONS(5661),
    [anon_sym_register] = ACTIONS(5659),
    [anon_sym_inline] = ACTIONS(5659),
    [anon_sym___inline] = ACTIONS(5659),
    [anon_sym___inline__] = ACTIONS(5659),
    [anon_sym___forceinline] = ACTIONS(5659),
    [anon_sym_thread_local] = ACTIONS(5659),
    [anon_sym___thread] = ACTIONS(5659),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_asm] = ACTIONS(5659),
    [anon_sym___asm__] = ACTIONS(5659),
    [anon_sym___asm] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [anon_sym_template] = ACTIONS(5659),
    [anon_sym_GT2] = ACTIONS(5661),
    [anon_sym_operator] = ACTIONS(5659),
    [anon_sym_try] = ACTIONS(5659),
    [anon_sym_requires] = ACTIONS(5659),
    [anon_sym___launch_bounds__] = ACTIONS(5659),
  },
  [STATE(2127)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5686),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_signed] = ACTIONS(5684),
    [anon_sym_unsigned] = ACTIONS(5684),
    [anon_sym_long] = ACTIONS(5684),
    [anon_sym_short] = ACTIONS(5684),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_primitive_type] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_and] = ACTIONS(5684),
    [anon_sym_bitor] = ACTIONS(5684),
    [anon_sym_xor] = ACTIONS(5684),
    [anon_sym_bitand] = ACTIONS(5684),
    [anon_sym_not_eq] = ACTIONS(5684),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_final] = ACTIONS(5684),
    [anon_sym_override] = ACTIONS(5684),
    [anon_sym_requires] = ACTIONS(5684),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2128)] = {
    [sym_identifier] = ACTIONS(5742),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5744),
    [anon_sym_COMMA] = ACTIONS(5744),
    [anon_sym_RPAREN] = ACTIONS(5744),
    [anon_sym_LPAREN2] = ACTIONS(5744),
    [anon_sym_DASH] = ACTIONS(5742),
    [anon_sym_PLUS] = ACTIONS(5742),
    [anon_sym_STAR] = ACTIONS(5744),
    [anon_sym_SLASH] = ACTIONS(5742),
    [anon_sym_PERCENT] = ACTIONS(5744),
    [anon_sym_PIPE_PIPE] = ACTIONS(5744),
    [anon_sym_AMP_AMP] = ACTIONS(5744),
    [anon_sym_PIPE] = ACTIONS(5742),
    [anon_sym_CARET] = ACTIONS(5744),
    [anon_sym_AMP] = ACTIONS(5742),
    [anon_sym_EQ_EQ] = ACTIONS(5744),
    [anon_sym_BANG_EQ] = ACTIONS(5744),
    [anon_sym_GT] = ACTIONS(5742),
    [anon_sym_GT_EQ] = ACTIONS(5744),
    [anon_sym_LT_EQ] = ACTIONS(5742),
    [anon_sym_LT] = ACTIONS(5742),
    [anon_sym_LT_LT] = ACTIONS(5742),
    [anon_sym_GT_GT] = ACTIONS(5744),
    [anon_sym_SEMI] = ACTIONS(5744),
    [anon_sym___extension__] = ACTIONS(5742),
    [anon_sym___global__] = ACTIONS(5742),
    [anon_sym___attribute__] = ACTIONS(5742),
    [anon_sym___attribute] = ACTIONS(5742),
    [anon_sym___based] = ACTIONS(5742),
    [anon_sym_LBRACE] = ACTIONS(5744),
    [anon_sym_RBRACE] = ACTIONS(5744),
    [anon_sym_signed] = ACTIONS(5742),
    [anon_sym_unsigned] = ACTIONS(5742),
    [anon_sym_long] = ACTIONS(5742),
    [anon_sym_short] = ACTIONS(5742),
    [anon_sym_LBRACK] = ACTIONS(5744),
    [anon_sym_RBRACK] = ACTIONS(5744),
    [anon_sym_const] = ACTIONS(5742),
    [anon_sym_constexpr] = ACTIONS(5742),
    [anon_sym_volatile] = ACTIONS(5742),
    [anon_sym_restrict] = ACTIONS(5742),
    [anon_sym___restrict__] = ACTIONS(5742),
    [anon_sym__Atomic] = ACTIONS(5742),
    [anon_sym__Noreturn] = ACTIONS(5742),
    [anon_sym_noreturn] = ACTIONS(5742),
    [anon_sym__Nonnull] = ACTIONS(5742),
    [anon_sym_mutable] = ACTIONS(5742),
    [anon_sym_constinit] = ACTIONS(5742),
    [anon_sym_consteval] = ACTIONS(5742),
    [anon_sym___shared__] = ACTIONS(5742),
    [anon_sym___local__] = ACTIONS(5742),
    [anon_sym___constant__] = ACTIONS(5742),
    [anon_sym___managed__] = ACTIONS(5742),
    [anon_sym___grid_constant__] = ACTIONS(5742),
    [anon_sym_alignas] = ACTIONS(5742),
    [anon_sym__Alignas] = ACTIONS(5742),
    [sym_primitive_type] = ACTIONS(5742),
    [anon_sym_COLON] = ACTIONS(5744),
    [anon_sym_QMARK] = ACTIONS(5744),
    [anon_sym_LT_EQ_GT] = ACTIONS(5744),
    [anon_sym_or] = ACTIONS(5742),
    [anon_sym_and] = ACTIONS(5742),
    [anon_sym_bitor] = ACTIONS(5742),
    [anon_sym_xor] = ACTIONS(5742),
    [anon_sym_bitand] = ACTIONS(5742),
    [anon_sym_not_eq] = ACTIONS(5742),
    [anon_sym_DASH_DASH] = ACTIONS(5744),
    [anon_sym_PLUS_PLUS] = ACTIONS(5744),
    [anon_sym_DOT] = ACTIONS(5742),
    [anon_sym_DOT_STAR] = ACTIONS(5744),
    [anon_sym_DASH_GT] = ACTIONS(5744),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5742),
    [anon_sym_decltype] = ACTIONS(5742),
    [anon_sym_final] = ACTIONS(5742),
    [anon_sym_override] = ACTIONS(5742),
    [anon_sym_requires] = ACTIONS(5742),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5744),
  },
  [STATE(2129)] = {
    [sym_identifier] = ACTIONS(5746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5748),
    [anon_sym_COMMA] = ACTIONS(5748),
    [anon_sym_RPAREN] = ACTIONS(5748),
    [anon_sym_LPAREN2] = ACTIONS(5748),
    [anon_sym_DASH] = ACTIONS(5746),
    [anon_sym_PLUS] = ACTIONS(5746),
    [anon_sym_STAR] = ACTIONS(5748),
    [anon_sym_SLASH] = ACTIONS(5746),
    [anon_sym_PERCENT] = ACTIONS(5748),
    [anon_sym_PIPE_PIPE] = ACTIONS(5748),
    [anon_sym_AMP_AMP] = ACTIONS(5748),
    [anon_sym_PIPE] = ACTIONS(5746),
    [anon_sym_CARET] = ACTIONS(5748),
    [anon_sym_AMP] = ACTIONS(5746),
    [anon_sym_EQ_EQ] = ACTIONS(5748),
    [anon_sym_BANG_EQ] = ACTIONS(5748),
    [anon_sym_GT] = ACTIONS(5746),
    [anon_sym_GT_EQ] = ACTIONS(5748),
    [anon_sym_LT_EQ] = ACTIONS(5746),
    [anon_sym_LT] = ACTIONS(5746),
    [anon_sym_LT_LT] = ACTIONS(5746),
    [anon_sym_GT_GT] = ACTIONS(5748),
    [anon_sym_SEMI] = ACTIONS(5748),
    [anon_sym___extension__] = ACTIONS(5746),
    [anon_sym___global__] = ACTIONS(5746),
    [anon_sym___attribute__] = ACTIONS(5746),
    [anon_sym___attribute] = ACTIONS(5746),
    [anon_sym___based] = ACTIONS(5746),
    [anon_sym_LBRACE] = ACTIONS(5748),
    [anon_sym_RBRACE] = ACTIONS(5748),
    [anon_sym_signed] = ACTIONS(5746),
    [anon_sym_unsigned] = ACTIONS(5746),
    [anon_sym_long] = ACTIONS(5746),
    [anon_sym_short] = ACTIONS(5746),
    [anon_sym_LBRACK] = ACTIONS(5748),
    [anon_sym_RBRACK] = ACTIONS(5748),
    [anon_sym_const] = ACTIONS(5746),
    [anon_sym_constexpr] = ACTIONS(5746),
    [anon_sym_volatile] = ACTIONS(5746),
    [anon_sym_restrict] = ACTIONS(5746),
    [anon_sym___restrict__] = ACTIONS(5746),
    [anon_sym__Atomic] = ACTIONS(5746),
    [anon_sym__Noreturn] = ACTIONS(5746),
    [anon_sym_noreturn] = ACTIONS(5746),
    [anon_sym__Nonnull] = ACTIONS(5746),
    [anon_sym_mutable] = ACTIONS(5746),
    [anon_sym_constinit] = ACTIONS(5746),
    [anon_sym_consteval] = ACTIONS(5746),
    [anon_sym___shared__] = ACTIONS(5746),
    [anon_sym___local__] = ACTIONS(5746),
    [anon_sym___constant__] = ACTIONS(5746),
    [anon_sym___managed__] = ACTIONS(5746),
    [anon_sym___grid_constant__] = ACTIONS(5746),
    [anon_sym_alignas] = ACTIONS(5746),
    [anon_sym__Alignas] = ACTIONS(5746),
    [sym_primitive_type] = ACTIONS(5746),
    [anon_sym_COLON] = ACTIONS(5748),
    [anon_sym_QMARK] = ACTIONS(5748),
    [anon_sym_LT_EQ_GT] = ACTIONS(5748),
    [anon_sym_or] = ACTIONS(5746),
    [anon_sym_and] = ACTIONS(5746),
    [anon_sym_bitor] = ACTIONS(5746),
    [anon_sym_xor] = ACTIONS(5746),
    [anon_sym_bitand] = ACTIONS(5746),
    [anon_sym_not_eq] = ACTIONS(5746),
    [anon_sym_DASH_DASH] = ACTIONS(5748),
    [anon_sym_PLUS_PLUS] = ACTIONS(5748),
    [anon_sym_DOT] = ACTIONS(5746),
    [anon_sym_DOT_STAR] = ACTIONS(5748),
    [anon_sym_DASH_GT] = ACTIONS(5748),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5746),
    [anon_sym_decltype] = ACTIONS(5746),
    [anon_sym_final] = ACTIONS(5746),
    [anon_sym_override] = ACTIONS(5746),
    [anon_sym_requires] = ACTIONS(5746),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5748),
  },
  [STATE(2130)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5752),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5752),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5752),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___extension__] = ACTIONS(5750),
    [anon_sym___global__] = ACTIONS(5750),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym___based] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_RBRACE] = ACTIONS(5752),
    [anon_sym_signed] = ACTIONS(5750),
    [anon_sym_unsigned] = ACTIONS(5750),
    [anon_sym_long] = ACTIONS(5750),
    [anon_sym_short] = ACTIONS(5750),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_RBRACK] = ACTIONS(5752),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5750),
    [anon_sym_volatile] = ACTIONS(5750),
    [anon_sym_restrict] = ACTIONS(5750),
    [anon_sym___restrict__] = ACTIONS(5750),
    [anon_sym__Atomic] = ACTIONS(5750),
    [anon_sym__Noreturn] = ACTIONS(5750),
    [anon_sym_noreturn] = ACTIONS(5750),
    [anon_sym__Nonnull] = ACTIONS(5750),
    [anon_sym_mutable] = ACTIONS(5750),
    [anon_sym_constinit] = ACTIONS(5750),
    [anon_sym_consteval] = ACTIONS(5750),
    [anon_sym___shared__] = ACTIONS(5750),
    [anon_sym___local__] = ACTIONS(5750),
    [anon_sym___constant__] = ACTIONS(5750),
    [anon_sym___managed__] = ACTIONS(5750),
    [anon_sym___grid_constant__] = ACTIONS(5750),
    [anon_sym_alignas] = ACTIONS(5750),
    [anon_sym__Alignas] = ACTIONS(5750),
    [sym_primitive_type] = ACTIONS(5750),
    [anon_sym_COLON] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5750),
    [anon_sym_and] = ACTIONS(5750),
    [anon_sym_bitor] = ACTIONS(5750),
    [anon_sym_xor] = ACTIONS(5750),
    [anon_sym_bitand] = ACTIONS(5750),
    [anon_sym_not_eq] = ACTIONS(5750),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [anon_sym_final] = ACTIONS(5750),
    [anon_sym_override] = ACTIONS(5750),
    [anon_sym_requires] = ACTIONS(5750),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2131)] = {
    [sym_identifier] = ACTIONS(5754),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5756),
    [anon_sym_COMMA] = ACTIONS(5756),
    [anon_sym_RPAREN] = ACTIONS(5756),
    [anon_sym_LPAREN2] = ACTIONS(5756),
    [anon_sym_DASH] = ACTIONS(5754),
    [anon_sym_PLUS] = ACTIONS(5754),
    [anon_sym_STAR] = ACTIONS(5756),
    [anon_sym_SLASH] = ACTIONS(5754),
    [anon_sym_PERCENT] = ACTIONS(5756),
    [anon_sym_PIPE_PIPE] = ACTIONS(5756),
    [anon_sym_AMP_AMP] = ACTIONS(5756),
    [anon_sym_PIPE] = ACTIONS(5754),
    [anon_sym_CARET] = ACTIONS(5756),
    [anon_sym_AMP] = ACTIONS(5754),
    [anon_sym_EQ_EQ] = ACTIONS(5756),
    [anon_sym_BANG_EQ] = ACTIONS(5756),
    [anon_sym_GT] = ACTIONS(5754),
    [anon_sym_GT_EQ] = ACTIONS(5756),
    [anon_sym_LT_EQ] = ACTIONS(5754),
    [anon_sym_LT] = ACTIONS(5754),
    [anon_sym_LT_LT] = ACTIONS(5754),
    [anon_sym_GT_GT] = ACTIONS(5756),
    [anon_sym_SEMI] = ACTIONS(5756),
    [anon_sym___extension__] = ACTIONS(5754),
    [anon_sym___global__] = ACTIONS(5754),
    [anon_sym___attribute__] = ACTIONS(5754),
    [anon_sym___attribute] = ACTIONS(5754),
    [anon_sym___based] = ACTIONS(5754),
    [anon_sym_LBRACE] = ACTIONS(5756),
    [anon_sym_RBRACE] = ACTIONS(5756),
    [anon_sym_signed] = ACTIONS(5754),
    [anon_sym_unsigned] = ACTIONS(5754),
    [anon_sym_long] = ACTIONS(5754),
    [anon_sym_short] = ACTIONS(5754),
    [anon_sym_LBRACK] = ACTIONS(5756),
    [anon_sym_RBRACK] = ACTIONS(5756),
    [anon_sym_const] = ACTIONS(5754),
    [anon_sym_constexpr] = ACTIONS(5754),
    [anon_sym_volatile] = ACTIONS(5754),
    [anon_sym_restrict] = ACTIONS(5754),
    [anon_sym___restrict__] = ACTIONS(5754),
    [anon_sym__Atomic] = ACTIONS(5754),
    [anon_sym__Noreturn] = ACTIONS(5754),
    [anon_sym_noreturn] = ACTIONS(5754),
    [anon_sym__Nonnull] = ACTIONS(5754),
    [anon_sym_mutable] = ACTIONS(5754),
    [anon_sym_constinit] = ACTIONS(5754),
    [anon_sym_consteval] = ACTIONS(5754),
    [anon_sym___shared__] = ACTIONS(5754),
    [anon_sym___local__] = ACTIONS(5754),
    [anon_sym___constant__] = ACTIONS(5754),
    [anon_sym___managed__] = ACTIONS(5754),
    [anon_sym___grid_constant__] = ACTIONS(5754),
    [anon_sym_alignas] = ACTIONS(5754),
    [anon_sym__Alignas] = ACTIONS(5754),
    [sym_primitive_type] = ACTIONS(5754),
    [anon_sym_COLON] = ACTIONS(5756),
    [anon_sym_QMARK] = ACTIONS(5756),
    [anon_sym_LT_EQ_GT] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5754),
    [anon_sym_and] = ACTIONS(5754),
    [anon_sym_bitor] = ACTIONS(5754),
    [anon_sym_xor] = ACTIONS(5754),
    [anon_sym_bitand] = ACTIONS(5754),
    [anon_sym_not_eq] = ACTIONS(5754),
    [anon_sym_DASH_DASH] = ACTIONS(5756),
    [anon_sym_PLUS_PLUS] = ACTIONS(5756),
    [anon_sym_DOT] = ACTIONS(5754),
    [anon_sym_DOT_STAR] = ACTIONS(5756),
    [anon_sym_DASH_GT] = ACTIONS(5756),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5754),
    [anon_sym_decltype] = ACTIONS(5754),
    [anon_sym_final] = ACTIONS(5754),
    [anon_sym_override] = ACTIONS(5754),
    [anon_sym_requires] = ACTIONS(5754),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5756),
  },
  [STATE(2132)] = {
    [sym_identifier] = ACTIONS(5758),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5760),
    [anon_sym_COMMA] = ACTIONS(5760),
    [anon_sym_RPAREN] = ACTIONS(5760),
    [anon_sym_LPAREN2] = ACTIONS(5760),
    [anon_sym_DASH] = ACTIONS(5758),
    [anon_sym_PLUS] = ACTIONS(5758),
    [anon_sym_STAR] = ACTIONS(5760),
    [anon_sym_SLASH] = ACTIONS(5758),
    [anon_sym_PERCENT] = ACTIONS(5760),
    [anon_sym_PIPE_PIPE] = ACTIONS(5760),
    [anon_sym_AMP_AMP] = ACTIONS(5760),
    [anon_sym_PIPE] = ACTIONS(5758),
    [anon_sym_CARET] = ACTIONS(5760),
    [anon_sym_AMP] = ACTIONS(5758),
    [anon_sym_EQ_EQ] = ACTIONS(5760),
    [anon_sym_BANG_EQ] = ACTIONS(5760),
    [anon_sym_GT] = ACTIONS(5758),
    [anon_sym_GT_EQ] = ACTIONS(5760),
    [anon_sym_LT_EQ] = ACTIONS(5758),
    [anon_sym_LT] = ACTIONS(5758),
    [anon_sym_LT_LT] = ACTIONS(5758),
    [anon_sym_GT_GT] = ACTIONS(5760),
    [anon_sym_SEMI] = ACTIONS(5760),
    [anon_sym___extension__] = ACTIONS(5758),
    [anon_sym___global__] = ACTIONS(5758),
    [anon_sym___attribute__] = ACTIONS(5758),
    [anon_sym___attribute] = ACTIONS(5758),
    [anon_sym___based] = ACTIONS(5758),
    [anon_sym_LBRACE] = ACTIONS(5760),
    [anon_sym_RBRACE] = ACTIONS(5760),
    [anon_sym_signed] = ACTIONS(5758),
    [anon_sym_unsigned] = ACTIONS(5758),
    [anon_sym_long] = ACTIONS(5758),
    [anon_sym_short] = ACTIONS(5758),
    [anon_sym_LBRACK] = ACTIONS(5760),
    [anon_sym_RBRACK] = ACTIONS(5760),
    [anon_sym_const] = ACTIONS(5758),
    [anon_sym_constexpr] = ACTIONS(5758),
    [anon_sym_volatile] = ACTIONS(5758),
    [anon_sym_restrict] = ACTIONS(5758),
    [anon_sym___restrict__] = ACTIONS(5758),
    [anon_sym__Atomic] = ACTIONS(5758),
    [anon_sym__Noreturn] = ACTIONS(5758),
    [anon_sym_noreturn] = ACTIONS(5758),
    [anon_sym__Nonnull] = ACTIONS(5758),
    [anon_sym_mutable] = ACTIONS(5758),
    [anon_sym_constinit] = ACTIONS(5758),
    [anon_sym_consteval] = ACTIONS(5758),
    [anon_sym___shared__] = ACTIONS(5758),
    [anon_sym___local__] = ACTIONS(5758),
    [anon_sym___constant__] = ACTIONS(5758),
    [anon_sym___managed__] = ACTIONS(5758),
    [anon_sym___grid_constant__] = ACTIONS(5758),
    [anon_sym_alignas] = ACTIONS(5758),
    [anon_sym__Alignas] = ACTIONS(5758),
    [sym_primitive_type] = ACTIONS(5758),
    [anon_sym_COLON] = ACTIONS(5760),
    [anon_sym_QMARK] = ACTIONS(5760),
    [anon_sym_LT_EQ_GT] = ACTIONS(5760),
    [anon_sym_or] = ACTIONS(5758),
    [anon_sym_and] = ACTIONS(5758),
    [anon_sym_bitor] = ACTIONS(5758),
    [anon_sym_xor] = ACTIONS(5758),
    [anon_sym_bitand] = ACTIONS(5758),
    [anon_sym_not_eq] = ACTIONS(5758),
    [anon_sym_DASH_DASH] = ACTIONS(5760),
    [anon_sym_PLUS_PLUS] = ACTIONS(5760),
    [anon_sym_DOT] = ACTIONS(5758),
    [anon_sym_DOT_STAR] = ACTIONS(5760),
    [anon_sym_DASH_GT] = ACTIONS(5760),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5758),
    [anon_sym_decltype] = ACTIONS(5758),
    [anon_sym_final] = ACTIONS(5758),
    [anon_sym_override] = ACTIONS(5758),
    [anon_sym_requires] = ACTIONS(5758),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5760),
  },
  [STATE(2133)] = {
    [sym_identifier] = ACTIONS(5762),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5764),
    [anon_sym_COMMA] = ACTIONS(5764),
    [anon_sym_RPAREN] = ACTIONS(5764),
    [anon_sym_LPAREN2] = ACTIONS(5764),
    [anon_sym_DASH] = ACTIONS(5762),
    [anon_sym_PLUS] = ACTIONS(5762),
    [anon_sym_STAR] = ACTIONS(5764),
    [anon_sym_SLASH] = ACTIONS(5762),
    [anon_sym_PERCENT] = ACTIONS(5764),
    [anon_sym_PIPE_PIPE] = ACTIONS(5764),
    [anon_sym_AMP_AMP] = ACTIONS(5764),
    [anon_sym_PIPE] = ACTIONS(5762),
    [anon_sym_CARET] = ACTIONS(5764),
    [anon_sym_AMP] = ACTIONS(5762),
    [anon_sym_EQ_EQ] = ACTIONS(5764),
    [anon_sym_BANG_EQ] = ACTIONS(5764),
    [anon_sym_GT] = ACTIONS(5762),
    [anon_sym_GT_EQ] = ACTIONS(5764),
    [anon_sym_LT_EQ] = ACTIONS(5762),
    [anon_sym_LT] = ACTIONS(5762),
    [anon_sym_LT_LT] = ACTIONS(5762),
    [anon_sym_GT_GT] = ACTIONS(5764),
    [anon_sym_SEMI] = ACTIONS(5764),
    [anon_sym___extension__] = ACTIONS(5762),
    [anon_sym___global__] = ACTIONS(5762),
    [anon_sym___attribute__] = ACTIONS(5762),
    [anon_sym___attribute] = ACTIONS(5762),
    [anon_sym___based] = ACTIONS(5762),
    [anon_sym_LBRACE] = ACTIONS(5764),
    [anon_sym_RBRACE] = ACTIONS(5764),
    [anon_sym_signed] = ACTIONS(5762),
    [anon_sym_unsigned] = ACTIONS(5762),
    [anon_sym_long] = ACTIONS(5762),
    [anon_sym_short] = ACTIONS(5762),
    [anon_sym_LBRACK] = ACTIONS(5764),
    [anon_sym_RBRACK] = ACTIONS(5764),
    [anon_sym_const] = ACTIONS(5762),
    [anon_sym_constexpr] = ACTIONS(5762),
    [anon_sym_volatile] = ACTIONS(5762),
    [anon_sym_restrict] = ACTIONS(5762),
    [anon_sym___restrict__] = ACTIONS(5762),
    [anon_sym__Atomic] = ACTIONS(5762),
    [anon_sym__Noreturn] = ACTIONS(5762),
    [anon_sym_noreturn] = ACTIONS(5762),
    [anon_sym__Nonnull] = ACTIONS(5762),
    [anon_sym_mutable] = ACTIONS(5762),
    [anon_sym_constinit] = ACTIONS(5762),
    [anon_sym_consteval] = ACTIONS(5762),
    [anon_sym___shared__] = ACTIONS(5762),
    [anon_sym___local__] = ACTIONS(5762),
    [anon_sym___constant__] = ACTIONS(5762),
    [anon_sym___managed__] = ACTIONS(5762),
    [anon_sym___grid_constant__] = ACTIONS(5762),
    [anon_sym_alignas] = ACTIONS(5762),
    [anon_sym__Alignas] = ACTIONS(5762),
    [sym_primitive_type] = ACTIONS(5762),
    [anon_sym_COLON] = ACTIONS(5764),
    [anon_sym_QMARK] = ACTIONS(5764),
    [anon_sym_LT_EQ_GT] = ACTIONS(5764),
    [anon_sym_or] = ACTIONS(5762),
    [anon_sym_and] = ACTIONS(5762),
    [anon_sym_bitor] = ACTIONS(5762),
    [anon_sym_xor] = ACTIONS(5762),
    [anon_sym_bitand] = ACTIONS(5762),
    [anon_sym_not_eq] = ACTIONS(5762),
    [anon_sym_DASH_DASH] = ACTIONS(5764),
    [anon_sym_PLUS_PLUS] = ACTIONS(5764),
    [anon_sym_DOT] = ACTIONS(5762),
    [anon_sym_DOT_STAR] = ACTIONS(5764),
    [anon_sym_DASH_GT] = ACTIONS(5764),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5762),
    [anon_sym_decltype] = ACTIONS(5762),
    [anon_sym_final] = ACTIONS(5762),
    [anon_sym_override] = ACTIONS(5762),
    [anon_sym_requires] = ACTIONS(5762),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5764),
  },
  [STATE(2134)] = {
    [sym_identifier] = ACTIONS(5766),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5768),
    [anon_sym_COMMA] = ACTIONS(5768),
    [anon_sym_RPAREN] = ACTIONS(5768),
    [anon_sym_LPAREN2] = ACTIONS(5768),
    [anon_sym_DASH] = ACTIONS(5766),
    [anon_sym_PLUS] = ACTIONS(5766),
    [anon_sym_STAR] = ACTIONS(5768),
    [anon_sym_SLASH] = ACTIONS(5766),
    [anon_sym_PERCENT] = ACTIONS(5768),
    [anon_sym_PIPE_PIPE] = ACTIONS(5768),
    [anon_sym_AMP_AMP] = ACTIONS(5768),
    [anon_sym_PIPE] = ACTIONS(5766),
    [anon_sym_CARET] = ACTIONS(5768),
    [anon_sym_AMP] = ACTIONS(5766),
    [anon_sym_EQ_EQ] = ACTIONS(5768),
    [anon_sym_BANG_EQ] = ACTIONS(5768),
    [anon_sym_GT] = ACTIONS(5766),
    [anon_sym_GT_EQ] = ACTIONS(5768),
    [anon_sym_LT_EQ] = ACTIONS(5766),
    [anon_sym_LT] = ACTIONS(5766),
    [anon_sym_LT_LT] = ACTIONS(5766),
    [anon_sym_GT_GT] = ACTIONS(5768),
    [anon_sym_SEMI] = ACTIONS(5768),
    [anon_sym___extension__] = ACTIONS(5766),
    [anon_sym___global__] = ACTIONS(5766),
    [anon_sym___attribute__] = ACTIONS(5766),
    [anon_sym___attribute] = ACTIONS(5766),
    [anon_sym___based] = ACTIONS(5766),
    [anon_sym_LBRACE] = ACTIONS(5768),
    [anon_sym_RBRACE] = ACTIONS(5768),
    [anon_sym_signed] = ACTIONS(5766),
    [anon_sym_unsigned] = ACTIONS(5766),
    [anon_sym_long] = ACTIONS(5766),
    [anon_sym_short] = ACTIONS(5766),
    [anon_sym_LBRACK] = ACTIONS(5768),
    [anon_sym_RBRACK] = ACTIONS(5768),
    [anon_sym_const] = ACTIONS(5766),
    [anon_sym_constexpr] = ACTIONS(5766),
    [anon_sym_volatile] = ACTIONS(5766),
    [anon_sym_restrict] = ACTIONS(5766),
    [anon_sym___restrict__] = ACTIONS(5766),
    [anon_sym__Atomic] = ACTIONS(5766),
    [anon_sym__Noreturn] = ACTIONS(5766),
    [anon_sym_noreturn] = ACTIONS(5766),
    [anon_sym__Nonnull] = ACTIONS(5766),
    [anon_sym_mutable] = ACTIONS(5766),
    [anon_sym_constinit] = ACTIONS(5766),
    [anon_sym_consteval] = ACTIONS(5766),
    [anon_sym___shared__] = ACTIONS(5766),
    [anon_sym___local__] = ACTIONS(5766),
    [anon_sym___constant__] = ACTIONS(5766),
    [anon_sym___managed__] = ACTIONS(5766),
    [anon_sym___grid_constant__] = ACTIONS(5766),
    [anon_sym_alignas] = ACTIONS(5766),
    [anon_sym__Alignas] = ACTIONS(5766),
    [sym_primitive_type] = ACTIONS(5766),
    [anon_sym_COLON] = ACTIONS(5768),
    [anon_sym_QMARK] = ACTIONS(5768),
    [anon_sym_LT_EQ_GT] = ACTIONS(5768),
    [anon_sym_or] = ACTIONS(5766),
    [anon_sym_and] = ACTIONS(5766),
    [anon_sym_bitor] = ACTIONS(5766),
    [anon_sym_xor] = ACTIONS(5766),
    [anon_sym_bitand] = ACTIONS(5766),
    [anon_sym_not_eq] = ACTIONS(5766),
    [anon_sym_DASH_DASH] = ACTIONS(5768),
    [anon_sym_PLUS_PLUS] = ACTIONS(5768),
    [anon_sym_DOT] = ACTIONS(5766),
    [anon_sym_DOT_STAR] = ACTIONS(5768),
    [anon_sym_DASH_GT] = ACTIONS(5768),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5766),
    [anon_sym_decltype] = ACTIONS(5766),
    [anon_sym_final] = ACTIONS(5766),
    [anon_sym_override] = ACTIONS(5766),
    [anon_sym_requires] = ACTIONS(5766),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5768),
  },
  [STATE(2135)] = {
    [sym_identifier] = ACTIONS(5770),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_RPAREN] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_DASH] = ACTIONS(5770),
    [anon_sym_PLUS] = ACTIONS(5770),
    [anon_sym_STAR] = ACTIONS(5772),
    [anon_sym_SLASH] = ACTIONS(5770),
    [anon_sym_PERCENT] = ACTIONS(5772),
    [anon_sym_PIPE_PIPE] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_PIPE] = ACTIONS(5770),
    [anon_sym_CARET] = ACTIONS(5772),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_EQ_EQ] = ACTIONS(5772),
    [anon_sym_BANG_EQ] = ACTIONS(5772),
    [anon_sym_GT] = ACTIONS(5770),
    [anon_sym_GT_EQ] = ACTIONS(5772),
    [anon_sym_LT_EQ] = ACTIONS(5770),
    [anon_sym_LT] = ACTIONS(5770),
    [anon_sym_LT_LT] = ACTIONS(5770),
    [anon_sym_GT_GT] = ACTIONS(5772),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym___extension__] = ACTIONS(5770),
    [anon_sym___global__] = ACTIONS(5770),
    [anon_sym___attribute__] = ACTIONS(5770),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym___based] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_RBRACE] = ACTIONS(5772),
    [anon_sym_signed] = ACTIONS(5770),
    [anon_sym_unsigned] = ACTIONS(5770),
    [anon_sym_long] = ACTIONS(5770),
    [anon_sym_short] = ACTIONS(5770),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_RBRACK] = ACTIONS(5772),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_constexpr] = ACTIONS(5770),
    [anon_sym_volatile] = ACTIONS(5770),
    [anon_sym_restrict] = ACTIONS(5770),
    [anon_sym___restrict__] = ACTIONS(5770),
    [anon_sym__Atomic] = ACTIONS(5770),
    [anon_sym__Noreturn] = ACTIONS(5770),
    [anon_sym_noreturn] = ACTIONS(5770),
    [anon_sym__Nonnull] = ACTIONS(5770),
    [anon_sym_mutable] = ACTIONS(5770),
    [anon_sym_constinit] = ACTIONS(5770),
    [anon_sym_consteval] = ACTIONS(5770),
    [anon_sym___shared__] = ACTIONS(5770),
    [anon_sym___local__] = ACTIONS(5770),
    [anon_sym___constant__] = ACTIONS(5770),
    [anon_sym___managed__] = ACTIONS(5770),
    [anon_sym___grid_constant__] = ACTIONS(5770),
    [anon_sym_alignas] = ACTIONS(5770),
    [anon_sym__Alignas] = ACTIONS(5770),
    [sym_primitive_type] = ACTIONS(5770),
    [anon_sym_COLON] = ACTIONS(5772),
    [anon_sym_QMARK] = ACTIONS(5772),
    [anon_sym_LT_EQ_GT] = ACTIONS(5772),
    [anon_sym_or] = ACTIONS(5770),
    [anon_sym_and] = ACTIONS(5770),
    [anon_sym_bitor] = ACTIONS(5770),
    [anon_sym_xor] = ACTIONS(5770),
    [anon_sym_bitand] = ACTIONS(5770),
    [anon_sym_not_eq] = ACTIONS(5770),
    [anon_sym_DASH_DASH] = ACTIONS(5772),
    [anon_sym_PLUS_PLUS] = ACTIONS(5772),
    [anon_sym_DOT] = ACTIONS(5770),
    [anon_sym_DOT_STAR] = ACTIONS(5772),
    [anon_sym_DASH_GT] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5770),
    [anon_sym_decltype] = ACTIONS(5770),
    [anon_sym_final] = ACTIONS(5770),
    [anon_sym_override] = ACTIONS(5770),
    [anon_sym_requires] = ACTIONS(5770),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5772),
  },
  [STATE(2136)] = {
    [sym_identifier] = ACTIONS(5774),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5776),
    [anon_sym_COMMA] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5776),
    [anon_sym_LPAREN2] = ACTIONS(5776),
    [anon_sym_DASH] = ACTIONS(5774),
    [anon_sym_PLUS] = ACTIONS(5774),
    [anon_sym_STAR] = ACTIONS(5776),
    [anon_sym_SLASH] = ACTIONS(5774),
    [anon_sym_PERCENT] = ACTIONS(5776),
    [anon_sym_PIPE_PIPE] = ACTIONS(5776),
    [anon_sym_AMP_AMP] = ACTIONS(5776),
    [anon_sym_PIPE] = ACTIONS(5774),
    [anon_sym_CARET] = ACTIONS(5776),
    [anon_sym_AMP] = ACTIONS(5774),
    [anon_sym_EQ_EQ] = ACTIONS(5776),
    [anon_sym_BANG_EQ] = ACTIONS(5776),
    [anon_sym_GT] = ACTIONS(5774),
    [anon_sym_GT_EQ] = ACTIONS(5776),
    [anon_sym_LT_EQ] = ACTIONS(5774),
    [anon_sym_LT] = ACTIONS(5774),
    [anon_sym_LT_LT] = ACTIONS(5774),
    [anon_sym_GT_GT] = ACTIONS(5776),
    [anon_sym_SEMI] = ACTIONS(5776),
    [anon_sym___extension__] = ACTIONS(5774),
    [anon_sym___global__] = ACTIONS(5774),
    [anon_sym___attribute__] = ACTIONS(5774),
    [anon_sym___attribute] = ACTIONS(5774),
    [anon_sym___based] = ACTIONS(5774),
    [anon_sym_LBRACE] = ACTIONS(5776),
    [anon_sym_RBRACE] = ACTIONS(5776),
    [anon_sym_signed] = ACTIONS(5774),
    [anon_sym_unsigned] = ACTIONS(5774),
    [anon_sym_long] = ACTIONS(5774),
    [anon_sym_short] = ACTIONS(5774),
    [anon_sym_LBRACK] = ACTIONS(5776),
    [anon_sym_RBRACK] = ACTIONS(5776),
    [anon_sym_const] = ACTIONS(5774),
    [anon_sym_constexpr] = ACTIONS(5774),
    [anon_sym_volatile] = ACTIONS(5774),
    [anon_sym_restrict] = ACTIONS(5774),
    [anon_sym___restrict__] = ACTIONS(5774),
    [anon_sym__Atomic] = ACTIONS(5774),
    [anon_sym__Noreturn] = ACTIONS(5774),
    [anon_sym_noreturn] = ACTIONS(5774),
    [anon_sym__Nonnull] = ACTIONS(5774),
    [anon_sym_mutable] = ACTIONS(5774),
    [anon_sym_constinit] = ACTIONS(5774),
    [anon_sym_consteval] = ACTIONS(5774),
    [anon_sym___shared__] = ACTIONS(5774),
    [anon_sym___local__] = ACTIONS(5774),
    [anon_sym___constant__] = ACTIONS(5774),
    [anon_sym___managed__] = ACTIONS(5774),
    [anon_sym___grid_constant__] = ACTIONS(5774),
    [anon_sym_alignas] = ACTIONS(5774),
    [anon_sym__Alignas] = ACTIONS(5774),
    [sym_primitive_type] = ACTIONS(5774),
    [anon_sym_COLON] = ACTIONS(5776),
    [anon_sym_QMARK] = ACTIONS(5776),
    [anon_sym_LT_EQ_GT] = ACTIONS(5776),
    [anon_sym_or] = ACTIONS(5774),
    [anon_sym_and] = ACTIONS(5774),
    [anon_sym_bitor] = ACTIONS(5774),
    [anon_sym_xor] = ACTIONS(5774),
    [anon_sym_bitand] = ACTIONS(5774),
    [anon_sym_not_eq] = ACTIONS(5774),
    [anon_sym_DASH_DASH] = ACTIONS(5776),
    [anon_sym_PLUS_PLUS] = ACTIONS(5776),
    [anon_sym_DOT] = ACTIONS(5774),
    [anon_sym_DOT_STAR] = ACTIONS(5776),
    [anon_sym_DASH_GT] = ACTIONS(5776),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5774),
    [anon_sym_decltype] = ACTIONS(5774),
    [anon_sym_final] = ACTIONS(5774),
    [anon_sym_override] = ACTIONS(5774),
    [anon_sym_requires] = ACTIONS(5774),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5776),
  },
  [STATE(2137)] = {
    [sym_identifier] = ACTIONS(5778),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5780),
    [anon_sym_COMMA] = ACTIONS(5780),
    [anon_sym_RPAREN] = ACTIONS(5780),
    [anon_sym_LPAREN2] = ACTIONS(5780),
    [anon_sym_DASH] = ACTIONS(5778),
    [anon_sym_PLUS] = ACTIONS(5778),
    [anon_sym_STAR] = ACTIONS(5780),
    [anon_sym_SLASH] = ACTIONS(5778),
    [anon_sym_PERCENT] = ACTIONS(5780),
    [anon_sym_PIPE_PIPE] = ACTIONS(5780),
    [anon_sym_AMP_AMP] = ACTIONS(5780),
    [anon_sym_PIPE] = ACTIONS(5778),
    [anon_sym_CARET] = ACTIONS(5780),
    [anon_sym_AMP] = ACTIONS(5778),
    [anon_sym_EQ_EQ] = ACTIONS(5780),
    [anon_sym_BANG_EQ] = ACTIONS(5780),
    [anon_sym_GT] = ACTIONS(5778),
    [anon_sym_GT_EQ] = ACTIONS(5780),
    [anon_sym_LT_EQ] = ACTIONS(5778),
    [anon_sym_LT] = ACTIONS(5778),
    [anon_sym_LT_LT] = ACTIONS(5778),
    [anon_sym_GT_GT] = ACTIONS(5780),
    [anon_sym_SEMI] = ACTIONS(5780),
    [anon_sym___extension__] = ACTIONS(5778),
    [anon_sym___global__] = ACTIONS(5778),
    [anon_sym___attribute__] = ACTIONS(5778),
    [anon_sym___attribute] = ACTIONS(5778),
    [anon_sym___based] = ACTIONS(5778),
    [anon_sym_LBRACE] = ACTIONS(5780),
    [anon_sym_RBRACE] = ACTIONS(5780),
    [anon_sym_signed] = ACTIONS(5778),
    [anon_sym_unsigned] = ACTIONS(5778),
    [anon_sym_long] = ACTIONS(5778),
    [anon_sym_short] = ACTIONS(5778),
    [anon_sym_LBRACK] = ACTIONS(5780),
    [anon_sym_RBRACK] = ACTIONS(5780),
    [anon_sym_const] = ACTIONS(5778),
    [anon_sym_constexpr] = ACTIONS(5778),
    [anon_sym_volatile] = ACTIONS(5778),
    [anon_sym_restrict] = ACTIONS(5778),
    [anon_sym___restrict__] = ACTIONS(5778),
    [anon_sym__Atomic] = ACTIONS(5778),
    [anon_sym__Noreturn] = ACTIONS(5778),
    [anon_sym_noreturn] = ACTIONS(5778),
    [anon_sym__Nonnull] = ACTIONS(5778),
    [anon_sym_mutable] = ACTIONS(5778),
    [anon_sym_constinit] = ACTIONS(5778),
    [anon_sym_consteval] = ACTIONS(5778),
    [anon_sym___shared__] = ACTIONS(5778),
    [anon_sym___local__] = ACTIONS(5778),
    [anon_sym___constant__] = ACTIONS(5778),
    [anon_sym___managed__] = ACTIONS(5778),
    [anon_sym___grid_constant__] = ACTIONS(5778),
    [anon_sym_alignas] = ACTIONS(5778),
    [anon_sym__Alignas] = ACTIONS(5778),
    [sym_primitive_type] = ACTIONS(5778),
    [anon_sym_COLON] = ACTIONS(5780),
    [anon_sym_QMARK] = ACTIONS(5780),
    [anon_sym_LT_EQ_GT] = ACTIONS(5780),
    [anon_sym_or] = ACTIONS(5778),
    [anon_sym_and] = ACTIONS(5778),
    [anon_sym_bitor] = ACTIONS(5778),
    [anon_sym_xor] = ACTIONS(5778),
    [anon_sym_bitand] = ACTIONS(5778),
    [anon_sym_not_eq] = ACTIONS(5778),
    [anon_sym_DASH_DASH] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5780),
    [anon_sym_DOT] = ACTIONS(5778),
    [anon_sym_DOT_STAR] = ACTIONS(5780),
    [anon_sym_DASH_GT] = ACTIONS(5780),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5778),
    [anon_sym_decltype] = ACTIONS(5778),
    [anon_sym_final] = ACTIONS(5778),
    [anon_sym_override] = ACTIONS(5778),
    [anon_sym_requires] = ACTIONS(5778),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5780),
  },
  [STATE(2138)] = {
    [sym_identifier] = ACTIONS(5782),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5784),
    [anon_sym_COMMA] = ACTIONS(5784),
    [anon_sym_RPAREN] = ACTIONS(5784),
    [anon_sym_LPAREN2] = ACTIONS(5784),
    [anon_sym_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(5782),
    [anon_sym_STAR] = ACTIONS(5784),
    [anon_sym_SLASH] = ACTIONS(5782),
    [anon_sym_PERCENT] = ACTIONS(5784),
    [anon_sym_PIPE_PIPE] = ACTIONS(5784),
    [anon_sym_AMP_AMP] = ACTIONS(5784),
    [anon_sym_PIPE] = ACTIONS(5782),
    [anon_sym_CARET] = ACTIONS(5784),
    [anon_sym_AMP] = ACTIONS(5782),
    [anon_sym_EQ_EQ] = ACTIONS(5784),
    [anon_sym_BANG_EQ] = ACTIONS(5784),
    [anon_sym_GT] = ACTIONS(5782),
    [anon_sym_GT_EQ] = ACTIONS(5784),
    [anon_sym_LT_EQ] = ACTIONS(5782),
    [anon_sym_LT] = ACTIONS(5782),
    [anon_sym_LT_LT] = ACTIONS(5782),
    [anon_sym_GT_GT] = ACTIONS(5784),
    [anon_sym_SEMI] = ACTIONS(5784),
    [anon_sym___extension__] = ACTIONS(5782),
    [anon_sym___global__] = ACTIONS(5782),
    [anon_sym___attribute__] = ACTIONS(5782),
    [anon_sym___attribute] = ACTIONS(5782),
    [anon_sym___based] = ACTIONS(5782),
    [anon_sym_LBRACE] = ACTIONS(5784),
    [anon_sym_RBRACE] = ACTIONS(5784),
    [anon_sym_signed] = ACTIONS(5782),
    [anon_sym_unsigned] = ACTIONS(5782),
    [anon_sym_long] = ACTIONS(5782),
    [anon_sym_short] = ACTIONS(5782),
    [anon_sym_LBRACK] = ACTIONS(5784),
    [anon_sym_RBRACK] = ACTIONS(5784),
    [anon_sym_const] = ACTIONS(5782),
    [anon_sym_constexpr] = ACTIONS(5782),
    [anon_sym_volatile] = ACTIONS(5782),
    [anon_sym_restrict] = ACTIONS(5782),
    [anon_sym___restrict__] = ACTIONS(5782),
    [anon_sym__Atomic] = ACTIONS(5782),
    [anon_sym__Noreturn] = ACTIONS(5782),
    [anon_sym_noreturn] = ACTIONS(5782),
    [anon_sym__Nonnull] = ACTIONS(5782),
    [anon_sym_mutable] = ACTIONS(5782),
    [anon_sym_constinit] = ACTIONS(5782),
    [anon_sym_consteval] = ACTIONS(5782),
    [anon_sym___shared__] = ACTIONS(5782),
    [anon_sym___local__] = ACTIONS(5782),
    [anon_sym___constant__] = ACTIONS(5782),
    [anon_sym___managed__] = ACTIONS(5782),
    [anon_sym___grid_constant__] = ACTIONS(5782),
    [anon_sym_alignas] = ACTIONS(5782),
    [anon_sym__Alignas] = ACTIONS(5782),
    [sym_primitive_type] = ACTIONS(5782),
    [anon_sym_COLON] = ACTIONS(5784),
    [anon_sym_QMARK] = ACTIONS(5784),
    [anon_sym_LT_EQ_GT] = ACTIONS(5784),
    [anon_sym_or] = ACTIONS(5782),
    [anon_sym_and] = ACTIONS(5782),
    [anon_sym_bitor] = ACTIONS(5782),
    [anon_sym_xor] = ACTIONS(5782),
    [anon_sym_bitand] = ACTIONS(5782),
    [anon_sym_not_eq] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5784),
    [anon_sym_PLUS_PLUS] = ACTIONS(5784),
    [anon_sym_DOT] = ACTIONS(5782),
    [anon_sym_DOT_STAR] = ACTIONS(5784),
    [anon_sym_DASH_GT] = ACTIONS(5784),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5782),
    [anon_sym_decltype] = ACTIONS(5782),
    [anon_sym_final] = ACTIONS(5782),
    [anon_sym_override] = ACTIONS(5782),
    [anon_sym_requires] = ACTIONS(5782),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5784),
  },
  [STATE(2139)] = {
    [sym_identifier] = ACTIONS(5786),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5788),
    [anon_sym_COMMA] = ACTIONS(5788),
    [anon_sym_RPAREN] = ACTIONS(5788),
    [anon_sym_LPAREN2] = ACTIONS(5788),
    [anon_sym_DASH] = ACTIONS(5786),
    [anon_sym_PLUS] = ACTIONS(5786),
    [anon_sym_STAR] = ACTIONS(5788),
    [anon_sym_SLASH] = ACTIONS(5786),
    [anon_sym_PERCENT] = ACTIONS(5788),
    [anon_sym_PIPE_PIPE] = ACTIONS(5788),
    [anon_sym_AMP_AMP] = ACTIONS(5788),
    [anon_sym_PIPE] = ACTIONS(5786),
    [anon_sym_CARET] = ACTIONS(5788),
    [anon_sym_AMP] = ACTIONS(5786),
    [anon_sym_EQ_EQ] = ACTIONS(5788),
    [anon_sym_BANG_EQ] = ACTIONS(5788),
    [anon_sym_GT] = ACTIONS(5786),
    [anon_sym_GT_EQ] = ACTIONS(5788),
    [anon_sym_LT_EQ] = ACTIONS(5786),
    [anon_sym_LT] = ACTIONS(5786),
    [anon_sym_LT_LT] = ACTIONS(5786),
    [anon_sym_GT_GT] = ACTIONS(5788),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym___extension__] = ACTIONS(5786),
    [anon_sym___global__] = ACTIONS(5786),
    [anon_sym___attribute__] = ACTIONS(5786),
    [anon_sym___attribute] = ACTIONS(5786),
    [anon_sym___based] = ACTIONS(5786),
    [anon_sym_LBRACE] = ACTIONS(5788),
    [anon_sym_RBRACE] = ACTIONS(5788),
    [anon_sym_signed] = ACTIONS(5786),
    [anon_sym_unsigned] = ACTIONS(5786),
    [anon_sym_long] = ACTIONS(5786),
    [anon_sym_short] = ACTIONS(5786),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_RBRACK] = ACTIONS(5788),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_constexpr] = ACTIONS(5786),
    [anon_sym_volatile] = ACTIONS(5786),
    [anon_sym_restrict] = ACTIONS(5786),
    [anon_sym___restrict__] = ACTIONS(5786),
    [anon_sym__Atomic] = ACTIONS(5786),
    [anon_sym__Noreturn] = ACTIONS(5786),
    [anon_sym_noreturn] = ACTIONS(5786),
    [anon_sym__Nonnull] = ACTIONS(5786),
    [anon_sym_mutable] = ACTIONS(5786),
    [anon_sym_constinit] = ACTIONS(5786),
    [anon_sym_consteval] = ACTIONS(5786),
    [anon_sym___shared__] = ACTIONS(5786),
    [anon_sym___local__] = ACTIONS(5786),
    [anon_sym___constant__] = ACTIONS(5786),
    [anon_sym___managed__] = ACTIONS(5786),
    [anon_sym___grid_constant__] = ACTIONS(5786),
    [anon_sym_alignas] = ACTIONS(5786),
    [anon_sym__Alignas] = ACTIONS(5786),
    [sym_primitive_type] = ACTIONS(5786),
    [anon_sym_COLON] = ACTIONS(5788),
    [anon_sym_QMARK] = ACTIONS(5788),
    [anon_sym_LT_EQ_GT] = ACTIONS(5788),
    [anon_sym_or] = ACTIONS(5786),
    [anon_sym_and] = ACTIONS(5786),
    [anon_sym_bitor] = ACTIONS(5786),
    [anon_sym_xor] = ACTIONS(5786),
    [anon_sym_bitand] = ACTIONS(5786),
    [anon_sym_not_eq] = ACTIONS(5786),
    [anon_sym_DASH_DASH] = ACTIONS(5788),
    [anon_sym_PLUS_PLUS] = ACTIONS(5788),
    [anon_sym_DOT] = ACTIONS(5786),
    [anon_sym_DOT_STAR] = ACTIONS(5788),
    [anon_sym_DASH_GT] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5786),
    [anon_sym_decltype] = ACTIONS(5786),
    [anon_sym_final] = ACTIONS(5786),
    [anon_sym_override] = ACTIONS(5786),
    [anon_sym_requires] = ACTIONS(5786),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5788),
  },
  [STATE(2140)] = {
    [sym_type_qualifier] = STATE(1738),
    [sym_alignas_qualifier] = STATE(1873),
    [aux_sym__type_definition_type_repeat1] = STATE(1738),
    [aux_sym_sized_type_specifier_repeat1] = STATE(3836),
    [sym_identifier] = ACTIONS(5790),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [aux_sym_preproc_if_token2] = ACTIONS(5173),
    [aux_sym_preproc_else_token1] = ACTIONS(5173),
    [aux_sym_preproc_elif_token1] = ACTIONS(5175),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5173),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5173),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5173),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5173),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5173),
    [anon_sym___extension__] = ACTIONS(5702),
    [anon_sym___global__] = ACTIONS(5702),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5793),
    [anon_sym_unsigned] = ACTIONS(5793),
    [anon_sym_long] = ACTIONS(5793),
    [anon_sym_short] = ACTIONS(5793),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_const] = ACTIONS(5702),
    [anon_sym_constexpr] = ACTIONS(5702),
    [anon_sym_volatile] = ACTIONS(5702),
    [anon_sym_restrict] = ACTIONS(5702),
    [anon_sym___restrict__] = ACTIONS(5702),
    [anon_sym__Atomic] = ACTIONS(5702),
    [anon_sym__Noreturn] = ACTIONS(5702),
    [anon_sym_noreturn] = ACTIONS(5702),
    [anon_sym__Nonnull] = ACTIONS(5702),
    [anon_sym_mutable] = ACTIONS(5702),
    [anon_sym_constinit] = ACTIONS(5702),
    [anon_sym_consteval] = ACTIONS(5702),
    [anon_sym___shared__] = ACTIONS(5702),
    [anon_sym___local__] = ACTIONS(5702),
    [anon_sym___constant__] = ACTIONS(5702),
    [anon_sym___managed__] = ACTIONS(5702),
    [anon_sym___grid_constant__] = ACTIONS(5702),
    [anon_sym_alignas] = ACTIONS(5706),
    [anon_sym__Alignas] = ACTIONS(5706),
    [sym_primitive_type] = ACTIONS(5795),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5173),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
  },
  [STATE(2141)] = {
    [sym_identifier] = ACTIONS(5797),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5799),
    [anon_sym_COMMA] = ACTIONS(5799),
    [anon_sym_RPAREN] = ACTIONS(5799),
    [anon_sym_LPAREN2] = ACTIONS(5799),
    [anon_sym_DASH] = ACTIONS(5797),
    [anon_sym_PLUS] = ACTIONS(5797),
    [anon_sym_STAR] = ACTIONS(5799),
    [anon_sym_SLASH] = ACTIONS(5797),
    [anon_sym_PERCENT] = ACTIONS(5799),
    [anon_sym_PIPE_PIPE] = ACTIONS(5799),
    [anon_sym_AMP_AMP] = ACTIONS(5799),
    [anon_sym_PIPE] = ACTIONS(5797),
    [anon_sym_CARET] = ACTIONS(5799),
    [anon_sym_AMP] = ACTIONS(5797),
    [anon_sym_EQ_EQ] = ACTIONS(5799),
    [anon_sym_BANG_EQ] = ACTIONS(5799),
    [anon_sym_GT] = ACTIONS(5797),
    [anon_sym_GT_EQ] = ACTIONS(5799),
    [anon_sym_LT_EQ] = ACTIONS(5797),
    [anon_sym_LT] = ACTIONS(5797),
    [anon_sym_LT_LT] = ACTIONS(5797),
    [anon_sym_GT_GT] = ACTIONS(5799),
    [anon_sym_SEMI] = ACTIONS(5799),
    [anon_sym___extension__] = ACTIONS(5797),
    [anon_sym___global__] = ACTIONS(5797),
    [anon_sym___attribute__] = ACTIONS(5797),
    [anon_sym___attribute] = ACTIONS(5797),
    [anon_sym___based] = ACTIONS(5797),
    [anon_sym_LBRACE] = ACTIONS(5799),
    [anon_sym_RBRACE] = ACTIONS(5799),
    [anon_sym_signed] = ACTIONS(5797),
    [anon_sym_unsigned] = ACTIONS(5797),
    [anon_sym_long] = ACTIONS(5797),
    [anon_sym_short] = ACTIONS(5797),
    [anon_sym_LBRACK] = ACTIONS(5799),
    [anon_sym_RBRACK] = ACTIONS(5799),
    [anon_sym_const] = ACTIONS(5797),
    [anon_sym_constexpr] = ACTIONS(5797),
    [anon_sym_volatile] = ACTIONS(5797),
    [anon_sym_restrict] = ACTIONS(5797),
    [anon_sym___restrict__] = ACTIONS(5797),
    [anon_sym__Atomic] = ACTIONS(5797),
    [anon_sym__Noreturn] = ACTIONS(5797),
    [anon_sym_noreturn] = ACTIONS(5797),
    [anon_sym__Nonnull] = ACTIONS(5797),
    [anon_sym_mutable] = ACTIONS(5797),
    [anon_sym_constinit] = ACTIONS(5797),
    [anon_sym_consteval] = ACTIONS(5797),
    [anon_sym___shared__] = ACTIONS(5797),
    [anon_sym___local__] = ACTIONS(5797),
    [anon_sym___constant__] = ACTIONS(5797),
    [anon_sym___managed__] = ACTIONS(5797),
    [anon_sym___grid_constant__] = ACTIONS(5797),
    [anon_sym_alignas] = ACTIONS(5797),
    [anon_sym__Alignas] = ACTIONS(5797),
    [sym_primitive_type] = ACTIONS(5797),
    [anon_sym_COLON] = ACTIONS(5799),
    [anon_sym_QMARK] = ACTIONS(5799),
    [anon_sym_LT_EQ_GT] = ACTIONS(5799),
    [anon_sym_or] = ACTIONS(5797),
    [anon_sym_and] = ACTIONS(5797),
    [anon_sym_bitor] = ACTIONS(5797),
    [anon_sym_xor] = ACTIONS(5797),
    [anon_sym_bitand] = ACTIONS(5797),
    [anon_sym_not_eq] = ACTIONS(5797),
    [anon_sym_DASH_DASH] = ACTIONS(5799),
    [anon_sym_PLUS_PLUS] = ACTIONS(5799),
    [anon_sym_DOT] = ACTIONS(5797),
    [anon_sym_DOT_STAR] = ACTIONS(5799),
    [anon_sym_DASH_GT] = ACTIONS(5799),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5797),
    [anon_sym_decltype] = ACTIONS(5797),
    [anon_sym_final] = ACTIONS(5797),
    [anon_sym_override] = ACTIONS(5797),
    [anon_sym_requires] = ACTIONS(5797),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5799),
  },
  [STATE(2142)] = {
    [sym_identifier] = ACTIONS(5801),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5803),
    [anon_sym_COMMA] = ACTIONS(5803),
    [anon_sym_RPAREN] = ACTIONS(5803),
    [anon_sym_LPAREN2] = ACTIONS(5803),
    [anon_sym_DASH] = ACTIONS(5801),
    [anon_sym_PLUS] = ACTIONS(5801),
    [anon_sym_STAR] = ACTIONS(5803),
    [anon_sym_SLASH] = ACTIONS(5801),
    [anon_sym_PERCENT] = ACTIONS(5803),
    [anon_sym_PIPE_PIPE] = ACTIONS(5803),
    [anon_sym_AMP_AMP] = ACTIONS(5803),
    [anon_sym_PIPE] = ACTIONS(5801),
    [anon_sym_CARET] = ACTIONS(5803),
    [anon_sym_AMP] = ACTIONS(5801),
    [anon_sym_EQ_EQ] = ACTIONS(5803),
    [anon_sym_BANG_EQ] = ACTIONS(5803),
    [anon_sym_GT] = ACTIONS(5801),
    [anon_sym_GT_EQ] = ACTIONS(5803),
    [anon_sym_LT_EQ] = ACTIONS(5801),
    [anon_sym_LT] = ACTIONS(5801),
    [anon_sym_LT_LT] = ACTIONS(5801),
    [anon_sym_GT_GT] = ACTIONS(5803),
    [anon_sym_SEMI] = ACTIONS(5803),
    [anon_sym___extension__] = ACTIONS(5801),
    [anon_sym___global__] = ACTIONS(5801),
    [anon_sym___attribute__] = ACTIONS(5801),
    [anon_sym___attribute] = ACTIONS(5801),
    [anon_sym___based] = ACTIONS(5801),
    [anon_sym_LBRACE] = ACTIONS(5803),
    [anon_sym_RBRACE] = ACTIONS(5803),
    [anon_sym_signed] = ACTIONS(5801),
    [anon_sym_unsigned] = ACTIONS(5801),
    [anon_sym_long] = ACTIONS(5801),
    [anon_sym_short] = ACTIONS(5801),
    [anon_sym_LBRACK] = ACTIONS(5803),
    [anon_sym_RBRACK] = ACTIONS(5803),
    [anon_sym_const] = ACTIONS(5801),
    [anon_sym_constexpr] = ACTIONS(5801),
    [anon_sym_volatile] = ACTIONS(5801),
    [anon_sym_restrict] = ACTIONS(5801),
    [anon_sym___restrict__] = ACTIONS(5801),
    [anon_sym__Atomic] = ACTIONS(5801),
    [anon_sym__Noreturn] = ACTIONS(5801),
    [anon_sym_noreturn] = ACTIONS(5801),
    [anon_sym__Nonnull] = ACTIONS(5801),
    [anon_sym_mutable] = ACTIONS(5801),
    [anon_sym_constinit] = ACTIONS(5801),
    [anon_sym_consteval] = ACTIONS(5801),
    [anon_sym___shared__] = ACTIONS(5801),
    [anon_sym___local__] = ACTIONS(5801),
    [anon_sym___constant__] = ACTIONS(5801),
    [anon_sym___managed__] = ACTIONS(5801),
    [anon_sym___grid_constant__] = ACTIONS(5801),
    [anon_sym_alignas] = ACTIONS(5801),
    [anon_sym__Alignas] = ACTIONS(5801),
    [sym_primitive_type] = ACTIONS(5801),
    [anon_sym_COLON] = ACTIONS(5803),
    [anon_sym_QMARK] = ACTIONS(5803),
    [anon_sym_LT_EQ_GT] = ACTIONS(5803),
    [anon_sym_or] = ACTIONS(5801),
    [anon_sym_and] = ACTIONS(5801),
    [anon_sym_bitor] = ACTIONS(5801),
    [anon_sym_xor] = ACTIONS(5801),
    [anon_sym_bitand] = ACTIONS(5801),
    [anon_sym_not_eq] = ACTIONS(5801),
    [anon_sym_DASH_DASH] = ACTIONS(5803),
    [anon_sym_PLUS_PLUS] = ACTIONS(5803),
    [anon_sym_DOT] = ACTIONS(5801),
    [anon_sym_DOT_STAR] = ACTIONS(5803),
    [anon_sym_DASH_GT] = ACTIONS(5803),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5801),
    [anon_sym_decltype] = ACTIONS(5801),
    [anon_sym_final] = ACTIONS(5801),
    [anon_sym_override] = ACTIONS(5801),
    [anon_sym_requires] = ACTIONS(5801),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5803),
  },
  [STATE(2143)] = {
    [sym_identifier] = ACTIONS(5805),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5807),
    [anon_sym_COMMA] = ACTIONS(5807),
    [anon_sym_RPAREN] = ACTIONS(5807),
    [anon_sym_LPAREN2] = ACTIONS(5807),
    [anon_sym_DASH] = ACTIONS(5805),
    [anon_sym_PLUS] = ACTIONS(5805),
    [anon_sym_STAR] = ACTIONS(5807),
    [anon_sym_SLASH] = ACTIONS(5805),
    [anon_sym_PERCENT] = ACTIONS(5807),
    [anon_sym_PIPE_PIPE] = ACTIONS(5807),
    [anon_sym_AMP_AMP] = ACTIONS(5807),
    [anon_sym_PIPE] = ACTIONS(5805),
    [anon_sym_CARET] = ACTIONS(5807),
    [anon_sym_AMP] = ACTIONS(5805),
    [anon_sym_EQ_EQ] = ACTIONS(5807),
    [anon_sym_BANG_EQ] = ACTIONS(5807),
    [anon_sym_GT] = ACTIONS(5805),
    [anon_sym_GT_EQ] = ACTIONS(5807),
    [anon_sym_LT_EQ] = ACTIONS(5805),
    [anon_sym_LT] = ACTIONS(5805),
    [anon_sym_LT_LT] = ACTIONS(5805),
    [anon_sym_GT_GT] = ACTIONS(5807),
    [anon_sym_SEMI] = ACTIONS(5807),
    [anon_sym___extension__] = ACTIONS(5805),
    [anon_sym___global__] = ACTIONS(5805),
    [anon_sym___attribute__] = ACTIONS(5805),
    [anon_sym___attribute] = ACTIONS(5805),
    [anon_sym___based] = ACTIONS(5805),
    [anon_sym_LBRACE] = ACTIONS(5807),
    [anon_sym_RBRACE] = ACTIONS(5807),
    [anon_sym_signed] = ACTIONS(5805),
    [anon_sym_unsigned] = ACTIONS(5805),
    [anon_sym_long] = ACTIONS(5805),
    [anon_sym_short] = ACTIONS(5805),
    [anon_sym_LBRACK] = ACTIONS(5807),
    [anon_sym_RBRACK] = ACTIONS(5807),
    [anon_sym_const] = ACTIONS(5805),
    [anon_sym_constexpr] = ACTIONS(5805),
    [anon_sym_volatile] = ACTIONS(5805),
    [anon_sym_restrict] = ACTIONS(5805),
    [anon_sym___restrict__] = ACTIONS(5805),
    [anon_sym__Atomic] = ACTIONS(5805),
    [anon_sym__Noreturn] = ACTIONS(5805),
    [anon_sym_noreturn] = ACTIONS(5805),
    [anon_sym__Nonnull] = ACTIONS(5805),
    [anon_sym_mutable] = ACTIONS(5805),
    [anon_sym_constinit] = ACTIONS(5805),
    [anon_sym_consteval] = ACTIONS(5805),
    [anon_sym___shared__] = ACTIONS(5805),
    [anon_sym___local__] = ACTIONS(5805),
    [anon_sym___constant__] = ACTIONS(5805),
    [anon_sym___managed__] = ACTIONS(5805),
    [anon_sym___grid_constant__] = ACTIONS(5805),
    [anon_sym_alignas] = ACTIONS(5805),
    [anon_sym__Alignas] = ACTIONS(5805),
    [sym_primitive_type] = ACTIONS(5805),
    [anon_sym_COLON] = ACTIONS(5807),
    [anon_sym_QMARK] = ACTIONS(5807),
    [anon_sym_LT_EQ_GT] = ACTIONS(5807),
    [anon_sym_or] = ACTIONS(5805),
    [anon_sym_and] = ACTIONS(5805),
    [anon_sym_bitor] = ACTIONS(5805),
    [anon_sym_xor] = ACTIONS(5805),
    [anon_sym_bitand] = ACTIONS(5805),
    [anon_sym_not_eq] = ACTIONS(5805),
    [anon_sym_DASH_DASH] = ACTIONS(5807),
    [anon_sym_PLUS_PLUS] = ACTIONS(5807),
    [anon_sym_DOT] = ACTIONS(5805),
    [anon_sym_DOT_STAR] = ACTIONS(5807),
    [anon_sym_DASH_GT] = ACTIONS(5807),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5805),
    [anon_sym_decltype] = ACTIONS(5805),
    [anon_sym_final] = ACTIONS(5805),
    [anon_sym_override] = ACTIONS(5805),
    [anon_sym_requires] = ACTIONS(5805),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5807),
  },
  [STATE(2144)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_TILDE] = ACTIONS(5661),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___device__] = ACTIONS(5659),
    [anon_sym___host__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___forceinline__] = ACTIONS(5659),
    [anon_sym___noinline__] = ACTIONS(5659),
    [anon_sym_virtual] = ACTIONS(5659),
    [anon_sym_extern] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5661),
    [anon_sym___declspec] = ACTIONS(5659),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym___cdecl] = ACTIONS(5659),
    [anon_sym___clrcall] = ACTIONS(5659),
    [anon_sym___stdcall] = ACTIONS(5659),
    [anon_sym___fastcall] = ACTIONS(5659),
    [anon_sym___thiscall] = ACTIONS(5659),
    [anon_sym___vectorcall] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [anon_sym_static] = ACTIONS(5659),
    [anon_sym_EQ] = ACTIONS(5661),
    [anon_sym_register] = ACTIONS(5659),
    [anon_sym_inline] = ACTIONS(5659),
    [anon_sym___inline] = ACTIONS(5659),
    [anon_sym___inline__] = ACTIONS(5659),
    [anon_sym___forceinline] = ACTIONS(5659),
    [anon_sym_thread_local] = ACTIONS(5659),
    [anon_sym___thread] = ACTIONS(5659),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_asm] = ACTIONS(5659),
    [anon_sym___asm__] = ACTIONS(5659),
    [anon_sym___asm] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [anon_sym_template] = ACTIONS(5659),
    [anon_sym_GT2] = ACTIONS(5661),
    [anon_sym_operator] = ACTIONS(5659),
    [anon_sym_try] = ACTIONS(5659),
    [anon_sym_requires] = ACTIONS(5659),
    [anon_sym___launch_bounds__] = ACTIONS(5659),
  },
  [STATE(2145)] = {
    [sym_identifier] = ACTIONS(5809),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5811),
    [anon_sym_COMMA] = ACTIONS(5811),
    [anon_sym_RPAREN] = ACTIONS(5811),
    [anon_sym_LPAREN2] = ACTIONS(5811),
    [anon_sym_DASH] = ACTIONS(5809),
    [anon_sym_PLUS] = ACTIONS(5809),
    [anon_sym_STAR] = ACTIONS(5811),
    [anon_sym_SLASH] = ACTIONS(5809),
    [anon_sym_PERCENT] = ACTIONS(5811),
    [anon_sym_PIPE_PIPE] = ACTIONS(5811),
    [anon_sym_AMP_AMP] = ACTIONS(5811),
    [anon_sym_PIPE] = ACTIONS(5809),
    [anon_sym_CARET] = ACTIONS(5811),
    [anon_sym_AMP] = ACTIONS(5809),
    [anon_sym_EQ_EQ] = ACTIONS(5811),
    [anon_sym_BANG_EQ] = ACTIONS(5811),
    [anon_sym_GT] = ACTIONS(5809),
    [anon_sym_GT_EQ] = ACTIONS(5811),
    [anon_sym_LT_EQ] = ACTIONS(5809),
    [anon_sym_LT] = ACTIONS(5809),
    [anon_sym_LT_LT] = ACTIONS(5809),
    [anon_sym_GT_GT] = ACTIONS(5811),
    [anon_sym_SEMI] = ACTIONS(5811),
    [anon_sym___extension__] = ACTIONS(5809),
    [anon_sym___global__] = ACTIONS(5809),
    [anon_sym___attribute__] = ACTIONS(5809),
    [anon_sym___attribute] = ACTIONS(5809),
    [anon_sym___based] = ACTIONS(5809),
    [anon_sym_LBRACE] = ACTIONS(5811),
    [anon_sym_RBRACE] = ACTIONS(5811),
    [anon_sym_signed] = ACTIONS(5809),
    [anon_sym_unsigned] = ACTIONS(5809),
    [anon_sym_long] = ACTIONS(5809),
    [anon_sym_short] = ACTIONS(5809),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [anon_sym_RBRACK] = ACTIONS(5811),
    [anon_sym_const] = ACTIONS(5809),
    [anon_sym_constexpr] = ACTIONS(5809),
    [anon_sym_volatile] = ACTIONS(5809),
    [anon_sym_restrict] = ACTIONS(5809),
    [anon_sym___restrict__] = ACTIONS(5809),
    [anon_sym__Atomic] = ACTIONS(5809),
    [anon_sym__Noreturn] = ACTIONS(5809),
    [anon_sym_noreturn] = ACTIONS(5809),
    [anon_sym__Nonnull] = ACTIONS(5809),
    [anon_sym_mutable] = ACTIONS(5809),
    [anon_sym_constinit] = ACTIONS(5809),
    [anon_sym_consteval] = ACTIONS(5809),
    [anon_sym___shared__] = ACTIONS(5809),
    [anon_sym___local__] = ACTIONS(5809),
    [anon_sym___constant__] = ACTIONS(5809),
    [anon_sym___managed__] = ACTIONS(5809),
    [anon_sym___grid_constant__] = ACTIONS(5809),
    [anon_sym_alignas] = ACTIONS(5809),
    [anon_sym__Alignas] = ACTIONS(5809),
    [sym_primitive_type] = ACTIONS(5809),
    [anon_sym_COLON] = ACTIONS(5811),
    [anon_sym_QMARK] = ACTIONS(5811),
    [anon_sym_LT_EQ_GT] = ACTIONS(5811),
    [anon_sym_or] = ACTIONS(5809),
    [anon_sym_and] = ACTIONS(5809),
    [anon_sym_bitor] = ACTIONS(5809),
    [anon_sym_xor] = ACTIONS(5809),
    [anon_sym_bitand] = ACTIONS(5809),
    [anon_sym_not_eq] = ACTIONS(5809),
    [anon_sym_DASH_DASH] = ACTIONS(5811),
    [anon_sym_PLUS_PLUS] = ACTIONS(5811),
    [anon_sym_DOT] = ACTIONS(5809),
    [anon_sym_DOT_STAR] = ACTIONS(5811),
    [anon_sym_DASH_GT] = ACTIONS(5811),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5809),
    [anon_sym_decltype] = ACTIONS(5809),
    [anon_sym_final] = ACTIONS(5809),
    [anon_sym_override] = ACTIONS(5809),
    [anon_sym_requires] = ACTIONS(5809),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5811),
  },
  [STATE(2146)] = {
    [sym_identifier] = ACTIONS(5813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5815),
    [anon_sym_COMMA] = ACTIONS(5815),
    [anon_sym_RPAREN] = ACTIONS(5815),
    [anon_sym_LPAREN2] = ACTIONS(5815),
    [anon_sym_DASH] = ACTIONS(5813),
    [anon_sym_PLUS] = ACTIONS(5813),
    [anon_sym_STAR] = ACTIONS(5815),
    [anon_sym_SLASH] = ACTIONS(5813),
    [anon_sym_PERCENT] = ACTIONS(5815),
    [anon_sym_PIPE_PIPE] = ACTIONS(5815),
    [anon_sym_AMP_AMP] = ACTIONS(5815),
    [anon_sym_PIPE] = ACTIONS(5813),
    [anon_sym_CARET] = ACTIONS(5815),
    [anon_sym_AMP] = ACTIONS(5813),
    [anon_sym_EQ_EQ] = ACTIONS(5815),
    [anon_sym_BANG_EQ] = ACTIONS(5815),
    [anon_sym_GT] = ACTIONS(5813),
    [anon_sym_GT_EQ] = ACTIONS(5815),
    [anon_sym_LT_EQ] = ACTIONS(5813),
    [anon_sym_LT] = ACTIONS(5813),
    [anon_sym_LT_LT] = ACTIONS(5813),
    [anon_sym_GT_GT] = ACTIONS(5815),
    [anon_sym_SEMI] = ACTIONS(5815),
    [anon_sym___extension__] = ACTIONS(5813),
    [anon_sym___global__] = ACTIONS(5813),
    [anon_sym___attribute__] = ACTIONS(5813),
    [anon_sym___attribute] = ACTIONS(5813),
    [anon_sym___based] = ACTIONS(5813),
    [anon_sym_LBRACE] = ACTIONS(5815),
    [anon_sym_RBRACE] = ACTIONS(5815),
    [anon_sym_signed] = ACTIONS(5813),
    [anon_sym_unsigned] = ACTIONS(5813),
    [anon_sym_long] = ACTIONS(5813),
    [anon_sym_short] = ACTIONS(5813),
    [anon_sym_LBRACK] = ACTIONS(5815),
    [anon_sym_RBRACK] = ACTIONS(5815),
    [anon_sym_const] = ACTIONS(5813),
    [anon_sym_constexpr] = ACTIONS(5813),
    [anon_sym_volatile] = ACTIONS(5813),
    [anon_sym_restrict] = ACTIONS(5813),
    [anon_sym___restrict__] = ACTIONS(5813),
    [anon_sym__Atomic] = ACTIONS(5813),
    [anon_sym__Noreturn] = ACTIONS(5813),
    [anon_sym_noreturn] = ACTIONS(5813),
    [anon_sym__Nonnull] = ACTIONS(5813),
    [anon_sym_mutable] = ACTIONS(5813),
    [anon_sym_constinit] = ACTIONS(5813),
    [anon_sym_consteval] = ACTIONS(5813),
    [anon_sym___shared__] = ACTIONS(5813),
    [anon_sym___local__] = ACTIONS(5813),
    [anon_sym___constant__] = ACTIONS(5813),
    [anon_sym___managed__] = ACTIONS(5813),
    [anon_sym___grid_constant__] = ACTIONS(5813),
    [anon_sym_alignas] = ACTIONS(5813),
    [anon_sym__Alignas] = ACTIONS(5813),
    [sym_primitive_type] = ACTIONS(5813),
    [anon_sym_COLON] = ACTIONS(5815),
    [anon_sym_QMARK] = ACTIONS(5815),
    [anon_sym_LT_EQ_GT] = ACTIONS(5815),
    [anon_sym_or] = ACTIONS(5813),
    [anon_sym_and] = ACTIONS(5813),
    [anon_sym_bitor] = ACTIONS(5813),
    [anon_sym_xor] = ACTIONS(5813),
    [anon_sym_bitand] = ACTIONS(5813),
    [anon_sym_not_eq] = ACTIONS(5813),
    [anon_sym_DASH_DASH] = ACTIONS(5815),
    [anon_sym_PLUS_PLUS] = ACTIONS(5815),
    [anon_sym_DOT] = ACTIONS(5813),
    [anon_sym_DOT_STAR] = ACTIONS(5815),
    [anon_sym_DASH_GT] = ACTIONS(5815),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5813),
    [anon_sym_decltype] = ACTIONS(5813),
    [anon_sym_final] = ACTIONS(5813),
    [anon_sym_override] = ACTIONS(5813),
    [anon_sym_requires] = ACTIONS(5813),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5815),
  },
  [STATE(2147)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4555),
    [anon_sym_COMMA] = ACTIONS(4555),
    [anon_sym_RPAREN] = ACTIONS(4557),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym___extension__] = ACTIONS(4560),
    [anon_sym___global__] = ACTIONS(4560),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4557),
    [anon_sym_EQ] = ACTIONS(4562),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4560),
    [anon_sym_volatile] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym___restrict__] = ACTIONS(4560),
    [anon_sym__Atomic] = ACTIONS(4560),
    [anon_sym__Noreturn] = ACTIONS(4560),
    [anon_sym_noreturn] = ACTIONS(4560),
    [anon_sym__Nonnull] = ACTIONS(4560),
    [anon_sym_mutable] = ACTIONS(4560),
    [anon_sym_constinit] = ACTIONS(4560),
    [anon_sym_consteval] = ACTIONS(4560),
    [anon_sym___shared__] = ACTIONS(4560),
    [anon_sym___local__] = ACTIONS(4560),
    [anon_sym___constant__] = ACTIONS(4560),
    [anon_sym___managed__] = ACTIONS(4560),
    [anon_sym___grid_constant__] = ACTIONS(4560),
    [anon_sym_alignas] = ACTIONS(4560),
    [anon_sym__Alignas] = ACTIONS(4560),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4555),
    [anon_sym_or_eq] = ACTIONS(4555),
    [anon_sym_xor_eq] = ACTIONS(4555),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4555),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4555),
    [anon_sym_not_eq] = ACTIONS(4555),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4562),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4560),
    [anon_sym_decltype] = ACTIONS(4560),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4555),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
  },
  [STATE(2148)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5752),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5752),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5752),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___extension__] = ACTIONS(5750),
    [anon_sym___global__] = ACTIONS(5750),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym___based] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_RBRACE] = ACTIONS(5752),
    [anon_sym_signed] = ACTIONS(5750),
    [anon_sym_unsigned] = ACTIONS(5750),
    [anon_sym_long] = ACTIONS(5750),
    [anon_sym_short] = ACTIONS(5750),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_RBRACK] = ACTIONS(5752),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5750),
    [anon_sym_volatile] = ACTIONS(5750),
    [anon_sym_restrict] = ACTIONS(5750),
    [anon_sym___restrict__] = ACTIONS(5750),
    [anon_sym__Atomic] = ACTIONS(5750),
    [anon_sym__Noreturn] = ACTIONS(5750),
    [anon_sym_noreturn] = ACTIONS(5750),
    [anon_sym__Nonnull] = ACTIONS(5750),
    [anon_sym_mutable] = ACTIONS(5750),
    [anon_sym_constinit] = ACTIONS(5750),
    [anon_sym_consteval] = ACTIONS(5750),
    [anon_sym___shared__] = ACTIONS(5750),
    [anon_sym___local__] = ACTIONS(5750),
    [anon_sym___constant__] = ACTIONS(5750),
    [anon_sym___managed__] = ACTIONS(5750),
    [anon_sym___grid_constant__] = ACTIONS(5750),
    [anon_sym_alignas] = ACTIONS(5750),
    [anon_sym__Alignas] = ACTIONS(5750),
    [sym_primitive_type] = ACTIONS(5750),
    [anon_sym_COLON] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5750),
    [anon_sym_and] = ACTIONS(5750),
    [anon_sym_bitor] = ACTIONS(5750),
    [anon_sym_xor] = ACTIONS(5750),
    [anon_sym_bitand] = ACTIONS(5750),
    [anon_sym_not_eq] = ACTIONS(5750),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [anon_sym_final] = ACTIONS(5750),
    [anon_sym_override] = ACTIONS(5750),
    [anon_sym_requires] = ACTIONS(5750),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2149)] = {
    [sym_identifier] = ACTIONS(5817),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5819),
    [anon_sym_COMMA] = ACTIONS(5819),
    [anon_sym_RPAREN] = ACTIONS(5819),
    [anon_sym_LPAREN2] = ACTIONS(5819),
    [anon_sym_DASH] = ACTIONS(5817),
    [anon_sym_PLUS] = ACTIONS(5817),
    [anon_sym_STAR] = ACTIONS(5819),
    [anon_sym_SLASH] = ACTIONS(5817),
    [anon_sym_PERCENT] = ACTIONS(5819),
    [anon_sym_PIPE_PIPE] = ACTIONS(5819),
    [anon_sym_AMP_AMP] = ACTIONS(5819),
    [anon_sym_PIPE] = ACTIONS(5817),
    [anon_sym_CARET] = ACTIONS(5819),
    [anon_sym_AMP] = ACTIONS(5817),
    [anon_sym_EQ_EQ] = ACTIONS(5819),
    [anon_sym_BANG_EQ] = ACTIONS(5819),
    [anon_sym_GT] = ACTIONS(5817),
    [anon_sym_GT_EQ] = ACTIONS(5819),
    [anon_sym_LT_EQ] = ACTIONS(5817),
    [anon_sym_LT] = ACTIONS(5817),
    [anon_sym_LT_LT] = ACTIONS(5817),
    [anon_sym_GT_GT] = ACTIONS(5819),
    [anon_sym_SEMI] = ACTIONS(5819),
    [anon_sym___extension__] = ACTIONS(5817),
    [anon_sym___global__] = ACTIONS(5817),
    [anon_sym___attribute__] = ACTIONS(5817),
    [anon_sym___attribute] = ACTIONS(5817),
    [anon_sym___based] = ACTIONS(5817),
    [anon_sym_LBRACE] = ACTIONS(5819),
    [anon_sym_RBRACE] = ACTIONS(5819),
    [anon_sym_signed] = ACTIONS(5817),
    [anon_sym_unsigned] = ACTIONS(5817),
    [anon_sym_long] = ACTIONS(5817),
    [anon_sym_short] = ACTIONS(5817),
    [anon_sym_LBRACK] = ACTIONS(5819),
    [anon_sym_RBRACK] = ACTIONS(5819),
    [anon_sym_const] = ACTIONS(5817),
    [anon_sym_constexpr] = ACTIONS(5817),
    [anon_sym_volatile] = ACTIONS(5817),
    [anon_sym_restrict] = ACTIONS(5817),
    [anon_sym___restrict__] = ACTIONS(5817),
    [anon_sym__Atomic] = ACTIONS(5817),
    [anon_sym__Noreturn] = ACTIONS(5817),
    [anon_sym_noreturn] = ACTIONS(5817),
    [anon_sym__Nonnull] = ACTIONS(5817),
    [anon_sym_mutable] = ACTIONS(5817),
    [anon_sym_constinit] = ACTIONS(5817),
    [anon_sym_consteval] = ACTIONS(5817),
    [anon_sym___shared__] = ACTIONS(5817),
    [anon_sym___local__] = ACTIONS(5817),
    [anon_sym___constant__] = ACTIONS(5817),
    [anon_sym___managed__] = ACTIONS(5817),
    [anon_sym___grid_constant__] = ACTIONS(5817),
    [anon_sym_alignas] = ACTIONS(5817),
    [anon_sym__Alignas] = ACTIONS(5817),
    [sym_primitive_type] = ACTIONS(5817),
    [anon_sym_COLON] = ACTIONS(5819),
    [anon_sym_QMARK] = ACTIONS(5819),
    [anon_sym_LT_EQ_GT] = ACTIONS(5819),
    [anon_sym_or] = ACTIONS(5817),
    [anon_sym_and] = ACTIONS(5817),
    [anon_sym_bitor] = ACTIONS(5817),
    [anon_sym_xor] = ACTIONS(5817),
    [anon_sym_bitand] = ACTIONS(5817),
    [anon_sym_not_eq] = ACTIONS(5817),
    [anon_sym_DASH_DASH] = ACTIONS(5819),
    [anon_sym_PLUS_PLUS] = ACTIONS(5819),
    [anon_sym_DOT] = ACTIONS(5817),
    [anon_sym_DOT_STAR] = ACTIONS(5819),
    [anon_sym_DASH_GT] = ACTIONS(5819),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5817),
    [anon_sym_decltype] = ACTIONS(5817),
    [anon_sym_final] = ACTIONS(5817),
    [anon_sym_override] = ACTIONS(5817),
    [anon_sym_requires] = ACTIONS(5817),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5819),
  },
  [STATE(2150)] = {
    [sym_identifier] = ACTIONS(5665),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5667),
    [anon_sym_COMMA] = ACTIONS(5667),
    [anon_sym_RPAREN] = ACTIONS(5667),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_TILDE] = ACTIONS(5667),
    [anon_sym_STAR] = ACTIONS(5667),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_AMP] = ACTIONS(5665),
    [anon_sym_SEMI] = ACTIONS(5667),
    [anon_sym___extension__] = ACTIONS(5665),
    [anon_sym___device__] = ACTIONS(5665),
    [anon_sym___host__] = ACTIONS(5665),
    [anon_sym___global__] = ACTIONS(5665),
    [anon_sym___forceinline__] = ACTIONS(5665),
    [anon_sym___noinline__] = ACTIONS(5665),
    [anon_sym_virtual] = ACTIONS(5665),
    [anon_sym_extern] = ACTIONS(5665),
    [anon_sym___attribute__] = ACTIONS(5665),
    [anon_sym___attribute] = ACTIONS(5665),
    [anon_sym_COLON_COLON] = ACTIONS(5667),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5667),
    [anon_sym___declspec] = ACTIONS(5665),
    [anon_sym___based] = ACTIONS(5665),
    [anon_sym___cdecl] = ACTIONS(5665),
    [anon_sym___clrcall] = ACTIONS(5665),
    [anon_sym___stdcall] = ACTIONS(5665),
    [anon_sym___fastcall] = ACTIONS(5665),
    [anon_sym___thiscall] = ACTIONS(5665),
    [anon_sym___vectorcall] = ACTIONS(5665),
    [anon_sym_LBRACE] = ACTIONS(5667),
    [anon_sym_LBRACK] = ACTIONS(5665),
    [anon_sym_static] = ACTIONS(5665),
    [anon_sym_EQ] = ACTIONS(5667),
    [anon_sym_register] = ACTIONS(5665),
    [anon_sym_inline] = ACTIONS(5665),
    [anon_sym___inline] = ACTIONS(5665),
    [anon_sym___inline__] = ACTIONS(5665),
    [anon_sym___forceinline] = ACTIONS(5665),
    [anon_sym_thread_local] = ACTIONS(5665),
    [anon_sym___thread] = ACTIONS(5665),
    [anon_sym_const] = ACTIONS(5665),
    [anon_sym_constexpr] = ACTIONS(5665),
    [anon_sym_volatile] = ACTIONS(5665),
    [anon_sym_restrict] = ACTIONS(5665),
    [anon_sym___restrict__] = ACTIONS(5665),
    [anon_sym__Atomic] = ACTIONS(5665),
    [anon_sym__Noreturn] = ACTIONS(5665),
    [anon_sym_noreturn] = ACTIONS(5665),
    [anon_sym__Nonnull] = ACTIONS(5665),
    [anon_sym_mutable] = ACTIONS(5665),
    [anon_sym_constinit] = ACTIONS(5665),
    [anon_sym_consteval] = ACTIONS(5665),
    [anon_sym___shared__] = ACTIONS(5665),
    [anon_sym___local__] = ACTIONS(5665),
    [anon_sym___constant__] = ACTIONS(5665),
    [anon_sym___managed__] = ACTIONS(5665),
    [anon_sym___grid_constant__] = ACTIONS(5665),
    [anon_sym_alignas] = ACTIONS(5665),
    [anon_sym__Alignas] = ACTIONS(5665),
    [anon_sym_COLON] = ACTIONS(5665),
    [anon_sym_or] = ACTIONS(5665),
    [anon_sym_and] = ACTIONS(5665),
    [anon_sym_asm] = ACTIONS(5665),
    [anon_sym___asm__] = ACTIONS(5665),
    [anon_sym___asm] = ACTIONS(5665),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5665),
    [anon_sym_decltype] = ACTIONS(5665),
    [anon_sym_final] = ACTIONS(5665),
    [anon_sym_override] = ACTIONS(5665),
    [anon_sym_template] = ACTIONS(5665),
    [anon_sym_GT2] = ACTIONS(5667),
    [anon_sym_operator] = ACTIONS(5665),
    [anon_sym_try] = ACTIONS(5665),
    [anon_sym_requires] = ACTIONS(5665),
    [anon_sym___launch_bounds__] = ACTIONS(5665),
  },
  [STATE(2151)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5752),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5752),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5752),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___extension__] = ACTIONS(5750),
    [anon_sym___global__] = ACTIONS(5750),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym___based] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_RBRACE] = ACTIONS(5752),
    [anon_sym_signed] = ACTIONS(5750),
    [anon_sym_unsigned] = ACTIONS(5750),
    [anon_sym_long] = ACTIONS(5750),
    [anon_sym_short] = ACTIONS(5750),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_RBRACK] = ACTIONS(5752),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5750),
    [anon_sym_volatile] = ACTIONS(5750),
    [anon_sym_restrict] = ACTIONS(5750),
    [anon_sym___restrict__] = ACTIONS(5750),
    [anon_sym__Atomic] = ACTIONS(5750),
    [anon_sym__Noreturn] = ACTIONS(5750),
    [anon_sym_noreturn] = ACTIONS(5750),
    [anon_sym__Nonnull] = ACTIONS(5750),
    [anon_sym_mutable] = ACTIONS(5750),
    [anon_sym_constinit] = ACTIONS(5750),
    [anon_sym_consteval] = ACTIONS(5750),
    [anon_sym___shared__] = ACTIONS(5750),
    [anon_sym___local__] = ACTIONS(5750),
    [anon_sym___constant__] = ACTIONS(5750),
    [anon_sym___managed__] = ACTIONS(5750),
    [anon_sym___grid_constant__] = ACTIONS(5750),
    [anon_sym_alignas] = ACTIONS(5750),
    [anon_sym__Alignas] = ACTIONS(5750),
    [sym_primitive_type] = ACTIONS(5750),
    [anon_sym_COLON] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5750),
    [anon_sym_and] = ACTIONS(5750),
    [anon_sym_bitor] = ACTIONS(5750),
    [anon_sym_xor] = ACTIONS(5750),
    [anon_sym_bitand] = ACTIONS(5750),
    [anon_sym_not_eq] = ACTIONS(5750),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [anon_sym_final] = ACTIONS(5750),
    [anon_sym_override] = ACTIONS(5750),
    [anon_sym_requires] = ACTIONS(5750),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2152)] = {
    [sym_identifier] = ACTIONS(5821),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5823),
    [anon_sym_COMMA] = ACTIONS(5823),
    [anon_sym_RPAREN] = ACTIONS(5823),
    [anon_sym_LPAREN2] = ACTIONS(5823),
    [anon_sym_DASH] = ACTIONS(5821),
    [anon_sym_PLUS] = ACTIONS(5821),
    [anon_sym_STAR] = ACTIONS(5823),
    [anon_sym_SLASH] = ACTIONS(5821),
    [anon_sym_PERCENT] = ACTIONS(5823),
    [anon_sym_PIPE_PIPE] = ACTIONS(5823),
    [anon_sym_AMP_AMP] = ACTIONS(5823),
    [anon_sym_PIPE] = ACTIONS(5821),
    [anon_sym_CARET] = ACTIONS(5823),
    [anon_sym_AMP] = ACTIONS(5821),
    [anon_sym_EQ_EQ] = ACTIONS(5823),
    [anon_sym_BANG_EQ] = ACTIONS(5823),
    [anon_sym_GT] = ACTIONS(5821),
    [anon_sym_GT_EQ] = ACTIONS(5823),
    [anon_sym_LT_EQ] = ACTIONS(5821),
    [anon_sym_LT] = ACTIONS(5821),
    [anon_sym_LT_LT] = ACTIONS(5821),
    [anon_sym_GT_GT] = ACTIONS(5823),
    [anon_sym_SEMI] = ACTIONS(5823),
    [anon_sym___extension__] = ACTIONS(5821),
    [anon_sym___global__] = ACTIONS(5821),
    [anon_sym___attribute__] = ACTIONS(5821),
    [anon_sym___attribute] = ACTIONS(5821),
    [anon_sym___based] = ACTIONS(5821),
    [anon_sym_LBRACE] = ACTIONS(5823),
    [anon_sym_RBRACE] = ACTIONS(5823),
    [anon_sym_signed] = ACTIONS(5821),
    [anon_sym_unsigned] = ACTIONS(5821),
    [anon_sym_long] = ACTIONS(5821),
    [anon_sym_short] = ACTIONS(5821),
    [anon_sym_LBRACK] = ACTIONS(5823),
    [anon_sym_RBRACK] = ACTIONS(5823),
    [anon_sym_const] = ACTIONS(5821),
    [anon_sym_constexpr] = ACTIONS(5821),
    [anon_sym_volatile] = ACTIONS(5821),
    [anon_sym_restrict] = ACTIONS(5821),
    [anon_sym___restrict__] = ACTIONS(5821),
    [anon_sym__Atomic] = ACTIONS(5821),
    [anon_sym__Noreturn] = ACTIONS(5821),
    [anon_sym_noreturn] = ACTIONS(5821),
    [anon_sym__Nonnull] = ACTIONS(5821),
    [anon_sym_mutable] = ACTIONS(5821),
    [anon_sym_constinit] = ACTIONS(5821),
    [anon_sym_consteval] = ACTIONS(5821),
    [anon_sym___shared__] = ACTIONS(5821),
    [anon_sym___local__] = ACTIONS(5821),
    [anon_sym___constant__] = ACTIONS(5821),
    [anon_sym___managed__] = ACTIONS(5821),
    [anon_sym___grid_constant__] = ACTIONS(5821),
    [anon_sym_alignas] = ACTIONS(5821),
    [anon_sym__Alignas] = ACTIONS(5821),
    [sym_primitive_type] = ACTIONS(5821),
    [anon_sym_COLON] = ACTIONS(5823),
    [anon_sym_QMARK] = ACTIONS(5823),
    [anon_sym_LT_EQ_GT] = ACTIONS(5823),
    [anon_sym_or] = ACTIONS(5821),
    [anon_sym_and] = ACTIONS(5821),
    [anon_sym_bitor] = ACTIONS(5821),
    [anon_sym_xor] = ACTIONS(5821),
    [anon_sym_bitand] = ACTIONS(5821),
    [anon_sym_not_eq] = ACTIONS(5821),
    [anon_sym_DASH_DASH] = ACTIONS(5823),
    [anon_sym_PLUS_PLUS] = ACTIONS(5823),
    [anon_sym_DOT] = ACTIONS(5821),
    [anon_sym_DOT_STAR] = ACTIONS(5823),
    [anon_sym_DASH_GT] = ACTIONS(5823),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5821),
    [anon_sym_decltype] = ACTIONS(5821),
    [anon_sym_final] = ACTIONS(5821),
    [anon_sym_override] = ACTIONS(5821),
    [anon_sym_requires] = ACTIONS(5821),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5823),
  },
  [STATE(2153)] = {
    [sym_identifier] = ACTIONS(5825),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5827),
    [anon_sym_COMMA] = ACTIONS(5827),
    [anon_sym_RPAREN] = ACTIONS(5827),
    [anon_sym_LPAREN2] = ACTIONS(5827),
    [anon_sym_DASH] = ACTIONS(5825),
    [anon_sym_PLUS] = ACTIONS(5825),
    [anon_sym_STAR] = ACTIONS(5827),
    [anon_sym_SLASH] = ACTIONS(5825),
    [anon_sym_PERCENT] = ACTIONS(5827),
    [anon_sym_PIPE_PIPE] = ACTIONS(5827),
    [anon_sym_AMP_AMP] = ACTIONS(5827),
    [anon_sym_PIPE] = ACTIONS(5825),
    [anon_sym_CARET] = ACTIONS(5827),
    [anon_sym_AMP] = ACTIONS(5825),
    [anon_sym_EQ_EQ] = ACTIONS(5827),
    [anon_sym_BANG_EQ] = ACTIONS(5827),
    [anon_sym_GT] = ACTIONS(5825),
    [anon_sym_GT_EQ] = ACTIONS(5827),
    [anon_sym_LT_EQ] = ACTIONS(5825),
    [anon_sym_LT] = ACTIONS(5825),
    [anon_sym_LT_LT] = ACTIONS(5825),
    [anon_sym_GT_GT] = ACTIONS(5827),
    [anon_sym_SEMI] = ACTIONS(5827),
    [anon_sym___extension__] = ACTIONS(5825),
    [anon_sym___global__] = ACTIONS(5825),
    [anon_sym___attribute__] = ACTIONS(5825),
    [anon_sym___attribute] = ACTIONS(5825),
    [anon_sym___based] = ACTIONS(5825),
    [anon_sym_LBRACE] = ACTIONS(5827),
    [anon_sym_RBRACE] = ACTIONS(5827),
    [anon_sym_signed] = ACTIONS(5825),
    [anon_sym_unsigned] = ACTIONS(5825),
    [anon_sym_long] = ACTIONS(5825),
    [anon_sym_short] = ACTIONS(5825),
    [anon_sym_LBRACK] = ACTIONS(5827),
    [anon_sym_RBRACK] = ACTIONS(5827),
    [anon_sym_const] = ACTIONS(5825),
    [anon_sym_constexpr] = ACTIONS(5825),
    [anon_sym_volatile] = ACTIONS(5825),
    [anon_sym_restrict] = ACTIONS(5825),
    [anon_sym___restrict__] = ACTIONS(5825),
    [anon_sym__Atomic] = ACTIONS(5825),
    [anon_sym__Noreturn] = ACTIONS(5825),
    [anon_sym_noreturn] = ACTIONS(5825),
    [anon_sym__Nonnull] = ACTIONS(5825),
    [anon_sym_mutable] = ACTIONS(5825),
    [anon_sym_constinit] = ACTIONS(5825),
    [anon_sym_consteval] = ACTIONS(5825),
    [anon_sym___shared__] = ACTIONS(5825),
    [anon_sym___local__] = ACTIONS(5825),
    [anon_sym___constant__] = ACTIONS(5825),
    [anon_sym___managed__] = ACTIONS(5825),
    [anon_sym___grid_constant__] = ACTIONS(5825),
    [anon_sym_alignas] = ACTIONS(5825),
    [anon_sym__Alignas] = ACTIONS(5825),
    [sym_primitive_type] = ACTIONS(5825),
    [anon_sym_COLON] = ACTIONS(5827),
    [anon_sym_QMARK] = ACTIONS(5827),
    [anon_sym_LT_EQ_GT] = ACTIONS(5827),
    [anon_sym_or] = ACTIONS(5825),
    [anon_sym_and] = ACTIONS(5825),
    [anon_sym_bitor] = ACTIONS(5825),
    [anon_sym_xor] = ACTIONS(5825),
    [anon_sym_bitand] = ACTIONS(5825),
    [anon_sym_not_eq] = ACTIONS(5825),
    [anon_sym_DASH_DASH] = ACTIONS(5827),
    [anon_sym_PLUS_PLUS] = ACTIONS(5827),
    [anon_sym_DOT] = ACTIONS(5825),
    [anon_sym_DOT_STAR] = ACTIONS(5827),
    [anon_sym_DASH_GT] = ACTIONS(5827),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5825),
    [anon_sym_decltype] = ACTIONS(5825),
    [anon_sym_final] = ACTIONS(5825),
    [anon_sym_override] = ACTIONS(5825),
    [anon_sym_requires] = ACTIONS(5825),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5827),
  },
  [STATE(2154)] = {
    [sym_identifier] = ACTIONS(5696),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5698),
    [anon_sym_COMMA] = ACTIONS(5698),
    [anon_sym_RPAREN] = ACTIONS(5698),
    [anon_sym_LPAREN2] = ACTIONS(5698),
    [anon_sym_DASH] = ACTIONS(5696),
    [anon_sym_PLUS] = ACTIONS(5696),
    [anon_sym_STAR] = ACTIONS(5698),
    [anon_sym_SLASH] = ACTIONS(5696),
    [anon_sym_PERCENT] = ACTIONS(5698),
    [anon_sym_PIPE_PIPE] = ACTIONS(5698),
    [anon_sym_AMP_AMP] = ACTIONS(5698),
    [anon_sym_PIPE] = ACTIONS(5696),
    [anon_sym_CARET] = ACTIONS(5698),
    [anon_sym_AMP] = ACTIONS(5696),
    [anon_sym_EQ_EQ] = ACTIONS(5698),
    [anon_sym_BANG_EQ] = ACTIONS(5698),
    [anon_sym_GT] = ACTIONS(5696),
    [anon_sym_GT_EQ] = ACTIONS(5698),
    [anon_sym_LT_EQ] = ACTIONS(5696),
    [anon_sym_LT] = ACTIONS(5696),
    [anon_sym_LT_LT] = ACTIONS(5696),
    [anon_sym_GT_GT] = ACTIONS(5698),
    [anon_sym_SEMI] = ACTIONS(5698),
    [anon_sym___extension__] = ACTIONS(5696),
    [anon_sym___global__] = ACTIONS(5696),
    [anon_sym___attribute__] = ACTIONS(5696),
    [anon_sym___attribute] = ACTIONS(5696),
    [anon_sym___based] = ACTIONS(5696),
    [anon_sym_LBRACE] = ACTIONS(5698),
    [anon_sym_RBRACE] = ACTIONS(5698),
    [anon_sym_signed] = ACTIONS(5696),
    [anon_sym_unsigned] = ACTIONS(5696),
    [anon_sym_long] = ACTIONS(5696),
    [anon_sym_short] = ACTIONS(5696),
    [anon_sym_LBRACK] = ACTIONS(5698),
    [anon_sym_RBRACK] = ACTIONS(5698),
    [anon_sym_const] = ACTIONS(5696),
    [anon_sym_constexpr] = ACTIONS(5696),
    [anon_sym_volatile] = ACTIONS(5696),
    [anon_sym_restrict] = ACTIONS(5696),
    [anon_sym___restrict__] = ACTIONS(5696),
    [anon_sym__Atomic] = ACTIONS(5696),
    [anon_sym__Noreturn] = ACTIONS(5696),
    [anon_sym_noreturn] = ACTIONS(5696),
    [anon_sym__Nonnull] = ACTIONS(5696),
    [anon_sym_mutable] = ACTIONS(5696),
    [anon_sym_constinit] = ACTIONS(5696),
    [anon_sym_consteval] = ACTIONS(5696),
    [anon_sym___shared__] = ACTIONS(5696),
    [anon_sym___local__] = ACTIONS(5696),
    [anon_sym___constant__] = ACTIONS(5696),
    [anon_sym___managed__] = ACTIONS(5696),
    [anon_sym___grid_constant__] = ACTIONS(5696),
    [anon_sym_alignas] = ACTIONS(5696),
    [anon_sym__Alignas] = ACTIONS(5696),
    [sym_primitive_type] = ACTIONS(5696),
    [anon_sym_COLON] = ACTIONS(5698),
    [anon_sym_QMARK] = ACTIONS(5698),
    [anon_sym_LT_EQ_GT] = ACTIONS(5698),
    [anon_sym_or] = ACTIONS(5696),
    [anon_sym_and] = ACTIONS(5696),
    [anon_sym_bitor] = ACTIONS(5696),
    [anon_sym_xor] = ACTIONS(5696),
    [anon_sym_bitand] = ACTIONS(5696),
    [anon_sym_not_eq] = ACTIONS(5696),
    [anon_sym_DASH_DASH] = ACTIONS(5698),
    [anon_sym_PLUS_PLUS] = ACTIONS(5698),
    [anon_sym_DOT] = ACTIONS(5696),
    [anon_sym_DOT_STAR] = ACTIONS(5698),
    [anon_sym_DASH_GT] = ACTIONS(5698),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5696),
    [anon_sym_decltype] = ACTIONS(5696),
    [anon_sym_final] = ACTIONS(5696),
    [anon_sym_override] = ACTIONS(5696),
    [anon_sym_requires] = ACTIONS(5696),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5698),
  },
  [STATE(2155)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4560),
    [anon_sym_COMMA] = ACTIONS(4560),
    [anon_sym_RPAREN] = ACTIONS(4560),
    [aux_sym_preproc_if_token2] = ACTIONS(4560),
    [aux_sym_preproc_else_token1] = ACTIONS(4560),
    [aux_sym_preproc_elif_token1] = ACTIONS(4553),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4560),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4560),
    [anon_sym_LPAREN2] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4553),
    [anon_sym_PLUS] = ACTIONS(4553),
    [anon_sym_STAR] = ACTIONS(4560),
    [anon_sym_SLASH] = ACTIONS(4553),
    [anon_sym_PERCENT] = ACTIONS(4560),
    [anon_sym_PIPE_PIPE] = ACTIONS(4560),
    [anon_sym_AMP_AMP] = ACTIONS(4560),
    [anon_sym_PIPE] = ACTIONS(4553),
    [anon_sym_CARET] = ACTIONS(4560),
    [anon_sym_AMP] = ACTIONS(4553),
    [anon_sym_EQ_EQ] = ACTIONS(4560),
    [anon_sym_BANG_EQ] = ACTIONS(4560),
    [anon_sym_GT] = ACTIONS(4553),
    [anon_sym_GT_EQ] = ACTIONS(4560),
    [anon_sym_LT_EQ] = ACTIONS(4553),
    [anon_sym_LT] = ACTIONS(4553),
    [anon_sym_LT_LT] = ACTIONS(4553),
    [anon_sym_GT_GT] = ACTIONS(4560),
    [anon_sym_SEMI] = ACTIONS(4560),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_RBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4560),
    [anon_sym_RBRACK] = ACTIONS(4560),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_COLON] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4560),
    [anon_sym_LT_EQ_GT] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4553),
    [anon_sym_and] = ACTIONS(4553),
    [anon_sym_bitor] = ACTIONS(4553),
    [anon_sym_xor] = ACTIONS(4553),
    [anon_sym_bitand] = ACTIONS(4553),
    [anon_sym_not_eq] = ACTIONS(4553),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_DOT] = ACTIONS(4553),
    [anon_sym_DOT_STAR] = ACTIONS(4560),
    [anon_sym_DASH_GT] = ACTIONS(4560),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_final] = ACTIONS(4553),
    [anon_sym_override] = ACTIONS(4553),
    [anon_sym_requires] = ACTIONS(4553),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4560),
  },
  [STATE(2156)] = {
    [sym_identifier] = ACTIONS(5829),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5831),
    [anon_sym_COMMA] = ACTIONS(5831),
    [anon_sym_RPAREN] = ACTIONS(5831),
    [anon_sym_LPAREN2] = ACTIONS(5831),
    [anon_sym_DASH] = ACTIONS(5829),
    [anon_sym_PLUS] = ACTIONS(5829),
    [anon_sym_STAR] = ACTIONS(5831),
    [anon_sym_SLASH] = ACTIONS(5829),
    [anon_sym_PERCENT] = ACTIONS(5831),
    [anon_sym_PIPE_PIPE] = ACTIONS(5831),
    [anon_sym_AMP_AMP] = ACTIONS(5831),
    [anon_sym_PIPE] = ACTIONS(5829),
    [anon_sym_CARET] = ACTIONS(5831),
    [anon_sym_AMP] = ACTIONS(5829),
    [anon_sym_EQ_EQ] = ACTIONS(5831),
    [anon_sym_BANG_EQ] = ACTIONS(5831),
    [anon_sym_GT] = ACTIONS(5829),
    [anon_sym_GT_EQ] = ACTIONS(5831),
    [anon_sym_LT_EQ] = ACTIONS(5829),
    [anon_sym_LT] = ACTIONS(5829),
    [anon_sym_LT_LT] = ACTIONS(5829),
    [anon_sym_GT_GT] = ACTIONS(5831),
    [anon_sym_SEMI] = ACTIONS(5831),
    [anon_sym___extension__] = ACTIONS(5829),
    [anon_sym___global__] = ACTIONS(5829),
    [anon_sym___attribute__] = ACTIONS(5829),
    [anon_sym___attribute] = ACTIONS(5829),
    [anon_sym___based] = ACTIONS(5829),
    [anon_sym_LBRACE] = ACTIONS(5831),
    [anon_sym_RBRACE] = ACTIONS(5831),
    [anon_sym_signed] = ACTIONS(5829),
    [anon_sym_unsigned] = ACTIONS(5829),
    [anon_sym_long] = ACTIONS(5829),
    [anon_sym_short] = ACTIONS(5829),
    [anon_sym_LBRACK] = ACTIONS(5831),
    [anon_sym_RBRACK] = ACTIONS(5831),
    [anon_sym_const] = ACTIONS(5829),
    [anon_sym_constexpr] = ACTIONS(5829),
    [anon_sym_volatile] = ACTIONS(5829),
    [anon_sym_restrict] = ACTIONS(5829),
    [anon_sym___restrict__] = ACTIONS(5829),
    [anon_sym__Atomic] = ACTIONS(5829),
    [anon_sym__Noreturn] = ACTIONS(5829),
    [anon_sym_noreturn] = ACTIONS(5829),
    [anon_sym__Nonnull] = ACTIONS(5829),
    [anon_sym_mutable] = ACTIONS(5829),
    [anon_sym_constinit] = ACTIONS(5829),
    [anon_sym_consteval] = ACTIONS(5829),
    [anon_sym___shared__] = ACTIONS(5829),
    [anon_sym___local__] = ACTIONS(5829),
    [anon_sym___constant__] = ACTIONS(5829),
    [anon_sym___managed__] = ACTIONS(5829),
    [anon_sym___grid_constant__] = ACTIONS(5829),
    [anon_sym_alignas] = ACTIONS(5829),
    [anon_sym__Alignas] = ACTIONS(5829),
    [sym_primitive_type] = ACTIONS(5829),
    [anon_sym_COLON] = ACTIONS(5831),
    [anon_sym_QMARK] = ACTIONS(5831),
    [anon_sym_LT_EQ_GT] = ACTIONS(5831),
    [anon_sym_or] = ACTIONS(5829),
    [anon_sym_and] = ACTIONS(5829),
    [anon_sym_bitor] = ACTIONS(5829),
    [anon_sym_xor] = ACTIONS(5829),
    [anon_sym_bitand] = ACTIONS(5829),
    [anon_sym_not_eq] = ACTIONS(5829),
    [anon_sym_DASH_DASH] = ACTIONS(5831),
    [anon_sym_PLUS_PLUS] = ACTIONS(5831),
    [anon_sym_DOT] = ACTIONS(5829),
    [anon_sym_DOT_STAR] = ACTIONS(5831),
    [anon_sym_DASH_GT] = ACTIONS(5831),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5829),
    [anon_sym_decltype] = ACTIONS(5829),
    [anon_sym_final] = ACTIONS(5829),
    [anon_sym_override] = ACTIONS(5829),
    [anon_sym_requires] = ACTIONS(5829),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5831),
  },
  [STATE(2157)] = {
    [sym_template_argument_list] = STATE(2177),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4516),
    [anon_sym_COMMA] = ACTIONS(4516),
    [anon_sym_LPAREN2] = ACTIONS(4516),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4523),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4516),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4523),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4521),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(5833),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym___extension__] = ACTIONS(4519),
    [anon_sym___global__] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_EQ] = ACTIONS(4521),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4519),
    [anon_sym_volatile] = ACTIONS(4519),
    [anon_sym_restrict] = ACTIONS(4519),
    [anon_sym___restrict__] = ACTIONS(4519),
    [anon_sym__Atomic] = ACTIONS(4519),
    [anon_sym__Noreturn] = ACTIONS(4519),
    [anon_sym_noreturn] = ACTIONS(4519),
    [anon_sym__Nonnull] = ACTIONS(4519),
    [anon_sym_mutable] = ACTIONS(4519),
    [anon_sym_constinit] = ACTIONS(4519),
    [anon_sym_consteval] = ACTIONS(4519),
    [anon_sym___shared__] = ACTIONS(4519),
    [anon_sym___local__] = ACTIONS(4519),
    [anon_sym___constant__] = ACTIONS(4519),
    [anon_sym___managed__] = ACTIONS(4519),
    [anon_sym___grid_constant__] = ACTIONS(4519),
    [anon_sym_alignas] = ACTIONS(4519),
    [anon_sym__Alignas] = ACTIONS(4519),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4521),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4514),
    [anon_sym_or_eq] = ACTIONS(4514),
    [anon_sym_xor_eq] = ACTIONS(4514),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4514),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4514),
    [anon_sym_not_eq] = ACTIONS(4514),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4514),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4519),
    [anon_sym_decltype] = ACTIONS(4519),
    [anon_sym_GT2] = ACTIONS(4516),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
  },
  [STATE(2158)] = {
    [sym_type_qualifier] = STATE(2117),
    [sym_alignas_qualifier] = STATE(1873),
    [aux_sym__type_definition_type_repeat1] = STATE(2117),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2213),
    [sym_identifier] = ACTIONS(5836),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_RPAREN] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5158),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5158),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5158),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5158),
    [anon_sym_SEMI] = ACTIONS(5158),
    [anon_sym___extension__] = ACTIONS(5702),
    [anon_sym___global__] = ACTIONS(5702),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_RBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5838),
    [anon_sym_unsigned] = ACTIONS(5838),
    [anon_sym_long] = ACTIONS(5838),
    [anon_sym_short] = ACTIONS(5838),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_RBRACK] = ACTIONS(5158),
    [anon_sym_const] = ACTIONS(5702),
    [anon_sym_constexpr] = ACTIONS(5702),
    [anon_sym_volatile] = ACTIONS(5702),
    [anon_sym_restrict] = ACTIONS(5702),
    [anon_sym___restrict__] = ACTIONS(5702),
    [anon_sym__Atomic] = ACTIONS(5702),
    [anon_sym__Noreturn] = ACTIONS(5702),
    [anon_sym_noreturn] = ACTIONS(5702),
    [anon_sym__Nonnull] = ACTIONS(5702),
    [anon_sym_mutable] = ACTIONS(5702),
    [anon_sym_constinit] = ACTIONS(5702),
    [anon_sym_consteval] = ACTIONS(5702),
    [anon_sym___shared__] = ACTIONS(5702),
    [anon_sym___local__] = ACTIONS(5702),
    [anon_sym___constant__] = ACTIONS(5702),
    [anon_sym___managed__] = ACTIONS(5702),
    [anon_sym___grid_constant__] = ACTIONS(5702),
    [anon_sym_alignas] = ACTIONS(5706),
    [anon_sym__Alignas] = ACTIONS(5706),
    [sym_primitive_type] = ACTIONS(5840),
    [anon_sym_COLON] = ACTIONS(5158),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
  },
  [STATE(2159)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5661),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_RBRACE] = ACTIONS(5661),
    [anon_sym_signed] = ACTIONS(5659),
    [anon_sym_unsigned] = ACTIONS(5659),
    [anon_sym_long] = ACTIONS(5659),
    [anon_sym_short] = ACTIONS(5659),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_RBRACK] = ACTIONS(5661),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [sym_primitive_type] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5661),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_bitor] = ACTIONS(5659),
    [anon_sym_xor] = ACTIONS(5659),
    [anon_sym_bitand] = ACTIONS(5659),
    [anon_sym_not_eq] = ACTIONS(5659),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [anon_sym_requires] = ACTIONS(5659),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(2160)] = {
    [sym_identifier] = ACTIONS(5842),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5844),
    [anon_sym_COMMA] = ACTIONS(5844),
    [anon_sym_RPAREN] = ACTIONS(5844),
    [anon_sym_LPAREN2] = ACTIONS(5844),
    [anon_sym_DASH] = ACTIONS(5842),
    [anon_sym_PLUS] = ACTIONS(5842),
    [anon_sym_STAR] = ACTIONS(5844),
    [anon_sym_SLASH] = ACTIONS(5842),
    [anon_sym_PERCENT] = ACTIONS(5844),
    [anon_sym_PIPE_PIPE] = ACTIONS(5844),
    [anon_sym_AMP_AMP] = ACTIONS(5844),
    [anon_sym_PIPE] = ACTIONS(5842),
    [anon_sym_CARET] = ACTIONS(5844),
    [anon_sym_AMP] = ACTIONS(5842),
    [anon_sym_EQ_EQ] = ACTIONS(5844),
    [anon_sym_BANG_EQ] = ACTIONS(5844),
    [anon_sym_GT] = ACTIONS(5842),
    [anon_sym_GT_EQ] = ACTIONS(5844),
    [anon_sym_LT_EQ] = ACTIONS(5842),
    [anon_sym_LT] = ACTIONS(5842),
    [anon_sym_LT_LT] = ACTIONS(5842),
    [anon_sym_GT_GT] = ACTIONS(5844),
    [anon_sym_SEMI] = ACTIONS(5844),
    [anon_sym___extension__] = ACTIONS(5842),
    [anon_sym___global__] = ACTIONS(5842),
    [anon_sym___attribute__] = ACTIONS(5842),
    [anon_sym___attribute] = ACTIONS(5842),
    [anon_sym___based] = ACTIONS(5842),
    [anon_sym_LBRACE] = ACTIONS(5844),
    [anon_sym_RBRACE] = ACTIONS(5844),
    [anon_sym_signed] = ACTIONS(5842),
    [anon_sym_unsigned] = ACTIONS(5842),
    [anon_sym_long] = ACTIONS(5842),
    [anon_sym_short] = ACTIONS(5842),
    [anon_sym_LBRACK] = ACTIONS(5844),
    [anon_sym_RBRACK] = ACTIONS(5844),
    [anon_sym_const] = ACTIONS(5842),
    [anon_sym_constexpr] = ACTIONS(5842),
    [anon_sym_volatile] = ACTIONS(5842),
    [anon_sym_restrict] = ACTIONS(5842),
    [anon_sym___restrict__] = ACTIONS(5842),
    [anon_sym__Atomic] = ACTIONS(5842),
    [anon_sym__Noreturn] = ACTIONS(5842),
    [anon_sym_noreturn] = ACTIONS(5842),
    [anon_sym__Nonnull] = ACTIONS(5842),
    [anon_sym_mutable] = ACTIONS(5842),
    [anon_sym_constinit] = ACTIONS(5842),
    [anon_sym_consteval] = ACTIONS(5842),
    [anon_sym___shared__] = ACTIONS(5842),
    [anon_sym___local__] = ACTIONS(5842),
    [anon_sym___constant__] = ACTIONS(5842),
    [anon_sym___managed__] = ACTIONS(5842),
    [anon_sym___grid_constant__] = ACTIONS(5842),
    [anon_sym_alignas] = ACTIONS(5842),
    [anon_sym__Alignas] = ACTIONS(5842),
    [sym_primitive_type] = ACTIONS(5842),
    [anon_sym_COLON] = ACTIONS(5844),
    [anon_sym_QMARK] = ACTIONS(5844),
    [anon_sym_LT_EQ_GT] = ACTIONS(5844),
    [anon_sym_or] = ACTIONS(5842),
    [anon_sym_and] = ACTIONS(5842),
    [anon_sym_bitor] = ACTIONS(5842),
    [anon_sym_xor] = ACTIONS(5842),
    [anon_sym_bitand] = ACTIONS(5842),
    [anon_sym_not_eq] = ACTIONS(5842),
    [anon_sym_DASH_DASH] = ACTIONS(5844),
    [anon_sym_PLUS_PLUS] = ACTIONS(5844),
    [anon_sym_DOT] = ACTIONS(5842),
    [anon_sym_DOT_STAR] = ACTIONS(5844),
    [anon_sym_DASH_GT] = ACTIONS(5844),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5842),
    [anon_sym_decltype] = ACTIONS(5842),
    [anon_sym_final] = ACTIONS(5842),
    [anon_sym_override] = ACTIONS(5842),
    [anon_sym_requires] = ACTIONS(5842),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5844),
  },
  [STATE(2161)] = {
    [sym_identifier] = ACTIONS(5688),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5690),
    [anon_sym_COMMA] = ACTIONS(5690),
    [anon_sym_RPAREN] = ACTIONS(5690),
    [anon_sym_LPAREN2] = ACTIONS(5690),
    [anon_sym_TILDE] = ACTIONS(5690),
    [anon_sym_STAR] = ACTIONS(5690),
    [anon_sym_PIPE_PIPE] = ACTIONS(5690),
    [anon_sym_AMP_AMP] = ACTIONS(5690),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_SEMI] = ACTIONS(5690),
    [anon_sym___extension__] = ACTIONS(5688),
    [anon_sym___device__] = ACTIONS(5688),
    [anon_sym___host__] = ACTIONS(5688),
    [anon_sym___global__] = ACTIONS(5688),
    [anon_sym___forceinline__] = ACTIONS(5688),
    [anon_sym___noinline__] = ACTIONS(5688),
    [anon_sym_virtual] = ACTIONS(5688),
    [anon_sym_extern] = ACTIONS(5688),
    [anon_sym___attribute__] = ACTIONS(5688),
    [anon_sym___attribute] = ACTIONS(5688),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5690),
    [anon_sym___declspec] = ACTIONS(5688),
    [anon_sym___based] = ACTIONS(5688),
    [anon_sym___cdecl] = ACTIONS(5688),
    [anon_sym___clrcall] = ACTIONS(5688),
    [anon_sym___stdcall] = ACTIONS(5688),
    [anon_sym___fastcall] = ACTIONS(5688),
    [anon_sym___thiscall] = ACTIONS(5688),
    [anon_sym___vectorcall] = ACTIONS(5688),
    [anon_sym_LBRACE] = ACTIONS(5690),
    [anon_sym_LBRACK] = ACTIONS(5688),
    [anon_sym_static] = ACTIONS(5688),
    [anon_sym_EQ] = ACTIONS(5690),
    [anon_sym_register] = ACTIONS(5688),
    [anon_sym_inline] = ACTIONS(5688),
    [anon_sym___inline] = ACTIONS(5688),
    [anon_sym___inline__] = ACTIONS(5688),
    [anon_sym___forceinline] = ACTIONS(5688),
    [anon_sym_thread_local] = ACTIONS(5688),
    [anon_sym___thread] = ACTIONS(5688),
    [anon_sym_const] = ACTIONS(5688),
    [anon_sym_constexpr] = ACTIONS(5688),
    [anon_sym_volatile] = ACTIONS(5688),
    [anon_sym_restrict] = ACTIONS(5688),
    [anon_sym___restrict__] = ACTIONS(5688),
    [anon_sym__Atomic] = ACTIONS(5688),
    [anon_sym__Noreturn] = ACTIONS(5688),
    [anon_sym_noreturn] = ACTIONS(5688),
    [anon_sym__Nonnull] = ACTIONS(5688),
    [anon_sym_mutable] = ACTIONS(5688),
    [anon_sym_constinit] = ACTIONS(5688),
    [anon_sym_consteval] = ACTIONS(5688),
    [anon_sym___shared__] = ACTIONS(5688),
    [anon_sym___local__] = ACTIONS(5688),
    [anon_sym___constant__] = ACTIONS(5688),
    [anon_sym___managed__] = ACTIONS(5688),
    [anon_sym___grid_constant__] = ACTIONS(5688),
    [anon_sym_alignas] = ACTIONS(5688),
    [anon_sym__Alignas] = ACTIONS(5688),
    [anon_sym_COLON] = ACTIONS(5688),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_and] = ACTIONS(5688),
    [anon_sym_asm] = ACTIONS(5688),
    [anon_sym___asm__] = ACTIONS(5688),
    [anon_sym___asm] = ACTIONS(5688),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5688),
    [anon_sym_decltype] = ACTIONS(5688),
    [anon_sym_final] = ACTIONS(5688),
    [anon_sym_override] = ACTIONS(5688),
    [anon_sym_template] = ACTIONS(5688),
    [anon_sym_GT2] = ACTIONS(5690),
    [anon_sym_operator] = ACTIONS(5688),
    [anon_sym_try] = ACTIONS(5688),
    [anon_sym_requires] = ACTIONS(5688),
    [anon_sym___launch_bounds__] = ACTIONS(5688),
  },
  [STATE(2162)] = {
    [sym_type_qualifier] = STATE(2140),
    [sym_alignas_qualifier] = STATE(1873),
    [aux_sym__type_definition_type_repeat1] = STATE(2140),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2214),
    [sym_identifier] = ACTIONS(5846),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [aux_sym_preproc_if_token2] = ACTIONS(5158),
    [aux_sym_preproc_else_token1] = ACTIONS(5158),
    [aux_sym_preproc_elif_token1] = ACTIONS(5160),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5158),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5158),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5158),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5158),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5158),
    [anon_sym___extension__] = ACTIONS(5702),
    [anon_sym___global__] = ACTIONS(5702),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5849),
    [anon_sym_unsigned] = ACTIONS(5849),
    [anon_sym_long] = ACTIONS(5849),
    [anon_sym_short] = ACTIONS(5849),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_const] = ACTIONS(5702),
    [anon_sym_constexpr] = ACTIONS(5702),
    [anon_sym_volatile] = ACTIONS(5702),
    [anon_sym_restrict] = ACTIONS(5702),
    [anon_sym___restrict__] = ACTIONS(5702),
    [anon_sym__Atomic] = ACTIONS(5702),
    [anon_sym__Noreturn] = ACTIONS(5702),
    [anon_sym_noreturn] = ACTIONS(5702),
    [anon_sym__Nonnull] = ACTIONS(5702),
    [anon_sym_mutable] = ACTIONS(5702),
    [anon_sym_constinit] = ACTIONS(5702),
    [anon_sym_consteval] = ACTIONS(5702),
    [anon_sym___shared__] = ACTIONS(5702),
    [anon_sym___local__] = ACTIONS(5702),
    [anon_sym___constant__] = ACTIONS(5702),
    [anon_sym___managed__] = ACTIONS(5702),
    [anon_sym___grid_constant__] = ACTIONS(5702),
    [anon_sym_alignas] = ACTIONS(5706),
    [anon_sym__Alignas] = ACTIONS(5706),
    [sym_primitive_type] = ACTIONS(5851),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
  },
  [STATE(2163)] = {
    [sym_identifier] = ACTIONS(5853),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5855),
    [anon_sym_COMMA] = ACTIONS(5855),
    [anon_sym_RPAREN] = ACTIONS(5855),
    [anon_sym_LPAREN2] = ACTIONS(5855),
    [anon_sym_DASH] = ACTIONS(5853),
    [anon_sym_PLUS] = ACTIONS(5853),
    [anon_sym_STAR] = ACTIONS(5855),
    [anon_sym_SLASH] = ACTIONS(5853),
    [anon_sym_PERCENT] = ACTIONS(5855),
    [anon_sym_PIPE_PIPE] = ACTIONS(5855),
    [anon_sym_AMP_AMP] = ACTIONS(5855),
    [anon_sym_PIPE] = ACTIONS(5853),
    [anon_sym_CARET] = ACTIONS(5855),
    [anon_sym_AMP] = ACTIONS(5853),
    [anon_sym_EQ_EQ] = ACTIONS(5855),
    [anon_sym_BANG_EQ] = ACTIONS(5855),
    [anon_sym_GT] = ACTIONS(5853),
    [anon_sym_GT_EQ] = ACTIONS(5855),
    [anon_sym_LT_EQ] = ACTIONS(5853),
    [anon_sym_LT] = ACTIONS(5853),
    [anon_sym_LT_LT] = ACTIONS(5853),
    [anon_sym_GT_GT] = ACTIONS(5855),
    [anon_sym_SEMI] = ACTIONS(5855),
    [anon_sym___extension__] = ACTIONS(5853),
    [anon_sym___global__] = ACTIONS(5853),
    [anon_sym___attribute__] = ACTIONS(5853),
    [anon_sym___attribute] = ACTIONS(5853),
    [anon_sym___based] = ACTIONS(5853),
    [anon_sym_LBRACE] = ACTIONS(5855),
    [anon_sym_RBRACE] = ACTIONS(5855),
    [anon_sym_signed] = ACTIONS(5853),
    [anon_sym_unsigned] = ACTIONS(5853),
    [anon_sym_long] = ACTIONS(5853),
    [anon_sym_short] = ACTIONS(5853),
    [anon_sym_LBRACK] = ACTIONS(5855),
    [anon_sym_RBRACK] = ACTIONS(5855),
    [anon_sym_const] = ACTIONS(5853),
    [anon_sym_constexpr] = ACTIONS(5853),
    [anon_sym_volatile] = ACTIONS(5853),
    [anon_sym_restrict] = ACTIONS(5853),
    [anon_sym___restrict__] = ACTIONS(5853),
    [anon_sym__Atomic] = ACTIONS(5853),
    [anon_sym__Noreturn] = ACTIONS(5853),
    [anon_sym_noreturn] = ACTIONS(5853),
    [anon_sym__Nonnull] = ACTIONS(5853),
    [anon_sym_mutable] = ACTIONS(5853),
    [anon_sym_constinit] = ACTIONS(5853),
    [anon_sym_consteval] = ACTIONS(5853),
    [anon_sym___shared__] = ACTIONS(5853),
    [anon_sym___local__] = ACTIONS(5853),
    [anon_sym___constant__] = ACTIONS(5853),
    [anon_sym___managed__] = ACTIONS(5853),
    [anon_sym___grid_constant__] = ACTIONS(5853),
    [anon_sym_alignas] = ACTIONS(5853),
    [anon_sym__Alignas] = ACTIONS(5853),
    [sym_primitive_type] = ACTIONS(5853),
    [anon_sym_COLON] = ACTIONS(5855),
    [anon_sym_QMARK] = ACTIONS(5855),
    [anon_sym_LT_EQ_GT] = ACTIONS(5855),
    [anon_sym_or] = ACTIONS(5853),
    [anon_sym_and] = ACTIONS(5853),
    [anon_sym_bitor] = ACTIONS(5853),
    [anon_sym_xor] = ACTIONS(5853),
    [anon_sym_bitand] = ACTIONS(5853),
    [anon_sym_not_eq] = ACTIONS(5853),
    [anon_sym_DASH_DASH] = ACTIONS(5855),
    [anon_sym_PLUS_PLUS] = ACTIONS(5855),
    [anon_sym_DOT] = ACTIONS(5853),
    [anon_sym_DOT_STAR] = ACTIONS(5855),
    [anon_sym_DASH_GT] = ACTIONS(5855),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5853),
    [anon_sym_decltype] = ACTIONS(5853),
    [anon_sym_final] = ACTIONS(5853),
    [anon_sym_override] = ACTIONS(5853),
    [anon_sym_requires] = ACTIONS(5853),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5855),
  },
  [STATE(2164)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_TILDE] = ACTIONS(5661),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___device__] = ACTIONS(5659),
    [anon_sym___host__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___forceinline__] = ACTIONS(5659),
    [anon_sym___noinline__] = ACTIONS(5659),
    [anon_sym_virtual] = ACTIONS(5659),
    [anon_sym_extern] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5661),
    [anon_sym___declspec] = ACTIONS(5659),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym___cdecl] = ACTIONS(5659),
    [anon_sym___clrcall] = ACTIONS(5659),
    [anon_sym___stdcall] = ACTIONS(5659),
    [anon_sym___fastcall] = ACTIONS(5659),
    [anon_sym___thiscall] = ACTIONS(5659),
    [anon_sym___vectorcall] = ACTIONS(5659),
    [anon_sym_signed] = ACTIONS(5659),
    [anon_sym_unsigned] = ACTIONS(5659),
    [anon_sym_long] = ACTIONS(5659),
    [anon_sym_short] = ACTIONS(5659),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [anon_sym_static] = ACTIONS(5659),
    [anon_sym_register] = ACTIONS(5659),
    [anon_sym_inline] = ACTIONS(5659),
    [anon_sym___inline] = ACTIONS(5659),
    [anon_sym___inline__] = ACTIONS(5659),
    [anon_sym___forceinline] = ACTIONS(5659),
    [anon_sym_thread_local] = ACTIONS(5659),
    [anon_sym___thread] = ACTIONS(5659),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [sym_primitive_type] = ACTIONS(5659),
    [anon_sym_enum] = ACTIONS(5659),
    [anon_sym_class] = ACTIONS(5659),
    [anon_sym_struct] = ACTIONS(5659),
    [anon_sym_union] = ACTIONS(5659),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_explicit] = ACTIONS(5659),
    [anon_sym_typename] = ACTIONS(5659),
    [anon_sym_template] = ACTIONS(5659),
    [anon_sym_operator] = ACTIONS(5659),
    [anon_sym_friend] = ACTIONS(5659),
    [anon_sym_using] = ACTIONS(5659),
    [anon_sym_concept] = ACTIONS(5659),
    [anon_sym___launch_bounds__] = ACTIONS(5659),
  },
  [STATE(2165)] = {
    [sym_identifier] = ACTIONS(4402),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_TILDE] = ACTIONS(4404),
    [anon_sym_STAR] = ACTIONS(4404),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym___extension__] = ACTIONS(4402),
    [anon_sym___device__] = ACTIONS(4402),
    [anon_sym___host__] = ACTIONS(4402),
    [anon_sym___global__] = ACTIONS(4402),
    [anon_sym___forceinline__] = ACTIONS(4402),
    [anon_sym___noinline__] = ACTIONS(4402),
    [anon_sym_virtual] = ACTIONS(4402),
    [anon_sym_extern] = ACTIONS(4402),
    [anon_sym___attribute__] = ACTIONS(4402),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4404),
    [anon_sym___declspec] = ACTIONS(4402),
    [anon_sym___based] = ACTIONS(4402),
    [anon_sym___cdecl] = ACTIONS(4402),
    [anon_sym___clrcall] = ACTIONS(4402),
    [anon_sym___stdcall] = ACTIONS(4402),
    [anon_sym___fastcall] = ACTIONS(4402),
    [anon_sym___thiscall] = ACTIONS(4402),
    [anon_sym___vectorcall] = ACTIONS(4402),
    [anon_sym_signed] = ACTIONS(4402),
    [anon_sym_unsigned] = ACTIONS(4402),
    [anon_sym_long] = ACTIONS(4402),
    [anon_sym_short] = ACTIONS(4402),
    [anon_sym_LBRACK] = ACTIONS(4402),
    [anon_sym_static] = ACTIONS(4402),
    [anon_sym_register] = ACTIONS(4402),
    [anon_sym_inline] = ACTIONS(4402),
    [anon_sym___inline] = ACTIONS(4402),
    [anon_sym___inline__] = ACTIONS(4402),
    [anon_sym___forceinline] = ACTIONS(4402),
    [anon_sym_thread_local] = ACTIONS(4402),
    [anon_sym___thread] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4402),
    [anon_sym_volatile] = ACTIONS(4402),
    [anon_sym_restrict] = ACTIONS(4402),
    [anon_sym___restrict__] = ACTIONS(4402),
    [anon_sym__Atomic] = ACTIONS(4402),
    [anon_sym__Noreturn] = ACTIONS(4402),
    [anon_sym_noreturn] = ACTIONS(4402),
    [anon_sym__Nonnull] = ACTIONS(4402),
    [anon_sym_mutable] = ACTIONS(4402),
    [anon_sym_constinit] = ACTIONS(4402),
    [anon_sym_consteval] = ACTIONS(4402),
    [anon_sym___shared__] = ACTIONS(4402),
    [anon_sym___local__] = ACTIONS(4402),
    [anon_sym___constant__] = ACTIONS(4402),
    [anon_sym___managed__] = ACTIONS(4402),
    [anon_sym___grid_constant__] = ACTIONS(4402),
    [anon_sym_alignas] = ACTIONS(4402),
    [anon_sym__Alignas] = ACTIONS(4402),
    [sym_primitive_type] = ACTIONS(4402),
    [anon_sym_enum] = ACTIONS(4402),
    [anon_sym_class] = ACTIONS(4402),
    [anon_sym_struct] = ACTIONS(4402),
    [anon_sym_union] = ACTIONS(4402),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4402),
    [anon_sym_decltype] = ACTIONS(4402),
    [anon_sym_explicit] = ACTIONS(4402),
    [anon_sym_typename] = ACTIONS(4402),
    [anon_sym_template] = ACTIONS(4402),
    [anon_sym_operator] = ACTIONS(4402),
    [anon_sym_friend] = ACTIONS(4402),
    [anon_sym_using] = ACTIONS(4402),
    [anon_sym_concept] = ACTIONS(4402),
    [anon_sym___launch_bounds__] = ACTIONS(4402),
  },
  [STATE(2166)] = {
    [sym_string_literal] = STATE(2204),
    [sym_template_argument_list] = STATE(2672),
    [sym_raw_string_literal] = STATE(2204),
    [sym_identifier] = ACTIONS(4012),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(4004),
    [aux_sym_preproc_if_token2] = ACTIONS(4004),
    [aux_sym_preproc_else_token1] = ACTIONS(4004),
    [aux_sym_preproc_elif_token1] = ACTIONS(4012),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4004),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5857),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4004),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_RBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_COLON] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4012),
    [anon_sym_or_eq] = ACTIONS(4012),
    [anon_sym_xor_eq] = ACTIONS(4012),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2167)] = {
    [sym_identifier] = ACTIONS(4408),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_TILDE] = ACTIONS(4410),
    [anon_sym_STAR] = ACTIONS(4410),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym___extension__] = ACTIONS(4408),
    [anon_sym___device__] = ACTIONS(4408),
    [anon_sym___host__] = ACTIONS(4408),
    [anon_sym___global__] = ACTIONS(4408),
    [anon_sym___forceinline__] = ACTIONS(4408),
    [anon_sym___noinline__] = ACTIONS(4408),
    [anon_sym_virtual] = ACTIONS(4408),
    [anon_sym_extern] = ACTIONS(4408),
    [anon_sym___attribute__] = ACTIONS(4408),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4410),
    [anon_sym___declspec] = ACTIONS(4408),
    [anon_sym___based] = ACTIONS(4408),
    [anon_sym___cdecl] = ACTIONS(4408),
    [anon_sym___clrcall] = ACTIONS(4408),
    [anon_sym___stdcall] = ACTIONS(4408),
    [anon_sym___fastcall] = ACTIONS(4408),
    [anon_sym___thiscall] = ACTIONS(4408),
    [anon_sym___vectorcall] = ACTIONS(4408),
    [anon_sym_signed] = ACTIONS(4408),
    [anon_sym_unsigned] = ACTIONS(4408),
    [anon_sym_long] = ACTIONS(4408),
    [anon_sym_short] = ACTIONS(4408),
    [anon_sym_LBRACK] = ACTIONS(4408),
    [anon_sym_static] = ACTIONS(4408),
    [anon_sym_register] = ACTIONS(4408),
    [anon_sym_inline] = ACTIONS(4408),
    [anon_sym___inline] = ACTIONS(4408),
    [anon_sym___inline__] = ACTIONS(4408),
    [anon_sym___forceinline] = ACTIONS(4408),
    [anon_sym_thread_local] = ACTIONS(4408),
    [anon_sym___thread] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4408),
    [anon_sym_volatile] = ACTIONS(4408),
    [anon_sym_restrict] = ACTIONS(4408),
    [anon_sym___restrict__] = ACTIONS(4408),
    [anon_sym__Atomic] = ACTIONS(4408),
    [anon_sym__Noreturn] = ACTIONS(4408),
    [anon_sym_noreturn] = ACTIONS(4408),
    [anon_sym__Nonnull] = ACTIONS(4408),
    [anon_sym_mutable] = ACTIONS(4408),
    [anon_sym_constinit] = ACTIONS(4408),
    [anon_sym_consteval] = ACTIONS(4408),
    [anon_sym___shared__] = ACTIONS(4408),
    [anon_sym___local__] = ACTIONS(4408),
    [anon_sym___constant__] = ACTIONS(4408),
    [anon_sym___managed__] = ACTIONS(4408),
    [anon_sym___grid_constant__] = ACTIONS(4408),
    [anon_sym_alignas] = ACTIONS(4408),
    [anon_sym__Alignas] = ACTIONS(4408),
    [sym_primitive_type] = ACTIONS(4408),
    [anon_sym_enum] = ACTIONS(4408),
    [anon_sym_class] = ACTIONS(4408),
    [anon_sym_struct] = ACTIONS(4408),
    [anon_sym_union] = ACTIONS(4408),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4408),
    [anon_sym_decltype] = ACTIONS(4408),
    [anon_sym_explicit] = ACTIONS(4408),
    [anon_sym_typename] = ACTIONS(4408),
    [anon_sym_template] = ACTIONS(4408),
    [anon_sym_operator] = ACTIONS(4408),
    [anon_sym_friend] = ACTIONS(4408),
    [anon_sym_using] = ACTIONS(4408),
    [anon_sym_concept] = ACTIONS(4408),
    [anon_sym___launch_bounds__] = ACTIONS(4408),
  },
  [STATE(2168)] = {
    [sym_identifier] = ACTIONS(5860),
    [anon_sym_LPAREN2] = ACTIONS(5862),
    [anon_sym_TILDE] = ACTIONS(5862),
    [anon_sym_STAR] = ACTIONS(5862),
    [anon_sym_PIPE_PIPE] = ACTIONS(5862),
    [anon_sym_AMP_AMP] = ACTIONS(5864),
    [anon_sym_AMP] = ACTIONS(5860),
    [anon_sym___extension__] = ACTIONS(5860),
    [anon_sym___device__] = ACTIONS(5860),
    [anon_sym___host__] = ACTIONS(5860),
    [anon_sym___global__] = ACTIONS(5860),
    [anon_sym___forceinline__] = ACTIONS(5860),
    [anon_sym___noinline__] = ACTIONS(5860),
    [anon_sym_virtual] = ACTIONS(5860),
    [anon_sym_extern] = ACTIONS(5860),
    [anon_sym___attribute__] = ACTIONS(5860),
    [anon_sym___attribute] = ACTIONS(5860),
    [anon_sym_COLON_COLON] = ACTIONS(5862),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5862),
    [anon_sym___declspec] = ACTIONS(5860),
    [anon_sym___based] = ACTIONS(5860),
    [anon_sym___cdecl] = ACTIONS(5860),
    [anon_sym___clrcall] = ACTIONS(5860),
    [anon_sym___stdcall] = ACTIONS(5860),
    [anon_sym___fastcall] = ACTIONS(5860),
    [anon_sym___thiscall] = ACTIONS(5860),
    [anon_sym___vectorcall] = ACTIONS(5860),
    [anon_sym_signed] = ACTIONS(5860),
    [anon_sym_unsigned] = ACTIONS(5860),
    [anon_sym_long] = ACTIONS(5860),
    [anon_sym_short] = ACTIONS(5860),
    [anon_sym_LBRACK] = ACTIONS(5860),
    [anon_sym_static] = ACTIONS(5860),
    [anon_sym_register] = ACTIONS(5860),
    [anon_sym_inline] = ACTIONS(5860),
    [anon_sym___inline] = ACTIONS(5860),
    [anon_sym___inline__] = ACTIONS(5860),
    [anon_sym___forceinline] = ACTIONS(5860),
    [anon_sym_thread_local] = ACTIONS(5860),
    [anon_sym___thread] = ACTIONS(5860),
    [anon_sym_const] = ACTIONS(5860),
    [anon_sym_constexpr] = ACTIONS(5860),
    [anon_sym_volatile] = ACTIONS(5860),
    [anon_sym_restrict] = ACTIONS(5860),
    [anon_sym___restrict__] = ACTIONS(5860),
    [anon_sym__Atomic] = ACTIONS(5860),
    [anon_sym__Noreturn] = ACTIONS(5860),
    [anon_sym_noreturn] = ACTIONS(5860),
    [anon_sym__Nonnull] = ACTIONS(5860),
    [anon_sym_mutable] = ACTIONS(5860),
    [anon_sym_constinit] = ACTIONS(5860),
    [anon_sym_consteval] = ACTIONS(5860),
    [anon_sym___shared__] = ACTIONS(5860),
    [anon_sym___local__] = ACTIONS(5860),
    [anon_sym___constant__] = ACTIONS(5860),
    [anon_sym___managed__] = ACTIONS(5860),
    [anon_sym___grid_constant__] = ACTIONS(5860),
    [anon_sym_alignas] = ACTIONS(5860),
    [anon_sym__Alignas] = ACTIONS(5860),
    [sym_primitive_type] = ACTIONS(5860),
    [anon_sym_enum] = ACTIONS(5860),
    [anon_sym_class] = ACTIONS(5860),
    [anon_sym_struct] = ACTIONS(5860),
    [anon_sym_union] = ACTIONS(5860),
    [anon_sym_or] = ACTIONS(5860),
    [anon_sym_and] = ACTIONS(5866),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5860),
    [anon_sym_decltype] = ACTIONS(5860),
    [anon_sym_explicit] = ACTIONS(5860),
    [anon_sym_typename] = ACTIONS(5860),
    [anon_sym_template] = ACTIONS(5860),
    [anon_sym_operator] = ACTIONS(5860),
    [anon_sym_friend] = ACTIONS(5860),
    [anon_sym_using] = ACTIONS(5860),
    [anon_sym_concept] = ACTIONS(5860),
    [anon_sym___launch_bounds__] = ACTIONS(5860),
  },
  [STATE(2169)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [aux_sym_preproc_if_token2] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5684),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5686),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5686),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_and] = ACTIONS(5684),
    [anon_sym_bitor] = ACTIONS(5684),
    [anon_sym_xor] = ACTIONS(5684),
    [anon_sym_bitand] = ACTIONS(5684),
    [anon_sym_not_eq] = ACTIONS(5684),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_final] = ACTIONS(5684),
    [anon_sym_override] = ACTIONS(5684),
    [anon_sym_requires] = ACTIONS(5684),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2170)] = {
    [sym_identifier] = ACTIONS(4396),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_TILDE] = ACTIONS(4398),
    [anon_sym_STAR] = ACTIONS(4398),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym___extension__] = ACTIONS(4396),
    [anon_sym___device__] = ACTIONS(4396),
    [anon_sym___host__] = ACTIONS(4396),
    [anon_sym___global__] = ACTIONS(4396),
    [anon_sym___forceinline__] = ACTIONS(4396),
    [anon_sym___noinline__] = ACTIONS(4396),
    [anon_sym_virtual] = ACTIONS(4396),
    [anon_sym_extern] = ACTIONS(4396),
    [anon_sym___attribute__] = ACTIONS(4396),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4398),
    [anon_sym___declspec] = ACTIONS(4396),
    [anon_sym___based] = ACTIONS(4396),
    [anon_sym___cdecl] = ACTIONS(4396),
    [anon_sym___clrcall] = ACTIONS(4396),
    [anon_sym___stdcall] = ACTIONS(4396),
    [anon_sym___fastcall] = ACTIONS(4396),
    [anon_sym___thiscall] = ACTIONS(4396),
    [anon_sym___vectorcall] = ACTIONS(4396),
    [anon_sym_signed] = ACTIONS(4396),
    [anon_sym_unsigned] = ACTIONS(4396),
    [anon_sym_long] = ACTIONS(4396),
    [anon_sym_short] = ACTIONS(4396),
    [anon_sym_LBRACK] = ACTIONS(4396),
    [anon_sym_static] = ACTIONS(4396),
    [anon_sym_register] = ACTIONS(4396),
    [anon_sym_inline] = ACTIONS(4396),
    [anon_sym___inline] = ACTIONS(4396),
    [anon_sym___inline__] = ACTIONS(4396),
    [anon_sym___forceinline] = ACTIONS(4396),
    [anon_sym_thread_local] = ACTIONS(4396),
    [anon_sym___thread] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4396),
    [anon_sym_volatile] = ACTIONS(4396),
    [anon_sym_restrict] = ACTIONS(4396),
    [anon_sym___restrict__] = ACTIONS(4396),
    [anon_sym__Atomic] = ACTIONS(4396),
    [anon_sym__Noreturn] = ACTIONS(4396),
    [anon_sym_noreturn] = ACTIONS(4396),
    [anon_sym__Nonnull] = ACTIONS(4396),
    [anon_sym_mutable] = ACTIONS(4396),
    [anon_sym_constinit] = ACTIONS(4396),
    [anon_sym_consteval] = ACTIONS(4396),
    [anon_sym___shared__] = ACTIONS(4396),
    [anon_sym___local__] = ACTIONS(4396),
    [anon_sym___constant__] = ACTIONS(4396),
    [anon_sym___managed__] = ACTIONS(4396),
    [anon_sym___grid_constant__] = ACTIONS(4396),
    [anon_sym_alignas] = ACTIONS(4396),
    [anon_sym__Alignas] = ACTIONS(4396),
    [sym_primitive_type] = ACTIONS(4396),
    [anon_sym_enum] = ACTIONS(4396),
    [anon_sym_class] = ACTIONS(4396),
    [anon_sym_struct] = ACTIONS(4396),
    [anon_sym_union] = ACTIONS(4396),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4396),
    [anon_sym_decltype] = ACTIONS(4396),
    [anon_sym_explicit] = ACTIONS(4396),
    [anon_sym_typename] = ACTIONS(4396),
    [anon_sym_template] = ACTIONS(4396),
    [anon_sym_operator] = ACTIONS(4396),
    [anon_sym_friend] = ACTIONS(4396),
    [anon_sym_using] = ACTIONS(4396),
    [anon_sym_concept] = ACTIONS(4396),
    [anon_sym___launch_bounds__] = ACTIONS(4396),
  },
  [STATE(2171)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_BANG] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_RBRACK] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(1969),
    [anon_sym_compl] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_sizeof] = ACTIONS(1969),
    [anon_sym___alignof__] = ACTIONS(1969),
    [anon_sym___alignof] = ACTIONS(1969),
    [anon_sym__alignof] = ACTIONS(1969),
    [anon_sym_alignof] = ACTIONS(1969),
    [anon_sym__Alignof] = ACTIONS(1969),
    [anon_sym_offsetof] = ACTIONS(1969),
    [anon_sym__Generic] = ACTIONS(1969),
    [anon_sym_asm] = ACTIONS(1969),
    [anon_sym___asm__] = ACTIONS(1969),
    [anon_sym___asm] = ACTIONS(1969),
    [sym_number_literal] = ACTIONS(1959),
    [anon_sym_L_SQUOTE] = ACTIONS(1959),
    [anon_sym_u_SQUOTE] = ACTIONS(1959),
    [anon_sym_U_SQUOTE] = ACTIONS(1959),
    [anon_sym_u8_SQUOTE] = ACTIONS(1959),
    [anon_sym_SQUOTE] = ACTIONS(1959),
    [anon_sym_L_DQUOTE] = ACTIONS(1959),
    [anon_sym_u_DQUOTE] = ACTIONS(1959),
    [anon_sym_U_DQUOTE] = ACTIONS(1959),
    [anon_sym_u8_DQUOTE] = ACTIONS(1959),
    [anon_sym_DQUOTE] = ACTIONS(1959),
    [sym_true] = ACTIONS(1969),
    [sym_false] = ACTIONS(1969),
    [anon_sym_NULL] = ACTIONS(1969),
    [anon_sym_nullptr] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1969),
    [anon_sym_R_DQUOTE] = ACTIONS(1959),
    [anon_sym_LR_DQUOTE] = ACTIONS(1959),
    [anon_sym_uR_DQUOTE] = ACTIONS(1959),
    [anon_sym_UR_DQUOTE] = ACTIONS(1959),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1959),
    [anon_sym_co_await] = ACTIONS(1969),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [sym_this] = ACTIONS(1969),
  },
  [STATE(2172)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_TILDE] = ACTIONS(5661),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___device__] = ACTIONS(5659),
    [anon_sym___host__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___forceinline__] = ACTIONS(5659),
    [anon_sym___noinline__] = ACTIONS(5659),
    [anon_sym_virtual] = ACTIONS(5659),
    [anon_sym_extern] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5661),
    [anon_sym___declspec] = ACTIONS(5659),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym___cdecl] = ACTIONS(5659),
    [anon_sym___clrcall] = ACTIONS(5659),
    [anon_sym___stdcall] = ACTIONS(5659),
    [anon_sym___fastcall] = ACTIONS(5659),
    [anon_sym___thiscall] = ACTIONS(5659),
    [anon_sym___vectorcall] = ACTIONS(5659),
    [anon_sym_signed] = ACTIONS(5659),
    [anon_sym_unsigned] = ACTIONS(5659),
    [anon_sym_long] = ACTIONS(5659),
    [anon_sym_short] = ACTIONS(5659),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [anon_sym_static] = ACTIONS(5659),
    [anon_sym_register] = ACTIONS(5659),
    [anon_sym_inline] = ACTIONS(5659),
    [anon_sym___inline] = ACTIONS(5659),
    [anon_sym___inline__] = ACTIONS(5659),
    [anon_sym___forceinline] = ACTIONS(5659),
    [anon_sym_thread_local] = ACTIONS(5659),
    [anon_sym___thread] = ACTIONS(5659),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [sym_primitive_type] = ACTIONS(5659),
    [anon_sym_enum] = ACTIONS(5659),
    [anon_sym_class] = ACTIONS(5659),
    [anon_sym_struct] = ACTIONS(5659),
    [anon_sym_union] = ACTIONS(5659),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_explicit] = ACTIONS(5659),
    [anon_sym_typename] = ACTIONS(5659),
    [anon_sym_template] = ACTIONS(5659),
    [anon_sym_operator] = ACTIONS(5659),
    [anon_sym_friend] = ACTIONS(5659),
    [anon_sym_using] = ACTIONS(5659),
    [anon_sym_concept] = ACTIONS(5659),
    [anon_sym___launch_bounds__] = ACTIONS(5659),
  },
  [STATE(2173)] = {
    [sym_identifier] = ACTIONS(5628),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5630),
    [anon_sym_COMMA] = ACTIONS(5630),
    [anon_sym_RPAREN] = ACTIONS(5630),
    [aux_sym_preproc_if_token2] = ACTIONS(5630),
    [aux_sym_preproc_else_token1] = ACTIONS(5630),
    [aux_sym_preproc_elif_token1] = ACTIONS(5628),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5630),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5630),
    [anon_sym_LPAREN2] = ACTIONS(5630),
    [anon_sym_DASH] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(5628),
    [anon_sym_STAR] = ACTIONS(5630),
    [anon_sym_SLASH] = ACTIONS(5628),
    [anon_sym_PERCENT] = ACTIONS(5630),
    [anon_sym_PIPE_PIPE] = ACTIONS(5630),
    [anon_sym_AMP_AMP] = ACTIONS(5630),
    [anon_sym_PIPE] = ACTIONS(5628),
    [anon_sym_CARET] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5628),
    [anon_sym_EQ_EQ] = ACTIONS(5630),
    [anon_sym_BANG_EQ] = ACTIONS(5630),
    [anon_sym_GT] = ACTIONS(5628),
    [anon_sym_GT_EQ] = ACTIONS(5630),
    [anon_sym_LT_EQ] = ACTIONS(5628),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_LT_LT] = ACTIONS(5628),
    [anon_sym_GT_GT] = ACTIONS(5630),
    [anon_sym_SEMI] = ACTIONS(5630),
    [anon_sym___extension__] = ACTIONS(5628),
    [anon_sym___global__] = ACTIONS(5628),
    [anon_sym___attribute__] = ACTIONS(5628),
    [anon_sym___attribute] = ACTIONS(5628),
    [anon_sym_LBRACE] = ACTIONS(5630),
    [anon_sym_RBRACE] = ACTIONS(5630),
    [anon_sym_LBRACK] = ACTIONS(5630),
    [anon_sym_RBRACK] = ACTIONS(5630),
    [anon_sym_const] = ACTIONS(5628),
    [anon_sym_constexpr] = ACTIONS(5628),
    [anon_sym_volatile] = ACTIONS(5628),
    [anon_sym_restrict] = ACTIONS(5628),
    [anon_sym___restrict__] = ACTIONS(5628),
    [anon_sym__Atomic] = ACTIONS(5628),
    [anon_sym__Noreturn] = ACTIONS(5628),
    [anon_sym_noreturn] = ACTIONS(5628),
    [anon_sym__Nonnull] = ACTIONS(5628),
    [anon_sym_mutable] = ACTIONS(5628),
    [anon_sym_constinit] = ACTIONS(5628),
    [anon_sym_consteval] = ACTIONS(5628),
    [anon_sym___shared__] = ACTIONS(5628),
    [anon_sym___local__] = ACTIONS(5628),
    [anon_sym___constant__] = ACTIONS(5628),
    [anon_sym___managed__] = ACTIONS(5628),
    [anon_sym___grid_constant__] = ACTIONS(5628),
    [anon_sym_alignas] = ACTIONS(5628),
    [anon_sym__Alignas] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(5630),
    [anon_sym_QMARK] = ACTIONS(5630),
    [anon_sym_LT_EQ_GT] = ACTIONS(5630),
    [anon_sym_or] = ACTIONS(5628),
    [anon_sym_and] = ACTIONS(5628),
    [anon_sym_bitor] = ACTIONS(5628),
    [anon_sym_xor] = ACTIONS(5628),
    [anon_sym_bitand] = ACTIONS(5628),
    [anon_sym_not_eq] = ACTIONS(5628),
    [anon_sym_DASH_DASH] = ACTIONS(5630),
    [anon_sym_PLUS_PLUS] = ACTIONS(5630),
    [anon_sym_DOT] = ACTIONS(5628),
    [anon_sym_DOT_STAR] = ACTIONS(5630),
    [anon_sym_DASH_GT] = ACTIONS(5630),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5628),
    [anon_sym_decltype] = ACTIONS(5628),
    [anon_sym_final] = ACTIONS(5628),
    [anon_sym_override] = ACTIONS(5628),
    [anon_sym_requires] = ACTIONS(5628),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5630),
  },
  [STATE(2174)] = {
    [sym_identifier] = ACTIONS(4350),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_TILDE] = ACTIONS(4352),
    [anon_sym_STAR] = ACTIONS(4352),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym___extension__] = ACTIONS(4350),
    [anon_sym___device__] = ACTIONS(4350),
    [anon_sym___host__] = ACTIONS(4350),
    [anon_sym___global__] = ACTIONS(4350),
    [anon_sym___forceinline__] = ACTIONS(4350),
    [anon_sym___noinline__] = ACTIONS(4350),
    [anon_sym_virtual] = ACTIONS(4350),
    [anon_sym_extern] = ACTIONS(4350),
    [anon_sym___attribute__] = ACTIONS(4350),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4352),
    [anon_sym___declspec] = ACTIONS(4350),
    [anon_sym___based] = ACTIONS(4350),
    [anon_sym___cdecl] = ACTIONS(4350),
    [anon_sym___clrcall] = ACTIONS(4350),
    [anon_sym___stdcall] = ACTIONS(4350),
    [anon_sym___fastcall] = ACTIONS(4350),
    [anon_sym___thiscall] = ACTIONS(4350),
    [anon_sym___vectorcall] = ACTIONS(4350),
    [anon_sym_signed] = ACTIONS(4350),
    [anon_sym_unsigned] = ACTIONS(4350),
    [anon_sym_long] = ACTIONS(4350),
    [anon_sym_short] = ACTIONS(4350),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_static] = ACTIONS(4350),
    [anon_sym_register] = ACTIONS(4350),
    [anon_sym_inline] = ACTIONS(4350),
    [anon_sym___inline] = ACTIONS(4350),
    [anon_sym___inline__] = ACTIONS(4350),
    [anon_sym___forceinline] = ACTIONS(4350),
    [anon_sym_thread_local] = ACTIONS(4350),
    [anon_sym___thread] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4350),
    [anon_sym_volatile] = ACTIONS(4350),
    [anon_sym_restrict] = ACTIONS(4350),
    [anon_sym___restrict__] = ACTIONS(4350),
    [anon_sym__Atomic] = ACTIONS(4350),
    [anon_sym__Noreturn] = ACTIONS(4350),
    [anon_sym_noreturn] = ACTIONS(4350),
    [anon_sym__Nonnull] = ACTIONS(4350),
    [anon_sym_mutable] = ACTIONS(4350),
    [anon_sym_constinit] = ACTIONS(4350),
    [anon_sym_consteval] = ACTIONS(4350),
    [anon_sym___shared__] = ACTIONS(4350),
    [anon_sym___local__] = ACTIONS(4350),
    [anon_sym___constant__] = ACTIONS(4350),
    [anon_sym___managed__] = ACTIONS(4350),
    [anon_sym___grid_constant__] = ACTIONS(4350),
    [anon_sym_alignas] = ACTIONS(4350),
    [anon_sym__Alignas] = ACTIONS(4350),
    [sym_primitive_type] = ACTIONS(4350),
    [anon_sym_enum] = ACTIONS(4350),
    [anon_sym_class] = ACTIONS(4350),
    [anon_sym_struct] = ACTIONS(4350),
    [anon_sym_union] = ACTIONS(4350),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4350),
    [anon_sym_decltype] = ACTIONS(4350),
    [anon_sym_explicit] = ACTIONS(4350),
    [anon_sym_typename] = ACTIONS(4350),
    [anon_sym_template] = ACTIONS(4350),
    [anon_sym_operator] = ACTIONS(4350),
    [anon_sym_friend] = ACTIONS(4350),
    [anon_sym_using] = ACTIONS(4350),
    [anon_sym_concept] = ACTIONS(4350),
    [anon_sym___launch_bounds__] = ACTIONS(4350),
  },
  [STATE(2175)] = {
    [sym_template_argument_list] = STATE(2196),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4514),
    [anon_sym_RPAREN] = ACTIONS(4516),
    [anon_sym_LPAREN2] = ACTIONS(4516),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4523),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4516),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4523),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4514),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(5868),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym___extension__] = ACTIONS(4519),
    [anon_sym___global__] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_EQ] = ACTIONS(4521),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4519),
    [anon_sym_volatile] = ACTIONS(4519),
    [anon_sym_restrict] = ACTIONS(4519),
    [anon_sym___restrict__] = ACTIONS(4519),
    [anon_sym__Atomic] = ACTIONS(4519),
    [anon_sym__Noreturn] = ACTIONS(4519),
    [anon_sym_noreturn] = ACTIONS(4519),
    [anon_sym__Nonnull] = ACTIONS(4519),
    [anon_sym_mutable] = ACTIONS(4519),
    [anon_sym_constinit] = ACTIONS(4519),
    [anon_sym_consteval] = ACTIONS(4519),
    [anon_sym___shared__] = ACTIONS(4519),
    [anon_sym___local__] = ACTIONS(4519),
    [anon_sym___constant__] = ACTIONS(4519),
    [anon_sym___managed__] = ACTIONS(4519),
    [anon_sym___grid_constant__] = ACTIONS(4519),
    [anon_sym_alignas] = ACTIONS(4519),
    [anon_sym__Alignas] = ACTIONS(4519),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4514),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4514),
    [anon_sym_or_eq] = ACTIONS(4514),
    [anon_sym_xor_eq] = ACTIONS(4514),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4514),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4514),
    [anon_sym_not_eq] = ACTIONS(4514),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4514),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4519),
    [anon_sym_decltype] = ACTIONS(4519),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
  },
  [STATE(2176)] = {
    [sym_identifier] = ACTIONS(4356),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_TILDE] = ACTIONS(4358),
    [anon_sym_STAR] = ACTIONS(4358),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym___extension__] = ACTIONS(4356),
    [anon_sym___device__] = ACTIONS(4356),
    [anon_sym___host__] = ACTIONS(4356),
    [anon_sym___global__] = ACTIONS(4356),
    [anon_sym___forceinline__] = ACTIONS(4356),
    [anon_sym___noinline__] = ACTIONS(4356),
    [anon_sym_virtual] = ACTIONS(4356),
    [anon_sym_extern] = ACTIONS(4356),
    [anon_sym___attribute__] = ACTIONS(4356),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4358),
    [anon_sym___declspec] = ACTIONS(4356),
    [anon_sym___based] = ACTIONS(4356),
    [anon_sym___cdecl] = ACTIONS(4356),
    [anon_sym___clrcall] = ACTIONS(4356),
    [anon_sym___stdcall] = ACTIONS(4356),
    [anon_sym___fastcall] = ACTIONS(4356),
    [anon_sym___thiscall] = ACTIONS(4356),
    [anon_sym___vectorcall] = ACTIONS(4356),
    [anon_sym_signed] = ACTIONS(4356),
    [anon_sym_unsigned] = ACTIONS(4356),
    [anon_sym_long] = ACTIONS(4356),
    [anon_sym_short] = ACTIONS(4356),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_static] = ACTIONS(4356),
    [anon_sym_register] = ACTIONS(4356),
    [anon_sym_inline] = ACTIONS(4356),
    [anon_sym___inline] = ACTIONS(4356),
    [anon_sym___inline__] = ACTIONS(4356),
    [anon_sym___forceinline] = ACTIONS(4356),
    [anon_sym_thread_local] = ACTIONS(4356),
    [anon_sym___thread] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4356),
    [anon_sym_volatile] = ACTIONS(4356),
    [anon_sym_restrict] = ACTIONS(4356),
    [anon_sym___restrict__] = ACTIONS(4356),
    [anon_sym__Atomic] = ACTIONS(4356),
    [anon_sym__Noreturn] = ACTIONS(4356),
    [anon_sym_noreturn] = ACTIONS(4356),
    [anon_sym__Nonnull] = ACTIONS(4356),
    [anon_sym_mutable] = ACTIONS(4356),
    [anon_sym_constinit] = ACTIONS(4356),
    [anon_sym_consteval] = ACTIONS(4356),
    [anon_sym___shared__] = ACTIONS(4356),
    [anon_sym___local__] = ACTIONS(4356),
    [anon_sym___constant__] = ACTIONS(4356),
    [anon_sym___managed__] = ACTIONS(4356),
    [anon_sym___grid_constant__] = ACTIONS(4356),
    [anon_sym_alignas] = ACTIONS(4356),
    [anon_sym__Alignas] = ACTIONS(4356),
    [sym_primitive_type] = ACTIONS(4356),
    [anon_sym_enum] = ACTIONS(4356),
    [anon_sym_class] = ACTIONS(4356),
    [anon_sym_struct] = ACTIONS(4356),
    [anon_sym_union] = ACTIONS(4356),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4356),
    [anon_sym_decltype] = ACTIONS(4356),
    [anon_sym_explicit] = ACTIONS(4356),
    [anon_sym_typename] = ACTIONS(4356),
    [anon_sym_template] = ACTIONS(4356),
    [anon_sym_operator] = ACTIONS(4356),
    [anon_sym_friend] = ACTIONS(4356),
    [anon_sym_using] = ACTIONS(4356),
    [anon_sym_concept] = ACTIONS(4356),
    [anon_sym___launch_bounds__] = ACTIONS(4356),
  },
  [STATE(2177)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4557),
    [anon_sym_COMMA] = ACTIONS(4557),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4562),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym___extension__] = ACTIONS(4560),
    [anon_sym___global__] = ACTIONS(4560),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4557),
    [anon_sym_EQ] = ACTIONS(4562),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4560),
    [anon_sym_volatile] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym___restrict__] = ACTIONS(4560),
    [anon_sym__Atomic] = ACTIONS(4560),
    [anon_sym__Noreturn] = ACTIONS(4560),
    [anon_sym_noreturn] = ACTIONS(4560),
    [anon_sym__Nonnull] = ACTIONS(4560),
    [anon_sym_mutable] = ACTIONS(4560),
    [anon_sym_constinit] = ACTIONS(4560),
    [anon_sym_consteval] = ACTIONS(4560),
    [anon_sym___shared__] = ACTIONS(4560),
    [anon_sym___local__] = ACTIONS(4560),
    [anon_sym___constant__] = ACTIONS(4560),
    [anon_sym___managed__] = ACTIONS(4560),
    [anon_sym___grid_constant__] = ACTIONS(4560),
    [anon_sym_alignas] = ACTIONS(4560),
    [anon_sym__Alignas] = ACTIONS(4560),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4562),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4555),
    [anon_sym_or_eq] = ACTIONS(4555),
    [anon_sym_xor_eq] = ACTIONS(4555),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4555),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4555),
    [anon_sym_not_eq] = ACTIONS(4555),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4560),
    [anon_sym_decltype] = ACTIONS(4560),
    [anon_sym_GT2] = ACTIONS(4557),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
  },
  [STATE(2178)] = {
    [sym_identifier] = ACTIONS(5665),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_TILDE] = ACTIONS(5667),
    [anon_sym_STAR] = ACTIONS(5667),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_AMP] = ACTIONS(5665),
    [anon_sym___extension__] = ACTIONS(5665),
    [anon_sym___device__] = ACTIONS(5665),
    [anon_sym___host__] = ACTIONS(5665),
    [anon_sym___global__] = ACTIONS(5665),
    [anon_sym___forceinline__] = ACTIONS(5665),
    [anon_sym___noinline__] = ACTIONS(5665),
    [anon_sym_virtual] = ACTIONS(5665),
    [anon_sym_extern] = ACTIONS(5665),
    [anon_sym___attribute__] = ACTIONS(5665),
    [anon_sym___attribute] = ACTIONS(5665),
    [anon_sym_COLON_COLON] = ACTIONS(5667),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5667),
    [anon_sym___declspec] = ACTIONS(5665),
    [anon_sym___based] = ACTIONS(5665),
    [anon_sym___cdecl] = ACTIONS(5665),
    [anon_sym___clrcall] = ACTIONS(5665),
    [anon_sym___stdcall] = ACTIONS(5665),
    [anon_sym___fastcall] = ACTIONS(5665),
    [anon_sym___thiscall] = ACTIONS(5665),
    [anon_sym___vectorcall] = ACTIONS(5665),
    [anon_sym_signed] = ACTIONS(5665),
    [anon_sym_unsigned] = ACTIONS(5665),
    [anon_sym_long] = ACTIONS(5665),
    [anon_sym_short] = ACTIONS(5665),
    [anon_sym_LBRACK] = ACTIONS(5665),
    [anon_sym_static] = ACTIONS(5665),
    [anon_sym_register] = ACTIONS(5665),
    [anon_sym_inline] = ACTIONS(5665),
    [anon_sym___inline] = ACTIONS(5665),
    [anon_sym___inline__] = ACTIONS(5665),
    [anon_sym___forceinline] = ACTIONS(5665),
    [anon_sym_thread_local] = ACTIONS(5665),
    [anon_sym___thread] = ACTIONS(5665),
    [anon_sym_const] = ACTIONS(5665),
    [anon_sym_constexpr] = ACTIONS(5665),
    [anon_sym_volatile] = ACTIONS(5665),
    [anon_sym_restrict] = ACTIONS(5665),
    [anon_sym___restrict__] = ACTIONS(5665),
    [anon_sym__Atomic] = ACTIONS(5665),
    [anon_sym__Noreturn] = ACTIONS(5665),
    [anon_sym_noreturn] = ACTIONS(5665),
    [anon_sym__Nonnull] = ACTIONS(5665),
    [anon_sym_mutable] = ACTIONS(5665),
    [anon_sym_constinit] = ACTIONS(5665),
    [anon_sym_consteval] = ACTIONS(5665),
    [anon_sym___shared__] = ACTIONS(5665),
    [anon_sym___local__] = ACTIONS(5665),
    [anon_sym___constant__] = ACTIONS(5665),
    [anon_sym___managed__] = ACTIONS(5665),
    [anon_sym___grid_constant__] = ACTIONS(5665),
    [anon_sym_alignas] = ACTIONS(5665),
    [anon_sym__Alignas] = ACTIONS(5665),
    [sym_primitive_type] = ACTIONS(5665),
    [anon_sym_enum] = ACTIONS(5665),
    [anon_sym_class] = ACTIONS(5665),
    [anon_sym_struct] = ACTIONS(5665),
    [anon_sym_union] = ACTIONS(5665),
    [anon_sym_or] = ACTIONS(5665),
    [anon_sym_and] = ACTIONS(5665),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5665),
    [anon_sym_decltype] = ACTIONS(5665),
    [anon_sym_explicit] = ACTIONS(5665),
    [anon_sym_typename] = ACTIONS(5665),
    [anon_sym_template] = ACTIONS(5665),
    [anon_sym_operator] = ACTIONS(5665),
    [anon_sym_friend] = ACTIONS(5665),
    [anon_sym_using] = ACTIONS(5665),
    [anon_sym_concept] = ACTIONS(5665),
    [anon_sym___launch_bounds__] = ACTIONS(5665),
  },
  [STATE(2179)] = {
    [sym_identifier] = ACTIONS(1928),
    [anon_sym_LPAREN2] = ACTIONS(1926),
    [anon_sym_TILDE] = ACTIONS(1926),
    [anon_sym_STAR] = ACTIONS(1926),
    [anon_sym_PIPE_PIPE] = ACTIONS(1926),
    [anon_sym_AMP_AMP] = ACTIONS(1926),
    [anon_sym_AMP] = ACTIONS(1928),
    [anon_sym___extension__] = ACTIONS(1928),
    [anon_sym___device__] = ACTIONS(1928),
    [anon_sym___host__] = ACTIONS(1928),
    [anon_sym___global__] = ACTIONS(1928),
    [anon_sym___forceinline__] = ACTIONS(1928),
    [anon_sym___noinline__] = ACTIONS(1928),
    [anon_sym_virtual] = ACTIONS(1928),
    [anon_sym_extern] = ACTIONS(1928),
    [anon_sym___attribute__] = ACTIONS(1928),
    [anon_sym___attribute] = ACTIONS(1928),
    [anon_sym_COLON_COLON] = ACTIONS(1926),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1926),
    [anon_sym___declspec] = ACTIONS(1928),
    [anon_sym___based] = ACTIONS(1928),
    [anon_sym___cdecl] = ACTIONS(1928),
    [anon_sym___clrcall] = ACTIONS(1928),
    [anon_sym___stdcall] = ACTIONS(1928),
    [anon_sym___fastcall] = ACTIONS(1928),
    [anon_sym___thiscall] = ACTIONS(1928),
    [anon_sym___vectorcall] = ACTIONS(1928),
    [anon_sym_signed] = ACTIONS(1928),
    [anon_sym_unsigned] = ACTIONS(1928),
    [anon_sym_long] = ACTIONS(1928),
    [anon_sym_short] = ACTIONS(1928),
    [anon_sym_LBRACK] = ACTIONS(1928),
    [anon_sym_static] = ACTIONS(1928),
    [anon_sym_register] = ACTIONS(1928),
    [anon_sym_inline] = ACTIONS(1928),
    [anon_sym___inline] = ACTIONS(1928),
    [anon_sym___inline__] = ACTIONS(1928),
    [anon_sym___forceinline] = ACTIONS(1928),
    [anon_sym_thread_local] = ACTIONS(1928),
    [anon_sym___thread] = ACTIONS(1928),
    [anon_sym_const] = ACTIONS(1928),
    [anon_sym_constexpr] = ACTIONS(1928),
    [anon_sym_volatile] = ACTIONS(1928),
    [anon_sym_restrict] = ACTIONS(1928),
    [anon_sym___restrict__] = ACTIONS(1928),
    [anon_sym__Atomic] = ACTIONS(1928),
    [anon_sym__Noreturn] = ACTIONS(1928),
    [anon_sym_noreturn] = ACTIONS(1928),
    [anon_sym__Nonnull] = ACTIONS(1928),
    [anon_sym_mutable] = ACTIONS(1928),
    [anon_sym_constinit] = ACTIONS(1928),
    [anon_sym_consteval] = ACTIONS(1928),
    [anon_sym___shared__] = ACTIONS(1928),
    [anon_sym___local__] = ACTIONS(1928),
    [anon_sym___constant__] = ACTIONS(1928),
    [anon_sym___managed__] = ACTIONS(1928),
    [anon_sym___grid_constant__] = ACTIONS(1928),
    [anon_sym_alignas] = ACTIONS(1928),
    [anon_sym__Alignas] = ACTIONS(1928),
    [sym_primitive_type] = ACTIONS(1928),
    [anon_sym_enum] = ACTIONS(1928),
    [anon_sym_class] = ACTIONS(1928),
    [anon_sym_struct] = ACTIONS(1928),
    [anon_sym_union] = ACTIONS(1928),
    [anon_sym_or] = ACTIONS(1928),
    [anon_sym_and] = ACTIONS(1928),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1928),
    [anon_sym_decltype] = ACTIONS(1928),
    [anon_sym_explicit] = ACTIONS(1928),
    [anon_sym_typename] = ACTIONS(1928),
    [anon_sym_template] = ACTIONS(1928),
    [anon_sym_operator] = ACTIONS(1928),
    [anon_sym_friend] = ACTIONS(1928),
    [anon_sym_using] = ACTIONS(1928),
    [anon_sym_concept] = ACTIONS(1928),
    [anon_sym___launch_bounds__] = ACTIONS(1928),
  },
  [STATE(2180)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_BANG] = ACTIONS(5145),
    [anon_sym_TILDE] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5145),
    [anon_sym_AMP] = ACTIONS(5145),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym_COLON_COLON] = ACTIONS(5145),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_static] = ACTIONS(5143),
    [anon_sym_RBRACK] = ACTIONS(5145),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_not] = ACTIONS(5143),
    [anon_sym_compl] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_sizeof] = ACTIONS(5143),
    [anon_sym___alignof__] = ACTIONS(5143),
    [anon_sym___alignof] = ACTIONS(5143),
    [anon_sym__alignof] = ACTIONS(5143),
    [anon_sym_alignof] = ACTIONS(5143),
    [anon_sym__Alignof] = ACTIONS(5143),
    [anon_sym_offsetof] = ACTIONS(5143),
    [anon_sym__Generic] = ACTIONS(5143),
    [anon_sym_asm] = ACTIONS(5143),
    [anon_sym___asm__] = ACTIONS(5143),
    [anon_sym___asm] = ACTIONS(5143),
    [sym_number_literal] = ACTIONS(5145),
    [anon_sym_L_SQUOTE] = ACTIONS(5145),
    [anon_sym_u_SQUOTE] = ACTIONS(5145),
    [anon_sym_U_SQUOTE] = ACTIONS(5145),
    [anon_sym_u8_SQUOTE] = ACTIONS(5145),
    [anon_sym_SQUOTE] = ACTIONS(5145),
    [anon_sym_L_DQUOTE] = ACTIONS(5145),
    [anon_sym_u_DQUOTE] = ACTIONS(5145),
    [anon_sym_U_DQUOTE] = ACTIONS(5145),
    [anon_sym_u8_DQUOTE] = ACTIONS(5145),
    [anon_sym_DQUOTE] = ACTIONS(5145),
    [sym_true] = ACTIONS(5143),
    [sym_false] = ACTIONS(5143),
    [anon_sym_NULL] = ACTIONS(5143),
    [anon_sym_nullptr] = ACTIONS(5143),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5143),
    [anon_sym_template] = ACTIONS(5143),
    [anon_sym_delete] = ACTIONS(5143),
    [anon_sym_R_DQUOTE] = ACTIONS(5145),
    [anon_sym_LR_DQUOTE] = ACTIONS(5145),
    [anon_sym_uR_DQUOTE] = ACTIONS(5145),
    [anon_sym_UR_DQUOTE] = ACTIONS(5145),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5145),
    [anon_sym_co_await] = ACTIONS(5143),
    [anon_sym_new] = ACTIONS(5143),
    [anon_sym_requires] = ACTIONS(5143),
    [sym_this] = ACTIONS(5143),
  },
  [STATE(2181)] = {
    [sym_identifier] = ACTIONS(5688),
    [anon_sym_LPAREN2] = ACTIONS(5690),
    [anon_sym_TILDE] = ACTIONS(5690),
    [anon_sym_STAR] = ACTIONS(5690),
    [anon_sym_PIPE_PIPE] = ACTIONS(5690),
    [anon_sym_AMP_AMP] = ACTIONS(5690),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym___extension__] = ACTIONS(5688),
    [anon_sym___device__] = ACTIONS(5688),
    [anon_sym___host__] = ACTIONS(5688),
    [anon_sym___global__] = ACTIONS(5688),
    [anon_sym___forceinline__] = ACTIONS(5688),
    [anon_sym___noinline__] = ACTIONS(5688),
    [anon_sym_virtual] = ACTIONS(5688),
    [anon_sym_extern] = ACTIONS(5688),
    [anon_sym___attribute__] = ACTIONS(5688),
    [anon_sym___attribute] = ACTIONS(5688),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5690),
    [anon_sym___declspec] = ACTIONS(5688),
    [anon_sym___based] = ACTIONS(5688),
    [anon_sym___cdecl] = ACTIONS(5688),
    [anon_sym___clrcall] = ACTIONS(5688),
    [anon_sym___stdcall] = ACTIONS(5688),
    [anon_sym___fastcall] = ACTIONS(5688),
    [anon_sym___thiscall] = ACTIONS(5688),
    [anon_sym___vectorcall] = ACTIONS(5688),
    [anon_sym_signed] = ACTIONS(5688),
    [anon_sym_unsigned] = ACTIONS(5688),
    [anon_sym_long] = ACTIONS(5688),
    [anon_sym_short] = ACTIONS(5688),
    [anon_sym_LBRACK] = ACTIONS(5688),
    [anon_sym_static] = ACTIONS(5688),
    [anon_sym_register] = ACTIONS(5688),
    [anon_sym_inline] = ACTIONS(5688),
    [anon_sym___inline] = ACTIONS(5688),
    [anon_sym___inline__] = ACTIONS(5688),
    [anon_sym___forceinline] = ACTIONS(5688),
    [anon_sym_thread_local] = ACTIONS(5688),
    [anon_sym___thread] = ACTIONS(5688),
    [anon_sym_const] = ACTIONS(5688),
    [anon_sym_constexpr] = ACTIONS(5688),
    [anon_sym_volatile] = ACTIONS(5688),
    [anon_sym_restrict] = ACTIONS(5688),
    [anon_sym___restrict__] = ACTIONS(5688),
    [anon_sym__Atomic] = ACTIONS(5688),
    [anon_sym__Noreturn] = ACTIONS(5688),
    [anon_sym_noreturn] = ACTIONS(5688),
    [anon_sym__Nonnull] = ACTIONS(5688),
    [anon_sym_mutable] = ACTIONS(5688),
    [anon_sym_constinit] = ACTIONS(5688),
    [anon_sym_consteval] = ACTIONS(5688),
    [anon_sym___shared__] = ACTIONS(5688),
    [anon_sym___local__] = ACTIONS(5688),
    [anon_sym___constant__] = ACTIONS(5688),
    [anon_sym___managed__] = ACTIONS(5688),
    [anon_sym___grid_constant__] = ACTIONS(5688),
    [anon_sym_alignas] = ACTIONS(5688),
    [anon_sym__Alignas] = ACTIONS(5688),
    [sym_primitive_type] = ACTIONS(5688),
    [anon_sym_enum] = ACTIONS(5688),
    [anon_sym_class] = ACTIONS(5688),
    [anon_sym_struct] = ACTIONS(5688),
    [anon_sym_union] = ACTIONS(5688),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_and] = ACTIONS(5688),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5688),
    [anon_sym_decltype] = ACTIONS(5688),
    [anon_sym_explicit] = ACTIONS(5688),
    [anon_sym_typename] = ACTIONS(5688),
    [anon_sym_template] = ACTIONS(5688),
    [anon_sym_operator] = ACTIONS(5688),
    [anon_sym_friend] = ACTIONS(5688),
    [anon_sym_using] = ACTIONS(5688),
    [anon_sym_concept] = ACTIONS(5688),
    [anon_sym___launch_bounds__] = ACTIONS(5688),
  },
  [STATE(2182)] = {
    [sym_identifier] = ACTIONS(1932),
    [anon_sym_LPAREN2] = ACTIONS(1930),
    [anon_sym_TILDE] = ACTIONS(1930),
    [anon_sym_STAR] = ACTIONS(1930),
    [anon_sym_PIPE_PIPE] = ACTIONS(1930),
    [anon_sym_AMP_AMP] = ACTIONS(1930),
    [anon_sym_AMP] = ACTIONS(1932),
    [anon_sym___extension__] = ACTIONS(1932),
    [anon_sym___device__] = ACTIONS(1932),
    [anon_sym___host__] = ACTIONS(1932),
    [anon_sym___global__] = ACTIONS(1932),
    [anon_sym___forceinline__] = ACTIONS(1932),
    [anon_sym___noinline__] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1932),
    [anon_sym_extern] = ACTIONS(1932),
    [anon_sym___attribute__] = ACTIONS(1932),
    [anon_sym___attribute] = ACTIONS(1932),
    [anon_sym_COLON_COLON] = ACTIONS(1930),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1930),
    [anon_sym___declspec] = ACTIONS(1932),
    [anon_sym___based] = ACTIONS(1932),
    [anon_sym___cdecl] = ACTIONS(1932),
    [anon_sym___clrcall] = ACTIONS(1932),
    [anon_sym___stdcall] = ACTIONS(1932),
    [anon_sym___fastcall] = ACTIONS(1932),
    [anon_sym___thiscall] = ACTIONS(1932),
    [anon_sym___vectorcall] = ACTIONS(1932),
    [anon_sym_signed] = ACTIONS(1932),
    [anon_sym_unsigned] = ACTIONS(1932),
    [anon_sym_long] = ACTIONS(1932),
    [anon_sym_short] = ACTIONS(1932),
    [anon_sym_LBRACK] = ACTIONS(1932),
    [anon_sym_static] = ACTIONS(1932),
    [anon_sym_register] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1932),
    [anon_sym___inline] = ACTIONS(1932),
    [anon_sym___inline__] = ACTIONS(1932),
    [anon_sym___forceinline] = ACTIONS(1932),
    [anon_sym_thread_local] = ACTIONS(1932),
    [anon_sym___thread] = ACTIONS(1932),
    [anon_sym_const] = ACTIONS(1932),
    [anon_sym_constexpr] = ACTIONS(1932),
    [anon_sym_volatile] = ACTIONS(1932),
    [anon_sym_restrict] = ACTIONS(1932),
    [anon_sym___restrict__] = ACTIONS(1932),
    [anon_sym__Atomic] = ACTIONS(1932),
    [anon_sym__Noreturn] = ACTIONS(1932),
    [anon_sym_noreturn] = ACTIONS(1932),
    [anon_sym__Nonnull] = ACTIONS(1932),
    [anon_sym_mutable] = ACTIONS(1932),
    [anon_sym_constinit] = ACTIONS(1932),
    [anon_sym_consteval] = ACTIONS(1932),
    [anon_sym___shared__] = ACTIONS(1932),
    [anon_sym___local__] = ACTIONS(1932),
    [anon_sym___constant__] = ACTIONS(1932),
    [anon_sym___managed__] = ACTIONS(1932),
    [anon_sym___grid_constant__] = ACTIONS(1932),
    [anon_sym_alignas] = ACTIONS(1932),
    [anon_sym__Alignas] = ACTIONS(1932),
    [sym_primitive_type] = ACTIONS(1932),
    [anon_sym_enum] = ACTIONS(1932),
    [anon_sym_class] = ACTIONS(1932),
    [anon_sym_struct] = ACTIONS(1932),
    [anon_sym_union] = ACTIONS(1932),
    [anon_sym_or] = ACTIONS(1932),
    [anon_sym_and] = ACTIONS(1932),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1932),
    [anon_sym_decltype] = ACTIONS(1932),
    [anon_sym_explicit] = ACTIONS(1932),
    [anon_sym_typename] = ACTIONS(1932),
    [anon_sym_template] = ACTIONS(1932),
    [anon_sym_operator] = ACTIONS(1932),
    [anon_sym_friend] = ACTIONS(1932),
    [anon_sym_using] = ACTIONS(1932),
    [anon_sym_concept] = ACTIONS(1932),
    [anon_sym___launch_bounds__] = ACTIONS(1932),
  },
  [STATE(2183)] = {
    [sym_identifier] = ACTIONS(4330),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_TILDE] = ACTIONS(4332),
    [anon_sym_STAR] = ACTIONS(4332),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym___extension__] = ACTIONS(4330),
    [anon_sym___device__] = ACTIONS(4330),
    [anon_sym___host__] = ACTIONS(4330),
    [anon_sym___global__] = ACTIONS(4330),
    [anon_sym___forceinline__] = ACTIONS(4330),
    [anon_sym___noinline__] = ACTIONS(4330),
    [anon_sym_virtual] = ACTIONS(4330),
    [anon_sym_extern] = ACTIONS(4330),
    [anon_sym___attribute__] = ACTIONS(4330),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4332),
    [anon_sym___declspec] = ACTIONS(4330),
    [anon_sym___based] = ACTIONS(4330),
    [anon_sym___cdecl] = ACTIONS(4330),
    [anon_sym___clrcall] = ACTIONS(4330),
    [anon_sym___stdcall] = ACTIONS(4330),
    [anon_sym___fastcall] = ACTIONS(4330),
    [anon_sym___thiscall] = ACTIONS(4330),
    [anon_sym___vectorcall] = ACTIONS(4330),
    [anon_sym_signed] = ACTIONS(4330),
    [anon_sym_unsigned] = ACTIONS(4330),
    [anon_sym_long] = ACTIONS(4330),
    [anon_sym_short] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4330),
    [anon_sym_static] = ACTIONS(4330),
    [anon_sym_register] = ACTIONS(4330),
    [anon_sym_inline] = ACTIONS(4330),
    [anon_sym___inline] = ACTIONS(4330),
    [anon_sym___inline__] = ACTIONS(4330),
    [anon_sym___forceinline] = ACTIONS(4330),
    [anon_sym_thread_local] = ACTIONS(4330),
    [anon_sym___thread] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4330),
    [anon_sym_volatile] = ACTIONS(4330),
    [anon_sym_restrict] = ACTIONS(4330),
    [anon_sym___restrict__] = ACTIONS(4330),
    [anon_sym__Atomic] = ACTIONS(4330),
    [anon_sym__Noreturn] = ACTIONS(4330),
    [anon_sym_noreturn] = ACTIONS(4330),
    [anon_sym__Nonnull] = ACTIONS(4330),
    [anon_sym_mutable] = ACTIONS(4330),
    [anon_sym_constinit] = ACTIONS(4330),
    [anon_sym_consteval] = ACTIONS(4330),
    [anon_sym___shared__] = ACTIONS(4330),
    [anon_sym___local__] = ACTIONS(4330),
    [anon_sym___constant__] = ACTIONS(4330),
    [anon_sym___managed__] = ACTIONS(4330),
    [anon_sym___grid_constant__] = ACTIONS(4330),
    [anon_sym_alignas] = ACTIONS(4330),
    [anon_sym__Alignas] = ACTIONS(4330),
    [sym_primitive_type] = ACTIONS(4330),
    [anon_sym_enum] = ACTIONS(4330),
    [anon_sym_class] = ACTIONS(4330),
    [anon_sym_struct] = ACTIONS(4330),
    [anon_sym_union] = ACTIONS(4330),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4330),
    [anon_sym_decltype] = ACTIONS(4330),
    [anon_sym_explicit] = ACTIONS(4330),
    [anon_sym_typename] = ACTIONS(4330),
    [anon_sym_template] = ACTIONS(4330),
    [anon_sym_operator] = ACTIONS(4330),
    [anon_sym_friend] = ACTIONS(4330),
    [anon_sym_using] = ACTIONS(4330),
    [anon_sym_concept] = ACTIONS(4330),
    [anon_sym___launch_bounds__] = ACTIONS(4330),
  },
  [STATE(2184)] = {
    [sym_identifier] = ACTIONS(5871),
    [anon_sym_LPAREN2] = ACTIONS(5873),
    [anon_sym_TILDE] = ACTIONS(5873),
    [anon_sym_STAR] = ACTIONS(5873),
    [anon_sym_PIPE_PIPE] = ACTIONS(5875),
    [anon_sym_AMP_AMP] = ACTIONS(5864),
    [anon_sym_AMP] = ACTIONS(5871),
    [anon_sym___extension__] = ACTIONS(5871),
    [anon_sym___device__] = ACTIONS(5871),
    [anon_sym___host__] = ACTIONS(5871),
    [anon_sym___global__] = ACTIONS(5871),
    [anon_sym___forceinline__] = ACTIONS(5871),
    [anon_sym___noinline__] = ACTIONS(5871),
    [anon_sym_virtual] = ACTIONS(5871),
    [anon_sym_extern] = ACTIONS(5871),
    [anon_sym___attribute__] = ACTIONS(5871),
    [anon_sym___attribute] = ACTIONS(5871),
    [anon_sym_COLON_COLON] = ACTIONS(5873),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5873),
    [anon_sym___declspec] = ACTIONS(5871),
    [anon_sym___based] = ACTIONS(5871),
    [anon_sym___cdecl] = ACTIONS(5871),
    [anon_sym___clrcall] = ACTIONS(5871),
    [anon_sym___stdcall] = ACTIONS(5871),
    [anon_sym___fastcall] = ACTIONS(5871),
    [anon_sym___thiscall] = ACTIONS(5871),
    [anon_sym___vectorcall] = ACTIONS(5871),
    [anon_sym_signed] = ACTIONS(5871),
    [anon_sym_unsigned] = ACTIONS(5871),
    [anon_sym_long] = ACTIONS(5871),
    [anon_sym_short] = ACTIONS(5871),
    [anon_sym_LBRACK] = ACTIONS(5871),
    [anon_sym_static] = ACTIONS(5871),
    [anon_sym_register] = ACTIONS(5871),
    [anon_sym_inline] = ACTIONS(5871),
    [anon_sym___inline] = ACTIONS(5871),
    [anon_sym___inline__] = ACTIONS(5871),
    [anon_sym___forceinline] = ACTIONS(5871),
    [anon_sym_thread_local] = ACTIONS(5871),
    [anon_sym___thread] = ACTIONS(5871),
    [anon_sym_const] = ACTIONS(5871),
    [anon_sym_constexpr] = ACTIONS(5871),
    [anon_sym_volatile] = ACTIONS(5871),
    [anon_sym_restrict] = ACTIONS(5871),
    [anon_sym___restrict__] = ACTIONS(5871),
    [anon_sym__Atomic] = ACTIONS(5871),
    [anon_sym__Noreturn] = ACTIONS(5871),
    [anon_sym_noreturn] = ACTIONS(5871),
    [anon_sym__Nonnull] = ACTIONS(5871),
    [anon_sym_mutable] = ACTIONS(5871),
    [anon_sym_constinit] = ACTIONS(5871),
    [anon_sym_consteval] = ACTIONS(5871),
    [anon_sym___shared__] = ACTIONS(5871),
    [anon_sym___local__] = ACTIONS(5871),
    [anon_sym___constant__] = ACTIONS(5871),
    [anon_sym___managed__] = ACTIONS(5871),
    [anon_sym___grid_constant__] = ACTIONS(5871),
    [anon_sym_alignas] = ACTIONS(5871),
    [anon_sym__Alignas] = ACTIONS(5871),
    [sym_primitive_type] = ACTIONS(5871),
    [anon_sym_enum] = ACTIONS(5871),
    [anon_sym_class] = ACTIONS(5871),
    [anon_sym_struct] = ACTIONS(5871),
    [anon_sym_union] = ACTIONS(5871),
    [anon_sym_or] = ACTIONS(5877),
    [anon_sym_and] = ACTIONS(5866),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5871),
    [anon_sym_decltype] = ACTIONS(5871),
    [anon_sym_explicit] = ACTIONS(5871),
    [anon_sym_typename] = ACTIONS(5871),
    [anon_sym_template] = ACTIONS(5871),
    [anon_sym_operator] = ACTIONS(5871),
    [anon_sym_friend] = ACTIONS(5871),
    [anon_sym_using] = ACTIONS(5871),
    [anon_sym_concept] = ACTIONS(5871),
    [anon_sym___launch_bounds__] = ACTIONS(5871),
  },
  [STATE(2185)] = {
    [sym_identifier] = ACTIONS(4366),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_TILDE] = ACTIONS(4368),
    [anon_sym_STAR] = ACTIONS(4368),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym___extension__] = ACTIONS(4366),
    [anon_sym___device__] = ACTIONS(4366),
    [anon_sym___host__] = ACTIONS(4366),
    [anon_sym___global__] = ACTIONS(4366),
    [anon_sym___forceinline__] = ACTIONS(4366),
    [anon_sym___noinline__] = ACTIONS(4366),
    [anon_sym_virtual] = ACTIONS(4366),
    [anon_sym_extern] = ACTIONS(4366),
    [anon_sym___attribute__] = ACTIONS(4366),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4368),
    [anon_sym___declspec] = ACTIONS(4366),
    [anon_sym___based] = ACTIONS(4366),
    [anon_sym___cdecl] = ACTIONS(4366),
    [anon_sym___clrcall] = ACTIONS(4366),
    [anon_sym___stdcall] = ACTIONS(4366),
    [anon_sym___fastcall] = ACTIONS(4366),
    [anon_sym___thiscall] = ACTIONS(4366),
    [anon_sym___vectorcall] = ACTIONS(4366),
    [anon_sym_signed] = ACTIONS(4366),
    [anon_sym_unsigned] = ACTIONS(4366),
    [anon_sym_long] = ACTIONS(4366),
    [anon_sym_short] = ACTIONS(4366),
    [anon_sym_LBRACK] = ACTIONS(4366),
    [anon_sym_static] = ACTIONS(4366),
    [anon_sym_register] = ACTIONS(4366),
    [anon_sym_inline] = ACTIONS(4366),
    [anon_sym___inline] = ACTIONS(4366),
    [anon_sym___inline__] = ACTIONS(4366),
    [anon_sym___forceinline] = ACTIONS(4366),
    [anon_sym_thread_local] = ACTIONS(4366),
    [anon_sym___thread] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4366),
    [anon_sym_volatile] = ACTIONS(4366),
    [anon_sym_restrict] = ACTIONS(4366),
    [anon_sym___restrict__] = ACTIONS(4366),
    [anon_sym__Atomic] = ACTIONS(4366),
    [anon_sym__Noreturn] = ACTIONS(4366),
    [anon_sym_noreturn] = ACTIONS(4366),
    [anon_sym__Nonnull] = ACTIONS(4366),
    [anon_sym_mutable] = ACTIONS(4366),
    [anon_sym_constinit] = ACTIONS(4366),
    [anon_sym_consteval] = ACTIONS(4366),
    [anon_sym___shared__] = ACTIONS(4366),
    [anon_sym___local__] = ACTIONS(4366),
    [anon_sym___constant__] = ACTIONS(4366),
    [anon_sym___managed__] = ACTIONS(4366),
    [anon_sym___grid_constant__] = ACTIONS(4366),
    [anon_sym_alignas] = ACTIONS(4366),
    [anon_sym__Alignas] = ACTIONS(4366),
    [sym_primitive_type] = ACTIONS(4366),
    [anon_sym_enum] = ACTIONS(4366),
    [anon_sym_class] = ACTIONS(4366),
    [anon_sym_struct] = ACTIONS(4366),
    [anon_sym_union] = ACTIONS(4366),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4366),
    [anon_sym_decltype] = ACTIONS(4366),
    [anon_sym_explicit] = ACTIONS(4366),
    [anon_sym_typename] = ACTIONS(4366),
    [anon_sym_template] = ACTIONS(4366),
    [anon_sym_operator] = ACTIONS(4366),
    [anon_sym_friend] = ACTIONS(4366),
    [anon_sym_using] = ACTIONS(4366),
    [anon_sym_concept] = ACTIONS(4366),
    [anon_sym___launch_bounds__] = ACTIONS(4366),
  },
  [STATE(2186)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_TILDE] = ACTIONS(5661),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___device__] = ACTIONS(5659),
    [anon_sym___host__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___forceinline__] = ACTIONS(5659),
    [anon_sym___noinline__] = ACTIONS(5659),
    [anon_sym_virtual] = ACTIONS(5659),
    [anon_sym_extern] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5661),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5661),
    [anon_sym___declspec] = ACTIONS(5659),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym___cdecl] = ACTIONS(5659),
    [anon_sym___clrcall] = ACTIONS(5659),
    [anon_sym___stdcall] = ACTIONS(5659),
    [anon_sym___fastcall] = ACTIONS(5659),
    [anon_sym___thiscall] = ACTIONS(5659),
    [anon_sym___vectorcall] = ACTIONS(5659),
    [anon_sym_signed] = ACTIONS(5659),
    [anon_sym_unsigned] = ACTIONS(5659),
    [anon_sym_long] = ACTIONS(5659),
    [anon_sym_short] = ACTIONS(5659),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [anon_sym_static] = ACTIONS(5659),
    [anon_sym_register] = ACTIONS(5659),
    [anon_sym_inline] = ACTIONS(5659),
    [anon_sym___inline] = ACTIONS(5659),
    [anon_sym___inline__] = ACTIONS(5659),
    [anon_sym___forceinline] = ACTIONS(5659),
    [anon_sym_thread_local] = ACTIONS(5659),
    [anon_sym___thread] = ACTIONS(5659),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [sym_primitive_type] = ACTIONS(5659),
    [anon_sym_enum] = ACTIONS(5659),
    [anon_sym_class] = ACTIONS(5659),
    [anon_sym_struct] = ACTIONS(5659),
    [anon_sym_union] = ACTIONS(5659),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_explicit] = ACTIONS(5659),
    [anon_sym_typename] = ACTIONS(5659),
    [anon_sym_template] = ACTIONS(5659),
    [anon_sym_operator] = ACTIONS(5659),
    [anon_sym_friend] = ACTIONS(5659),
    [anon_sym_using] = ACTIONS(5659),
    [anon_sym_concept] = ACTIONS(5659),
    [anon_sym___launch_bounds__] = ACTIONS(5659),
  },
  [STATE(2187)] = {
    [sym_string_literal] = STATE(2187),
    [sym_raw_string_literal] = STATE(2187),
    [aux_sym_concatenated_string_repeat1] = STATE(2187),
    [sym_identifier] = ACTIONS(5879),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5882),
    [anon_sym_COMMA] = ACTIONS(5882),
    [anon_sym_RPAREN] = ACTIONS(5882),
    [aux_sym_preproc_if_token2] = ACTIONS(5882),
    [aux_sym_preproc_else_token1] = ACTIONS(5882),
    [aux_sym_preproc_elif_token1] = ACTIONS(5884),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5882),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5882),
    [anon_sym_LPAREN2] = ACTIONS(5882),
    [anon_sym_DASH] = ACTIONS(5884),
    [anon_sym_PLUS] = ACTIONS(5884),
    [anon_sym_STAR] = ACTIONS(5884),
    [anon_sym_SLASH] = ACTIONS(5884),
    [anon_sym_PERCENT] = ACTIONS(5884),
    [anon_sym_PIPE_PIPE] = ACTIONS(5882),
    [anon_sym_AMP_AMP] = ACTIONS(5882),
    [anon_sym_PIPE] = ACTIONS(5884),
    [anon_sym_CARET] = ACTIONS(5884),
    [anon_sym_AMP] = ACTIONS(5884),
    [anon_sym_EQ_EQ] = ACTIONS(5882),
    [anon_sym_BANG_EQ] = ACTIONS(5882),
    [anon_sym_GT] = ACTIONS(5884),
    [anon_sym_GT_EQ] = ACTIONS(5882),
    [anon_sym_LT_EQ] = ACTIONS(5884),
    [anon_sym_LT] = ACTIONS(5884),
    [anon_sym_LT_LT] = ACTIONS(5884),
    [anon_sym_GT_GT] = ACTIONS(5884),
    [anon_sym_SEMI] = ACTIONS(5882),
    [anon_sym_RBRACE] = ACTIONS(5882),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_RBRACK] = ACTIONS(5882),
    [anon_sym_EQ] = ACTIONS(5884),
    [anon_sym_COLON] = ACTIONS(5882),
    [anon_sym_QMARK] = ACTIONS(5882),
    [anon_sym_STAR_EQ] = ACTIONS(5882),
    [anon_sym_SLASH_EQ] = ACTIONS(5882),
    [anon_sym_PERCENT_EQ] = ACTIONS(5882),
    [anon_sym_PLUS_EQ] = ACTIONS(5882),
    [anon_sym_DASH_EQ] = ACTIONS(5882),
    [anon_sym_LT_LT_EQ] = ACTIONS(5882),
    [anon_sym_GT_GT_EQ] = ACTIONS(5882),
    [anon_sym_AMP_EQ] = ACTIONS(5882),
    [anon_sym_CARET_EQ] = ACTIONS(5882),
    [anon_sym_PIPE_EQ] = ACTIONS(5882),
    [anon_sym_and_eq] = ACTIONS(5884),
    [anon_sym_or_eq] = ACTIONS(5884),
    [anon_sym_xor_eq] = ACTIONS(5884),
    [anon_sym_LT_EQ_GT] = ACTIONS(5882),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_bitor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_bitand] = ACTIONS(5884),
    [anon_sym_not_eq] = ACTIONS(5884),
    [anon_sym_DASH_DASH] = ACTIONS(5882),
    [anon_sym_PLUS_PLUS] = ACTIONS(5882),
    [anon_sym_DOT] = ACTIONS(5884),
    [anon_sym_DOT_STAR] = ACTIONS(5882),
    [anon_sym_DASH_GT] = ACTIONS(5882),
    [anon_sym_L_DQUOTE] = ACTIONS(5886),
    [anon_sym_u_DQUOTE] = ACTIONS(5886),
    [anon_sym_U_DQUOTE] = ACTIONS(5886),
    [anon_sym_u8_DQUOTE] = ACTIONS(5886),
    [anon_sym_DQUOTE] = ACTIONS(5886),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5889),
    [anon_sym_LR_DQUOTE] = ACTIONS(5889),
    [anon_sym_uR_DQUOTE] = ACTIONS(5889),
    [anon_sym_UR_DQUOTE] = ACTIONS(5889),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5889),
    [sym_literal_suffix] = ACTIONS(5884),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5882),
  },
  [STATE(2188)] = {
    [sym_type_qualifier] = STATE(2188),
    [sym_alignas_qualifier] = STATE(2279),
    [aux_sym__type_definition_type_repeat1] = STATE(2188),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_DASH] = ACTIONS(5110),
    [anon_sym_PLUS] = ACTIONS(5110),
    [anon_sym_STAR] = ACTIONS(5112),
    [anon_sym_SLASH] = ACTIONS(5110),
    [anon_sym_PERCENT] = ACTIONS(5112),
    [anon_sym_PIPE_PIPE] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_PIPE] = ACTIONS(5110),
    [anon_sym_CARET] = ACTIONS(5112),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_EQ_EQ] = ACTIONS(5112),
    [anon_sym_BANG_EQ] = ACTIONS(5112),
    [anon_sym_GT] = ACTIONS(5110),
    [anon_sym_GT_EQ] = ACTIONS(5110),
    [anon_sym_LT_EQ] = ACTIONS(5110),
    [anon_sym_LT] = ACTIONS(5110),
    [anon_sym_LT_LT] = ACTIONS(5110),
    [anon_sym_GT_GT] = ACTIONS(5110),
    [anon_sym___extension__] = ACTIONS(5892),
    [anon_sym___global__] = ACTIONS(5892),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5112),
    [anon_sym_const] = ACTIONS(5892),
    [anon_sym_constexpr] = ACTIONS(5892),
    [anon_sym_volatile] = ACTIONS(5892),
    [anon_sym_restrict] = ACTIONS(5892),
    [anon_sym___restrict__] = ACTIONS(5892),
    [anon_sym__Atomic] = ACTIONS(5892),
    [anon_sym__Noreturn] = ACTIONS(5892),
    [anon_sym_noreturn] = ACTIONS(5892),
    [anon_sym__Nonnull] = ACTIONS(5892),
    [anon_sym_mutable] = ACTIONS(5892),
    [anon_sym_constinit] = ACTIONS(5892),
    [anon_sym_consteval] = ACTIONS(5892),
    [anon_sym___shared__] = ACTIONS(5892),
    [anon_sym___local__] = ACTIONS(5892),
    [anon_sym___constant__] = ACTIONS(5892),
    [anon_sym___managed__] = ACTIONS(5892),
    [anon_sym___grid_constant__] = ACTIONS(5892),
    [anon_sym_alignas] = ACTIONS(5895),
    [anon_sym__Alignas] = ACTIONS(5895),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_QMARK] = ACTIONS(5112),
    [anon_sym_LT_EQ_GT] = ACTIONS(5112),
    [anon_sym_or] = ACTIONS(5110),
    [anon_sym_and] = ACTIONS(5110),
    [anon_sym_bitor] = ACTIONS(5110),
    [anon_sym_xor] = ACTIONS(5110),
    [anon_sym_bitand] = ACTIONS(5110),
    [anon_sym_not_eq] = ACTIONS(5110),
    [anon_sym_DASH_DASH] = ACTIONS(5112),
    [anon_sym_PLUS_PLUS] = ACTIONS(5112),
    [anon_sym_DOT] = ACTIONS(5110),
    [anon_sym_DOT_STAR] = ACTIONS(5112),
    [anon_sym_DASH_GT] = ACTIONS(5112),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [anon_sym_final] = ACTIONS(5110),
    [anon_sym_override] = ACTIONS(5110),
    [anon_sym_GT2] = ACTIONS(5112),
    [anon_sym_requires] = ACTIONS(5110),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5112),
  },
  [STATE(2189)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5898),
    [anon_sym_COMMA] = ACTIONS(5898),
    [anon_sym_RPAREN] = ACTIONS(5898),
    [anon_sym_LPAREN2] = ACTIONS(5898),
    [anon_sym_DASH] = ACTIONS(5900),
    [anon_sym_PLUS] = ACTIONS(5900),
    [anon_sym_STAR] = ACTIONS(5898),
    [anon_sym_SLASH] = ACTIONS(5900),
    [anon_sym_PERCENT] = ACTIONS(5898),
    [anon_sym_PIPE_PIPE] = ACTIONS(5898),
    [anon_sym_AMP_AMP] = ACTIONS(5898),
    [anon_sym_PIPE] = ACTIONS(5900),
    [anon_sym_CARET] = ACTIONS(5898),
    [anon_sym_AMP] = ACTIONS(5900),
    [anon_sym_EQ_EQ] = ACTIONS(5898),
    [anon_sym_BANG_EQ] = ACTIONS(5898),
    [anon_sym_GT] = ACTIONS(5900),
    [anon_sym_GT_EQ] = ACTIONS(5898),
    [anon_sym_LT_EQ] = ACTIONS(5900),
    [anon_sym_LT] = ACTIONS(5900),
    [anon_sym_LT_LT] = ACTIONS(5900),
    [anon_sym_GT_GT] = ACTIONS(5898),
    [anon_sym_SEMI] = ACTIONS(5898),
    [anon_sym___extension__] = ACTIONS(5898),
    [anon_sym___global__] = ACTIONS(5898),
    [anon_sym___attribute__] = ACTIONS(5898),
    [anon_sym___attribute] = ACTIONS(5900),
    [anon_sym_LBRACE] = ACTIONS(5898),
    [anon_sym_RBRACE] = ACTIONS(5898),
    [anon_sym_signed] = ACTIONS(5902),
    [anon_sym_unsigned] = ACTIONS(5902),
    [anon_sym_long] = ACTIONS(5902),
    [anon_sym_short] = ACTIONS(5902),
    [anon_sym_LBRACK] = ACTIONS(5898),
    [anon_sym_RBRACK] = ACTIONS(5898),
    [anon_sym_const] = ACTIONS(5900),
    [anon_sym_constexpr] = ACTIONS(5898),
    [anon_sym_volatile] = ACTIONS(5898),
    [anon_sym_restrict] = ACTIONS(5898),
    [anon_sym___restrict__] = ACTIONS(5898),
    [anon_sym__Atomic] = ACTIONS(5898),
    [anon_sym__Noreturn] = ACTIONS(5898),
    [anon_sym_noreturn] = ACTIONS(5898),
    [anon_sym__Nonnull] = ACTIONS(5898),
    [anon_sym_mutable] = ACTIONS(5898),
    [anon_sym_constinit] = ACTIONS(5898),
    [anon_sym_consteval] = ACTIONS(5898),
    [anon_sym___shared__] = ACTIONS(5898),
    [anon_sym___local__] = ACTIONS(5898),
    [anon_sym___constant__] = ACTIONS(5898),
    [anon_sym___managed__] = ACTIONS(5898),
    [anon_sym___grid_constant__] = ACTIONS(5898),
    [anon_sym_alignas] = ACTIONS(5898),
    [anon_sym__Alignas] = ACTIONS(5898),
    [anon_sym_COLON] = ACTIONS(5898),
    [anon_sym_QMARK] = ACTIONS(5898),
    [anon_sym_LT_EQ_GT] = ACTIONS(5898),
    [anon_sym_or] = ACTIONS(5898),
    [anon_sym_and] = ACTIONS(5898),
    [anon_sym_bitor] = ACTIONS(5898),
    [anon_sym_xor] = ACTIONS(5898),
    [anon_sym_bitand] = ACTIONS(5898),
    [anon_sym_not_eq] = ACTIONS(5898),
    [anon_sym_DASH_DASH] = ACTIONS(5898),
    [anon_sym_PLUS_PLUS] = ACTIONS(5898),
    [anon_sym_DOT] = ACTIONS(5900),
    [anon_sym_DOT_STAR] = ACTIONS(5898),
    [anon_sym_DASH_GT] = ACTIONS(5898),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5898),
    [anon_sym_decltype] = ACTIONS(5898),
    [anon_sym_final] = ACTIONS(5898),
    [anon_sym_override] = ACTIONS(5898),
    [anon_sym_requires] = ACTIONS(5898),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5898),
  },
  [STATE(2190)] = {
    [sym_type_qualifier] = STATE(2193),
    [sym_alignas_qualifier] = STATE(1719),
    [aux_sym__type_definition_type_repeat1] = STATE(2193),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2276),
    [sym_identifier] = ACTIONS(5904),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_RPAREN] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_TILDE] = ACTIONS(5158),
    [anon_sym_STAR] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_SEMI] = ACTIONS(5158),
    [anon_sym___extension__] = ACTIONS(5907),
    [anon_sym___device__] = ACTIONS(5160),
    [anon_sym___host__] = ACTIONS(5160),
    [anon_sym___global__] = ACTIONS(5907),
    [anon_sym___forceinline__] = ACTIONS(5160),
    [anon_sym___noinline__] = ACTIONS(5160),
    [anon_sym_virtual] = ACTIONS(5160),
    [anon_sym_extern] = ACTIONS(5160),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_COLON_COLON] = ACTIONS(5158),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5158),
    [anon_sym___declspec] = ACTIONS(5160),
    [anon_sym___based] = ACTIONS(5160),
    [anon_sym___cdecl] = ACTIONS(5160),
    [anon_sym___clrcall] = ACTIONS(5160),
    [anon_sym___stdcall] = ACTIONS(5160),
    [anon_sym___fastcall] = ACTIONS(5160),
    [anon_sym___thiscall] = ACTIONS(5160),
    [anon_sym___vectorcall] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(5910),
    [anon_sym_unsigned] = ACTIONS(5910),
    [anon_sym_long] = ACTIONS(5910),
    [anon_sym_short] = ACTIONS(5910),
    [anon_sym_LBRACK] = ACTIONS(5160),
    [anon_sym_static] = ACTIONS(5160),
    [anon_sym_EQ] = ACTIONS(5158),
    [anon_sym_register] = ACTIONS(5160),
    [anon_sym_inline] = ACTIONS(5160),
    [anon_sym___inline] = ACTIONS(5160),
    [anon_sym___inline__] = ACTIONS(5160),
    [anon_sym___forceinline] = ACTIONS(5160),
    [anon_sym_thread_local] = ACTIONS(5160),
    [anon_sym___thread] = ACTIONS(5160),
    [anon_sym_const] = ACTIONS(5907),
    [anon_sym_constexpr] = ACTIONS(5907),
    [anon_sym_volatile] = ACTIONS(5907),
    [anon_sym_restrict] = ACTIONS(5907),
    [anon_sym___restrict__] = ACTIONS(5907),
    [anon_sym__Atomic] = ACTIONS(5907),
    [anon_sym__Noreturn] = ACTIONS(5907),
    [anon_sym_noreturn] = ACTIONS(5907),
    [anon_sym__Nonnull] = ACTIONS(5907),
    [anon_sym_mutable] = ACTIONS(5907),
    [anon_sym_constinit] = ACTIONS(5907),
    [anon_sym_consteval] = ACTIONS(5907),
    [anon_sym___shared__] = ACTIONS(5907),
    [anon_sym___local__] = ACTIONS(5907),
    [anon_sym___constant__] = ACTIONS(5907),
    [anon_sym___managed__] = ACTIONS(5907),
    [anon_sym___grid_constant__] = ACTIONS(5907),
    [anon_sym_alignas] = ACTIONS(5912),
    [anon_sym__Alignas] = ACTIONS(5912),
    [sym_primitive_type] = ACTIONS(5915),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [anon_sym_template] = ACTIONS(5160),
    [anon_sym_GT2] = ACTIONS(5158),
    [anon_sym_operator] = ACTIONS(5160),
    [anon_sym___launch_bounds__] = ACTIONS(5160),
  },
  [STATE(2191)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2206),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5917),
    [anon_sym_COMMA] = ACTIONS(5917),
    [anon_sym_RPAREN] = ACTIONS(5917),
    [anon_sym_LPAREN2] = ACTIONS(5917),
    [anon_sym_DASH] = ACTIONS(5919),
    [anon_sym_PLUS] = ACTIONS(5919),
    [anon_sym_STAR] = ACTIONS(5917),
    [anon_sym_SLASH] = ACTIONS(5919),
    [anon_sym_PERCENT] = ACTIONS(5917),
    [anon_sym_PIPE_PIPE] = ACTIONS(5917),
    [anon_sym_AMP_AMP] = ACTIONS(5917),
    [anon_sym_PIPE] = ACTIONS(5919),
    [anon_sym_CARET] = ACTIONS(5917),
    [anon_sym_AMP] = ACTIONS(5919),
    [anon_sym_EQ_EQ] = ACTIONS(5917),
    [anon_sym_BANG_EQ] = ACTIONS(5917),
    [anon_sym_GT] = ACTIONS(5919),
    [anon_sym_GT_EQ] = ACTIONS(5917),
    [anon_sym_LT_EQ] = ACTIONS(5919),
    [anon_sym_LT] = ACTIONS(5919),
    [anon_sym_LT_LT] = ACTIONS(5919),
    [anon_sym_GT_GT] = ACTIONS(5917),
    [anon_sym_SEMI] = ACTIONS(5917),
    [anon_sym___extension__] = ACTIONS(5917),
    [anon_sym___global__] = ACTIONS(5917),
    [anon_sym___attribute__] = ACTIONS(5917),
    [anon_sym___attribute] = ACTIONS(5919),
    [anon_sym_LBRACE] = ACTIONS(5917),
    [anon_sym_RBRACE] = ACTIONS(5917),
    [anon_sym_signed] = ACTIONS(5921),
    [anon_sym_unsigned] = ACTIONS(5921),
    [anon_sym_long] = ACTIONS(5921),
    [anon_sym_short] = ACTIONS(5921),
    [anon_sym_LBRACK] = ACTIONS(5917),
    [anon_sym_RBRACK] = ACTIONS(5917),
    [anon_sym_const] = ACTIONS(5919),
    [anon_sym_constexpr] = ACTIONS(5917),
    [anon_sym_volatile] = ACTIONS(5917),
    [anon_sym_restrict] = ACTIONS(5917),
    [anon_sym___restrict__] = ACTIONS(5917),
    [anon_sym__Atomic] = ACTIONS(5917),
    [anon_sym__Noreturn] = ACTIONS(5917),
    [anon_sym_noreturn] = ACTIONS(5917),
    [anon_sym__Nonnull] = ACTIONS(5917),
    [anon_sym_mutable] = ACTIONS(5917),
    [anon_sym_constinit] = ACTIONS(5917),
    [anon_sym_consteval] = ACTIONS(5917),
    [anon_sym___shared__] = ACTIONS(5917),
    [anon_sym___local__] = ACTIONS(5917),
    [anon_sym___constant__] = ACTIONS(5917),
    [anon_sym___managed__] = ACTIONS(5917),
    [anon_sym___grid_constant__] = ACTIONS(5917),
    [anon_sym_alignas] = ACTIONS(5917),
    [anon_sym__Alignas] = ACTIONS(5917),
    [anon_sym_COLON] = ACTIONS(5917),
    [anon_sym_QMARK] = ACTIONS(5917),
    [anon_sym_LT_EQ_GT] = ACTIONS(5917),
    [anon_sym_or] = ACTIONS(5917),
    [anon_sym_and] = ACTIONS(5917),
    [anon_sym_bitor] = ACTIONS(5917),
    [anon_sym_xor] = ACTIONS(5917),
    [anon_sym_bitand] = ACTIONS(5917),
    [anon_sym_not_eq] = ACTIONS(5917),
    [anon_sym_DASH_DASH] = ACTIONS(5917),
    [anon_sym_PLUS_PLUS] = ACTIONS(5917),
    [anon_sym_DOT] = ACTIONS(5919),
    [anon_sym_DOT_STAR] = ACTIONS(5917),
    [anon_sym_DASH_GT] = ACTIONS(5917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5917),
    [anon_sym_decltype] = ACTIONS(5917),
    [anon_sym_final] = ACTIONS(5917),
    [anon_sym_override] = ACTIONS(5917),
    [anon_sym_requires] = ACTIONS(5917),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5917),
  },
  [STATE(2192)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(3478),
    [sym__declarator] = STATE(6947),
    [sym__abstract_declarator] = STATE(7137),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(2469),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3007),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(2469),
    [aux_sym_pointer_declarator_repeat1] = STATE(3478),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(5925),
    [anon_sym_RPAREN] = ACTIONS(5925),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(5927),
    [anon_sym_AMP_AMP] = ACTIONS(5929),
    [anon_sym_AMP] = ACTIONS(5931),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(5933),
    [anon_sym___attribute] = ACTIONS(5933),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_EQ] = ACTIONS(5925),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(5925),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2193)] = {
    [sym_type_qualifier] = STATE(1698),
    [sym_alignas_qualifier] = STATE(1719),
    [aux_sym__type_definition_type_repeat1] = STATE(1698),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2308),
    [sym_identifier] = ACTIONS(5939),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_RPAREN] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_TILDE] = ACTIONS(5173),
    [anon_sym_STAR] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_SEMI] = ACTIONS(5173),
    [anon_sym___extension__] = ACTIONS(5942),
    [anon_sym___device__] = ACTIONS(5175),
    [anon_sym___host__] = ACTIONS(5175),
    [anon_sym___global__] = ACTIONS(5942),
    [anon_sym___forceinline__] = ACTIONS(5175),
    [anon_sym___noinline__] = ACTIONS(5175),
    [anon_sym_virtual] = ACTIONS(5175),
    [anon_sym_extern] = ACTIONS(5175),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_COLON_COLON] = ACTIONS(5173),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5173),
    [anon_sym___declspec] = ACTIONS(5175),
    [anon_sym___based] = ACTIONS(5175),
    [anon_sym___cdecl] = ACTIONS(5175),
    [anon_sym___clrcall] = ACTIONS(5175),
    [anon_sym___stdcall] = ACTIONS(5175),
    [anon_sym___fastcall] = ACTIONS(5175),
    [anon_sym___thiscall] = ACTIONS(5175),
    [anon_sym___vectorcall] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(5945),
    [anon_sym_unsigned] = ACTIONS(5945),
    [anon_sym_long] = ACTIONS(5945),
    [anon_sym_short] = ACTIONS(5945),
    [anon_sym_LBRACK] = ACTIONS(5175),
    [anon_sym_static] = ACTIONS(5175),
    [anon_sym_EQ] = ACTIONS(5173),
    [anon_sym_register] = ACTIONS(5175),
    [anon_sym_inline] = ACTIONS(5175),
    [anon_sym___inline] = ACTIONS(5175),
    [anon_sym___inline__] = ACTIONS(5175),
    [anon_sym___forceinline] = ACTIONS(5175),
    [anon_sym_thread_local] = ACTIONS(5175),
    [anon_sym___thread] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5942),
    [anon_sym_constexpr] = ACTIONS(5942),
    [anon_sym_volatile] = ACTIONS(5942),
    [anon_sym_restrict] = ACTIONS(5942),
    [anon_sym___restrict__] = ACTIONS(5942),
    [anon_sym__Atomic] = ACTIONS(5942),
    [anon_sym__Noreturn] = ACTIONS(5942),
    [anon_sym_noreturn] = ACTIONS(5942),
    [anon_sym__Nonnull] = ACTIONS(5942),
    [anon_sym_mutable] = ACTIONS(5942),
    [anon_sym_constinit] = ACTIONS(5942),
    [anon_sym_consteval] = ACTIONS(5942),
    [anon_sym___shared__] = ACTIONS(5942),
    [anon_sym___local__] = ACTIONS(5942),
    [anon_sym___constant__] = ACTIONS(5942),
    [anon_sym___managed__] = ACTIONS(5942),
    [anon_sym___grid_constant__] = ACTIONS(5942),
    [anon_sym_alignas] = ACTIONS(5947),
    [anon_sym__Alignas] = ACTIONS(5947),
    [sym_primitive_type] = ACTIONS(5950),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [anon_sym_template] = ACTIONS(5175),
    [anon_sym_GT2] = ACTIONS(5173),
    [anon_sym_operator] = ACTIONS(5175),
    [anon_sym___launch_bounds__] = ACTIONS(5175),
  },
  [STATE(2194)] = {
    [sym__declaration_modifiers] = STATE(2256),
    [sym_attribute_specifier] = STATE(2256),
    [sym_attribute_declaration] = STATE(2256),
    [sym_ms_declspec_modifier] = STATE(2256),
    [sym_storage_class_specifier] = STATE(2256),
    [sym_type_qualifier] = STATE(2256),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2256),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2256),
    [sym_identifier] = ACTIONS(5952),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5954),
    [anon_sym_COMMA] = ACTIONS(5954),
    [anon_sym_RPAREN] = ACTIONS(5954),
    [anon_sym_LPAREN2] = ACTIONS(5954),
    [anon_sym_TILDE] = ACTIONS(5954),
    [anon_sym_STAR] = ACTIONS(5954),
    [anon_sym_AMP_AMP] = ACTIONS(5954),
    [anon_sym_AMP] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(5954),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5956),
    [anon_sym___host__] = ACTIONS(5956),
    [anon_sym___global__] = ACTIONS(5956),
    [anon_sym___forceinline__] = ACTIONS(5956),
    [anon_sym___noinline__] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5954),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5952),
    [anon_sym___cdecl] = ACTIONS(5952),
    [anon_sym___clrcall] = ACTIONS(5952),
    [anon_sym___stdcall] = ACTIONS(5952),
    [anon_sym___fastcall] = ACTIONS(5952),
    [anon_sym___thiscall] = ACTIONS(5952),
    [anon_sym___vectorcall] = ACTIONS(5952),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_EQ] = ACTIONS(5954),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5952),
    [anon_sym_GT2] = ACTIONS(5954),
    [anon_sym_operator] = ACTIONS(5952),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2195)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5962),
    [anon_sym_COMMA] = ACTIONS(5962),
    [anon_sym_RPAREN] = ACTIONS(5962),
    [anon_sym_LPAREN2] = ACTIONS(5962),
    [anon_sym_DASH] = ACTIONS(5964),
    [anon_sym_PLUS] = ACTIONS(5964),
    [anon_sym_STAR] = ACTIONS(5962),
    [anon_sym_SLASH] = ACTIONS(5964),
    [anon_sym_PERCENT] = ACTIONS(5962),
    [anon_sym_PIPE_PIPE] = ACTIONS(5962),
    [anon_sym_AMP_AMP] = ACTIONS(5962),
    [anon_sym_PIPE] = ACTIONS(5964),
    [anon_sym_CARET] = ACTIONS(5962),
    [anon_sym_AMP] = ACTIONS(5964),
    [anon_sym_EQ_EQ] = ACTIONS(5962),
    [anon_sym_BANG_EQ] = ACTIONS(5962),
    [anon_sym_GT] = ACTIONS(5964),
    [anon_sym_GT_EQ] = ACTIONS(5962),
    [anon_sym_LT_EQ] = ACTIONS(5964),
    [anon_sym_LT] = ACTIONS(5964),
    [anon_sym_LT_LT] = ACTIONS(5964),
    [anon_sym_GT_GT] = ACTIONS(5962),
    [anon_sym_SEMI] = ACTIONS(5962),
    [anon_sym___extension__] = ACTIONS(5962),
    [anon_sym___global__] = ACTIONS(5962),
    [anon_sym___attribute__] = ACTIONS(5962),
    [anon_sym___attribute] = ACTIONS(5964),
    [anon_sym_LBRACE] = ACTIONS(5962),
    [anon_sym_RBRACE] = ACTIONS(5962),
    [anon_sym_signed] = ACTIONS(5902),
    [anon_sym_unsigned] = ACTIONS(5902),
    [anon_sym_long] = ACTIONS(5902),
    [anon_sym_short] = ACTIONS(5902),
    [anon_sym_LBRACK] = ACTIONS(5962),
    [anon_sym_RBRACK] = ACTIONS(5962),
    [anon_sym_const] = ACTIONS(5964),
    [anon_sym_constexpr] = ACTIONS(5962),
    [anon_sym_volatile] = ACTIONS(5962),
    [anon_sym_restrict] = ACTIONS(5962),
    [anon_sym___restrict__] = ACTIONS(5962),
    [anon_sym__Atomic] = ACTIONS(5962),
    [anon_sym__Noreturn] = ACTIONS(5962),
    [anon_sym_noreturn] = ACTIONS(5962),
    [anon_sym__Nonnull] = ACTIONS(5962),
    [anon_sym_mutable] = ACTIONS(5962),
    [anon_sym_constinit] = ACTIONS(5962),
    [anon_sym_consteval] = ACTIONS(5962),
    [anon_sym___shared__] = ACTIONS(5962),
    [anon_sym___local__] = ACTIONS(5962),
    [anon_sym___constant__] = ACTIONS(5962),
    [anon_sym___managed__] = ACTIONS(5962),
    [anon_sym___grid_constant__] = ACTIONS(5962),
    [anon_sym_alignas] = ACTIONS(5962),
    [anon_sym__Alignas] = ACTIONS(5962),
    [anon_sym_COLON] = ACTIONS(5962),
    [anon_sym_QMARK] = ACTIONS(5962),
    [anon_sym_LT_EQ_GT] = ACTIONS(5962),
    [anon_sym_or] = ACTIONS(5962),
    [anon_sym_and] = ACTIONS(5962),
    [anon_sym_bitor] = ACTIONS(5962),
    [anon_sym_xor] = ACTIONS(5962),
    [anon_sym_bitand] = ACTIONS(5962),
    [anon_sym_not_eq] = ACTIONS(5962),
    [anon_sym_DASH_DASH] = ACTIONS(5962),
    [anon_sym_PLUS_PLUS] = ACTIONS(5962),
    [anon_sym_DOT] = ACTIONS(5964),
    [anon_sym_DOT_STAR] = ACTIONS(5962),
    [anon_sym_DASH_GT] = ACTIONS(5962),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5962),
    [anon_sym_decltype] = ACTIONS(5962),
    [anon_sym_final] = ACTIONS(5962),
    [anon_sym_override] = ACTIONS(5962),
    [anon_sym_requires] = ACTIONS(5962),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5962),
  },
  [STATE(2196)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4555),
    [anon_sym_RPAREN] = ACTIONS(4557),
    [anon_sym_LPAREN2] = ACTIONS(4557),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4564),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4557),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4564),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym___extension__] = ACTIONS(4560),
    [anon_sym___global__] = ACTIONS(4560),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4557),
    [anon_sym_EQ] = ACTIONS(4562),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4560),
    [anon_sym_volatile] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym___restrict__] = ACTIONS(4560),
    [anon_sym__Atomic] = ACTIONS(4560),
    [anon_sym__Noreturn] = ACTIONS(4560),
    [anon_sym_noreturn] = ACTIONS(4560),
    [anon_sym__Nonnull] = ACTIONS(4560),
    [anon_sym_mutable] = ACTIONS(4560),
    [anon_sym_constinit] = ACTIONS(4560),
    [anon_sym_consteval] = ACTIONS(4560),
    [anon_sym___shared__] = ACTIONS(4560),
    [anon_sym___local__] = ACTIONS(4560),
    [anon_sym___constant__] = ACTIONS(4560),
    [anon_sym___managed__] = ACTIONS(4560),
    [anon_sym___grid_constant__] = ACTIONS(4560),
    [anon_sym_alignas] = ACTIONS(4560),
    [anon_sym__Alignas] = ACTIONS(4560),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4555),
    [anon_sym_or_eq] = ACTIONS(4555),
    [anon_sym_xor_eq] = ACTIONS(4555),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4555),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4555),
    [anon_sym_not_eq] = ACTIONS(4555),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4560),
    [anon_sym_decltype] = ACTIONS(4560),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
  },
  [STATE(2197)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2210),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5966),
    [anon_sym_COMMA] = ACTIONS(5966),
    [anon_sym_RPAREN] = ACTIONS(5966),
    [anon_sym_LPAREN2] = ACTIONS(5966),
    [anon_sym_DASH] = ACTIONS(5968),
    [anon_sym_PLUS] = ACTIONS(5968),
    [anon_sym_STAR] = ACTIONS(5966),
    [anon_sym_SLASH] = ACTIONS(5968),
    [anon_sym_PERCENT] = ACTIONS(5966),
    [anon_sym_PIPE_PIPE] = ACTIONS(5966),
    [anon_sym_AMP_AMP] = ACTIONS(5966),
    [anon_sym_PIPE] = ACTIONS(5968),
    [anon_sym_CARET] = ACTIONS(5966),
    [anon_sym_AMP] = ACTIONS(5968),
    [anon_sym_EQ_EQ] = ACTIONS(5966),
    [anon_sym_BANG_EQ] = ACTIONS(5966),
    [anon_sym_GT] = ACTIONS(5968),
    [anon_sym_GT_EQ] = ACTIONS(5966),
    [anon_sym_LT_EQ] = ACTIONS(5968),
    [anon_sym_LT] = ACTIONS(5968),
    [anon_sym_LT_LT] = ACTIONS(5968),
    [anon_sym_GT_GT] = ACTIONS(5966),
    [anon_sym_SEMI] = ACTIONS(5966),
    [anon_sym___extension__] = ACTIONS(5966),
    [anon_sym___global__] = ACTIONS(5966),
    [anon_sym___attribute__] = ACTIONS(5966),
    [anon_sym___attribute] = ACTIONS(5968),
    [anon_sym_LBRACE] = ACTIONS(5966),
    [anon_sym_RBRACE] = ACTIONS(5966),
    [anon_sym_signed] = ACTIONS(5970),
    [anon_sym_unsigned] = ACTIONS(5970),
    [anon_sym_long] = ACTIONS(5970),
    [anon_sym_short] = ACTIONS(5970),
    [anon_sym_LBRACK] = ACTIONS(5966),
    [anon_sym_RBRACK] = ACTIONS(5966),
    [anon_sym_const] = ACTIONS(5968),
    [anon_sym_constexpr] = ACTIONS(5966),
    [anon_sym_volatile] = ACTIONS(5966),
    [anon_sym_restrict] = ACTIONS(5966),
    [anon_sym___restrict__] = ACTIONS(5966),
    [anon_sym__Atomic] = ACTIONS(5966),
    [anon_sym__Noreturn] = ACTIONS(5966),
    [anon_sym_noreturn] = ACTIONS(5966),
    [anon_sym__Nonnull] = ACTIONS(5966),
    [anon_sym_mutable] = ACTIONS(5966),
    [anon_sym_constinit] = ACTIONS(5966),
    [anon_sym_consteval] = ACTIONS(5966),
    [anon_sym___shared__] = ACTIONS(5966),
    [anon_sym___local__] = ACTIONS(5966),
    [anon_sym___constant__] = ACTIONS(5966),
    [anon_sym___managed__] = ACTIONS(5966),
    [anon_sym___grid_constant__] = ACTIONS(5966),
    [anon_sym_alignas] = ACTIONS(5966),
    [anon_sym__Alignas] = ACTIONS(5966),
    [anon_sym_COLON] = ACTIONS(5966),
    [anon_sym_QMARK] = ACTIONS(5966),
    [anon_sym_LT_EQ_GT] = ACTIONS(5966),
    [anon_sym_or] = ACTIONS(5966),
    [anon_sym_and] = ACTIONS(5966),
    [anon_sym_bitor] = ACTIONS(5966),
    [anon_sym_xor] = ACTIONS(5966),
    [anon_sym_bitand] = ACTIONS(5966),
    [anon_sym_not_eq] = ACTIONS(5966),
    [anon_sym_DASH_DASH] = ACTIONS(5966),
    [anon_sym_PLUS_PLUS] = ACTIONS(5966),
    [anon_sym_DOT] = ACTIONS(5968),
    [anon_sym_DOT_STAR] = ACTIONS(5966),
    [anon_sym_DASH_GT] = ACTIONS(5966),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5966),
    [anon_sym_decltype] = ACTIONS(5966),
    [anon_sym_final] = ACTIONS(5966),
    [anon_sym_override] = ACTIONS(5966),
    [anon_sym_requires] = ACTIONS(5966),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5966),
  },
  [STATE(2198)] = {
    [sym__declaration_modifiers] = STATE(2238),
    [sym_attribute_specifier] = STATE(2238),
    [sym_attribute_declaration] = STATE(2238),
    [sym_ms_declspec_modifier] = STATE(2238),
    [sym_storage_class_specifier] = STATE(2238),
    [sym_type_qualifier] = STATE(2238),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2238),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2238),
    [sym_identifier] = ACTIONS(5972),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5974),
    [anon_sym_COMMA] = ACTIONS(5974),
    [anon_sym_RPAREN] = ACTIONS(5974),
    [anon_sym_LPAREN2] = ACTIONS(5974),
    [anon_sym_TILDE] = ACTIONS(5974),
    [anon_sym_STAR] = ACTIONS(5974),
    [anon_sym_AMP_AMP] = ACTIONS(5974),
    [anon_sym_AMP] = ACTIONS(5972),
    [anon_sym_SEMI] = ACTIONS(5974),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5976),
    [anon_sym___host__] = ACTIONS(5976),
    [anon_sym___global__] = ACTIONS(5976),
    [anon_sym___forceinline__] = ACTIONS(5976),
    [anon_sym___noinline__] = ACTIONS(5976),
    [anon_sym_virtual] = ACTIONS(5976),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5974),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5972),
    [anon_sym___cdecl] = ACTIONS(5972),
    [anon_sym___clrcall] = ACTIONS(5972),
    [anon_sym___stdcall] = ACTIONS(5972),
    [anon_sym___fastcall] = ACTIONS(5972),
    [anon_sym___thiscall] = ACTIONS(5972),
    [anon_sym___vectorcall] = ACTIONS(5972),
    [anon_sym_LBRACK] = ACTIONS(5972),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_EQ] = ACTIONS(5974),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5972),
    [anon_sym_GT2] = ACTIONS(5974),
    [anon_sym_operator] = ACTIONS(5972),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2199)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2189),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_RPAREN] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_DASH] = ACTIONS(5770),
    [anon_sym_PLUS] = ACTIONS(5770),
    [anon_sym_STAR] = ACTIONS(5772),
    [anon_sym_SLASH] = ACTIONS(5770),
    [anon_sym_PERCENT] = ACTIONS(5772),
    [anon_sym_PIPE_PIPE] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_PIPE] = ACTIONS(5770),
    [anon_sym_CARET] = ACTIONS(5772),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_EQ_EQ] = ACTIONS(5772),
    [anon_sym_BANG_EQ] = ACTIONS(5772),
    [anon_sym_GT] = ACTIONS(5770),
    [anon_sym_GT_EQ] = ACTIONS(5772),
    [anon_sym_LT_EQ] = ACTIONS(5770),
    [anon_sym_LT] = ACTIONS(5770),
    [anon_sym_LT_LT] = ACTIONS(5770),
    [anon_sym_GT_GT] = ACTIONS(5772),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym___extension__] = ACTIONS(5772),
    [anon_sym___global__] = ACTIONS(5772),
    [anon_sym___attribute__] = ACTIONS(5772),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_RBRACE] = ACTIONS(5772),
    [anon_sym_signed] = ACTIONS(5978),
    [anon_sym_unsigned] = ACTIONS(5978),
    [anon_sym_long] = ACTIONS(5978),
    [anon_sym_short] = ACTIONS(5978),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_RBRACK] = ACTIONS(5772),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_constexpr] = ACTIONS(5772),
    [anon_sym_volatile] = ACTIONS(5772),
    [anon_sym_restrict] = ACTIONS(5772),
    [anon_sym___restrict__] = ACTIONS(5772),
    [anon_sym__Atomic] = ACTIONS(5772),
    [anon_sym__Noreturn] = ACTIONS(5772),
    [anon_sym_noreturn] = ACTIONS(5772),
    [anon_sym__Nonnull] = ACTIONS(5772),
    [anon_sym_mutable] = ACTIONS(5772),
    [anon_sym_constinit] = ACTIONS(5772),
    [anon_sym_consteval] = ACTIONS(5772),
    [anon_sym___shared__] = ACTIONS(5772),
    [anon_sym___local__] = ACTIONS(5772),
    [anon_sym___constant__] = ACTIONS(5772),
    [anon_sym___managed__] = ACTIONS(5772),
    [anon_sym___grid_constant__] = ACTIONS(5772),
    [anon_sym_alignas] = ACTIONS(5772),
    [anon_sym__Alignas] = ACTIONS(5772),
    [anon_sym_COLON] = ACTIONS(5772),
    [anon_sym_QMARK] = ACTIONS(5772),
    [anon_sym_LT_EQ_GT] = ACTIONS(5772),
    [anon_sym_or] = ACTIONS(5772),
    [anon_sym_and] = ACTIONS(5772),
    [anon_sym_bitor] = ACTIONS(5772),
    [anon_sym_xor] = ACTIONS(5772),
    [anon_sym_bitand] = ACTIONS(5772),
    [anon_sym_not_eq] = ACTIONS(5772),
    [anon_sym_DASH_DASH] = ACTIONS(5772),
    [anon_sym_PLUS_PLUS] = ACTIONS(5772),
    [anon_sym_DOT] = ACTIONS(5770),
    [anon_sym_DOT_STAR] = ACTIONS(5772),
    [anon_sym_DASH_GT] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5772),
    [anon_sym_decltype] = ACTIONS(5772),
    [anon_sym_final] = ACTIONS(5772),
    [anon_sym_override] = ACTIONS(5772),
    [anon_sym_requires] = ACTIONS(5772),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5772),
  },
  [STATE(2200)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5980),
    [anon_sym_COMMA] = ACTIONS(5980),
    [anon_sym_RPAREN] = ACTIONS(5980),
    [anon_sym_LPAREN2] = ACTIONS(5980),
    [anon_sym_DASH] = ACTIONS(5982),
    [anon_sym_PLUS] = ACTIONS(5982),
    [anon_sym_STAR] = ACTIONS(5980),
    [anon_sym_SLASH] = ACTIONS(5982),
    [anon_sym_PERCENT] = ACTIONS(5980),
    [anon_sym_PIPE_PIPE] = ACTIONS(5980),
    [anon_sym_AMP_AMP] = ACTIONS(5980),
    [anon_sym_PIPE] = ACTIONS(5982),
    [anon_sym_CARET] = ACTIONS(5980),
    [anon_sym_AMP] = ACTIONS(5982),
    [anon_sym_EQ_EQ] = ACTIONS(5980),
    [anon_sym_BANG_EQ] = ACTIONS(5980),
    [anon_sym_GT] = ACTIONS(5982),
    [anon_sym_GT_EQ] = ACTIONS(5980),
    [anon_sym_LT_EQ] = ACTIONS(5982),
    [anon_sym_LT] = ACTIONS(5982),
    [anon_sym_LT_LT] = ACTIONS(5982),
    [anon_sym_GT_GT] = ACTIONS(5980),
    [anon_sym_SEMI] = ACTIONS(5980),
    [anon_sym___extension__] = ACTIONS(5980),
    [anon_sym___global__] = ACTIONS(5980),
    [anon_sym___attribute__] = ACTIONS(5980),
    [anon_sym___attribute] = ACTIONS(5982),
    [anon_sym_LBRACE] = ACTIONS(5980),
    [anon_sym_RBRACE] = ACTIONS(5980),
    [anon_sym_signed] = ACTIONS(5902),
    [anon_sym_unsigned] = ACTIONS(5902),
    [anon_sym_long] = ACTIONS(5902),
    [anon_sym_short] = ACTIONS(5902),
    [anon_sym_LBRACK] = ACTIONS(5980),
    [anon_sym_RBRACK] = ACTIONS(5980),
    [anon_sym_const] = ACTIONS(5982),
    [anon_sym_constexpr] = ACTIONS(5980),
    [anon_sym_volatile] = ACTIONS(5980),
    [anon_sym_restrict] = ACTIONS(5980),
    [anon_sym___restrict__] = ACTIONS(5980),
    [anon_sym__Atomic] = ACTIONS(5980),
    [anon_sym__Noreturn] = ACTIONS(5980),
    [anon_sym_noreturn] = ACTIONS(5980),
    [anon_sym__Nonnull] = ACTIONS(5980),
    [anon_sym_mutable] = ACTIONS(5980),
    [anon_sym_constinit] = ACTIONS(5980),
    [anon_sym_consteval] = ACTIONS(5980),
    [anon_sym___shared__] = ACTIONS(5980),
    [anon_sym___local__] = ACTIONS(5980),
    [anon_sym___constant__] = ACTIONS(5980),
    [anon_sym___managed__] = ACTIONS(5980),
    [anon_sym___grid_constant__] = ACTIONS(5980),
    [anon_sym_alignas] = ACTIONS(5980),
    [anon_sym__Alignas] = ACTIONS(5980),
    [anon_sym_COLON] = ACTIONS(5980),
    [anon_sym_QMARK] = ACTIONS(5980),
    [anon_sym_LT_EQ_GT] = ACTIONS(5980),
    [anon_sym_or] = ACTIONS(5980),
    [anon_sym_and] = ACTIONS(5980),
    [anon_sym_bitor] = ACTIONS(5980),
    [anon_sym_xor] = ACTIONS(5980),
    [anon_sym_bitand] = ACTIONS(5980),
    [anon_sym_not_eq] = ACTIONS(5980),
    [anon_sym_DASH_DASH] = ACTIONS(5980),
    [anon_sym_PLUS_PLUS] = ACTIONS(5980),
    [anon_sym_DOT] = ACTIONS(5982),
    [anon_sym_DOT_STAR] = ACTIONS(5980),
    [anon_sym_DASH_GT] = ACTIONS(5980),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5980),
    [anon_sym_decltype] = ACTIONS(5980),
    [anon_sym_final] = ACTIONS(5980),
    [anon_sym_override] = ACTIONS(5980),
    [anon_sym_requires] = ACTIONS(5980),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5980),
  },
  [STATE(2201)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5984),
    [anon_sym_COMMA] = ACTIONS(5984),
    [anon_sym_RPAREN] = ACTIONS(5984),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(5986),
    [anon_sym_PLUS] = ACTIONS(5986),
    [anon_sym_STAR] = ACTIONS(5984),
    [anon_sym_SLASH] = ACTIONS(5986),
    [anon_sym_PERCENT] = ACTIONS(5984),
    [anon_sym_PIPE_PIPE] = ACTIONS(5984),
    [anon_sym_AMP_AMP] = ACTIONS(5984),
    [anon_sym_PIPE] = ACTIONS(5986),
    [anon_sym_CARET] = ACTIONS(5984),
    [anon_sym_AMP] = ACTIONS(5986),
    [anon_sym_EQ_EQ] = ACTIONS(5984),
    [anon_sym_BANG_EQ] = ACTIONS(5984),
    [anon_sym_GT] = ACTIONS(5986),
    [anon_sym_GT_EQ] = ACTIONS(5984),
    [anon_sym_LT_EQ] = ACTIONS(5986),
    [anon_sym_LT] = ACTIONS(5986),
    [anon_sym_LT_LT] = ACTIONS(5986),
    [anon_sym_GT_GT] = ACTIONS(5984),
    [anon_sym_SEMI] = ACTIONS(5984),
    [anon_sym___extension__] = ACTIONS(5984),
    [anon_sym___global__] = ACTIONS(5984),
    [anon_sym___attribute__] = ACTIONS(5984),
    [anon_sym___attribute] = ACTIONS(5986),
    [anon_sym_LBRACE] = ACTIONS(5984),
    [anon_sym_RBRACE] = ACTIONS(5984),
    [anon_sym_signed] = ACTIONS(5902),
    [anon_sym_unsigned] = ACTIONS(5902),
    [anon_sym_long] = ACTIONS(5902),
    [anon_sym_short] = ACTIONS(5902),
    [anon_sym_LBRACK] = ACTIONS(5984),
    [anon_sym_RBRACK] = ACTIONS(5984),
    [anon_sym_const] = ACTIONS(5986),
    [anon_sym_constexpr] = ACTIONS(5984),
    [anon_sym_volatile] = ACTIONS(5984),
    [anon_sym_restrict] = ACTIONS(5984),
    [anon_sym___restrict__] = ACTIONS(5984),
    [anon_sym__Atomic] = ACTIONS(5984),
    [anon_sym__Noreturn] = ACTIONS(5984),
    [anon_sym_noreturn] = ACTIONS(5984),
    [anon_sym__Nonnull] = ACTIONS(5984),
    [anon_sym_mutable] = ACTIONS(5984),
    [anon_sym_constinit] = ACTIONS(5984),
    [anon_sym_consteval] = ACTIONS(5984),
    [anon_sym___shared__] = ACTIONS(5984),
    [anon_sym___local__] = ACTIONS(5984),
    [anon_sym___constant__] = ACTIONS(5984),
    [anon_sym___managed__] = ACTIONS(5984),
    [anon_sym___grid_constant__] = ACTIONS(5984),
    [anon_sym_alignas] = ACTIONS(5984),
    [anon_sym__Alignas] = ACTIONS(5984),
    [anon_sym_COLON] = ACTIONS(5984),
    [anon_sym_QMARK] = ACTIONS(5984),
    [anon_sym_LT_EQ_GT] = ACTIONS(5984),
    [anon_sym_or] = ACTIONS(5984),
    [anon_sym_and] = ACTIONS(5984),
    [anon_sym_bitor] = ACTIONS(5984),
    [anon_sym_xor] = ACTIONS(5984),
    [anon_sym_bitand] = ACTIONS(5984),
    [anon_sym_not_eq] = ACTIONS(5984),
    [anon_sym_DASH_DASH] = ACTIONS(5984),
    [anon_sym_PLUS_PLUS] = ACTIONS(5984),
    [anon_sym_DOT] = ACTIONS(5986),
    [anon_sym_DOT_STAR] = ACTIONS(5984),
    [anon_sym_DASH_GT] = ACTIONS(5984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5984),
    [anon_sym_decltype] = ACTIONS(5984),
    [anon_sym_final] = ACTIONS(5984),
    [anon_sym_override] = ACTIONS(5984),
    [anon_sym_requires] = ACTIONS(5984),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5984),
  },
  [STATE(2202)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2200),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5988),
    [anon_sym_COMMA] = ACTIONS(5988),
    [anon_sym_RPAREN] = ACTIONS(5988),
    [anon_sym_LPAREN2] = ACTIONS(5988),
    [anon_sym_DASH] = ACTIONS(5990),
    [anon_sym_PLUS] = ACTIONS(5990),
    [anon_sym_STAR] = ACTIONS(5988),
    [anon_sym_SLASH] = ACTIONS(5990),
    [anon_sym_PERCENT] = ACTIONS(5988),
    [anon_sym_PIPE_PIPE] = ACTIONS(5988),
    [anon_sym_AMP_AMP] = ACTIONS(5988),
    [anon_sym_PIPE] = ACTIONS(5990),
    [anon_sym_CARET] = ACTIONS(5988),
    [anon_sym_AMP] = ACTIONS(5990),
    [anon_sym_EQ_EQ] = ACTIONS(5988),
    [anon_sym_BANG_EQ] = ACTIONS(5988),
    [anon_sym_GT] = ACTIONS(5990),
    [anon_sym_GT_EQ] = ACTIONS(5988),
    [anon_sym_LT_EQ] = ACTIONS(5990),
    [anon_sym_LT] = ACTIONS(5990),
    [anon_sym_LT_LT] = ACTIONS(5990),
    [anon_sym_GT_GT] = ACTIONS(5988),
    [anon_sym_SEMI] = ACTIONS(5988),
    [anon_sym___extension__] = ACTIONS(5988),
    [anon_sym___global__] = ACTIONS(5988),
    [anon_sym___attribute__] = ACTIONS(5988),
    [anon_sym___attribute] = ACTIONS(5990),
    [anon_sym_LBRACE] = ACTIONS(5988),
    [anon_sym_RBRACE] = ACTIONS(5988),
    [anon_sym_signed] = ACTIONS(5992),
    [anon_sym_unsigned] = ACTIONS(5992),
    [anon_sym_long] = ACTIONS(5992),
    [anon_sym_short] = ACTIONS(5992),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_RBRACK] = ACTIONS(5988),
    [anon_sym_const] = ACTIONS(5990),
    [anon_sym_constexpr] = ACTIONS(5988),
    [anon_sym_volatile] = ACTIONS(5988),
    [anon_sym_restrict] = ACTIONS(5988),
    [anon_sym___restrict__] = ACTIONS(5988),
    [anon_sym__Atomic] = ACTIONS(5988),
    [anon_sym__Noreturn] = ACTIONS(5988),
    [anon_sym_noreturn] = ACTIONS(5988),
    [anon_sym__Nonnull] = ACTIONS(5988),
    [anon_sym_mutable] = ACTIONS(5988),
    [anon_sym_constinit] = ACTIONS(5988),
    [anon_sym_consteval] = ACTIONS(5988),
    [anon_sym___shared__] = ACTIONS(5988),
    [anon_sym___local__] = ACTIONS(5988),
    [anon_sym___constant__] = ACTIONS(5988),
    [anon_sym___managed__] = ACTIONS(5988),
    [anon_sym___grid_constant__] = ACTIONS(5988),
    [anon_sym_alignas] = ACTIONS(5988),
    [anon_sym__Alignas] = ACTIONS(5988),
    [anon_sym_COLON] = ACTIONS(5988),
    [anon_sym_QMARK] = ACTIONS(5988),
    [anon_sym_LT_EQ_GT] = ACTIONS(5988),
    [anon_sym_or] = ACTIONS(5988),
    [anon_sym_and] = ACTIONS(5988),
    [anon_sym_bitor] = ACTIONS(5988),
    [anon_sym_xor] = ACTIONS(5988),
    [anon_sym_bitand] = ACTIONS(5988),
    [anon_sym_not_eq] = ACTIONS(5988),
    [anon_sym_DASH_DASH] = ACTIONS(5988),
    [anon_sym_PLUS_PLUS] = ACTIONS(5988),
    [anon_sym_DOT] = ACTIONS(5990),
    [anon_sym_DOT_STAR] = ACTIONS(5988),
    [anon_sym_DASH_GT] = ACTIONS(5988),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5988),
    [anon_sym_decltype] = ACTIONS(5988),
    [anon_sym_final] = ACTIONS(5988),
    [anon_sym_override] = ACTIONS(5988),
    [anon_sym_requires] = ACTIONS(5988),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5988),
  },
  [STATE(2203)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2195),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5994),
    [anon_sym_COMMA] = ACTIONS(5994),
    [anon_sym_RPAREN] = ACTIONS(5994),
    [anon_sym_LPAREN2] = ACTIONS(5994),
    [anon_sym_DASH] = ACTIONS(5996),
    [anon_sym_PLUS] = ACTIONS(5996),
    [anon_sym_STAR] = ACTIONS(5994),
    [anon_sym_SLASH] = ACTIONS(5996),
    [anon_sym_PERCENT] = ACTIONS(5994),
    [anon_sym_PIPE_PIPE] = ACTIONS(5994),
    [anon_sym_AMP_AMP] = ACTIONS(5994),
    [anon_sym_PIPE] = ACTIONS(5996),
    [anon_sym_CARET] = ACTIONS(5994),
    [anon_sym_AMP] = ACTIONS(5996),
    [anon_sym_EQ_EQ] = ACTIONS(5994),
    [anon_sym_BANG_EQ] = ACTIONS(5994),
    [anon_sym_GT] = ACTIONS(5996),
    [anon_sym_GT_EQ] = ACTIONS(5994),
    [anon_sym_LT_EQ] = ACTIONS(5996),
    [anon_sym_LT] = ACTIONS(5996),
    [anon_sym_LT_LT] = ACTIONS(5996),
    [anon_sym_GT_GT] = ACTIONS(5994),
    [anon_sym_SEMI] = ACTIONS(5994),
    [anon_sym___extension__] = ACTIONS(5994),
    [anon_sym___global__] = ACTIONS(5994),
    [anon_sym___attribute__] = ACTIONS(5994),
    [anon_sym___attribute] = ACTIONS(5996),
    [anon_sym_LBRACE] = ACTIONS(5994),
    [anon_sym_RBRACE] = ACTIONS(5994),
    [anon_sym_signed] = ACTIONS(5998),
    [anon_sym_unsigned] = ACTIONS(5998),
    [anon_sym_long] = ACTIONS(5998),
    [anon_sym_short] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5994),
    [anon_sym_RBRACK] = ACTIONS(5994),
    [anon_sym_const] = ACTIONS(5996),
    [anon_sym_constexpr] = ACTIONS(5994),
    [anon_sym_volatile] = ACTIONS(5994),
    [anon_sym_restrict] = ACTIONS(5994),
    [anon_sym___restrict__] = ACTIONS(5994),
    [anon_sym__Atomic] = ACTIONS(5994),
    [anon_sym__Noreturn] = ACTIONS(5994),
    [anon_sym_noreturn] = ACTIONS(5994),
    [anon_sym__Nonnull] = ACTIONS(5994),
    [anon_sym_mutable] = ACTIONS(5994),
    [anon_sym_constinit] = ACTIONS(5994),
    [anon_sym_consteval] = ACTIONS(5994),
    [anon_sym___shared__] = ACTIONS(5994),
    [anon_sym___local__] = ACTIONS(5994),
    [anon_sym___constant__] = ACTIONS(5994),
    [anon_sym___managed__] = ACTIONS(5994),
    [anon_sym___grid_constant__] = ACTIONS(5994),
    [anon_sym_alignas] = ACTIONS(5994),
    [anon_sym__Alignas] = ACTIONS(5994),
    [anon_sym_COLON] = ACTIONS(5994),
    [anon_sym_QMARK] = ACTIONS(5994),
    [anon_sym_LT_EQ_GT] = ACTIONS(5994),
    [anon_sym_or] = ACTIONS(5994),
    [anon_sym_and] = ACTIONS(5994),
    [anon_sym_bitor] = ACTIONS(5994),
    [anon_sym_xor] = ACTIONS(5994),
    [anon_sym_bitand] = ACTIONS(5994),
    [anon_sym_not_eq] = ACTIONS(5994),
    [anon_sym_DASH_DASH] = ACTIONS(5994),
    [anon_sym_PLUS_PLUS] = ACTIONS(5994),
    [anon_sym_DOT] = ACTIONS(5996),
    [anon_sym_DOT_STAR] = ACTIONS(5994),
    [anon_sym_DASH_GT] = ACTIONS(5994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5994),
    [anon_sym_decltype] = ACTIONS(5994),
    [anon_sym_final] = ACTIONS(5994),
    [anon_sym_override] = ACTIONS(5994),
    [anon_sym_requires] = ACTIONS(5994),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5994),
  },
  [STATE(2204)] = {
    [sym_string_literal] = STATE(2208),
    [sym_raw_string_literal] = STATE(2208),
    [aux_sym_concatenated_string_repeat1] = STATE(2208),
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6002),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_RPAREN] = ACTIONS(6002),
    [aux_sym_preproc_if_token2] = ACTIONS(6002),
    [aux_sym_preproc_else_token1] = ACTIONS(6002),
    [aux_sym_preproc_elif_token1] = ACTIONS(6004),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6002),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6002),
    [anon_sym_LPAREN2] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_STAR] = ACTIONS(6004),
    [anon_sym_SLASH] = ACTIONS(6004),
    [anon_sym_PERCENT] = ACTIONS(6004),
    [anon_sym_PIPE_PIPE] = ACTIONS(6002),
    [anon_sym_AMP_AMP] = ACTIONS(6002),
    [anon_sym_PIPE] = ACTIONS(6004),
    [anon_sym_CARET] = ACTIONS(6004),
    [anon_sym_AMP] = ACTIONS(6004),
    [anon_sym_EQ_EQ] = ACTIONS(6002),
    [anon_sym_BANG_EQ] = ACTIONS(6002),
    [anon_sym_GT] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(6002),
    [anon_sym_LT_EQ] = ACTIONS(6004),
    [anon_sym_LT] = ACTIONS(6004),
    [anon_sym_LT_LT] = ACTIONS(6004),
    [anon_sym_GT_GT] = ACTIONS(6004),
    [anon_sym_SEMI] = ACTIONS(6002),
    [anon_sym_RBRACE] = ACTIONS(6002),
    [anon_sym_LBRACK] = ACTIONS(6002),
    [anon_sym_RBRACK] = ACTIONS(6002),
    [anon_sym_EQ] = ACTIONS(6004),
    [anon_sym_COLON] = ACTIONS(6002),
    [anon_sym_QMARK] = ACTIONS(6002),
    [anon_sym_STAR_EQ] = ACTIONS(6002),
    [anon_sym_SLASH_EQ] = ACTIONS(6002),
    [anon_sym_PERCENT_EQ] = ACTIONS(6002),
    [anon_sym_PLUS_EQ] = ACTIONS(6002),
    [anon_sym_DASH_EQ] = ACTIONS(6002),
    [anon_sym_LT_LT_EQ] = ACTIONS(6002),
    [anon_sym_GT_GT_EQ] = ACTIONS(6002),
    [anon_sym_AMP_EQ] = ACTIONS(6002),
    [anon_sym_CARET_EQ] = ACTIONS(6002),
    [anon_sym_PIPE_EQ] = ACTIONS(6002),
    [anon_sym_and_eq] = ACTIONS(6004),
    [anon_sym_or_eq] = ACTIONS(6004),
    [anon_sym_xor_eq] = ACTIONS(6004),
    [anon_sym_LT_EQ_GT] = ACTIONS(6002),
    [anon_sym_or] = ACTIONS(6004),
    [anon_sym_and] = ACTIONS(6004),
    [anon_sym_bitor] = ACTIONS(6004),
    [anon_sym_xor] = ACTIONS(6004),
    [anon_sym_bitand] = ACTIONS(6004),
    [anon_sym_not_eq] = ACTIONS(6004),
    [anon_sym_DASH_DASH] = ACTIONS(6002),
    [anon_sym_PLUS_PLUS] = ACTIONS(6002),
    [anon_sym_DOT] = ACTIONS(6004),
    [anon_sym_DOT_STAR] = ACTIONS(6002),
    [anon_sym_DASH_GT] = ACTIONS(6002),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [sym_literal_suffix] = ACTIONS(6004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6002),
  },
  [STATE(2205)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6006),
    [anon_sym_COMMA] = ACTIONS(6006),
    [anon_sym_RPAREN] = ACTIONS(6006),
    [anon_sym_LPAREN2] = ACTIONS(6006),
    [anon_sym_DASH] = ACTIONS(6008),
    [anon_sym_PLUS] = ACTIONS(6008),
    [anon_sym_STAR] = ACTIONS(6006),
    [anon_sym_SLASH] = ACTIONS(6008),
    [anon_sym_PERCENT] = ACTIONS(6006),
    [anon_sym_PIPE_PIPE] = ACTIONS(6006),
    [anon_sym_AMP_AMP] = ACTIONS(6006),
    [anon_sym_PIPE] = ACTIONS(6008),
    [anon_sym_CARET] = ACTIONS(6006),
    [anon_sym_AMP] = ACTIONS(6008),
    [anon_sym_EQ_EQ] = ACTIONS(6006),
    [anon_sym_BANG_EQ] = ACTIONS(6006),
    [anon_sym_GT] = ACTIONS(6008),
    [anon_sym_GT_EQ] = ACTIONS(6006),
    [anon_sym_LT_EQ] = ACTIONS(6008),
    [anon_sym_LT] = ACTIONS(6008),
    [anon_sym_LT_LT] = ACTIONS(6008),
    [anon_sym_GT_GT] = ACTIONS(6006),
    [anon_sym_SEMI] = ACTIONS(6006),
    [anon_sym___extension__] = ACTIONS(6006),
    [anon_sym___global__] = ACTIONS(6006),
    [anon_sym___attribute__] = ACTIONS(6006),
    [anon_sym___attribute] = ACTIONS(6008),
    [anon_sym_LBRACE] = ACTIONS(6006),
    [anon_sym_RBRACE] = ACTIONS(6006),
    [anon_sym_signed] = ACTIONS(5902),
    [anon_sym_unsigned] = ACTIONS(5902),
    [anon_sym_long] = ACTIONS(5902),
    [anon_sym_short] = ACTIONS(5902),
    [anon_sym_LBRACK] = ACTIONS(6006),
    [anon_sym_RBRACK] = ACTIONS(6006),
    [anon_sym_const] = ACTIONS(6008),
    [anon_sym_constexpr] = ACTIONS(6006),
    [anon_sym_volatile] = ACTIONS(6006),
    [anon_sym_restrict] = ACTIONS(6006),
    [anon_sym___restrict__] = ACTIONS(6006),
    [anon_sym__Atomic] = ACTIONS(6006),
    [anon_sym__Noreturn] = ACTIONS(6006),
    [anon_sym_noreturn] = ACTIONS(6006),
    [anon_sym__Nonnull] = ACTIONS(6006),
    [anon_sym_mutable] = ACTIONS(6006),
    [anon_sym_constinit] = ACTIONS(6006),
    [anon_sym_consteval] = ACTIONS(6006),
    [anon_sym___shared__] = ACTIONS(6006),
    [anon_sym___local__] = ACTIONS(6006),
    [anon_sym___constant__] = ACTIONS(6006),
    [anon_sym___managed__] = ACTIONS(6006),
    [anon_sym___grid_constant__] = ACTIONS(6006),
    [anon_sym_alignas] = ACTIONS(6006),
    [anon_sym__Alignas] = ACTIONS(6006),
    [anon_sym_COLON] = ACTIONS(6006),
    [anon_sym_QMARK] = ACTIONS(6006),
    [anon_sym_LT_EQ_GT] = ACTIONS(6006),
    [anon_sym_or] = ACTIONS(6006),
    [anon_sym_and] = ACTIONS(6006),
    [anon_sym_bitor] = ACTIONS(6006),
    [anon_sym_xor] = ACTIONS(6006),
    [anon_sym_bitand] = ACTIONS(6006),
    [anon_sym_not_eq] = ACTIONS(6006),
    [anon_sym_DASH_DASH] = ACTIONS(6006),
    [anon_sym_PLUS_PLUS] = ACTIONS(6006),
    [anon_sym_DOT] = ACTIONS(6008),
    [anon_sym_DOT_STAR] = ACTIONS(6006),
    [anon_sym_DASH_GT] = ACTIONS(6006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6006),
    [anon_sym_decltype] = ACTIONS(6006),
    [anon_sym_final] = ACTIONS(6006),
    [anon_sym_override] = ACTIONS(6006),
    [anon_sym_requires] = ACTIONS(6006),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6006),
  },
  [STATE(2206)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6010),
    [anon_sym_COMMA] = ACTIONS(6010),
    [anon_sym_RPAREN] = ACTIONS(6010),
    [anon_sym_LPAREN2] = ACTIONS(6010),
    [anon_sym_DASH] = ACTIONS(6012),
    [anon_sym_PLUS] = ACTIONS(6012),
    [anon_sym_STAR] = ACTIONS(6010),
    [anon_sym_SLASH] = ACTIONS(6012),
    [anon_sym_PERCENT] = ACTIONS(6010),
    [anon_sym_PIPE_PIPE] = ACTIONS(6010),
    [anon_sym_AMP_AMP] = ACTIONS(6010),
    [anon_sym_PIPE] = ACTIONS(6012),
    [anon_sym_CARET] = ACTIONS(6010),
    [anon_sym_AMP] = ACTIONS(6012),
    [anon_sym_EQ_EQ] = ACTIONS(6010),
    [anon_sym_BANG_EQ] = ACTIONS(6010),
    [anon_sym_GT] = ACTIONS(6012),
    [anon_sym_GT_EQ] = ACTIONS(6010),
    [anon_sym_LT_EQ] = ACTIONS(6012),
    [anon_sym_LT] = ACTIONS(6012),
    [anon_sym_LT_LT] = ACTIONS(6012),
    [anon_sym_GT_GT] = ACTIONS(6010),
    [anon_sym_SEMI] = ACTIONS(6010),
    [anon_sym___extension__] = ACTIONS(6010),
    [anon_sym___global__] = ACTIONS(6010),
    [anon_sym___attribute__] = ACTIONS(6010),
    [anon_sym___attribute] = ACTIONS(6012),
    [anon_sym_LBRACE] = ACTIONS(6010),
    [anon_sym_RBRACE] = ACTIONS(6010),
    [anon_sym_signed] = ACTIONS(5902),
    [anon_sym_unsigned] = ACTIONS(5902),
    [anon_sym_long] = ACTIONS(5902),
    [anon_sym_short] = ACTIONS(5902),
    [anon_sym_LBRACK] = ACTIONS(6010),
    [anon_sym_RBRACK] = ACTIONS(6010),
    [anon_sym_const] = ACTIONS(6012),
    [anon_sym_constexpr] = ACTIONS(6010),
    [anon_sym_volatile] = ACTIONS(6010),
    [anon_sym_restrict] = ACTIONS(6010),
    [anon_sym___restrict__] = ACTIONS(6010),
    [anon_sym__Atomic] = ACTIONS(6010),
    [anon_sym__Noreturn] = ACTIONS(6010),
    [anon_sym_noreturn] = ACTIONS(6010),
    [anon_sym__Nonnull] = ACTIONS(6010),
    [anon_sym_mutable] = ACTIONS(6010),
    [anon_sym_constinit] = ACTIONS(6010),
    [anon_sym_consteval] = ACTIONS(6010),
    [anon_sym___shared__] = ACTIONS(6010),
    [anon_sym___local__] = ACTIONS(6010),
    [anon_sym___constant__] = ACTIONS(6010),
    [anon_sym___managed__] = ACTIONS(6010),
    [anon_sym___grid_constant__] = ACTIONS(6010),
    [anon_sym_alignas] = ACTIONS(6010),
    [anon_sym__Alignas] = ACTIONS(6010),
    [anon_sym_COLON] = ACTIONS(6010),
    [anon_sym_QMARK] = ACTIONS(6010),
    [anon_sym_LT_EQ_GT] = ACTIONS(6010),
    [anon_sym_or] = ACTIONS(6010),
    [anon_sym_and] = ACTIONS(6010),
    [anon_sym_bitor] = ACTIONS(6010),
    [anon_sym_xor] = ACTIONS(6010),
    [anon_sym_bitand] = ACTIONS(6010),
    [anon_sym_not_eq] = ACTIONS(6010),
    [anon_sym_DASH_DASH] = ACTIONS(6010),
    [anon_sym_PLUS_PLUS] = ACTIONS(6010),
    [anon_sym_DOT] = ACTIONS(6012),
    [anon_sym_DOT_STAR] = ACTIONS(6010),
    [anon_sym_DASH_GT] = ACTIONS(6010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6010),
    [anon_sym_decltype] = ACTIONS(6010),
    [anon_sym_final] = ACTIONS(6010),
    [anon_sym_override] = ACTIONS(6010),
    [anon_sym_requires] = ACTIONS(6010),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6010),
  },
  [STATE(2207)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2189),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5686),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5686),
    [anon_sym___global__] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5686),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_signed] = ACTIONS(5978),
    [anon_sym_unsigned] = ACTIONS(5978),
    [anon_sym_long] = ACTIONS(5978),
    [anon_sym_short] = ACTIONS(5978),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5686),
    [anon_sym_volatile] = ACTIONS(5686),
    [anon_sym_restrict] = ACTIONS(5686),
    [anon_sym___restrict__] = ACTIONS(5686),
    [anon_sym__Atomic] = ACTIONS(5686),
    [anon_sym__Noreturn] = ACTIONS(5686),
    [anon_sym_noreturn] = ACTIONS(5686),
    [anon_sym__Nonnull] = ACTIONS(5686),
    [anon_sym_mutable] = ACTIONS(5686),
    [anon_sym_constinit] = ACTIONS(5686),
    [anon_sym_consteval] = ACTIONS(5686),
    [anon_sym___shared__] = ACTIONS(5686),
    [anon_sym___local__] = ACTIONS(5686),
    [anon_sym___constant__] = ACTIONS(5686),
    [anon_sym___managed__] = ACTIONS(5686),
    [anon_sym___grid_constant__] = ACTIONS(5686),
    [anon_sym_alignas] = ACTIONS(5686),
    [anon_sym__Alignas] = ACTIONS(5686),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_bitor] = ACTIONS(5686),
    [anon_sym_xor] = ACTIONS(5686),
    [anon_sym_bitand] = ACTIONS(5686),
    [anon_sym_not_eq] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5686),
    [anon_sym_decltype] = ACTIONS(5686),
    [anon_sym_final] = ACTIONS(5686),
    [anon_sym_override] = ACTIONS(5686),
    [anon_sym_requires] = ACTIONS(5686),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2208)] = {
    [sym_string_literal] = STATE(2187),
    [sym_raw_string_literal] = STATE(2187),
    [aux_sym_concatenated_string_repeat1] = STATE(2187),
    [sym_identifier] = ACTIONS(6014),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6016),
    [anon_sym_COMMA] = ACTIONS(6016),
    [anon_sym_RPAREN] = ACTIONS(6016),
    [aux_sym_preproc_if_token2] = ACTIONS(6016),
    [aux_sym_preproc_else_token1] = ACTIONS(6016),
    [aux_sym_preproc_elif_token1] = ACTIONS(6018),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6016),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6016),
    [anon_sym_LPAREN2] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6018),
    [anon_sym_STAR] = ACTIONS(6018),
    [anon_sym_SLASH] = ACTIONS(6018),
    [anon_sym_PERCENT] = ACTIONS(6018),
    [anon_sym_PIPE_PIPE] = ACTIONS(6016),
    [anon_sym_AMP_AMP] = ACTIONS(6016),
    [anon_sym_PIPE] = ACTIONS(6018),
    [anon_sym_CARET] = ACTIONS(6018),
    [anon_sym_AMP] = ACTIONS(6018),
    [anon_sym_EQ_EQ] = ACTIONS(6016),
    [anon_sym_BANG_EQ] = ACTIONS(6016),
    [anon_sym_GT] = ACTIONS(6018),
    [anon_sym_GT_EQ] = ACTIONS(6016),
    [anon_sym_LT_EQ] = ACTIONS(6018),
    [anon_sym_LT] = ACTIONS(6018),
    [anon_sym_LT_LT] = ACTIONS(6018),
    [anon_sym_GT_GT] = ACTIONS(6018),
    [anon_sym_SEMI] = ACTIONS(6016),
    [anon_sym_RBRACE] = ACTIONS(6016),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [anon_sym_RBRACK] = ACTIONS(6016),
    [anon_sym_EQ] = ACTIONS(6018),
    [anon_sym_COLON] = ACTIONS(6016),
    [anon_sym_QMARK] = ACTIONS(6016),
    [anon_sym_STAR_EQ] = ACTIONS(6016),
    [anon_sym_SLASH_EQ] = ACTIONS(6016),
    [anon_sym_PERCENT_EQ] = ACTIONS(6016),
    [anon_sym_PLUS_EQ] = ACTIONS(6016),
    [anon_sym_DASH_EQ] = ACTIONS(6016),
    [anon_sym_LT_LT_EQ] = ACTIONS(6016),
    [anon_sym_GT_GT_EQ] = ACTIONS(6016),
    [anon_sym_AMP_EQ] = ACTIONS(6016),
    [anon_sym_CARET_EQ] = ACTIONS(6016),
    [anon_sym_PIPE_EQ] = ACTIONS(6016),
    [anon_sym_and_eq] = ACTIONS(6018),
    [anon_sym_or_eq] = ACTIONS(6018),
    [anon_sym_xor_eq] = ACTIONS(6018),
    [anon_sym_LT_EQ_GT] = ACTIONS(6016),
    [anon_sym_or] = ACTIONS(6018),
    [anon_sym_and] = ACTIONS(6018),
    [anon_sym_bitor] = ACTIONS(6018),
    [anon_sym_xor] = ACTIONS(6018),
    [anon_sym_bitand] = ACTIONS(6018),
    [anon_sym_not_eq] = ACTIONS(6018),
    [anon_sym_DASH_DASH] = ACTIONS(6016),
    [anon_sym_PLUS_PLUS] = ACTIONS(6016),
    [anon_sym_DOT] = ACTIONS(6018),
    [anon_sym_DOT_STAR] = ACTIONS(6016),
    [anon_sym_DASH_GT] = ACTIONS(6016),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [sym_literal_suffix] = ACTIONS(6018),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6016),
  },
  [STATE(2209)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(2192),
    [sym__declarator] = STATE(6926),
    [sym__abstract_declarator] = STATE(7134),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(2468),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3007),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(2468),
    [aux_sym_pointer_declarator_repeat1] = STATE(2192),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(6020),
    [anon_sym_RPAREN] = ACTIONS(6020),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(5927),
    [anon_sym_AMP_AMP] = ACTIONS(5929),
    [anon_sym_AMP] = ACTIONS(5931),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(6022),
    [anon_sym___attribute] = ACTIONS(6022),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_EQ] = ACTIONS(6020),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(6020),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2210)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6024),
    [anon_sym_COMMA] = ACTIONS(6024),
    [anon_sym_RPAREN] = ACTIONS(6024),
    [anon_sym_LPAREN2] = ACTIONS(6024),
    [anon_sym_DASH] = ACTIONS(6026),
    [anon_sym_PLUS] = ACTIONS(6026),
    [anon_sym_STAR] = ACTIONS(6024),
    [anon_sym_SLASH] = ACTIONS(6026),
    [anon_sym_PERCENT] = ACTIONS(6024),
    [anon_sym_PIPE_PIPE] = ACTIONS(6024),
    [anon_sym_AMP_AMP] = ACTIONS(6024),
    [anon_sym_PIPE] = ACTIONS(6026),
    [anon_sym_CARET] = ACTIONS(6024),
    [anon_sym_AMP] = ACTIONS(6026),
    [anon_sym_EQ_EQ] = ACTIONS(6024),
    [anon_sym_BANG_EQ] = ACTIONS(6024),
    [anon_sym_GT] = ACTIONS(6026),
    [anon_sym_GT_EQ] = ACTIONS(6024),
    [anon_sym_LT_EQ] = ACTIONS(6026),
    [anon_sym_LT] = ACTIONS(6026),
    [anon_sym_LT_LT] = ACTIONS(6026),
    [anon_sym_GT_GT] = ACTIONS(6024),
    [anon_sym_SEMI] = ACTIONS(6024),
    [anon_sym___extension__] = ACTIONS(6024),
    [anon_sym___global__] = ACTIONS(6024),
    [anon_sym___attribute__] = ACTIONS(6024),
    [anon_sym___attribute] = ACTIONS(6026),
    [anon_sym_LBRACE] = ACTIONS(6024),
    [anon_sym_RBRACE] = ACTIONS(6024),
    [anon_sym_signed] = ACTIONS(5902),
    [anon_sym_unsigned] = ACTIONS(5902),
    [anon_sym_long] = ACTIONS(5902),
    [anon_sym_short] = ACTIONS(5902),
    [anon_sym_LBRACK] = ACTIONS(6024),
    [anon_sym_RBRACK] = ACTIONS(6024),
    [anon_sym_const] = ACTIONS(6026),
    [anon_sym_constexpr] = ACTIONS(6024),
    [anon_sym_volatile] = ACTIONS(6024),
    [anon_sym_restrict] = ACTIONS(6024),
    [anon_sym___restrict__] = ACTIONS(6024),
    [anon_sym__Atomic] = ACTIONS(6024),
    [anon_sym__Noreturn] = ACTIONS(6024),
    [anon_sym_noreturn] = ACTIONS(6024),
    [anon_sym__Nonnull] = ACTIONS(6024),
    [anon_sym_mutable] = ACTIONS(6024),
    [anon_sym_constinit] = ACTIONS(6024),
    [anon_sym_consteval] = ACTIONS(6024),
    [anon_sym___shared__] = ACTIONS(6024),
    [anon_sym___local__] = ACTIONS(6024),
    [anon_sym___constant__] = ACTIONS(6024),
    [anon_sym___managed__] = ACTIONS(6024),
    [anon_sym___grid_constant__] = ACTIONS(6024),
    [anon_sym_alignas] = ACTIONS(6024),
    [anon_sym__Alignas] = ACTIONS(6024),
    [anon_sym_COLON] = ACTIONS(6024),
    [anon_sym_QMARK] = ACTIONS(6024),
    [anon_sym_LT_EQ_GT] = ACTIONS(6024),
    [anon_sym_or] = ACTIONS(6024),
    [anon_sym_and] = ACTIONS(6024),
    [anon_sym_bitor] = ACTIONS(6024),
    [anon_sym_xor] = ACTIONS(6024),
    [anon_sym_bitand] = ACTIONS(6024),
    [anon_sym_not_eq] = ACTIONS(6024),
    [anon_sym_DASH_DASH] = ACTIONS(6024),
    [anon_sym_PLUS_PLUS] = ACTIONS(6024),
    [anon_sym_DOT] = ACTIONS(6026),
    [anon_sym_DOT_STAR] = ACTIONS(6024),
    [anon_sym_DASH_GT] = ACTIONS(6024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6024),
    [anon_sym_decltype] = ACTIONS(6024),
    [anon_sym_final] = ACTIONS(6024),
    [anon_sym_override] = ACTIONS(6024),
    [anon_sym_requires] = ACTIONS(6024),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6024),
  },
  [STATE(2211)] = {
    [sym_identifier] = ACTIONS(6028),
    [anon_sym_LPAREN2] = ACTIONS(6030),
    [anon_sym_TILDE] = ACTIONS(6030),
    [anon_sym_STAR] = ACTIONS(6030),
    [anon_sym_AMP_AMP] = ACTIONS(6030),
    [anon_sym_AMP] = ACTIONS(6028),
    [anon_sym___extension__] = ACTIONS(6028),
    [anon_sym___device__] = ACTIONS(6028),
    [anon_sym___host__] = ACTIONS(6028),
    [anon_sym___global__] = ACTIONS(6028),
    [anon_sym___forceinline__] = ACTIONS(6028),
    [anon_sym___noinline__] = ACTIONS(6028),
    [anon_sym_virtual] = ACTIONS(6028),
    [anon_sym_extern] = ACTIONS(6028),
    [anon_sym___attribute__] = ACTIONS(6028),
    [anon_sym___attribute] = ACTIONS(6028),
    [anon_sym_COLON_COLON] = ACTIONS(6030),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6030),
    [anon_sym___declspec] = ACTIONS(6028),
    [anon_sym___based] = ACTIONS(6028),
    [anon_sym___cdecl] = ACTIONS(6028),
    [anon_sym___clrcall] = ACTIONS(6028),
    [anon_sym___stdcall] = ACTIONS(6028),
    [anon_sym___fastcall] = ACTIONS(6028),
    [anon_sym___thiscall] = ACTIONS(6028),
    [anon_sym___vectorcall] = ACTIONS(6028),
    [anon_sym_signed] = ACTIONS(6028),
    [anon_sym_unsigned] = ACTIONS(6028),
    [anon_sym_long] = ACTIONS(6028),
    [anon_sym_short] = ACTIONS(6028),
    [anon_sym_LBRACK] = ACTIONS(6028),
    [anon_sym_static] = ACTIONS(6028),
    [anon_sym_register] = ACTIONS(6028),
    [anon_sym_inline] = ACTIONS(6028),
    [anon_sym___inline] = ACTIONS(6028),
    [anon_sym___inline__] = ACTIONS(6028),
    [anon_sym___forceinline] = ACTIONS(6028),
    [anon_sym_thread_local] = ACTIONS(6028),
    [anon_sym___thread] = ACTIONS(6028),
    [anon_sym_const] = ACTIONS(6028),
    [anon_sym_constexpr] = ACTIONS(6028),
    [anon_sym_volatile] = ACTIONS(6028),
    [anon_sym_restrict] = ACTIONS(6028),
    [anon_sym___restrict__] = ACTIONS(6028),
    [anon_sym__Atomic] = ACTIONS(6028),
    [anon_sym__Noreturn] = ACTIONS(6028),
    [anon_sym_noreturn] = ACTIONS(6028),
    [anon_sym__Nonnull] = ACTIONS(6028),
    [anon_sym_mutable] = ACTIONS(6028),
    [anon_sym_constinit] = ACTIONS(6028),
    [anon_sym_consteval] = ACTIONS(6028),
    [anon_sym___shared__] = ACTIONS(6028),
    [anon_sym___local__] = ACTIONS(6028),
    [anon_sym___constant__] = ACTIONS(6028),
    [anon_sym___managed__] = ACTIONS(6028),
    [anon_sym___grid_constant__] = ACTIONS(6028),
    [anon_sym_alignas] = ACTIONS(6028),
    [anon_sym__Alignas] = ACTIONS(6028),
    [sym_primitive_type] = ACTIONS(6028),
    [anon_sym_enum] = ACTIONS(6028),
    [anon_sym_class] = ACTIONS(6028),
    [anon_sym_struct] = ACTIONS(6028),
    [anon_sym_union] = ACTIONS(6028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6028),
    [anon_sym_decltype] = ACTIONS(6028),
    [anon_sym_explicit] = ACTIONS(6028),
    [anon_sym_typename] = ACTIONS(6028),
    [anon_sym_template] = ACTIONS(6028),
    [anon_sym_operator] = ACTIONS(6028),
    [anon_sym_friend] = ACTIONS(6028),
    [anon_sym_using] = ACTIONS(6028),
    [anon_sym_concept] = ACTIONS(6028),
    [anon_sym_requires] = ACTIONS(6028),
    [anon_sym___launch_bounds__] = ACTIONS(6028),
  },
  [STATE(2212)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_TILDE] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym___cdecl] = ACTIONS(5684),
    [anon_sym___clrcall] = ACTIONS(5684),
    [anon_sym___stdcall] = ACTIONS(5684),
    [anon_sym___fastcall] = ACTIONS(5684),
    [anon_sym___thiscall] = ACTIONS(5684),
    [anon_sym___vectorcall] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5684),
    [anon_sym_asm] = ACTIONS(5684),
    [anon_sym___asm__] = ACTIONS(5684),
    [anon_sym___asm] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_final] = ACTIONS(5684),
    [anon_sym_override] = ACTIONS(5684),
    [anon_sym_template] = ACTIONS(5684),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_operator] = ACTIONS(5684),
    [anon_sym_try] = ACTIONS(5684),
    [anon_sym_requires] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2213)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_RPAREN] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5354),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5354),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5354),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5354),
    [anon_sym_SEMI] = ACTIONS(5354),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_RBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_long] = ACTIONS(5600),
    [anon_sym_short] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_RBRACK] = ACTIONS(5354),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_COLON] = ACTIONS(5354),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5354),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
  },
  [STATE(2214)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1845),
    [sym_identifier] = ACTIONS(5351),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [aux_sym_preproc_if_token2] = ACTIONS(5354),
    [aux_sym_preproc_else_token1] = ACTIONS(5354),
    [aux_sym_preproc_elif_token1] = ACTIONS(5351),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5354),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5354),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5354),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5354),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5354),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_long] = ACTIONS(5600),
    [anon_sym_short] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5354),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
  },
  [STATE(2215)] = {
    [sym_identifier] = ACTIONS(5655),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5657),
    [anon_sym_COMMA] = ACTIONS(5657),
    [anon_sym_RPAREN] = ACTIONS(5657),
    [anon_sym_LPAREN2] = ACTIONS(5657),
    [anon_sym_TILDE] = ACTIONS(5657),
    [anon_sym_STAR] = ACTIONS(5657),
    [anon_sym_AMP_AMP] = ACTIONS(5657),
    [anon_sym_AMP] = ACTIONS(5655),
    [anon_sym_SEMI] = ACTIONS(5657),
    [anon_sym___extension__] = ACTIONS(5655),
    [anon_sym___device__] = ACTIONS(5655),
    [anon_sym___host__] = ACTIONS(5655),
    [anon_sym___global__] = ACTIONS(5655),
    [anon_sym___forceinline__] = ACTIONS(5655),
    [anon_sym___noinline__] = ACTIONS(5655),
    [anon_sym_virtual] = ACTIONS(5655),
    [anon_sym_extern] = ACTIONS(5655),
    [anon_sym___attribute__] = ACTIONS(5655),
    [anon_sym___attribute] = ACTIONS(5655),
    [anon_sym_COLON_COLON] = ACTIONS(5657),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5657),
    [anon_sym___declspec] = ACTIONS(5655),
    [anon_sym___based] = ACTIONS(5655),
    [anon_sym___cdecl] = ACTIONS(5655),
    [anon_sym___clrcall] = ACTIONS(5655),
    [anon_sym___stdcall] = ACTIONS(5655),
    [anon_sym___fastcall] = ACTIONS(5655),
    [anon_sym___thiscall] = ACTIONS(5655),
    [anon_sym___vectorcall] = ACTIONS(5655),
    [anon_sym_LBRACE] = ACTIONS(5657),
    [anon_sym_LBRACK] = ACTIONS(5655),
    [anon_sym_static] = ACTIONS(5655),
    [anon_sym_EQ] = ACTIONS(5657),
    [anon_sym_register] = ACTIONS(5655),
    [anon_sym_inline] = ACTIONS(5655),
    [anon_sym___inline] = ACTIONS(5655),
    [anon_sym___inline__] = ACTIONS(5655),
    [anon_sym___forceinline] = ACTIONS(5655),
    [anon_sym_thread_local] = ACTIONS(5655),
    [anon_sym___thread] = ACTIONS(5655),
    [anon_sym_const] = ACTIONS(5655),
    [anon_sym_constexpr] = ACTIONS(5655),
    [anon_sym_volatile] = ACTIONS(5655),
    [anon_sym_restrict] = ACTIONS(5655),
    [anon_sym___restrict__] = ACTIONS(5655),
    [anon_sym__Atomic] = ACTIONS(5655),
    [anon_sym__Noreturn] = ACTIONS(5655),
    [anon_sym_noreturn] = ACTIONS(5655),
    [anon_sym__Nonnull] = ACTIONS(5655),
    [anon_sym_mutable] = ACTIONS(5655),
    [anon_sym_constinit] = ACTIONS(5655),
    [anon_sym_consteval] = ACTIONS(5655),
    [anon_sym___shared__] = ACTIONS(5655),
    [anon_sym___local__] = ACTIONS(5655),
    [anon_sym___constant__] = ACTIONS(5655),
    [anon_sym___managed__] = ACTIONS(5655),
    [anon_sym___grid_constant__] = ACTIONS(5655),
    [anon_sym_alignas] = ACTIONS(5655),
    [anon_sym__Alignas] = ACTIONS(5655),
    [anon_sym_COLON] = ACTIONS(5655),
    [anon_sym_asm] = ACTIONS(5655),
    [anon_sym___asm__] = ACTIONS(5655),
    [anon_sym___asm] = ACTIONS(5655),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5655),
    [anon_sym_decltype] = ACTIONS(5655),
    [anon_sym_final] = ACTIONS(5655),
    [anon_sym_override] = ACTIONS(5655),
    [anon_sym_template] = ACTIONS(5655),
    [anon_sym_GT2] = ACTIONS(5657),
    [anon_sym_operator] = ACTIONS(5655),
    [anon_sym_try] = ACTIONS(5655),
    [anon_sym_requires] = ACTIONS(5655),
    [anon_sym___launch_bounds__] = ACTIONS(5655),
  },
  [STATE(2216)] = {
    [sym_identifier] = ACTIONS(6032),
    [anon_sym_LPAREN2] = ACTIONS(6034),
    [anon_sym_BANG] = ACTIONS(6034),
    [anon_sym_TILDE] = ACTIONS(6034),
    [anon_sym_DASH] = ACTIONS(6032),
    [anon_sym_PLUS] = ACTIONS(6032),
    [anon_sym_STAR] = ACTIONS(6034),
    [anon_sym_AMP] = ACTIONS(6034),
    [anon_sym_SEMI] = ACTIONS(6034),
    [anon_sym___extension__] = ACTIONS(6032),
    [anon_sym_COLON_COLON] = ACTIONS(6034),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6034),
    [anon_sym_LBRACE] = ACTIONS(6034),
    [anon_sym_LBRACK] = ACTIONS(6032),
    [sym_primitive_type] = ACTIONS(6032),
    [anon_sym_if] = ACTIONS(6032),
    [anon_sym_switch] = ACTIONS(6032),
    [anon_sym_case] = ACTIONS(6032),
    [anon_sym_default] = ACTIONS(6032),
    [anon_sym_while] = ACTIONS(6032),
    [anon_sym_do] = ACTIONS(6032),
    [anon_sym_for] = ACTIONS(6032),
    [anon_sym_return] = ACTIONS(6032),
    [anon_sym_break] = ACTIONS(6032),
    [anon_sym_continue] = ACTIONS(6032),
    [anon_sym_goto] = ACTIONS(6032),
    [anon_sym___try] = ACTIONS(6032),
    [anon_sym___leave] = ACTIONS(6032),
    [anon_sym_not] = ACTIONS(6032),
    [anon_sym_compl] = ACTIONS(6032),
    [anon_sym_DASH_DASH] = ACTIONS(6034),
    [anon_sym_PLUS_PLUS] = ACTIONS(6034),
    [anon_sym_sizeof] = ACTIONS(6032),
    [anon_sym___alignof__] = ACTIONS(6032),
    [anon_sym___alignof] = ACTIONS(6032),
    [anon_sym__alignof] = ACTIONS(6032),
    [anon_sym_alignof] = ACTIONS(6032),
    [anon_sym__Alignof] = ACTIONS(6032),
    [anon_sym_offsetof] = ACTIONS(6032),
    [anon_sym__Generic] = ACTIONS(6032),
    [anon_sym_asm] = ACTIONS(6032),
    [anon_sym___asm__] = ACTIONS(6032),
    [anon_sym___asm] = ACTIONS(6032),
    [sym_number_literal] = ACTIONS(6034),
    [anon_sym_L_SQUOTE] = ACTIONS(6034),
    [anon_sym_u_SQUOTE] = ACTIONS(6034),
    [anon_sym_U_SQUOTE] = ACTIONS(6034),
    [anon_sym_u8_SQUOTE] = ACTIONS(6034),
    [anon_sym_SQUOTE] = ACTIONS(6034),
    [anon_sym_L_DQUOTE] = ACTIONS(6034),
    [anon_sym_u_DQUOTE] = ACTIONS(6034),
    [anon_sym_U_DQUOTE] = ACTIONS(6034),
    [anon_sym_u8_DQUOTE] = ACTIONS(6034),
    [anon_sym_DQUOTE] = ACTIONS(6034),
    [sym_true] = ACTIONS(6032),
    [sym_false] = ACTIONS(6032),
    [anon_sym_NULL] = ACTIONS(6032),
    [anon_sym_nullptr] = ACTIONS(6032),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6032),
    [anon_sym_template] = ACTIONS(6032),
    [anon_sym_try] = ACTIONS(6032),
    [anon_sym_delete] = ACTIONS(6032),
    [anon_sym_throw] = ACTIONS(6032),
    [anon_sym_co_return] = ACTIONS(6032),
    [anon_sym_co_yield] = ACTIONS(6032),
    [anon_sym_R_DQUOTE] = ACTIONS(6034),
    [anon_sym_LR_DQUOTE] = ACTIONS(6034),
    [anon_sym_uR_DQUOTE] = ACTIONS(6034),
    [anon_sym_UR_DQUOTE] = ACTIONS(6034),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6034),
    [anon_sym_co_await] = ACTIONS(6032),
    [anon_sym_new] = ACTIONS(6032),
    [anon_sym_requires] = ACTIONS(6032),
    [sym_this] = ACTIONS(6032),
  },
  [STATE(2217)] = {
    [sym_attribute_specifier] = STATE(2143),
    [sym_field_declaration_list] = STATE(2289),
    [sym_virtual_specifier] = STATE(7543),
    [sym_base_class_clause] = STATE(8302),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6036),
    [anon_sym_COMMA] = ACTIONS(6036),
    [anon_sym_RPAREN] = ACTIONS(6036),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_DASH] = ACTIONS(6038),
    [anon_sym_PLUS] = ACTIONS(6038),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_SLASH] = ACTIONS(6038),
    [anon_sym_PERCENT] = ACTIONS(6036),
    [anon_sym_PIPE_PIPE] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_PIPE] = ACTIONS(6038),
    [anon_sym_CARET] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_EQ_EQ] = ACTIONS(6036),
    [anon_sym_BANG_EQ] = ACTIONS(6036),
    [anon_sym_GT] = ACTIONS(6038),
    [anon_sym_GT_EQ] = ACTIONS(6036),
    [anon_sym_LT_EQ] = ACTIONS(6038),
    [anon_sym_LT] = ACTIONS(6038),
    [anon_sym_LT_LT] = ACTIONS(6038),
    [anon_sym_GT_GT] = ACTIONS(6036),
    [anon_sym_SEMI] = ACTIONS(6036),
    [anon_sym___extension__] = ACTIONS(6036),
    [anon_sym___global__] = ACTIONS(6036),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6044),
    [anon_sym_RBRACE] = ACTIONS(6036),
    [anon_sym_LBRACK] = ACTIONS(6036),
    [anon_sym_RBRACK] = ACTIONS(6036),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6036),
    [anon_sym_volatile] = ACTIONS(6036),
    [anon_sym_restrict] = ACTIONS(6036),
    [anon_sym___restrict__] = ACTIONS(6036),
    [anon_sym__Atomic] = ACTIONS(6036),
    [anon_sym__Noreturn] = ACTIONS(6036),
    [anon_sym_noreturn] = ACTIONS(6036),
    [anon_sym__Nonnull] = ACTIONS(6036),
    [anon_sym_mutable] = ACTIONS(6036),
    [anon_sym_constinit] = ACTIONS(6036),
    [anon_sym_consteval] = ACTIONS(6036),
    [anon_sym___shared__] = ACTIONS(6036),
    [anon_sym___local__] = ACTIONS(6036),
    [anon_sym___constant__] = ACTIONS(6036),
    [anon_sym___managed__] = ACTIONS(6036),
    [anon_sym___grid_constant__] = ACTIONS(6036),
    [anon_sym_alignas] = ACTIONS(6036),
    [anon_sym__Alignas] = ACTIONS(6036),
    [anon_sym_COLON] = ACTIONS(6046),
    [anon_sym_QMARK] = ACTIONS(6036),
    [anon_sym_LT_EQ_GT] = ACTIONS(6036),
    [anon_sym_or] = ACTIONS(6036),
    [anon_sym_and] = ACTIONS(6036),
    [anon_sym_bitor] = ACTIONS(6036),
    [anon_sym_xor] = ACTIONS(6036),
    [anon_sym_bitand] = ACTIONS(6036),
    [anon_sym_not_eq] = ACTIONS(6036),
    [anon_sym_DASH_DASH] = ACTIONS(6036),
    [anon_sym_PLUS_PLUS] = ACTIONS(6036),
    [anon_sym_DOT] = ACTIONS(6038),
    [anon_sym_DOT_STAR] = ACTIONS(6036),
    [anon_sym_DASH_GT] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6036),
    [anon_sym_decltype] = ACTIONS(6036),
    [anon_sym_final] = ACTIONS(6048),
    [anon_sym_override] = ACTIONS(6048),
    [anon_sym_requires] = ACTIONS(6036),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6036),
  },
  [STATE(2218)] = {
    [sym_decltype_auto] = STATE(2255),
    [sym_identifier] = ACTIONS(5673),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5675),
    [anon_sym_COMMA] = ACTIONS(5675),
    [anon_sym_RPAREN] = ACTIONS(5675),
    [anon_sym_LPAREN2] = ACTIONS(5675),
    [anon_sym_TILDE] = ACTIONS(5675),
    [anon_sym_STAR] = ACTIONS(5675),
    [anon_sym_AMP_AMP] = ACTIONS(5675),
    [anon_sym_AMP] = ACTIONS(5673),
    [anon_sym_SEMI] = ACTIONS(5675),
    [anon_sym___extension__] = ACTIONS(5673),
    [anon_sym___device__] = ACTIONS(5673),
    [anon_sym___host__] = ACTIONS(5673),
    [anon_sym___global__] = ACTIONS(5673),
    [anon_sym___forceinline__] = ACTIONS(5673),
    [anon_sym___noinline__] = ACTIONS(5673),
    [anon_sym_virtual] = ACTIONS(5673),
    [anon_sym_extern] = ACTIONS(5673),
    [anon_sym___attribute__] = ACTIONS(5673),
    [anon_sym___attribute] = ACTIONS(5673),
    [anon_sym_COLON_COLON] = ACTIONS(5675),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5675),
    [anon_sym___declspec] = ACTIONS(5673),
    [anon_sym___based] = ACTIONS(5673),
    [anon_sym___cdecl] = ACTIONS(5673),
    [anon_sym___clrcall] = ACTIONS(5673),
    [anon_sym___stdcall] = ACTIONS(5673),
    [anon_sym___fastcall] = ACTIONS(5673),
    [anon_sym___thiscall] = ACTIONS(5673),
    [anon_sym___vectorcall] = ACTIONS(5673),
    [anon_sym_LBRACE] = ACTIONS(5675),
    [anon_sym_LBRACK] = ACTIONS(5673),
    [anon_sym_static] = ACTIONS(5673),
    [anon_sym_EQ] = ACTIONS(5675),
    [anon_sym_register] = ACTIONS(5673),
    [anon_sym_inline] = ACTIONS(5673),
    [anon_sym___inline] = ACTIONS(5673),
    [anon_sym___inline__] = ACTIONS(5673),
    [anon_sym___forceinline] = ACTIONS(5673),
    [anon_sym_thread_local] = ACTIONS(5673),
    [anon_sym___thread] = ACTIONS(5673),
    [anon_sym_const] = ACTIONS(5673),
    [anon_sym_constexpr] = ACTIONS(5673),
    [anon_sym_volatile] = ACTIONS(5673),
    [anon_sym_restrict] = ACTIONS(5673),
    [anon_sym___restrict__] = ACTIONS(5673),
    [anon_sym__Atomic] = ACTIONS(5673),
    [anon_sym__Noreturn] = ACTIONS(5673),
    [anon_sym_noreturn] = ACTIONS(5673),
    [anon_sym__Nonnull] = ACTIONS(5673),
    [anon_sym_mutable] = ACTIONS(5673),
    [anon_sym_constinit] = ACTIONS(5673),
    [anon_sym_consteval] = ACTIONS(5673),
    [anon_sym___shared__] = ACTIONS(5673),
    [anon_sym___local__] = ACTIONS(5673),
    [anon_sym___constant__] = ACTIONS(5673),
    [anon_sym___managed__] = ACTIONS(5673),
    [anon_sym___grid_constant__] = ACTIONS(5673),
    [anon_sym_alignas] = ACTIONS(5673),
    [anon_sym__Alignas] = ACTIONS(5673),
    [anon_sym_asm] = ACTIONS(5673),
    [anon_sym___asm__] = ACTIONS(5673),
    [anon_sym___asm] = ACTIONS(5673),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_final] = ACTIONS(5673),
    [anon_sym_override] = ACTIONS(5673),
    [anon_sym_template] = ACTIONS(5673),
    [anon_sym_GT2] = ACTIONS(5675),
    [anon_sym_operator] = ACTIONS(5673),
    [anon_sym_try] = ACTIONS(5673),
    [anon_sym_requires] = ACTIONS(5673),
    [anon_sym___launch_bounds__] = ACTIONS(5673),
  },
  [STATE(2219)] = {
    [sym_identifier] = ACTIONS(6050),
    [anon_sym_LPAREN2] = ACTIONS(6052),
    [anon_sym_BANG] = ACTIONS(6052),
    [anon_sym_TILDE] = ACTIONS(6052),
    [anon_sym_DASH] = ACTIONS(6050),
    [anon_sym_PLUS] = ACTIONS(6050),
    [anon_sym_STAR] = ACTIONS(6052),
    [anon_sym_AMP] = ACTIONS(6052),
    [anon_sym_SEMI] = ACTIONS(6052),
    [anon_sym___extension__] = ACTIONS(6050),
    [anon_sym_COLON_COLON] = ACTIONS(6052),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6052),
    [anon_sym_LBRACE] = ACTIONS(6052),
    [anon_sym_LBRACK] = ACTIONS(6050),
    [sym_primitive_type] = ACTIONS(6050),
    [anon_sym_if] = ACTIONS(6050),
    [anon_sym_switch] = ACTIONS(6050),
    [anon_sym_case] = ACTIONS(6050),
    [anon_sym_default] = ACTIONS(6050),
    [anon_sym_while] = ACTIONS(6050),
    [anon_sym_do] = ACTIONS(6050),
    [anon_sym_for] = ACTIONS(6050),
    [anon_sym_return] = ACTIONS(6050),
    [anon_sym_break] = ACTIONS(6050),
    [anon_sym_continue] = ACTIONS(6050),
    [anon_sym_goto] = ACTIONS(6050),
    [anon_sym___try] = ACTIONS(6050),
    [anon_sym___leave] = ACTIONS(6050),
    [anon_sym_not] = ACTIONS(6050),
    [anon_sym_compl] = ACTIONS(6050),
    [anon_sym_DASH_DASH] = ACTIONS(6052),
    [anon_sym_PLUS_PLUS] = ACTIONS(6052),
    [anon_sym_sizeof] = ACTIONS(6050),
    [anon_sym___alignof__] = ACTIONS(6050),
    [anon_sym___alignof] = ACTIONS(6050),
    [anon_sym__alignof] = ACTIONS(6050),
    [anon_sym_alignof] = ACTIONS(6050),
    [anon_sym__Alignof] = ACTIONS(6050),
    [anon_sym_offsetof] = ACTIONS(6050),
    [anon_sym__Generic] = ACTIONS(6050),
    [anon_sym_asm] = ACTIONS(6050),
    [anon_sym___asm__] = ACTIONS(6050),
    [anon_sym___asm] = ACTIONS(6050),
    [sym_number_literal] = ACTIONS(6052),
    [anon_sym_L_SQUOTE] = ACTIONS(6052),
    [anon_sym_u_SQUOTE] = ACTIONS(6052),
    [anon_sym_U_SQUOTE] = ACTIONS(6052),
    [anon_sym_u8_SQUOTE] = ACTIONS(6052),
    [anon_sym_SQUOTE] = ACTIONS(6052),
    [anon_sym_L_DQUOTE] = ACTIONS(6052),
    [anon_sym_u_DQUOTE] = ACTIONS(6052),
    [anon_sym_U_DQUOTE] = ACTIONS(6052),
    [anon_sym_u8_DQUOTE] = ACTIONS(6052),
    [anon_sym_DQUOTE] = ACTIONS(6052),
    [sym_true] = ACTIONS(6050),
    [sym_false] = ACTIONS(6050),
    [anon_sym_NULL] = ACTIONS(6050),
    [anon_sym_nullptr] = ACTIONS(6050),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6050),
    [anon_sym_template] = ACTIONS(6050),
    [anon_sym_try] = ACTIONS(6050),
    [anon_sym_delete] = ACTIONS(6050),
    [anon_sym_throw] = ACTIONS(6050),
    [anon_sym_co_return] = ACTIONS(6050),
    [anon_sym_co_yield] = ACTIONS(6050),
    [anon_sym_R_DQUOTE] = ACTIONS(6052),
    [anon_sym_LR_DQUOTE] = ACTIONS(6052),
    [anon_sym_uR_DQUOTE] = ACTIONS(6052),
    [anon_sym_UR_DQUOTE] = ACTIONS(6052),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6052),
    [anon_sym_co_await] = ACTIONS(6050),
    [anon_sym_new] = ACTIONS(6050),
    [anon_sym_requires] = ACTIONS(6050),
    [sym_this] = ACTIONS(6050),
  },
  [STATE(2220)] = {
    [sym_identifier] = ACTIONS(6054),
    [anon_sym_LPAREN2] = ACTIONS(6056),
    [anon_sym_TILDE] = ACTIONS(6056),
    [anon_sym_STAR] = ACTIONS(6056),
    [anon_sym_AMP_AMP] = ACTIONS(6056),
    [anon_sym_AMP] = ACTIONS(6054),
    [anon_sym___extension__] = ACTIONS(6054),
    [anon_sym___device__] = ACTIONS(6054),
    [anon_sym___host__] = ACTIONS(6054),
    [anon_sym___global__] = ACTIONS(6054),
    [anon_sym___forceinline__] = ACTIONS(6054),
    [anon_sym___noinline__] = ACTIONS(6054),
    [anon_sym_virtual] = ACTIONS(6054),
    [anon_sym_extern] = ACTIONS(6054),
    [anon_sym___attribute__] = ACTIONS(6054),
    [anon_sym___attribute] = ACTIONS(6054),
    [anon_sym_COLON_COLON] = ACTIONS(6056),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6056),
    [anon_sym___declspec] = ACTIONS(6054),
    [anon_sym___based] = ACTIONS(6054),
    [anon_sym___cdecl] = ACTIONS(6054),
    [anon_sym___clrcall] = ACTIONS(6054),
    [anon_sym___stdcall] = ACTIONS(6054),
    [anon_sym___fastcall] = ACTIONS(6054),
    [anon_sym___thiscall] = ACTIONS(6054),
    [anon_sym___vectorcall] = ACTIONS(6054),
    [anon_sym_signed] = ACTIONS(6054),
    [anon_sym_unsigned] = ACTIONS(6054),
    [anon_sym_long] = ACTIONS(6054),
    [anon_sym_short] = ACTIONS(6054),
    [anon_sym_LBRACK] = ACTIONS(6054),
    [anon_sym_static] = ACTIONS(6054),
    [anon_sym_register] = ACTIONS(6054),
    [anon_sym_inline] = ACTIONS(6054),
    [anon_sym___inline] = ACTIONS(6054),
    [anon_sym___inline__] = ACTIONS(6054),
    [anon_sym___forceinline] = ACTIONS(6054),
    [anon_sym_thread_local] = ACTIONS(6054),
    [anon_sym___thread] = ACTIONS(6054),
    [anon_sym_const] = ACTIONS(6054),
    [anon_sym_constexpr] = ACTIONS(6054),
    [anon_sym_volatile] = ACTIONS(6054),
    [anon_sym_restrict] = ACTIONS(6054),
    [anon_sym___restrict__] = ACTIONS(6054),
    [anon_sym__Atomic] = ACTIONS(6054),
    [anon_sym__Noreturn] = ACTIONS(6054),
    [anon_sym_noreturn] = ACTIONS(6054),
    [anon_sym__Nonnull] = ACTIONS(6054),
    [anon_sym_mutable] = ACTIONS(6054),
    [anon_sym_constinit] = ACTIONS(6054),
    [anon_sym_consteval] = ACTIONS(6054),
    [anon_sym___shared__] = ACTIONS(6054),
    [anon_sym___local__] = ACTIONS(6054),
    [anon_sym___constant__] = ACTIONS(6054),
    [anon_sym___managed__] = ACTIONS(6054),
    [anon_sym___grid_constant__] = ACTIONS(6054),
    [anon_sym_alignas] = ACTIONS(6054),
    [anon_sym__Alignas] = ACTIONS(6054),
    [sym_primitive_type] = ACTIONS(6054),
    [anon_sym_enum] = ACTIONS(6054),
    [anon_sym_class] = ACTIONS(6054),
    [anon_sym_struct] = ACTIONS(6054),
    [anon_sym_union] = ACTIONS(6054),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6054),
    [anon_sym_decltype] = ACTIONS(6054),
    [anon_sym_explicit] = ACTIONS(6054),
    [anon_sym_typename] = ACTIONS(6054),
    [anon_sym_template] = ACTIONS(6054),
    [anon_sym_operator] = ACTIONS(6054),
    [anon_sym_friend] = ACTIONS(6054),
    [anon_sym_using] = ACTIONS(6054),
    [anon_sym_concept] = ACTIONS(6054),
    [anon_sym_requires] = ACTIONS(6054),
    [anon_sym___launch_bounds__] = ACTIONS(6054),
  },
  [STATE(2221)] = {
    [sym_identifier] = ACTIONS(6058),
    [anon_sym_LPAREN2] = ACTIONS(6060),
    [anon_sym_TILDE] = ACTIONS(6060),
    [anon_sym_STAR] = ACTIONS(6060),
    [anon_sym_AMP_AMP] = ACTIONS(6060),
    [anon_sym_AMP] = ACTIONS(6058),
    [anon_sym___extension__] = ACTIONS(6058),
    [anon_sym___device__] = ACTIONS(6058),
    [anon_sym___host__] = ACTIONS(6058),
    [anon_sym___global__] = ACTIONS(6058),
    [anon_sym___forceinline__] = ACTIONS(6058),
    [anon_sym___noinline__] = ACTIONS(6058),
    [anon_sym_virtual] = ACTIONS(6058),
    [anon_sym_extern] = ACTIONS(6058),
    [anon_sym___attribute__] = ACTIONS(6058),
    [anon_sym___attribute] = ACTIONS(6058),
    [anon_sym_COLON_COLON] = ACTIONS(6060),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6060),
    [anon_sym___declspec] = ACTIONS(6058),
    [anon_sym___based] = ACTIONS(6058),
    [anon_sym___cdecl] = ACTIONS(6058),
    [anon_sym___clrcall] = ACTIONS(6058),
    [anon_sym___stdcall] = ACTIONS(6058),
    [anon_sym___fastcall] = ACTIONS(6058),
    [anon_sym___thiscall] = ACTIONS(6058),
    [anon_sym___vectorcall] = ACTIONS(6058),
    [anon_sym_signed] = ACTIONS(6058),
    [anon_sym_unsigned] = ACTIONS(6058),
    [anon_sym_long] = ACTIONS(6058),
    [anon_sym_short] = ACTIONS(6058),
    [anon_sym_LBRACK] = ACTIONS(6058),
    [anon_sym_static] = ACTIONS(6058),
    [anon_sym_register] = ACTIONS(6058),
    [anon_sym_inline] = ACTIONS(6058),
    [anon_sym___inline] = ACTIONS(6058),
    [anon_sym___inline__] = ACTIONS(6058),
    [anon_sym___forceinline] = ACTIONS(6058),
    [anon_sym_thread_local] = ACTIONS(6058),
    [anon_sym___thread] = ACTIONS(6058),
    [anon_sym_const] = ACTIONS(6058),
    [anon_sym_constexpr] = ACTIONS(6058),
    [anon_sym_volatile] = ACTIONS(6058),
    [anon_sym_restrict] = ACTIONS(6058),
    [anon_sym___restrict__] = ACTIONS(6058),
    [anon_sym__Atomic] = ACTIONS(6058),
    [anon_sym__Noreturn] = ACTIONS(6058),
    [anon_sym_noreturn] = ACTIONS(6058),
    [anon_sym__Nonnull] = ACTIONS(6058),
    [anon_sym_mutable] = ACTIONS(6058),
    [anon_sym_constinit] = ACTIONS(6058),
    [anon_sym_consteval] = ACTIONS(6058),
    [anon_sym___shared__] = ACTIONS(6058),
    [anon_sym___local__] = ACTIONS(6058),
    [anon_sym___constant__] = ACTIONS(6058),
    [anon_sym___managed__] = ACTIONS(6058),
    [anon_sym___grid_constant__] = ACTIONS(6058),
    [anon_sym_alignas] = ACTIONS(6058),
    [anon_sym__Alignas] = ACTIONS(6058),
    [sym_primitive_type] = ACTIONS(6058),
    [anon_sym_enum] = ACTIONS(6058),
    [anon_sym_class] = ACTIONS(6058),
    [anon_sym_struct] = ACTIONS(6058),
    [anon_sym_union] = ACTIONS(6058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6058),
    [anon_sym_decltype] = ACTIONS(6058),
    [anon_sym_explicit] = ACTIONS(6058),
    [anon_sym_typename] = ACTIONS(6058),
    [anon_sym_template] = ACTIONS(6058),
    [anon_sym_operator] = ACTIONS(6058),
    [anon_sym_friend] = ACTIONS(6058),
    [anon_sym_using] = ACTIONS(6058),
    [anon_sym_concept] = ACTIONS(6058),
    [anon_sym_requires] = ACTIONS(6058),
    [anon_sym___launch_bounds__] = ACTIONS(6058),
  },
  [STATE(2222)] = {
    [sym_type_qualifier] = STATE(2277),
    [sym_alignas_qualifier] = STATE(2368),
    [aux_sym__type_definition_type_repeat1] = STATE(2277),
    [aux_sym_sized_type_specifier_repeat1] = STATE(4481),
    [sym_identifier] = ACTIONS(6062),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5173),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5173),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5173),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5173),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5175),
    [anon_sym___extension__] = ACTIONS(6064),
    [anon_sym___global__] = ACTIONS(6064),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(6066),
    [anon_sym_unsigned] = ACTIONS(6066),
    [anon_sym_long] = ACTIONS(6066),
    [anon_sym_short] = ACTIONS(6066),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_const] = ACTIONS(6064),
    [anon_sym_constexpr] = ACTIONS(6064),
    [anon_sym_volatile] = ACTIONS(6064),
    [anon_sym_restrict] = ACTIONS(6064),
    [anon_sym___restrict__] = ACTIONS(6064),
    [anon_sym__Atomic] = ACTIONS(6064),
    [anon_sym__Noreturn] = ACTIONS(6064),
    [anon_sym_noreturn] = ACTIONS(6064),
    [anon_sym__Nonnull] = ACTIONS(6064),
    [anon_sym_mutable] = ACTIONS(6064),
    [anon_sym_constinit] = ACTIONS(6064),
    [anon_sym_consteval] = ACTIONS(6064),
    [anon_sym___shared__] = ACTIONS(6064),
    [anon_sym___local__] = ACTIONS(6064),
    [anon_sym___constant__] = ACTIONS(6064),
    [anon_sym___managed__] = ACTIONS(6064),
    [anon_sym___grid_constant__] = ACTIONS(6064),
    [anon_sym_alignas] = ACTIONS(6068),
    [anon_sym__Alignas] = ACTIONS(6068),
    [sym_primitive_type] = ACTIONS(6070),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5173),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5173),
  },
  [STATE(2223)] = {
    [sym_identifier] = ACTIONS(5766),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5768),
    [anon_sym_COMMA] = ACTIONS(5768),
    [anon_sym_RPAREN] = ACTIONS(5768),
    [anon_sym_LPAREN2] = ACTIONS(5768),
    [anon_sym_TILDE] = ACTIONS(5768),
    [anon_sym_STAR] = ACTIONS(5768),
    [anon_sym_AMP_AMP] = ACTIONS(5768),
    [anon_sym_AMP] = ACTIONS(5766),
    [anon_sym_SEMI] = ACTIONS(5768),
    [anon_sym___extension__] = ACTIONS(5766),
    [anon_sym___device__] = ACTIONS(5766),
    [anon_sym___host__] = ACTIONS(5766),
    [anon_sym___global__] = ACTIONS(5766),
    [anon_sym___forceinline__] = ACTIONS(5766),
    [anon_sym___noinline__] = ACTIONS(5766),
    [anon_sym_virtual] = ACTIONS(5766),
    [anon_sym_extern] = ACTIONS(5766),
    [anon_sym___attribute__] = ACTIONS(5766),
    [anon_sym___attribute] = ACTIONS(5766),
    [anon_sym_COLON_COLON] = ACTIONS(5768),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5768),
    [anon_sym___declspec] = ACTIONS(5766),
    [anon_sym___based] = ACTIONS(5766),
    [anon_sym___cdecl] = ACTIONS(5766),
    [anon_sym___clrcall] = ACTIONS(5766),
    [anon_sym___stdcall] = ACTIONS(5766),
    [anon_sym___fastcall] = ACTIONS(5766),
    [anon_sym___thiscall] = ACTIONS(5766),
    [anon_sym___vectorcall] = ACTIONS(5766),
    [anon_sym_LBRACE] = ACTIONS(5768),
    [anon_sym_LBRACK] = ACTIONS(5766),
    [anon_sym_static] = ACTIONS(5766),
    [anon_sym_EQ] = ACTIONS(5768),
    [anon_sym_register] = ACTIONS(5766),
    [anon_sym_inline] = ACTIONS(5766),
    [anon_sym___inline] = ACTIONS(5766),
    [anon_sym___inline__] = ACTIONS(5766),
    [anon_sym___forceinline] = ACTIONS(5766),
    [anon_sym_thread_local] = ACTIONS(5766),
    [anon_sym___thread] = ACTIONS(5766),
    [anon_sym_const] = ACTIONS(5766),
    [anon_sym_constexpr] = ACTIONS(5766),
    [anon_sym_volatile] = ACTIONS(5766),
    [anon_sym_restrict] = ACTIONS(5766),
    [anon_sym___restrict__] = ACTIONS(5766),
    [anon_sym__Atomic] = ACTIONS(5766),
    [anon_sym__Noreturn] = ACTIONS(5766),
    [anon_sym_noreturn] = ACTIONS(5766),
    [anon_sym__Nonnull] = ACTIONS(5766),
    [anon_sym_mutable] = ACTIONS(5766),
    [anon_sym_constinit] = ACTIONS(5766),
    [anon_sym_consteval] = ACTIONS(5766),
    [anon_sym___shared__] = ACTIONS(5766),
    [anon_sym___local__] = ACTIONS(5766),
    [anon_sym___constant__] = ACTIONS(5766),
    [anon_sym___managed__] = ACTIONS(5766),
    [anon_sym___grid_constant__] = ACTIONS(5766),
    [anon_sym_alignas] = ACTIONS(5766),
    [anon_sym__Alignas] = ACTIONS(5766),
    [anon_sym_asm] = ACTIONS(5766),
    [anon_sym___asm__] = ACTIONS(5766),
    [anon_sym___asm] = ACTIONS(5766),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5766),
    [anon_sym_decltype] = ACTIONS(5766),
    [anon_sym_final] = ACTIONS(5766),
    [anon_sym_override] = ACTIONS(5766),
    [anon_sym_template] = ACTIONS(5766),
    [anon_sym_GT2] = ACTIONS(5768),
    [anon_sym_operator] = ACTIONS(5766),
    [anon_sym_try] = ACTIONS(5766),
    [anon_sym_requires] = ACTIONS(5766),
    [anon_sym___launch_bounds__] = ACTIONS(5766),
  },
  [STATE(2224)] = {
    [sym_template_argument_list] = STATE(1659),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(6072),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6074),
    [anon_sym_COMMA] = ACTIONS(6074),
    [anon_sym_RPAREN] = ACTIONS(6074),
    [anon_sym_LPAREN2] = ACTIONS(6074),
    [anon_sym_TILDE] = ACTIONS(6074),
    [anon_sym_STAR] = ACTIONS(6074),
    [anon_sym_AMP_AMP] = ACTIONS(6074),
    [anon_sym_AMP] = ACTIONS(6072),
    [anon_sym_LT] = ACTIONS(6076),
    [anon_sym_SEMI] = ACTIONS(6074),
    [anon_sym___extension__] = ACTIONS(6072),
    [anon_sym___device__] = ACTIONS(6072),
    [anon_sym___host__] = ACTIONS(6072),
    [anon_sym___global__] = ACTIONS(6072),
    [anon_sym___forceinline__] = ACTIONS(6072),
    [anon_sym___noinline__] = ACTIONS(6072),
    [anon_sym_virtual] = ACTIONS(6072),
    [anon_sym_extern] = ACTIONS(6072),
    [anon_sym___attribute__] = ACTIONS(6072),
    [anon_sym___attribute] = ACTIONS(6072),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6074),
    [anon_sym___declspec] = ACTIONS(6072),
    [anon_sym___based] = ACTIONS(6072),
    [anon_sym___cdecl] = ACTIONS(6072),
    [anon_sym___clrcall] = ACTIONS(6072),
    [anon_sym___stdcall] = ACTIONS(6072),
    [anon_sym___fastcall] = ACTIONS(6072),
    [anon_sym___thiscall] = ACTIONS(6072),
    [anon_sym___vectorcall] = ACTIONS(6072),
    [anon_sym_LBRACE] = ACTIONS(6074),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(6072),
    [anon_sym_static] = ACTIONS(6072),
    [anon_sym_EQ] = ACTIONS(6074),
    [anon_sym_register] = ACTIONS(6072),
    [anon_sym_inline] = ACTIONS(6072),
    [anon_sym___inline] = ACTIONS(6072),
    [anon_sym___inline__] = ACTIONS(6072),
    [anon_sym___forceinline] = ACTIONS(6072),
    [anon_sym_thread_local] = ACTIONS(6072),
    [anon_sym___thread] = ACTIONS(6072),
    [anon_sym_const] = ACTIONS(6072),
    [anon_sym_constexpr] = ACTIONS(6072),
    [anon_sym_volatile] = ACTIONS(6072),
    [anon_sym_restrict] = ACTIONS(6072),
    [anon_sym___restrict__] = ACTIONS(6072),
    [anon_sym__Atomic] = ACTIONS(6072),
    [anon_sym__Noreturn] = ACTIONS(6072),
    [anon_sym_noreturn] = ACTIONS(6072),
    [anon_sym__Nonnull] = ACTIONS(6072),
    [anon_sym_mutable] = ACTIONS(6072),
    [anon_sym_constinit] = ACTIONS(6072),
    [anon_sym_consteval] = ACTIONS(6072),
    [anon_sym___shared__] = ACTIONS(6072),
    [anon_sym___local__] = ACTIONS(6072),
    [anon_sym___constant__] = ACTIONS(6072),
    [anon_sym___managed__] = ACTIONS(6072),
    [anon_sym___grid_constant__] = ACTIONS(6072),
    [anon_sym_alignas] = ACTIONS(6072),
    [anon_sym__Alignas] = ACTIONS(6072),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6072),
    [anon_sym_decltype] = ACTIONS(6072),
    [anon_sym_template] = ACTIONS(6072),
    [anon_sym_GT2] = ACTIONS(6074),
    [anon_sym_operator] = ACTIONS(6072),
    [anon_sym___launch_bounds__] = ACTIONS(6072),
  },
  [STATE(2225)] = {
    [sym_identifier] = ACTIONS(5770),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_RPAREN] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_TILDE] = ACTIONS(5772),
    [anon_sym_STAR] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym___extension__] = ACTIONS(5770),
    [anon_sym___device__] = ACTIONS(5770),
    [anon_sym___host__] = ACTIONS(5770),
    [anon_sym___global__] = ACTIONS(5770),
    [anon_sym___forceinline__] = ACTIONS(5770),
    [anon_sym___noinline__] = ACTIONS(5770),
    [anon_sym_virtual] = ACTIONS(5770),
    [anon_sym_extern] = ACTIONS(5770),
    [anon_sym___attribute__] = ACTIONS(5770),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_COLON_COLON] = ACTIONS(5772),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5772),
    [anon_sym___declspec] = ACTIONS(5770),
    [anon_sym___based] = ACTIONS(5770),
    [anon_sym___cdecl] = ACTIONS(5770),
    [anon_sym___clrcall] = ACTIONS(5770),
    [anon_sym___stdcall] = ACTIONS(5770),
    [anon_sym___fastcall] = ACTIONS(5770),
    [anon_sym___thiscall] = ACTIONS(5770),
    [anon_sym___vectorcall] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_LBRACK] = ACTIONS(5770),
    [anon_sym_static] = ACTIONS(5770),
    [anon_sym_EQ] = ACTIONS(5772),
    [anon_sym_register] = ACTIONS(5770),
    [anon_sym_inline] = ACTIONS(5770),
    [anon_sym___inline] = ACTIONS(5770),
    [anon_sym___inline__] = ACTIONS(5770),
    [anon_sym___forceinline] = ACTIONS(5770),
    [anon_sym_thread_local] = ACTIONS(5770),
    [anon_sym___thread] = ACTIONS(5770),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_constexpr] = ACTIONS(5770),
    [anon_sym_volatile] = ACTIONS(5770),
    [anon_sym_restrict] = ACTIONS(5770),
    [anon_sym___restrict__] = ACTIONS(5770),
    [anon_sym__Atomic] = ACTIONS(5770),
    [anon_sym__Noreturn] = ACTIONS(5770),
    [anon_sym_noreturn] = ACTIONS(5770),
    [anon_sym__Nonnull] = ACTIONS(5770),
    [anon_sym_mutable] = ACTIONS(5770),
    [anon_sym_constinit] = ACTIONS(5770),
    [anon_sym_consteval] = ACTIONS(5770),
    [anon_sym___shared__] = ACTIONS(5770),
    [anon_sym___local__] = ACTIONS(5770),
    [anon_sym___constant__] = ACTIONS(5770),
    [anon_sym___managed__] = ACTIONS(5770),
    [anon_sym___grid_constant__] = ACTIONS(5770),
    [anon_sym_alignas] = ACTIONS(5770),
    [anon_sym__Alignas] = ACTIONS(5770),
    [anon_sym_asm] = ACTIONS(5770),
    [anon_sym___asm__] = ACTIONS(5770),
    [anon_sym___asm] = ACTIONS(5770),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5770),
    [anon_sym_decltype] = ACTIONS(5770),
    [anon_sym_final] = ACTIONS(5770),
    [anon_sym_override] = ACTIONS(5770),
    [anon_sym_template] = ACTIONS(5770),
    [anon_sym_GT2] = ACTIONS(5772),
    [anon_sym_operator] = ACTIONS(5770),
    [anon_sym_try] = ACTIONS(5770),
    [anon_sym_requires] = ACTIONS(5770),
    [anon_sym___launch_bounds__] = ACTIONS(5770),
  },
  [STATE(2226)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(2260),
    [sym__declarator] = STATE(6926),
    [sym__abstract_declarator] = STATE(7249),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(2657),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3083),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(2657),
    [aux_sym_pointer_declarator_repeat1] = STATE(2260),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(6020),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(6078),
    [anon_sym_AMP_AMP] = ACTIONS(6080),
    [anon_sym_AMP] = ACTIONS(6082),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(6022),
    [anon_sym___attribute] = ACTIONS(6022),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(6020),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2227)] = {
    [sym_identifier] = ACTIONS(5774),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5776),
    [anon_sym_COMMA] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5776),
    [anon_sym_LPAREN2] = ACTIONS(5776),
    [anon_sym_TILDE] = ACTIONS(5776),
    [anon_sym_STAR] = ACTIONS(5776),
    [anon_sym_AMP_AMP] = ACTIONS(5776),
    [anon_sym_AMP] = ACTIONS(5774),
    [anon_sym_SEMI] = ACTIONS(5776),
    [anon_sym___extension__] = ACTIONS(5774),
    [anon_sym___device__] = ACTIONS(5774),
    [anon_sym___host__] = ACTIONS(5774),
    [anon_sym___global__] = ACTIONS(5774),
    [anon_sym___forceinline__] = ACTIONS(5774),
    [anon_sym___noinline__] = ACTIONS(5774),
    [anon_sym_virtual] = ACTIONS(5774),
    [anon_sym_extern] = ACTIONS(5774),
    [anon_sym___attribute__] = ACTIONS(5774),
    [anon_sym___attribute] = ACTIONS(5774),
    [anon_sym_COLON_COLON] = ACTIONS(5776),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5776),
    [anon_sym___declspec] = ACTIONS(5774),
    [anon_sym___based] = ACTIONS(5774),
    [anon_sym___cdecl] = ACTIONS(5774),
    [anon_sym___clrcall] = ACTIONS(5774),
    [anon_sym___stdcall] = ACTIONS(5774),
    [anon_sym___fastcall] = ACTIONS(5774),
    [anon_sym___thiscall] = ACTIONS(5774),
    [anon_sym___vectorcall] = ACTIONS(5774),
    [anon_sym_LBRACE] = ACTIONS(5776),
    [anon_sym_LBRACK] = ACTIONS(5774),
    [anon_sym_static] = ACTIONS(5774),
    [anon_sym_EQ] = ACTIONS(5776),
    [anon_sym_register] = ACTIONS(5774),
    [anon_sym_inline] = ACTIONS(5774),
    [anon_sym___inline] = ACTIONS(5774),
    [anon_sym___inline__] = ACTIONS(5774),
    [anon_sym___forceinline] = ACTIONS(5774),
    [anon_sym_thread_local] = ACTIONS(5774),
    [anon_sym___thread] = ACTIONS(5774),
    [anon_sym_const] = ACTIONS(5774),
    [anon_sym_constexpr] = ACTIONS(5774),
    [anon_sym_volatile] = ACTIONS(5774),
    [anon_sym_restrict] = ACTIONS(5774),
    [anon_sym___restrict__] = ACTIONS(5774),
    [anon_sym__Atomic] = ACTIONS(5774),
    [anon_sym__Noreturn] = ACTIONS(5774),
    [anon_sym_noreturn] = ACTIONS(5774),
    [anon_sym__Nonnull] = ACTIONS(5774),
    [anon_sym_mutable] = ACTIONS(5774),
    [anon_sym_constinit] = ACTIONS(5774),
    [anon_sym_consteval] = ACTIONS(5774),
    [anon_sym___shared__] = ACTIONS(5774),
    [anon_sym___local__] = ACTIONS(5774),
    [anon_sym___constant__] = ACTIONS(5774),
    [anon_sym___managed__] = ACTIONS(5774),
    [anon_sym___grid_constant__] = ACTIONS(5774),
    [anon_sym_alignas] = ACTIONS(5774),
    [anon_sym__Alignas] = ACTIONS(5774),
    [anon_sym_asm] = ACTIONS(5774),
    [anon_sym___asm__] = ACTIONS(5774),
    [anon_sym___asm] = ACTIONS(5774),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5774),
    [anon_sym_decltype] = ACTIONS(5774),
    [anon_sym_final] = ACTIONS(5774),
    [anon_sym_override] = ACTIONS(5774),
    [anon_sym_template] = ACTIONS(5774),
    [anon_sym_GT2] = ACTIONS(5776),
    [anon_sym_operator] = ACTIONS(5774),
    [anon_sym_try] = ACTIONS(5774),
    [anon_sym_requires] = ACTIONS(5774),
    [anon_sym___launch_bounds__] = ACTIONS(5774),
  },
  [STATE(2228)] = {
    [sym_identifier] = ACTIONS(5853),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5855),
    [anon_sym_COMMA] = ACTIONS(5855),
    [anon_sym_RPAREN] = ACTIONS(5855),
    [anon_sym_LPAREN2] = ACTIONS(5855),
    [anon_sym_TILDE] = ACTIONS(5855),
    [anon_sym_STAR] = ACTIONS(5855),
    [anon_sym_AMP_AMP] = ACTIONS(5855),
    [anon_sym_AMP] = ACTIONS(5853),
    [anon_sym_SEMI] = ACTIONS(5855),
    [anon_sym___extension__] = ACTIONS(5853),
    [anon_sym___device__] = ACTIONS(5853),
    [anon_sym___host__] = ACTIONS(5853),
    [anon_sym___global__] = ACTIONS(5853),
    [anon_sym___forceinline__] = ACTIONS(5853),
    [anon_sym___noinline__] = ACTIONS(5853),
    [anon_sym_virtual] = ACTIONS(5853),
    [anon_sym_extern] = ACTIONS(5853),
    [anon_sym___attribute__] = ACTIONS(5853),
    [anon_sym___attribute] = ACTIONS(5853),
    [anon_sym_COLON_COLON] = ACTIONS(5855),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5855),
    [anon_sym___declspec] = ACTIONS(5853),
    [anon_sym___based] = ACTIONS(5853),
    [anon_sym___cdecl] = ACTIONS(5853),
    [anon_sym___clrcall] = ACTIONS(5853),
    [anon_sym___stdcall] = ACTIONS(5853),
    [anon_sym___fastcall] = ACTIONS(5853),
    [anon_sym___thiscall] = ACTIONS(5853),
    [anon_sym___vectorcall] = ACTIONS(5853),
    [anon_sym_LBRACE] = ACTIONS(5855),
    [anon_sym_LBRACK] = ACTIONS(5853),
    [anon_sym_static] = ACTIONS(5853),
    [anon_sym_EQ] = ACTIONS(5855),
    [anon_sym_register] = ACTIONS(5853),
    [anon_sym_inline] = ACTIONS(5853),
    [anon_sym___inline] = ACTIONS(5853),
    [anon_sym___inline__] = ACTIONS(5853),
    [anon_sym___forceinline] = ACTIONS(5853),
    [anon_sym_thread_local] = ACTIONS(5853),
    [anon_sym___thread] = ACTIONS(5853),
    [anon_sym_const] = ACTIONS(5853),
    [anon_sym_constexpr] = ACTIONS(5853),
    [anon_sym_volatile] = ACTIONS(5853),
    [anon_sym_restrict] = ACTIONS(5853),
    [anon_sym___restrict__] = ACTIONS(5853),
    [anon_sym__Atomic] = ACTIONS(5853),
    [anon_sym__Noreturn] = ACTIONS(5853),
    [anon_sym_noreturn] = ACTIONS(5853),
    [anon_sym__Nonnull] = ACTIONS(5853),
    [anon_sym_mutable] = ACTIONS(5853),
    [anon_sym_constinit] = ACTIONS(5853),
    [anon_sym_consteval] = ACTIONS(5853),
    [anon_sym___shared__] = ACTIONS(5853),
    [anon_sym___local__] = ACTIONS(5853),
    [anon_sym___constant__] = ACTIONS(5853),
    [anon_sym___managed__] = ACTIONS(5853),
    [anon_sym___grid_constant__] = ACTIONS(5853),
    [anon_sym_alignas] = ACTIONS(5853),
    [anon_sym__Alignas] = ACTIONS(5853),
    [anon_sym_asm] = ACTIONS(5853),
    [anon_sym___asm__] = ACTIONS(5853),
    [anon_sym___asm] = ACTIONS(5853),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5853),
    [anon_sym_decltype] = ACTIONS(5853),
    [anon_sym_final] = ACTIONS(5853),
    [anon_sym_override] = ACTIONS(5853),
    [anon_sym_template] = ACTIONS(5853),
    [anon_sym_GT2] = ACTIONS(5855),
    [anon_sym_operator] = ACTIONS(5853),
    [anon_sym_try] = ACTIONS(5853),
    [anon_sym_requires] = ACTIONS(5853),
    [anon_sym___launch_bounds__] = ACTIONS(5853),
  },
  [STATE(2229)] = {
    [sym_identifier] = ACTIONS(5821),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5823),
    [anon_sym_COMMA] = ACTIONS(5823),
    [anon_sym_RPAREN] = ACTIONS(5823),
    [anon_sym_LPAREN2] = ACTIONS(5823),
    [anon_sym_TILDE] = ACTIONS(5823),
    [anon_sym_STAR] = ACTIONS(5823),
    [anon_sym_AMP_AMP] = ACTIONS(5823),
    [anon_sym_AMP] = ACTIONS(5821),
    [anon_sym_SEMI] = ACTIONS(5823),
    [anon_sym___extension__] = ACTIONS(5821),
    [anon_sym___device__] = ACTIONS(5821),
    [anon_sym___host__] = ACTIONS(5821),
    [anon_sym___global__] = ACTIONS(5821),
    [anon_sym___forceinline__] = ACTIONS(5821),
    [anon_sym___noinline__] = ACTIONS(5821),
    [anon_sym_virtual] = ACTIONS(5821),
    [anon_sym_extern] = ACTIONS(5821),
    [anon_sym___attribute__] = ACTIONS(5821),
    [anon_sym___attribute] = ACTIONS(5821),
    [anon_sym_COLON_COLON] = ACTIONS(5823),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5823),
    [anon_sym___declspec] = ACTIONS(5821),
    [anon_sym___based] = ACTIONS(5821),
    [anon_sym___cdecl] = ACTIONS(5821),
    [anon_sym___clrcall] = ACTIONS(5821),
    [anon_sym___stdcall] = ACTIONS(5821),
    [anon_sym___fastcall] = ACTIONS(5821),
    [anon_sym___thiscall] = ACTIONS(5821),
    [anon_sym___vectorcall] = ACTIONS(5821),
    [anon_sym_LBRACE] = ACTIONS(5823),
    [anon_sym_LBRACK] = ACTIONS(5821),
    [anon_sym_static] = ACTIONS(5821),
    [anon_sym_EQ] = ACTIONS(5823),
    [anon_sym_register] = ACTIONS(5821),
    [anon_sym_inline] = ACTIONS(5821),
    [anon_sym___inline] = ACTIONS(5821),
    [anon_sym___inline__] = ACTIONS(5821),
    [anon_sym___forceinline] = ACTIONS(5821),
    [anon_sym_thread_local] = ACTIONS(5821),
    [anon_sym___thread] = ACTIONS(5821),
    [anon_sym_const] = ACTIONS(5821),
    [anon_sym_constexpr] = ACTIONS(5821),
    [anon_sym_volatile] = ACTIONS(5821),
    [anon_sym_restrict] = ACTIONS(5821),
    [anon_sym___restrict__] = ACTIONS(5821),
    [anon_sym__Atomic] = ACTIONS(5821),
    [anon_sym__Noreturn] = ACTIONS(5821),
    [anon_sym_noreturn] = ACTIONS(5821),
    [anon_sym__Nonnull] = ACTIONS(5821),
    [anon_sym_mutable] = ACTIONS(5821),
    [anon_sym_constinit] = ACTIONS(5821),
    [anon_sym_consteval] = ACTIONS(5821),
    [anon_sym___shared__] = ACTIONS(5821),
    [anon_sym___local__] = ACTIONS(5821),
    [anon_sym___constant__] = ACTIONS(5821),
    [anon_sym___managed__] = ACTIONS(5821),
    [anon_sym___grid_constant__] = ACTIONS(5821),
    [anon_sym_alignas] = ACTIONS(5821),
    [anon_sym__Alignas] = ACTIONS(5821),
    [anon_sym_asm] = ACTIONS(5821),
    [anon_sym___asm__] = ACTIONS(5821),
    [anon_sym___asm] = ACTIONS(5821),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5821),
    [anon_sym_decltype] = ACTIONS(5821),
    [anon_sym_final] = ACTIONS(5821),
    [anon_sym_override] = ACTIONS(5821),
    [anon_sym_template] = ACTIONS(5821),
    [anon_sym_GT2] = ACTIONS(5823),
    [anon_sym_operator] = ACTIONS(5821),
    [anon_sym_try] = ACTIONS(5821),
    [anon_sym_requires] = ACTIONS(5821),
    [anon_sym___launch_bounds__] = ACTIONS(5821),
  },
  [STATE(2230)] = {
    [sym_identifier] = ACTIONS(5696),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5698),
    [anon_sym_COMMA] = ACTIONS(5698),
    [anon_sym_RPAREN] = ACTIONS(5698),
    [anon_sym_LPAREN2] = ACTIONS(5698),
    [anon_sym_TILDE] = ACTIONS(5698),
    [anon_sym_STAR] = ACTIONS(5698),
    [anon_sym_AMP_AMP] = ACTIONS(5698),
    [anon_sym_AMP] = ACTIONS(5696),
    [anon_sym_SEMI] = ACTIONS(5698),
    [anon_sym___extension__] = ACTIONS(5696),
    [anon_sym___device__] = ACTIONS(5696),
    [anon_sym___host__] = ACTIONS(5696),
    [anon_sym___global__] = ACTIONS(5696),
    [anon_sym___forceinline__] = ACTIONS(5696),
    [anon_sym___noinline__] = ACTIONS(5696),
    [anon_sym_virtual] = ACTIONS(5696),
    [anon_sym_extern] = ACTIONS(5696),
    [anon_sym___attribute__] = ACTIONS(5696),
    [anon_sym___attribute] = ACTIONS(5696),
    [anon_sym_COLON_COLON] = ACTIONS(5698),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5698),
    [anon_sym___declspec] = ACTIONS(5696),
    [anon_sym___based] = ACTIONS(5696),
    [anon_sym___cdecl] = ACTIONS(5696),
    [anon_sym___clrcall] = ACTIONS(5696),
    [anon_sym___stdcall] = ACTIONS(5696),
    [anon_sym___fastcall] = ACTIONS(5696),
    [anon_sym___thiscall] = ACTIONS(5696),
    [anon_sym___vectorcall] = ACTIONS(5696),
    [anon_sym_LBRACE] = ACTIONS(5698),
    [anon_sym_LBRACK] = ACTIONS(5696),
    [anon_sym_static] = ACTIONS(5696),
    [anon_sym_EQ] = ACTIONS(5698),
    [anon_sym_register] = ACTIONS(5696),
    [anon_sym_inline] = ACTIONS(5696),
    [anon_sym___inline] = ACTIONS(5696),
    [anon_sym___inline__] = ACTIONS(5696),
    [anon_sym___forceinline] = ACTIONS(5696),
    [anon_sym_thread_local] = ACTIONS(5696),
    [anon_sym___thread] = ACTIONS(5696),
    [anon_sym_const] = ACTIONS(5696),
    [anon_sym_constexpr] = ACTIONS(5696),
    [anon_sym_volatile] = ACTIONS(5696),
    [anon_sym_restrict] = ACTIONS(5696),
    [anon_sym___restrict__] = ACTIONS(5696),
    [anon_sym__Atomic] = ACTIONS(5696),
    [anon_sym__Noreturn] = ACTIONS(5696),
    [anon_sym_noreturn] = ACTIONS(5696),
    [anon_sym__Nonnull] = ACTIONS(5696),
    [anon_sym_mutable] = ACTIONS(5696),
    [anon_sym_constinit] = ACTIONS(5696),
    [anon_sym_consteval] = ACTIONS(5696),
    [anon_sym___shared__] = ACTIONS(5696),
    [anon_sym___local__] = ACTIONS(5696),
    [anon_sym___constant__] = ACTIONS(5696),
    [anon_sym___managed__] = ACTIONS(5696),
    [anon_sym___grid_constant__] = ACTIONS(5696),
    [anon_sym_alignas] = ACTIONS(5696),
    [anon_sym__Alignas] = ACTIONS(5696),
    [anon_sym_asm] = ACTIONS(5696),
    [anon_sym___asm__] = ACTIONS(5696),
    [anon_sym___asm] = ACTIONS(5696),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5696),
    [anon_sym_decltype] = ACTIONS(5696),
    [anon_sym_final] = ACTIONS(5696),
    [anon_sym_override] = ACTIONS(5696),
    [anon_sym_template] = ACTIONS(5696),
    [anon_sym_GT2] = ACTIONS(5698),
    [anon_sym_operator] = ACTIONS(5696),
    [anon_sym_try] = ACTIONS(5696),
    [anon_sym_requires] = ACTIONS(5696),
    [anon_sym___launch_bounds__] = ACTIONS(5696),
  },
  [STATE(2231)] = {
    [sym_identifier] = ACTIONS(5801),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5803),
    [anon_sym_COMMA] = ACTIONS(5803),
    [anon_sym_RPAREN] = ACTIONS(5803),
    [anon_sym_LPAREN2] = ACTIONS(5803),
    [anon_sym_TILDE] = ACTIONS(5803),
    [anon_sym_STAR] = ACTIONS(5803),
    [anon_sym_AMP_AMP] = ACTIONS(5803),
    [anon_sym_AMP] = ACTIONS(5801),
    [anon_sym_SEMI] = ACTIONS(5803),
    [anon_sym___extension__] = ACTIONS(5801),
    [anon_sym___device__] = ACTIONS(5801),
    [anon_sym___host__] = ACTIONS(5801),
    [anon_sym___global__] = ACTIONS(5801),
    [anon_sym___forceinline__] = ACTIONS(5801),
    [anon_sym___noinline__] = ACTIONS(5801),
    [anon_sym_virtual] = ACTIONS(5801),
    [anon_sym_extern] = ACTIONS(5801),
    [anon_sym___attribute__] = ACTIONS(5801),
    [anon_sym___attribute] = ACTIONS(5801),
    [anon_sym_COLON_COLON] = ACTIONS(5803),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5803),
    [anon_sym___declspec] = ACTIONS(5801),
    [anon_sym___based] = ACTIONS(5801),
    [anon_sym___cdecl] = ACTIONS(5801),
    [anon_sym___clrcall] = ACTIONS(5801),
    [anon_sym___stdcall] = ACTIONS(5801),
    [anon_sym___fastcall] = ACTIONS(5801),
    [anon_sym___thiscall] = ACTIONS(5801),
    [anon_sym___vectorcall] = ACTIONS(5801),
    [anon_sym_LBRACE] = ACTIONS(5803),
    [anon_sym_LBRACK] = ACTIONS(5801),
    [anon_sym_static] = ACTIONS(5801),
    [anon_sym_EQ] = ACTIONS(5803),
    [anon_sym_register] = ACTIONS(5801),
    [anon_sym_inline] = ACTIONS(5801),
    [anon_sym___inline] = ACTIONS(5801),
    [anon_sym___inline__] = ACTIONS(5801),
    [anon_sym___forceinline] = ACTIONS(5801),
    [anon_sym_thread_local] = ACTIONS(5801),
    [anon_sym___thread] = ACTIONS(5801),
    [anon_sym_const] = ACTIONS(5801),
    [anon_sym_constexpr] = ACTIONS(5801),
    [anon_sym_volatile] = ACTIONS(5801),
    [anon_sym_restrict] = ACTIONS(5801),
    [anon_sym___restrict__] = ACTIONS(5801),
    [anon_sym__Atomic] = ACTIONS(5801),
    [anon_sym__Noreturn] = ACTIONS(5801),
    [anon_sym_noreturn] = ACTIONS(5801),
    [anon_sym__Nonnull] = ACTIONS(5801),
    [anon_sym_mutable] = ACTIONS(5801),
    [anon_sym_constinit] = ACTIONS(5801),
    [anon_sym_consteval] = ACTIONS(5801),
    [anon_sym___shared__] = ACTIONS(5801),
    [anon_sym___local__] = ACTIONS(5801),
    [anon_sym___constant__] = ACTIONS(5801),
    [anon_sym___managed__] = ACTIONS(5801),
    [anon_sym___grid_constant__] = ACTIONS(5801),
    [anon_sym_alignas] = ACTIONS(5801),
    [anon_sym__Alignas] = ACTIONS(5801),
    [anon_sym_asm] = ACTIONS(5801),
    [anon_sym___asm__] = ACTIONS(5801),
    [anon_sym___asm] = ACTIONS(5801),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5801),
    [anon_sym_decltype] = ACTIONS(5801),
    [anon_sym_final] = ACTIONS(5801),
    [anon_sym_override] = ACTIONS(5801),
    [anon_sym_template] = ACTIONS(5801),
    [anon_sym_GT2] = ACTIONS(5803),
    [anon_sym_operator] = ACTIONS(5801),
    [anon_sym_try] = ACTIONS(5801),
    [anon_sym_requires] = ACTIONS(5801),
    [anon_sym___launch_bounds__] = ACTIONS(5801),
  },
  [STATE(2232)] = {
    [sym_identifier] = ACTIONS(5817),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5819),
    [anon_sym_COMMA] = ACTIONS(5819),
    [anon_sym_RPAREN] = ACTIONS(5819),
    [anon_sym_LPAREN2] = ACTIONS(5819),
    [anon_sym_TILDE] = ACTIONS(5819),
    [anon_sym_STAR] = ACTIONS(5819),
    [anon_sym_AMP_AMP] = ACTIONS(5819),
    [anon_sym_AMP] = ACTIONS(5817),
    [anon_sym_SEMI] = ACTIONS(5819),
    [anon_sym___extension__] = ACTIONS(5817),
    [anon_sym___device__] = ACTIONS(5817),
    [anon_sym___host__] = ACTIONS(5817),
    [anon_sym___global__] = ACTIONS(5817),
    [anon_sym___forceinline__] = ACTIONS(5817),
    [anon_sym___noinline__] = ACTIONS(5817),
    [anon_sym_virtual] = ACTIONS(5817),
    [anon_sym_extern] = ACTIONS(5817),
    [anon_sym___attribute__] = ACTIONS(5817),
    [anon_sym___attribute] = ACTIONS(5817),
    [anon_sym_COLON_COLON] = ACTIONS(5819),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5819),
    [anon_sym___declspec] = ACTIONS(5817),
    [anon_sym___based] = ACTIONS(5817),
    [anon_sym___cdecl] = ACTIONS(5817),
    [anon_sym___clrcall] = ACTIONS(5817),
    [anon_sym___stdcall] = ACTIONS(5817),
    [anon_sym___fastcall] = ACTIONS(5817),
    [anon_sym___thiscall] = ACTIONS(5817),
    [anon_sym___vectorcall] = ACTIONS(5817),
    [anon_sym_LBRACE] = ACTIONS(5819),
    [anon_sym_LBRACK] = ACTIONS(5817),
    [anon_sym_static] = ACTIONS(5817),
    [anon_sym_EQ] = ACTIONS(5819),
    [anon_sym_register] = ACTIONS(5817),
    [anon_sym_inline] = ACTIONS(5817),
    [anon_sym___inline] = ACTIONS(5817),
    [anon_sym___inline__] = ACTIONS(5817),
    [anon_sym___forceinline] = ACTIONS(5817),
    [anon_sym_thread_local] = ACTIONS(5817),
    [anon_sym___thread] = ACTIONS(5817),
    [anon_sym_const] = ACTIONS(5817),
    [anon_sym_constexpr] = ACTIONS(5817),
    [anon_sym_volatile] = ACTIONS(5817),
    [anon_sym_restrict] = ACTIONS(5817),
    [anon_sym___restrict__] = ACTIONS(5817),
    [anon_sym__Atomic] = ACTIONS(5817),
    [anon_sym__Noreturn] = ACTIONS(5817),
    [anon_sym_noreturn] = ACTIONS(5817),
    [anon_sym__Nonnull] = ACTIONS(5817),
    [anon_sym_mutable] = ACTIONS(5817),
    [anon_sym_constinit] = ACTIONS(5817),
    [anon_sym_consteval] = ACTIONS(5817),
    [anon_sym___shared__] = ACTIONS(5817),
    [anon_sym___local__] = ACTIONS(5817),
    [anon_sym___constant__] = ACTIONS(5817),
    [anon_sym___managed__] = ACTIONS(5817),
    [anon_sym___grid_constant__] = ACTIONS(5817),
    [anon_sym_alignas] = ACTIONS(5817),
    [anon_sym__Alignas] = ACTIONS(5817),
    [anon_sym_asm] = ACTIONS(5817),
    [anon_sym___asm__] = ACTIONS(5817),
    [anon_sym___asm] = ACTIONS(5817),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5817),
    [anon_sym_decltype] = ACTIONS(5817),
    [anon_sym_final] = ACTIONS(5817),
    [anon_sym_override] = ACTIONS(5817),
    [anon_sym_template] = ACTIONS(5817),
    [anon_sym_GT2] = ACTIONS(5819),
    [anon_sym_operator] = ACTIONS(5817),
    [anon_sym_try] = ACTIONS(5817),
    [anon_sym_requires] = ACTIONS(5817),
    [anon_sym___launch_bounds__] = ACTIONS(5817),
  },
  [STATE(2233)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(2234),
    [sym__declarator] = STATE(6926),
    [sym__abstract_declarator] = STATE(7255),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(2671),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3094),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(2671),
    [aux_sym_pointer_declarator_repeat1] = STATE(2234),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(6020),
    [anon_sym_RPAREN] = ACTIONS(6020),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(6084),
    [anon_sym_AMP_AMP] = ACTIONS(6086),
    [anon_sym_AMP] = ACTIONS(6088),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(6022),
    [anon_sym___attribute] = ACTIONS(6022),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2234)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(3478),
    [sym__declarator] = STATE(6947),
    [sym__abstract_declarator] = STATE(7260),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(2678),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3094),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(2678),
    [aux_sym_pointer_declarator_repeat1] = STATE(3478),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(5925),
    [anon_sym_RPAREN] = ACTIONS(5925),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(6084),
    [anon_sym_AMP_AMP] = ACTIONS(6086),
    [anon_sym_AMP] = ACTIONS(6088),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(5933),
    [anon_sym___attribute] = ACTIONS(5933),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2235)] = {
    [sym_identifier] = ACTIONS(5696),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5698),
    [anon_sym_COMMA] = ACTIONS(5698),
    [anon_sym_RPAREN] = ACTIONS(5698),
    [anon_sym_LPAREN2] = ACTIONS(5698),
    [anon_sym_TILDE] = ACTIONS(5698),
    [anon_sym_STAR] = ACTIONS(5698),
    [anon_sym_AMP_AMP] = ACTIONS(5698),
    [anon_sym_AMP] = ACTIONS(5696),
    [anon_sym_SEMI] = ACTIONS(5698),
    [anon_sym___extension__] = ACTIONS(5696),
    [anon_sym___device__] = ACTIONS(5696),
    [anon_sym___host__] = ACTIONS(5696),
    [anon_sym___global__] = ACTIONS(5696),
    [anon_sym___forceinline__] = ACTIONS(5696),
    [anon_sym___noinline__] = ACTIONS(5696),
    [anon_sym_virtual] = ACTIONS(5696),
    [anon_sym_extern] = ACTIONS(5696),
    [anon_sym___attribute__] = ACTIONS(5696),
    [anon_sym___attribute] = ACTIONS(5696),
    [anon_sym_COLON_COLON] = ACTIONS(5698),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5698),
    [anon_sym___declspec] = ACTIONS(5696),
    [anon_sym___based] = ACTIONS(5696),
    [anon_sym___cdecl] = ACTIONS(5696),
    [anon_sym___clrcall] = ACTIONS(5696),
    [anon_sym___stdcall] = ACTIONS(5696),
    [anon_sym___fastcall] = ACTIONS(5696),
    [anon_sym___thiscall] = ACTIONS(5696),
    [anon_sym___vectorcall] = ACTIONS(5696),
    [anon_sym_LBRACE] = ACTIONS(5698),
    [anon_sym_LBRACK] = ACTIONS(5696),
    [anon_sym_static] = ACTIONS(5696),
    [anon_sym_EQ] = ACTIONS(5698),
    [anon_sym_register] = ACTIONS(5696),
    [anon_sym_inline] = ACTIONS(5696),
    [anon_sym___inline] = ACTIONS(5696),
    [anon_sym___inline__] = ACTIONS(5696),
    [anon_sym___forceinline] = ACTIONS(5696),
    [anon_sym_thread_local] = ACTIONS(5696),
    [anon_sym___thread] = ACTIONS(5696),
    [anon_sym_const] = ACTIONS(5696),
    [anon_sym_constexpr] = ACTIONS(5696),
    [anon_sym_volatile] = ACTIONS(5696),
    [anon_sym_restrict] = ACTIONS(5696),
    [anon_sym___restrict__] = ACTIONS(5696),
    [anon_sym__Atomic] = ACTIONS(5696),
    [anon_sym__Noreturn] = ACTIONS(5696),
    [anon_sym_noreturn] = ACTIONS(5696),
    [anon_sym__Nonnull] = ACTIONS(5696),
    [anon_sym_mutable] = ACTIONS(5696),
    [anon_sym_constinit] = ACTIONS(5696),
    [anon_sym_consteval] = ACTIONS(5696),
    [anon_sym___shared__] = ACTIONS(5696),
    [anon_sym___local__] = ACTIONS(5696),
    [anon_sym___constant__] = ACTIONS(5696),
    [anon_sym___managed__] = ACTIONS(5696),
    [anon_sym___grid_constant__] = ACTIONS(5696),
    [anon_sym_alignas] = ACTIONS(5696),
    [anon_sym__Alignas] = ACTIONS(5696),
    [anon_sym_asm] = ACTIONS(5696),
    [anon_sym___asm__] = ACTIONS(5696),
    [anon_sym___asm] = ACTIONS(5696),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5696),
    [anon_sym_decltype] = ACTIONS(5696),
    [anon_sym_final] = ACTIONS(5696),
    [anon_sym_override] = ACTIONS(5696),
    [anon_sym_template] = ACTIONS(5696),
    [anon_sym_GT2] = ACTIONS(5698),
    [anon_sym_operator] = ACTIONS(5696),
    [anon_sym_try] = ACTIONS(5696),
    [anon_sym_requires] = ACTIONS(5696),
    [anon_sym___launch_bounds__] = ACTIONS(5696),
  },
  [STATE(2236)] = {
    [sym_type_qualifier] = STATE(2222),
    [sym_alignas_qualifier] = STATE(2368),
    [aux_sym__type_definition_type_repeat1] = STATE(2222),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2338),
    [sym_identifier] = ACTIONS(6090),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5158),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5158),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5158),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5158),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5160),
    [anon_sym___extension__] = ACTIONS(6064),
    [anon_sym___global__] = ACTIONS(6064),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(6092),
    [anon_sym_unsigned] = ACTIONS(6092),
    [anon_sym_long] = ACTIONS(6092),
    [anon_sym_short] = ACTIONS(6092),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_const] = ACTIONS(6064),
    [anon_sym_constexpr] = ACTIONS(6064),
    [anon_sym_volatile] = ACTIONS(6064),
    [anon_sym_restrict] = ACTIONS(6064),
    [anon_sym___restrict__] = ACTIONS(6064),
    [anon_sym__Atomic] = ACTIONS(6064),
    [anon_sym__Noreturn] = ACTIONS(6064),
    [anon_sym_noreturn] = ACTIONS(6064),
    [anon_sym__Nonnull] = ACTIONS(6064),
    [anon_sym_mutable] = ACTIONS(6064),
    [anon_sym_constinit] = ACTIONS(6064),
    [anon_sym_consteval] = ACTIONS(6064),
    [anon_sym___shared__] = ACTIONS(6064),
    [anon_sym___local__] = ACTIONS(6064),
    [anon_sym___constant__] = ACTIONS(6064),
    [anon_sym___managed__] = ACTIONS(6064),
    [anon_sym___grid_constant__] = ACTIONS(6064),
    [anon_sym_alignas] = ACTIONS(6068),
    [anon_sym__Alignas] = ACTIONS(6068),
    [sym_primitive_type] = ACTIONS(6094),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5158),
  },
  [STATE(2237)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5135),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5135),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5135),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5133),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(6096),
    [anon_sym_unsigned] = ACTIONS(6096),
    [anon_sym_long] = ACTIONS(6096),
    [anon_sym_short] = ACTIONS(6096),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_final] = ACTIONS(5133),
    [anon_sym_override] = ACTIONS(5133),
    [anon_sym_GT2] = ACTIONS(5135),
    [anon_sym_requires] = ACTIONS(5133),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
  },
  [STATE(2238)] = {
    [sym__declaration_modifiers] = STATE(2261),
    [sym_attribute_specifier] = STATE(2261),
    [sym_attribute_declaration] = STATE(2261),
    [sym_ms_declspec_modifier] = STATE(2261),
    [sym_storage_class_specifier] = STATE(2261),
    [sym_type_qualifier] = STATE(2261),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_launch_bounds] = STATE(2261),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2261),
    [sym_identifier] = ACTIONS(6099),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6101),
    [anon_sym_COMMA] = ACTIONS(6101),
    [anon_sym_RPAREN] = ACTIONS(6101),
    [anon_sym_LPAREN2] = ACTIONS(6101),
    [anon_sym_TILDE] = ACTIONS(6101),
    [anon_sym_STAR] = ACTIONS(6101),
    [anon_sym_AMP_AMP] = ACTIONS(6101),
    [anon_sym_AMP] = ACTIONS(6099),
    [anon_sym_SEMI] = ACTIONS(6101),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(6103),
    [anon_sym___host__] = ACTIONS(6103),
    [anon_sym___global__] = ACTIONS(6103),
    [anon_sym___forceinline__] = ACTIONS(6103),
    [anon_sym___noinline__] = ACTIONS(6103),
    [anon_sym_virtual] = ACTIONS(6103),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6101),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(6099),
    [anon_sym___cdecl] = ACTIONS(6099),
    [anon_sym___clrcall] = ACTIONS(6099),
    [anon_sym___stdcall] = ACTIONS(6099),
    [anon_sym___fastcall] = ACTIONS(6099),
    [anon_sym___thiscall] = ACTIONS(6099),
    [anon_sym___vectorcall] = ACTIONS(6099),
    [anon_sym_LBRACK] = ACTIONS(6099),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_EQ] = ACTIONS(6101),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6099),
    [anon_sym_template] = ACTIONS(6099),
    [anon_sym_GT2] = ACTIONS(6101),
    [anon_sym_operator] = ACTIONS(6099),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2239)] = {
    [sym_identifier] = ACTIONS(5782),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5784),
    [anon_sym_COMMA] = ACTIONS(5784),
    [anon_sym_RPAREN] = ACTIONS(5784),
    [anon_sym_LPAREN2] = ACTIONS(5784),
    [anon_sym_TILDE] = ACTIONS(5784),
    [anon_sym_STAR] = ACTIONS(5784),
    [anon_sym_AMP_AMP] = ACTIONS(5784),
    [anon_sym_AMP] = ACTIONS(5782),
    [anon_sym_SEMI] = ACTIONS(5784),
    [anon_sym___extension__] = ACTIONS(5782),
    [anon_sym___device__] = ACTIONS(5782),
    [anon_sym___host__] = ACTIONS(5782),
    [anon_sym___global__] = ACTIONS(5782),
    [anon_sym___forceinline__] = ACTIONS(5782),
    [anon_sym___noinline__] = ACTIONS(5782),
    [anon_sym_virtual] = ACTIONS(5782),
    [anon_sym_extern] = ACTIONS(5782),
    [anon_sym___attribute__] = ACTIONS(5782),
    [anon_sym___attribute] = ACTIONS(5782),
    [anon_sym_COLON_COLON] = ACTIONS(5784),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5784),
    [anon_sym___declspec] = ACTIONS(5782),
    [anon_sym___based] = ACTIONS(5782),
    [anon_sym___cdecl] = ACTIONS(5782),
    [anon_sym___clrcall] = ACTIONS(5782),
    [anon_sym___stdcall] = ACTIONS(5782),
    [anon_sym___fastcall] = ACTIONS(5782),
    [anon_sym___thiscall] = ACTIONS(5782),
    [anon_sym___vectorcall] = ACTIONS(5782),
    [anon_sym_LBRACE] = ACTIONS(5784),
    [anon_sym_LBRACK] = ACTIONS(5782),
    [anon_sym_static] = ACTIONS(5782),
    [anon_sym_EQ] = ACTIONS(5784),
    [anon_sym_register] = ACTIONS(5782),
    [anon_sym_inline] = ACTIONS(5782),
    [anon_sym___inline] = ACTIONS(5782),
    [anon_sym___inline__] = ACTIONS(5782),
    [anon_sym___forceinline] = ACTIONS(5782),
    [anon_sym_thread_local] = ACTIONS(5782),
    [anon_sym___thread] = ACTIONS(5782),
    [anon_sym_const] = ACTIONS(5782),
    [anon_sym_constexpr] = ACTIONS(5782),
    [anon_sym_volatile] = ACTIONS(5782),
    [anon_sym_restrict] = ACTIONS(5782),
    [anon_sym___restrict__] = ACTIONS(5782),
    [anon_sym__Atomic] = ACTIONS(5782),
    [anon_sym__Noreturn] = ACTIONS(5782),
    [anon_sym_noreturn] = ACTIONS(5782),
    [anon_sym__Nonnull] = ACTIONS(5782),
    [anon_sym_mutable] = ACTIONS(5782),
    [anon_sym_constinit] = ACTIONS(5782),
    [anon_sym_consteval] = ACTIONS(5782),
    [anon_sym___shared__] = ACTIONS(5782),
    [anon_sym___local__] = ACTIONS(5782),
    [anon_sym___constant__] = ACTIONS(5782),
    [anon_sym___managed__] = ACTIONS(5782),
    [anon_sym___grid_constant__] = ACTIONS(5782),
    [anon_sym_alignas] = ACTIONS(5782),
    [anon_sym__Alignas] = ACTIONS(5782),
    [anon_sym_asm] = ACTIONS(5782),
    [anon_sym___asm__] = ACTIONS(5782),
    [anon_sym___asm] = ACTIONS(5782),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5782),
    [anon_sym_decltype] = ACTIONS(5782),
    [anon_sym_final] = ACTIONS(5782),
    [anon_sym_override] = ACTIONS(5782),
    [anon_sym_template] = ACTIONS(5782),
    [anon_sym_GT2] = ACTIONS(5784),
    [anon_sym_operator] = ACTIONS(5782),
    [anon_sym_try] = ACTIONS(5782),
    [anon_sym_requires] = ACTIONS(5782),
    [anon_sym___launch_bounds__] = ACTIONS(5782),
  },
  [STATE(2240)] = {
    [sym_identifier] = ACTIONS(5692),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5694),
    [anon_sym_COMMA] = ACTIONS(5694),
    [anon_sym_RPAREN] = ACTIONS(5694),
    [anon_sym_LPAREN2] = ACTIONS(5694),
    [anon_sym_TILDE] = ACTIONS(5694),
    [anon_sym_STAR] = ACTIONS(5694),
    [anon_sym_AMP_AMP] = ACTIONS(5694),
    [anon_sym_AMP] = ACTIONS(5692),
    [anon_sym_SEMI] = ACTIONS(5694),
    [anon_sym___extension__] = ACTIONS(5692),
    [anon_sym___device__] = ACTIONS(5692),
    [anon_sym___host__] = ACTIONS(5692),
    [anon_sym___global__] = ACTIONS(5692),
    [anon_sym___forceinline__] = ACTIONS(5692),
    [anon_sym___noinline__] = ACTIONS(5692),
    [anon_sym_virtual] = ACTIONS(5692),
    [anon_sym_extern] = ACTIONS(5692),
    [anon_sym___attribute__] = ACTIONS(5692),
    [anon_sym___attribute] = ACTIONS(5692),
    [anon_sym_COLON_COLON] = ACTIONS(5694),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5694),
    [anon_sym___declspec] = ACTIONS(5692),
    [anon_sym___based] = ACTIONS(5692),
    [anon_sym___cdecl] = ACTIONS(5692),
    [anon_sym___clrcall] = ACTIONS(5692),
    [anon_sym___stdcall] = ACTIONS(5692),
    [anon_sym___fastcall] = ACTIONS(5692),
    [anon_sym___thiscall] = ACTIONS(5692),
    [anon_sym___vectorcall] = ACTIONS(5692),
    [anon_sym_LBRACE] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5692),
    [anon_sym_static] = ACTIONS(5692),
    [anon_sym_EQ] = ACTIONS(5694),
    [anon_sym_register] = ACTIONS(5692),
    [anon_sym_inline] = ACTIONS(5692),
    [anon_sym___inline] = ACTIONS(5692),
    [anon_sym___inline__] = ACTIONS(5692),
    [anon_sym___forceinline] = ACTIONS(5692),
    [anon_sym_thread_local] = ACTIONS(5692),
    [anon_sym___thread] = ACTIONS(5692),
    [anon_sym_const] = ACTIONS(5692),
    [anon_sym_constexpr] = ACTIONS(5692),
    [anon_sym_volatile] = ACTIONS(5692),
    [anon_sym_restrict] = ACTIONS(5692),
    [anon_sym___restrict__] = ACTIONS(5692),
    [anon_sym__Atomic] = ACTIONS(5692),
    [anon_sym__Noreturn] = ACTIONS(5692),
    [anon_sym_noreturn] = ACTIONS(5692),
    [anon_sym__Nonnull] = ACTIONS(5692),
    [anon_sym_mutable] = ACTIONS(5692),
    [anon_sym_constinit] = ACTIONS(5692),
    [anon_sym_consteval] = ACTIONS(5692),
    [anon_sym___shared__] = ACTIONS(5692),
    [anon_sym___local__] = ACTIONS(5692),
    [anon_sym___constant__] = ACTIONS(5692),
    [anon_sym___managed__] = ACTIONS(5692),
    [anon_sym___grid_constant__] = ACTIONS(5692),
    [anon_sym_alignas] = ACTIONS(5692),
    [anon_sym__Alignas] = ACTIONS(5692),
    [anon_sym_asm] = ACTIONS(5692),
    [anon_sym___asm__] = ACTIONS(5692),
    [anon_sym___asm] = ACTIONS(5692),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5692),
    [anon_sym_decltype] = ACTIONS(5692),
    [anon_sym_final] = ACTIONS(5692),
    [anon_sym_override] = ACTIONS(5692),
    [anon_sym_template] = ACTIONS(5692),
    [anon_sym_GT2] = ACTIONS(5694),
    [anon_sym_operator] = ACTIONS(5692),
    [anon_sym_try] = ACTIONS(5692),
    [anon_sym_requires] = ACTIONS(5692),
    [anon_sym___launch_bounds__] = ACTIONS(5692),
  },
  [STATE(2241)] = {
    [sym_identifier] = ACTIONS(5738),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5740),
    [anon_sym_COMMA] = ACTIONS(5740),
    [anon_sym_RPAREN] = ACTIONS(5740),
    [anon_sym_LPAREN2] = ACTIONS(5740),
    [anon_sym_TILDE] = ACTIONS(5740),
    [anon_sym_STAR] = ACTIONS(5740),
    [anon_sym_AMP_AMP] = ACTIONS(5740),
    [anon_sym_AMP] = ACTIONS(5738),
    [anon_sym_SEMI] = ACTIONS(5740),
    [anon_sym___extension__] = ACTIONS(5738),
    [anon_sym___device__] = ACTIONS(5738),
    [anon_sym___host__] = ACTIONS(5738),
    [anon_sym___global__] = ACTIONS(5738),
    [anon_sym___forceinline__] = ACTIONS(5738),
    [anon_sym___noinline__] = ACTIONS(5738),
    [anon_sym_virtual] = ACTIONS(5738),
    [anon_sym_extern] = ACTIONS(5738),
    [anon_sym___attribute__] = ACTIONS(5738),
    [anon_sym___attribute] = ACTIONS(5738),
    [anon_sym_COLON_COLON] = ACTIONS(5740),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5740),
    [anon_sym___declspec] = ACTIONS(5738),
    [anon_sym___based] = ACTIONS(5738),
    [anon_sym___cdecl] = ACTIONS(5738),
    [anon_sym___clrcall] = ACTIONS(5738),
    [anon_sym___stdcall] = ACTIONS(5738),
    [anon_sym___fastcall] = ACTIONS(5738),
    [anon_sym___thiscall] = ACTIONS(5738),
    [anon_sym___vectorcall] = ACTIONS(5738),
    [anon_sym_LBRACE] = ACTIONS(5740),
    [anon_sym_LBRACK] = ACTIONS(5738),
    [anon_sym_static] = ACTIONS(5738),
    [anon_sym_EQ] = ACTIONS(5740),
    [anon_sym_register] = ACTIONS(5738),
    [anon_sym_inline] = ACTIONS(5738),
    [anon_sym___inline] = ACTIONS(5738),
    [anon_sym___inline__] = ACTIONS(5738),
    [anon_sym___forceinline] = ACTIONS(5738),
    [anon_sym_thread_local] = ACTIONS(5738),
    [anon_sym___thread] = ACTIONS(5738),
    [anon_sym_const] = ACTIONS(5738),
    [anon_sym_constexpr] = ACTIONS(5738),
    [anon_sym_volatile] = ACTIONS(5738),
    [anon_sym_restrict] = ACTIONS(5738),
    [anon_sym___restrict__] = ACTIONS(5738),
    [anon_sym__Atomic] = ACTIONS(5738),
    [anon_sym__Noreturn] = ACTIONS(5738),
    [anon_sym_noreturn] = ACTIONS(5738),
    [anon_sym__Nonnull] = ACTIONS(5738),
    [anon_sym_mutable] = ACTIONS(5738),
    [anon_sym_constinit] = ACTIONS(5738),
    [anon_sym_consteval] = ACTIONS(5738),
    [anon_sym___shared__] = ACTIONS(5738),
    [anon_sym___local__] = ACTIONS(5738),
    [anon_sym___constant__] = ACTIONS(5738),
    [anon_sym___managed__] = ACTIONS(5738),
    [anon_sym___grid_constant__] = ACTIONS(5738),
    [anon_sym_alignas] = ACTIONS(5738),
    [anon_sym__Alignas] = ACTIONS(5738),
    [anon_sym_asm] = ACTIONS(5738),
    [anon_sym___asm__] = ACTIONS(5738),
    [anon_sym___asm] = ACTIONS(5738),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5738),
    [anon_sym_decltype] = ACTIONS(5738),
    [anon_sym_final] = ACTIONS(5738),
    [anon_sym_override] = ACTIONS(5738),
    [anon_sym_template] = ACTIONS(5738),
    [anon_sym_GT2] = ACTIONS(5740),
    [anon_sym_operator] = ACTIONS(5738),
    [anon_sym_try] = ACTIONS(5738),
    [anon_sym_requires] = ACTIONS(5738),
    [anon_sym___launch_bounds__] = ACTIONS(5738),
  },
  [STATE(2242)] = {
    [sym_identifier] = ACTIONS(5746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5748),
    [anon_sym_COMMA] = ACTIONS(5748),
    [anon_sym_RPAREN] = ACTIONS(5748),
    [anon_sym_LPAREN2] = ACTIONS(5748),
    [anon_sym_TILDE] = ACTIONS(5748),
    [anon_sym_STAR] = ACTIONS(5748),
    [anon_sym_AMP_AMP] = ACTIONS(5748),
    [anon_sym_AMP] = ACTIONS(5746),
    [anon_sym_SEMI] = ACTIONS(5748),
    [anon_sym___extension__] = ACTIONS(5746),
    [anon_sym___device__] = ACTIONS(5746),
    [anon_sym___host__] = ACTIONS(5746),
    [anon_sym___global__] = ACTIONS(5746),
    [anon_sym___forceinline__] = ACTIONS(5746),
    [anon_sym___noinline__] = ACTIONS(5746),
    [anon_sym_virtual] = ACTIONS(5746),
    [anon_sym_extern] = ACTIONS(5746),
    [anon_sym___attribute__] = ACTIONS(5746),
    [anon_sym___attribute] = ACTIONS(5746),
    [anon_sym_COLON_COLON] = ACTIONS(5748),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5748),
    [anon_sym___declspec] = ACTIONS(5746),
    [anon_sym___based] = ACTIONS(5746),
    [anon_sym___cdecl] = ACTIONS(5746),
    [anon_sym___clrcall] = ACTIONS(5746),
    [anon_sym___stdcall] = ACTIONS(5746),
    [anon_sym___fastcall] = ACTIONS(5746),
    [anon_sym___thiscall] = ACTIONS(5746),
    [anon_sym___vectorcall] = ACTIONS(5746),
    [anon_sym_LBRACE] = ACTIONS(5748),
    [anon_sym_LBRACK] = ACTIONS(5746),
    [anon_sym_static] = ACTIONS(5746),
    [anon_sym_EQ] = ACTIONS(5748),
    [anon_sym_register] = ACTIONS(5746),
    [anon_sym_inline] = ACTIONS(5746),
    [anon_sym___inline] = ACTIONS(5746),
    [anon_sym___inline__] = ACTIONS(5746),
    [anon_sym___forceinline] = ACTIONS(5746),
    [anon_sym_thread_local] = ACTIONS(5746),
    [anon_sym___thread] = ACTIONS(5746),
    [anon_sym_const] = ACTIONS(5746),
    [anon_sym_constexpr] = ACTIONS(5746),
    [anon_sym_volatile] = ACTIONS(5746),
    [anon_sym_restrict] = ACTIONS(5746),
    [anon_sym___restrict__] = ACTIONS(5746),
    [anon_sym__Atomic] = ACTIONS(5746),
    [anon_sym__Noreturn] = ACTIONS(5746),
    [anon_sym_noreturn] = ACTIONS(5746),
    [anon_sym__Nonnull] = ACTIONS(5746),
    [anon_sym_mutable] = ACTIONS(5746),
    [anon_sym_constinit] = ACTIONS(5746),
    [anon_sym_consteval] = ACTIONS(5746),
    [anon_sym___shared__] = ACTIONS(5746),
    [anon_sym___local__] = ACTIONS(5746),
    [anon_sym___constant__] = ACTIONS(5746),
    [anon_sym___managed__] = ACTIONS(5746),
    [anon_sym___grid_constant__] = ACTIONS(5746),
    [anon_sym_alignas] = ACTIONS(5746),
    [anon_sym__Alignas] = ACTIONS(5746),
    [anon_sym_asm] = ACTIONS(5746),
    [anon_sym___asm__] = ACTIONS(5746),
    [anon_sym___asm] = ACTIONS(5746),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5746),
    [anon_sym_decltype] = ACTIONS(5746),
    [anon_sym_final] = ACTIONS(5746),
    [anon_sym_override] = ACTIONS(5746),
    [anon_sym_template] = ACTIONS(5746),
    [anon_sym_GT2] = ACTIONS(5748),
    [anon_sym_operator] = ACTIONS(5746),
    [anon_sym_try] = ACTIONS(5746),
    [anon_sym_requires] = ACTIONS(5746),
    [anon_sym___launch_bounds__] = ACTIONS(5746),
  },
  [STATE(2243)] = {
    [sym_identifier] = ACTIONS(5730),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5732),
    [anon_sym_COMMA] = ACTIONS(5732),
    [anon_sym_RPAREN] = ACTIONS(5732),
    [anon_sym_LPAREN2] = ACTIONS(5732),
    [anon_sym_TILDE] = ACTIONS(5732),
    [anon_sym_STAR] = ACTIONS(5732),
    [anon_sym_AMP_AMP] = ACTIONS(5732),
    [anon_sym_AMP] = ACTIONS(5730),
    [anon_sym_SEMI] = ACTIONS(5732),
    [anon_sym___extension__] = ACTIONS(5730),
    [anon_sym___device__] = ACTIONS(5730),
    [anon_sym___host__] = ACTIONS(5730),
    [anon_sym___global__] = ACTIONS(5730),
    [anon_sym___forceinline__] = ACTIONS(5730),
    [anon_sym___noinline__] = ACTIONS(5730),
    [anon_sym_virtual] = ACTIONS(5730),
    [anon_sym_extern] = ACTIONS(5730),
    [anon_sym___attribute__] = ACTIONS(5730),
    [anon_sym___attribute] = ACTIONS(5730),
    [anon_sym_COLON_COLON] = ACTIONS(5732),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5732),
    [anon_sym___declspec] = ACTIONS(5730),
    [anon_sym___based] = ACTIONS(5730),
    [anon_sym___cdecl] = ACTIONS(5730),
    [anon_sym___clrcall] = ACTIONS(5730),
    [anon_sym___stdcall] = ACTIONS(5730),
    [anon_sym___fastcall] = ACTIONS(5730),
    [anon_sym___thiscall] = ACTIONS(5730),
    [anon_sym___vectorcall] = ACTIONS(5730),
    [anon_sym_LBRACE] = ACTIONS(5732),
    [anon_sym_LBRACK] = ACTIONS(5730),
    [anon_sym_static] = ACTIONS(5730),
    [anon_sym_EQ] = ACTIONS(5732),
    [anon_sym_register] = ACTIONS(5730),
    [anon_sym_inline] = ACTIONS(5730),
    [anon_sym___inline] = ACTIONS(5730),
    [anon_sym___inline__] = ACTIONS(5730),
    [anon_sym___forceinline] = ACTIONS(5730),
    [anon_sym_thread_local] = ACTIONS(5730),
    [anon_sym___thread] = ACTIONS(5730),
    [anon_sym_const] = ACTIONS(5730),
    [anon_sym_constexpr] = ACTIONS(5730),
    [anon_sym_volatile] = ACTIONS(5730),
    [anon_sym_restrict] = ACTIONS(5730),
    [anon_sym___restrict__] = ACTIONS(5730),
    [anon_sym__Atomic] = ACTIONS(5730),
    [anon_sym__Noreturn] = ACTIONS(5730),
    [anon_sym_noreturn] = ACTIONS(5730),
    [anon_sym__Nonnull] = ACTIONS(5730),
    [anon_sym_mutable] = ACTIONS(5730),
    [anon_sym_constinit] = ACTIONS(5730),
    [anon_sym_consteval] = ACTIONS(5730),
    [anon_sym___shared__] = ACTIONS(5730),
    [anon_sym___local__] = ACTIONS(5730),
    [anon_sym___constant__] = ACTIONS(5730),
    [anon_sym___managed__] = ACTIONS(5730),
    [anon_sym___grid_constant__] = ACTIONS(5730),
    [anon_sym_alignas] = ACTIONS(5730),
    [anon_sym__Alignas] = ACTIONS(5730),
    [anon_sym_asm] = ACTIONS(5730),
    [anon_sym___asm__] = ACTIONS(5730),
    [anon_sym___asm] = ACTIONS(5730),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5730),
    [anon_sym_decltype] = ACTIONS(5730),
    [anon_sym_final] = ACTIONS(5730),
    [anon_sym_override] = ACTIONS(5730),
    [anon_sym_template] = ACTIONS(5730),
    [anon_sym_GT2] = ACTIONS(5732),
    [anon_sym_operator] = ACTIONS(5730),
    [anon_sym_try] = ACTIONS(5730),
    [anon_sym_requires] = ACTIONS(5730),
    [anon_sym___launch_bounds__] = ACTIONS(5730),
  },
  [STATE(2244)] = {
    [sym_type_qualifier] = STATE(2188),
    [sym_alignas_qualifier] = STATE(2279),
    [aux_sym__type_definition_type_repeat1] = STATE(2188),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2285),
    [sym_identifier] = ACTIONS(6105),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5173),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_DASH] = ACTIONS(5175),
    [anon_sym_PLUS] = ACTIONS(5175),
    [anon_sym_STAR] = ACTIONS(5173),
    [anon_sym_SLASH] = ACTIONS(5175),
    [anon_sym_PERCENT] = ACTIONS(5173),
    [anon_sym_PIPE_PIPE] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_PIPE] = ACTIONS(5175),
    [anon_sym_CARET] = ACTIONS(5173),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_EQ_EQ] = ACTIONS(5173),
    [anon_sym_BANG_EQ] = ACTIONS(5173),
    [anon_sym_GT] = ACTIONS(5175),
    [anon_sym_GT_EQ] = ACTIONS(5175),
    [anon_sym_LT_EQ] = ACTIONS(5175),
    [anon_sym_LT] = ACTIONS(5175),
    [anon_sym_LT_LT] = ACTIONS(5175),
    [anon_sym_GT_GT] = ACTIONS(5175),
    [anon_sym___extension__] = ACTIONS(6107),
    [anon_sym___global__] = ACTIONS(6107),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(6109),
    [anon_sym_unsigned] = ACTIONS(6109),
    [anon_sym_long] = ACTIONS(6109),
    [anon_sym_short] = ACTIONS(6109),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_const] = ACTIONS(6107),
    [anon_sym_constexpr] = ACTIONS(6107),
    [anon_sym_volatile] = ACTIONS(6107),
    [anon_sym_restrict] = ACTIONS(6107),
    [anon_sym___restrict__] = ACTIONS(6107),
    [anon_sym__Atomic] = ACTIONS(6107),
    [anon_sym__Noreturn] = ACTIONS(6107),
    [anon_sym_noreturn] = ACTIONS(6107),
    [anon_sym__Nonnull] = ACTIONS(6107),
    [anon_sym_mutable] = ACTIONS(6107),
    [anon_sym_constinit] = ACTIONS(6107),
    [anon_sym_consteval] = ACTIONS(6107),
    [anon_sym___shared__] = ACTIONS(6107),
    [anon_sym___local__] = ACTIONS(6107),
    [anon_sym___constant__] = ACTIONS(6107),
    [anon_sym___managed__] = ACTIONS(6107),
    [anon_sym___grid_constant__] = ACTIONS(6107),
    [anon_sym_alignas] = ACTIONS(6111),
    [anon_sym__Alignas] = ACTIONS(6111),
    [sym_primitive_type] = ACTIONS(6113),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_LT_EQ_GT] = ACTIONS(5173),
    [anon_sym_or] = ACTIONS(5175),
    [anon_sym_and] = ACTIONS(5175),
    [anon_sym_bitor] = ACTIONS(5175),
    [anon_sym_xor] = ACTIONS(5175),
    [anon_sym_bitand] = ACTIONS(5175),
    [anon_sym_not_eq] = ACTIONS(5175),
    [anon_sym_DASH_DASH] = ACTIONS(5173),
    [anon_sym_PLUS_PLUS] = ACTIONS(5173),
    [anon_sym_DOT] = ACTIONS(5175),
    [anon_sym_DOT_STAR] = ACTIONS(5173),
    [anon_sym_DASH_GT] = ACTIONS(5173),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [anon_sym_GT2] = ACTIONS(5173),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5173),
  },
  [STATE(2245)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_TILDE] = ACTIONS(5752),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___extension__] = ACTIONS(5750),
    [anon_sym___device__] = ACTIONS(5750),
    [anon_sym___host__] = ACTIONS(5750),
    [anon_sym___global__] = ACTIONS(5750),
    [anon_sym___forceinline__] = ACTIONS(5750),
    [anon_sym___noinline__] = ACTIONS(5750),
    [anon_sym_virtual] = ACTIONS(5750),
    [anon_sym_extern] = ACTIONS(5750),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_COLON_COLON] = ACTIONS(5752),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5752),
    [anon_sym___declspec] = ACTIONS(5750),
    [anon_sym___based] = ACTIONS(5750),
    [anon_sym___cdecl] = ACTIONS(5750),
    [anon_sym___clrcall] = ACTIONS(5750),
    [anon_sym___stdcall] = ACTIONS(5750),
    [anon_sym___fastcall] = ACTIONS(5750),
    [anon_sym___thiscall] = ACTIONS(5750),
    [anon_sym___vectorcall] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5750),
    [anon_sym_static] = ACTIONS(5750),
    [anon_sym_EQ] = ACTIONS(5752),
    [anon_sym_register] = ACTIONS(5750),
    [anon_sym_inline] = ACTIONS(5750),
    [anon_sym___inline] = ACTIONS(5750),
    [anon_sym___inline__] = ACTIONS(5750),
    [anon_sym___forceinline] = ACTIONS(5750),
    [anon_sym_thread_local] = ACTIONS(5750),
    [anon_sym___thread] = ACTIONS(5750),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5750),
    [anon_sym_volatile] = ACTIONS(5750),
    [anon_sym_restrict] = ACTIONS(5750),
    [anon_sym___restrict__] = ACTIONS(5750),
    [anon_sym__Atomic] = ACTIONS(5750),
    [anon_sym__Noreturn] = ACTIONS(5750),
    [anon_sym_noreturn] = ACTIONS(5750),
    [anon_sym__Nonnull] = ACTIONS(5750),
    [anon_sym_mutable] = ACTIONS(5750),
    [anon_sym_constinit] = ACTIONS(5750),
    [anon_sym_consteval] = ACTIONS(5750),
    [anon_sym___shared__] = ACTIONS(5750),
    [anon_sym___local__] = ACTIONS(5750),
    [anon_sym___constant__] = ACTIONS(5750),
    [anon_sym___managed__] = ACTIONS(5750),
    [anon_sym___grid_constant__] = ACTIONS(5750),
    [anon_sym_alignas] = ACTIONS(5750),
    [anon_sym__Alignas] = ACTIONS(5750),
    [anon_sym_asm] = ACTIONS(5750),
    [anon_sym___asm__] = ACTIONS(5750),
    [anon_sym___asm] = ACTIONS(5750),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [anon_sym_final] = ACTIONS(5750),
    [anon_sym_override] = ACTIONS(5750),
    [anon_sym_template] = ACTIONS(5750),
    [anon_sym_GT2] = ACTIONS(5752),
    [anon_sym_operator] = ACTIONS(5750),
    [anon_sym_try] = ACTIONS(5750),
    [anon_sym_requires] = ACTIONS(5750),
    [anon_sym___launch_bounds__] = ACTIONS(5750),
  },
  [STATE(2246)] = {
    [sym_identifier] = ACTIONS(5809),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5811),
    [anon_sym_COMMA] = ACTIONS(5811),
    [anon_sym_RPAREN] = ACTIONS(5811),
    [anon_sym_LPAREN2] = ACTIONS(5811),
    [anon_sym_TILDE] = ACTIONS(5811),
    [anon_sym_STAR] = ACTIONS(5811),
    [anon_sym_AMP_AMP] = ACTIONS(5811),
    [anon_sym_AMP] = ACTIONS(5809),
    [anon_sym_SEMI] = ACTIONS(5811),
    [anon_sym___extension__] = ACTIONS(5809),
    [anon_sym___device__] = ACTIONS(5809),
    [anon_sym___host__] = ACTIONS(5809),
    [anon_sym___global__] = ACTIONS(5809),
    [anon_sym___forceinline__] = ACTIONS(5809),
    [anon_sym___noinline__] = ACTIONS(5809),
    [anon_sym_virtual] = ACTIONS(5809),
    [anon_sym_extern] = ACTIONS(5809),
    [anon_sym___attribute__] = ACTIONS(5809),
    [anon_sym___attribute] = ACTIONS(5809),
    [anon_sym_COLON_COLON] = ACTIONS(5811),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5811),
    [anon_sym___declspec] = ACTIONS(5809),
    [anon_sym___based] = ACTIONS(5809),
    [anon_sym___cdecl] = ACTIONS(5809),
    [anon_sym___clrcall] = ACTIONS(5809),
    [anon_sym___stdcall] = ACTIONS(5809),
    [anon_sym___fastcall] = ACTIONS(5809),
    [anon_sym___thiscall] = ACTIONS(5809),
    [anon_sym___vectorcall] = ACTIONS(5809),
    [anon_sym_LBRACE] = ACTIONS(5811),
    [anon_sym_LBRACK] = ACTIONS(5809),
    [anon_sym_static] = ACTIONS(5809),
    [anon_sym_EQ] = ACTIONS(5811),
    [anon_sym_register] = ACTIONS(5809),
    [anon_sym_inline] = ACTIONS(5809),
    [anon_sym___inline] = ACTIONS(5809),
    [anon_sym___inline__] = ACTIONS(5809),
    [anon_sym___forceinline] = ACTIONS(5809),
    [anon_sym_thread_local] = ACTIONS(5809),
    [anon_sym___thread] = ACTIONS(5809),
    [anon_sym_const] = ACTIONS(5809),
    [anon_sym_constexpr] = ACTIONS(5809),
    [anon_sym_volatile] = ACTIONS(5809),
    [anon_sym_restrict] = ACTIONS(5809),
    [anon_sym___restrict__] = ACTIONS(5809),
    [anon_sym__Atomic] = ACTIONS(5809),
    [anon_sym__Noreturn] = ACTIONS(5809),
    [anon_sym_noreturn] = ACTIONS(5809),
    [anon_sym__Nonnull] = ACTIONS(5809),
    [anon_sym_mutable] = ACTIONS(5809),
    [anon_sym_constinit] = ACTIONS(5809),
    [anon_sym_consteval] = ACTIONS(5809),
    [anon_sym___shared__] = ACTIONS(5809),
    [anon_sym___local__] = ACTIONS(5809),
    [anon_sym___constant__] = ACTIONS(5809),
    [anon_sym___managed__] = ACTIONS(5809),
    [anon_sym___grid_constant__] = ACTIONS(5809),
    [anon_sym_alignas] = ACTIONS(5809),
    [anon_sym__Alignas] = ACTIONS(5809),
    [anon_sym_asm] = ACTIONS(5809),
    [anon_sym___asm__] = ACTIONS(5809),
    [anon_sym___asm] = ACTIONS(5809),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5809),
    [anon_sym_decltype] = ACTIONS(5809),
    [anon_sym_final] = ACTIONS(5809),
    [anon_sym_override] = ACTIONS(5809),
    [anon_sym_template] = ACTIONS(5809),
    [anon_sym_GT2] = ACTIONS(5811),
    [anon_sym_operator] = ACTIONS(5809),
    [anon_sym_try] = ACTIONS(5809),
    [anon_sym_requires] = ACTIONS(5809),
    [anon_sym___launch_bounds__] = ACTIONS(5809),
  },
  [STATE(2247)] = {
    [sym_identifier] = ACTIONS(5805),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5807),
    [anon_sym_COMMA] = ACTIONS(5807),
    [anon_sym_RPAREN] = ACTIONS(5807),
    [anon_sym_LPAREN2] = ACTIONS(5807),
    [anon_sym_TILDE] = ACTIONS(5807),
    [anon_sym_STAR] = ACTIONS(5807),
    [anon_sym_AMP_AMP] = ACTIONS(5807),
    [anon_sym_AMP] = ACTIONS(5805),
    [anon_sym_SEMI] = ACTIONS(5807),
    [anon_sym___extension__] = ACTIONS(5805),
    [anon_sym___device__] = ACTIONS(5805),
    [anon_sym___host__] = ACTIONS(5805),
    [anon_sym___global__] = ACTIONS(5805),
    [anon_sym___forceinline__] = ACTIONS(5805),
    [anon_sym___noinline__] = ACTIONS(5805),
    [anon_sym_virtual] = ACTIONS(5805),
    [anon_sym_extern] = ACTIONS(5805),
    [anon_sym___attribute__] = ACTIONS(5805),
    [anon_sym___attribute] = ACTIONS(5805),
    [anon_sym_COLON_COLON] = ACTIONS(5807),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5807),
    [anon_sym___declspec] = ACTIONS(5805),
    [anon_sym___based] = ACTIONS(5805),
    [anon_sym___cdecl] = ACTIONS(5805),
    [anon_sym___clrcall] = ACTIONS(5805),
    [anon_sym___stdcall] = ACTIONS(5805),
    [anon_sym___fastcall] = ACTIONS(5805),
    [anon_sym___thiscall] = ACTIONS(5805),
    [anon_sym___vectorcall] = ACTIONS(5805),
    [anon_sym_LBRACE] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5805),
    [anon_sym_static] = ACTIONS(5805),
    [anon_sym_EQ] = ACTIONS(5807),
    [anon_sym_register] = ACTIONS(5805),
    [anon_sym_inline] = ACTIONS(5805),
    [anon_sym___inline] = ACTIONS(5805),
    [anon_sym___inline__] = ACTIONS(5805),
    [anon_sym___forceinline] = ACTIONS(5805),
    [anon_sym_thread_local] = ACTIONS(5805),
    [anon_sym___thread] = ACTIONS(5805),
    [anon_sym_const] = ACTIONS(5805),
    [anon_sym_constexpr] = ACTIONS(5805),
    [anon_sym_volatile] = ACTIONS(5805),
    [anon_sym_restrict] = ACTIONS(5805),
    [anon_sym___restrict__] = ACTIONS(5805),
    [anon_sym__Atomic] = ACTIONS(5805),
    [anon_sym__Noreturn] = ACTIONS(5805),
    [anon_sym_noreturn] = ACTIONS(5805),
    [anon_sym__Nonnull] = ACTIONS(5805),
    [anon_sym_mutable] = ACTIONS(5805),
    [anon_sym_constinit] = ACTIONS(5805),
    [anon_sym_consteval] = ACTIONS(5805),
    [anon_sym___shared__] = ACTIONS(5805),
    [anon_sym___local__] = ACTIONS(5805),
    [anon_sym___constant__] = ACTIONS(5805),
    [anon_sym___managed__] = ACTIONS(5805),
    [anon_sym___grid_constant__] = ACTIONS(5805),
    [anon_sym_alignas] = ACTIONS(5805),
    [anon_sym__Alignas] = ACTIONS(5805),
    [anon_sym_asm] = ACTIONS(5805),
    [anon_sym___asm__] = ACTIONS(5805),
    [anon_sym___asm] = ACTIONS(5805),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5805),
    [anon_sym_decltype] = ACTIONS(5805),
    [anon_sym_final] = ACTIONS(5805),
    [anon_sym_override] = ACTIONS(5805),
    [anon_sym_template] = ACTIONS(5805),
    [anon_sym_GT2] = ACTIONS(5807),
    [anon_sym_operator] = ACTIONS(5805),
    [anon_sym_try] = ACTIONS(5805),
    [anon_sym_requires] = ACTIONS(5805),
    [anon_sym___launch_bounds__] = ACTIONS(5805),
  },
  [STATE(2248)] = {
    [sym_identifier] = ACTIONS(5718),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5720),
    [anon_sym_COMMA] = ACTIONS(5720),
    [anon_sym_RPAREN] = ACTIONS(5720),
    [anon_sym_LPAREN2] = ACTIONS(5720),
    [anon_sym_TILDE] = ACTIONS(5720),
    [anon_sym_STAR] = ACTIONS(5720),
    [anon_sym_AMP_AMP] = ACTIONS(5720),
    [anon_sym_AMP] = ACTIONS(5718),
    [anon_sym_SEMI] = ACTIONS(5720),
    [anon_sym___extension__] = ACTIONS(5718),
    [anon_sym___device__] = ACTIONS(5718),
    [anon_sym___host__] = ACTIONS(5718),
    [anon_sym___global__] = ACTIONS(5718),
    [anon_sym___forceinline__] = ACTIONS(5718),
    [anon_sym___noinline__] = ACTIONS(5718),
    [anon_sym_virtual] = ACTIONS(5718),
    [anon_sym_extern] = ACTIONS(5718),
    [anon_sym___attribute__] = ACTIONS(5718),
    [anon_sym___attribute] = ACTIONS(5718),
    [anon_sym_COLON_COLON] = ACTIONS(5720),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5720),
    [anon_sym___declspec] = ACTIONS(5718),
    [anon_sym___based] = ACTIONS(5718),
    [anon_sym___cdecl] = ACTIONS(5718),
    [anon_sym___clrcall] = ACTIONS(5718),
    [anon_sym___stdcall] = ACTIONS(5718),
    [anon_sym___fastcall] = ACTIONS(5718),
    [anon_sym___thiscall] = ACTIONS(5718),
    [anon_sym___vectorcall] = ACTIONS(5718),
    [anon_sym_LBRACE] = ACTIONS(5720),
    [anon_sym_LBRACK] = ACTIONS(5718),
    [anon_sym_static] = ACTIONS(5718),
    [anon_sym_EQ] = ACTIONS(5720),
    [anon_sym_register] = ACTIONS(5718),
    [anon_sym_inline] = ACTIONS(5718),
    [anon_sym___inline] = ACTIONS(5718),
    [anon_sym___inline__] = ACTIONS(5718),
    [anon_sym___forceinline] = ACTIONS(5718),
    [anon_sym_thread_local] = ACTIONS(5718),
    [anon_sym___thread] = ACTIONS(5718),
    [anon_sym_const] = ACTIONS(5718),
    [anon_sym_constexpr] = ACTIONS(5718),
    [anon_sym_volatile] = ACTIONS(5718),
    [anon_sym_restrict] = ACTIONS(5718),
    [anon_sym___restrict__] = ACTIONS(5718),
    [anon_sym__Atomic] = ACTIONS(5718),
    [anon_sym__Noreturn] = ACTIONS(5718),
    [anon_sym_noreturn] = ACTIONS(5718),
    [anon_sym__Nonnull] = ACTIONS(5718),
    [anon_sym_mutable] = ACTIONS(5718),
    [anon_sym_constinit] = ACTIONS(5718),
    [anon_sym_consteval] = ACTIONS(5718),
    [anon_sym___shared__] = ACTIONS(5718),
    [anon_sym___local__] = ACTIONS(5718),
    [anon_sym___constant__] = ACTIONS(5718),
    [anon_sym___managed__] = ACTIONS(5718),
    [anon_sym___grid_constant__] = ACTIONS(5718),
    [anon_sym_alignas] = ACTIONS(5718),
    [anon_sym__Alignas] = ACTIONS(5718),
    [anon_sym_asm] = ACTIONS(5718),
    [anon_sym___asm__] = ACTIONS(5718),
    [anon_sym___asm] = ACTIONS(5718),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5718),
    [anon_sym_decltype] = ACTIONS(5718),
    [anon_sym_final] = ACTIONS(5718),
    [anon_sym_override] = ACTIONS(5718),
    [anon_sym_template] = ACTIONS(5718),
    [anon_sym_GT2] = ACTIONS(5720),
    [anon_sym_operator] = ACTIONS(5718),
    [anon_sym_try] = ACTIONS(5718),
    [anon_sym_requires] = ACTIONS(5718),
    [anon_sym___launch_bounds__] = ACTIONS(5718),
  },
  [STATE(2249)] = {
    [sym_identifier] = ACTIONS(5710),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5712),
    [anon_sym_COMMA] = ACTIONS(5712),
    [anon_sym_RPAREN] = ACTIONS(5712),
    [anon_sym_LPAREN2] = ACTIONS(5712),
    [anon_sym_TILDE] = ACTIONS(5712),
    [anon_sym_STAR] = ACTIONS(5712),
    [anon_sym_AMP_AMP] = ACTIONS(5712),
    [anon_sym_AMP] = ACTIONS(5710),
    [anon_sym_SEMI] = ACTIONS(5712),
    [anon_sym___extension__] = ACTIONS(5710),
    [anon_sym___device__] = ACTIONS(5710),
    [anon_sym___host__] = ACTIONS(5710),
    [anon_sym___global__] = ACTIONS(5710),
    [anon_sym___forceinline__] = ACTIONS(5710),
    [anon_sym___noinline__] = ACTIONS(5710),
    [anon_sym_virtual] = ACTIONS(5710),
    [anon_sym_extern] = ACTIONS(5710),
    [anon_sym___attribute__] = ACTIONS(5710),
    [anon_sym___attribute] = ACTIONS(5710),
    [anon_sym_COLON_COLON] = ACTIONS(5712),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5712),
    [anon_sym___declspec] = ACTIONS(5710),
    [anon_sym___based] = ACTIONS(5710),
    [anon_sym___cdecl] = ACTIONS(5710),
    [anon_sym___clrcall] = ACTIONS(5710),
    [anon_sym___stdcall] = ACTIONS(5710),
    [anon_sym___fastcall] = ACTIONS(5710),
    [anon_sym___thiscall] = ACTIONS(5710),
    [anon_sym___vectorcall] = ACTIONS(5710),
    [anon_sym_LBRACE] = ACTIONS(5712),
    [anon_sym_LBRACK] = ACTIONS(5710),
    [anon_sym_static] = ACTIONS(5710),
    [anon_sym_EQ] = ACTIONS(5712),
    [anon_sym_register] = ACTIONS(5710),
    [anon_sym_inline] = ACTIONS(5710),
    [anon_sym___inline] = ACTIONS(5710),
    [anon_sym___inline__] = ACTIONS(5710),
    [anon_sym___forceinline] = ACTIONS(5710),
    [anon_sym_thread_local] = ACTIONS(5710),
    [anon_sym___thread] = ACTIONS(5710),
    [anon_sym_const] = ACTIONS(5710),
    [anon_sym_constexpr] = ACTIONS(5710),
    [anon_sym_volatile] = ACTIONS(5710),
    [anon_sym_restrict] = ACTIONS(5710),
    [anon_sym___restrict__] = ACTIONS(5710),
    [anon_sym__Atomic] = ACTIONS(5710),
    [anon_sym__Noreturn] = ACTIONS(5710),
    [anon_sym_noreturn] = ACTIONS(5710),
    [anon_sym__Nonnull] = ACTIONS(5710),
    [anon_sym_mutable] = ACTIONS(5710),
    [anon_sym_constinit] = ACTIONS(5710),
    [anon_sym_consteval] = ACTIONS(5710),
    [anon_sym___shared__] = ACTIONS(5710),
    [anon_sym___local__] = ACTIONS(5710),
    [anon_sym___constant__] = ACTIONS(5710),
    [anon_sym___managed__] = ACTIONS(5710),
    [anon_sym___grid_constant__] = ACTIONS(5710),
    [anon_sym_alignas] = ACTIONS(5710),
    [anon_sym__Alignas] = ACTIONS(5710),
    [anon_sym_asm] = ACTIONS(5710),
    [anon_sym___asm__] = ACTIONS(5710),
    [anon_sym___asm] = ACTIONS(5710),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5710),
    [anon_sym_decltype] = ACTIONS(5710),
    [anon_sym_final] = ACTIONS(5710),
    [anon_sym_override] = ACTIONS(5710),
    [anon_sym_template] = ACTIONS(5710),
    [anon_sym_GT2] = ACTIONS(5712),
    [anon_sym_operator] = ACTIONS(5710),
    [anon_sym_try] = ACTIONS(5710),
    [anon_sym_requires] = ACTIONS(5710),
    [anon_sym___launch_bounds__] = ACTIONS(5710),
  },
  [STATE(2250)] = {
    [sym_identifier] = ACTIONS(5726),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5728),
    [anon_sym_COMMA] = ACTIONS(5728),
    [anon_sym_RPAREN] = ACTIONS(5728),
    [anon_sym_LPAREN2] = ACTIONS(5728),
    [anon_sym_TILDE] = ACTIONS(5728),
    [anon_sym_STAR] = ACTIONS(5728),
    [anon_sym_AMP_AMP] = ACTIONS(5728),
    [anon_sym_AMP] = ACTIONS(5726),
    [anon_sym_SEMI] = ACTIONS(5728),
    [anon_sym___extension__] = ACTIONS(5726),
    [anon_sym___device__] = ACTIONS(5726),
    [anon_sym___host__] = ACTIONS(5726),
    [anon_sym___global__] = ACTIONS(5726),
    [anon_sym___forceinline__] = ACTIONS(5726),
    [anon_sym___noinline__] = ACTIONS(5726),
    [anon_sym_virtual] = ACTIONS(5726),
    [anon_sym_extern] = ACTIONS(5726),
    [anon_sym___attribute__] = ACTIONS(5726),
    [anon_sym___attribute] = ACTIONS(5726),
    [anon_sym_COLON_COLON] = ACTIONS(5728),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5728),
    [anon_sym___declspec] = ACTIONS(5726),
    [anon_sym___based] = ACTIONS(5726),
    [anon_sym___cdecl] = ACTIONS(5726),
    [anon_sym___clrcall] = ACTIONS(5726),
    [anon_sym___stdcall] = ACTIONS(5726),
    [anon_sym___fastcall] = ACTIONS(5726),
    [anon_sym___thiscall] = ACTIONS(5726),
    [anon_sym___vectorcall] = ACTIONS(5726),
    [anon_sym_LBRACE] = ACTIONS(5728),
    [anon_sym_LBRACK] = ACTIONS(5726),
    [anon_sym_static] = ACTIONS(5726),
    [anon_sym_EQ] = ACTIONS(5728),
    [anon_sym_register] = ACTIONS(5726),
    [anon_sym_inline] = ACTIONS(5726),
    [anon_sym___inline] = ACTIONS(5726),
    [anon_sym___inline__] = ACTIONS(5726),
    [anon_sym___forceinline] = ACTIONS(5726),
    [anon_sym_thread_local] = ACTIONS(5726),
    [anon_sym___thread] = ACTIONS(5726),
    [anon_sym_const] = ACTIONS(5726),
    [anon_sym_constexpr] = ACTIONS(5726),
    [anon_sym_volatile] = ACTIONS(5726),
    [anon_sym_restrict] = ACTIONS(5726),
    [anon_sym___restrict__] = ACTIONS(5726),
    [anon_sym__Atomic] = ACTIONS(5726),
    [anon_sym__Noreturn] = ACTIONS(5726),
    [anon_sym_noreturn] = ACTIONS(5726),
    [anon_sym__Nonnull] = ACTIONS(5726),
    [anon_sym_mutable] = ACTIONS(5726),
    [anon_sym_constinit] = ACTIONS(5726),
    [anon_sym_consteval] = ACTIONS(5726),
    [anon_sym___shared__] = ACTIONS(5726),
    [anon_sym___local__] = ACTIONS(5726),
    [anon_sym___constant__] = ACTIONS(5726),
    [anon_sym___managed__] = ACTIONS(5726),
    [anon_sym___grid_constant__] = ACTIONS(5726),
    [anon_sym_alignas] = ACTIONS(5726),
    [anon_sym__Alignas] = ACTIONS(5726),
    [anon_sym_asm] = ACTIONS(5726),
    [anon_sym___asm__] = ACTIONS(5726),
    [anon_sym___asm] = ACTIONS(5726),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5726),
    [anon_sym_decltype] = ACTIONS(5726),
    [anon_sym_final] = ACTIONS(5726),
    [anon_sym_override] = ACTIONS(5726),
    [anon_sym_template] = ACTIONS(5726),
    [anon_sym_GT2] = ACTIONS(5728),
    [anon_sym_operator] = ACTIONS(5726),
    [anon_sym_try] = ACTIONS(5726),
    [anon_sym_requires] = ACTIONS(5726),
    [anon_sym___launch_bounds__] = ACTIONS(5726),
  },
  [STATE(2251)] = {
    [sym_identifier] = ACTIONS(5734),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5736),
    [anon_sym_COMMA] = ACTIONS(5736),
    [anon_sym_RPAREN] = ACTIONS(5736),
    [anon_sym_LPAREN2] = ACTIONS(5736),
    [anon_sym_TILDE] = ACTIONS(5736),
    [anon_sym_STAR] = ACTIONS(5736),
    [anon_sym_AMP_AMP] = ACTIONS(5736),
    [anon_sym_AMP] = ACTIONS(5734),
    [anon_sym_SEMI] = ACTIONS(5736),
    [anon_sym___extension__] = ACTIONS(5734),
    [anon_sym___device__] = ACTIONS(5734),
    [anon_sym___host__] = ACTIONS(5734),
    [anon_sym___global__] = ACTIONS(5734),
    [anon_sym___forceinline__] = ACTIONS(5734),
    [anon_sym___noinline__] = ACTIONS(5734),
    [anon_sym_virtual] = ACTIONS(5734),
    [anon_sym_extern] = ACTIONS(5734),
    [anon_sym___attribute__] = ACTIONS(5734),
    [anon_sym___attribute] = ACTIONS(5734),
    [anon_sym_COLON_COLON] = ACTIONS(5736),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5736),
    [anon_sym___declspec] = ACTIONS(5734),
    [anon_sym___based] = ACTIONS(5734),
    [anon_sym___cdecl] = ACTIONS(5734),
    [anon_sym___clrcall] = ACTIONS(5734),
    [anon_sym___stdcall] = ACTIONS(5734),
    [anon_sym___fastcall] = ACTIONS(5734),
    [anon_sym___thiscall] = ACTIONS(5734),
    [anon_sym___vectorcall] = ACTIONS(5734),
    [anon_sym_LBRACE] = ACTIONS(5736),
    [anon_sym_LBRACK] = ACTIONS(5734),
    [anon_sym_static] = ACTIONS(5734),
    [anon_sym_EQ] = ACTIONS(5736),
    [anon_sym_register] = ACTIONS(5734),
    [anon_sym_inline] = ACTIONS(5734),
    [anon_sym___inline] = ACTIONS(5734),
    [anon_sym___inline__] = ACTIONS(5734),
    [anon_sym___forceinline] = ACTIONS(5734),
    [anon_sym_thread_local] = ACTIONS(5734),
    [anon_sym___thread] = ACTIONS(5734),
    [anon_sym_const] = ACTIONS(5734),
    [anon_sym_constexpr] = ACTIONS(5734),
    [anon_sym_volatile] = ACTIONS(5734),
    [anon_sym_restrict] = ACTIONS(5734),
    [anon_sym___restrict__] = ACTIONS(5734),
    [anon_sym__Atomic] = ACTIONS(5734),
    [anon_sym__Noreturn] = ACTIONS(5734),
    [anon_sym_noreturn] = ACTIONS(5734),
    [anon_sym__Nonnull] = ACTIONS(5734),
    [anon_sym_mutable] = ACTIONS(5734),
    [anon_sym_constinit] = ACTIONS(5734),
    [anon_sym_consteval] = ACTIONS(5734),
    [anon_sym___shared__] = ACTIONS(5734),
    [anon_sym___local__] = ACTIONS(5734),
    [anon_sym___constant__] = ACTIONS(5734),
    [anon_sym___managed__] = ACTIONS(5734),
    [anon_sym___grid_constant__] = ACTIONS(5734),
    [anon_sym_alignas] = ACTIONS(5734),
    [anon_sym__Alignas] = ACTIONS(5734),
    [anon_sym_asm] = ACTIONS(5734),
    [anon_sym___asm__] = ACTIONS(5734),
    [anon_sym___asm] = ACTIONS(5734),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5734),
    [anon_sym_decltype] = ACTIONS(5734),
    [anon_sym_final] = ACTIONS(5734),
    [anon_sym_override] = ACTIONS(5734),
    [anon_sym_template] = ACTIONS(5734),
    [anon_sym_GT2] = ACTIONS(5736),
    [anon_sym_operator] = ACTIONS(5734),
    [anon_sym_try] = ACTIONS(5734),
    [anon_sym_requires] = ACTIONS(5734),
    [anon_sym___launch_bounds__] = ACTIONS(5734),
  },
  [STATE(2252)] = {
    [sym_identifier] = ACTIONS(5742),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5744),
    [anon_sym_COMMA] = ACTIONS(5744),
    [anon_sym_RPAREN] = ACTIONS(5744),
    [anon_sym_LPAREN2] = ACTIONS(5744),
    [anon_sym_TILDE] = ACTIONS(5744),
    [anon_sym_STAR] = ACTIONS(5744),
    [anon_sym_AMP_AMP] = ACTIONS(5744),
    [anon_sym_AMP] = ACTIONS(5742),
    [anon_sym_SEMI] = ACTIONS(5744),
    [anon_sym___extension__] = ACTIONS(5742),
    [anon_sym___device__] = ACTIONS(5742),
    [anon_sym___host__] = ACTIONS(5742),
    [anon_sym___global__] = ACTIONS(5742),
    [anon_sym___forceinline__] = ACTIONS(5742),
    [anon_sym___noinline__] = ACTIONS(5742),
    [anon_sym_virtual] = ACTIONS(5742),
    [anon_sym_extern] = ACTIONS(5742),
    [anon_sym___attribute__] = ACTIONS(5742),
    [anon_sym___attribute] = ACTIONS(5742),
    [anon_sym_COLON_COLON] = ACTIONS(5744),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5744),
    [anon_sym___declspec] = ACTIONS(5742),
    [anon_sym___based] = ACTIONS(5742),
    [anon_sym___cdecl] = ACTIONS(5742),
    [anon_sym___clrcall] = ACTIONS(5742),
    [anon_sym___stdcall] = ACTIONS(5742),
    [anon_sym___fastcall] = ACTIONS(5742),
    [anon_sym___thiscall] = ACTIONS(5742),
    [anon_sym___vectorcall] = ACTIONS(5742),
    [anon_sym_LBRACE] = ACTIONS(5744),
    [anon_sym_LBRACK] = ACTIONS(5742),
    [anon_sym_static] = ACTIONS(5742),
    [anon_sym_EQ] = ACTIONS(5744),
    [anon_sym_register] = ACTIONS(5742),
    [anon_sym_inline] = ACTIONS(5742),
    [anon_sym___inline] = ACTIONS(5742),
    [anon_sym___inline__] = ACTIONS(5742),
    [anon_sym___forceinline] = ACTIONS(5742),
    [anon_sym_thread_local] = ACTIONS(5742),
    [anon_sym___thread] = ACTIONS(5742),
    [anon_sym_const] = ACTIONS(5742),
    [anon_sym_constexpr] = ACTIONS(5742),
    [anon_sym_volatile] = ACTIONS(5742),
    [anon_sym_restrict] = ACTIONS(5742),
    [anon_sym___restrict__] = ACTIONS(5742),
    [anon_sym__Atomic] = ACTIONS(5742),
    [anon_sym__Noreturn] = ACTIONS(5742),
    [anon_sym_noreturn] = ACTIONS(5742),
    [anon_sym__Nonnull] = ACTIONS(5742),
    [anon_sym_mutable] = ACTIONS(5742),
    [anon_sym_constinit] = ACTIONS(5742),
    [anon_sym_consteval] = ACTIONS(5742),
    [anon_sym___shared__] = ACTIONS(5742),
    [anon_sym___local__] = ACTIONS(5742),
    [anon_sym___constant__] = ACTIONS(5742),
    [anon_sym___managed__] = ACTIONS(5742),
    [anon_sym___grid_constant__] = ACTIONS(5742),
    [anon_sym_alignas] = ACTIONS(5742),
    [anon_sym__Alignas] = ACTIONS(5742),
    [anon_sym_asm] = ACTIONS(5742),
    [anon_sym___asm__] = ACTIONS(5742),
    [anon_sym___asm] = ACTIONS(5742),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5742),
    [anon_sym_decltype] = ACTIONS(5742),
    [anon_sym_final] = ACTIONS(5742),
    [anon_sym_override] = ACTIONS(5742),
    [anon_sym_template] = ACTIONS(5742),
    [anon_sym_GT2] = ACTIONS(5744),
    [anon_sym_operator] = ACTIONS(5742),
    [anon_sym_try] = ACTIONS(5742),
    [anon_sym_requires] = ACTIONS(5742),
    [anon_sym___launch_bounds__] = ACTIONS(5742),
  },
  [STATE(2253)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_TILDE] = ACTIONS(5752),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___extension__] = ACTIONS(5750),
    [anon_sym___device__] = ACTIONS(5750),
    [anon_sym___host__] = ACTIONS(5750),
    [anon_sym___global__] = ACTIONS(5750),
    [anon_sym___forceinline__] = ACTIONS(5750),
    [anon_sym___noinline__] = ACTIONS(5750),
    [anon_sym_virtual] = ACTIONS(5750),
    [anon_sym_extern] = ACTIONS(5750),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_COLON_COLON] = ACTIONS(5752),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5752),
    [anon_sym___declspec] = ACTIONS(5750),
    [anon_sym___based] = ACTIONS(5750),
    [anon_sym___cdecl] = ACTIONS(5750),
    [anon_sym___clrcall] = ACTIONS(5750),
    [anon_sym___stdcall] = ACTIONS(5750),
    [anon_sym___fastcall] = ACTIONS(5750),
    [anon_sym___thiscall] = ACTIONS(5750),
    [anon_sym___vectorcall] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5750),
    [anon_sym_static] = ACTIONS(5750),
    [anon_sym_EQ] = ACTIONS(5752),
    [anon_sym_register] = ACTIONS(5750),
    [anon_sym_inline] = ACTIONS(5750),
    [anon_sym___inline] = ACTIONS(5750),
    [anon_sym___inline__] = ACTIONS(5750),
    [anon_sym___forceinline] = ACTIONS(5750),
    [anon_sym_thread_local] = ACTIONS(5750),
    [anon_sym___thread] = ACTIONS(5750),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5750),
    [anon_sym_volatile] = ACTIONS(5750),
    [anon_sym_restrict] = ACTIONS(5750),
    [anon_sym___restrict__] = ACTIONS(5750),
    [anon_sym__Atomic] = ACTIONS(5750),
    [anon_sym__Noreturn] = ACTIONS(5750),
    [anon_sym_noreturn] = ACTIONS(5750),
    [anon_sym__Nonnull] = ACTIONS(5750),
    [anon_sym_mutable] = ACTIONS(5750),
    [anon_sym_constinit] = ACTIONS(5750),
    [anon_sym_consteval] = ACTIONS(5750),
    [anon_sym___shared__] = ACTIONS(5750),
    [anon_sym___local__] = ACTIONS(5750),
    [anon_sym___constant__] = ACTIONS(5750),
    [anon_sym___managed__] = ACTIONS(5750),
    [anon_sym___grid_constant__] = ACTIONS(5750),
    [anon_sym_alignas] = ACTIONS(5750),
    [anon_sym__Alignas] = ACTIONS(5750),
    [anon_sym_asm] = ACTIONS(5750),
    [anon_sym___asm__] = ACTIONS(5750),
    [anon_sym___asm] = ACTIONS(5750),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [anon_sym_final] = ACTIONS(5750),
    [anon_sym_override] = ACTIONS(5750),
    [anon_sym_template] = ACTIONS(5750),
    [anon_sym_GT2] = ACTIONS(5752),
    [anon_sym_operator] = ACTIONS(5750),
    [anon_sym_try] = ACTIONS(5750),
    [anon_sym_requires] = ACTIONS(5750),
    [anon_sym___launch_bounds__] = ACTIONS(5750),
  },
  [STATE(2254)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_TILDE] = ACTIONS(5752),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___extension__] = ACTIONS(5750),
    [anon_sym___device__] = ACTIONS(5750),
    [anon_sym___host__] = ACTIONS(5750),
    [anon_sym___global__] = ACTIONS(5750),
    [anon_sym___forceinline__] = ACTIONS(5750),
    [anon_sym___noinline__] = ACTIONS(5750),
    [anon_sym_virtual] = ACTIONS(5750),
    [anon_sym_extern] = ACTIONS(5750),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_COLON_COLON] = ACTIONS(5752),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5752),
    [anon_sym___declspec] = ACTIONS(5750),
    [anon_sym___based] = ACTIONS(5750),
    [anon_sym___cdecl] = ACTIONS(5750),
    [anon_sym___clrcall] = ACTIONS(5750),
    [anon_sym___stdcall] = ACTIONS(5750),
    [anon_sym___fastcall] = ACTIONS(5750),
    [anon_sym___thiscall] = ACTIONS(5750),
    [anon_sym___vectorcall] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5750),
    [anon_sym_static] = ACTIONS(5750),
    [anon_sym_EQ] = ACTIONS(5752),
    [anon_sym_register] = ACTIONS(5750),
    [anon_sym_inline] = ACTIONS(5750),
    [anon_sym___inline] = ACTIONS(5750),
    [anon_sym___inline__] = ACTIONS(5750),
    [anon_sym___forceinline] = ACTIONS(5750),
    [anon_sym_thread_local] = ACTIONS(5750),
    [anon_sym___thread] = ACTIONS(5750),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5750),
    [anon_sym_volatile] = ACTIONS(5750),
    [anon_sym_restrict] = ACTIONS(5750),
    [anon_sym___restrict__] = ACTIONS(5750),
    [anon_sym__Atomic] = ACTIONS(5750),
    [anon_sym__Noreturn] = ACTIONS(5750),
    [anon_sym_noreturn] = ACTIONS(5750),
    [anon_sym__Nonnull] = ACTIONS(5750),
    [anon_sym_mutable] = ACTIONS(5750),
    [anon_sym_constinit] = ACTIONS(5750),
    [anon_sym_consteval] = ACTIONS(5750),
    [anon_sym___shared__] = ACTIONS(5750),
    [anon_sym___local__] = ACTIONS(5750),
    [anon_sym___constant__] = ACTIONS(5750),
    [anon_sym___managed__] = ACTIONS(5750),
    [anon_sym___grid_constant__] = ACTIONS(5750),
    [anon_sym_alignas] = ACTIONS(5750),
    [anon_sym__Alignas] = ACTIONS(5750),
    [anon_sym_asm] = ACTIONS(5750),
    [anon_sym___asm__] = ACTIONS(5750),
    [anon_sym___asm] = ACTIONS(5750),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [anon_sym_final] = ACTIONS(5750),
    [anon_sym_override] = ACTIONS(5750),
    [anon_sym_template] = ACTIONS(5750),
    [anon_sym_GT2] = ACTIONS(5752),
    [anon_sym_operator] = ACTIONS(5750),
    [anon_sym_try] = ACTIONS(5750),
    [anon_sym_requires] = ACTIONS(5750),
    [anon_sym___launch_bounds__] = ACTIONS(5750),
  },
  [STATE(2255)] = {
    [sym_identifier] = ACTIONS(5842),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5844),
    [anon_sym_COMMA] = ACTIONS(5844),
    [anon_sym_RPAREN] = ACTIONS(5844),
    [anon_sym_LPAREN2] = ACTIONS(5844),
    [anon_sym_TILDE] = ACTIONS(5844),
    [anon_sym_STAR] = ACTIONS(5844),
    [anon_sym_AMP_AMP] = ACTIONS(5844),
    [anon_sym_AMP] = ACTIONS(5842),
    [anon_sym_SEMI] = ACTIONS(5844),
    [anon_sym___extension__] = ACTIONS(5842),
    [anon_sym___device__] = ACTIONS(5842),
    [anon_sym___host__] = ACTIONS(5842),
    [anon_sym___global__] = ACTIONS(5842),
    [anon_sym___forceinline__] = ACTIONS(5842),
    [anon_sym___noinline__] = ACTIONS(5842),
    [anon_sym_virtual] = ACTIONS(5842),
    [anon_sym_extern] = ACTIONS(5842),
    [anon_sym___attribute__] = ACTIONS(5842),
    [anon_sym___attribute] = ACTIONS(5842),
    [anon_sym_COLON_COLON] = ACTIONS(5844),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5844),
    [anon_sym___declspec] = ACTIONS(5842),
    [anon_sym___based] = ACTIONS(5842),
    [anon_sym___cdecl] = ACTIONS(5842),
    [anon_sym___clrcall] = ACTIONS(5842),
    [anon_sym___stdcall] = ACTIONS(5842),
    [anon_sym___fastcall] = ACTIONS(5842),
    [anon_sym___thiscall] = ACTIONS(5842),
    [anon_sym___vectorcall] = ACTIONS(5842),
    [anon_sym_LBRACE] = ACTIONS(5844),
    [anon_sym_LBRACK] = ACTIONS(5842),
    [anon_sym_static] = ACTIONS(5842),
    [anon_sym_EQ] = ACTIONS(5844),
    [anon_sym_register] = ACTIONS(5842),
    [anon_sym_inline] = ACTIONS(5842),
    [anon_sym___inline] = ACTIONS(5842),
    [anon_sym___inline__] = ACTIONS(5842),
    [anon_sym___forceinline] = ACTIONS(5842),
    [anon_sym_thread_local] = ACTIONS(5842),
    [anon_sym___thread] = ACTIONS(5842),
    [anon_sym_const] = ACTIONS(5842),
    [anon_sym_constexpr] = ACTIONS(5842),
    [anon_sym_volatile] = ACTIONS(5842),
    [anon_sym_restrict] = ACTIONS(5842),
    [anon_sym___restrict__] = ACTIONS(5842),
    [anon_sym__Atomic] = ACTIONS(5842),
    [anon_sym__Noreturn] = ACTIONS(5842),
    [anon_sym_noreturn] = ACTIONS(5842),
    [anon_sym__Nonnull] = ACTIONS(5842),
    [anon_sym_mutable] = ACTIONS(5842),
    [anon_sym_constinit] = ACTIONS(5842),
    [anon_sym_consteval] = ACTIONS(5842),
    [anon_sym___shared__] = ACTIONS(5842),
    [anon_sym___local__] = ACTIONS(5842),
    [anon_sym___constant__] = ACTIONS(5842),
    [anon_sym___managed__] = ACTIONS(5842),
    [anon_sym___grid_constant__] = ACTIONS(5842),
    [anon_sym_alignas] = ACTIONS(5842),
    [anon_sym__Alignas] = ACTIONS(5842),
    [anon_sym_asm] = ACTIONS(5842),
    [anon_sym___asm__] = ACTIONS(5842),
    [anon_sym___asm] = ACTIONS(5842),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5842),
    [anon_sym_decltype] = ACTIONS(5842),
    [anon_sym_final] = ACTIONS(5842),
    [anon_sym_override] = ACTIONS(5842),
    [anon_sym_template] = ACTIONS(5842),
    [anon_sym_GT2] = ACTIONS(5844),
    [anon_sym_operator] = ACTIONS(5842),
    [anon_sym_try] = ACTIONS(5842),
    [anon_sym_requires] = ACTIONS(5842),
    [anon_sym___launch_bounds__] = ACTIONS(5842),
  },
  [STATE(2256)] = {
    [sym__declaration_modifiers] = STATE(2261),
    [sym_attribute_specifier] = STATE(2261),
    [sym_attribute_declaration] = STATE(2261),
    [sym_ms_declspec_modifier] = STATE(2261),
    [sym_storage_class_specifier] = STATE(2261),
    [sym_type_qualifier] = STATE(2261),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_launch_bounds] = STATE(2261),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2261),
    [sym_identifier] = ACTIONS(6115),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6117),
    [anon_sym_COMMA] = ACTIONS(6117),
    [anon_sym_RPAREN] = ACTIONS(6117),
    [anon_sym_LPAREN2] = ACTIONS(6117),
    [anon_sym_TILDE] = ACTIONS(6117),
    [anon_sym_STAR] = ACTIONS(6117),
    [anon_sym_AMP_AMP] = ACTIONS(6117),
    [anon_sym_AMP] = ACTIONS(6115),
    [anon_sym_SEMI] = ACTIONS(6117),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(6103),
    [anon_sym___host__] = ACTIONS(6103),
    [anon_sym___global__] = ACTIONS(6103),
    [anon_sym___forceinline__] = ACTIONS(6103),
    [anon_sym___noinline__] = ACTIONS(6103),
    [anon_sym_virtual] = ACTIONS(6103),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6117),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(6115),
    [anon_sym___cdecl] = ACTIONS(6115),
    [anon_sym___clrcall] = ACTIONS(6115),
    [anon_sym___stdcall] = ACTIONS(6115),
    [anon_sym___fastcall] = ACTIONS(6115),
    [anon_sym___thiscall] = ACTIONS(6115),
    [anon_sym___vectorcall] = ACTIONS(6115),
    [anon_sym_LBRACK] = ACTIONS(6115),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_EQ] = ACTIONS(6117),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6115),
    [anon_sym_template] = ACTIONS(6115),
    [anon_sym_GT2] = ACTIONS(6117),
    [anon_sym_operator] = ACTIONS(6115),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2257)] = {
    [sym_identifier] = ACTIONS(5722),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5724),
    [anon_sym_COMMA] = ACTIONS(5724),
    [anon_sym_RPAREN] = ACTIONS(5724),
    [anon_sym_LPAREN2] = ACTIONS(5724),
    [anon_sym_TILDE] = ACTIONS(5724),
    [anon_sym_STAR] = ACTIONS(5724),
    [anon_sym_AMP_AMP] = ACTIONS(5724),
    [anon_sym_AMP] = ACTIONS(5722),
    [anon_sym_SEMI] = ACTIONS(5724),
    [anon_sym___extension__] = ACTIONS(5722),
    [anon_sym___device__] = ACTIONS(5722),
    [anon_sym___host__] = ACTIONS(5722),
    [anon_sym___global__] = ACTIONS(5722),
    [anon_sym___forceinline__] = ACTIONS(5722),
    [anon_sym___noinline__] = ACTIONS(5722),
    [anon_sym_virtual] = ACTIONS(5722),
    [anon_sym_extern] = ACTIONS(5722),
    [anon_sym___attribute__] = ACTIONS(5722),
    [anon_sym___attribute] = ACTIONS(5722),
    [anon_sym_COLON_COLON] = ACTIONS(5724),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5724),
    [anon_sym___declspec] = ACTIONS(5722),
    [anon_sym___based] = ACTIONS(5722),
    [anon_sym___cdecl] = ACTIONS(5722),
    [anon_sym___clrcall] = ACTIONS(5722),
    [anon_sym___stdcall] = ACTIONS(5722),
    [anon_sym___fastcall] = ACTIONS(5722),
    [anon_sym___thiscall] = ACTIONS(5722),
    [anon_sym___vectorcall] = ACTIONS(5722),
    [anon_sym_LBRACE] = ACTIONS(5724),
    [anon_sym_LBRACK] = ACTIONS(5722),
    [anon_sym_static] = ACTIONS(5722),
    [anon_sym_EQ] = ACTIONS(5724),
    [anon_sym_register] = ACTIONS(5722),
    [anon_sym_inline] = ACTIONS(5722),
    [anon_sym___inline] = ACTIONS(5722),
    [anon_sym___inline__] = ACTIONS(5722),
    [anon_sym___forceinline] = ACTIONS(5722),
    [anon_sym_thread_local] = ACTIONS(5722),
    [anon_sym___thread] = ACTIONS(5722),
    [anon_sym_const] = ACTIONS(5722),
    [anon_sym_constexpr] = ACTIONS(5722),
    [anon_sym_volatile] = ACTIONS(5722),
    [anon_sym_restrict] = ACTIONS(5722),
    [anon_sym___restrict__] = ACTIONS(5722),
    [anon_sym__Atomic] = ACTIONS(5722),
    [anon_sym__Noreturn] = ACTIONS(5722),
    [anon_sym_noreturn] = ACTIONS(5722),
    [anon_sym__Nonnull] = ACTIONS(5722),
    [anon_sym_mutable] = ACTIONS(5722),
    [anon_sym_constinit] = ACTIONS(5722),
    [anon_sym_consteval] = ACTIONS(5722),
    [anon_sym___shared__] = ACTIONS(5722),
    [anon_sym___local__] = ACTIONS(5722),
    [anon_sym___constant__] = ACTIONS(5722),
    [anon_sym___managed__] = ACTIONS(5722),
    [anon_sym___grid_constant__] = ACTIONS(5722),
    [anon_sym_alignas] = ACTIONS(5722),
    [anon_sym__Alignas] = ACTIONS(5722),
    [anon_sym_asm] = ACTIONS(5722),
    [anon_sym___asm__] = ACTIONS(5722),
    [anon_sym___asm] = ACTIONS(5722),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5722),
    [anon_sym_decltype] = ACTIONS(5722),
    [anon_sym_final] = ACTIONS(5722),
    [anon_sym_override] = ACTIONS(5722),
    [anon_sym_template] = ACTIONS(5722),
    [anon_sym_GT2] = ACTIONS(5724),
    [anon_sym_operator] = ACTIONS(5722),
    [anon_sym_try] = ACTIONS(5722),
    [anon_sym_requires] = ACTIONS(5722),
    [anon_sym___launch_bounds__] = ACTIONS(5722),
  },
  [STATE(2258)] = {
    [sym_identifier] = ACTIONS(5758),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5760),
    [anon_sym_COMMA] = ACTIONS(5760),
    [anon_sym_RPAREN] = ACTIONS(5760),
    [anon_sym_LPAREN2] = ACTIONS(5760),
    [anon_sym_TILDE] = ACTIONS(5760),
    [anon_sym_STAR] = ACTIONS(5760),
    [anon_sym_AMP_AMP] = ACTIONS(5760),
    [anon_sym_AMP] = ACTIONS(5758),
    [anon_sym_SEMI] = ACTIONS(5760),
    [anon_sym___extension__] = ACTIONS(5758),
    [anon_sym___device__] = ACTIONS(5758),
    [anon_sym___host__] = ACTIONS(5758),
    [anon_sym___global__] = ACTIONS(5758),
    [anon_sym___forceinline__] = ACTIONS(5758),
    [anon_sym___noinline__] = ACTIONS(5758),
    [anon_sym_virtual] = ACTIONS(5758),
    [anon_sym_extern] = ACTIONS(5758),
    [anon_sym___attribute__] = ACTIONS(5758),
    [anon_sym___attribute] = ACTIONS(5758),
    [anon_sym_COLON_COLON] = ACTIONS(5760),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5760),
    [anon_sym___declspec] = ACTIONS(5758),
    [anon_sym___based] = ACTIONS(5758),
    [anon_sym___cdecl] = ACTIONS(5758),
    [anon_sym___clrcall] = ACTIONS(5758),
    [anon_sym___stdcall] = ACTIONS(5758),
    [anon_sym___fastcall] = ACTIONS(5758),
    [anon_sym___thiscall] = ACTIONS(5758),
    [anon_sym___vectorcall] = ACTIONS(5758),
    [anon_sym_LBRACE] = ACTIONS(5760),
    [anon_sym_LBRACK] = ACTIONS(5758),
    [anon_sym_static] = ACTIONS(5758),
    [anon_sym_EQ] = ACTIONS(5760),
    [anon_sym_register] = ACTIONS(5758),
    [anon_sym_inline] = ACTIONS(5758),
    [anon_sym___inline] = ACTIONS(5758),
    [anon_sym___inline__] = ACTIONS(5758),
    [anon_sym___forceinline] = ACTIONS(5758),
    [anon_sym_thread_local] = ACTIONS(5758),
    [anon_sym___thread] = ACTIONS(5758),
    [anon_sym_const] = ACTIONS(5758),
    [anon_sym_constexpr] = ACTIONS(5758),
    [anon_sym_volatile] = ACTIONS(5758),
    [anon_sym_restrict] = ACTIONS(5758),
    [anon_sym___restrict__] = ACTIONS(5758),
    [anon_sym__Atomic] = ACTIONS(5758),
    [anon_sym__Noreturn] = ACTIONS(5758),
    [anon_sym_noreturn] = ACTIONS(5758),
    [anon_sym__Nonnull] = ACTIONS(5758),
    [anon_sym_mutable] = ACTIONS(5758),
    [anon_sym_constinit] = ACTIONS(5758),
    [anon_sym_consteval] = ACTIONS(5758),
    [anon_sym___shared__] = ACTIONS(5758),
    [anon_sym___local__] = ACTIONS(5758),
    [anon_sym___constant__] = ACTIONS(5758),
    [anon_sym___managed__] = ACTIONS(5758),
    [anon_sym___grid_constant__] = ACTIONS(5758),
    [anon_sym_alignas] = ACTIONS(5758),
    [anon_sym__Alignas] = ACTIONS(5758),
    [anon_sym_asm] = ACTIONS(5758),
    [anon_sym___asm__] = ACTIONS(5758),
    [anon_sym___asm] = ACTIONS(5758),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5758),
    [anon_sym_decltype] = ACTIONS(5758),
    [anon_sym_final] = ACTIONS(5758),
    [anon_sym_override] = ACTIONS(5758),
    [anon_sym_template] = ACTIONS(5758),
    [anon_sym_GT2] = ACTIONS(5760),
    [anon_sym_operator] = ACTIONS(5758),
    [anon_sym_try] = ACTIONS(5758),
    [anon_sym_requires] = ACTIONS(5758),
    [anon_sym___launch_bounds__] = ACTIONS(5758),
  },
  [STATE(2259)] = {
    [sym_identifier] = ACTIONS(5762),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5764),
    [anon_sym_COMMA] = ACTIONS(5764),
    [anon_sym_RPAREN] = ACTIONS(5764),
    [anon_sym_LPAREN2] = ACTIONS(5764),
    [anon_sym_TILDE] = ACTIONS(5764),
    [anon_sym_STAR] = ACTIONS(5764),
    [anon_sym_AMP_AMP] = ACTIONS(5764),
    [anon_sym_AMP] = ACTIONS(5762),
    [anon_sym_SEMI] = ACTIONS(5764),
    [anon_sym___extension__] = ACTIONS(5762),
    [anon_sym___device__] = ACTIONS(5762),
    [anon_sym___host__] = ACTIONS(5762),
    [anon_sym___global__] = ACTIONS(5762),
    [anon_sym___forceinline__] = ACTIONS(5762),
    [anon_sym___noinline__] = ACTIONS(5762),
    [anon_sym_virtual] = ACTIONS(5762),
    [anon_sym_extern] = ACTIONS(5762),
    [anon_sym___attribute__] = ACTIONS(5762),
    [anon_sym___attribute] = ACTIONS(5762),
    [anon_sym_COLON_COLON] = ACTIONS(5764),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5764),
    [anon_sym___declspec] = ACTIONS(5762),
    [anon_sym___based] = ACTIONS(5762),
    [anon_sym___cdecl] = ACTIONS(5762),
    [anon_sym___clrcall] = ACTIONS(5762),
    [anon_sym___stdcall] = ACTIONS(5762),
    [anon_sym___fastcall] = ACTIONS(5762),
    [anon_sym___thiscall] = ACTIONS(5762),
    [anon_sym___vectorcall] = ACTIONS(5762),
    [anon_sym_LBRACE] = ACTIONS(5764),
    [anon_sym_LBRACK] = ACTIONS(5762),
    [anon_sym_static] = ACTIONS(5762),
    [anon_sym_EQ] = ACTIONS(5764),
    [anon_sym_register] = ACTIONS(5762),
    [anon_sym_inline] = ACTIONS(5762),
    [anon_sym___inline] = ACTIONS(5762),
    [anon_sym___inline__] = ACTIONS(5762),
    [anon_sym___forceinline] = ACTIONS(5762),
    [anon_sym_thread_local] = ACTIONS(5762),
    [anon_sym___thread] = ACTIONS(5762),
    [anon_sym_const] = ACTIONS(5762),
    [anon_sym_constexpr] = ACTIONS(5762),
    [anon_sym_volatile] = ACTIONS(5762),
    [anon_sym_restrict] = ACTIONS(5762),
    [anon_sym___restrict__] = ACTIONS(5762),
    [anon_sym__Atomic] = ACTIONS(5762),
    [anon_sym__Noreturn] = ACTIONS(5762),
    [anon_sym_noreturn] = ACTIONS(5762),
    [anon_sym__Nonnull] = ACTIONS(5762),
    [anon_sym_mutable] = ACTIONS(5762),
    [anon_sym_constinit] = ACTIONS(5762),
    [anon_sym_consteval] = ACTIONS(5762),
    [anon_sym___shared__] = ACTIONS(5762),
    [anon_sym___local__] = ACTIONS(5762),
    [anon_sym___constant__] = ACTIONS(5762),
    [anon_sym___managed__] = ACTIONS(5762),
    [anon_sym___grid_constant__] = ACTIONS(5762),
    [anon_sym_alignas] = ACTIONS(5762),
    [anon_sym__Alignas] = ACTIONS(5762),
    [anon_sym_asm] = ACTIONS(5762),
    [anon_sym___asm__] = ACTIONS(5762),
    [anon_sym___asm] = ACTIONS(5762),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5762),
    [anon_sym_decltype] = ACTIONS(5762),
    [anon_sym_final] = ACTIONS(5762),
    [anon_sym_override] = ACTIONS(5762),
    [anon_sym_template] = ACTIONS(5762),
    [anon_sym_GT2] = ACTIONS(5764),
    [anon_sym_operator] = ACTIONS(5762),
    [anon_sym_try] = ACTIONS(5762),
    [anon_sym_requires] = ACTIONS(5762),
    [anon_sym___launch_bounds__] = ACTIONS(5762),
  },
  [STATE(2260)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(3478),
    [sym__declarator] = STATE(6947),
    [sym__abstract_declarator] = STATE(7265),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(2651),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3083),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(2651),
    [aux_sym_pointer_declarator_repeat1] = STATE(3478),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(5925),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(6078),
    [anon_sym_AMP_AMP] = ACTIONS(6080),
    [anon_sym_AMP] = ACTIONS(6082),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(5933),
    [anon_sym___attribute] = ACTIONS(5933),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(5925),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2261)] = {
    [sym__declaration_modifiers] = STATE(2261),
    [sym_attribute_specifier] = STATE(2261),
    [sym_attribute_declaration] = STATE(2261),
    [sym_ms_declspec_modifier] = STATE(2261),
    [sym_storage_class_specifier] = STATE(2261),
    [sym_type_qualifier] = STATE(2261),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_launch_bounds] = STATE(2261),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2261),
    [sym_identifier] = ACTIONS(6119),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6121),
    [anon_sym_COMMA] = ACTIONS(6121),
    [anon_sym_RPAREN] = ACTIONS(6121),
    [anon_sym_LPAREN2] = ACTIONS(6121),
    [anon_sym_TILDE] = ACTIONS(6121),
    [anon_sym_STAR] = ACTIONS(6121),
    [anon_sym_AMP_AMP] = ACTIONS(6121),
    [anon_sym_AMP] = ACTIONS(6119),
    [anon_sym_SEMI] = ACTIONS(6121),
    [anon_sym___extension__] = ACTIONS(6123),
    [anon_sym___device__] = ACTIONS(6126),
    [anon_sym___host__] = ACTIONS(6126),
    [anon_sym___global__] = ACTIONS(6126),
    [anon_sym___forceinline__] = ACTIONS(6126),
    [anon_sym___noinline__] = ACTIONS(6126),
    [anon_sym_virtual] = ACTIONS(6126),
    [anon_sym_extern] = ACTIONS(6129),
    [anon_sym___attribute__] = ACTIONS(6132),
    [anon_sym___attribute] = ACTIONS(6132),
    [anon_sym_COLON_COLON] = ACTIONS(6121),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6135),
    [anon_sym___declspec] = ACTIONS(6138),
    [anon_sym___based] = ACTIONS(6119),
    [anon_sym___cdecl] = ACTIONS(6119),
    [anon_sym___clrcall] = ACTIONS(6119),
    [anon_sym___stdcall] = ACTIONS(6119),
    [anon_sym___fastcall] = ACTIONS(6119),
    [anon_sym___thiscall] = ACTIONS(6119),
    [anon_sym___vectorcall] = ACTIONS(6119),
    [anon_sym_LBRACK] = ACTIONS(6119),
    [anon_sym_static] = ACTIONS(6129),
    [anon_sym_EQ] = ACTIONS(6121),
    [anon_sym_register] = ACTIONS(6129),
    [anon_sym_inline] = ACTIONS(6129),
    [anon_sym___inline] = ACTIONS(6129),
    [anon_sym___inline__] = ACTIONS(6129),
    [anon_sym___forceinline] = ACTIONS(6129),
    [anon_sym_thread_local] = ACTIONS(6129),
    [anon_sym___thread] = ACTIONS(6129),
    [anon_sym_const] = ACTIONS(6123),
    [anon_sym_constexpr] = ACTIONS(6123),
    [anon_sym_volatile] = ACTIONS(6123),
    [anon_sym_restrict] = ACTIONS(6123),
    [anon_sym___restrict__] = ACTIONS(6123),
    [anon_sym__Atomic] = ACTIONS(6123),
    [anon_sym__Noreturn] = ACTIONS(6123),
    [anon_sym_noreturn] = ACTIONS(6123),
    [anon_sym__Nonnull] = ACTIONS(6123),
    [anon_sym_mutable] = ACTIONS(6123),
    [anon_sym_constinit] = ACTIONS(6123),
    [anon_sym_consteval] = ACTIONS(6123),
    [anon_sym___shared__] = ACTIONS(6123),
    [anon_sym___local__] = ACTIONS(6123),
    [anon_sym___constant__] = ACTIONS(6123),
    [anon_sym___managed__] = ACTIONS(6123),
    [anon_sym___grid_constant__] = ACTIONS(6123),
    [anon_sym_alignas] = ACTIONS(6141),
    [anon_sym__Alignas] = ACTIONS(6141),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6119),
    [anon_sym_template] = ACTIONS(6119),
    [anon_sym_GT2] = ACTIONS(6121),
    [anon_sym_operator] = ACTIONS(6119),
    [anon_sym___launch_bounds__] = ACTIONS(6144),
  },
  [STATE(2262)] = {
    [sym_identifier] = ACTIONS(5714),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5716),
    [anon_sym_COMMA] = ACTIONS(5716),
    [anon_sym_RPAREN] = ACTIONS(5716),
    [anon_sym_LPAREN2] = ACTIONS(5716),
    [anon_sym_TILDE] = ACTIONS(5716),
    [anon_sym_STAR] = ACTIONS(5716),
    [anon_sym_AMP_AMP] = ACTIONS(5716),
    [anon_sym_AMP] = ACTIONS(5714),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym___extension__] = ACTIONS(5714),
    [anon_sym___device__] = ACTIONS(5714),
    [anon_sym___host__] = ACTIONS(5714),
    [anon_sym___global__] = ACTIONS(5714),
    [anon_sym___forceinline__] = ACTIONS(5714),
    [anon_sym___noinline__] = ACTIONS(5714),
    [anon_sym_virtual] = ACTIONS(5714),
    [anon_sym_extern] = ACTIONS(5714),
    [anon_sym___attribute__] = ACTIONS(5714),
    [anon_sym___attribute] = ACTIONS(5714),
    [anon_sym_COLON_COLON] = ACTIONS(5716),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5716),
    [anon_sym___declspec] = ACTIONS(5714),
    [anon_sym___based] = ACTIONS(5714),
    [anon_sym___cdecl] = ACTIONS(5714),
    [anon_sym___clrcall] = ACTIONS(5714),
    [anon_sym___stdcall] = ACTIONS(5714),
    [anon_sym___fastcall] = ACTIONS(5714),
    [anon_sym___thiscall] = ACTIONS(5714),
    [anon_sym___vectorcall] = ACTIONS(5714),
    [anon_sym_LBRACE] = ACTIONS(5716),
    [anon_sym_LBRACK] = ACTIONS(5714),
    [anon_sym_static] = ACTIONS(5714),
    [anon_sym_EQ] = ACTIONS(5716),
    [anon_sym_register] = ACTIONS(5714),
    [anon_sym_inline] = ACTIONS(5714),
    [anon_sym___inline] = ACTIONS(5714),
    [anon_sym___inline__] = ACTIONS(5714),
    [anon_sym___forceinline] = ACTIONS(5714),
    [anon_sym_thread_local] = ACTIONS(5714),
    [anon_sym___thread] = ACTIONS(5714),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_constexpr] = ACTIONS(5714),
    [anon_sym_volatile] = ACTIONS(5714),
    [anon_sym_restrict] = ACTIONS(5714),
    [anon_sym___restrict__] = ACTIONS(5714),
    [anon_sym__Atomic] = ACTIONS(5714),
    [anon_sym__Noreturn] = ACTIONS(5714),
    [anon_sym_noreturn] = ACTIONS(5714),
    [anon_sym__Nonnull] = ACTIONS(5714),
    [anon_sym_mutable] = ACTIONS(5714),
    [anon_sym_constinit] = ACTIONS(5714),
    [anon_sym_consteval] = ACTIONS(5714),
    [anon_sym___shared__] = ACTIONS(5714),
    [anon_sym___local__] = ACTIONS(5714),
    [anon_sym___constant__] = ACTIONS(5714),
    [anon_sym___managed__] = ACTIONS(5714),
    [anon_sym___grid_constant__] = ACTIONS(5714),
    [anon_sym_alignas] = ACTIONS(5714),
    [anon_sym__Alignas] = ACTIONS(5714),
    [anon_sym_asm] = ACTIONS(5714),
    [anon_sym___asm__] = ACTIONS(5714),
    [anon_sym___asm] = ACTIONS(5714),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5714),
    [anon_sym_decltype] = ACTIONS(5714),
    [anon_sym_final] = ACTIONS(5714),
    [anon_sym_override] = ACTIONS(5714),
    [anon_sym_template] = ACTIONS(5714),
    [anon_sym_GT2] = ACTIONS(5716),
    [anon_sym_operator] = ACTIONS(5714),
    [anon_sym_try] = ACTIONS(5714),
    [anon_sym_requires] = ACTIONS(5714),
    [anon_sym___launch_bounds__] = ACTIONS(5714),
  },
  [STATE(2263)] = {
    [sym_identifier] = ACTIONS(5797),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5799),
    [anon_sym_COMMA] = ACTIONS(5799),
    [anon_sym_RPAREN] = ACTIONS(5799),
    [anon_sym_LPAREN2] = ACTIONS(5799),
    [anon_sym_TILDE] = ACTIONS(5799),
    [anon_sym_STAR] = ACTIONS(5799),
    [anon_sym_AMP_AMP] = ACTIONS(5799),
    [anon_sym_AMP] = ACTIONS(5797),
    [anon_sym_SEMI] = ACTIONS(5799),
    [anon_sym___extension__] = ACTIONS(5797),
    [anon_sym___device__] = ACTIONS(5797),
    [anon_sym___host__] = ACTIONS(5797),
    [anon_sym___global__] = ACTIONS(5797),
    [anon_sym___forceinline__] = ACTIONS(5797),
    [anon_sym___noinline__] = ACTIONS(5797),
    [anon_sym_virtual] = ACTIONS(5797),
    [anon_sym_extern] = ACTIONS(5797),
    [anon_sym___attribute__] = ACTIONS(5797),
    [anon_sym___attribute] = ACTIONS(5797),
    [anon_sym_COLON_COLON] = ACTIONS(5799),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5799),
    [anon_sym___declspec] = ACTIONS(5797),
    [anon_sym___based] = ACTIONS(5797),
    [anon_sym___cdecl] = ACTIONS(5797),
    [anon_sym___clrcall] = ACTIONS(5797),
    [anon_sym___stdcall] = ACTIONS(5797),
    [anon_sym___fastcall] = ACTIONS(5797),
    [anon_sym___thiscall] = ACTIONS(5797),
    [anon_sym___vectorcall] = ACTIONS(5797),
    [anon_sym_LBRACE] = ACTIONS(5799),
    [anon_sym_LBRACK] = ACTIONS(5797),
    [anon_sym_static] = ACTIONS(5797),
    [anon_sym_EQ] = ACTIONS(5799),
    [anon_sym_register] = ACTIONS(5797),
    [anon_sym_inline] = ACTIONS(5797),
    [anon_sym___inline] = ACTIONS(5797),
    [anon_sym___inline__] = ACTIONS(5797),
    [anon_sym___forceinline] = ACTIONS(5797),
    [anon_sym_thread_local] = ACTIONS(5797),
    [anon_sym___thread] = ACTIONS(5797),
    [anon_sym_const] = ACTIONS(5797),
    [anon_sym_constexpr] = ACTIONS(5797),
    [anon_sym_volatile] = ACTIONS(5797),
    [anon_sym_restrict] = ACTIONS(5797),
    [anon_sym___restrict__] = ACTIONS(5797),
    [anon_sym__Atomic] = ACTIONS(5797),
    [anon_sym__Noreturn] = ACTIONS(5797),
    [anon_sym_noreturn] = ACTIONS(5797),
    [anon_sym__Nonnull] = ACTIONS(5797),
    [anon_sym_mutable] = ACTIONS(5797),
    [anon_sym_constinit] = ACTIONS(5797),
    [anon_sym_consteval] = ACTIONS(5797),
    [anon_sym___shared__] = ACTIONS(5797),
    [anon_sym___local__] = ACTIONS(5797),
    [anon_sym___constant__] = ACTIONS(5797),
    [anon_sym___managed__] = ACTIONS(5797),
    [anon_sym___grid_constant__] = ACTIONS(5797),
    [anon_sym_alignas] = ACTIONS(5797),
    [anon_sym__Alignas] = ACTIONS(5797),
    [anon_sym_asm] = ACTIONS(5797),
    [anon_sym___asm__] = ACTIONS(5797),
    [anon_sym___asm] = ACTIONS(5797),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5797),
    [anon_sym_decltype] = ACTIONS(5797),
    [anon_sym_final] = ACTIONS(5797),
    [anon_sym_override] = ACTIONS(5797),
    [anon_sym_template] = ACTIONS(5797),
    [anon_sym_GT2] = ACTIONS(5799),
    [anon_sym_operator] = ACTIONS(5797),
    [anon_sym_try] = ACTIONS(5797),
    [anon_sym_requires] = ACTIONS(5797),
    [anon_sym___launch_bounds__] = ACTIONS(5797),
  },
  [STATE(2264)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_TILDE] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5686),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym___cdecl] = ACTIONS(5684),
    [anon_sym___clrcall] = ACTIONS(5684),
    [anon_sym___stdcall] = ACTIONS(5684),
    [anon_sym___fastcall] = ACTIONS(5684),
    [anon_sym___thiscall] = ACTIONS(5684),
    [anon_sym___vectorcall] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [anon_sym_asm] = ACTIONS(5684),
    [anon_sym___asm__] = ACTIONS(5684),
    [anon_sym___asm] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_final] = ACTIONS(5684),
    [anon_sym_override] = ACTIONS(5684),
    [anon_sym_template] = ACTIONS(5684),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_operator] = ACTIONS(5684),
    [anon_sym_try] = ACTIONS(5684),
    [anon_sym_requires] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2265)] = {
    [sym_identifier] = ACTIONS(5825),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5827),
    [anon_sym_COMMA] = ACTIONS(5827),
    [anon_sym_RPAREN] = ACTIONS(5827),
    [anon_sym_LPAREN2] = ACTIONS(5827),
    [anon_sym_TILDE] = ACTIONS(5827),
    [anon_sym_STAR] = ACTIONS(5827),
    [anon_sym_AMP_AMP] = ACTIONS(5827),
    [anon_sym_AMP] = ACTIONS(5825),
    [anon_sym_SEMI] = ACTIONS(5827),
    [anon_sym___extension__] = ACTIONS(5825),
    [anon_sym___device__] = ACTIONS(5825),
    [anon_sym___host__] = ACTIONS(5825),
    [anon_sym___global__] = ACTIONS(5825),
    [anon_sym___forceinline__] = ACTIONS(5825),
    [anon_sym___noinline__] = ACTIONS(5825),
    [anon_sym_virtual] = ACTIONS(5825),
    [anon_sym_extern] = ACTIONS(5825),
    [anon_sym___attribute__] = ACTIONS(5825),
    [anon_sym___attribute] = ACTIONS(5825),
    [anon_sym_COLON_COLON] = ACTIONS(5827),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5827),
    [anon_sym___declspec] = ACTIONS(5825),
    [anon_sym___based] = ACTIONS(5825),
    [anon_sym___cdecl] = ACTIONS(5825),
    [anon_sym___clrcall] = ACTIONS(5825),
    [anon_sym___stdcall] = ACTIONS(5825),
    [anon_sym___fastcall] = ACTIONS(5825),
    [anon_sym___thiscall] = ACTIONS(5825),
    [anon_sym___vectorcall] = ACTIONS(5825),
    [anon_sym_LBRACE] = ACTIONS(5827),
    [anon_sym_LBRACK] = ACTIONS(5825),
    [anon_sym_static] = ACTIONS(5825),
    [anon_sym_EQ] = ACTIONS(5827),
    [anon_sym_register] = ACTIONS(5825),
    [anon_sym_inline] = ACTIONS(5825),
    [anon_sym___inline] = ACTIONS(5825),
    [anon_sym___inline__] = ACTIONS(5825),
    [anon_sym___forceinline] = ACTIONS(5825),
    [anon_sym_thread_local] = ACTIONS(5825),
    [anon_sym___thread] = ACTIONS(5825),
    [anon_sym_const] = ACTIONS(5825),
    [anon_sym_constexpr] = ACTIONS(5825),
    [anon_sym_volatile] = ACTIONS(5825),
    [anon_sym_restrict] = ACTIONS(5825),
    [anon_sym___restrict__] = ACTIONS(5825),
    [anon_sym__Atomic] = ACTIONS(5825),
    [anon_sym__Noreturn] = ACTIONS(5825),
    [anon_sym_noreturn] = ACTIONS(5825),
    [anon_sym__Nonnull] = ACTIONS(5825),
    [anon_sym_mutable] = ACTIONS(5825),
    [anon_sym_constinit] = ACTIONS(5825),
    [anon_sym_consteval] = ACTIONS(5825),
    [anon_sym___shared__] = ACTIONS(5825),
    [anon_sym___local__] = ACTIONS(5825),
    [anon_sym___constant__] = ACTIONS(5825),
    [anon_sym___managed__] = ACTIONS(5825),
    [anon_sym___grid_constant__] = ACTIONS(5825),
    [anon_sym_alignas] = ACTIONS(5825),
    [anon_sym__Alignas] = ACTIONS(5825),
    [anon_sym_asm] = ACTIONS(5825),
    [anon_sym___asm__] = ACTIONS(5825),
    [anon_sym___asm] = ACTIONS(5825),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5825),
    [anon_sym_decltype] = ACTIONS(5825),
    [anon_sym_final] = ACTIONS(5825),
    [anon_sym_override] = ACTIONS(5825),
    [anon_sym_template] = ACTIONS(5825),
    [anon_sym_GT2] = ACTIONS(5827),
    [anon_sym_operator] = ACTIONS(5825),
    [anon_sym_try] = ACTIONS(5825),
    [anon_sym_requires] = ACTIONS(5825),
    [anon_sym___launch_bounds__] = ACTIONS(5825),
  },
  [STATE(2266)] = {
    [sym_identifier] = ACTIONS(5829),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5831),
    [anon_sym_COMMA] = ACTIONS(5831),
    [anon_sym_RPAREN] = ACTIONS(5831),
    [anon_sym_LPAREN2] = ACTIONS(5831),
    [anon_sym_TILDE] = ACTIONS(5831),
    [anon_sym_STAR] = ACTIONS(5831),
    [anon_sym_AMP_AMP] = ACTIONS(5831),
    [anon_sym_AMP] = ACTIONS(5829),
    [anon_sym_SEMI] = ACTIONS(5831),
    [anon_sym___extension__] = ACTIONS(5829),
    [anon_sym___device__] = ACTIONS(5829),
    [anon_sym___host__] = ACTIONS(5829),
    [anon_sym___global__] = ACTIONS(5829),
    [anon_sym___forceinline__] = ACTIONS(5829),
    [anon_sym___noinline__] = ACTIONS(5829),
    [anon_sym_virtual] = ACTIONS(5829),
    [anon_sym_extern] = ACTIONS(5829),
    [anon_sym___attribute__] = ACTIONS(5829),
    [anon_sym___attribute] = ACTIONS(5829),
    [anon_sym_COLON_COLON] = ACTIONS(5831),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5831),
    [anon_sym___declspec] = ACTIONS(5829),
    [anon_sym___based] = ACTIONS(5829),
    [anon_sym___cdecl] = ACTIONS(5829),
    [anon_sym___clrcall] = ACTIONS(5829),
    [anon_sym___stdcall] = ACTIONS(5829),
    [anon_sym___fastcall] = ACTIONS(5829),
    [anon_sym___thiscall] = ACTIONS(5829),
    [anon_sym___vectorcall] = ACTIONS(5829),
    [anon_sym_LBRACE] = ACTIONS(5831),
    [anon_sym_LBRACK] = ACTIONS(5829),
    [anon_sym_static] = ACTIONS(5829),
    [anon_sym_EQ] = ACTIONS(5831),
    [anon_sym_register] = ACTIONS(5829),
    [anon_sym_inline] = ACTIONS(5829),
    [anon_sym___inline] = ACTIONS(5829),
    [anon_sym___inline__] = ACTIONS(5829),
    [anon_sym___forceinline] = ACTIONS(5829),
    [anon_sym_thread_local] = ACTIONS(5829),
    [anon_sym___thread] = ACTIONS(5829),
    [anon_sym_const] = ACTIONS(5829),
    [anon_sym_constexpr] = ACTIONS(5829),
    [anon_sym_volatile] = ACTIONS(5829),
    [anon_sym_restrict] = ACTIONS(5829),
    [anon_sym___restrict__] = ACTIONS(5829),
    [anon_sym__Atomic] = ACTIONS(5829),
    [anon_sym__Noreturn] = ACTIONS(5829),
    [anon_sym_noreturn] = ACTIONS(5829),
    [anon_sym__Nonnull] = ACTIONS(5829),
    [anon_sym_mutable] = ACTIONS(5829),
    [anon_sym_constinit] = ACTIONS(5829),
    [anon_sym_consteval] = ACTIONS(5829),
    [anon_sym___shared__] = ACTIONS(5829),
    [anon_sym___local__] = ACTIONS(5829),
    [anon_sym___constant__] = ACTIONS(5829),
    [anon_sym___managed__] = ACTIONS(5829),
    [anon_sym___grid_constant__] = ACTIONS(5829),
    [anon_sym_alignas] = ACTIONS(5829),
    [anon_sym__Alignas] = ACTIONS(5829),
    [anon_sym_asm] = ACTIONS(5829),
    [anon_sym___asm__] = ACTIONS(5829),
    [anon_sym___asm] = ACTIONS(5829),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5829),
    [anon_sym_decltype] = ACTIONS(5829),
    [anon_sym_final] = ACTIONS(5829),
    [anon_sym_override] = ACTIONS(5829),
    [anon_sym_template] = ACTIONS(5829),
    [anon_sym_GT2] = ACTIONS(5831),
    [anon_sym_operator] = ACTIONS(5829),
    [anon_sym_try] = ACTIONS(5829),
    [anon_sym_requires] = ACTIONS(5829),
    [anon_sym___launch_bounds__] = ACTIONS(5829),
  },
  [STATE(2267)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6036),
    [anon_sym_COMMA] = ACTIONS(6036),
    [anon_sym_RPAREN] = ACTIONS(6036),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6036),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_EQ] = ACTIONS(6036),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_GT2] = ACTIONS(6036),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2268)] = {
    [sym_identifier] = ACTIONS(5754),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5756),
    [anon_sym_COMMA] = ACTIONS(5756),
    [anon_sym_RPAREN] = ACTIONS(5756),
    [anon_sym_LPAREN2] = ACTIONS(5756),
    [anon_sym_TILDE] = ACTIONS(5756),
    [anon_sym_STAR] = ACTIONS(5756),
    [anon_sym_AMP_AMP] = ACTIONS(5756),
    [anon_sym_AMP] = ACTIONS(5754),
    [anon_sym_SEMI] = ACTIONS(5756),
    [anon_sym___extension__] = ACTIONS(5754),
    [anon_sym___device__] = ACTIONS(5754),
    [anon_sym___host__] = ACTIONS(5754),
    [anon_sym___global__] = ACTIONS(5754),
    [anon_sym___forceinline__] = ACTIONS(5754),
    [anon_sym___noinline__] = ACTIONS(5754),
    [anon_sym_virtual] = ACTIONS(5754),
    [anon_sym_extern] = ACTIONS(5754),
    [anon_sym___attribute__] = ACTIONS(5754),
    [anon_sym___attribute] = ACTIONS(5754),
    [anon_sym_COLON_COLON] = ACTIONS(5756),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5756),
    [anon_sym___declspec] = ACTIONS(5754),
    [anon_sym___based] = ACTIONS(5754),
    [anon_sym___cdecl] = ACTIONS(5754),
    [anon_sym___clrcall] = ACTIONS(5754),
    [anon_sym___stdcall] = ACTIONS(5754),
    [anon_sym___fastcall] = ACTIONS(5754),
    [anon_sym___thiscall] = ACTIONS(5754),
    [anon_sym___vectorcall] = ACTIONS(5754),
    [anon_sym_LBRACE] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5754),
    [anon_sym_static] = ACTIONS(5754),
    [anon_sym_EQ] = ACTIONS(5756),
    [anon_sym_register] = ACTIONS(5754),
    [anon_sym_inline] = ACTIONS(5754),
    [anon_sym___inline] = ACTIONS(5754),
    [anon_sym___inline__] = ACTIONS(5754),
    [anon_sym___forceinline] = ACTIONS(5754),
    [anon_sym_thread_local] = ACTIONS(5754),
    [anon_sym___thread] = ACTIONS(5754),
    [anon_sym_const] = ACTIONS(5754),
    [anon_sym_constexpr] = ACTIONS(5754),
    [anon_sym_volatile] = ACTIONS(5754),
    [anon_sym_restrict] = ACTIONS(5754),
    [anon_sym___restrict__] = ACTIONS(5754),
    [anon_sym__Atomic] = ACTIONS(5754),
    [anon_sym__Noreturn] = ACTIONS(5754),
    [anon_sym_noreturn] = ACTIONS(5754),
    [anon_sym__Nonnull] = ACTIONS(5754),
    [anon_sym_mutable] = ACTIONS(5754),
    [anon_sym_constinit] = ACTIONS(5754),
    [anon_sym_consteval] = ACTIONS(5754),
    [anon_sym___shared__] = ACTIONS(5754),
    [anon_sym___local__] = ACTIONS(5754),
    [anon_sym___constant__] = ACTIONS(5754),
    [anon_sym___managed__] = ACTIONS(5754),
    [anon_sym___grid_constant__] = ACTIONS(5754),
    [anon_sym_alignas] = ACTIONS(5754),
    [anon_sym__Alignas] = ACTIONS(5754),
    [anon_sym_asm] = ACTIONS(5754),
    [anon_sym___asm__] = ACTIONS(5754),
    [anon_sym___asm] = ACTIONS(5754),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5754),
    [anon_sym_decltype] = ACTIONS(5754),
    [anon_sym_final] = ACTIONS(5754),
    [anon_sym_override] = ACTIONS(5754),
    [anon_sym_template] = ACTIONS(5754),
    [anon_sym_GT2] = ACTIONS(5756),
    [anon_sym_operator] = ACTIONS(5754),
    [anon_sym_try] = ACTIONS(5754),
    [anon_sym_requires] = ACTIONS(5754),
    [anon_sym___launch_bounds__] = ACTIONS(5754),
  },
  [STATE(2269)] = {
    [sym_identifier] = ACTIONS(5778),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5780),
    [anon_sym_COMMA] = ACTIONS(5780),
    [anon_sym_RPAREN] = ACTIONS(5780),
    [anon_sym_LPAREN2] = ACTIONS(5780),
    [anon_sym_TILDE] = ACTIONS(5780),
    [anon_sym_STAR] = ACTIONS(5780),
    [anon_sym_AMP_AMP] = ACTIONS(5780),
    [anon_sym_AMP] = ACTIONS(5778),
    [anon_sym_SEMI] = ACTIONS(5780),
    [anon_sym___extension__] = ACTIONS(5778),
    [anon_sym___device__] = ACTIONS(5778),
    [anon_sym___host__] = ACTIONS(5778),
    [anon_sym___global__] = ACTIONS(5778),
    [anon_sym___forceinline__] = ACTIONS(5778),
    [anon_sym___noinline__] = ACTIONS(5778),
    [anon_sym_virtual] = ACTIONS(5778),
    [anon_sym_extern] = ACTIONS(5778),
    [anon_sym___attribute__] = ACTIONS(5778),
    [anon_sym___attribute] = ACTIONS(5778),
    [anon_sym_COLON_COLON] = ACTIONS(5780),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5780),
    [anon_sym___declspec] = ACTIONS(5778),
    [anon_sym___based] = ACTIONS(5778),
    [anon_sym___cdecl] = ACTIONS(5778),
    [anon_sym___clrcall] = ACTIONS(5778),
    [anon_sym___stdcall] = ACTIONS(5778),
    [anon_sym___fastcall] = ACTIONS(5778),
    [anon_sym___thiscall] = ACTIONS(5778),
    [anon_sym___vectorcall] = ACTIONS(5778),
    [anon_sym_LBRACE] = ACTIONS(5780),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_static] = ACTIONS(5778),
    [anon_sym_EQ] = ACTIONS(5780),
    [anon_sym_register] = ACTIONS(5778),
    [anon_sym_inline] = ACTIONS(5778),
    [anon_sym___inline] = ACTIONS(5778),
    [anon_sym___inline__] = ACTIONS(5778),
    [anon_sym___forceinline] = ACTIONS(5778),
    [anon_sym_thread_local] = ACTIONS(5778),
    [anon_sym___thread] = ACTIONS(5778),
    [anon_sym_const] = ACTIONS(5778),
    [anon_sym_constexpr] = ACTIONS(5778),
    [anon_sym_volatile] = ACTIONS(5778),
    [anon_sym_restrict] = ACTIONS(5778),
    [anon_sym___restrict__] = ACTIONS(5778),
    [anon_sym__Atomic] = ACTIONS(5778),
    [anon_sym__Noreturn] = ACTIONS(5778),
    [anon_sym_noreturn] = ACTIONS(5778),
    [anon_sym__Nonnull] = ACTIONS(5778),
    [anon_sym_mutable] = ACTIONS(5778),
    [anon_sym_constinit] = ACTIONS(5778),
    [anon_sym_consteval] = ACTIONS(5778),
    [anon_sym___shared__] = ACTIONS(5778),
    [anon_sym___local__] = ACTIONS(5778),
    [anon_sym___constant__] = ACTIONS(5778),
    [anon_sym___managed__] = ACTIONS(5778),
    [anon_sym___grid_constant__] = ACTIONS(5778),
    [anon_sym_alignas] = ACTIONS(5778),
    [anon_sym__Alignas] = ACTIONS(5778),
    [anon_sym_asm] = ACTIONS(5778),
    [anon_sym___asm__] = ACTIONS(5778),
    [anon_sym___asm] = ACTIONS(5778),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5778),
    [anon_sym_decltype] = ACTIONS(5778),
    [anon_sym_final] = ACTIONS(5778),
    [anon_sym_override] = ACTIONS(5778),
    [anon_sym_template] = ACTIONS(5778),
    [anon_sym_GT2] = ACTIONS(5780),
    [anon_sym_operator] = ACTIONS(5778),
    [anon_sym_try] = ACTIONS(5778),
    [anon_sym_requires] = ACTIONS(5778),
    [anon_sym___launch_bounds__] = ACTIONS(5778),
  },
  [STATE(2270)] = {
    [sym_identifier] = ACTIONS(5813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5815),
    [anon_sym_COMMA] = ACTIONS(5815),
    [anon_sym_RPAREN] = ACTIONS(5815),
    [anon_sym_LPAREN2] = ACTIONS(5815),
    [anon_sym_TILDE] = ACTIONS(5815),
    [anon_sym_STAR] = ACTIONS(5815),
    [anon_sym_AMP_AMP] = ACTIONS(5815),
    [anon_sym_AMP] = ACTIONS(5813),
    [anon_sym_SEMI] = ACTIONS(5815),
    [anon_sym___extension__] = ACTIONS(5813),
    [anon_sym___device__] = ACTIONS(5813),
    [anon_sym___host__] = ACTIONS(5813),
    [anon_sym___global__] = ACTIONS(5813),
    [anon_sym___forceinline__] = ACTIONS(5813),
    [anon_sym___noinline__] = ACTIONS(5813),
    [anon_sym_virtual] = ACTIONS(5813),
    [anon_sym_extern] = ACTIONS(5813),
    [anon_sym___attribute__] = ACTIONS(5813),
    [anon_sym___attribute] = ACTIONS(5813),
    [anon_sym_COLON_COLON] = ACTIONS(5815),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5815),
    [anon_sym___declspec] = ACTIONS(5813),
    [anon_sym___based] = ACTIONS(5813),
    [anon_sym___cdecl] = ACTIONS(5813),
    [anon_sym___clrcall] = ACTIONS(5813),
    [anon_sym___stdcall] = ACTIONS(5813),
    [anon_sym___fastcall] = ACTIONS(5813),
    [anon_sym___thiscall] = ACTIONS(5813),
    [anon_sym___vectorcall] = ACTIONS(5813),
    [anon_sym_LBRACE] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(5813),
    [anon_sym_static] = ACTIONS(5813),
    [anon_sym_EQ] = ACTIONS(5815),
    [anon_sym_register] = ACTIONS(5813),
    [anon_sym_inline] = ACTIONS(5813),
    [anon_sym___inline] = ACTIONS(5813),
    [anon_sym___inline__] = ACTIONS(5813),
    [anon_sym___forceinline] = ACTIONS(5813),
    [anon_sym_thread_local] = ACTIONS(5813),
    [anon_sym___thread] = ACTIONS(5813),
    [anon_sym_const] = ACTIONS(5813),
    [anon_sym_constexpr] = ACTIONS(5813),
    [anon_sym_volatile] = ACTIONS(5813),
    [anon_sym_restrict] = ACTIONS(5813),
    [anon_sym___restrict__] = ACTIONS(5813),
    [anon_sym__Atomic] = ACTIONS(5813),
    [anon_sym__Noreturn] = ACTIONS(5813),
    [anon_sym_noreturn] = ACTIONS(5813),
    [anon_sym__Nonnull] = ACTIONS(5813),
    [anon_sym_mutable] = ACTIONS(5813),
    [anon_sym_constinit] = ACTIONS(5813),
    [anon_sym_consteval] = ACTIONS(5813),
    [anon_sym___shared__] = ACTIONS(5813),
    [anon_sym___local__] = ACTIONS(5813),
    [anon_sym___constant__] = ACTIONS(5813),
    [anon_sym___managed__] = ACTIONS(5813),
    [anon_sym___grid_constant__] = ACTIONS(5813),
    [anon_sym_alignas] = ACTIONS(5813),
    [anon_sym__Alignas] = ACTIONS(5813),
    [anon_sym_asm] = ACTIONS(5813),
    [anon_sym___asm__] = ACTIONS(5813),
    [anon_sym___asm] = ACTIONS(5813),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5813),
    [anon_sym_decltype] = ACTIONS(5813),
    [anon_sym_final] = ACTIONS(5813),
    [anon_sym_override] = ACTIONS(5813),
    [anon_sym_template] = ACTIONS(5813),
    [anon_sym_GT2] = ACTIONS(5815),
    [anon_sym_operator] = ACTIONS(5813),
    [anon_sym_try] = ACTIONS(5813),
    [anon_sym_requires] = ACTIONS(5813),
    [anon_sym___launch_bounds__] = ACTIONS(5813),
  },
  [STATE(2271)] = {
    [sym_type_qualifier] = STATE(2244),
    [sym_alignas_qualifier] = STATE(2279),
    [aux_sym__type_definition_type_repeat1] = STATE(2244),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2334),
    [sym_identifier] = ACTIONS(6153),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5158),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_DASH] = ACTIONS(5160),
    [anon_sym_PLUS] = ACTIONS(5160),
    [anon_sym_STAR] = ACTIONS(5158),
    [anon_sym_SLASH] = ACTIONS(5160),
    [anon_sym_PERCENT] = ACTIONS(5158),
    [anon_sym_PIPE_PIPE] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_PIPE] = ACTIONS(5160),
    [anon_sym_CARET] = ACTIONS(5158),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_EQ_EQ] = ACTIONS(5158),
    [anon_sym_BANG_EQ] = ACTIONS(5158),
    [anon_sym_GT] = ACTIONS(5160),
    [anon_sym_GT_EQ] = ACTIONS(5160),
    [anon_sym_LT_EQ] = ACTIONS(5160),
    [anon_sym_LT] = ACTIONS(5160),
    [anon_sym_LT_LT] = ACTIONS(5160),
    [anon_sym_GT_GT] = ACTIONS(5160),
    [anon_sym___extension__] = ACTIONS(6107),
    [anon_sym___global__] = ACTIONS(6107),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(6155),
    [anon_sym_unsigned] = ACTIONS(6155),
    [anon_sym_long] = ACTIONS(6155),
    [anon_sym_short] = ACTIONS(6155),
    [anon_sym_LBRACK] = ACTIONS(5158),
    [anon_sym_const] = ACTIONS(6107),
    [anon_sym_constexpr] = ACTIONS(6107),
    [anon_sym_volatile] = ACTIONS(6107),
    [anon_sym_restrict] = ACTIONS(6107),
    [anon_sym___restrict__] = ACTIONS(6107),
    [anon_sym__Atomic] = ACTIONS(6107),
    [anon_sym__Noreturn] = ACTIONS(6107),
    [anon_sym_noreturn] = ACTIONS(6107),
    [anon_sym__Nonnull] = ACTIONS(6107),
    [anon_sym_mutable] = ACTIONS(6107),
    [anon_sym_constinit] = ACTIONS(6107),
    [anon_sym_consteval] = ACTIONS(6107),
    [anon_sym___shared__] = ACTIONS(6107),
    [anon_sym___local__] = ACTIONS(6107),
    [anon_sym___constant__] = ACTIONS(6107),
    [anon_sym___managed__] = ACTIONS(6107),
    [anon_sym___grid_constant__] = ACTIONS(6107),
    [anon_sym_alignas] = ACTIONS(6111),
    [anon_sym__Alignas] = ACTIONS(6111),
    [sym_primitive_type] = ACTIONS(6157),
    [anon_sym_QMARK] = ACTIONS(5158),
    [anon_sym_LT_EQ_GT] = ACTIONS(5158),
    [anon_sym_or] = ACTIONS(5160),
    [anon_sym_and] = ACTIONS(5160),
    [anon_sym_bitor] = ACTIONS(5160),
    [anon_sym_xor] = ACTIONS(5160),
    [anon_sym_bitand] = ACTIONS(5160),
    [anon_sym_not_eq] = ACTIONS(5160),
    [anon_sym_DASH_DASH] = ACTIONS(5158),
    [anon_sym_PLUS_PLUS] = ACTIONS(5158),
    [anon_sym_DOT] = ACTIONS(5160),
    [anon_sym_DOT_STAR] = ACTIONS(5158),
    [anon_sym_DASH_GT] = ACTIONS(5158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [anon_sym_GT2] = ACTIONS(5158),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5158),
  },
  [STATE(2272)] = {
    [sym_identifier] = ACTIONS(5786),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5788),
    [anon_sym_COMMA] = ACTIONS(5788),
    [anon_sym_RPAREN] = ACTIONS(5788),
    [anon_sym_LPAREN2] = ACTIONS(5788),
    [anon_sym_TILDE] = ACTIONS(5788),
    [anon_sym_STAR] = ACTIONS(5788),
    [anon_sym_AMP_AMP] = ACTIONS(5788),
    [anon_sym_AMP] = ACTIONS(5786),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym___extension__] = ACTIONS(5786),
    [anon_sym___device__] = ACTIONS(5786),
    [anon_sym___host__] = ACTIONS(5786),
    [anon_sym___global__] = ACTIONS(5786),
    [anon_sym___forceinline__] = ACTIONS(5786),
    [anon_sym___noinline__] = ACTIONS(5786),
    [anon_sym_virtual] = ACTIONS(5786),
    [anon_sym_extern] = ACTIONS(5786),
    [anon_sym___attribute__] = ACTIONS(5786),
    [anon_sym___attribute] = ACTIONS(5786),
    [anon_sym_COLON_COLON] = ACTIONS(5788),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5788),
    [anon_sym___declspec] = ACTIONS(5786),
    [anon_sym___based] = ACTIONS(5786),
    [anon_sym___cdecl] = ACTIONS(5786),
    [anon_sym___clrcall] = ACTIONS(5786),
    [anon_sym___stdcall] = ACTIONS(5786),
    [anon_sym___fastcall] = ACTIONS(5786),
    [anon_sym___thiscall] = ACTIONS(5786),
    [anon_sym___vectorcall] = ACTIONS(5786),
    [anon_sym_LBRACE] = ACTIONS(5788),
    [anon_sym_LBRACK] = ACTIONS(5786),
    [anon_sym_static] = ACTIONS(5786),
    [anon_sym_EQ] = ACTIONS(5788),
    [anon_sym_register] = ACTIONS(5786),
    [anon_sym_inline] = ACTIONS(5786),
    [anon_sym___inline] = ACTIONS(5786),
    [anon_sym___inline__] = ACTIONS(5786),
    [anon_sym___forceinline] = ACTIONS(5786),
    [anon_sym_thread_local] = ACTIONS(5786),
    [anon_sym___thread] = ACTIONS(5786),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_constexpr] = ACTIONS(5786),
    [anon_sym_volatile] = ACTIONS(5786),
    [anon_sym_restrict] = ACTIONS(5786),
    [anon_sym___restrict__] = ACTIONS(5786),
    [anon_sym__Atomic] = ACTIONS(5786),
    [anon_sym__Noreturn] = ACTIONS(5786),
    [anon_sym_noreturn] = ACTIONS(5786),
    [anon_sym__Nonnull] = ACTIONS(5786),
    [anon_sym_mutable] = ACTIONS(5786),
    [anon_sym_constinit] = ACTIONS(5786),
    [anon_sym_consteval] = ACTIONS(5786),
    [anon_sym___shared__] = ACTIONS(5786),
    [anon_sym___local__] = ACTIONS(5786),
    [anon_sym___constant__] = ACTIONS(5786),
    [anon_sym___managed__] = ACTIONS(5786),
    [anon_sym___grid_constant__] = ACTIONS(5786),
    [anon_sym_alignas] = ACTIONS(5786),
    [anon_sym__Alignas] = ACTIONS(5786),
    [anon_sym_asm] = ACTIONS(5786),
    [anon_sym___asm__] = ACTIONS(5786),
    [anon_sym___asm] = ACTIONS(5786),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5786),
    [anon_sym_decltype] = ACTIONS(5786),
    [anon_sym_final] = ACTIONS(5786),
    [anon_sym_override] = ACTIONS(5786),
    [anon_sym_template] = ACTIONS(5786),
    [anon_sym_GT2] = ACTIONS(5788),
    [anon_sym_operator] = ACTIONS(5786),
    [anon_sym_try] = ACTIONS(5786),
    [anon_sym_requires] = ACTIONS(5786),
    [anon_sym___launch_bounds__] = ACTIONS(5786),
  },
  [STATE(2273)] = {
    [sym_identifier] = ACTIONS(6159),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6161),
    [anon_sym_COMMA] = ACTIONS(6161),
    [anon_sym_RPAREN] = ACTIONS(6161),
    [aux_sym_preproc_if_token2] = ACTIONS(6161),
    [aux_sym_preproc_else_token1] = ACTIONS(6161),
    [aux_sym_preproc_elif_token1] = ACTIONS(6159),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6161),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6161),
    [anon_sym_LPAREN2] = ACTIONS(6161),
    [anon_sym_DASH] = ACTIONS(6159),
    [anon_sym_PLUS] = ACTIONS(6159),
    [anon_sym_STAR] = ACTIONS(6159),
    [anon_sym_SLASH] = ACTIONS(6159),
    [anon_sym_PERCENT] = ACTIONS(6159),
    [anon_sym_PIPE_PIPE] = ACTIONS(6161),
    [anon_sym_AMP_AMP] = ACTIONS(6161),
    [anon_sym_PIPE] = ACTIONS(6159),
    [anon_sym_CARET] = ACTIONS(6159),
    [anon_sym_AMP] = ACTIONS(6159),
    [anon_sym_EQ_EQ] = ACTIONS(6161),
    [anon_sym_BANG_EQ] = ACTIONS(6161),
    [anon_sym_GT] = ACTIONS(6159),
    [anon_sym_GT_EQ] = ACTIONS(6161),
    [anon_sym_LT_EQ] = ACTIONS(6159),
    [anon_sym_LT] = ACTIONS(6159),
    [anon_sym_LT_LT] = ACTIONS(6159),
    [anon_sym_GT_GT] = ACTIONS(6159),
    [anon_sym_SEMI] = ACTIONS(6161),
    [anon_sym_RBRACE] = ACTIONS(6161),
    [anon_sym_LBRACK] = ACTIONS(6161),
    [anon_sym_RBRACK] = ACTIONS(6161),
    [anon_sym_EQ] = ACTIONS(6159),
    [anon_sym_COLON] = ACTIONS(6161),
    [anon_sym_QMARK] = ACTIONS(6161),
    [anon_sym_STAR_EQ] = ACTIONS(6161),
    [anon_sym_SLASH_EQ] = ACTIONS(6161),
    [anon_sym_PERCENT_EQ] = ACTIONS(6161),
    [anon_sym_PLUS_EQ] = ACTIONS(6161),
    [anon_sym_DASH_EQ] = ACTIONS(6161),
    [anon_sym_LT_LT_EQ] = ACTIONS(6161),
    [anon_sym_GT_GT_EQ] = ACTIONS(6161),
    [anon_sym_AMP_EQ] = ACTIONS(6161),
    [anon_sym_CARET_EQ] = ACTIONS(6161),
    [anon_sym_PIPE_EQ] = ACTIONS(6161),
    [anon_sym_and_eq] = ACTIONS(6159),
    [anon_sym_or_eq] = ACTIONS(6159),
    [anon_sym_xor_eq] = ACTIONS(6159),
    [anon_sym_LT_EQ_GT] = ACTIONS(6161),
    [anon_sym_or] = ACTIONS(6159),
    [anon_sym_and] = ACTIONS(6159),
    [anon_sym_bitor] = ACTIONS(6159),
    [anon_sym_xor] = ACTIONS(6159),
    [anon_sym_bitand] = ACTIONS(6159),
    [anon_sym_not_eq] = ACTIONS(6159),
    [anon_sym_DASH_DASH] = ACTIONS(6161),
    [anon_sym_PLUS_PLUS] = ACTIONS(6161),
    [anon_sym_DOT] = ACTIONS(6159),
    [anon_sym_DOT_STAR] = ACTIONS(6161),
    [anon_sym_DASH_GT] = ACTIONS(6161),
    [anon_sym_L_DQUOTE] = ACTIONS(6161),
    [anon_sym_u_DQUOTE] = ACTIONS(6161),
    [anon_sym_U_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8_DQUOTE] = ACTIONS(6161),
    [anon_sym_DQUOTE] = ACTIONS(6161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6161),
    [anon_sym_LR_DQUOTE] = ACTIONS(6161),
    [anon_sym_uR_DQUOTE] = ACTIONS(6161),
    [anon_sym_UR_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6161),
    [sym_literal_suffix] = ACTIONS(6159),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6161),
  },
  [STATE(2274)] = {
    [sym_identifier] = ACTIONS(6163),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6165),
    [anon_sym_COMMA] = ACTIONS(6165),
    [anon_sym_RPAREN] = ACTIONS(6165),
    [aux_sym_preproc_if_token2] = ACTIONS(6165),
    [aux_sym_preproc_else_token1] = ACTIONS(6165),
    [aux_sym_preproc_elif_token1] = ACTIONS(6163),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6165),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6165),
    [anon_sym_LPAREN2] = ACTIONS(6165),
    [anon_sym_DASH] = ACTIONS(6163),
    [anon_sym_PLUS] = ACTIONS(6163),
    [anon_sym_STAR] = ACTIONS(6163),
    [anon_sym_SLASH] = ACTIONS(6163),
    [anon_sym_PERCENT] = ACTIONS(6163),
    [anon_sym_PIPE_PIPE] = ACTIONS(6165),
    [anon_sym_AMP_AMP] = ACTIONS(6165),
    [anon_sym_PIPE] = ACTIONS(6163),
    [anon_sym_CARET] = ACTIONS(6163),
    [anon_sym_AMP] = ACTIONS(6163),
    [anon_sym_EQ_EQ] = ACTIONS(6165),
    [anon_sym_BANG_EQ] = ACTIONS(6165),
    [anon_sym_GT] = ACTIONS(6163),
    [anon_sym_GT_EQ] = ACTIONS(6165),
    [anon_sym_LT_EQ] = ACTIONS(6163),
    [anon_sym_LT] = ACTIONS(6163),
    [anon_sym_LT_LT] = ACTIONS(6163),
    [anon_sym_GT_GT] = ACTIONS(6163),
    [anon_sym_SEMI] = ACTIONS(6165),
    [anon_sym_RBRACE] = ACTIONS(6165),
    [anon_sym_LBRACK] = ACTIONS(6165),
    [anon_sym_RBRACK] = ACTIONS(6165),
    [anon_sym_EQ] = ACTIONS(6163),
    [anon_sym_COLON] = ACTIONS(6165),
    [anon_sym_QMARK] = ACTIONS(6165),
    [anon_sym_STAR_EQ] = ACTIONS(6165),
    [anon_sym_SLASH_EQ] = ACTIONS(6165),
    [anon_sym_PERCENT_EQ] = ACTIONS(6165),
    [anon_sym_PLUS_EQ] = ACTIONS(6165),
    [anon_sym_DASH_EQ] = ACTIONS(6165),
    [anon_sym_LT_LT_EQ] = ACTIONS(6165),
    [anon_sym_GT_GT_EQ] = ACTIONS(6165),
    [anon_sym_AMP_EQ] = ACTIONS(6165),
    [anon_sym_CARET_EQ] = ACTIONS(6165),
    [anon_sym_PIPE_EQ] = ACTIONS(6165),
    [anon_sym_and_eq] = ACTIONS(6163),
    [anon_sym_or_eq] = ACTIONS(6163),
    [anon_sym_xor_eq] = ACTIONS(6163),
    [anon_sym_LT_EQ_GT] = ACTIONS(6165),
    [anon_sym_or] = ACTIONS(6163),
    [anon_sym_and] = ACTIONS(6163),
    [anon_sym_bitor] = ACTIONS(6163),
    [anon_sym_xor] = ACTIONS(6163),
    [anon_sym_bitand] = ACTIONS(6163),
    [anon_sym_not_eq] = ACTIONS(6163),
    [anon_sym_DASH_DASH] = ACTIONS(6165),
    [anon_sym_PLUS_PLUS] = ACTIONS(6165),
    [anon_sym_DOT] = ACTIONS(6163),
    [anon_sym_DOT_STAR] = ACTIONS(6165),
    [anon_sym_DASH_GT] = ACTIONS(6165),
    [anon_sym_L_DQUOTE] = ACTIONS(6165),
    [anon_sym_u_DQUOTE] = ACTIONS(6165),
    [anon_sym_U_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8_DQUOTE] = ACTIONS(6165),
    [anon_sym_DQUOTE] = ACTIONS(6165),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6165),
    [anon_sym_LR_DQUOTE] = ACTIONS(6165),
    [anon_sym_uR_DQUOTE] = ACTIONS(6165),
    [anon_sym_UR_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6165),
    [sym_literal_suffix] = ACTIONS(6163),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6165),
  },
  [STATE(2275)] = {
    [sym_identifier] = ACTIONS(6167),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6169),
    [anon_sym_COMMA] = ACTIONS(6169),
    [anon_sym_RPAREN] = ACTIONS(6169),
    [aux_sym_preproc_if_token2] = ACTIONS(6169),
    [aux_sym_preproc_else_token1] = ACTIONS(6169),
    [aux_sym_preproc_elif_token1] = ACTIONS(6167),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6169),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6169),
    [anon_sym_LPAREN2] = ACTIONS(6169),
    [anon_sym_DASH] = ACTIONS(6167),
    [anon_sym_PLUS] = ACTIONS(6167),
    [anon_sym_STAR] = ACTIONS(6167),
    [anon_sym_SLASH] = ACTIONS(6167),
    [anon_sym_PERCENT] = ACTIONS(6167),
    [anon_sym_PIPE_PIPE] = ACTIONS(6169),
    [anon_sym_AMP_AMP] = ACTIONS(6169),
    [anon_sym_PIPE] = ACTIONS(6167),
    [anon_sym_CARET] = ACTIONS(6167),
    [anon_sym_AMP] = ACTIONS(6167),
    [anon_sym_EQ_EQ] = ACTIONS(6169),
    [anon_sym_BANG_EQ] = ACTIONS(6169),
    [anon_sym_GT] = ACTIONS(6167),
    [anon_sym_GT_EQ] = ACTIONS(6169),
    [anon_sym_LT_EQ] = ACTIONS(6167),
    [anon_sym_LT] = ACTIONS(6167),
    [anon_sym_LT_LT] = ACTIONS(6167),
    [anon_sym_GT_GT] = ACTIONS(6167),
    [anon_sym_SEMI] = ACTIONS(6169),
    [anon_sym_RBRACE] = ACTIONS(6169),
    [anon_sym_LBRACK] = ACTIONS(6169),
    [anon_sym_RBRACK] = ACTIONS(6169),
    [anon_sym_EQ] = ACTIONS(6167),
    [anon_sym_COLON] = ACTIONS(6169),
    [anon_sym_QMARK] = ACTIONS(6169),
    [anon_sym_STAR_EQ] = ACTIONS(6169),
    [anon_sym_SLASH_EQ] = ACTIONS(6169),
    [anon_sym_PERCENT_EQ] = ACTIONS(6169),
    [anon_sym_PLUS_EQ] = ACTIONS(6169),
    [anon_sym_DASH_EQ] = ACTIONS(6169),
    [anon_sym_LT_LT_EQ] = ACTIONS(6169),
    [anon_sym_GT_GT_EQ] = ACTIONS(6169),
    [anon_sym_AMP_EQ] = ACTIONS(6169),
    [anon_sym_CARET_EQ] = ACTIONS(6169),
    [anon_sym_PIPE_EQ] = ACTIONS(6169),
    [anon_sym_and_eq] = ACTIONS(6167),
    [anon_sym_or_eq] = ACTIONS(6167),
    [anon_sym_xor_eq] = ACTIONS(6167),
    [anon_sym_LT_EQ_GT] = ACTIONS(6169),
    [anon_sym_or] = ACTIONS(6167),
    [anon_sym_and] = ACTIONS(6167),
    [anon_sym_bitor] = ACTIONS(6167),
    [anon_sym_xor] = ACTIONS(6167),
    [anon_sym_bitand] = ACTIONS(6167),
    [anon_sym_not_eq] = ACTIONS(6167),
    [anon_sym_DASH_DASH] = ACTIONS(6169),
    [anon_sym_PLUS_PLUS] = ACTIONS(6169),
    [anon_sym_DOT] = ACTIONS(6167),
    [anon_sym_DOT_STAR] = ACTIONS(6169),
    [anon_sym_DASH_GT] = ACTIONS(6169),
    [anon_sym_L_DQUOTE] = ACTIONS(6169),
    [anon_sym_u_DQUOTE] = ACTIONS(6169),
    [anon_sym_U_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8_DQUOTE] = ACTIONS(6169),
    [anon_sym_DQUOTE] = ACTIONS(6169),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6169),
    [anon_sym_LR_DQUOTE] = ACTIONS(6169),
    [anon_sym_uR_DQUOTE] = ACTIONS(6169),
    [anon_sym_UR_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6169),
    [sym_literal_suffix] = ACTIONS(6167),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6169),
  },
  [STATE(2276)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [sym_identifier] = ACTIONS(5351),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_RPAREN] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_TILDE] = ACTIONS(5354),
    [anon_sym_STAR] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_SEMI] = ACTIONS(5354),
    [anon_sym___extension__] = ACTIONS(5351),
    [anon_sym___device__] = ACTIONS(5351),
    [anon_sym___host__] = ACTIONS(5351),
    [anon_sym___global__] = ACTIONS(5351),
    [anon_sym___forceinline__] = ACTIONS(5351),
    [anon_sym___noinline__] = ACTIONS(5351),
    [anon_sym_virtual] = ACTIONS(5351),
    [anon_sym_extern] = ACTIONS(5351),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_COLON_COLON] = ACTIONS(5354),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5354),
    [anon_sym___declspec] = ACTIONS(5351),
    [anon_sym___based] = ACTIONS(5351),
    [anon_sym___cdecl] = ACTIONS(5351),
    [anon_sym___clrcall] = ACTIONS(5351),
    [anon_sym___stdcall] = ACTIONS(5351),
    [anon_sym___fastcall] = ACTIONS(5351),
    [anon_sym___thiscall] = ACTIONS(5351),
    [anon_sym___vectorcall] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5650),
    [anon_sym_unsigned] = ACTIONS(5650),
    [anon_sym_long] = ACTIONS(5650),
    [anon_sym_short] = ACTIONS(5650),
    [anon_sym_LBRACK] = ACTIONS(5351),
    [anon_sym_static] = ACTIONS(5351),
    [anon_sym_EQ] = ACTIONS(5354),
    [anon_sym_register] = ACTIONS(5351),
    [anon_sym_inline] = ACTIONS(5351),
    [anon_sym___inline] = ACTIONS(5351),
    [anon_sym___inline__] = ACTIONS(5351),
    [anon_sym___forceinline] = ACTIONS(5351),
    [anon_sym_thread_local] = ACTIONS(5351),
    [anon_sym___thread] = ACTIONS(5351),
    [anon_sym_const] = ACTIONS(5351),
    [anon_sym_constexpr] = ACTIONS(5351),
    [anon_sym_volatile] = ACTIONS(5351),
    [anon_sym_restrict] = ACTIONS(5351),
    [anon_sym___restrict__] = ACTIONS(5351),
    [anon_sym__Atomic] = ACTIONS(5351),
    [anon_sym__Noreturn] = ACTIONS(5351),
    [anon_sym_noreturn] = ACTIONS(5351),
    [anon_sym__Nonnull] = ACTIONS(5351),
    [anon_sym_mutable] = ACTIONS(5351),
    [anon_sym_constinit] = ACTIONS(5351),
    [anon_sym_consteval] = ACTIONS(5351),
    [anon_sym___shared__] = ACTIONS(5351),
    [anon_sym___local__] = ACTIONS(5351),
    [anon_sym___constant__] = ACTIONS(5351),
    [anon_sym___managed__] = ACTIONS(5351),
    [anon_sym___grid_constant__] = ACTIONS(5351),
    [anon_sym_alignas] = ACTIONS(5351),
    [anon_sym__Alignas] = ACTIONS(5351),
    [sym_primitive_type] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [anon_sym_template] = ACTIONS(5351),
    [anon_sym_GT2] = ACTIONS(5354),
    [anon_sym_operator] = ACTIONS(5351),
    [anon_sym___launch_bounds__] = ACTIONS(5351),
  },
  [STATE(2277)] = {
    [sym_type_qualifier] = STATE(2277),
    [sym_alignas_qualifier] = STATE(2368),
    [aux_sym__type_definition_type_repeat1] = STATE(2277),
    [sym_identifier] = ACTIONS(5110),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5112),
    [anon_sym_COMMA] = ACTIONS(5112),
    [anon_sym_LPAREN2] = ACTIONS(5112),
    [anon_sym_DASH] = ACTIONS(5110),
    [anon_sym_PLUS] = ACTIONS(5110),
    [anon_sym_STAR] = ACTIONS(5112),
    [anon_sym_SLASH] = ACTIONS(5110),
    [anon_sym_PERCENT] = ACTIONS(5112),
    [anon_sym_PIPE_PIPE] = ACTIONS(5112),
    [anon_sym_AMP_AMP] = ACTIONS(5112),
    [anon_sym_PIPE] = ACTIONS(5110),
    [anon_sym_CARET] = ACTIONS(5112),
    [anon_sym_AMP] = ACTIONS(5110),
    [anon_sym_EQ_EQ] = ACTIONS(5112),
    [anon_sym_BANG_EQ] = ACTIONS(5112),
    [anon_sym_GT] = ACTIONS(5110),
    [anon_sym_GT_EQ] = ACTIONS(5112),
    [anon_sym_LT_EQ] = ACTIONS(5110),
    [anon_sym_LT] = ACTIONS(5110),
    [anon_sym_LT_LT] = ACTIONS(5110),
    [anon_sym_GT_GT] = ACTIONS(5110),
    [anon_sym___extension__] = ACTIONS(6171),
    [anon_sym___global__] = ACTIONS(6171),
    [anon_sym___attribute__] = ACTIONS(5110),
    [anon_sym___attribute] = ACTIONS(5110),
    [anon_sym_LBRACE] = ACTIONS(5112),
    [anon_sym_signed] = ACTIONS(5110),
    [anon_sym_unsigned] = ACTIONS(5110),
    [anon_sym_long] = ACTIONS(5110),
    [anon_sym_short] = ACTIONS(5110),
    [anon_sym_LBRACK] = ACTIONS(5112),
    [anon_sym_const] = ACTIONS(6171),
    [anon_sym_constexpr] = ACTIONS(6171),
    [anon_sym_volatile] = ACTIONS(6171),
    [anon_sym_restrict] = ACTIONS(6171),
    [anon_sym___restrict__] = ACTIONS(6171),
    [anon_sym__Atomic] = ACTIONS(6171),
    [anon_sym__Noreturn] = ACTIONS(6171),
    [anon_sym_noreturn] = ACTIONS(6171),
    [anon_sym__Nonnull] = ACTIONS(6171),
    [anon_sym_mutable] = ACTIONS(6171),
    [anon_sym_constinit] = ACTIONS(6171),
    [anon_sym_consteval] = ACTIONS(6171),
    [anon_sym___shared__] = ACTIONS(6171),
    [anon_sym___local__] = ACTIONS(6171),
    [anon_sym___constant__] = ACTIONS(6171),
    [anon_sym___managed__] = ACTIONS(6171),
    [anon_sym___grid_constant__] = ACTIONS(6171),
    [anon_sym_alignas] = ACTIONS(6174),
    [anon_sym__Alignas] = ACTIONS(6174),
    [sym_primitive_type] = ACTIONS(5110),
    [anon_sym_QMARK] = ACTIONS(5112),
    [anon_sym_LT_EQ_GT] = ACTIONS(5112),
    [anon_sym_or] = ACTIONS(5110),
    [anon_sym_and] = ACTIONS(5110),
    [anon_sym_bitor] = ACTIONS(5110),
    [anon_sym_xor] = ACTIONS(5110),
    [anon_sym_bitand] = ACTIONS(5110),
    [anon_sym_not_eq] = ACTIONS(5110),
    [anon_sym_DASH_DASH] = ACTIONS(5112),
    [anon_sym_PLUS_PLUS] = ACTIONS(5112),
    [anon_sym_DOT] = ACTIONS(5110),
    [anon_sym_DOT_STAR] = ACTIONS(5112),
    [anon_sym_DASH_GT] = ACTIONS(5112),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5110),
    [anon_sym_decltype] = ACTIONS(5110),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5112),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5112),
  },
  [STATE(2278)] = {
    [sym_attribute_specifier] = STATE(2124),
    [sym_enumerator_list] = STATE(2310),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6177),
    [anon_sym_COMMA] = ACTIONS(6177),
    [anon_sym_RPAREN] = ACTIONS(6177),
    [anon_sym_LPAREN2] = ACTIONS(6177),
    [anon_sym_DASH] = ACTIONS(6179),
    [anon_sym_PLUS] = ACTIONS(6179),
    [anon_sym_STAR] = ACTIONS(6177),
    [anon_sym_SLASH] = ACTIONS(6179),
    [anon_sym_PERCENT] = ACTIONS(6177),
    [anon_sym_PIPE_PIPE] = ACTIONS(6177),
    [anon_sym_AMP_AMP] = ACTIONS(6177),
    [anon_sym_PIPE] = ACTIONS(6179),
    [anon_sym_CARET] = ACTIONS(6177),
    [anon_sym_AMP] = ACTIONS(6179),
    [anon_sym_EQ_EQ] = ACTIONS(6177),
    [anon_sym_BANG_EQ] = ACTIONS(6177),
    [anon_sym_GT] = ACTIONS(6179),
    [anon_sym_GT_EQ] = ACTIONS(6177),
    [anon_sym_LT_EQ] = ACTIONS(6179),
    [anon_sym_LT] = ACTIONS(6179),
    [anon_sym_LT_LT] = ACTIONS(6179),
    [anon_sym_GT_GT] = ACTIONS(6177),
    [anon_sym_SEMI] = ACTIONS(6177),
    [anon_sym___extension__] = ACTIONS(6177),
    [anon_sym___global__] = ACTIONS(6177),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6181),
    [anon_sym_RBRACE] = ACTIONS(6177),
    [anon_sym_LBRACK] = ACTIONS(6177),
    [anon_sym_RBRACK] = ACTIONS(6177),
    [anon_sym_const] = ACTIONS(6179),
    [anon_sym_constexpr] = ACTIONS(6177),
    [anon_sym_volatile] = ACTIONS(6177),
    [anon_sym_restrict] = ACTIONS(6177),
    [anon_sym___restrict__] = ACTIONS(6177),
    [anon_sym__Atomic] = ACTIONS(6177),
    [anon_sym__Noreturn] = ACTIONS(6177),
    [anon_sym_noreturn] = ACTIONS(6177),
    [anon_sym__Nonnull] = ACTIONS(6177),
    [anon_sym_mutable] = ACTIONS(6177),
    [anon_sym_constinit] = ACTIONS(6177),
    [anon_sym_consteval] = ACTIONS(6177),
    [anon_sym___shared__] = ACTIONS(6177),
    [anon_sym___local__] = ACTIONS(6177),
    [anon_sym___constant__] = ACTIONS(6177),
    [anon_sym___managed__] = ACTIONS(6177),
    [anon_sym___grid_constant__] = ACTIONS(6177),
    [anon_sym_alignas] = ACTIONS(6177),
    [anon_sym__Alignas] = ACTIONS(6177),
    [anon_sym_COLON] = ACTIONS(6177),
    [anon_sym_QMARK] = ACTIONS(6177),
    [anon_sym_LT_EQ_GT] = ACTIONS(6177),
    [anon_sym_or] = ACTIONS(6177),
    [anon_sym_and] = ACTIONS(6177),
    [anon_sym_bitor] = ACTIONS(6177),
    [anon_sym_xor] = ACTIONS(6177),
    [anon_sym_bitand] = ACTIONS(6177),
    [anon_sym_not_eq] = ACTIONS(6177),
    [anon_sym_DASH_DASH] = ACTIONS(6177),
    [anon_sym_PLUS_PLUS] = ACTIONS(6177),
    [anon_sym_DOT] = ACTIONS(6179),
    [anon_sym_DOT_STAR] = ACTIONS(6177),
    [anon_sym_DASH_GT] = ACTIONS(6177),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6177),
    [anon_sym_decltype] = ACTIONS(6177),
    [anon_sym_final] = ACTIONS(6177),
    [anon_sym_override] = ACTIONS(6177),
    [anon_sym_requires] = ACTIONS(6177),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6177),
  },
  [STATE(2279)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1959),
    [anon_sym_PIPE_PIPE] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1959),
    [anon_sym_BANG_EQ] = ACTIONS(1959),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1969),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(1959),
    [anon_sym_LT_EQ_GT] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1959),
    [anon_sym_DASH_GT] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_GT2] = ACTIONS(1959),
    [anon_sym_requires] = ACTIONS(1969),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1959),
  },
  [STATE(2280)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5145),
    [anon_sym_SLASH] = ACTIONS(5143),
    [anon_sym_PERCENT] = ACTIONS(5145),
    [anon_sym_PIPE_PIPE] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_PIPE] = ACTIONS(5143),
    [anon_sym_CARET] = ACTIONS(5145),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_GT] = ACTIONS(5143),
    [anon_sym_GT_EQ] = ACTIONS(5143),
    [anon_sym_LT_EQ] = ACTIONS(5143),
    [anon_sym_LT] = ACTIONS(5143),
    [anon_sym_LT_LT] = ACTIONS(5143),
    [anon_sym_GT_GT] = ACTIONS(5143),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_LT_EQ_GT] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5143),
    [anon_sym_and] = ACTIONS(5143),
    [anon_sym_bitor] = ACTIONS(5143),
    [anon_sym_xor] = ACTIONS(5143),
    [anon_sym_bitand] = ACTIONS(5143),
    [anon_sym_not_eq] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5143),
    [anon_sym_DOT_STAR] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [anon_sym_final] = ACTIONS(5143),
    [anon_sym_override] = ACTIONS(5143),
    [anon_sym_GT2] = ACTIONS(5145),
    [anon_sym_requires] = ACTIONS(5143),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5145),
  },
  [STATE(2281)] = {
    [sym_attribute_specifier] = STATE(2163),
    [sym_enumerator_list] = STATE(2316),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6183),
    [anon_sym_COMMA] = ACTIONS(6183),
    [anon_sym_RPAREN] = ACTIONS(6183),
    [anon_sym_LPAREN2] = ACTIONS(6183),
    [anon_sym_DASH] = ACTIONS(6185),
    [anon_sym_PLUS] = ACTIONS(6185),
    [anon_sym_STAR] = ACTIONS(6183),
    [anon_sym_SLASH] = ACTIONS(6185),
    [anon_sym_PERCENT] = ACTIONS(6183),
    [anon_sym_PIPE_PIPE] = ACTIONS(6183),
    [anon_sym_AMP_AMP] = ACTIONS(6183),
    [anon_sym_PIPE] = ACTIONS(6185),
    [anon_sym_CARET] = ACTIONS(6183),
    [anon_sym_AMP] = ACTIONS(6185),
    [anon_sym_EQ_EQ] = ACTIONS(6183),
    [anon_sym_BANG_EQ] = ACTIONS(6183),
    [anon_sym_GT] = ACTIONS(6185),
    [anon_sym_GT_EQ] = ACTIONS(6183),
    [anon_sym_LT_EQ] = ACTIONS(6185),
    [anon_sym_LT] = ACTIONS(6185),
    [anon_sym_LT_LT] = ACTIONS(6185),
    [anon_sym_GT_GT] = ACTIONS(6183),
    [anon_sym_SEMI] = ACTIONS(6183),
    [anon_sym___extension__] = ACTIONS(6183),
    [anon_sym___global__] = ACTIONS(6183),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6181),
    [anon_sym_RBRACE] = ACTIONS(6183),
    [anon_sym_LBRACK] = ACTIONS(6183),
    [anon_sym_RBRACK] = ACTIONS(6183),
    [anon_sym_const] = ACTIONS(6185),
    [anon_sym_constexpr] = ACTIONS(6183),
    [anon_sym_volatile] = ACTIONS(6183),
    [anon_sym_restrict] = ACTIONS(6183),
    [anon_sym___restrict__] = ACTIONS(6183),
    [anon_sym__Atomic] = ACTIONS(6183),
    [anon_sym__Noreturn] = ACTIONS(6183),
    [anon_sym_noreturn] = ACTIONS(6183),
    [anon_sym__Nonnull] = ACTIONS(6183),
    [anon_sym_mutable] = ACTIONS(6183),
    [anon_sym_constinit] = ACTIONS(6183),
    [anon_sym_consteval] = ACTIONS(6183),
    [anon_sym___shared__] = ACTIONS(6183),
    [anon_sym___local__] = ACTIONS(6183),
    [anon_sym___constant__] = ACTIONS(6183),
    [anon_sym___managed__] = ACTIONS(6183),
    [anon_sym___grid_constant__] = ACTIONS(6183),
    [anon_sym_alignas] = ACTIONS(6183),
    [anon_sym__Alignas] = ACTIONS(6183),
    [anon_sym_COLON] = ACTIONS(6183),
    [anon_sym_QMARK] = ACTIONS(6183),
    [anon_sym_LT_EQ_GT] = ACTIONS(6183),
    [anon_sym_or] = ACTIONS(6183),
    [anon_sym_and] = ACTIONS(6183),
    [anon_sym_bitor] = ACTIONS(6183),
    [anon_sym_xor] = ACTIONS(6183),
    [anon_sym_bitand] = ACTIONS(6183),
    [anon_sym_not_eq] = ACTIONS(6183),
    [anon_sym_DASH_DASH] = ACTIONS(6183),
    [anon_sym_PLUS_PLUS] = ACTIONS(6183),
    [anon_sym_DOT] = ACTIONS(6185),
    [anon_sym_DOT_STAR] = ACTIONS(6183),
    [anon_sym_DASH_GT] = ACTIONS(6183),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6183),
    [anon_sym_decltype] = ACTIONS(6183),
    [anon_sym_final] = ACTIONS(6183),
    [anon_sym_override] = ACTIONS(6183),
    [anon_sym_requires] = ACTIONS(6183),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6183),
  },
  [STATE(2282)] = {
    [sym_argument_list] = STATE(2776),
    [sym_initializer_list] = STATE(4315),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2309),
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(6187),
    [anon_sym_TILDE] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5686),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym___cdecl] = ACTIONS(5684),
    [anon_sym___clrcall] = ACTIONS(5684),
    [anon_sym___stdcall] = ACTIONS(5684),
    [anon_sym___fastcall] = ACTIONS(5684),
    [anon_sym___thiscall] = ACTIONS(5684),
    [anon_sym___vectorcall] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(3780),
    [anon_sym_signed] = ACTIONS(6190),
    [anon_sym_unsigned] = ACTIONS(6190),
    [anon_sym_long] = ACTIONS(6190),
    [anon_sym_short] = ACTIONS(6190),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_template] = ACTIONS(5684),
    [anon_sym_operator] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2283)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6194),
    [anon_sym_COMMA] = ACTIONS(6194),
    [anon_sym_RPAREN] = ACTIONS(6194),
    [aux_sym_preproc_if_token2] = ACTIONS(6194),
    [aux_sym_preproc_else_token1] = ACTIONS(6194),
    [aux_sym_preproc_elif_token1] = ACTIONS(6192),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6194),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6194),
    [anon_sym_LPAREN2] = ACTIONS(6194),
    [anon_sym_DASH] = ACTIONS(6192),
    [anon_sym_PLUS] = ACTIONS(6192),
    [anon_sym_STAR] = ACTIONS(6192),
    [anon_sym_SLASH] = ACTIONS(6192),
    [anon_sym_PERCENT] = ACTIONS(6192),
    [anon_sym_PIPE_PIPE] = ACTIONS(6194),
    [anon_sym_AMP_AMP] = ACTIONS(6194),
    [anon_sym_PIPE] = ACTIONS(6192),
    [anon_sym_CARET] = ACTIONS(6192),
    [anon_sym_AMP] = ACTIONS(6192),
    [anon_sym_EQ_EQ] = ACTIONS(6194),
    [anon_sym_BANG_EQ] = ACTIONS(6194),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_GT_EQ] = ACTIONS(6194),
    [anon_sym_LT_EQ] = ACTIONS(6192),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_LT_LT] = ACTIONS(6192),
    [anon_sym_GT_GT] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [anon_sym_RBRACE] = ACTIONS(6194),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [anon_sym_RBRACK] = ACTIONS(6194),
    [anon_sym_EQ] = ACTIONS(6192),
    [anon_sym_COLON] = ACTIONS(6194),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_STAR_EQ] = ACTIONS(6194),
    [anon_sym_SLASH_EQ] = ACTIONS(6194),
    [anon_sym_PERCENT_EQ] = ACTIONS(6194),
    [anon_sym_PLUS_EQ] = ACTIONS(6194),
    [anon_sym_DASH_EQ] = ACTIONS(6194),
    [anon_sym_LT_LT_EQ] = ACTIONS(6194),
    [anon_sym_GT_GT_EQ] = ACTIONS(6194),
    [anon_sym_AMP_EQ] = ACTIONS(6194),
    [anon_sym_CARET_EQ] = ACTIONS(6194),
    [anon_sym_PIPE_EQ] = ACTIONS(6194),
    [anon_sym_and_eq] = ACTIONS(6192),
    [anon_sym_or_eq] = ACTIONS(6192),
    [anon_sym_xor_eq] = ACTIONS(6192),
    [anon_sym_LT_EQ_GT] = ACTIONS(6194),
    [anon_sym_or] = ACTIONS(6192),
    [anon_sym_and] = ACTIONS(6192),
    [anon_sym_bitor] = ACTIONS(6192),
    [anon_sym_xor] = ACTIONS(6192),
    [anon_sym_bitand] = ACTIONS(6192),
    [anon_sym_not_eq] = ACTIONS(6192),
    [anon_sym_DASH_DASH] = ACTIONS(6194),
    [anon_sym_PLUS_PLUS] = ACTIONS(6194),
    [anon_sym_DOT] = ACTIONS(6192),
    [anon_sym_DOT_STAR] = ACTIONS(6194),
    [anon_sym_DASH_GT] = ACTIONS(6194),
    [anon_sym_L_DQUOTE] = ACTIONS(6194),
    [anon_sym_u_DQUOTE] = ACTIONS(6194),
    [anon_sym_U_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8_DQUOTE] = ACTIONS(6194),
    [anon_sym_DQUOTE] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6194),
    [anon_sym_LR_DQUOTE] = ACTIONS(6194),
    [anon_sym_uR_DQUOTE] = ACTIONS(6194),
    [anon_sym_UR_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6194),
    [sym_literal_suffix] = ACTIONS(6192),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6194),
  },
  [STATE(2284)] = {
    [sym_attribute_specifier] = STATE(2518),
    [sym_field_declaration_list] = STATE(2444),
    [sym_virtual_specifier] = STATE(7573),
    [sym_base_class_clause] = STATE(8515),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6036),
    [anon_sym_COMMA] = ACTIONS(6036),
    [anon_sym_RPAREN] = ACTIONS(6036),
    [aux_sym_preproc_if_token2] = ACTIONS(6036),
    [aux_sym_preproc_else_token1] = ACTIONS(6036),
    [aux_sym_preproc_elif_token1] = ACTIONS(6038),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6036),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6036),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_DASH] = ACTIONS(6038),
    [anon_sym_PLUS] = ACTIONS(6038),
    [anon_sym_STAR] = ACTIONS(6038),
    [anon_sym_SLASH] = ACTIONS(6038),
    [anon_sym_PERCENT] = ACTIONS(6038),
    [anon_sym_PIPE_PIPE] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_PIPE] = ACTIONS(6038),
    [anon_sym_CARET] = ACTIONS(6038),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_EQ_EQ] = ACTIONS(6036),
    [anon_sym_BANG_EQ] = ACTIONS(6036),
    [anon_sym_GT] = ACTIONS(6038),
    [anon_sym_GT_EQ] = ACTIONS(6036),
    [anon_sym_LT_EQ] = ACTIONS(6038),
    [anon_sym_LT] = ACTIONS(6038),
    [anon_sym_LT_LT] = ACTIONS(6038),
    [anon_sym_GT_GT] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6036),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6198),
    [anon_sym_RBRACE] = ACTIONS(6036),
    [anon_sym_LBRACK] = ACTIONS(6036),
    [anon_sym_RBRACK] = ACTIONS(6036),
    [anon_sym_EQ] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6046),
    [anon_sym_QMARK] = ACTIONS(6036),
    [anon_sym_STAR_EQ] = ACTIONS(6036),
    [anon_sym_SLASH_EQ] = ACTIONS(6036),
    [anon_sym_PERCENT_EQ] = ACTIONS(6036),
    [anon_sym_PLUS_EQ] = ACTIONS(6036),
    [anon_sym_DASH_EQ] = ACTIONS(6036),
    [anon_sym_LT_LT_EQ] = ACTIONS(6036),
    [anon_sym_GT_GT_EQ] = ACTIONS(6036),
    [anon_sym_AMP_EQ] = ACTIONS(6036),
    [anon_sym_CARET_EQ] = ACTIONS(6036),
    [anon_sym_PIPE_EQ] = ACTIONS(6036),
    [anon_sym_and_eq] = ACTIONS(6038),
    [anon_sym_or_eq] = ACTIONS(6038),
    [anon_sym_xor_eq] = ACTIONS(6038),
    [anon_sym_LT_EQ_GT] = ACTIONS(6036),
    [anon_sym_or] = ACTIONS(6038),
    [anon_sym_and] = ACTIONS(6038),
    [anon_sym_bitor] = ACTIONS(6038),
    [anon_sym_xor] = ACTIONS(6038),
    [anon_sym_bitand] = ACTIONS(6038),
    [anon_sym_not_eq] = ACTIONS(6038),
    [anon_sym_DASH_DASH] = ACTIONS(6036),
    [anon_sym_PLUS_PLUS] = ACTIONS(6036),
    [anon_sym_DOT] = ACTIONS(6038),
    [anon_sym_DOT_STAR] = ACTIONS(6036),
    [anon_sym_DASH_GT] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6036),
  },
  [STATE(2285)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6006),
    [anon_sym_COMMA] = ACTIONS(6006),
    [anon_sym_LPAREN2] = ACTIONS(6006),
    [anon_sym_DASH] = ACTIONS(6008),
    [anon_sym_PLUS] = ACTIONS(6008),
    [anon_sym_STAR] = ACTIONS(6006),
    [anon_sym_SLASH] = ACTIONS(6008),
    [anon_sym_PERCENT] = ACTIONS(6006),
    [anon_sym_PIPE_PIPE] = ACTIONS(6006),
    [anon_sym_AMP_AMP] = ACTIONS(6006),
    [anon_sym_PIPE] = ACTIONS(6008),
    [anon_sym_CARET] = ACTIONS(6006),
    [anon_sym_AMP] = ACTIONS(6008),
    [anon_sym_EQ_EQ] = ACTIONS(6006),
    [anon_sym_BANG_EQ] = ACTIONS(6006),
    [anon_sym_GT] = ACTIONS(6008),
    [anon_sym_GT_EQ] = ACTIONS(6008),
    [anon_sym_LT_EQ] = ACTIONS(6008),
    [anon_sym_LT] = ACTIONS(6008),
    [anon_sym_LT_LT] = ACTIONS(6008),
    [anon_sym_GT_GT] = ACTIONS(6008),
    [anon_sym___extension__] = ACTIONS(6006),
    [anon_sym___global__] = ACTIONS(6006),
    [anon_sym___attribute__] = ACTIONS(6006),
    [anon_sym___attribute] = ACTIONS(6008),
    [anon_sym_LBRACE] = ACTIONS(6006),
    [anon_sym_signed] = ACTIONS(6200),
    [anon_sym_unsigned] = ACTIONS(6200),
    [anon_sym_long] = ACTIONS(6200),
    [anon_sym_short] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(6006),
    [anon_sym_const] = ACTIONS(6008),
    [anon_sym_constexpr] = ACTIONS(6006),
    [anon_sym_volatile] = ACTIONS(6006),
    [anon_sym_restrict] = ACTIONS(6006),
    [anon_sym___restrict__] = ACTIONS(6006),
    [anon_sym__Atomic] = ACTIONS(6006),
    [anon_sym__Noreturn] = ACTIONS(6006),
    [anon_sym_noreturn] = ACTIONS(6006),
    [anon_sym__Nonnull] = ACTIONS(6006),
    [anon_sym_mutable] = ACTIONS(6006),
    [anon_sym_constinit] = ACTIONS(6006),
    [anon_sym_consteval] = ACTIONS(6006),
    [anon_sym___shared__] = ACTIONS(6006),
    [anon_sym___local__] = ACTIONS(6006),
    [anon_sym___constant__] = ACTIONS(6006),
    [anon_sym___managed__] = ACTIONS(6006),
    [anon_sym___grid_constant__] = ACTIONS(6006),
    [anon_sym_alignas] = ACTIONS(6006),
    [anon_sym__Alignas] = ACTIONS(6006),
    [anon_sym_QMARK] = ACTIONS(6006),
    [anon_sym_LT_EQ_GT] = ACTIONS(6006),
    [anon_sym_or] = ACTIONS(6006),
    [anon_sym_and] = ACTIONS(6006),
    [anon_sym_bitor] = ACTIONS(6006),
    [anon_sym_xor] = ACTIONS(6006),
    [anon_sym_bitand] = ACTIONS(6006),
    [anon_sym_not_eq] = ACTIONS(6006),
    [anon_sym_DASH_DASH] = ACTIONS(6006),
    [anon_sym_PLUS_PLUS] = ACTIONS(6006),
    [anon_sym_DOT] = ACTIONS(6008),
    [anon_sym_DOT_STAR] = ACTIONS(6006),
    [anon_sym_DASH_GT] = ACTIONS(6006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6006),
    [anon_sym_decltype] = ACTIONS(6006),
    [anon_sym_final] = ACTIONS(6006),
    [anon_sym_override] = ACTIONS(6006),
    [anon_sym_GT2] = ACTIONS(6006),
    [anon_sym_requires] = ACTIONS(6006),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6006),
  },
  [STATE(2286)] = {
    [sym_attribute_specifier] = STATE(2508),
    [sym_field_declaration_list] = STATE(2441),
    [sym_virtual_specifier] = STATE(7557),
    [sym_base_class_clause] = STATE(8313),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6036),
    [anon_sym_COMMA] = ACTIONS(6036),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_DASH] = ACTIONS(6038),
    [anon_sym_PLUS] = ACTIONS(6038),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_SLASH] = ACTIONS(6038),
    [anon_sym_PERCENT] = ACTIONS(6036),
    [anon_sym_PIPE_PIPE] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_PIPE] = ACTIONS(6038),
    [anon_sym_CARET] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_EQ_EQ] = ACTIONS(6036),
    [anon_sym_BANG_EQ] = ACTIONS(6036),
    [anon_sym_GT] = ACTIONS(6038),
    [anon_sym_GT_EQ] = ACTIONS(6038),
    [anon_sym_LT_EQ] = ACTIONS(6038),
    [anon_sym_LT] = ACTIONS(6038),
    [anon_sym_LT_LT] = ACTIONS(6038),
    [anon_sym_GT_GT] = ACTIONS(6038),
    [anon_sym___extension__] = ACTIONS(6036),
    [anon_sym___global__] = ACTIONS(6036),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6206),
    [anon_sym_LBRACK] = ACTIONS(6036),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6036),
    [anon_sym_volatile] = ACTIONS(6036),
    [anon_sym_restrict] = ACTIONS(6036),
    [anon_sym___restrict__] = ACTIONS(6036),
    [anon_sym__Atomic] = ACTIONS(6036),
    [anon_sym__Noreturn] = ACTIONS(6036),
    [anon_sym_noreturn] = ACTIONS(6036),
    [anon_sym__Nonnull] = ACTIONS(6036),
    [anon_sym_mutable] = ACTIONS(6036),
    [anon_sym_constinit] = ACTIONS(6036),
    [anon_sym_consteval] = ACTIONS(6036),
    [anon_sym___shared__] = ACTIONS(6036),
    [anon_sym___local__] = ACTIONS(6036),
    [anon_sym___constant__] = ACTIONS(6036),
    [anon_sym___managed__] = ACTIONS(6036),
    [anon_sym___grid_constant__] = ACTIONS(6036),
    [anon_sym_alignas] = ACTIONS(6036),
    [anon_sym__Alignas] = ACTIONS(6036),
    [anon_sym_COLON] = ACTIONS(6046),
    [anon_sym_QMARK] = ACTIONS(6036),
    [anon_sym_LT_EQ_GT] = ACTIONS(6036),
    [anon_sym_or] = ACTIONS(6036),
    [anon_sym_and] = ACTIONS(6036),
    [anon_sym_bitor] = ACTIONS(6036),
    [anon_sym_xor] = ACTIONS(6036),
    [anon_sym_bitand] = ACTIONS(6036),
    [anon_sym_not_eq] = ACTIONS(6036),
    [anon_sym_DASH_DASH] = ACTIONS(6036),
    [anon_sym_PLUS_PLUS] = ACTIONS(6036),
    [anon_sym_DOT] = ACTIONS(6038),
    [anon_sym_DOT_STAR] = ACTIONS(6036),
    [anon_sym_DASH_GT] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6036),
    [anon_sym_decltype] = ACTIONS(6036),
    [anon_sym_final] = ACTIONS(6048),
    [anon_sym_override] = ACTIONS(6048),
    [anon_sym_GT2] = ACTIONS(6036),
    [anon_sym_requires] = ACTIONS(6036),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6036),
  },
  [STATE(2287)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5984),
    [anon_sym_COMMA] = ACTIONS(5984),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(5986),
    [anon_sym_PLUS] = ACTIONS(5986),
    [anon_sym_STAR] = ACTIONS(5984),
    [anon_sym_SLASH] = ACTIONS(5986),
    [anon_sym_PERCENT] = ACTIONS(5984),
    [anon_sym_PIPE_PIPE] = ACTIONS(5984),
    [anon_sym_AMP_AMP] = ACTIONS(5984),
    [anon_sym_PIPE] = ACTIONS(5986),
    [anon_sym_CARET] = ACTIONS(5984),
    [anon_sym_AMP] = ACTIONS(5986),
    [anon_sym_EQ_EQ] = ACTIONS(5984),
    [anon_sym_BANG_EQ] = ACTIONS(5984),
    [anon_sym_GT] = ACTIONS(5986),
    [anon_sym_GT_EQ] = ACTIONS(5986),
    [anon_sym_LT_EQ] = ACTIONS(5986),
    [anon_sym_LT] = ACTIONS(5986),
    [anon_sym_LT_LT] = ACTIONS(5986),
    [anon_sym_GT_GT] = ACTIONS(5986),
    [anon_sym___extension__] = ACTIONS(5984),
    [anon_sym___global__] = ACTIONS(5984),
    [anon_sym___attribute__] = ACTIONS(5984),
    [anon_sym___attribute] = ACTIONS(5986),
    [anon_sym_LBRACE] = ACTIONS(5984),
    [anon_sym_signed] = ACTIONS(6200),
    [anon_sym_unsigned] = ACTIONS(6200),
    [anon_sym_long] = ACTIONS(6200),
    [anon_sym_short] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(5984),
    [anon_sym_const] = ACTIONS(5986),
    [anon_sym_constexpr] = ACTIONS(5984),
    [anon_sym_volatile] = ACTIONS(5984),
    [anon_sym_restrict] = ACTIONS(5984),
    [anon_sym___restrict__] = ACTIONS(5984),
    [anon_sym__Atomic] = ACTIONS(5984),
    [anon_sym__Noreturn] = ACTIONS(5984),
    [anon_sym_noreturn] = ACTIONS(5984),
    [anon_sym__Nonnull] = ACTIONS(5984),
    [anon_sym_mutable] = ACTIONS(5984),
    [anon_sym_constinit] = ACTIONS(5984),
    [anon_sym_consteval] = ACTIONS(5984),
    [anon_sym___shared__] = ACTIONS(5984),
    [anon_sym___local__] = ACTIONS(5984),
    [anon_sym___constant__] = ACTIONS(5984),
    [anon_sym___managed__] = ACTIONS(5984),
    [anon_sym___grid_constant__] = ACTIONS(5984),
    [anon_sym_alignas] = ACTIONS(5984),
    [anon_sym__Alignas] = ACTIONS(5984),
    [anon_sym_QMARK] = ACTIONS(5984),
    [anon_sym_LT_EQ_GT] = ACTIONS(5984),
    [anon_sym_or] = ACTIONS(5984),
    [anon_sym_and] = ACTIONS(5984),
    [anon_sym_bitor] = ACTIONS(5984),
    [anon_sym_xor] = ACTIONS(5984),
    [anon_sym_bitand] = ACTIONS(5984),
    [anon_sym_not_eq] = ACTIONS(5984),
    [anon_sym_DASH_DASH] = ACTIONS(5984),
    [anon_sym_PLUS_PLUS] = ACTIONS(5984),
    [anon_sym_DOT] = ACTIONS(5986),
    [anon_sym_DOT_STAR] = ACTIONS(5984),
    [anon_sym_DASH_GT] = ACTIONS(5984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5984),
    [anon_sym_decltype] = ACTIONS(5984),
    [anon_sym_final] = ACTIONS(5984),
    [anon_sym_override] = ACTIONS(5984),
    [anon_sym_GT2] = ACTIONS(5984),
    [anon_sym_requires] = ACTIONS(5984),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5984),
  },
  [STATE(2288)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2326),
    [sym_identifier] = ACTIONS(5996),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5994),
    [anon_sym_COMMA] = ACTIONS(5994),
    [anon_sym_RPAREN] = ACTIONS(5994),
    [anon_sym_LPAREN2] = ACTIONS(5994),
    [anon_sym_TILDE] = ACTIONS(5994),
    [anon_sym_STAR] = ACTIONS(5994),
    [anon_sym_AMP_AMP] = ACTIONS(5994),
    [anon_sym_AMP] = ACTIONS(5996),
    [anon_sym_SEMI] = ACTIONS(5994),
    [anon_sym___extension__] = ACTIONS(5996),
    [anon_sym___device__] = ACTIONS(5996),
    [anon_sym___host__] = ACTIONS(5996),
    [anon_sym___global__] = ACTIONS(5996),
    [anon_sym___forceinline__] = ACTIONS(5996),
    [anon_sym___noinline__] = ACTIONS(5996),
    [anon_sym_virtual] = ACTIONS(5996),
    [anon_sym_extern] = ACTIONS(5996),
    [anon_sym___attribute__] = ACTIONS(5996),
    [anon_sym___attribute] = ACTIONS(5996),
    [anon_sym_COLON_COLON] = ACTIONS(5994),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5994),
    [anon_sym___declspec] = ACTIONS(5996),
    [anon_sym___based] = ACTIONS(5996),
    [anon_sym___cdecl] = ACTIONS(5996),
    [anon_sym___clrcall] = ACTIONS(5996),
    [anon_sym___stdcall] = ACTIONS(5996),
    [anon_sym___fastcall] = ACTIONS(5996),
    [anon_sym___thiscall] = ACTIONS(5996),
    [anon_sym___vectorcall] = ACTIONS(5996),
    [anon_sym_LBRACE] = ACTIONS(5994),
    [anon_sym_signed] = ACTIONS(6208),
    [anon_sym_unsigned] = ACTIONS(6208),
    [anon_sym_long] = ACTIONS(6208),
    [anon_sym_short] = ACTIONS(6208),
    [anon_sym_LBRACK] = ACTIONS(5996),
    [anon_sym_static] = ACTIONS(5996),
    [anon_sym_EQ] = ACTIONS(5994),
    [anon_sym_register] = ACTIONS(5996),
    [anon_sym_inline] = ACTIONS(5996),
    [anon_sym___inline] = ACTIONS(5996),
    [anon_sym___inline__] = ACTIONS(5996),
    [anon_sym___forceinline] = ACTIONS(5996),
    [anon_sym_thread_local] = ACTIONS(5996),
    [anon_sym___thread] = ACTIONS(5996),
    [anon_sym_const] = ACTIONS(5996),
    [anon_sym_constexpr] = ACTIONS(5996),
    [anon_sym_volatile] = ACTIONS(5996),
    [anon_sym_restrict] = ACTIONS(5996),
    [anon_sym___restrict__] = ACTIONS(5996),
    [anon_sym__Atomic] = ACTIONS(5996),
    [anon_sym__Noreturn] = ACTIONS(5996),
    [anon_sym_noreturn] = ACTIONS(5996),
    [anon_sym__Nonnull] = ACTIONS(5996),
    [anon_sym_mutable] = ACTIONS(5996),
    [anon_sym_constinit] = ACTIONS(5996),
    [anon_sym_consteval] = ACTIONS(5996),
    [anon_sym___shared__] = ACTIONS(5996),
    [anon_sym___local__] = ACTIONS(5996),
    [anon_sym___constant__] = ACTIONS(5996),
    [anon_sym___managed__] = ACTIONS(5996),
    [anon_sym___grid_constant__] = ACTIONS(5996),
    [anon_sym_alignas] = ACTIONS(5996),
    [anon_sym__Alignas] = ACTIONS(5996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5996),
    [anon_sym_decltype] = ACTIONS(5996),
    [anon_sym_template] = ACTIONS(5996),
    [anon_sym_GT2] = ACTIONS(5994),
    [anon_sym_operator] = ACTIONS(5996),
    [anon_sym___launch_bounds__] = ACTIONS(5996),
  },
  [STATE(2289)] = {
    [sym_attribute_specifier] = STATE(2142),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6210),
    [anon_sym_COMMA] = ACTIONS(6210),
    [anon_sym_RPAREN] = ACTIONS(6210),
    [anon_sym_LPAREN2] = ACTIONS(6210),
    [anon_sym_DASH] = ACTIONS(6212),
    [anon_sym_PLUS] = ACTIONS(6212),
    [anon_sym_STAR] = ACTIONS(6210),
    [anon_sym_SLASH] = ACTIONS(6212),
    [anon_sym_PERCENT] = ACTIONS(6210),
    [anon_sym_PIPE_PIPE] = ACTIONS(6210),
    [anon_sym_AMP_AMP] = ACTIONS(6210),
    [anon_sym_PIPE] = ACTIONS(6212),
    [anon_sym_CARET] = ACTIONS(6210),
    [anon_sym_AMP] = ACTIONS(6212),
    [anon_sym_EQ_EQ] = ACTIONS(6210),
    [anon_sym_BANG_EQ] = ACTIONS(6210),
    [anon_sym_GT] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6210),
    [anon_sym_LT_EQ] = ACTIONS(6212),
    [anon_sym_LT] = ACTIONS(6212),
    [anon_sym_LT_LT] = ACTIONS(6212),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_SEMI] = ACTIONS(6210),
    [anon_sym___extension__] = ACTIONS(6210),
    [anon_sym___global__] = ACTIONS(6210),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6210),
    [anon_sym_RBRACE] = ACTIONS(6210),
    [anon_sym_LBRACK] = ACTIONS(6210),
    [anon_sym_RBRACK] = ACTIONS(6210),
    [anon_sym_const] = ACTIONS(6212),
    [anon_sym_constexpr] = ACTIONS(6210),
    [anon_sym_volatile] = ACTIONS(6210),
    [anon_sym_restrict] = ACTIONS(6210),
    [anon_sym___restrict__] = ACTIONS(6210),
    [anon_sym__Atomic] = ACTIONS(6210),
    [anon_sym__Noreturn] = ACTIONS(6210),
    [anon_sym_noreturn] = ACTIONS(6210),
    [anon_sym__Nonnull] = ACTIONS(6210),
    [anon_sym_mutable] = ACTIONS(6210),
    [anon_sym_constinit] = ACTIONS(6210),
    [anon_sym_consteval] = ACTIONS(6210),
    [anon_sym___shared__] = ACTIONS(6210),
    [anon_sym___local__] = ACTIONS(6210),
    [anon_sym___constant__] = ACTIONS(6210),
    [anon_sym___managed__] = ACTIONS(6210),
    [anon_sym___grid_constant__] = ACTIONS(6210),
    [anon_sym_alignas] = ACTIONS(6210),
    [anon_sym__Alignas] = ACTIONS(6210),
    [anon_sym_COLON] = ACTIONS(6210),
    [anon_sym_QMARK] = ACTIONS(6210),
    [anon_sym_LT_EQ_GT] = ACTIONS(6210),
    [anon_sym_or] = ACTIONS(6210),
    [anon_sym_and] = ACTIONS(6210),
    [anon_sym_bitor] = ACTIONS(6210),
    [anon_sym_xor] = ACTIONS(6210),
    [anon_sym_bitand] = ACTIONS(6210),
    [anon_sym_not_eq] = ACTIONS(6210),
    [anon_sym_DASH_DASH] = ACTIONS(6210),
    [anon_sym_PLUS_PLUS] = ACTIONS(6210),
    [anon_sym_DOT] = ACTIONS(6212),
    [anon_sym_DOT_STAR] = ACTIONS(6210),
    [anon_sym_DASH_GT] = ACTIONS(6210),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6210),
    [anon_sym_decltype] = ACTIONS(6210),
    [anon_sym_final] = ACTIONS(6210),
    [anon_sym_override] = ACTIONS(6210),
    [anon_sym_requires] = ACTIONS(6210),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6210),
  },
  [STATE(2290)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2321),
    [sym_identifier] = ACTIONS(5990),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5988),
    [anon_sym_COMMA] = ACTIONS(5988),
    [anon_sym_RPAREN] = ACTIONS(5988),
    [anon_sym_LPAREN2] = ACTIONS(5988),
    [anon_sym_TILDE] = ACTIONS(5988),
    [anon_sym_STAR] = ACTIONS(5988),
    [anon_sym_AMP_AMP] = ACTIONS(5988),
    [anon_sym_AMP] = ACTIONS(5990),
    [anon_sym_SEMI] = ACTIONS(5988),
    [anon_sym___extension__] = ACTIONS(5990),
    [anon_sym___device__] = ACTIONS(5990),
    [anon_sym___host__] = ACTIONS(5990),
    [anon_sym___global__] = ACTIONS(5990),
    [anon_sym___forceinline__] = ACTIONS(5990),
    [anon_sym___noinline__] = ACTIONS(5990),
    [anon_sym_virtual] = ACTIONS(5990),
    [anon_sym_extern] = ACTIONS(5990),
    [anon_sym___attribute__] = ACTIONS(5990),
    [anon_sym___attribute] = ACTIONS(5990),
    [anon_sym_COLON_COLON] = ACTIONS(5988),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5988),
    [anon_sym___declspec] = ACTIONS(5990),
    [anon_sym___based] = ACTIONS(5990),
    [anon_sym___cdecl] = ACTIONS(5990),
    [anon_sym___clrcall] = ACTIONS(5990),
    [anon_sym___stdcall] = ACTIONS(5990),
    [anon_sym___fastcall] = ACTIONS(5990),
    [anon_sym___thiscall] = ACTIONS(5990),
    [anon_sym___vectorcall] = ACTIONS(5990),
    [anon_sym_LBRACE] = ACTIONS(5988),
    [anon_sym_signed] = ACTIONS(6214),
    [anon_sym_unsigned] = ACTIONS(6214),
    [anon_sym_long] = ACTIONS(6214),
    [anon_sym_short] = ACTIONS(6214),
    [anon_sym_LBRACK] = ACTIONS(5990),
    [anon_sym_static] = ACTIONS(5990),
    [anon_sym_EQ] = ACTIONS(5988),
    [anon_sym_register] = ACTIONS(5990),
    [anon_sym_inline] = ACTIONS(5990),
    [anon_sym___inline] = ACTIONS(5990),
    [anon_sym___inline__] = ACTIONS(5990),
    [anon_sym___forceinline] = ACTIONS(5990),
    [anon_sym_thread_local] = ACTIONS(5990),
    [anon_sym___thread] = ACTIONS(5990),
    [anon_sym_const] = ACTIONS(5990),
    [anon_sym_constexpr] = ACTIONS(5990),
    [anon_sym_volatile] = ACTIONS(5990),
    [anon_sym_restrict] = ACTIONS(5990),
    [anon_sym___restrict__] = ACTIONS(5990),
    [anon_sym__Atomic] = ACTIONS(5990),
    [anon_sym__Noreturn] = ACTIONS(5990),
    [anon_sym_noreturn] = ACTIONS(5990),
    [anon_sym__Nonnull] = ACTIONS(5990),
    [anon_sym_mutable] = ACTIONS(5990),
    [anon_sym_constinit] = ACTIONS(5990),
    [anon_sym_consteval] = ACTIONS(5990),
    [anon_sym___shared__] = ACTIONS(5990),
    [anon_sym___local__] = ACTIONS(5990),
    [anon_sym___constant__] = ACTIONS(5990),
    [anon_sym___managed__] = ACTIONS(5990),
    [anon_sym___grid_constant__] = ACTIONS(5990),
    [anon_sym_alignas] = ACTIONS(5990),
    [anon_sym__Alignas] = ACTIONS(5990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5990),
    [anon_sym_decltype] = ACTIONS(5990),
    [anon_sym_template] = ACTIONS(5990),
    [anon_sym_GT2] = ACTIONS(5988),
    [anon_sym_operator] = ACTIONS(5990),
    [anon_sym___launch_bounds__] = ACTIONS(5990),
  },
  [STATE(2291)] = {
    [sym_attribute_specifier] = STATE(2122),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6216),
    [anon_sym_COMMA] = ACTIONS(6216),
    [anon_sym_RPAREN] = ACTIONS(6216),
    [anon_sym_LPAREN2] = ACTIONS(6216),
    [anon_sym_DASH] = ACTIONS(6218),
    [anon_sym_PLUS] = ACTIONS(6218),
    [anon_sym_STAR] = ACTIONS(6216),
    [anon_sym_SLASH] = ACTIONS(6218),
    [anon_sym_PERCENT] = ACTIONS(6216),
    [anon_sym_PIPE_PIPE] = ACTIONS(6216),
    [anon_sym_AMP_AMP] = ACTIONS(6216),
    [anon_sym_PIPE] = ACTIONS(6218),
    [anon_sym_CARET] = ACTIONS(6216),
    [anon_sym_AMP] = ACTIONS(6218),
    [anon_sym_EQ_EQ] = ACTIONS(6216),
    [anon_sym_BANG_EQ] = ACTIONS(6216),
    [anon_sym_GT] = ACTIONS(6218),
    [anon_sym_GT_EQ] = ACTIONS(6216),
    [anon_sym_LT_EQ] = ACTIONS(6218),
    [anon_sym_LT] = ACTIONS(6218),
    [anon_sym_LT_LT] = ACTIONS(6218),
    [anon_sym_GT_GT] = ACTIONS(6216),
    [anon_sym_SEMI] = ACTIONS(6216),
    [anon_sym___extension__] = ACTIONS(6216),
    [anon_sym___global__] = ACTIONS(6216),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6216),
    [anon_sym_RBRACE] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6216),
    [anon_sym_RBRACK] = ACTIONS(6216),
    [anon_sym_const] = ACTIONS(6218),
    [anon_sym_constexpr] = ACTIONS(6216),
    [anon_sym_volatile] = ACTIONS(6216),
    [anon_sym_restrict] = ACTIONS(6216),
    [anon_sym___restrict__] = ACTIONS(6216),
    [anon_sym__Atomic] = ACTIONS(6216),
    [anon_sym__Noreturn] = ACTIONS(6216),
    [anon_sym_noreturn] = ACTIONS(6216),
    [anon_sym__Nonnull] = ACTIONS(6216),
    [anon_sym_mutable] = ACTIONS(6216),
    [anon_sym_constinit] = ACTIONS(6216),
    [anon_sym_consteval] = ACTIONS(6216),
    [anon_sym___shared__] = ACTIONS(6216),
    [anon_sym___local__] = ACTIONS(6216),
    [anon_sym___constant__] = ACTIONS(6216),
    [anon_sym___managed__] = ACTIONS(6216),
    [anon_sym___grid_constant__] = ACTIONS(6216),
    [anon_sym_alignas] = ACTIONS(6216),
    [anon_sym__Alignas] = ACTIONS(6216),
    [anon_sym_COLON] = ACTIONS(6216),
    [anon_sym_QMARK] = ACTIONS(6216),
    [anon_sym_LT_EQ_GT] = ACTIONS(6216),
    [anon_sym_or] = ACTIONS(6216),
    [anon_sym_and] = ACTIONS(6216),
    [anon_sym_bitor] = ACTIONS(6216),
    [anon_sym_xor] = ACTIONS(6216),
    [anon_sym_bitand] = ACTIONS(6216),
    [anon_sym_not_eq] = ACTIONS(6216),
    [anon_sym_DASH_DASH] = ACTIONS(6216),
    [anon_sym_PLUS_PLUS] = ACTIONS(6216),
    [anon_sym_DOT] = ACTIONS(6218),
    [anon_sym_DOT_STAR] = ACTIONS(6216),
    [anon_sym_DASH_GT] = ACTIONS(6216),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6216),
    [anon_sym_decltype] = ACTIONS(6216),
    [anon_sym_final] = ACTIONS(6216),
    [anon_sym_override] = ACTIONS(6216),
    [anon_sym_requires] = ACTIONS(6216),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6216),
  },
  [STATE(2292)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2324),
    [sym_identifier] = ACTIONS(5919),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5917),
    [anon_sym_COMMA] = ACTIONS(5917),
    [anon_sym_RPAREN] = ACTIONS(5917),
    [anon_sym_LPAREN2] = ACTIONS(5917),
    [anon_sym_TILDE] = ACTIONS(5917),
    [anon_sym_STAR] = ACTIONS(5917),
    [anon_sym_AMP_AMP] = ACTIONS(5917),
    [anon_sym_AMP] = ACTIONS(5919),
    [anon_sym_SEMI] = ACTIONS(5917),
    [anon_sym___extension__] = ACTIONS(5919),
    [anon_sym___device__] = ACTIONS(5919),
    [anon_sym___host__] = ACTIONS(5919),
    [anon_sym___global__] = ACTIONS(5919),
    [anon_sym___forceinline__] = ACTIONS(5919),
    [anon_sym___noinline__] = ACTIONS(5919),
    [anon_sym_virtual] = ACTIONS(5919),
    [anon_sym_extern] = ACTIONS(5919),
    [anon_sym___attribute__] = ACTIONS(5919),
    [anon_sym___attribute] = ACTIONS(5919),
    [anon_sym_COLON_COLON] = ACTIONS(5917),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5917),
    [anon_sym___declspec] = ACTIONS(5919),
    [anon_sym___based] = ACTIONS(5919),
    [anon_sym___cdecl] = ACTIONS(5919),
    [anon_sym___clrcall] = ACTIONS(5919),
    [anon_sym___stdcall] = ACTIONS(5919),
    [anon_sym___fastcall] = ACTIONS(5919),
    [anon_sym___thiscall] = ACTIONS(5919),
    [anon_sym___vectorcall] = ACTIONS(5919),
    [anon_sym_LBRACE] = ACTIONS(5917),
    [anon_sym_signed] = ACTIONS(6220),
    [anon_sym_unsigned] = ACTIONS(6220),
    [anon_sym_long] = ACTIONS(6220),
    [anon_sym_short] = ACTIONS(6220),
    [anon_sym_LBRACK] = ACTIONS(5919),
    [anon_sym_static] = ACTIONS(5919),
    [anon_sym_EQ] = ACTIONS(5917),
    [anon_sym_register] = ACTIONS(5919),
    [anon_sym_inline] = ACTIONS(5919),
    [anon_sym___inline] = ACTIONS(5919),
    [anon_sym___inline__] = ACTIONS(5919),
    [anon_sym___forceinline] = ACTIONS(5919),
    [anon_sym_thread_local] = ACTIONS(5919),
    [anon_sym___thread] = ACTIONS(5919),
    [anon_sym_const] = ACTIONS(5919),
    [anon_sym_constexpr] = ACTIONS(5919),
    [anon_sym_volatile] = ACTIONS(5919),
    [anon_sym_restrict] = ACTIONS(5919),
    [anon_sym___restrict__] = ACTIONS(5919),
    [anon_sym__Atomic] = ACTIONS(5919),
    [anon_sym__Noreturn] = ACTIONS(5919),
    [anon_sym_noreturn] = ACTIONS(5919),
    [anon_sym__Nonnull] = ACTIONS(5919),
    [anon_sym_mutable] = ACTIONS(5919),
    [anon_sym_constinit] = ACTIONS(5919),
    [anon_sym_consteval] = ACTIONS(5919),
    [anon_sym___shared__] = ACTIONS(5919),
    [anon_sym___local__] = ACTIONS(5919),
    [anon_sym___constant__] = ACTIONS(5919),
    [anon_sym___managed__] = ACTIONS(5919),
    [anon_sym___grid_constant__] = ACTIONS(5919),
    [anon_sym_alignas] = ACTIONS(5919),
    [anon_sym__Alignas] = ACTIONS(5919),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5919),
    [anon_sym_decltype] = ACTIONS(5919),
    [anon_sym_template] = ACTIONS(5919),
    [anon_sym_GT2] = ACTIONS(5917),
    [anon_sym_operator] = ACTIONS(5919),
    [anon_sym___launch_bounds__] = ACTIONS(5919),
  },
  [STATE(2293)] = {
    [sym_identifier] = ACTIONS(4350),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_RPAREN] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_TILDE] = ACTIONS(4352),
    [anon_sym_STAR] = ACTIONS(4352),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_SEMI] = ACTIONS(4352),
    [anon_sym___extension__] = ACTIONS(4350),
    [anon_sym___device__] = ACTIONS(4350),
    [anon_sym___host__] = ACTIONS(4350),
    [anon_sym___global__] = ACTIONS(4350),
    [anon_sym___forceinline__] = ACTIONS(4350),
    [anon_sym___noinline__] = ACTIONS(4350),
    [anon_sym_virtual] = ACTIONS(4350),
    [anon_sym_extern] = ACTIONS(4350),
    [anon_sym___attribute__] = ACTIONS(4350),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4352),
    [anon_sym___declspec] = ACTIONS(4350),
    [anon_sym___based] = ACTIONS(4350),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_static] = ACTIONS(4350),
    [anon_sym_EQ] = ACTIONS(4352),
    [anon_sym_register] = ACTIONS(4350),
    [anon_sym_inline] = ACTIONS(4350),
    [anon_sym___inline] = ACTIONS(4350),
    [anon_sym___inline__] = ACTIONS(4350),
    [anon_sym___forceinline] = ACTIONS(4350),
    [anon_sym_thread_local] = ACTIONS(4350),
    [anon_sym___thread] = ACTIONS(4350),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4350),
    [anon_sym_volatile] = ACTIONS(4350),
    [anon_sym_restrict] = ACTIONS(4350),
    [anon_sym___restrict__] = ACTIONS(4350),
    [anon_sym__Atomic] = ACTIONS(4350),
    [anon_sym__Noreturn] = ACTIONS(4350),
    [anon_sym_noreturn] = ACTIONS(4350),
    [anon_sym__Nonnull] = ACTIONS(4350),
    [anon_sym_mutable] = ACTIONS(4350),
    [anon_sym_constinit] = ACTIONS(4350),
    [anon_sym_consteval] = ACTIONS(4350),
    [anon_sym___shared__] = ACTIONS(4350),
    [anon_sym___local__] = ACTIONS(4350),
    [anon_sym___constant__] = ACTIONS(4350),
    [anon_sym___managed__] = ACTIONS(4350),
    [anon_sym___grid_constant__] = ACTIONS(4350),
    [anon_sym_alignas] = ACTIONS(4350),
    [anon_sym__Alignas] = ACTIONS(4350),
    [anon_sym_COLON] = ACTIONS(4350),
    [anon_sym_or] = ACTIONS(4350),
    [anon_sym_and] = ACTIONS(4350),
    [anon_sym_asm] = ACTIONS(4350),
    [anon_sym___asm__] = ACTIONS(4350),
    [anon_sym___asm] = ACTIONS(4350),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4350),
    [anon_sym_decltype] = ACTIONS(4350),
    [anon_sym_final] = ACTIONS(4350),
    [anon_sym_override] = ACTIONS(4350),
    [anon_sym_template] = ACTIONS(4350),
    [anon_sym_GT2] = ACTIONS(4352),
    [anon_sym_operator] = ACTIONS(4350),
    [anon_sym_try] = ACTIONS(4350),
    [anon_sym_requires] = ACTIONS(4350),
    [anon_sym___launch_bounds__] = ACTIONS(4350),
  },
  [STATE(2294)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2297),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5988),
    [anon_sym_COMMA] = ACTIONS(5988),
    [anon_sym_LPAREN2] = ACTIONS(5988),
    [anon_sym_DASH] = ACTIONS(5990),
    [anon_sym_PLUS] = ACTIONS(5990),
    [anon_sym_STAR] = ACTIONS(5988),
    [anon_sym_SLASH] = ACTIONS(5990),
    [anon_sym_PERCENT] = ACTIONS(5988),
    [anon_sym_PIPE_PIPE] = ACTIONS(5988),
    [anon_sym_AMP_AMP] = ACTIONS(5988),
    [anon_sym_PIPE] = ACTIONS(5990),
    [anon_sym_CARET] = ACTIONS(5988),
    [anon_sym_AMP] = ACTIONS(5990),
    [anon_sym_EQ_EQ] = ACTIONS(5988),
    [anon_sym_BANG_EQ] = ACTIONS(5988),
    [anon_sym_GT] = ACTIONS(5990),
    [anon_sym_GT_EQ] = ACTIONS(5990),
    [anon_sym_LT_EQ] = ACTIONS(5990),
    [anon_sym_LT] = ACTIONS(5990),
    [anon_sym_LT_LT] = ACTIONS(5990),
    [anon_sym_GT_GT] = ACTIONS(5990),
    [anon_sym___extension__] = ACTIONS(5988),
    [anon_sym___global__] = ACTIONS(5988),
    [anon_sym___attribute__] = ACTIONS(5988),
    [anon_sym___attribute] = ACTIONS(5990),
    [anon_sym_LBRACE] = ACTIONS(5988),
    [anon_sym_signed] = ACTIONS(6222),
    [anon_sym_unsigned] = ACTIONS(6222),
    [anon_sym_long] = ACTIONS(6222),
    [anon_sym_short] = ACTIONS(6222),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_const] = ACTIONS(5990),
    [anon_sym_constexpr] = ACTIONS(5988),
    [anon_sym_volatile] = ACTIONS(5988),
    [anon_sym_restrict] = ACTIONS(5988),
    [anon_sym___restrict__] = ACTIONS(5988),
    [anon_sym__Atomic] = ACTIONS(5988),
    [anon_sym__Noreturn] = ACTIONS(5988),
    [anon_sym_noreturn] = ACTIONS(5988),
    [anon_sym__Nonnull] = ACTIONS(5988),
    [anon_sym_mutable] = ACTIONS(5988),
    [anon_sym_constinit] = ACTIONS(5988),
    [anon_sym_consteval] = ACTIONS(5988),
    [anon_sym___shared__] = ACTIONS(5988),
    [anon_sym___local__] = ACTIONS(5988),
    [anon_sym___constant__] = ACTIONS(5988),
    [anon_sym___managed__] = ACTIONS(5988),
    [anon_sym___grid_constant__] = ACTIONS(5988),
    [anon_sym_alignas] = ACTIONS(5988),
    [anon_sym__Alignas] = ACTIONS(5988),
    [anon_sym_QMARK] = ACTIONS(5988),
    [anon_sym_LT_EQ_GT] = ACTIONS(5988),
    [anon_sym_or] = ACTIONS(5988),
    [anon_sym_and] = ACTIONS(5988),
    [anon_sym_bitor] = ACTIONS(5988),
    [anon_sym_xor] = ACTIONS(5988),
    [anon_sym_bitand] = ACTIONS(5988),
    [anon_sym_not_eq] = ACTIONS(5988),
    [anon_sym_DASH_DASH] = ACTIONS(5988),
    [anon_sym_PLUS_PLUS] = ACTIONS(5988),
    [anon_sym_DOT] = ACTIONS(5990),
    [anon_sym_DOT_STAR] = ACTIONS(5988),
    [anon_sym_DASH_GT] = ACTIONS(5988),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5988),
    [anon_sym_decltype] = ACTIONS(5988),
    [anon_sym_final] = ACTIONS(5988),
    [anon_sym_override] = ACTIONS(5988),
    [anon_sym_GT2] = ACTIONS(5988),
    [anon_sym_requires] = ACTIONS(5988),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5988),
  },
  [STATE(2295)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2298),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5917),
    [anon_sym_COMMA] = ACTIONS(5917),
    [anon_sym_LPAREN2] = ACTIONS(5917),
    [anon_sym_DASH] = ACTIONS(5919),
    [anon_sym_PLUS] = ACTIONS(5919),
    [anon_sym_STAR] = ACTIONS(5917),
    [anon_sym_SLASH] = ACTIONS(5919),
    [anon_sym_PERCENT] = ACTIONS(5917),
    [anon_sym_PIPE_PIPE] = ACTIONS(5917),
    [anon_sym_AMP_AMP] = ACTIONS(5917),
    [anon_sym_PIPE] = ACTIONS(5919),
    [anon_sym_CARET] = ACTIONS(5917),
    [anon_sym_AMP] = ACTIONS(5919),
    [anon_sym_EQ_EQ] = ACTIONS(5917),
    [anon_sym_BANG_EQ] = ACTIONS(5917),
    [anon_sym_GT] = ACTIONS(5919),
    [anon_sym_GT_EQ] = ACTIONS(5919),
    [anon_sym_LT_EQ] = ACTIONS(5919),
    [anon_sym_LT] = ACTIONS(5919),
    [anon_sym_LT_LT] = ACTIONS(5919),
    [anon_sym_GT_GT] = ACTIONS(5919),
    [anon_sym___extension__] = ACTIONS(5917),
    [anon_sym___global__] = ACTIONS(5917),
    [anon_sym___attribute__] = ACTIONS(5917),
    [anon_sym___attribute] = ACTIONS(5919),
    [anon_sym_LBRACE] = ACTIONS(5917),
    [anon_sym_signed] = ACTIONS(6224),
    [anon_sym_unsigned] = ACTIONS(6224),
    [anon_sym_long] = ACTIONS(6224),
    [anon_sym_short] = ACTIONS(6224),
    [anon_sym_LBRACK] = ACTIONS(5917),
    [anon_sym_const] = ACTIONS(5919),
    [anon_sym_constexpr] = ACTIONS(5917),
    [anon_sym_volatile] = ACTIONS(5917),
    [anon_sym_restrict] = ACTIONS(5917),
    [anon_sym___restrict__] = ACTIONS(5917),
    [anon_sym__Atomic] = ACTIONS(5917),
    [anon_sym__Noreturn] = ACTIONS(5917),
    [anon_sym_noreturn] = ACTIONS(5917),
    [anon_sym__Nonnull] = ACTIONS(5917),
    [anon_sym_mutable] = ACTIONS(5917),
    [anon_sym_constinit] = ACTIONS(5917),
    [anon_sym_consteval] = ACTIONS(5917),
    [anon_sym___shared__] = ACTIONS(5917),
    [anon_sym___local__] = ACTIONS(5917),
    [anon_sym___constant__] = ACTIONS(5917),
    [anon_sym___managed__] = ACTIONS(5917),
    [anon_sym___grid_constant__] = ACTIONS(5917),
    [anon_sym_alignas] = ACTIONS(5917),
    [anon_sym__Alignas] = ACTIONS(5917),
    [anon_sym_QMARK] = ACTIONS(5917),
    [anon_sym_LT_EQ_GT] = ACTIONS(5917),
    [anon_sym_or] = ACTIONS(5917),
    [anon_sym_and] = ACTIONS(5917),
    [anon_sym_bitor] = ACTIONS(5917),
    [anon_sym_xor] = ACTIONS(5917),
    [anon_sym_bitand] = ACTIONS(5917),
    [anon_sym_not_eq] = ACTIONS(5917),
    [anon_sym_DASH_DASH] = ACTIONS(5917),
    [anon_sym_PLUS_PLUS] = ACTIONS(5917),
    [anon_sym_DOT] = ACTIONS(5919),
    [anon_sym_DOT_STAR] = ACTIONS(5917),
    [anon_sym_DASH_GT] = ACTIONS(5917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5917),
    [anon_sym_decltype] = ACTIONS(5917),
    [anon_sym_final] = ACTIONS(5917),
    [anon_sym_override] = ACTIONS(5917),
    [anon_sym_GT2] = ACTIONS(5917),
    [anon_sym_requires] = ACTIONS(5917),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5917),
  },
  [STATE(2296)] = {
    [sym_attribute_specifier] = STATE(2149),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6226),
    [anon_sym_COMMA] = ACTIONS(6226),
    [anon_sym_RPAREN] = ACTIONS(6226),
    [anon_sym_LPAREN2] = ACTIONS(6226),
    [anon_sym_DASH] = ACTIONS(6228),
    [anon_sym_PLUS] = ACTIONS(6228),
    [anon_sym_STAR] = ACTIONS(6226),
    [anon_sym_SLASH] = ACTIONS(6228),
    [anon_sym_PERCENT] = ACTIONS(6226),
    [anon_sym_PIPE_PIPE] = ACTIONS(6226),
    [anon_sym_AMP_AMP] = ACTIONS(6226),
    [anon_sym_PIPE] = ACTIONS(6228),
    [anon_sym_CARET] = ACTIONS(6226),
    [anon_sym_AMP] = ACTIONS(6228),
    [anon_sym_EQ_EQ] = ACTIONS(6226),
    [anon_sym_BANG_EQ] = ACTIONS(6226),
    [anon_sym_GT] = ACTIONS(6228),
    [anon_sym_GT_EQ] = ACTIONS(6226),
    [anon_sym_LT_EQ] = ACTIONS(6228),
    [anon_sym_LT] = ACTIONS(6228),
    [anon_sym_LT_LT] = ACTIONS(6228),
    [anon_sym_GT_GT] = ACTIONS(6226),
    [anon_sym_SEMI] = ACTIONS(6226),
    [anon_sym___extension__] = ACTIONS(6226),
    [anon_sym___global__] = ACTIONS(6226),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6226),
    [anon_sym_RBRACE] = ACTIONS(6226),
    [anon_sym_LBRACK] = ACTIONS(6226),
    [anon_sym_RBRACK] = ACTIONS(6226),
    [anon_sym_const] = ACTIONS(6228),
    [anon_sym_constexpr] = ACTIONS(6226),
    [anon_sym_volatile] = ACTIONS(6226),
    [anon_sym_restrict] = ACTIONS(6226),
    [anon_sym___restrict__] = ACTIONS(6226),
    [anon_sym__Atomic] = ACTIONS(6226),
    [anon_sym__Noreturn] = ACTIONS(6226),
    [anon_sym_noreturn] = ACTIONS(6226),
    [anon_sym__Nonnull] = ACTIONS(6226),
    [anon_sym_mutable] = ACTIONS(6226),
    [anon_sym_constinit] = ACTIONS(6226),
    [anon_sym_consteval] = ACTIONS(6226),
    [anon_sym___shared__] = ACTIONS(6226),
    [anon_sym___local__] = ACTIONS(6226),
    [anon_sym___constant__] = ACTIONS(6226),
    [anon_sym___managed__] = ACTIONS(6226),
    [anon_sym___grid_constant__] = ACTIONS(6226),
    [anon_sym_alignas] = ACTIONS(6226),
    [anon_sym__Alignas] = ACTIONS(6226),
    [anon_sym_COLON] = ACTIONS(6226),
    [anon_sym_QMARK] = ACTIONS(6226),
    [anon_sym_LT_EQ_GT] = ACTIONS(6226),
    [anon_sym_or] = ACTIONS(6226),
    [anon_sym_and] = ACTIONS(6226),
    [anon_sym_bitor] = ACTIONS(6226),
    [anon_sym_xor] = ACTIONS(6226),
    [anon_sym_bitand] = ACTIONS(6226),
    [anon_sym_not_eq] = ACTIONS(6226),
    [anon_sym_DASH_DASH] = ACTIONS(6226),
    [anon_sym_PLUS_PLUS] = ACTIONS(6226),
    [anon_sym_DOT] = ACTIONS(6228),
    [anon_sym_DOT_STAR] = ACTIONS(6226),
    [anon_sym_DASH_GT] = ACTIONS(6226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6226),
    [anon_sym_decltype] = ACTIONS(6226),
    [anon_sym_final] = ACTIONS(6226),
    [anon_sym_override] = ACTIONS(6226),
    [anon_sym_requires] = ACTIONS(6226),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6226),
  },
  [STATE(2297)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5980),
    [anon_sym_COMMA] = ACTIONS(5980),
    [anon_sym_LPAREN2] = ACTIONS(5980),
    [anon_sym_DASH] = ACTIONS(5982),
    [anon_sym_PLUS] = ACTIONS(5982),
    [anon_sym_STAR] = ACTIONS(5980),
    [anon_sym_SLASH] = ACTIONS(5982),
    [anon_sym_PERCENT] = ACTIONS(5980),
    [anon_sym_PIPE_PIPE] = ACTIONS(5980),
    [anon_sym_AMP_AMP] = ACTIONS(5980),
    [anon_sym_PIPE] = ACTIONS(5982),
    [anon_sym_CARET] = ACTIONS(5980),
    [anon_sym_AMP] = ACTIONS(5982),
    [anon_sym_EQ_EQ] = ACTIONS(5980),
    [anon_sym_BANG_EQ] = ACTIONS(5980),
    [anon_sym_GT] = ACTIONS(5982),
    [anon_sym_GT_EQ] = ACTIONS(5982),
    [anon_sym_LT_EQ] = ACTIONS(5982),
    [anon_sym_LT] = ACTIONS(5982),
    [anon_sym_LT_LT] = ACTIONS(5982),
    [anon_sym_GT_GT] = ACTIONS(5982),
    [anon_sym___extension__] = ACTIONS(5980),
    [anon_sym___global__] = ACTIONS(5980),
    [anon_sym___attribute__] = ACTIONS(5980),
    [anon_sym___attribute] = ACTIONS(5982),
    [anon_sym_LBRACE] = ACTIONS(5980),
    [anon_sym_signed] = ACTIONS(6200),
    [anon_sym_unsigned] = ACTIONS(6200),
    [anon_sym_long] = ACTIONS(6200),
    [anon_sym_short] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(5980),
    [anon_sym_const] = ACTIONS(5982),
    [anon_sym_constexpr] = ACTIONS(5980),
    [anon_sym_volatile] = ACTIONS(5980),
    [anon_sym_restrict] = ACTIONS(5980),
    [anon_sym___restrict__] = ACTIONS(5980),
    [anon_sym__Atomic] = ACTIONS(5980),
    [anon_sym__Noreturn] = ACTIONS(5980),
    [anon_sym_noreturn] = ACTIONS(5980),
    [anon_sym__Nonnull] = ACTIONS(5980),
    [anon_sym_mutable] = ACTIONS(5980),
    [anon_sym_constinit] = ACTIONS(5980),
    [anon_sym_consteval] = ACTIONS(5980),
    [anon_sym___shared__] = ACTIONS(5980),
    [anon_sym___local__] = ACTIONS(5980),
    [anon_sym___constant__] = ACTIONS(5980),
    [anon_sym___managed__] = ACTIONS(5980),
    [anon_sym___grid_constant__] = ACTIONS(5980),
    [anon_sym_alignas] = ACTIONS(5980),
    [anon_sym__Alignas] = ACTIONS(5980),
    [anon_sym_QMARK] = ACTIONS(5980),
    [anon_sym_LT_EQ_GT] = ACTIONS(5980),
    [anon_sym_or] = ACTIONS(5980),
    [anon_sym_and] = ACTIONS(5980),
    [anon_sym_bitor] = ACTIONS(5980),
    [anon_sym_xor] = ACTIONS(5980),
    [anon_sym_bitand] = ACTIONS(5980),
    [anon_sym_not_eq] = ACTIONS(5980),
    [anon_sym_DASH_DASH] = ACTIONS(5980),
    [anon_sym_PLUS_PLUS] = ACTIONS(5980),
    [anon_sym_DOT] = ACTIONS(5982),
    [anon_sym_DOT_STAR] = ACTIONS(5980),
    [anon_sym_DASH_GT] = ACTIONS(5980),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5980),
    [anon_sym_decltype] = ACTIONS(5980),
    [anon_sym_final] = ACTIONS(5980),
    [anon_sym_override] = ACTIONS(5980),
    [anon_sym_GT2] = ACTIONS(5980),
    [anon_sym_requires] = ACTIONS(5980),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5980),
  },
  [STATE(2298)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6010),
    [anon_sym_COMMA] = ACTIONS(6010),
    [anon_sym_LPAREN2] = ACTIONS(6010),
    [anon_sym_DASH] = ACTIONS(6012),
    [anon_sym_PLUS] = ACTIONS(6012),
    [anon_sym_STAR] = ACTIONS(6010),
    [anon_sym_SLASH] = ACTIONS(6012),
    [anon_sym_PERCENT] = ACTIONS(6010),
    [anon_sym_PIPE_PIPE] = ACTIONS(6010),
    [anon_sym_AMP_AMP] = ACTIONS(6010),
    [anon_sym_PIPE] = ACTIONS(6012),
    [anon_sym_CARET] = ACTIONS(6010),
    [anon_sym_AMP] = ACTIONS(6012),
    [anon_sym_EQ_EQ] = ACTIONS(6010),
    [anon_sym_BANG_EQ] = ACTIONS(6010),
    [anon_sym_GT] = ACTIONS(6012),
    [anon_sym_GT_EQ] = ACTIONS(6012),
    [anon_sym_LT_EQ] = ACTIONS(6012),
    [anon_sym_LT] = ACTIONS(6012),
    [anon_sym_LT_LT] = ACTIONS(6012),
    [anon_sym_GT_GT] = ACTIONS(6012),
    [anon_sym___extension__] = ACTIONS(6010),
    [anon_sym___global__] = ACTIONS(6010),
    [anon_sym___attribute__] = ACTIONS(6010),
    [anon_sym___attribute] = ACTIONS(6012),
    [anon_sym_LBRACE] = ACTIONS(6010),
    [anon_sym_signed] = ACTIONS(6200),
    [anon_sym_unsigned] = ACTIONS(6200),
    [anon_sym_long] = ACTIONS(6200),
    [anon_sym_short] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(6010),
    [anon_sym_const] = ACTIONS(6012),
    [anon_sym_constexpr] = ACTIONS(6010),
    [anon_sym_volatile] = ACTIONS(6010),
    [anon_sym_restrict] = ACTIONS(6010),
    [anon_sym___restrict__] = ACTIONS(6010),
    [anon_sym__Atomic] = ACTIONS(6010),
    [anon_sym__Noreturn] = ACTIONS(6010),
    [anon_sym_noreturn] = ACTIONS(6010),
    [anon_sym__Nonnull] = ACTIONS(6010),
    [anon_sym_mutable] = ACTIONS(6010),
    [anon_sym_constinit] = ACTIONS(6010),
    [anon_sym_consteval] = ACTIONS(6010),
    [anon_sym___shared__] = ACTIONS(6010),
    [anon_sym___local__] = ACTIONS(6010),
    [anon_sym___constant__] = ACTIONS(6010),
    [anon_sym___managed__] = ACTIONS(6010),
    [anon_sym___grid_constant__] = ACTIONS(6010),
    [anon_sym_alignas] = ACTIONS(6010),
    [anon_sym__Alignas] = ACTIONS(6010),
    [anon_sym_QMARK] = ACTIONS(6010),
    [anon_sym_LT_EQ_GT] = ACTIONS(6010),
    [anon_sym_or] = ACTIONS(6010),
    [anon_sym_and] = ACTIONS(6010),
    [anon_sym_bitor] = ACTIONS(6010),
    [anon_sym_xor] = ACTIONS(6010),
    [anon_sym_bitand] = ACTIONS(6010),
    [anon_sym_not_eq] = ACTIONS(6010),
    [anon_sym_DASH_DASH] = ACTIONS(6010),
    [anon_sym_PLUS_PLUS] = ACTIONS(6010),
    [anon_sym_DOT] = ACTIONS(6012),
    [anon_sym_DOT_STAR] = ACTIONS(6010),
    [anon_sym_DASH_GT] = ACTIONS(6010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6010),
    [anon_sym_decltype] = ACTIONS(6010),
    [anon_sym_final] = ACTIONS(6010),
    [anon_sym_override] = ACTIONS(6010),
    [anon_sym_GT2] = ACTIONS(6010),
    [anon_sym_requires] = ACTIONS(6010),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6010),
  },
  [STATE(2299)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2314),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5966),
    [anon_sym_COMMA] = ACTIONS(5966),
    [anon_sym_LPAREN2] = ACTIONS(5966),
    [anon_sym_DASH] = ACTIONS(5968),
    [anon_sym_PLUS] = ACTIONS(5968),
    [anon_sym_STAR] = ACTIONS(5966),
    [anon_sym_SLASH] = ACTIONS(5968),
    [anon_sym_PERCENT] = ACTIONS(5966),
    [anon_sym_PIPE_PIPE] = ACTIONS(5966),
    [anon_sym_AMP_AMP] = ACTIONS(5966),
    [anon_sym_PIPE] = ACTIONS(5968),
    [anon_sym_CARET] = ACTIONS(5966),
    [anon_sym_AMP] = ACTIONS(5968),
    [anon_sym_EQ_EQ] = ACTIONS(5966),
    [anon_sym_BANG_EQ] = ACTIONS(5966),
    [anon_sym_GT] = ACTIONS(5968),
    [anon_sym_GT_EQ] = ACTIONS(5968),
    [anon_sym_LT_EQ] = ACTIONS(5968),
    [anon_sym_LT] = ACTIONS(5968),
    [anon_sym_LT_LT] = ACTIONS(5968),
    [anon_sym_GT_GT] = ACTIONS(5968),
    [anon_sym___extension__] = ACTIONS(5966),
    [anon_sym___global__] = ACTIONS(5966),
    [anon_sym___attribute__] = ACTIONS(5966),
    [anon_sym___attribute] = ACTIONS(5968),
    [anon_sym_LBRACE] = ACTIONS(5966),
    [anon_sym_signed] = ACTIONS(6230),
    [anon_sym_unsigned] = ACTIONS(6230),
    [anon_sym_long] = ACTIONS(6230),
    [anon_sym_short] = ACTIONS(6230),
    [anon_sym_LBRACK] = ACTIONS(5966),
    [anon_sym_const] = ACTIONS(5968),
    [anon_sym_constexpr] = ACTIONS(5966),
    [anon_sym_volatile] = ACTIONS(5966),
    [anon_sym_restrict] = ACTIONS(5966),
    [anon_sym___restrict__] = ACTIONS(5966),
    [anon_sym__Atomic] = ACTIONS(5966),
    [anon_sym__Noreturn] = ACTIONS(5966),
    [anon_sym_noreturn] = ACTIONS(5966),
    [anon_sym__Nonnull] = ACTIONS(5966),
    [anon_sym_mutable] = ACTIONS(5966),
    [anon_sym_constinit] = ACTIONS(5966),
    [anon_sym_consteval] = ACTIONS(5966),
    [anon_sym___shared__] = ACTIONS(5966),
    [anon_sym___local__] = ACTIONS(5966),
    [anon_sym___constant__] = ACTIONS(5966),
    [anon_sym___managed__] = ACTIONS(5966),
    [anon_sym___grid_constant__] = ACTIONS(5966),
    [anon_sym_alignas] = ACTIONS(5966),
    [anon_sym__Alignas] = ACTIONS(5966),
    [anon_sym_QMARK] = ACTIONS(5966),
    [anon_sym_LT_EQ_GT] = ACTIONS(5966),
    [anon_sym_or] = ACTIONS(5966),
    [anon_sym_and] = ACTIONS(5966),
    [anon_sym_bitor] = ACTIONS(5966),
    [anon_sym_xor] = ACTIONS(5966),
    [anon_sym_bitand] = ACTIONS(5966),
    [anon_sym_not_eq] = ACTIONS(5966),
    [anon_sym_DASH_DASH] = ACTIONS(5966),
    [anon_sym_PLUS_PLUS] = ACTIONS(5966),
    [anon_sym_DOT] = ACTIONS(5968),
    [anon_sym_DOT_STAR] = ACTIONS(5966),
    [anon_sym_DASH_GT] = ACTIONS(5966),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5966),
    [anon_sym_decltype] = ACTIONS(5966),
    [anon_sym_final] = ACTIONS(5966),
    [anon_sym_override] = ACTIONS(5966),
    [anon_sym_GT2] = ACTIONS(5966),
    [anon_sym_requires] = ACTIONS(5966),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5966),
  },
  [STATE(2300)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2315),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5994),
    [anon_sym_COMMA] = ACTIONS(5994),
    [anon_sym_LPAREN2] = ACTIONS(5994),
    [anon_sym_DASH] = ACTIONS(5996),
    [anon_sym_PLUS] = ACTIONS(5996),
    [anon_sym_STAR] = ACTIONS(5994),
    [anon_sym_SLASH] = ACTIONS(5996),
    [anon_sym_PERCENT] = ACTIONS(5994),
    [anon_sym_PIPE_PIPE] = ACTIONS(5994),
    [anon_sym_AMP_AMP] = ACTIONS(5994),
    [anon_sym_PIPE] = ACTIONS(5996),
    [anon_sym_CARET] = ACTIONS(5994),
    [anon_sym_AMP] = ACTIONS(5996),
    [anon_sym_EQ_EQ] = ACTIONS(5994),
    [anon_sym_BANG_EQ] = ACTIONS(5994),
    [anon_sym_GT] = ACTIONS(5996),
    [anon_sym_GT_EQ] = ACTIONS(5996),
    [anon_sym_LT_EQ] = ACTIONS(5996),
    [anon_sym_LT] = ACTIONS(5996),
    [anon_sym_LT_LT] = ACTIONS(5996),
    [anon_sym_GT_GT] = ACTIONS(5996),
    [anon_sym___extension__] = ACTIONS(5994),
    [anon_sym___global__] = ACTIONS(5994),
    [anon_sym___attribute__] = ACTIONS(5994),
    [anon_sym___attribute] = ACTIONS(5996),
    [anon_sym_LBRACE] = ACTIONS(5994),
    [anon_sym_signed] = ACTIONS(6232),
    [anon_sym_unsigned] = ACTIONS(6232),
    [anon_sym_long] = ACTIONS(6232),
    [anon_sym_short] = ACTIONS(6232),
    [anon_sym_LBRACK] = ACTIONS(5994),
    [anon_sym_const] = ACTIONS(5996),
    [anon_sym_constexpr] = ACTIONS(5994),
    [anon_sym_volatile] = ACTIONS(5994),
    [anon_sym_restrict] = ACTIONS(5994),
    [anon_sym___restrict__] = ACTIONS(5994),
    [anon_sym__Atomic] = ACTIONS(5994),
    [anon_sym__Noreturn] = ACTIONS(5994),
    [anon_sym_noreturn] = ACTIONS(5994),
    [anon_sym__Nonnull] = ACTIONS(5994),
    [anon_sym_mutable] = ACTIONS(5994),
    [anon_sym_constinit] = ACTIONS(5994),
    [anon_sym_consteval] = ACTIONS(5994),
    [anon_sym___shared__] = ACTIONS(5994),
    [anon_sym___local__] = ACTIONS(5994),
    [anon_sym___constant__] = ACTIONS(5994),
    [anon_sym___managed__] = ACTIONS(5994),
    [anon_sym___grid_constant__] = ACTIONS(5994),
    [anon_sym_alignas] = ACTIONS(5994),
    [anon_sym__Alignas] = ACTIONS(5994),
    [anon_sym_QMARK] = ACTIONS(5994),
    [anon_sym_LT_EQ_GT] = ACTIONS(5994),
    [anon_sym_or] = ACTIONS(5994),
    [anon_sym_and] = ACTIONS(5994),
    [anon_sym_bitor] = ACTIONS(5994),
    [anon_sym_xor] = ACTIONS(5994),
    [anon_sym_bitand] = ACTIONS(5994),
    [anon_sym_not_eq] = ACTIONS(5994),
    [anon_sym_DASH_DASH] = ACTIONS(5994),
    [anon_sym_PLUS_PLUS] = ACTIONS(5994),
    [anon_sym_DOT] = ACTIONS(5996),
    [anon_sym_DOT_STAR] = ACTIONS(5994),
    [anon_sym_DASH_GT] = ACTIONS(5994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5994),
    [anon_sym_decltype] = ACTIONS(5994),
    [anon_sym_final] = ACTIONS(5994),
    [anon_sym_override] = ACTIONS(5994),
    [anon_sym_GT2] = ACTIONS(5994),
    [anon_sym_requires] = ACTIONS(5994),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5994),
  },
  [STATE(2301)] = {
    [sym_attribute_specifier] = STATE(2141),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6234),
    [anon_sym_COMMA] = ACTIONS(6234),
    [anon_sym_RPAREN] = ACTIONS(6234),
    [anon_sym_LPAREN2] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6236),
    [anon_sym_PLUS] = ACTIONS(6236),
    [anon_sym_STAR] = ACTIONS(6234),
    [anon_sym_SLASH] = ACTIONS(6236),
    [anon_sym_PERCENT] = ACTIONS(6234),
    [anon_sym_PIPE_PIPE] = ACTIONS(6234),
    [anon_sym_AMP_AMP] = ACTIONS(6234),
    [anon_sym_PIPE] = ACTIONS(6236),
    [anon_sym_CARET] = ACTIONS(6234),
    [anon_sym_AMP] = ACTIONS(6236),
    [anon_sym_EQ_EQ] = ACTIONS(6234),
    [anon_sym_BANG_EQ] = ACTIONS(6234),
    [anon_sym_GT] = ACTIONS(6236),
    [anon_sym_GT_EQ] = ACTIONS(6234),
    [anon_sym_LT_EQ] = ACTIONS(6236),
    [anon_sym_LT] = ACTIONS(6236),
    [anon_sym_LT_LT] = ACTIONS(6236),
    [anon_sym_GT_GT] = ACTIONS(6234),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym___extension__] = ACTIONS(6234),
    [anon_sym___global__] = ACTIONS(6234),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6234),
    [anon_sym_RBRACE] = ACTIONS(6234),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [anon_sym_RBRACK] = ACTIONS(6234),
    [anon_sym_const] = ACTIONS(6236),
    [anon_sym_constexpr] = ACTIONS(6234),
    [anon_sym_volatile] = ACTIONS(6234),
    [anon_sym_restrict] = ACTIONS(6234),
    [anon_sym___restrict__] = ACTIONS(6234),
    [anon_sym__Atomic] = ACTIONS(6234),
    [anon_sym__Noreturn] = ACTIONS(6234),
    [anon_sym_noreturn] = ACTIONS(6234),
    [anon_sym__Nonnull] = ACTIONS(6234),
    [anon_sym_mutable] = ACTIONS(6234),
    [anon_sym_constinit] = ACTIONS(6234),
    [anon_sym_consteval] = ACTIONS(6234),
    [anon_sym___shared__] = ACTIONS(6234),
    [anon_sym___local__] = ACTIONS(6234),
    [anon_sym___constant__] = ACTIONS(6234),
    [anon_sym___managed__] = ACTIONS(6234),
    [anon_sym___grid_constant__] = ACTIONS(6234),
    [anon_sym_alignas] = ACTIONS(6234),
    [anon_sym__Alignas] = ACTIONS(6234),
    [anon_sym_COLON] = ACTIONS(6234),
    [anon_sym_QMARK] = ACTIONS(6234),
    [anon_sym_LT_EQ_GT] = ACTIONS(6234),
    [anon_sym_or] = ACTIONS(6234),
    [anon_sym_and] = ACTIONS(6234),
    [anon_sym_bitor] = ACTIONS(6234),
    [anon_sym_xor] = ACTIONS(6234),
    [anon_sym_bitand] = ACTIONS(6234),
    [anon_sym_not_eq] = ACTIONS(6234),
    [anon_sym_DASH_DASH] = ACTIONS(6234),
    [anon_sym_PLUS_PLUS] = ACTIONS(6234),
    [anon_sym_DOT] = ACTIONS(6236),
    [anon_sym_DOT_STAR] = ACTIONS(6234),
    [anon_sym_DASH_GT] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6234),
    [anon_sym_decltype] = ACTIONS(6234),
    [anon_sym_final] = ACTIONS(6234),
    [anon_sym_override] = ACTIONS(6234),
    [anon_sym_requires] = ACTIONS(6234),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6234),
  },
  [STATE(2302)] = {
    [sym_attribute_specifier] = STATE(2115),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6238),
    [anon_sym_COMMA] = ACTIONS(6238),
    [anon_sym_RPAREN] = ACTIONS(6238),
    [anon_sym_LPAREN2] = ACTIONS(6238),
    [anon_sym_DASH] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6240),
    [anon_sym_STAR] = ACTIONS(6238),
    [anon_sym_SLASH] = ACTIONS(6240),
    [anon_sym_PERCENT] = ACTIONS(6238),
    [anon_sym_PIPE_PIPE] = ACTIONS(6238),
    [anon_sym_AMP_AMP] = ACTIONS(6238),
    [anon_sym_PIPE] = ACTIONS(6240),
    [anon_sym_CARET] = ACTIONS(6238),
    [anon_sym_AMP] = ACTIONS(6240),
    [anon_sym_EQ_EQ] = ACTIONS(6238),
    [anon_sym_BANG_EQ] = ACTIONS(6238),
    [anon_sym_GT] = ACTIONS(6240),
    [anon_sym_GT_EQ] = ACTIONS(6238),
    [anon_sym_LT_EQ] = ACTIONS(6240),
    [anon_sym_LT] = ACTIONS(6240),
    [anon_sym_LT_LT] = ACTIONS(6240),
    [anon_sym_GT_GT] = ACTIONS(6238),
    [anon_sym_SEMI] = ACTIONS(6238),
    [anon_sym___extension__] = ACTIONS(6238),
    [anon_sym___global__] = ACTIONS(6238),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6238),
    [anon_sym_RBRACE] = ACTIONS(6238),
    [anon_sym_LBRACK] = ACTIONS(6238),
    [anon_sym_RBRACK] = ACTIONS(6238),
    [anon_sym_const] = ACTIONS(6240),
    [anon_sym_constexpr] = ACTIONS(6238),
    [anon_sym_volatile] = ACTIONS(6238),
    [anon_sym_restrict] = ACTIONS(6238),
    [anon_sym___restrict__] = ACTIONS(6238),
    [anon_sym__Atomic] = ACTIONS(6238),
    [anon_sym__Noreturn] = ACTIONS(6238),
    [anon_sym_noreturn] = ACTIONS(6238),
    [anon_sym__Nonnull] = ACTIONS(6238),
    [anon_sym_mutable] = ACTIONS(6238),
    [anon_sym_constinit] = ACTIONS(6238),
    [anon_sym_consteval] = ACTIONS(6238),
    [anon_sym___shared__] = ACTIONS(6238),
    [anon_sym___local__] = ACTIONS(6238),
    [anon_sym___constant__] = ACTIONS(6238),
    [anon_sym___managed__] = ACTIONS(6238),
    [anon_sym___grid_constant__] = ACTIONS(6238),
    [anon_sym_alignas] = ACTIONS(6238),
    [anon_sym__Alignas] = ACTIONS(6238),
    [anon_sym_COLON] = ACTIONS(6238),
    [anon_sym_QMARK] = ACTIONS(6238),
    [anon_sym_LT_EQ_GT] = ACTIONS(6238),
    [anon_sym_or] = ACTIONS(6238),
    [anon_sym_and] = ACTIONS(6238),
    [anon_sym_bitor] = ACTIONS(6238),
    [anon_sym_xor] = ACTIONS(6238),
    [anon_sym_bitand] = ACTIONS(6238),
    [anon_sym_not_eq] = ACTIONS(6238),
    [anon_sym_DASH_DASH] = ACTIONS(6238),
    [anon_sym_PLUS_PLUS] = ACTIONS(6238),
    [anon_sym_DOT] = ACTIONS(6240),
    [anon_sym_DOT_STAR] = ACTIONS(6238),
    [anon_sym_DASH_GT] = ACTIONS(6238),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6238),
    [anon_sym_decltype] = ACTIONS(6238),
    [anon_sym_final] = ACTIONS(6238),
    [anon_sym_override] = ACTIONS(6238),
    [anon_sym_requires] = ACTIONS(6238),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6238),
  },
  [STATE(2303)] = {
    [sym_attribute_specifier] = STATE(2139),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6242),
    [anon_sym_COMMA] = ACTIONS(6242),
    [anon_sym_RPAREN] = ACTIONS(6242),
    [anon_sym_LPAREN2] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6244),
    [anon_sym_PLUS] = ACTIONS(6244),
    [anon_sym_STAR] = ACTIONS(6242),
    [anon_sym_SLASH] = ACTIONS(6244),
    [anon_sym_PERCENT] = ACTIONS(6242),
    [anon_sym_PIPE_PIPE] = ACTIONS(6242),
    [anon_sym_AMP_AMP] = ACTIONS(6242),
    [anon_sym_PIPE] = ACTIONS(6244),
    [anon_sym_CARET] = ACTIONS(6242),
    [anon_sym_AMP] = ACTIONS(6244),
    [anon_sym_EQ_EQ] = ACTIONS(6242),
    [anon_sym_BANG_EQ] = ACTIONS(6242),
    [anon_sym_GT] = ACTIONS(6244),
    [anon_sym_GT_EQ] = ACTIONS(6242),
    [anon_sym_LT_EQ] = ACTIONS(6244),
    [anon_sym_LT] = ACTIONS(6244),
    [anon_sym_LT_LT] = ACTIONS(6244),
    [anon_sym_GT_GT] = ACTIONS(6242),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym___extension__] = ACTIONS(6242),
    [anon_sym___global__] = ACTIONS(6242),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6242),
    [anon_sym_RBRACE] = ACTIONS(6242),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [anon_sym_RBRACK] = ACTIONS(6242),
    [anon_sym_const] = ACTIONS(6244),
    [anon_sym_constexpr] = ACTIONS(6242),
    [anon_sym_volatile] = ACTIONS(6242),
    [anon_sym_restrict] = ACTIONS(6242),
    [anon_sym___restrict__] = ACTIONS(6242),
    [anon_sym__Atomic] = ACTIONS(6242),
    [anon_sym__Noreturn] = ACTIONS(6242),
    [anon_sym_noreturn] = ACTIONS(6242),
    [anon_sym__Nonnull] = ACTIONS(6242),
    [anon_sym_mutable] = ACTIONS(6242),
    [anon_sym_constinit] = ACTIONS(6242),
    [anon_sym_consteval] = ACTIONS(6242),
    [anon_sym___shared__] = ACTIONS(6242),
    [anon_sym___local__] = ACTIONS(6242),
    [anon_sym___constant__] = ACTIONS(6242),
    [anon_sym___managed__] = ACTIONS(6242),
    [anon_sym___grid_constant__] = ACTIONS(6242),
    [anon_sym_alignas] = ACTIONS(6242),
    [anon_sym__Alignas] = ACTIONS(6242),
    [anon_sym_COLON] = ACTIONS(6242),
    [anon_sym_QMARK] = ACTIONS(6242),
    [anon_sym_LT_EQ_GT] = ACTIONS(6242),
    [anon_sym_or] = ACTIONS(6242),
    [anon_sym_and] = ACTIONS(6242),
    [anon_sym_bitor] = ACTIONS(6242),
    [anon_sym_xor] = ACTIONS(6242),
    [anon_sym_bitand] = ACTIONS(6242),
    [anon_sym_not_eq] = ACTIONS(6242),
    [anon_sym_DASH_DASH] = ACTIONS(6242),
    [anon_sym_PLUS_PLUS] = ACTIONS(6242),
    [anon_sym_DOT] = ACTIONS(6244),
    [anon_sym_DOT_STAR] = ACTIONS(6242),
    [anon_sym_DASH_GT] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6242),
    [anon_sym_decltype] = ACTIONS(6242),
    [anon_sym_final] = ACTIONS(6242),
    [anon_sym_override] = ACTIONS(6242),
    [anon_sym_requires] = ACTIONS(6242),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6242),
  },
  [STATE(2304)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2319),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_DASH] = ACTIONS(5770),
    [anon_sym_PLUS] = ACTIONS(5770),
    [anon_sym_STAR] = ACTIONS(5772),
    [anon_sym_SLASH] = ACTIONS(5770),
    [anon_sym_PERCENT] = ACTIONS(5772),
    [anon_sym_PIPE_PIPE] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_PIPE] = ACTIONS(5770),
    [anon_sym_CARET] = ACTIONS(5772),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_EQ_EQ] = ACTIONS(5772),
    [anon_sym_BANG_EQ] = ACTIONS(5772),
    [anon_sym_GT] = ACTIONS(5770),
    [anon_sym_GT_EQ] = ACTIONS(5770),
    [anon_sym_LT_EQ] = ACTIONS(5770),
    [anon_sym_LT] = ACTIONS(5770),
    [anon_sym_LT_LT] = ACTIONS(5770),
    [anon_sym_GT_GT] = ACTIONS(5770),
    [anon_sym___extension__] = ACTIONS(5772),
    [anon_sym___global__] = ACTIONS(5772),
    [anon_sym___attribute__] = ACTIONS(5772),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_signed] = ACTIONS(6246),
    [anon_sym_unsigned] = ACTIONS(6246),
    [anon_sym_long] = ACTIONS(6246),
    [anon_sym_short] = ACTIONS(6246),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_constexpr] = ACTIONS(5772),
    [anon_sym_volatile] = ACTIONS(5772),
    [anon_sym_restrict] = ACTIONS(5772),
    [anon_sym___restrict__] = ACTIONS(5772),
    [anon_sym__Atomic] = ACTIONS(5772),
    [anon_sym__Noreturn] = ACTIONS(5772),
    [anon_sym_noreturn] = ACTIONS(5772),
    [anon_sym__Nonnull] = ACTIONS(5772),
    [anon_sym_mutable] = ACTIONS(5772),
    [anon_sym_constinit] = ACTIONS(5772),
    [anon_sym_consteval] = ACTIONS(5772),
    [anon_sym___shared__] = ACTIONS(5772),
    [anon_sym___local__] = ACTIONS(5772),
    [anon_sym___constant__] = ACTIONS(5772),
    [anon_sym___managed__] = ACTIONS(5772),
    [anon_sym___grid_constant__] = ACTIONS(5772),
    [anon_sym_alignas] = ACTIONS(5772),
    [anon_sym__Alignas] = ACTIONS(5772),
    [anon_sym_QMARK] = ACTIONS(5772),
    [anon_sym_LT_EQ_GT] = ACTIONS(5772),
    [anon_sym_or] = ACTIONS(5772),
    [anon_sym_and] = ACTIONS(5772),
    [anon_sym_bitor] = ACTIONS(5772),
    [anon_sym_xor] = ACTIONS(5772),
    [anon_sym_bitand] = ACTIONS(5772),
    [anon_sym_not_eq] = ACTIONS(5772),
    [anon_sym_DASH_DASH] = ACTIONS(5772),
    [anon_sym_PLUS_PLUS] = ACTIONS(5772),
    [anon_sym_DOT] = ACTIONS(5770),
    [anon_sym_DOT_STAR] = ACTIONS(5772),
    [anon_sym_DASH_GT] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5772),
    [anon_sym_decltype] = ACTIONS(5772),
    [anon_sym_final] = ACTIONS(5772),
    [anon_sym_override] = ACTIONS(5772),
    [anon_sym_GT2] = ACTIONS(5772),
    [anon_sym_requires] = ACTIONS(5772),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5772),
  },
  [STATE(2305)] = {
    [sym_identifier] = ACTIONS(4330),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_RPAREN] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_TILDE] = ACTIONS(4332),
    [anon_sym_STAR] = ACTIONS(4332),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_SEMI] = ACTIONS(4332),
    [anon_sym___extension__] = ACTIONS(4330),
    [anon_sym___device__] = ACTIONS(4330),
    [anon_sym___host__] = ACTIONS(4330),
    [anon_sym___global__] = ACTIONS(4330),
    [anon_sym___forceinline__] = ACTIONS(4330),
    [anon_sym___noinline__] = ACTIONS(4330),
    [anon_sym_virtual] = ACTIONS(4330),
    [anon_sym_extern] = ACTIONS(4330),
    [anon_sym___attribute__] = ACTIONS(4330),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4332),
    [anon_sym___declspec] = ACTIONS(4330),
    [anon_sym___based] = ACTIONS(4330),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4330),
    [anon_sym_static] = ACTIONS(4330),
    [anon_sym_EQ] = ACTIONS(4332),
    [anon_sym_register] = ACTIONS(4330),
    [anon_sym_inline] = ACTIONS(4330),
    [anon_sym___inline] = ACTIONS(4330),
    [anon_sym___inline__] = ACTIONS(4330),
    [anon_sym___forceinline] = ACTIONS(4330),
    [anon_sym_thread_local] = ACTIONS(4330),
    [anon_sym___thread] = ACTIONS(4330),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4330),
    [anon_sym_volatile] = ACTIONS(4330),
    [anon_sym_restrict] = ACTIONS(4330),
    [anon_sym___restrict__] = ACTIONS(4330),
    [anon_sym__Atomic] = ACTIONS(4330),
    [anon_sym__Noreturn] = ACTIONS(4330),
    [anon_sym_noreturn] = ACTIONS(4330),
    [anon_sym__Nonnull] = ACTIONS(4330),
    [anon_sym_mutable] = ACTIONS(4330),
    [anon_sym_constinit] = ACTIONS(4330),
    [anon_sym_consteval] = ACTIONS(4330),
    [anon_sym___shared__] = ACTIONS(4330),
    [anon_sym___local__] = ACTIONS(4330),
    [anon_sym___constant__] = ACTIONS(4330),
    [anon_sym___managed__] = ACTIONS(4330),
    [anon_sym___grid_constant__] = ACTIONS(4330),
    [anon_sym_alignas] = ACTIONS(4330),
    [anon_sym__Alignas] = ACTIONS(4330),
    [anon_sym_COLON] = ACTIONS(4330),
    [anon_sym_or] = ACTIONS(4330),
    [anon_sym_and] = ACTIONS(4330),
    [anon_sym_asm] = ACTIONS(4330),
    [anon_sym___asm__] = ACTIONS(4330),
    [anon_sym___asm] = ACTIONS(4330),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4330),
    [anon_sym_decltype] = ACTIONS(4330),
    [anon_sym_final] = ACTIONS(4330),
    [anon_sym_override] = ACTIONS(4330),
    [anon_sym_template] = ACTIONS(4330),
    [anon_sym_GT2] = ACTIONS(4332),
    [anon_sym_operator] = ACTIONS(4330),
    [anon_sym_try] = ACTIONS(4330),
    [anon_sym_requires] = ACTIONS(4330),
    [anon_sym___launch_bounds__] = ACTIONS(4330),
  },
  [STATE(2306)] = {
    [sym_attribute_specifier] = STATE(2121),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6248),
    [anon_sym_COMMA] = ACTIONS(6248),
    [anon_sym_RPAREN] = ACTIONS(6248),
    [anon_sym_LPAREN2] = ACTIONS(6248),
    [anon_sym_DASH] = ACTIONS(6250),
    [anon_sym_PLUS] = ACTIONS(6250),
    [anon_sym_STAR] = ACTIONS(6248),
    [anon_sym_SLASH] = ACTIONS(6250),
    [anon_sym_PERCENT] = ACTIONS(6248),
    [anon_sym_PIPE_PIPE] = ACTIONS(6248),
    [anon_sym_AMP_AMP] = ACTIONS(6248),
    [anon_sym_PIPE] = ACTIONS(6250),
    [anon_sym_CARET] = ACTIONS(6248),
    [anon_sym_AMP] = ACTIONS(6250),
    [anon_sym_EQ_EQ] = ACTIONS(6248),
    [anon_sym_BANG_EQ] = ACTIONS(6248),
    [anon_sym_GT] = ACTIONS(6250),
    [anon_sym_GT_EQ] = ACTIONS(6248),
    [anon_sym_LT_EQ] = ACTIONS(6250),
    [anon_sym_LT] = ACTIONS(6250),
    [anon_sym_LT_LT] = ACTIONS(6250),
    [anon_sym_GT_GT] = ACTIONS(6248),
    [anon_sym_SEMI] = ACTIONS(6248),
    [anon_sym___extension__] = ACTIONS(6248),
    [anon_sym___global__] = ACTIONS(6248),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6248),
    [anon_sym_RBRACE] = ACTIONS(6248),
    [anon_sym_LBRACK] = ACTIONS(6248),
    [anon_sym_RBRACK] = ACTIONS(6248),
    [anon_sym_const] = ACTIONS(6250),
    [anon_sym_constexpr] = ACTIONS(6248),
    [anon_sym_volatile] = ACTIONS(6248),
    [anon_sym_restrict] = ACTIONS(6248),
    [anon_sym___restrict__] = ACTIONS(6248),
    [anon_sym__Atomic] = ACTIONS(6248),
    [anon_sym__Noreturn] = ACTIONS(6248),
    [anon_sym_noreturn] = ACTIONS(6248),
    [anon_sym__Nonnull] = ACTIONS(6248),
    [anon_sym_mutable] = ACTIONS(6248),
    [anon_sym_constinit] = ACTIONS(6248),
    [anon_sym_consteval] = ACTIONS(6248),
    [anon_sym___shared__] = ACTIONS(6248),
    [anon_sym___local__] = ACTIONS(6248),
    [anon_sym___constant__] = ACTIONS(6248),
    [anon_sym___managed__] = ACTIONS(6248),
    [anon_sym___grid_constant__] = ACTIONS(6248),
    [anon_sym_alignas] = ACTIONS(6248),
    [anon_sym__Alignas] = ACTIONS(6248),
    [anon_sym_COLON] = ACTIONS(6248),
    [anon_sym_QMARK] = ACTIONS(6248),
    [anon_sym_LT_EQ_GT] = ACTIONS(6248),
    [anon_sym_or] = ACTIONS(6248),
    [anon_sym_and] = ACTIONS(6248),
    [anon_sym_bitor] = ACTIONS(6248),
    [anon_sym_xor] = ACTIONS(6248),
    [anon_sym_bitand] = ACTIONS(6248),
    [anon_sym_not_eq] = ACTIONS(6248),
    [anon_sym_DASH_DASH] = ACTIONS(6248),
    [anon_sym_PLUS_PLUS] = ACTIONS(6248),
    [anon_sym_DOT] = ACTIONS(6250),
    [anon_sym_DOT_STAR] = ACTIONS(6248),
    [anon_sym_DASH_GT] = ACTIONS(6248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6248),
    [anon_sym_decltype] = ACTIONS(6248),
    [anon_sym_final] = ACTIONS(6248),
    [anon_sym_override] = ACTIONS(6248),
    [anon_sym_requires] = ACTIONS(6248),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6248),
  },
  [STATE(2307)] = {
    [sym_attribute_specifier] = STATE(2136),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6252),
    [anon_sym_COMMA] = ACTIONS(6252),
    [anon_sym_RPAREN] = ACTIONS(6252),
    [anon_sym_LPAREN2] = ACTIONS(6252),
    [anon_sym_DASH] = ACTIONS(6254),
    [anon_sym_PLUS] = ACTIONS(6254),
    [anon_sym_STAR] = ACTIONS(6252),
    [anon_sym_SLASH] = ACTIONS(6254),
    [anon_sym_PERCENT] = ACTIONS(6252),
    [anon_sym_PIPE_PIPE] = ACTIONS(6252),
    [anon_sym_AMP_AMP] = ACTIONS(6252),
    [anon_sym_PIPE] = ACTIONS(6254),
    [anon_sym_CARET] = ACTIONS(6252),
    [anon_sym_AMP] = ACTIONS(6254),
    [anon_sym_EQ_EQ] = ACTIONS(6252),
    [anon_sym_BANG_EQ] = ACTIONS(6252),
    [anon_sym_GT] = ACTIONS(6254),
    [anon_sym_GT_EQ] = ACTIONS(6252),
    [anon_sym_LT_EQ] = ACTIONS(6254),
    [anon_sym_LT] = ACTIONS(6254),
    [anon_sym_LT_LT] = ACTIONS(6254),
    [anon_sym_GT_GT] = ACTIONS(6252),
    [anon_sym_SEMI] = ACTIONS(6252),
    [anon_sym___extension__] = ACTIONS(6252),
    [anon_sym___global__] = ACTIONS(6252),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6252),
    [anon_sym_RBRACE] = ACTIONS(6252),
    [anon_sym_LBRACK] = ACTIONS(6252),
    [anon_sym_RBRACK] = ACTIONS(6252),
    [anon_sym_const] = ACTIONS(6254),
    [anon_sym_constexpr] = ACTIONS(6252),
    [anon_sym_volatile] = ACTIONS(6252),
    [anon_sym_restrict] = ACTIONS(6252),
    [anon_sym___restrict__] = ACTIONS(6252),
    [anon_sym__Atomic] = ACTIONS(6252),
    [anon_sym__Noreturn] = ACTIONS(6252),
    [anon_sym_noreturn] = ACTIONS(6252),
    [anon_sym__Nonnull] = ACTIONS(6252),
    [anon_sym_mutable] = ACTIONS(6252),
    [anon_sym_constinit] = ACTIONS(6252),
    [anon_sym_consteval] = ACTIONS(6252),
    [anon_sym___shared__] = ACTIONS(6252),
    [anon_sym___local__] = ACTIONS(6252),
    [anon_sym___constant__] = ACTIONS(6252),
    [anon_sym___managed__] = ACTIONS(6252),
    [anon_sym___grid_constant__] = ACTIONS(6252),
    [anon_sym_alignas] = ACTIONS(6252),
    [anon_sym__Alignas] = ACTIONS(6252),
    [anon_sym_COLON] = ACTIONS(6252),
    [anon_sym_QMARK] = ACTIONS(6252),
    [anon_sym_LT_EQ_GT] = ACTIONS(6252),
    [anon_sym_or] = ACTIONS(6252),
    [anon_sym_and] = ACTIONS(6252),
    [anon_sym_bitor] = ACTIONS(6252),
    [anon_sym_xor] = ACTIONS(6252),
    [anon_sym_bitand] = ACTIONS(6252),
    [anon_sym_not_eq] = ACTIONS(6252),
    [anon_sym_DASH_DASH] = ACTIONS(6252),
    [anon_sym_PLUS_PLUS] = ACTIONS(6252),
    [anon_sym_DOT] = ACTIONS(6254),
    [anon_sym_DOT_STAR] = ACTIONS(6252),
    [anon_sym_DASH_GT] = ACTIONS(6252),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6252),
    [anon_sym_decltype] = ACTIONS(6252),
    [anon_sym_final] = ACTIONS(6252),
    [anon_sym_override] = ACTIONS(6252),
    [anon_sym_requires] = ACTIONS(6252),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6252),
  },
  [STATE(2308)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2327),
    [sym_identifier] = ACTIONS(6008),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6006),
    [anon_sym_COMMA] = ACTIONS(6006),
    [anon_sym_RPAREN] = ACTIONS(6006),
    [anon_sym_LPAREN2] = ACTIONS(6006),
    [anon_sym_TILDE] = ACTIONS(6006),
    [anon_sym_STAR] = ACTIONS(6006),
    [anon_sym_AMP_AMP] = ACTIONS(6006),
    [anon_sym_AMP] = ACTIONS(6008),
    [anon_sym_SEMI] = ACTIONS(6006),
    [anon_sym___extension__] = ACTIONS(6008),
    [anon_sym___device__] = ACTIONS(6008),
    [anon_sym___host__] = ACTIONS(6008),
    [anon_sym___global__] = ACTIONS(6008),
    [anon_sym___forceinline__] = ACTIONS(6008),
    [anon_sym___noinline__] = ACTIONS(6008),
    [anon_sym_virtual] = ACTIONS(6008),
    [anon_sym_extern] = ACTIONS(6008),
    [anon_sym___attribute__] = ACTIONS(6008),
    [anon_sym___attribute] = ACTIONS(6008),
    [anon_sym_COLON_COLON] = ACTIONS(6006),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6006),
    [anon_sym___declspec] = ACTIONS(6008),
    [anon_sym___based] = ACTIONS(6008),
    [anon_sym___cdecl] = ACTIONS(6008),
    [anon_sym___clrcall] = ACTIONS(6008),
    [anon_sym___stdcall] = ACTIONS(6008),
    [anon_sym___fastcall] = ACTIONS(6008),
    [anon_sym___thiscall] = ACTIONS(6008),
    [anon_sym___vectorcall] = ACTIONS(6008),
    [anon_sym_LBRACE] = ACTIONS(6006),
    [anon_sym_signed] = ACTIONS(6256),
    [anon_sym_unsigned] = ACTIONS(6256),
    [anon_sym_long] = ACTIONS(6256),
    [anon_sym_short] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(6008),
    [anon_sym_static] = ACTIONS(6008),
    [anon_sym_EQ] = ACTIONS(6006),
    [anon_sym_register] = ACTIONS(6008),
    [anon_sym_inline] = ACTIONS(6008),
    [anon_sym___inline] = ACTIONS(6008),
    [anon_sym___inline__] = ACTIONS(6008),
    [anon_sym___forceinline] = ACTIONS(6008),
    [anon_sym_thread_local] = ACTIONS(6008),
    [anon_sym___thread] = ACTIONS(6008),
    [anon_sym_const] = ACTIONS(6008),
    [anon_sym_constexpr] = ACTIONS(6008),
    [anon_sym_volatile] = ACTIONS(6008),
    [anon_sym_restrict] = ACTIONS(6008),
    [anon_sym___restrict__] = ACTIONS(6008),
    [anon_sym__Atomic] = ACTIONS(6008),
    [anon_sym__Noreturn] = ACTIONS(6008),
    [anon_sym_noreturn] = ACTIONS(6008),
    [anon_sym__Nonnull] = ACTIONS(6008),
    [anon_sym_mutable] = ACTIONS(6008),
    [anon_sym_constinit] = ACTIONS(6008),
    [anon_sym_consteval] = ACTIONS(6008),
    [anon_sym___shared__] = ACTIONS(6008),
    [anon_sym___local__] = ACTIONS(6008),
    [anon_sym___constant__] = ACTIONS(6008),
    [anon_sym___managed__] = ACTIONS(6008),
    [anon_sym___grid_constant__] = ACTIONS(6008),
    [anon_sym_alignas] = ACTIONS(6008),
    [anon_sym__Alignas] = ACTIONS(6008),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6008),
    [anon_sym_decltype] = ACTIONS(6008),
    [anon_sym_template] = ACTIONS(6008),
    [anon_sym_GT2] = ACTIONS(6006),
    [anon_sym_operator] = ACTIONS(6008),
    [anon_sym___launch_bounds__] = ACTIONS(6008),
  },
  [STATE(2309)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2327),
    [sym_identifier] = ACTIONS(5900),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5898),
    [anon_sym_COMMA] = ACTIONS(5898),
    [anon_sym_RPAREN] = ACTIONS(5898),
    [anon_sym_LPAREN2] = ACTIONS(5898),
    [anon_sym_TILDE] = ACTIONS(5898),
    [anon_sym_STAR] = ACTIONS(5898),
    [anon_sym_AMP_AMP] = ACTIONS(5898),
    [anon_sym_AMP] = ACTIONS(5900),
    [anon_sym_SEMI] = ACTIONS(5898),
    [anon_sym___extension__] = ACTIONS(5900),
    [anon_sym___device__] = ACTIONS(5900),
    [anon_sym___host__] = ACTIONS(5900),
    [anon_sym___global__] = ACTIONS(5900),
    [anon_sym___forceinline__] = ACTIONS(5900),
    [anon_sym___noinline__] = ACTIONS(5900),
    [anon_sym_virtual] = ACTIONS(5900),
    [anon_sym_extern] = ACTIONS(5900),
    [anon_sym___attribute__] = ACTIONS(5900),
    [anon_sym___attribute] = ACTIONS(5900),
    [anon_sym_COLON_COLON] = ACTIONS(5898),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5898),
    [anon_sym___declspec] = ACTIONS(5900),
    [anon_sym___based] = ACTIONS(5900),
    [anon_sym___cdecl] = ACTIONS(5900),
    [anon_sym___clrcall] = ACTIONS(5900),
    [anon_sym___stdcall] = ACTIONS(5900),
    [anon_sym___fastcall] = ACTIONS(5900),
    [anon_sym___thiscall] = ACTIONS(5900),
    [anon_sym___vectorcall] = ACTIONS(5900),
    [anon_sym_LBRACE] = ACTIONS(5898),
    [anon_sym_signed] = ACTIONS(6256),
    [anon_sym_unsigned] = ACTIONS(6256),
    [anon_sym_long] = ACTIONS(6256),
    [anon_sym_short] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(5900),
    [anon_sym_static] = ACTIONS(5900),
    [anon_sym_EQ] = ACTIONS(5898),
    [anon_sym_register] = ACTIONS(5900),
    [anon_sym_inline] = ACTIONS(5900),
    [anon_sym___inline] = ACTIONS(5900),
    [anon_sym___inline__] = ACTIONS(5900),
    [anon_sym___forceinline] = ACTIONS(5900),
    [anon_sym_thread_local] = ACTIONS(5900),
    [anon_sym___thread] = ACTIONS(5900),
    [anon_sym_const] = ACTIONS(5900),
    [anon_sym_constexpr] = ACTIONS(5900),
    [anon_sym_volatile] = ACTIONS(5900),
    [anon_sym_restrict] = ACTIONS(5900),
    [anon_sym___restrict__] = ACTIONS(5900),
    [anon_sym__Atomic] = ACTIONS(5900),
    [anon_sym__Noreturn] = ACTIONS(5900),
    [anon_sym_noreturn] = ACTIONS(5900),
    [anon_sym__Nonnull] = ACTIONS(5900),
    [anon_sym_mutable] = ACTIONS(5900),
    [anon_sym_constinit] = ACTIONS(5900),
    [anon_sym_consteval] = ACTIONS(5900),
    [anon_sym___shared__] = ACTIONS(5900),
    [anon_sym___local__] = ACTIONS(5900),
    [anon_sym___constant__] = ACTIONS(5900),
    [anon_sym___managed__] = ACTIONS(5900),
    [anon_sym___grid_constant__] = ACTIONS(5900),
    [anon_sym_alignas] = ACTIONS(5900),
    [anon_sym__Alignas] = ACTIONS(5900),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5900),
    [anon_sym_decltype] = ACTIONS(5900),
    [anon_sym_template] = ACTIONS(5900),
    [anon_sym_GT2] = ACTIONS(5898),
    [anon_sym_operator] = ACTIONS(5900),
    [anon_sym___launch_bounds__] = ACTIONS(5900),
  },
  [STATE(2310)] = {
    [sym_attribute_specifier] = STATE(2131),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6258),
    [anon_sym_COMMA] = ACTIONS(6258),
    [anon_sym_RPAREN] = ACTIONS(6258),
    [anon_sym_LPAREN2] = ACTIONS(6258),
    [anon_sym_DASH] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6260),
    [anon_sym_STAR] = ACTIONS(6258),
    [anon_sym_SLASH] = ACTIONS(6260),
    [anon_sym_PERCENT] = ACTIONS(6258),
    [anon_sym_PIPE_PIPE] = ACTIONS(6258),
    [anon_sym_AMP_AMP] = ACTIONS(6258),
    [anon_sym_PIPE] = ACTIONS(6260),
    [anon_sym_CARET] = ACTIONS(6258),
    [anon_sym_AMP] = ACTIONS(6260),
    [anon_sym_EQ_EQ] = ACTIONS(6258),
    [anon_sym_BANG_EQ] = ACTIONS(6258),
    [anon_sym_GT] = ACTIONS(6260),
    [anon_sym_GT_EQ] = ACTIONS(6258),
    [anon_sym_LT_EQ] = ACTIONS(6260),
    [anon_sym_LT] = ACTIONS(6260),
    [anon_sym_LT_LT] = ACTIONS(6260),
    [anon_sym_GT_GT] = ACTIONS(6258),
    [anon_sym_SEMI] = ACTIONS(6258),
    [anon_sym___extension__] = ACTIONS(6258),
    [anon_sym___global__] = ACTIONS(6258),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6258),
    [anon_sym_RBRACE] = ACTIONS(6258),
    [anon_sym_LBRACK] = ACTIONS(6258),
    [anon_sym_RBRACK] = ACTIONS(6258),
    [anon_sym_const] = ACTIONS(6260),
    [anon_sym_constexpr] = ACTIONS(6258),
    [anon_sym_volatile] = ACTIONS(6258),
    [anon_sym_restrict] = ACTIONS(6258),
    [anon_sym___restrict__] = ACTIONS(6258),
    [anon_sym__Atomic] = ACTIONS(6258),
    [anon_sym__Noreturn] = ACTIONS(6258),
    [anon_sym_noreturn] = ACTIONS(6258),
    [anon_sym__Nonnull] = ACTIONS(6258),
    [anon_sym_mutable] = ACTIONS(6258),
    [anon_sym_constinit] = ACTIONS(6258),
    [anon_sym_consteval] = ACTIONS(6258),
    [anon_sym___shared__] = ACTIONS(6258),
    [anon_sym___local__] = ACTIONS(6258),
    [anon_sym___constant__] = ACTIONS(6258),
    [anon_sym___managed__] = ACTIONS(6258),
    [anon_sym___grid_constant__] = ACTIONS(6258),
    [anon_sym_alignas] = ACTIONS(6258),
    [anon_sym__Alignas] = ACTIONS(6258),
    [anon_sym_COLON] = ACTIONS(6258),
    [anon_sym_QMARK] = ACTIONS(6258),
    [anon_sym_LT_EQ_GT] = ACTIONS(6258),
    [anon_sym_or] = ACTIONS(6258),
    [anon_sym_and] = ACTIONS(6258),
    [anon_sym_bitor] = ACTIONS(6258),
    [anon_sym_xor] = ACTIONS(6258),
    [anon_sym_bitand] = ACTIONS(6258),
    [anon_sym_not_eq] = ACTIONS(6258),
    [anon_sym_DASH_DASH] = ACTIONS(6258),
    [anon_sym_PLUS_PLUS] = ACTIONS(6258),
    [anon_sym_DOT] = ACTIONS(6260),
    [anon_sym_DOT_STAR] = ACTIONS(6258),
    [anon_sym_DASH_GT] = ACTIONS(6258),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6258),
    [anon_sym_decltype] = ACTIONS(6258),
    [anon_sym_final] = ACTIONS(6258),
    [anon_sym_override] = ACTIONS(6258),
    [anon_sym_requires] = ACTIONS(6258),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6258),
  },
  [STATE(2311)] = {
    [sym_attribute_specifier] = STATE(2132),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6262),
    [anon_sym_COMMA] = ACTIONS(6262),
    [anon_sym_RPAREN] = ACTIONS(6262),
    [anon_sym_LPAREN2] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6264),
    [anon_sym_STAR] = ACTIONS(6262),
    [anon_sym_SLASH] = ACTIONS(6264),
    [anon_sym_PERCENT] = ACTIONS(6262),
    [anon_sym_PIPE_PIPE] = ACTIONS(6262),
    [anon_sym_AMP_AMP] = ACTIONS(6262),
    [anon_sym_PIPE] = ACTIONS(6264),
    [anon_sym_CARET] = ACTIONS(6262),
    [anon_sym_AMP] = ACTIONS(6264),
    [anon_sym_EQ_EQ] = ACTIONS(6262),
    [anon_sym_BANG_EQ] = ACTIONS(6262),
    [anon_sym_GT] = ACTIONS(6264),
    [anon_sym_GT_EQ] = ACTIONS(6262),
    [anon_sym_LT_EQ] = ACTIONS(6264),
    [anon_sym_LT] = ACTIONS(6264),
    [anon_sym_LT_LT] = ACTIONS(6264),
    [anon_sym_GT_GT] = ACTIONS(6262),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym___extension__] = ACTIONS(6262),
    [anon_sym___global__] = ACTIONS(6262),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6262),
    [anon_sym_RBRACE] = ACTIONS(6262),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [anon_sym_RBRACK] = ACTIONS(6262),
    [anon_sym_const] = ACTIONS(6264),
    [anon_sym_constexpr] = ACTIONS(6262),
    [anon_sym_volatile] = ACTIONS(6262),
    [anon_sym_restrict] = ACTIONS(6262),
    [anon_sym___restrict__] = ACTIONS(6262),
    [anon_sym__Atomic] = ACTIONS(6262),
    [anon_sym__Noreturn] = ACTIONS(6262),
    [anon_sym_noreturn] = ACTIONS(6262),
    [anon_sym__Nonnull] = ACTIONS(6262),
    [anon_sym_mutable] = ACTIONS(6262),
    [anon_sym_constinit] = ACTIONS(6262),
    [anon_sym_consteval] = ACTIONS(6262),
    [anon_sym___shared__] = ACTIONS(6262),
    [anon_sym___local__] = ACTIONS(6262),
    [anon_sym___constant__] = ACTIONS(6262),
    [anon_sym___managed__] = ACTIONS(6262),
    [anon_sym___grid_constant__] = ACTIONS(6262),
    [anon_sym_alignas] = ACTIONS(6262),
    [anon_sym__Alignas] = ACTIONS(6262),
    [anon_sym_COLON] = ACTIONS(6262),
    [anon_sym_QMARK] = ACTIONS(6262),
    [anon_sym_LT_EQ_GT] = ACTIONS(6262),
    [anon_sym_or] = ACTIONS(6262),
    [anon_sym_and] = ACTIONS(6262),
    [anon_sym_bitor] = ACTIONS(6262),
    [anon_sym_xor] = ACTIONS(6262),
    [anon_sym_bitand] = ACTIONS(6262),
    [anon_sym_not_eq] = ACTIONS(6262),
    [anon_sym_DASH_DASH] = ACTIONS(6262),
    [anon_sym_PLUS_PLUS] = ACTIONS(6262),
    [anon_sym_DOT] = ACTIONS(6264),
    [anon_sym_DOT_STAR] = ACTIONS(6262),
    [anon_sym_DASH_GT] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6262),
    [anon_sym_decltype] = ACTIONS(6262),
    [anon_sym_final] = ACTIONS(6262),
    [anon_sym_override] = ACTIONS(6262),
    [anon_sym_requires] = ACTIONS(6262),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6262),
  },
  [STATE(2312)] = {
    [sym_attribute_specifier] = STATE(2120),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6266),
    [anon_sym_COMMA] = ACTIONS(6266),
    [anon_sym_RPAREN] = ACTIONS(6266),
    [anon_sym_LPAREN2] = ACTIONS(6266),
    [anon_sym_DASH] = ACTIONS(6268),
    [anon_sym_PLUS] = ACTIONS(6268),
    [anon_sym_STAR] = ACTIONS(6266),
    [anon_sym_SLASH] = ACTIONS(6268),
    [anon_sym_PERCENT] = ACTIONS(6266),
    [anon_sym_PIPE_PIPE] = ACTIONS(6266),
    [anon_sym_AMP_AMP] = ACTIONS(6266),
    [anon_sym_PIPE] = ACTIONS(6268),
    [anon_sym_CARET] = ACTIONS(6266),
    [anon_sym_AMP] = ACTIONS(6268),
    [anon_sym_EQ_EQ] = ACTIONS(6266),
    [anon_sym_BANG_EQ] = ACTIONS(6266),
    [anon_sym_GT] = ACTIONS(6268),
    [anon_sym_GT_EQ] = ACTIONS(6266),
    [anon_sym_LT_EQ] = ACTIONS(6268),
    [anon_sym_LT] = ACTIONS(6268),
    [anon_sym_LT_LT] = ACTIONS(6268),
    [anon_sym_GT_GT] = ACTIONS(6266),
    [anon_sym_SEMI] = ACTIONS(6266),
    [anon_sym___extension__] = ACTIONS(6266),
    [anon_sym___global__] = ACTIONS(6266),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6266),
    [anon_sym_RBRACE] = ACTIONS(6266),
    [anon_sym_LBRACK] = ACTIONS(6266),
    [anon_sym_RBRACK] = ACTIONS(6266),
    [anon_sym_const] = ACTIONS(6268),
    [anon_sym_constexpr] = ACTIONS(6266),
    [anon_sym_volatile] = ACTIONS(6266),
    [anon_sym_restrict] = ACTIONS(6266),
    [anon_sym___restrict__] = ACTIONS(6266),
    [anon_sym__Atomic] = ACTIONS(6266),
    [anon_sym__Noreturn] = ACTIONS(6266),
    [anon_sym_noreturn] = ACTIONS(6266),
    [anon_sym__Nonnull] = ACTIONS(6266),
    [anon_sym_mutable] = ACTIONS(6266),
    [anon_sym_constinit] = ACTIONS(6266),
    [anon_sym_consteval] = ACTIONS(6266),
    [anon_sym___shared__] = ACTIONS(6266),
    [anon_sym___local__] = ACTIONS(6266),
    [anon_sym___constant__] = ACTIONS(6266),
    [anon_sym___managed__] = ACTIONS(6266),
    [anon_sym___grid_constant__] = ACTIONS(6266),
    [anon_sym_alignas] = ACTIONS(6266),
    [anon_sym__Alignas] = ACTIONS(6266),
    [anon_sym_COLON] = ACTIONS(6266),
    [anon_sym_QMARK] = ACTIONS(6266),
    [anon_sym_LT_EQ_GT] = ACTIONS(6266),
    [anon_sym_or] = ACTIONS(6266),
    [anon_sym_and] = ACTIONS(6266),
    [anon_sym_bitor] = ACTIONS(6266),
    [anon_sym_xor] = ACTIONS(6266),
    [anon_sym_bitand] = ACTIONS(6266),
    [anon_sym_not_eq] = ACTIONS(6266),
    [anon_sym_DASH_DASH] = ACTIONS(6266),
    [anon_sym_PLUS_PLUS] = ACTIONS(6266),
    [anon_sym_DOT] = ACTIONS(6268),
    [anon_sym_DOT_STAR] = ACTIONS(6266),
    [anon_sym_DASH_GT] = ACTIONS(6266),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6266),
    [anon_sym_decltype] = ACTIONS(6266),
    [anon_sym_final] = ACTIONS(6266),
    [anon_sym_override] = ACTIONS(6266),
    [anon_sym_requires] = ACTIONS(6266),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6266),
  },
  [STATE(2313)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [sym_identifier] = ACTIONS(4012),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [aux_sym_preproc_if_token2] = ACTIONS(4004),
    [aux_sym_preproc_else_token1] = ACTIONS(4004),
    [aux_sym_preproc_elif_token1] = ACTIONS(4012),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4004),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(6270),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(6273),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(6275),
    [anon_sym_SLASH_EQ] = ACTIONS(6275),
    [anon_sym_PERCENT_EQ] = ACTIONS(6275),
    [anon_sym_PLUS_EQ] = ACTIONS(6275),
    [anon_sym_DASH_EQ] = ACTIONS(6275),
    [anon_sym_LT_LT_EQ] = ACTIONS(6275),
    [anon_sym_GT_GT_EQ] = ACTIONS(6275),
    [anon_sym_AMP_EQ] = ACTIONS(6275),
    [anon_sym_CARET_EQ] = ACTIONS(6275),
    [anon_sym_PIPE_EQ] = ACTIONS(6275),
    [anon_sym_and_eq] = ACTIONS(6273),
    [anon_sym_or_eq] = ACTIONS(6273),
    [anon_sym_xor_eq] = ACTIONS(6273),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4012),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4012),
    [anon_sym_not_eq] = ACTIONS(4012),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2314)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6024),
    [anon_sym_COMMA] = ACTIONS(6024),
    [anon_sym_LPAREN2] = ACTIONS(6024),
    [anon_sym_DASH] = ACTIONS(6026),
    [anon_sym_PLUS] = ACTIONS(6026),
    [anon_sym_STAR] = ACTIONS(6024),
    [anon_sym_SLASH] = ACTIONS(6026),
    [anon_sym_PERCENT] = ACTIONS(6024),
    [anon_sym_PIPE_PIPE] = ACTIONS(6024),
    [anon_sym_AMP_AMP] = ACTIONS(6024),
    [anon_sym_PIPE] = ACTIONS(6026),
    [anon_sym_CARET] = ACTIONS(6024),
    [anon_sym_AMP] = ACTIONS(6026),
    [anon_sym_EQ_EQ] = ACTIONS(6024),
    [anon_sym_BANG_EQ] = ACTIONS(6024),
    [anon_sym_GT] = ACTIONS(6026),
    [anon_sym_GT_EQ] = ACTIONS(6026),
    [anon_sym_LT_EQ] = ACTIONS(6026),
    [anon_sym_LT] = ACTIONS(6026),
    [anon_sym_LT_LT] = ACTIONS(6026),
    [anon_sym_GT_GT] = ACTIONS(6026),
    [anon_sym___extension__] = ACTIONS(6024),
    [anon_sym___global__] = ACTIONS(6024),
    [anon_sym___attribute__] = ACTIONS(6024),
    [anon_sym___attribute] = ACTIONS(6026),
    [anon_sym_LBRACE] = ACTIONS(6024),
    [anon_sym_signed] = ACTIONS(6200),
    [anon_sym_unsigned] = ACTIONS(6200),
    [anon_sym_long] = ACTIONS(6200),
    [anon_sym_short] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(6024),
    [anon_sym_const] = ACTIONS(6026),
    [anon_sym_constexpr] = ACTIONS(6024),
    [anon_sym_volatile] = ACTIONS(6024),
    [anon_sym_restrict] = ACTIONS(6024),
    [anon_sym___restrict__] = ACTIONS(6024),
    [anon_sym__Atomic] = ACTIONS(6024),
    [anon_sym__Noreturn] = ACTIONS(6024),
    [anon_sym_noreturn] = ACTIONS(6024),
    [anon_sym__Nonnull] = ACTIONS(6024),
    [anon_sym_mutable] = ACTIONS(6024),
    [anon_sym_constinit] = ACTIONS(6024),
    [anon_sym_consteval] = ACTIONS(6024),
    [anon_sym___shared__] = ACTIONS(6024),
    [anon_sym___local__] = ACTIONS(6024),
    [anon_sym___constant__] = ACTIONS(6024),
    [anon_sym___managed__] = ACTIONS(6024),
    [anon_sym___grid_constant__] = ACTIONS(6024),
    [anon_sym_alignas] = ACTIONS(6024),
    [anon_sym__Alignas] = ACTIONS(6024),
    [anon_sym_QMARK] = ACTIONS(6024),
    [anon_sym_LT_EQ_GT] = ACTIONS(6024),
    [anon_sym_or] = ACTIONS(6024),
    [anon_sym_and] = ACTIONS(6024),
    [anon_sym_bitor] = ACTIONS(6024),
    [anon_sym_xor] = ACTIONS(6024),
    [anon_sym_bitand] = ACTIONS(6024),
    [anon_sym_not_eq] = ACTIONS(6024),
    [anon_sym_DASH_DASH] = ACTIONS(6024),
    [anon_sym_PLUS_PLUS] = ACTIONS(6024),
    [anon_sym_DOT] = ACTIONS(6026),
    [anon_sym_DOT_STAR] = ACTIONS(6024),
    [anon_sym_DASH_GT] = ACTIONS(6024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6024),
    [anon_sym_decltype] = ACTIONS(6024),
    [anon_sym_final] = ACTIONS(6024),
    [anon_sym_override] = ACTIONS(6024),
    [anon_sym_GT2] = ACTIONS(6024),
    [anon_sym_requires] = ACTIONS(6024),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6024),
  },
  [STATE(2315)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5962),
    [anon_sym_COMMA] = ACTIONS(5962),
    [anon_sym_LPAREN2] = ACTIONS(5962),
    [anon_sym_DASH] = ACTIONS(5964),
    [anon_sym_PLUS] = ACTIONS(5964),
    [anon_sym_STAR] = ACTIONS(5962),
    [anon_sym_SLASH] = ACTIONS(5964),
    [anon_sym_PERCENT] = ACTIONS(5962),
    [anon_sym_PIPE_PIPE] = ACTIONS(5962),
    [anon_sym_AMP_AMP] = ACTIONS(5962),
    [anon_sym_PIPE] = ACTIONS(5964),
    [anon_sym_CARET] = ACTIONS(5962),
    [anon_sym_AMP] = ACTIONS(5964),
    [anon_sym_EQ_EQ] = ACTIONS(5962),
    [anon_sym_BANG_EQ] = ACTIONS(5962),
    [anon_sym_GT] = ACTIONS(5964),
    [anon_sym_GT_EQ] = ACTIONS(5964),
    [anon_sym_LT_EQ] = ACTIONS(5964),
    [anon_sym_LT] = ACTIONS(5964),
    [anon_sym_LT_LT] = ACTIONS(5964),
    [anon_sym_GT_GT] = ACTIONS(5964),
    [anon_sym___extension__] = ACTIONS(5962),
    [anon_sym___global__] = ACTIONS(5962),
    [anon_sym___attribute__] = ACTIONS(5962),
    [anon_sym___attribute] = ACTIONS(5964),
    [anon_sym_LBRACE] = ACTIONS(5962),
    [anon_sym_signed] = ACTIONS(6200),
    [anon_sym_unsigned] = ACTIONS(6200),
    [anon_sym_long] = ACTIONS(6200),
    [anon_sym_short] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(5962),
    [anon_sym_const] = ACTIONS(5964),
    [anon_sym_constexpr] = ACTIONS(5962),
    [anon_sym_volatile] = ACTIONS(5962),
    [anon_sym_restrict] = ACTIONS(5962),
    [anon_sym___restrict__] = ACTIONS(5962),
    [anon_sym__Atomic] = ACTIONS(5962),
    [anon_sym__Noreturn] = ACTIONS(5962),
    [anon_sym_noreturn] = ACTIONS(5962),
    [anon_sym__Nonnull] = ACTIONS(5962),
    [anon_sym_mutable] = ACTIONS(5962),
    [anon_sym_constinit] = ACTIONS(5962),
    [anon_sym_consteval] = ACTIONS(5962),
    [anon_sym___shared__] = ACTIONS(5962),
    [anon_sym___local__] = ACTIONS(5962),
    [anon_sym___constant__] = ACTIONS(5962),
    [anon_sym___managed__] = ACTIONS(5962),
    [anon_sym___grid_constant__] = ACTIONS(5962),
    [anon_sym_alignas] = ACTIONS(5962),
    [anon_sym__Alignas] = ACTIONS(5962),
    [anon_sym_QMARK] = ACTIONS(5962),
    [anon_sym_LT_EQ_GT] = ACTIONS(5962),
    [anon_sym_or] = ACTIONS(5962),
    [anon_sym_and] = ACTIONS(5962),
    [anon_sym_bitor] = ACTIONS(5962),
    [anon_sym_xor] = ACTIONS(5962),
    [anon_sym_bitand] = ACTIONS(5962),
    [anon_sym_not_eq] = ACTIONS(5962),
    [anon_sym_DASH_DASH] = ACTIONS(5962),
    [anon_sym_PLUS_PLUS] = ACTIONS(5962),
    [anon_sym_DOT] = ACTIONS(5964),
    [anon_sym_DOT_STAR] = ACTIONS(5962),
    [anon_sym_DASH_GT] = ACTIONS(5962),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5962),
    [anon_sym_decltype] = ACTIONS(5962),
    [anon_sym_final] = ACTIONS(5962),
    [anon_sym_override] = ACTIONS(5962),
    [anon_sym_GT2] = ACTIONS(5962),
    [anon_sym_requires] = ACTIONS(5962),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5962),
  },
  [STATE(2316)] = {
    [sym_attribute_specifier] = STATE(2128),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6277),
    [anon_sym_COMMA] = ACTIONS(6277),
    [anon_sym_RPAREN] = ACTIONS(6277),
    [anon_sym_LPAREN2] = ACTIONS(6277),
    [anon_sym_DASH] = ACTIONS(6279),
    [anon_sym_PLUS] = ACTIONS(6279),
    [anon_sym_STAR] = ACTIONS(6277),
    [anon_sym_SLASH] = ACTIONS(6279),
    [anon_sym_PERCENT] = ACTIONS(6277),
    [anon_sym_PIPE_PIPE] = ACTIONS(6277),
    [anon_sym_AMP_AMP] = ACTIONS(6277),
    [anon_sym_PIPE] = ACTIONS(6279),
    [anon_sym_CARET] = ACTIONS(6277),
    [anon_sym_AMP] = ACTIONS(6279),
    [anon_sym_EQ_EQ] = ACTIONS(6277),
    [anon_sym_BANG_EQ] = ACTIONS(6277),
    [anon_sym_GT] = ACTIONS(6279),
    [anon_sym_GT_EQ] = ACTIONS(6277),
    [anon_sym_LT_EQ] = ACTIONS(6279),
    [anon_sym_LT] = ACTIONS(6279),
    [anon_sym_LT_LT] = ACTIONS(6279),
    [anon_sym_GT_GT] = ACTIONS(6277),
    [anon_sym_SEMI] = ACTIONS(6277),
    [anon_sym___extension__] = ACTIONS(6277),
    [anon_sym___global__] = ACTIONS(6277),
    [anon_sym___attribute__] = ACTIONS(6040),
    [anon_sym___attribute] = ACTIONS(6042),
    [anon_sym_LBRACE] = ACTIONS(6277),
    [anon_sym_RBRACE] = ACTIONS(6277),
    [anon_sym_LBRACK] = ACTIONS(6277),
    [anon_sym_RBRACK] = ACTIONS(6277),
    [anon_sym_const] = ACTIONS(6279),
    [anon_sym_constexpr] = ACTIONS(6277),
    [anon_sym_volatile] = ACTIONS(6277),
    [anon_sym_restrict] = ACTIONS(6277),
    [anon_sym___restrict__] = ACTIONS(6277),
    [anon_sym__Atomic] = ACTIONS(6277),
    [anon_sym__Noreturn] = ACTIONS(6277),
    [anon_sym_noreturn] = ACTIONS(6277),
    [anon_sym__Nonnull] = ACTIONS(6277),
    [anon_sym_mutable] = ACTIONS(6277),
    [anon_sym_constinit] = ACTIONS(6277),
    [anon_sym_consteval] = ACTIONS(6277),
    [anon_sym___shared__] = ACTIONS(6277),
    [anon_sym___local__] = ACTIONS(6277),
    [anon_sym___constant__] = ACTIONS(6277),
    [anon_sym___managed__] = ACTIONS(6277),
    [anon_sym___grid_constant__] = ACTIONS(6277),
    [anon_sym_alignas] = ACTIONS(6277),
    [anon_sym__Alignas] = ACTIONS(6277),
    [anon_sym_COLON] = ACTIONS(6277),
    [anon_sym_QMARK] = ACTIONS(6277),
    [anon_sym_LT_EQ_GT] = ACTIONS(6277),
    [anon_sym_or] = ACTIONS(6277),
    [anon_sym_and] = ACTIONS(6277),
    [anon_sym_bitor] = ACTIONS(6277),
    [anon_sym_xor] = ACTIONS(6277),
    [anon_sym_bitand] = ACTIONS(6277),
    [anon_sym_not_eq] = ACTIONS(6277),
    [anon_sym_DASH_DASH] = ACTIONS(6277),
    [anon_sym_PLUS_PLUS] = ACTIONS(6277),
    [anon_sym_DOT] = ACTIONS(6279),
    [anon_sym_DOT_STAR] = ACTIONS(6277),
    [anon_sym_DASH_GT] = ACTIONS(6277),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6277),
    [anon_sym_decltype] = ACTIONS(6277),
    [anon_sym_final] = ACTIONS(6277),
    [anon_sym_override] = ACTIONS(6277),
    [anon_sym_requires] = ACTIONS(6277),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6277),
  },
  [STATE(2317)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2319),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5684),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym___extension__] = ACTIONS(5686),
    [anon_sym___global__] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5686),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_signed] = ACTIONS(6246),
    [anon_sym_unsigned] = ACTIONS(6246),
    [anon_sym_long] = ACTIONS(6246),
    [anon_sym_short] = ACTIONS(6246),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5686),
    [anon_sym_volatile] = ACTIONS(5686),
    [anon_sym_restrict] = ACTIONS(5686),
    [anon_sym___restrict__] = ACTIONS(5686),
    [anon_sym__Atomic] = ACTIONS(5686),
    [anon_sym__Noreturn] = ACTIONS(5686),
    [anon_sym_noreturn] = ACTIONS(5686),
    [anon_sym__Nonnull] = ACTIONS(5686),
    [anon_sym_mutable] = ACTIONS(5686),
    [anon_sym_constinit] = ACTIONS(5686),
    [anon_sym_consteval] = ACTIONS(5686),
    [anon_sym___shared__] = ACTIONS(5686),
    [anon_sym___local__] = ACTIONS(5686),
    [anon_sym___constant__] = ACTIONS(5686),
    [anon_sym___managed__] = ACTIONS(5686),
    [anon_sym___grid_constant__] = ACTIONS(5686),
    [anon_sym_alignas] = ACTIONS(5686),
    [anon_sym__Alignas] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_bitor] = ACTIONS(5686),
    [anon_sym_xor] = ACTIONS(5686),
    [anon_sym_bitand] = ACTIONS(5686),
    [anon_sym_not_eq] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5686),
    [anon_sym_decltype] = ACTIONS(5686),
    [anon_sym_final] = ACTIONS(5686),
    [anon_sym_override] = ACTIONS(5686),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_requires] = ACTIONS(5686),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2318)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2327),
    [sym_identifier] = ACTIONS(6026),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6024),
    [anon_sym_COMMA] = ACTIONS(6024),
    [anon_sym_RPAREN] = ACTIONS(6024),
    [anon_sym_LPAREN2] = ACTIONS(6024),
    [anon_sym_TILDE] = ACTIONS(6024),
    [anon_sym_STAR] = ACTIONS(6024),
    [anon_sym_AMP_AMP] = ACTIONS(6024),
    [anon_sym_AMP] = ACTIONS(6026),
    [anon_sym_SEMI] = ACTIONS(6024),
    [anon_sym___extension__] = ACTIONS(6026),
    [anon_sym___device__] = ACTIONS(6026),
    [anon_sym___host__] = ACTIONS(6026),
    [anon_sym___global__] = ACTIONS(6026),
    [anon_sym___forceinline__] = ACTIONS(6026),
    [anon_sym___noinline__] = ACTIONS(6026),
    [anon_sym_virtual] = ACTIONS(6026),
    [anon_sym_extern] = ACTIONS(6026),
    [anon_sym___attribute__] = ACTIONS(6026),
    [anon_sym___attribute] = ACTIONS(6026),
    [anon_sym_COLON_COLON] = ACTIONS(6024),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6024),
    [anon_sym___declspec] = ACTIONS(6026),
    [anon_sym___based] = ACTIONS(6026),
    [anon_sym___cdecl] = ACTIONS(6026),
    [anon_sym___clrcall] = ACTIONS(6026),
    [anon_sym___stdcall] = ACTIONS(6026),
    [anon_sym___fastcall] = ACTIONS(6026),
    [anon_sym___thiscall] = ACTIONS(6026),
    [anon_sym___vectorcall] = ACTIONS(6026),
    [anon_sym_LBRACE] = ACTIONS(6024),
    [anon_sym_signed] = ACTIONS(6256),
    [anon_sym_unsigned] = ACTIONS(6256),
    [anon_sym_long] = ACTIONS(6256),
    [anon_sym_short] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(6026),
    [anon_sym_static] = ACTIONS(6026),
    [anon_sym_EQ] = ACTIONS(6024),
    [anon_sym_register] = ACTIONS(6026),
    [anon_sym_inline] = ACTIONS(6026),
    [anon_sym___inline] = ACTIONS(6026),
    [anon_sym___inline__] = ACTIONS(6026),
    [anon_sym___forceinline] = ACTIONS(6026),
    [anon_sym_thread_local] = ACTIONS(6026),
    [anon_sym___thread] = ACTIONS(6026),
    [anon_sym_const] = ACTIONS(6026),
    [anon_sym_constexpr] = ACTIONS(6026),
    [anon_sym_volatile] = ACTIONS(6026),
    [anon_sym_restrict] = ACTIONS(6026),
    [anon_sym___restrict__] = ACTIONS(6026),
    [anon_sym__Atomic] = ACTIONS(6026),
    [anon_sym__Noreturn] = ACTIONS(6026),
    [anon_sym_noreturn] = ACTIONS(6026),
    [anon_sym__Nonnull] = ACTIONS(6026),
    [anon_sym_mutable] = ACTIONS(6026),
    [anon_sym_constinit] = ACTIONS(6026),
    [anon_sym_consteval] = ACTIONS(6026),
    [anon_sym___shared__] = ACTIONS(6026),
    [anon_sym___local__] = ACTIONS(6026),
    [anon_sym___constant__] = ACTIONS(6026),
    [anon_sym___managed__] = ACTIONS(6026),
    [anon_sym___grid_constant__] = ACTIONS(6026),
    [anon_sym_alignas] = ACTIONS(6026),
    [anon_sym__Alignas] = ACTIONS(6026),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6026),
    [anon_sym_decltype] = ACTIONS(6026),
    [anon_sym_template] = ACTIONS(6026),
    [anon_sym_GT2] = ACTIONS(6024),
    [anon_sym_operator] = ACTIONS(6026),
    [anon_sym___launch_bounds__] = ACTIONS(6026),
  },
  [STATE(2319)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5898),
    [anon_sym_COMMA] = ACTIONS(5898),
    [anon_sym_LPAREN2] = ACTIONS(5898),
    [anon_sym_DASH] = ACTIONS(5900),
    [anon_sym_PLUS] = ACTIONS(5900),
    [anon_sym_STAR] = ACTIONS(5898),
    [anon_sym_SLASH] = ACTIONS(5900),
    [anon_sym_PERCENT] = ACTIONS(5898),
    [anon_sym_PIPE_PIPE] = ACTIONS(5898),
    [anon_sym_AMP_AMP] = ACTIONS(5898),
    [anon_sym_PIPE] = ACTIONS(5900),
    [anon_sym_CARET] = ACTIONS(5898),
    [anon_sym_AMP] = ACTIONS(5900),
    [anon_sym_EQ_EQ] = ACTIONS(5898),
    [anon_sym_BANG_EQ] = ACTIONS(5898),
    [anon_sym_GT] = ACTIONS(5900),
    [anon_sym_GT_EQ] = ACTIONS(5900),
    [anon_sym_LT_EQ] = ACTIONS(5900),
    [anon_sym_LT] = ACTIONS(5900),
    [anon_sym_LT_LT] = ACTIONS(5900),
    [anon_sym_GT_GT] = ACTIONS(5900),
    [anon_sym___extension__] = ACTIONS(5898),
    [anon_sym___global__] = ACTIONS(5898),
    [anon_sym___attribute__] = ACTIONS(5898),
    [anon_sym___attribute] = ACTIONS(5900),
    [anon_sym_LBRACE] = ACTIONS(5898),
    [anon_sym_signed] = ACTIONS(6200),
    [anon_sym_unsigned] = ACTIONS(6200),
    [anon_sym_long] = ACTIONS(6200),
    [anon_sym_short] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(5898),
    [anon_sym_const] = ACTIONS(5900),
    [anon_sym_constexpr] = ACTIONS(5898),
    [anon_sym_volatile] = ACTIONS(5898),
    [anon_sym_restrict] = ACTIONS(5898),
    [anon_sym___restrict__] = ACTIONS(5898),
    [anon_sym__Atomic] = ACTIONS(5898),
    [anon_sym__Noreturn] = ACTIONS(5898),
    [anon_sym_noreturn] = ACTIONS(5898),
    [anon_sym__Nonnull] = ACTIONS(5898),
    [anon_sym_mutable] = ACTIONS(5898),
    [anon_sym_constinit] = ACTIONS(5898),
    [anon_sym_consteval] = ACTIONS(5898),
    [anon_sym___shared__] = ACTIONS(5898),
    [anon_sym___local__] = ACTIONS(5898),
    [anon_sym___constant__] = ACTIONS(5898),
    [anon_sym___managed__] = ACTIONS(5898),
    [anon_sym___grid_constant__] = ACTIONS(5898),
    [anon_sym_alignas] = ACTIONS(5898),
    [anon_sym__Alignas] = ACTIONS(5898),
    [anon_sym_QMARK] = ACTIONS(5898),
    [anon_sym_LT_EQ_GT] = ACTIONS(5898),
    [anon_sym_or] = ACTIONS(5898),
    [anon_sym_and] = ACTIONS(5898),
    [anon_sym_bitor] = ACTIONS(5898),
    [anon_sym_xor] = ACTIONS(5898),
    [anon_sym_bitand] = ACTIONS(5898),
    [anon_sym_not_eq] = ACTIONS(5898),
    [anon_sym_DASH_DASH] = ACTIONS(5898),
    [anon_sym_PLUS_PLUS] = ACTIONS(5898),
    [anon_sym_DOT] = ACTIONS(5900),
    [anon_sym_DOT_STAR] = ACTIONS(5898),
    [anon_sym_DASH_GT] = ACTIONS(5898),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5898),
    [anon_sym_decltype] = ACTIONS(5898),
    [anon_sym_final] = ACTIONS(5898),
    [anon_sym_override] = ACTIONS(5898),
    [anon_sym_GT2] = ACTIONS(5898),
    [anon_sym_requires] = ACTIONS(5898),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5898),
  },
  [STATE(2320)] = {
    [sym_identifier] = ACTIONS(4356),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_RPAREN] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_TILDE] = ACTIONS(4358),
    [anon_sym_STAR] = ACTIONS(4358),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_SEMI] = ACTIONS(4358),
    [anon_sym___extension__] = ACTIONS(4356),
    [anon_sym___device__] = ACTIONS(4356),
    [anon_sym___host__] = ACTIONS(4356),
    [anon_sym___global__] = ACTIONS(4356),
    [anon_sym___forceinline__] = ACTIONS(4356),
    [anon_sym___noinline__] = ACTIONS(4356),
    [anon_sym_virtual] = ACTIONS(4356),
    [anon_sym_extern] = ACTIONS(4356),
    [anon_sym___attribute__] = ACTIONS(4356),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4358),
    [anon_sym___declspec] = ACTIONS(4356),
    [anon_sym___based] = ACTIONS(4356),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_static] = ACTIONS(4356),
    [anon_sym_EQ] = ACTIONS(4358),
    [anon_sym_register] = ACTIONS(4356),
    [anon_sym_inline] = ACTIONS(4356),
    [anon_sym___inline] = ACTIONS(4356),
    [anon_sym___inline__] = ACTIONS(4356),
    [anon_sym___forceinline] = ACTIONS(4356),
    [anon_sym_thread_local] = ACTIONS(4356),
    [anon_sym___thread] = ACTIONS(4356),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4356),
    [anon_sym_volatile] = ACTIONS(4356),
    [anon_sym_restrict] = ACTIONS(4356),
    [anon_sym___restrict__] = ACTIONS(4356),
    [anon_sym__Atomic] = ACTIONS(4356),
    [anon_sym__Noreturn] = ACTIONS(4356),
    [anon_sym_noreturn] = ACTIONS(4356),
    [anon_sym__Nonnull] = ACTIONS(4356),
    [anon_sym_mutable] = ACTIONS(4356),
    [anon_sym_constinit] = ACTIONS(4356),
    [anon_sym_consteval] = ACTIONS(4356),
    [anon_sym___shared__] = ACTIONS(4356),
    [anon_sym___local__] = ACTIONS(4356),
    [anon_sym___constant__] = ACTIONS(4356),
    [anon_sym___managed__] = ACTIONS(4356),
    [anon_sym___grid_constant__] = ACTIONS(4356),
    [anon_sym_alignas] = ACTIONS(4356),
    [anon_sym__Alignas] = ACTIONS(4356),
    [anon_sym_COLON] = ACTIONS(4356),
    [anon_sym_or] = ACTIONS(4356),
    [anon_sym_and] = ACTIONS(4356),
    [anon_sym_asm] = ACTIONS(4356),
    [anon_sym___asm__] = ACTIONS(4356),
    [anon_sym___asm] = ACTIONS(4356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4356),
    [anon_sym_decltype] = ACTIONS(4356),
    [anon_sym_final] = ACTIONS(4356),
    [anon_sym_override] = ACTIONS(4356),
    [anon_sym_template] = ACTIONS(4356),
    [anon_sym_GT2] = ACTIONS(4358),
    [anon_sym_operator] = ACTIONS(4356),
    [anon_sym_try] = ACTIONS(4356),
    [anon_sym_requires] = ACTIONS(4356),
    [anon_sym___launch_bounds__] = ACTIONS(4356),
  },
  [STATE(2321)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2327),
    [sym_identifier] = ACTIONS(5982),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5980),
    [anon_sym_COMMA] = ACTIONS(5980),
    [anon_sym_RPAREN] = ACTIONS(5980),
    [anon_sym_LPAREN2] = ACTIONS(5980),
    [anon_sym_TILDE] = ACTIONS(5980),
    [anon_sym_STAR] = ACTIONS(5980),
    [anon_sym_AMP_AMP] = ACTIONS(5980),
    [anon_sym_AMP] = ACTIONS(5982),
    [anon_sym_SEMI] = ACTIONS(5980),
    [anon_sym___extension__] = ACTIONS(5982),
    [anon_sym___device__] = ACTIONS(5982),
    [anon_sym___host__] = ACTIONS(5982),
    [anon_sym___global__] = ACTIONS(5982),
    [anon_sym___forceinline__] = ACTIONS(5982),
    [anon_sym___noinline__] = ACTIONS(5982),
    [anon_sym_virtual] = ACTIONS(5982),
    [anon_sym_extern] = ACTIONS(5982),
    [anon_sym___attribute__] = ACTIONS(5982),
    [anon_sym___attribute] = ACTIONS(5982),
    [anon_sym_COLON_COLON] = ACTIONS(5980),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5980),
    [anon_sym___declspec] = ACTIONS(5982),
    [anon_sym___based] = ACTIONS(5982),
    [anon_sym___cdecl] = ACTIONS(5982),
    [anon_sym___clrcall] = ACTIONS(5982),
    [anon_sym___stdcall] = ACTIONS(5982),
    [anon_sym___fastcall] = ACTIONS(5982),
    [anon_sym___thiscall] = ACTIONS(5982),
    [anon_sym___vectorcall] = ACTIONS(5982),
    [anon_sym_LBRACE] = ACTIONS(5980),
    [anon_sym_signed] = ACTIONS(6256),
    [anon_sym_unsigned] = ACTIONS(6256),
    [anon_sym_long] = ACTIONS(6256),
    [anon_sym_short] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(5982),
    [anon_sym_static] = ACTIONS(5982),
    [anon_sym_EQ] = ACTIONS(5980),
    [anon_sym_register] = ACTIONS(5982),
    [anon_sym_inline] = ACTIONS(5982),
    [anon_sym___inline] = ACTIONS(5982),
    [anon_sym___inline__] = ACTIONS(5982),
    [anon_sym___forceinline] = ACTIONS(5982),
    [anon_sym_thread_local] = ACTIONS(5982),
    [anon_sym___thread] = ACTIONS(5982),
    [anon_sym_const] = ACTIONS(5982),
    [anon_sym_constexpr] = ACTIONS(5982),
    [anon_sym_volatile] = ACTIONS(5982),
    [anon_sym_restrict] = ACTIONS(5982),
    [anon_sym___restrict__] = ACTIONS(5982),
    [anon_sym__Atomic] = ACTIONS(5982),
    [anon_sym__Noreturn] = ACTIONS(5982),
    [anon_sym_noreturn] = ACTIONS(5982),
    [anon_sym__Nonnull] = ACTIONS(5982),
    [anon_sym_mutable] = ACTIONS(5982),
    [anon_sym_constinit] = ACTIONS(5982),
    [anon_sym_consteval] = ACTIONS(5982),
    [anon_sym___shared__] = ACTIONS(5982),
    [anon_sym___local__] = ACTIONS(5982),
    [anon_sym___constant__] = ACTIONS(5982),
    [anon_sym___managed__] = ACTIONS(5982),
    [anon_sym___grid_constant__] = ACTIONS(5982),
    [anon_sym_alignas] = ACTIONS(5982),
    [anon_sym__Alignas] = ACTIONS(5982),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5982),
    [anon_sym_decltype] = ACTIONS(5982),
    [anon_sym_template] = ACTIONS(5982),
    [anon_sym_GT2] = ACTIONS(5980),
    [anon_sym_operator] = ACTIONS(5982),
    [anon_sym___launch_bounds__] = ACTIONS(5982),
  },
  [STATE(2322)] = {
    [sym_identifier] = ACTIONS(4366),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_RPAREN] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_TILDE] = ACTIONS(4368),
    [anon_sym_STAR] = ACTIONS(4368),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_SEMI] = ACTIONS(4368),
    [anon_sym___extension__] = ACTIONS(4366),
    [anon_sym___device__] = ACTIONS(4366),
    [anon_sym___host__] = ACTIONS(4366),
    [anon_sym___global__] = ACTIONS(4366),
    [anon_sym___forceinline__] = ACTIONS(4366),
    [anon_sym___noinline__] = ACTIONS(4366),
    [anon_sym_virtual] = ACTIONS(4366),
    [anon_sym_extern] = ACTIONS(4366),
    [anon_sym___attribute__] = ACTIONS(4366),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4368),
    [anon_sym___declspec] = ACTIONS(4366),
    [anon_sym___based] = ACTIONS(4366),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4366),
    [anon_sym_static] = ACTIONS(4366),
    [anon_sym_EQ] = ACTIONS(4368),
    [anon_sym_register] = ACTIONS(4366),
    [anon_sym_inline] = ACTIONS(4366),
    [anon_sym___inline] = ACTIONS(4366),
    [anon_sym___inline__] = ACTIONS(4366),
    [anon_sym___forceinline] = ACTIONS(4366),
    [anon_sym_thread_local] = ACTIONS(4366),
    [anon_sym___thread] = ACTIONS(4366),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4366),
    [anon_sym_volatile] = ACTIONS(4366),
    [anon_sym_restrict] = ACTIONS(4366),
    [anon_sym___restrict__] = ACTIONS(4366),
    [anon_sym__Atomic] = ACTIONS(4366),
    [anon_sym__Noreturn] = ACTIONS(4366),
    [anon_sym_noreturn] = ACTIONS(4366),
    [anon_sym__Nonnull] = ACTIONS(4366),
    [anon_sym_mutable] = ACTIONS(4366),
    [anon_sym_constinit] = ACTIONS(4366),
    [anon_sym_consteval] = ACTIONS(4366),
    [anon_sym___shared__] = ACTIONS(4366),
    [anon_sym___local__] = ACTIONS(4366),
    [anon_sym___constant__] = ACTIONS(4366),
    [anon_sym___managed__] = ACTIONS(4366),
    [anon_sym___grid_constant__] = ACTIONS(4366),
    [anon_sym_alignas] = ACTIONS(4366),
    [anon_sym__Alignas] = ACTIONS(4366),
    [anon_sym_COLON] = ACTIONS(4366),
    [anon_sym_or] = ACTIONS(4366),
    [anon_sym_and] = ACTIONS(4366),
    [anon_sym_asm] = ACTIONS(4366),
    [anon_sym___asm__] = ACTIONS(4366),
    [anon_sym___asm] = ACTIONS(4366),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4366),
    [anon_sym_decltype] = ACTIONS(4366),
    [anon_sym_final] = ACTIONS(4366),
    [anon_sym_override] = ACTIONS(4366),
    [anon_sym_template] = ACTIONS(4366),
    [anon_sym_GT2] = ACTIONS(4368),
    [anon_sym_operator] = ACTIONS(4366),
    [anon_sym_try] = ACTIONS(4366),
    [anon_sym_requires] = ACTIONS(4366),
    [anon_sym___launch_bounds__] = ACTIONS(4366),
  },
  [STATE(2323)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2327),
    [sym_identifier] = ACTIONS(5986),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5984),
    [anon_sym_COMMA] = ACTIONS(5984),
    [anon_sym_RPAREN] = ACTIONS(5984),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_TILDE] = ACTIONS(5984),
    [anon_sym_STAR] = ACTIONS(5984),
    [anon_sym_AMP_AMP] = ACTIONS(5984),
    [anon_sym_AMP] = ACTIONS(5986),
    [anon_sym_SEMI] = ACTIONS(5984),
    [anon_sym___extension__] = ACTIONS(5986),
    [anon_sym___device__] = ACTIONS(5986),
    [anon_sym___host__] = ACTIONS(5986),
    [anon_sym___global__] = ACTIONS(5986),
    [anon_sym___forceinline__] = ACTIONS(5986),
    [anon_sym___noinline__] = ACTIONS(5986),
    [anon_sym_virtual] = ACTIONS(5986),
    [anon_sym_extern] = ACTIONS(5986),
    [anon_sym___attribute__] = ACTIONS(5986),
    [anon_sym___attribute] = ACTIONS(5986),
    [anon_sym_COLON_COLON] = ACTIONS(5984),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5984),
    [anon_sym___declspec] = ACTIONS(5986),
    [anon_sym___based] = ACTIONS(5986),
    [anon_sym___cdecl] = ACTIONS(5986),
    [anon_sym___clrcall] = ACTIONS(5986),
    [anon_sym___stdcall] = ACTIONS(5986),
    [anon_sym___fastcall] = ACTIONS(5986),
    [anon_sym___thiscall] = ACTIONS(5986),
    [anon_sym___vectorcall] = ACTIONS(5986),
    [anon_sym_LBRACE] = ACTIONS(5984),
    [anon_sym_signed] = ACTIONS(6256),
    [anon_sym_unsigned] = ACTIONS(6256),
    [anon_sym_long] = ACTIONS(6256),
    [anon_sym_short] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(5986),
    [anon_sym_static] = ACTIONS(5986),
    [anon_sym_EQ] = ACTIONS(5984),
    [anon_sym_register] = ACTIONS(5986),
    [anon_sym_inline] = ACTIONS(5986),
    [anon_sym___inline] = ACTIONS(5986),
    [anon_sym___inline__] = ACTIONS(5986),
    [anon_sym___forceinline] = ACTIONS(5986),
    [anon_sym_thread_local] = ACTIONS(5986),
    [anon_sym___thread] = ACTIONS(5986),
    [anon_sym_const] = ACTIONS(5986),
    [anon_sym_constexpr] = ACTIONS(5986),
    [anon_sym_volatile] = ACTIONS(5986),
    [anon_sym_restrict] = ACTIONS(5986),
    [anon_sym___restrict__] = ACTIONS(5986),
    [anon_sym__Atomic] = ACTIONS(5986),
    [anon_sym__Noreturn] = ACTIONS(5986),
    [anon_sym_noreturn] = ACTIONS(5986),
    [anon_sym__Nonnull] = ACTIONS(5986),
    [anon_sym_mutable] = ACTIONS(5986),
    [anon_sym_constinit] = ACTIONS(5986),
    [anon_sym_consteval] = ACTIONS(5986),
    [anon_sym___shared__] = ACTIONS(5986),
    [anon_sym___local__] = ACTIONS(5986),
    [anon_sym___constant__] = ACTIONS(5986),
    [anon_sym___managed__] = ACTIONS(5986),
    [anon_sym___grid_constant__] = ACTIONS(5986),
    [anon_sym_alignas] = ACTIONS(5986),
    [anon_sym__Alignas] = ACTIONS(5986),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5986),
    [anon_sym_decltype] = ACTIONS(5986),
    [anon_sym_template] = ACTIONS(5986),
    [anon_sym_GT2] = ACTIONS(5984),
    [anon_sym_operator] = ACTIONS(5986),
    [anon_sym___launch_bounds__] = ACTIONS(5986),
  },
  [STATE(2324)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2327),
    [sym_identifier] = ACTIONS(6012),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6010),
    [anon_sym_COMMA] = ACTIONS(6010),
    [anon_sym_RPAREN] = ACTIONS(6010),
    [anon_sym_LPAREN2] = ACTIONS(6010),
    [anon_sym_TILDE] = ACTIONS(6010),
    [anon_sym_STAR] = ACTIONS(6010),
    [anon_sym_AMP_AMP] = ACTIONS(6010),
    [anon_sym_AMP] = ACTIONS(6012),
    [anon_sym_SEMI] = ACTIONS(6010),
    [anon_sym___extension__] = ACTIONS(6012),
    [anon_sym___device__] = ACTIONS(6012),
    [anon_sym___host__] = ACTIONS(6012),
    [anon_sym___global__] = ACTIONS(6012),
    [anon_sym___forceinline__] = ACTIONS(6012),
    [anon_sym___noinline__] = ACTIONS(6012),
    [anon_sym_virtual] = ACTIONS(6012),
    [anon_sym_extern] = ACTIONS(6012),
    [anon_sym___attribute__] = ACTIONS(6012),
    [anon_sym___attribute] = ACTIONS(6012),
    [anon_sym_COLON_COLON] = ACTIONS(6010),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6010),
    [anon_sym___declspec] = ACTIONS(6012),
    [anon_sym___based] = ACTIONS(6012),
    [anon_sym___cdecl] = ACTIONS(6012),
    [anon_sym___clrcall] = ACTIONS(6012),
    [anon_sym___stdcall] = ACTIONS(6012),
    [anon_sym___fastcall] = ACTIONS(6012),
    [anon_sym___thiscall] = ACTIONS(6012),
    [anon_sym___vectorcall] = ACTIONS(6012),
    [anon_sym_LBRACE] = ACTIONS(6010),
    [anon_sym_signed] = ACTIONS(6256),
    [anon_sym_unsigned] = ACTIONS(6256),
    [anon_sym_long] = ACTIONS(6256),
    [anon_sym_short] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(6012),
    [anon_sym_static] = ACTIONS(6012),
    [anon_sym_EQ] = ACTIONS(6010),
    [anon_sym_register] = ACTIONS(6012),
    [anon_sym_inline] = ACTIONS(6012),
    [anon_sym___inline] = ACTIONS(6012),
    [anon_sym___inline__] = ACTIONS(6012),
    [anon_sym___forceinline] = ACTIONS(6012),
    [anon_sym_thread_local] = ACTIONS(6012),
    [anon_sym___thread] = ACTIONS(6012),
    [anon_sym_const] = ACTIONS(6012),
    [anon_sym_constexpr] = ACTIONS(6012),
    [anon_sym_volatile] = ACTIONS(6012),
    [anon_sym_restrict] = ACTIONS(6012),
    [anon_sym___restrict__] = ACTIONS(6012),
    [anon_sym__Atomic] = ACTIONS(6012),
    [anon_sym__Noreturn] = ACTIONS(6012),
    [anon_sym_noreturn] = ACTIONS(6012),
    [anon_sym__Nonnull] = ACTIONS(6012),
    [anon_sym_mutable] = ACTIONS(6012),
    [anon_sym_constinit] = ACTIONS(6012),
    [anon_sym_consteval] = ACTIONS(6012),
    [anon_sym___shared__] = ACTIONS(6012),
    [anon_sym___local__] = ACTIONS(6012),
    [anon_sym___constant__] = ACTIONS(6012),
    [anon_sym___managed__] = ACTIONS(6012),
    [anon_sym___grid_constant__] = ACTIONS(6012),
    [anon_sym_alignas] = ACTIONS(6012),
    [anon_sym__Alignas] = ACTIONS(6012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6012),
    [anon_sym_decltype] = ACTIONS(6012),
    [anon_sym_template] = ACTIONS(6012),
    [anon_sym_GT2] = ACTIONS(6010),
    [anon_sym_operator] = ACTIONS(6012),
    [anon_sym___launch_bounds__] = ACTIONS(6012),
  },
  [STATE(2325)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2318),
    [sym_identifier] = ACTIONS(5968),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5966),
    [anon_sym_COMMA] = ACTIONS(5966),
    [anon_sym_RPAREN] = ACTIONS(5966),
    [anon_sym_LPAREN2] = ACTIONS(5966),
    [anon_sym_TILDE] = ACTIONS(5966),
    [anon_sym_STAR] = ACTIONS(5966),
    [anon_sym_AMP_AMP] = ACTIONS(5966),
    [anon_sym_AMP] = ACTIONS(5968),
    [anon_sym_SEMI] = ACTIONS(5966),
    [anon_sym___extension__] = ACTIONS(5968),
    [anon_sym___device__] = ACTIONS(5968),
    [anon_sym___host__] = ACTIONS(5968),
    [anon_sym___global__] = ACTIONS(5968),
    [anon_sym___forceinline__] = ACTIONS(5968),
    [anon_sym___noinline__] = ACTIONS(5968),
    [anon_sym_virtual] = ACTIONS(5968),
    [anon_sym_extern] = ACTIONS(5968),
    [anon_sym___attribute__] = ACTIONS(5968),
    [anon_sym___attribute] = ACTIONS(5968),
    [anon_sym_COLON_COLON] = ACTIONS(5966),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5966),
    [anon_sym___declspec] = ACTIONS(5968),
    [anon_sym___based] = ACTIONS(5968),
    [anon_sym___cdecl] = ACTIONS(5968),
    [anon_sym___clrcall] = ACTIONS(5968),
    [anon_sym___stdcall] = ACTIONS(5968),
    [anon_sym___fastcall] = ACTIONS(5968),
    [anon_sym___thiscall] = ACTIONS(5968),
    [anon_sym___vectorcall] = ACTIONS(5968),
    [anon_sym_LBRACE] = ACTIONS(5966),
    [anon_sym_signed] = ACTIONS(6281),
    [anon_sym_unsigned] = ACTIONS(6281),
    [anon_sym_long] = ACTIONS(6281),
    [anon_sym_short] = ACTIONS(6281),
    [anon_sym_LBRACK] = ACTIONS(5968),
    [anon_sym_static] = ACTIONS(5968),
    [anon_sym_EQ] = ACTIONS(5966),
    [anon_sym_register] = ACTIONS(5968),
    [anon_sym_inline] = ACTIONS(5968),
    [anon_sym___inline] = ACTIONS(5968),
    [anon_sym___inline__] = ACTIONS(5968),
    [anon_sym___forceinline] = ACTIONS(5968),
    [anon_sym_thread_local] = ACTIONS(5968),
    [anon_sym___thread] = ACTIONS(5968),
    [anon_sym_const] = ACTIONS(5968),
    [anon_sym_constexpr] = ACTIONS(5968),
    [anon_sym_volatile] = ACTIONS(5968),
    [anon_sym_restrict] = ACTIONS(5968),
    [anon_sym___restrict__] = ACTIONS(5968),
    [anon_sym__Atomic] = ACTIONS(5968),
    [anon_sym__Noreturn] = ACTIONS(5968),
    [anon_sym_noreturn] = ACTIONS(5968),
    [anon_sym__Nonnull] = ACTIONS(5968),
    [anon_sym_mutable] = ACTIONS(5968),
    [anon_sym_constinit] = ACTIONS(5968),
    [anon_sym_consteval] = ACTIONS(5968),
    [anon_sym___shared__] = ACTIONS(5968),
    [anon_sym___local__] = ACTIONS(5968),
    [anon_sym___constant__] = ACTIONS(5968),
    [anon_sym___managed__] = ACTIONS(5968),
    [anon_sym___grid_constant__] = ACTIONS(5968),
    [anon_sym_alignas] = ACTIONS(5968),
    [anon_sym__Alignas] = ACTIONS(5968),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5968),
    [anon_sym_decltype] = ACTIONS(5968),
    [anon_sym_template] = ACTIONS(5968),
    [anon_sym_GT2] = ACTIONS(5966),
    [anon_sym_operator] = ACTIONS(5968),
    [anon_sym___launch_bounds__] = ACTIONS(5968),
  },
  [STATE(2326)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2327),
    [sym_identifier] = ACTIONS(5964),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5962),
    [anon_sym_COMMA] = ACTIONS(5962),
    [anon_sym_RPAREN] = ACTIONS(5962),
    [anon_sym_LPAREN2] = ACTIONS(5962),
    [anon_sym_TILDE] = ACTIONS(5962),
    [anon_sym_STAR] = ACTIONS(5962),
    [anon_sym_AMP_AMP] = ACTIONS(5962),
    [anon_sym_AMP] = ACTIONS(5964),
    [anon_sym_SEMI] = ACTIONS(5962),
    [anon_sym___extension__] = ACTIONS(5964),
    [anon_sym___device__] = ACTIONS(5964),
    [anon_sym___host__] = ACTIONS(5964),
    [anon_sym___global__] = ACTIONS(5964),
    [anon_sym___forceinline__] = ACTIONS(5964),
    [anon_sym___noinline__] = ACTIONS(5964),
    [anon_sym_virtual] = ACTIONS(5964),
    [anon_sym_extern] = ACTIONS(5964),
    [anon_sym___attribute__] = ACTIONS(5964),
    [anon_sym___attribute] = ACTIONS(5964),
    [anon_sym_COLON_COLON] = ACTIONS(5962),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5962),
    [anon_sym___declspec] = ACTIONS(5964),
    [anon_sym___based] = ACTIONS(5964),
    [anon_sym___cdecl] = ACTIONS(5964),
    [anon_sym___clrcall] = ACTIONS(5964),
    [anon_sym___stdcall] = ACTIONS(5964),
    [anon_sym___fastcall] = ACTIONS(5964),
    [anon_sym___thiscall] = ACTIONS(5964),
    [anon_sym___vectorcall] = ACTIONS(5964),
    [anon_sym_LBRACE] = ACTIONS(5962),
    [anon_sym_signed] = ACTIONS(6256),
    [anon_sym_unsigned] = ACTIONS(6256),
    [anon_sym_long] = ACTIONS(6256),
    [anon_sym_short] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(5964),
    [anon_sym_static] = ACTIONS(5964),
    [anon_sym_EQ] = ACTIONS(5962),
    [anon_sym_register] = ACTIONS(5964),
    [anon_sym_inline] = ACTIONS(5964),
    [anon_sym___inline] = ACTIONS(5964),
    [anon_sym___inline__] = ACTIONS(5964),
    [anon_sym___forceinline] = ACTIONS(5964),
    [anon_sym_thread_local] = ACTIONS(5964),
    [anon_sym___thread] = ACTIONS(5964),
    [anon_sym_const] = ACTIONS(5964),
    [anon_sym_constexpr] = ACTIONS(5964),
    [anon_sym_volatile] = ACTIONS(5964),
    [anon_sym_restrict] = ACTIONS(5964),
    [anon_sym___restrict__] = ACTIONS(5964),
    [anon_sym__Atomic] = ACTIONS(5964),
    [anon_sym__Noreturn] = ACTIONS(5964),
    [anon_sym_noreturn] = ACTIONS(5964),
    [anon_sym__Nonnull] = ACTIONS(5964),
    [anon_sym_mutable] = ACTIONS(5964),
    [anon_sym_constinit] = ACTIONS(5964),
    [anon_sym_consteval] = ACTIONS(5964),
    [anon_sym___shared__] = ACTIONS(5964),
    [anon_sym___local__] = ACTIONS(5964),
    [anon_sym___constant__] = ACTIONS(5964),
    [anon_sym___managed__] = ACTIONS(5964),
    [anon_sym___grid_constant__] = ACTIONS(5964),
    [anon_sym_alignas] = ACTIONS(5964),
    [anon_sym__Alignas] = ACTIONS(5964),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5964),
    [anon_sym_decltype] = ACTIONS(5964),
    [anon_sym_template] = ACTIONS(5964),
    [anon_sym_GT2] = ACTIONS(5962),
    [anon_sym_operator] = ACTIONS(5964),
    [anon_sym___launch_bounds__] = ACTIONS(5964),
  },
  [STATE(2327)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2327),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_TILDE] = ACTIONS(5135),
    [anon_sym_STAR] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___device__] = ACTIONS(5133),
    [anon_sym___host__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___forceinline__] = ACTIONS(5133),
    [anon_sym___noinline__] = ACTIONS(5133),
    [anon_sym_virtual] = ACTIONS(5133),
    [anon_sym_extern] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_COLON_COLON] = ACTIONS(5135),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5135),
    [anon_sym___declspec] = ACTIONS(5133),
    [anon_sym___based] = ACTIONS(5133),
    [anon_sym___cdecl] = ACTIONS(5133),
    [anon_sym___clrcall] = ACTIONS(5133),
    [anon_sym___stdcall] = ACTIONS(5133),
    [anon_sym___fastcall] = ACTIONS(5133),
    [anon_sym___thiscall] = ACTIONS(5133),
    [anon_sym___vectorcall] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(6283),
    [anon_sym_unsigned] = ACTIONS(6283),
    [anon_sym_long] = ACTIONS(6283),
    [anon_sym_short] = ACTIONS(6283),
    [anon_sym_LBRACK] = ACTIONS(5133),
    [anon_sym_static] = ACTIONS(5133),
    [anon_sym_EQ] = ACTIONS(5135),
    [anon_sym_register] = ACTIONS(5133),
    [anon_sym_inline] = ACTIONS(5133),
    [anon_sym___inline] = ACTIONS(5133),
    [anon_sym___inline__] = ACTIONS(5133),
    [anon_sym___forceinline] = ACTIONS(5133),
    [anon_sym_thread_local] = ACTIONS(5133),
    [anon_sym___thread] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_template] = ACTIONS(5133),
    [anon_sym_GT2] = ACTIONS(5135),
    [anon_sym_operator] = ACTIONS(5133),
    [anon_sym___launch_bounds__] = ACTIONS(5133),
  },
  [STATE(2328)] = {
    [sym_identifier] = ACTIONS(4396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_RPAREN] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_TILDE] = ACTIONS(4398),
    [anon_sym_STAR] = ACTIONS(4398),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_SEMI] = ACTIONS(4398),
    [anon_sym___extension__] = ACTIONS(4396),
    [anon_sym___device__] = ACTIONS(4396),
    [anon_sym___host__] = ACTIONS(4396),
    [anon_sym___global__] = ACTIONS(4396),
    [anon_sym___forceinline__] = ACTIONS(4396),
    [anon_sym___noinline__] = ACTIONS(4396),
    [anon_sym_virtual] = ACTIONS(4396),
    [anon_sym_extern] = ACTIONS(4396),
    [anon_sym___attribute__] = ACTIONS(4396),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4398),
    [anon_sym___declspec] = ACTIONS(4396),
    [anon_sym___based] = ACTIONS(4396),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4396),
    [anon_sym_static] = ACTIONS(4396),
    [anon_sym_EQ] = ACTIONS(4398),
    [anon_sym_register] = ACTIONS(4396),
    [anon_sym_inline] = ACTIONS(4396),
    [anon_sym___inline] = ACTIONS(4396),
    [anon_sym___inline__] = ACTIONS(4396),
    [anon_sym___forceinline] = ACTIONS(4396),
    [anon_sym_thread_local] = ACTIONS(4396),
    [anon_sym___thread] = ACTIONS(4396),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4396),
    [anon_sym_volatile] = ACTIONS(4396),
    [anon_sym_restrict] = ACTIONS(4396),
    [anon_sym___restrict__] = ACTIONS(4396),
    [anon_sym__Atomic] = ACTIONS(4396),
    [anon_sym__Noreturn] = ACTIONS(4396),
    [anon_sym_noreturn] = ACTIONS(4396),
    [anon_sym__Nonnull] = ACTIONS(4396),
    [anon_sym_mutable] = ACTIONS(4396),
    [anon_sym_constinit] = ACTIONS(4396),
    [anon_sym_consteval] = ACTIONS(4396),
    [anon_sym___shared__] = ACTIONS(4396),
    [anon_sym___local__] = ACTIONS(4396),
    [anon_sym___constant__] = ACTIONS(4396),
    [anon_sym___managed__] = ACTIONS(4396),
    [anon_sym___grid_constant__] = ACTIONS(4396),
    [anon_sym_alignas] = ACTIONS(4396),
    [anon_sym__Alignas] = ACTIONS(4396),
    [anon_sym_COLON] = ACTIONS(4396),
    [anon_sym_or] = ACTIONS(4396),
    [anon_sym_and] = ACTIONS(4396),
    [anon_sym_asm] = ACTIONS(4396),
    [anon_sym___asm__] = ACTIONS(4396),
    [anon_sym___asm] = ACTIONS(4396),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4396),
    [anon_sym_decltype] = ACTIONS(4396),
    [anon_sym_final] = ACTIONS(4396),
    [anon_sym_override] = ACTIONS(4396),
    [anon_sym_template] = ACTIONS(4396),
    [anon_sym_GT2] = ACTIONS(4398),
    [anon_sym_operator] = ACTIONS(4396),
    [anon_sym_try] = ACTIONS(4396),
    [anon_sym_requires] = ACTIONS(4396),
    [anon_sym___launch_bounds__] = ACTIONS(4396),
  },
  [STATE(2329)] = {
    [sym_identifier] = ACTIONS(4402),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_RPAREN] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_TILDE] = ACTIONS(4404),
    [anon_sym_STAR] = ACTIONS(4404),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_SEMI] = ACTIONS(4404),
    [anon_sym___extension__] = ACTIONS(4402),
    [anon_sym___device__] = ACTIONS(4402),
    [anon_sym___host__] = ACTIONS(4402),
    [anon_sym___global__] = ACTIONS(4402),
    [anon_sym___forceinline__] = ACTIONS(4402),
    [anon_sym___noinline__] = ACTIONS(4402),
    [anon_sym_virtual] = ACTIONS(4402),
    [anon_sym_extern] = ACTIONS(4402),
    [anon_sym___attribute__] = ACTIONS(4402),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4404),
    [anon_sym___declspec] = ACTIONS(4402),
    [anon_sym___based] = ACTIONS(4402),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4402),
    [anon_sym_static] = ACTIONS(4402),
    [anon_sym_EQ] = ACTIONS(4404),
    [anon_sym_register] = ACTIONS(4402),
    [anon_sym_inline] = ACTIONS(4402),
    [anon_sym___inline] = ACTIONS(4402),
    [anon_sym___inline__] = ACTIONS(4402),
    [anon_sym___forceinline] = ACTIONS(4402),
    [anon_sym_thread_local] = ACTIONS(4402),
    [anon_sym___thread] = ACTIONS(4402),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4402),
    [anon_sym_volatile] = ACTIONS(4402),
    [anon_sym_restrict] = ACTIONS(4402),
    [anon_sym___restrict__] = ACTIONS(4402),
    [anon_sym__Atomic] = ACTIONS(4402),
    [anon_sym__Noreturn] = ACTIONS(4402),
    [anon_sym_noreturn] = ACTIONS(4402),
    [anon_sym__Nonnull] = ACTIONS(4402),
    [anon_sym_mutable] = ACTIONS(4402),
    [anon_sym_constinit] = ACTIONS(4402),
    [anon_sym_consteval] = ACTIONS(4402),
    [anon_sym___shared__] = ACTIONS(4402),
    [anon_sym___local__] = ACTIONS(4402),
    [anon_sym___constant__] = ACTIONS(4402),
    [anon_sym___managed__] = ACTIONS(4402),
    [anon_sym___grid_constant__] = ACTIONS(4402),
    [anon_sym_alignas] = ACTIONS(4402),
    [anon_sym__Alignas] = ACTIONS(4402),
    [anon_sym_COLON] = ACTIONS(4402),
    [anon_sym_or] = ACTIONS(4402),
    [anon_sym_and] = ACTIONS(4402),
    [anon_sym_asm] = ACTIONS(4402),
    [anon_sym___asm__] = ACTIONS(4402),
    [anon_sym___asm] = ACTIONS(4402),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4402),
    [anon_sym_decltype] = ACTIONS(4402),
    [anon_sym_final] = ACTIONS(4402),
    [anon_sym_override] = ACTIONS(4402),
    [anon_sym_template] = ACTIONS(4402),
    [anon_sym_GT2] = ACTIONS(4404),
    [anon_sym_operator] = ACTIONS(4402),
    [anon_sym_try] = ACTIONS(4402),
    [anon_sym_requires] = ACTIONS(4402),
    [anon_sym___launch_bounds__] = ACTIONS(4402),
  },
  [STATE(2330)] = {
    [sym_identifier] = ACTIONS(4408),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_RPAREN] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_TILDE] = ACTIONS(4410),
    [anon_sym_STAR] = ACTIONS(4410),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_SEMI] = ACTIONS(4410),
    [anon_sym___extension__] = ACTIONS(4408),
    [anon_sym___device__] = ACTIONS(4408),
    [anon_sym___host__] = ACTIONS(4408),
    [anon_sym___global__] = ACTIONS(4408),
    [anon_sym___forceinline__] = ACTIONS(4408),
    [anon_sym___noinline__] = ACTIONS(4408),
    [anon_sym_virtual] = ACTIONS(4408),
    [anon_sym_extern] = ACTIONS(4408),
    [anon_sym___attribute__] = ACTIONS(4408),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4410),
    [anon_sym___declspec] = ACTIONS(4408),
    [anon_sym___based] = ACTIONS(4408),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4408),
    [anon_sym_static] = ACTIONS(4408),
    [anon_sym_EQ] = ACTIONS(4410),
    [anon_sym_register] = ACTIONS(4408),
    [anon_sym_inline] = ACTIONS(4408),
    [anon_sym___inline] = ACTIONS(4408),
    [anon_sym___inline__] = ACTIONS(4408),
    [anon_sym___forceinline] = ACTIONS(4408),
    [anon_sym_thread_local] = ACTIONS(4408),
    [anon_sym___thread] = ACTIONS(4408),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4408),
    [anon_sym_volatile] = ACTIONS(4408),
    [anon_sym_restrict] = ACTIONS(4408),
    [anon_sym___restrict__] = ACTIONS(4408),
    [anon_sym__Atomic] = ACTIONS(4408),
    [anon_sym__Noreturn] = ACTIONS(4408),
    [anon_sym_noreturn] = ACTIONS(4408),
    [anon_sym__Nonnull] = ACTIONS(4408),
    [anon_sym_mutable] = ACTIONS(4408),
    [anon_sym_constinit] = ACTIONS(4408),
    [anon_sym_consteval] = ACTIONS(4408),
    [anon_sym___shared__] = ACTIONS(4408),
    [anon_sym___local__] = ACTIONS(4408),
    [anon_sym___constant__] = ACTIONS(4408),
    [anon_sym___managed__] = ACTIONS(4408),
    [anon_sym___grid_constant__] = ACTIONS(4408),
    [anon_sym_alignas] = ACTIONS(4408),
    [anon_sym__Alignas] = ACTIONS(4408),
    [anon_sym_COLON] = ACTIONS(4408),
    [anon_sym_or] = ACTIONS(4408),
    [anon_sym_and] = ACTIONS(4408),
    [anon_sym_asm] = ACTIONS(4408),
    [anon_sym___asm__] = ACTIONS(4408),
    [anon_sym___asm] = ACTIONS(4408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4408),
    [anon_sym_decltype] = ACTIONS(4408),
    [anon_sym_final] = ACTIONS(4408),
    [anon_sym_override] = ACTIONS(4408),
    [anon_sym_template] = ACTIONS(4408),
    [anon_sym_GT2] = ACTIONS(4410),
    [anon_sym_operator] = ACTIONS(4408),
    [anon_sym_try] = ACTIONS(4408),
    [anon_sym_requires] = ACTIONS(4408),
    [anon_sym___launch_bounds__] = ACTIONS(4408),
  },
  [STATE(2331)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2309),
    [sym_identifier] = ACTIONS(5770),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_RPAREN] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_TILDE] = ACTIONS(5772),
    [anon_sym_STAR] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym___extension__] = ACTIONS(5770),
    [anon_sym___device__] = ACTIONS(5770),
    [anon_sym___host__] = ACTIONS(5770),
    [anon_sym___global__] = ACTIONS(5770),
    [anon_sym___forceinline__] = ACTIONS(5770),
    [anon_sym___noinline__] = ACTIONS(5770),
    [anon_sym_virtual] = ACTIONS(5770),
    [anon_sym_extern] = ACTIONS(5770),
    [anon_sym___attribute__] = ACTIONS(5770),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_COLON_COLON] = ACTIONS(5772),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5772),
    [anon_sym___declspec] = ACTIONS(5770),
    [anon_sym___based] = ACTIONS(5770),
    [anon_sym___cdecl] = ACTIONS(5770),
    [anon_sym___clrcall] = ACTIONS(5770),
    [anon_sym___stdcall] = ACTIONS(5770),
    [anon_sym___fastcall] = ACTIONS(5770),
    [anon_sym___thiscall] = ACTIONS(5770),
    [anon_sym___vectorcall] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_signed] = ACTIONS(6190),
    [anon_sym_unsigned] = ACTIONS(6190),
    [anon_sym_long] = ACTIONS(6190),
    [anon_sym_short] = ACTIONS(6190),
    [anon_sym_LBRACK] = ACTIONS(5770),
    [anon_sym_static] = ACTIONS(5770),
    [anon_sym_EQ] = ACTIONS(5772),
    [anon_sym_register] = ACTIONS(5770),
    [anon_sym_inline] = ACTIONS(5770),
    [anon_sym___inline] = ACTIONS(5770),
    [anon_sym___inline__] = ACTIONS(5770),
    [anon_sym___forceinline] = ACTIONS(5770),
    [anon_sym_thread_local] = ACTIONS(5770),
    [anon_sym___thread] = ACTIONS(5770),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_constexpr] = ACTIONS(5770),
    [anon_sym_volatile] = ACTIONS(5770),
    [anon_sym_restrict] = ACTIONS(5770),
    [anon_sym___restrict__] = ACTIONS(5770),
    [anon_sym__Atomic] = ACTIONS(5770),
    [anon_sym__Noreturn] = ACTIONS(5770),
    [anon_sym_noreturn] = ACTIONS(5770),
    [anon_sym__Nonnull] = ACTIONS(5770),
    [anon_sym_mutable] = ACTIONS(5770),
    [anon_sym_constinit] = ACTIONS(5770),
    [anon_sym_consteval] = ACTIONS(5770),
    [anon_sym___shared__] = ACTIONS(5770),
    [anon_sym___local__] = ACTIONS(5770),
    [anon_sym___constant__] = ACTIONS(5770),
    [anon_sym___managed__] = ACTIONS(5770),
    [anon_sym___grid_constant__] = ACTIONS(5770),
    [anon_sym_alignas] = ACTIONS(5770),
    [anon_sym__Alignas] = ACTIONS(5770),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5770),
    [anon_sym_decltype] = ACTIONS(5770),
    [anon_sym_template] = ACTIONS(5770),
    [anon_sym_GT2] = ACTIONS(5772),
    [anon_sym_operator] = ACTIONS(5770),
    [anon_sym___launch_bounds__] = ACTIONS(5770),
  },
  [STATE(2332)] = {
    [sym_string_literal] = STATE(1664),
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [anon_sym_L_DQUOTE] = ACTIONS(6290),
    [anon_sym_u_DQUOTE] = ACTIONS(6290),
    [anon_sym_U_DQUOTE] = ACTIONS(6290),
    [anon_sym_u8_DQUOTE] = ACTIONS(6290),
    [anon_sym_DQUOTE] = ACTIONS(6290),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2333)] = {
    [sym_type_qualifier] = STATE(1698),
    [sym_alignas_qualifier] = STATE(1719),
    [aux_sym__type_definition_type_repeat1] = STATE(1698),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2638),
    [sym_identifier] = ACTIONS(6292),
    [anon_sym_COMMA] = ACTIONS(5173),
    [anon_sym_RPAREN] = ACTIONS(5173),
    [anon_sym_LPAREN2] = ACTIONS(5173),
    [anon_sym_STAR] = ACTIONS(5173),
    [anon_sym_AMP_AMP] = ACTIONS(5173),
    [anon_sym_AMP] = ACTIONS(5175),
    [anon_sym_SEMI] = ACTIONS(5173),
    [anon_sym___extension__] = ACTIONS(5942),
    [anon_sym___device__] = ACTIONS(5175),
    [anon_sym___host__] = ACTIONS(5175),
    [anon_sym___global__] = ACTIONS(5942),
    [anon_sym___forceinline__] = ACTIONS(5175),
    [anon_sym___noinline__] = ACTIONS(5175),
    [anon_sym_virtual] = ACTIONS(5175),
    [anon_sym_extern] = ACTIONS(5175),
    [anon_sym___attribute__] = ACTIONS(5175),
    [anon_sym___attribute] = ACTIONS(5175),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5173),
    [anon_sym___declspec] = ACTIONS(5175),
    [anon_sym_LBRACE] = ACTIONS(5173),
    [anon_sym_signed] = ACTIONS(6294),
    [anon_sym_unsigned] = ACTIONS(6294),
    [anon_sym_long] = ACTIONS(6294),
    [anon_sym_short] = ACTIONS(6294),
    [anon_sym_LBRACK] = ACTIONS(5175),
    [anon_sym_static] = ACTIONS(5175),
    [anon_sym_EQ] = ACTIONS(5173),
    [anon_sym_register] = ACTIONS(5175),
    [anon_sym_inline] = ACTIONS(5175),
    [anon_sym___inline] = ACTIONS(5175),
    [anon_sym___inline__] = ACTIONS(5175),
    [anon_sym___forceinline] = ACTIONS(5175),
    [anon_sym_thread_local] = ACTIONS(5175),
    [anon_sym___thread] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5942),
    [anon_sym_constexpr] = ACTIONS(5942),
    [anon_sym_volatile] = ACTIONS(5942),
    [anon_sym_restrict] = ACTIONS(5942),
    [anon_sym___restrict__] = ACTIONS(5942),
    [anon_sym__Atomic] = ACTIONS(5942),
    [anon_sym__Noreturn] = ACTIONS(5942),
    [anon_sym_noreturn] = ACTIONS(5942),
    [anon_sym__Nonnull] = ACTIONS(5942),
    [anon_sym_mutable] = ACTIONS(5942),
    [anon_sym_constinit] = ACTIONS(5942),
    [anon_sym_consteval] = ACTIONS(5942),
    [anon_sym___shared__] = ACTIONS(5942),
    [anon_sym___local__] = ACTIONS(5942),
    [anon_sym___constant__] = ACTIONS(5942),
    [anon_sym___managed__] = ACTIONS(5942),
    [anon_sym___grid_constant__] = ACTIONS(5942),
    [anon_sym_alignas] = ACTIONS(5947),
    [anon_sym__Alignas] = ACTIONS(5947),
    [sym_primitive_type] = ACTIONS(6296),
    [anon_sym_asm] = ACTIONS(5175),
    [anon_sym___asm__] = ACTIONS(5175),
    [anon_sym___asm] = ACTIONS(5175),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5175),
    [anon_sym_decltype] = ACTIONS(5175),
    [anon_sym_final] = ACTIONS(5175),
    [anon_sym_override] = ACTIONS(5175),
    [anon_sym_GT2] = ACTIONS(5173),
    [anon_sym_try] = ACTIONS(5175),
    [anon_sym_requires] = ACTIONS(5175),
    [anon_sym___launch_bounds__] = ACTIONS(5175),
  },
  [STATE(2334)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2237),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5354),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5354),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5354),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5351),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5351),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(6096),
    [anon_sym_unsigned] = ACTIONS(6096),
    [anon_sym_long] = ACTIONS(6096),
    [anon_sym_short] = ACTIONS(6096),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5354),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [anon_sym_GT2] = ACTIONS(5354),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
  },
  [STATE(2335)] = {
    [sym__declaration_modifiers] = STATE(2256),
    [sym_attribute_specifier] = STATE(2256),
    [sym_attribute_declaration] = STATE(2256),
    [sym_ms_declspec_modifier] = STATE(2256),
    [sym_storage_class_specifier] = STATE(2256),
    [sym_type_qualifier] = STATE(2256),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2256),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2256),
    [sym_identifier] = ACTIONS(5952),
    [anon_sym_LPAREN2] = ACTIONS(5954),
    [anon_sym_TILDE] = ACTIONS(5954),
    [anon_sym_STAR] = ACTIONS(5954),
    [anon_sym_AMP_AMP] = ACTIONS(5954),
    [anon_sym_AMP] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(6298),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5956),
    [anon_sym___host__] = ACTIONS(5956),
    [anon_sym___global__] = ACTIONS(5956),
    [anon_sym___forceinline__] = ACTIONS(5956),
    [anon_sym___noinline__] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5954),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5952),
    [anon_sym___cdecl] = ACTIONS(5952),
    [anon_sym___clrcall] = ACTIONS(5952),
    [anon_sym___stdcall] = ACTIONS(5952),
    [anon_sym___fastcall] = ACTIONS(5952),
    [anon_sym___thiscall] = ACTIONS(5952),
    [anon_sym___vectorcall] = ACTIONS(5952),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5952),
    [anon_sym_operator] = ACTIONS(5952),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2336)] = {
    [sym__declaration_modifiers] = STATE(2256),
    [sym_attribute_specifier] = STATE(2256),
    [sym_attribute_declaration] = STATE(2256),
    [sym_ms_declspec_modifier] = STATE(2256),
    [sym_storage_class_specifier] = STATE(2256),
    [sym_type_qualifier] = STATE(2256),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2256),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2256),
    [sym_identifier] = ACTIONS(5952),
    [anon_sym_LPAREN2] = ACTIONS(5954),
    [anon_sym_TILDE] = ACTIONS(5954),
    [anon_sym_STAR] = ACTIONS(5954),
    [anon_sym_AMP_AMP] = ACTIONS(5954),
    [anon_sym_AMP] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(6300),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5956),
    [anon_sym___host__] = ACTIONS(5956),
    [anon_sym___global__] = ACTIONS(5956),
    [anon_sym___forceinline__] = ACTIONS(5956),
    [anon_sym___noinline__] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5954),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5952),
    [anon_sym___cdecl] = ACTIONS(5952),
    [anon_sym___clrcall] = ACTIONS(5952),
    [anon_sym___stdcall] = ACTIONS(5952),
    [anon_sym___fastcall] = ACTIONS(5952),
    [anon_sym___thiscall] = ACTIONS(5952),
    [anon_sym___vectorcall] = ACTIONS(5952),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5952),
    [anon_sym_operator] = ACTIONS(5952),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2337)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2337),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5135),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5135),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5135),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(6302),
    [anon_sym_unsigned] = ACTIONS(6302),
    [anon_sym_long] = ACTIONS(6302),
    [anon_sym_short] = ACTIONS(6302),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5135),
  },
  [STATE(2338)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2337),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5354),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_DASH] = ACTIONS(5351),
    [anon_sym_PLUS] = ACTIONS(5351),
    [anon_sym_STAR] = ACTIONS(5354),
    [anon_sym_SLASH] = ACTIONS(5351),
    [anon_sym_PERCENT] = ACTIONS(5354),
    [anon_sym_PIPE_PIPE] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_PIPE] = ACTIONS(5351),
    [anon_sym_CARET] = ACTIONS(5354),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_EQ_EQ] = ACTIONS(5354),
    [anon_sym_BANG_EQ] = ACTIONS(5354),
    [anon_sym_GT] = ACTIONS(5351),
    [anon_sym_GT_EQ] = ACTIONS(5354),
    [anon_sym_LT_EQ] = ACTIONS(5351),
    [anon_sym_LT] = ACTIONS(5351),
    [anon_sym_LT_LT] = ACTIONS(5351),
    [anon_sym_GT_GT] = ACTIONS(5351),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___global__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(6302),
    [anon_sym_unsigned] = ACTIONS(6302),
    [anon_sym_long] = ACTIONS(6302),
    [anon_sym_short] = ACTIONS(6302),
    [anon_sym_LBRACK] = ACTIONS(5354),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym__Nonnull] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym___shared__] = ACTIONS(5133),
    [anon_sym___local__] = ACTIONS(5133),
    [anon_sym___constant__] = ACTIONS(5133),
    [anon_sym___managed__] = ACTIONS(5133),
    [anon_sym___grid_constant__] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5354),
    [anon_sym_LT_EQ_GT] = ACTIONS(5354),
    [anon_sym_or] = ACTIONS(5351),
    [anon_sym_and] = ACTIONS(5351),
    [anon_sym_bitor] = ACTIONS(5351),
    [anon_sym_xor] = ACTIONS(5351),
    [anon_sym_bitand] = ACTIONS(5351),
    [anon_sym_not_eq] = ACTIONS(5351),
    [anon_sym_DASH_DASH] = ACTIONS(5354),
    [anon_sym_PLUS_PLUS] = ACTIONS(5354),
    [anon_sym_DOT] = ACTIONS(5351),
    [anon_sym_DOT_STAR] = ACTIONS(5354),
    [anon_sym_DASH_GT] = ACTIONS(5354),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5354),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5354),
  },
  [STATE(2339)] = {
    [sym_argument_list] = STATE(2778),
    [sym_initializer_list] = STATE(2778),
    [sym_decltype_auto] = STATE(2572),
    [sym_new_declarator] = STATE(2560),
    [sym_identifier] = ACTIONS(6305),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6307),
    [anon_sym_COMMA] = ACTIONS(6307),
    [anon_sym_RPAREN] = ACTIONS(6307),
    [aux_sym_preproc_if_token2] = ACTIONS(6307),
    [aux_sym_preproc_else_token1] = ACTIONS(6307),
    [aux_sym_preproc_elif_token1] = ACTIONS(6305),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6307),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6307),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6305),
    [anon_sym_PLUS] = ACTIONS(6305),
    [anon_sym_STAR] = ACTIONS(6305),
    [anon_sym_SLASH] = ACTIONS(6305),
    [anon_sym_PERCENT] = ACTIONS(6305),
    [anon_sym_PIPE_PIPE] = ACTIONS(6307),
    [anon_sym_AMP_AMP] = ACTIONS(6307),
    [anon_sym_PIPE] = ACTIONS(6305),
    [anon_sym_CARET] = ACTIONS(6305),
    [anon_sym_AMP] = ACTIONS(6305),
    [anon_sym_EQ_EQ] = ACTIONS(6307),
    [anon_sym_BANG_EQ] = ACTIONS(6307),
    [anon_sym_GT] = ACTIONS(6305),
    [anon_sym_GT_EQ] = ACTIONS(6307),
    [anon_sym_LT_EQ] = ACTIONS(6305),
    [anon_sym_LT] = ACTIONS(6305),
    [anon_sym_LT_LT] = ACTIONS(6305),
    [anon_sym_GT_GT] = ACTIONS(6305),
    [anon_sym_SEMI] = ACTIONS(6307),
    [anon_sym___attribute__] = ACTIONS(6305),
    [anon_sym___attribute] = ACTIONS(6305),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(6307),
    [anon_sym_LBRACK] = ACTIONS(6311),
    [anon_sym_RBRACK] = ACTIONS(6307),
    [anon_sym_EQ] = ACTIONS(6305),
    [anon_sym_COLON] = ACTIONS(6307),
    [anon_sym_QMARK] = ACTIONS(6307),
    [anon_sym_STAR_EQ] = ACTIONS(6307),
    [anon_sym_SLASH_EQ] = ACTIONS(6307),
    [anon_sym_PERCENT_EQ] = ACTIONS(6307),
    [anon_sym_PLUS_EQ] = ACTIONS(6307),
    [anon_sym_DASH_EQ] = ACTIONS(6307),
    [anon_sym_LT_LT_EQ] = ACTIONS(6307),
    [anon_sym_GT_GT_EQ] = ACTIONS(6307),
    [anon_sym_AMP_EQ] = ACTIONS(6307),
    [anon_sym_CARET_EQ] = ACTIONS(6307),
    [anon_sym_PIPE_EQ] = ACTIONS(6307),
    [anon_sym_and_eq] = ACTIONS(6305),
    [anon_sym_or_eq] = ACTIONS(6305),
    [anon_sym_xor_eq] = ACTIONS(6305),
    [anon_sym_LT_EQ_GT] = ACTIONS(6307),
    [anon_sym_or] = ACTIONS(6305),
    [anon_sym_and] = ACTIONS(6305),
    [anon_sym_bitor] = ACTIONS(6305),
    [anon_sym_xor] = ACTIONS(6305),
    [anon_sym_bitand] = ACTIONS(6305),
    [anon_sym_not_eq] = ACTIONS(6305),
    [anon_sym_DASH_DASH] = ACTIONS(6307),
    [anon_sym_PLUS_PLUS] = ACTIONS(6307),
    [anon_sym_DOT] = ACTIONS(6305),
    [anon_sym_DOT_STAR] = ACTIONS(6307),
    [anon_sym_DASH_GT] = ACTIONS(6307),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6313),
    [anon_sym_decltype] = ACTIONS(6315),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6307),
  },
  [STATE(2340)] = {
    [sym__declaration_modifiers] = STATE(2256),
    [sym_attribute_specifier] = STATE(2256),
    [sym_attribute_declaration] = STATE(2256),
    [sym_ms_declspec_modifier] = STATE(2256),
    [sym_storage_class_specifier] = STATE(2256),
    [sym_type_qualifier] = STATE(2256),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2256),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2256),
    [sym_identifier] = ACTIONS(5952),
    [anon_sym_LPAREN2] = ACTIONS(5954),
    [anon_sym_TILDE] = ACTIONS(5954),
    [anon_sym_STAR] = ACTIONS(5954),
    [anon_sym_AMP_AMP] = ACTIONS(5954),
    [anon_sym_AMP] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(6317),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5956),
    [anon_sym___host__] = ACTIONS(5956),
    [anon_sym___global__] = ACTIONS(5956),
    [anon_sym___forceinline__] = ACTIONS(5956),
    [anon_sym___noinline__] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5954),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5952),
    [anon_sym___cdecl] = ACTIONS(5952),
    [anon_sym___clrcall] = ACTIONS(5952),
    [anon_sym___stdcall] = ACTIONS(5952),
    [anon_sym___fastcall] = ACTIONS(5952),
    [anon_sym___thiscall] = ACTIONS(5952),
    [anon_sym___vectorcall] = ACTIONS(5952),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5952),
    [anon_sym_operator] = ACTIONS(5952),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2341)] = {
    [sym__declaration_modifiers] = STATE(2256),
    [sym_attribute_specifier] = STATE(2256),
    [sym_attribute_declaration] = STATE(2256),
    [sym_ms_declspec_modifier] = STATE(2256),
    [sym_storage_class_specifier] = STATE(2256),
    [sym_type_qualifier] = STATE(2256),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2256),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2256),
    [sym_identifier] = ACTIONS(5952),
    [anon_sym_LPAREN2] = ACTIONS(5954),
    [anon_sym_TILDE] = ACTIONS(5954),
    [anon_sym_STAR] = ACTIONS(5954),
    [anon_sym_AMP_AMP] = ACTIONS(5954),
    [anon_sym_AMP] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(6319),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5956),
    [anon_sym___host__] = ACTIONS(5956),
    [anon_sym___global__] = ACTIONS(5956),
    [anon_sym___forceinline__] = ACTIONS(5956),
    [anon_sym___noinline__] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5954),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5952),
    [anon_sym___cdecl] = ACTIONS(5952),
    [anon_sym___clrcall] = ACTIONS(5952),
    [anon_sym___stdcall] = ACTIONS(5952),
    [anon_sym___fastcall] = ACTIONS(5952),
    [anon_sym___thiscall] = ACTIONS(5952),
    [anon_sym___vectorcall] = ACTIONS(5952),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5952),
    [anon_sym_operator] = ACTIONS(5952),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2342)] = {
    [sym__declaration_modifiers] = STATE(2256),
    [sym_attribute_specifier] = STATE(2256),
    [sym_attribute_declaration] = STATE(2256),
    [sym_ms_declspec_modifier] = STATE(2256),
    [sym_storage_class_specifier] = STATE(2256),
    [sym_type_qualifier] = STATE(2256),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2256),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2256),
    [sym_identifier] = ACTIONS(5952),
    [anon_sym_LPAREN2] = ACTIONS(5954),
    [anon_sym_TILDE] = ACTIONS(5954),
    [anon_sym_STAR] = ACTIONS(5954),
    [anon_sym_AMP_AMP] = ACTIONS(5954),
    [anon_sym_AMP] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(6321),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5956),
    [anon_sym___host__] = ACTIONS(5956),
    [anon_sym___global__] = ACTIONS(5956),
    [anon_sym___forceinline__] = ACTIONS(5956),
    [anon_sym___noinline__] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5954),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5952),
    [anon_sym___cdecl] = ACTIONS(5952),
    [anon_sym___clrcall] = ACTIONS(5952),
    [anon_sym___stdcall] = ACTIONS(5952),
    [anon_sym___fastcall] = ACTIONS(5952),
    [anon_sym___thiscall] = ACTIONS(5952),
    [anon_sym___vectorcall] = ACTIONS(5952),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5952),
    [anon_sym_operator] = ACTIONS(5952),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2343)] = {
    [sym_argument_list] = STATE(2830),
    [sym_initializer_list] = STATE(2830),
    [sym_decltype_auto] = STATE(2572),
    [sym_new_declarator] = STATE(2615),
    [sym_identifier] = ACTIONS(6323),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6325),
    [anon_sym_COMMA] = ACTIONS(6325),
    [anon_sym_RPAREN] = ACTIONS(6325),
    [aux_sym_preproc_if_token2] = ACTIONS(6325),
    [aux_sym_preproc_else_token1] = ACTIONS(6325),
    [aux_sym_preproc_elif_token1] = ACTIONS(6323),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6325),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6325),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6323),
    [anon_sym_PLUS] = ACTIONS(6323),
    [anon_sym_STAR] = ACTIONS(6323),
    [anon_sym_SLASH] = ACTIONS(6323),
    [anon_sym_PERCENT] = ACTIONS(6323),
    [anon_sym_PIPE_PIPE] = ACTIONS(6325),
    [anon_sym_AMP_AMP] = ACTIONS(6325),
    [anon_sym_PIPE] = ACTIONS(6323),
    [anon_sym_CARET] = ACTIONS(6323),
    [anon_sym_AMP] = ACTIONS(6323),
    [anon_sym_EQ_EQ] = ACTIONS(6325),
    [anon_sym_BANG_EQ] = ACTIONS(6325),
    [anon_sym_GT] = ACTIONS(6323),
    [anon_sym_GT_EQ] = ACTIONS(6325),
    [anon_sym_LT_EQ] = ACTIONS(6323),
    [anon_sym_LT] = ACTIONS(6323),
    [anon_sym_LT_LT] = ACTIONS(6323),
    [anon_sym_GT_GT] = ACTIONS(6323),
    [anon_sym_SEMI] = ACTIONS(6325),
    [anon_sym___attribute__] = ACTIONS(6323),
    [anon_sym___attribute] = ACTIONS(6323),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(6325),
    [anon_sym_LBRACK] = ACTIONS(6311),
    [anon_sym_RBRACK] = ACTIONS(6325),
    [anon_sym_EQ] = ACTIONS(6323),
    [anon_sym_COLON] = ACTIONS(6325),
    [anon_sym_QMARK] = ACTIONS(6325),
    [anon_sym_STAR_EQ] = ACTIONS(6325),
    [anon_sym_SLASH_EQ] = ACTIONS(6325),
    [anon_sym_PERCENT_EQ] = ACTIONS(6325),
    [anon_sym_PLUS_EQ] = ACTIONS(6325),
    [anon_sym_DASH_EQ] = ACTIONS(6325),
    [anon_sym_LT_LT_EQ] = ACTIONS(6325),
    [anon_sym_GT_GT_EQ] = ACTIONS(6325),
    [anon_sym_AMP_EQ] = ACTIONS(6325),
    [anon_sym_CARET_EQ] = ACTIONS(6325),
    [anon_sym_PIPE_EQ] = ACTIONS(6325),
    [anon_sym_and_eq] = ACTIONS(6323),
    [anon_sym_or_eq] = ACTIONS(6323),
    [anon_sym_xor_eq] = ACTIONS(6323),
    [anon_sym_LT_EQ_GT] = ACTIONS(6325),
    [anon_sym_or] = ACTIONS(6323),
    [anon_sym_and] = ACTIONS(6323),
    [anon_sym_bitor] = ACTIONS(6323),
    [anon_sym_xor] = ACTIONS(6323),
    [anon_sym_bitand] = ACTIONS(6323),
    [anon_sym_not_eq] = ACTIONS(6323),
    [anon_sym_DASH_DASH] = ACTIONS(6325),
    [anon_sym_PLUS_PLUS] = ACTIONS(6325),
    [anon_sym_DOT] = ACTIONS(6323),
    [anon_sym_DOT_STAR] = ACTIONS(6325),
    [anon_sym_DASH_GT] = ACTIONS(6325),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6313),
    [anon_sym_decltype] = ACTIONS(6315),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6325),
  },
  [STATE(2344)] = {
    [sym_template_argument_list] = STATE(2363),
    [sym_identifier] = ACTIONS(4512),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4519),
    [anon_sym_COMMA] = ACTIONS(4519),
    [anon_sym_RPAREN] = ACTIONS(4519),
    [aux_sym_preproc_if_token2] = ACTIONS(4519),
    [aux_sym_preproc_else_token1] = ACTIONS(4519),
    [aux_sym_preproc_elif_token1] = ACTIONS(4512),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4519),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4519),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_DASH] = ACTIONS(4512),
    [anon_sym_PLUS] = ACTIONS(4512),
    [anon_sym_STAR] = ACTIONS(4512),
    [anon_sym_SLASH] = ACTIONS(4512),
    [anon_sym_PERCENT] = ACTIONS(4512),
    [anon_sym_PIPE_PIPE] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_PIPE] = ACTIONS(4512),
    [anon_sym_CARET] = ACTIONS(4512),
    [anon_sym_AMP] = ACTIONS(4512),
    [anon_sym_EQ_EQ] = ACTIONS(4519),
    [anon_sym_BANG_EQ] = ACTIONS(4519),
    [anon_sym_GT] = ACTIONS(4512),
    [anon_sym_GT_EQ] = ACTIONS(4519),
    [anon_sym_LT_EQ] = ACTIONS(4512),
    [anon_sym_LT] = ACTIONS(6327),
    [anon_sym_LT_LT] = ACTIONS(4512),
    [anon_sym_GT_GT] = ACTIONS(4512),
    [anon_sym_SEMI] = ACTIONS(4519),
    [anon_sym___attribute__] = ACTIONS(4512),
    [anon_sym___attribute] = ACTIONS(4512),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_RBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [anon_sym_RBRACK] = ACTIONS(4519),
    [anon_sym_EQ] = ACTIONS(4512),
    [anon_sym_COLON] = ACTIONS(4512),
    [anon_sym_QMARK] = ACTIONS(4519),
    [anon_sym_STAR_EQ] = ACTIONS(4519),
    [anon_sym_SLASH_EQ] = ACTIONS(4519),
    [anon_sym_PERCENT_EQ] = ACTIONS(4519),
    [anon_sym_PLUS_EQ] = ACTIONS(4519),
    [anon_sym_DASH_EQ] = ACTIONS(4519),
    [anon_sym_LT_LT_EQ] = ACTIONS(4519),
    [anon_sym_GT_GT_EQ] = ACTIONS(4519),
    [anon_sym_AMP_EQ] = ACTIONS(4519),
    [anon_sym_CARET_EQ] = ACTIONS(4519),
    [anon_sym_PIPE_EQ] = ACTIONS(4519),
    [anon_sym_and_eq] = ACTIONS(4512),
    [anon_sym_or_eq] = ACTIONS(4512),
    [anon_sym_xor_eq] = ACTIONS(4512),
    [anon_sym_LT_EQ_GT] = ACTIONS(4519),
    [anon_sym_or] = ACTIONS(4512),
    [anon_sym_and] = ACTIONS(4512),
    [anon_sym_bitor] = ACTIONS(4512),
    [anon_sym_xor] = ACTIONS(4512),
    [anon_sym_bitand] = ACTIONS(4512),
    [anon_sym_not_eq] = ACTIONS(4512),
    [anon_sym_DASH_DASH] = ACTIONS(4519),
    [anon_sym_PLUS_PLUS] = ACTIONS(4519),
    [anon_sym_DOT] = ACTIONS(4512),
    [anon_sym_DOT_STAR] = ACTIONS(4519),
    [anon_sym_DASH_GT] = ACTIONS(4519),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4512),
    [anon_sym_decltype] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_override] = ACTIONS(4512),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4519),
  },
  [STATE(2345)] = {
    [sym_string_literal] = STATE(1663),
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [anon_sym_L_DQUOTE] = ACTIONS(6290),
    [anon_sym_u_DQUOTE] = ACTIONS(6290),
    [anon_sym_U_DQUOTE] = ACTIONS(6290),
    [anon_sym_u8_DQUOTE] = ACTIONS(6290),
    [anon_sym_DQUOTE] = ACTIONS(6290),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2346)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(2348),
    [sym__declarator] = STATE(7042),
    [sym__abstract_declarator] = STATE(7352),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(2870),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(2996),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6393),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(2870),
    [aux_sym_pointer_declarator_repeat1] = STATE(2348),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_RPAREN] = ACTIONS(6020),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(4199),
    [anon_sym_AMP_AMP] = ACTIONS(4201),
    [anon_sym_AMP] = ACTIONS(4203),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym_COLON_COLON] = ACTIONS(6330),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2347)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2309),
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_TILDE] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5686),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym___cdecl] = ACTIONS(5684),
    [anon_sym___clrcall] = ACTIONS(5684),
    [anon_sym___stdcall] = ACTIONS(5684),
    [anon_sym___fastcall] = ACTIONS(5684),
    [anon_sym___thiscall] = ACTIONS(5684),
    [anon_sym___vectorcall] = ACTIONS(5684),
    [anon_sym_signed] = ACTIONS(6190),
    [anon_sym_unsigned] = ACTIONS(6190),
    [anon_sym_long] = ACTIONS(6190),
    [anon_sym_short] = ACTIONS(6190),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_template] = ACTIONS(5684),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_operator] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2348)] = {
    [sym_ms_based_modifier] = STATE(9004),
    [sym_ms_unaligned_ptr_modifier] = STATE(4239),
    [sym_ms_pointer_modifier] = STATE(3478),
    [sym__declarator] = STATE(7064),
    [sym__abstract_declarator] = STATE(7362),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(2841),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(2996),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6393),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(2841),
    [aux_sym_pointer_declarator_repeat1] = STATE(3478),
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_RPAREN] = ACTIONS(5925),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(4199),
    [anon_sym_AMP_AMP] = ACTIONS(4201),
    [anon_sym_AMP] = ACTIONS(4203),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym_COLON_COLON] = ACTIONS(6330),
    [anon_sym___based] = ACTIONS(51),
    [sym_ms_restrict_modifier] = ACTIONS(3129),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3129),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3129),
    [anon_sym__unaligned] = ACTIONS(3131),
    [anon_sym___unaligned] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2349)] = {
    [sym_string_literal] = STATE(1660),
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [anon_sym_L_DQUOTE] = ACTIONS(6290),
    [anon_sym_u_DQUOTE] = ACTIONS(6290),
    [anon_sym_U_DQUOTE] = ACTIONS(6290),
    [anon_sym_u8_DQUOTE] = ACTIONS(6290),
    [anon_sym_DQUOTE] = ACTIONS(6290),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2350)] = {
    [sym_string_literal] = STATE(1658),
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [anon_sym_L_DQUOTE] = ACTIONS(6290),
    [anon_sym_u_DQUOTE] = ACTIONS(6290),
    [anon_sym_U_DQUOTE] = ACTIONS(6290),
    [anon_sym_u8_DQUOTE] = ACTIONS(6290),
    [anon_sym_DQUOTE] = ACTIONS(6290),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2351)] = {
    [sym_argument_list] = STATE(2798),
    [sym_initializer_list] = STATE(2798),
    [sym_decltype_auto] = STATE(2572),
    [sym_new_declarator] = STATE(2590),
    [sym_identifier] = ACTIONS(6332),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6334),
    [anon_sym_COMMA] = ACTIONS(6334),
    [anon_sym_RPAREN] = ACTIONS(6334),
    [aux_sym_preproc_if_token2] = ACTIONS(6334),
    [aux_sym_preproc_else_token1] = ACTIONS(6334),
    [aux_sym_preproc_elif_token1] = ACTIONS(6332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6334),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6334),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6332),
    [anon_sym_PLUS] = ACTIONS(6332),
    [anon_sym_STAR] = ACTIONS(6332),
    [anon_sym_SLASH] = ACTIONS(6332),
    [anon_sym_PERCENT] = ACTIONS(6332),
    [anon_sym_PIPE_PIPE] = ACTIONS(6334),
    [anon_sym_AMP_AMP] = ACTIONS(6334),
    [anon_sym_PIPE] = ACTIONS(6332),
    [anon_sym_CARET] = ACTIONS(6332),
    [anon_sym_AMP] = ACTIONS(6332),
    [anon_sym_EQ_EQ] = ACTIONS(6334),
    [anon_sym_BANG_EQ] = ACTIONS(6334),
    [anon_sym_GT] = ACTIONS(6332),
    [anon_sym_GT_EQ] = ACTIONS(6334),
    [anon_sym_LT_EQ] = ACTIONS(6332),
    [anon_sym_LT] = ACTIONS(6332),
    [anon_sym_LT_LT] = ACTIONS(6332),
    [anon_sym_GT_GT] = ACTIONS(6332),
    [anon_sym_SEMI] = ACTIONS(6334),
    [anon_sym___attribute__] = ACTIONS(6332),
    [anon_sym___attribute] = ACTIONS(6332),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(6334),
    [anon_sym_LBRACK] = ACTIONS(6311),
    [anon_sym_RBRACK] = ACTIONS(6334),
    [anon_sym_EQ] = ACTIONS(6332),
    [anon_sym_COLON] = ACTIONS(6334),
    [anon_sym_QMARK] = ACTIONS(6334),
    [anon_sym_STAR_EQ] = ACTIONS(6334),
    [anon_sym_SLASH_EQ] = ACTIONS(6334),
    [anon_sym_PERCENT_EQ] = ACTIONS(6334),
    [anon_sym_PLUS_EQ] = ACTIONS(6334),
    [anon_sym_DASH_EQ] = ACTIONS(6334),
    [anon_sym_LT_LT_EQ] = ACTIONS(6334),
    [anon_sym_GT_GT_EQ] = ACTIONS(6334),
    [anon_sym_AMP_EQ] = ACTIONS(6334),
    [anon_sym_CARET_EQ] = ACTIONS(6334),
    [anon_sym_PIPE_EQ] = ACTIONS(6334),
    [anon_sym_and_eq] = ACTIONS(6332),
    [anon_sym_or_eq] = ACTIONS(6332),
    [anon_sym_xor_eq] = ACTIONS(6332),
    [anon_sym_LT_EQ_GT] = ACTIONS(6334),
    [anon_sym_or] = ACTIONS(6332),
    [anon_sym_and] = ACTIONS(6332),
    [anon_sym_bitor] = ACTIONS(6332),
    [anon_sym_xor] = ACTIONS(6332),
    [anon_sym_bitand] = ACTIONS(6332),
    [anon_sym_not_eq] = ACTIONS(6332),
    [anon_sym_DASH_DASH] = ACTIONS(6334),
    [anon_sym_PLUS_PLUS] = ACTIONS(6334),
    [anon_sym_DOT] = ACTIONS(6332),
    [anon_sym_DOT_STAR] = ACTIONS(6334),
    [anon_sym_DASH_GT] = ACTIONS(6334),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6313),
    [anon_sym_decltype] = ACTIONS(6315),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6334),
  },
  [STATE(2352)] = {
    [sym_template_argument_list] = STATE(2363),
    [sym_identifier] = ACTIONS(5669),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4028),
    [anon_sym_COMMA] = ACTIONS(4028),
    [anon_sym_RPAREN] = ACTIONS(4028),
    [aux_sym_preproc_if_token2] = ACTIONS(4028),
    [aux_sym_preproc_else_token1] = ACTIONS(4028),
    [aux_sym_preproc_elif_token1] = ACTIONS(5669),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4028),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4028),
    [anon_sym_LPAREN2] = ACTIONS(4028),
    [anon_sym_DASH] = ACTIONS(5669),
    [anon_sym_PLUS] = ACTIONS(5669),
    [anon_sym_STAR] = ACTIONS(5669),
    [anon_sym_SLASH] = ACTIONS(5669),
    [anon_sym_PERCENT] = ACTIONS(5669),
    [anon_sym_PIPE_PIPE] = ACTIONS(4028),
    [anon_sym_AMP_AMP] = ACTIONS(4028),
    [anon_sym_PIPE] = ACTIONS(5669),
    [anon_sym_CARET] = ACTIONS(5669),
    [anon_sym_AMP] = ACTIONS(5669),
    [anon_sym_EQ_EQ] = ACTIONS(4028),
    [anon_sym_BANG_EQ] = ACTIONS(4028),
    [anon_sym_GT] = ACTIONS(5669),
    [anon_sym_GT_EQ] = ACTIONS(4028),
    [anon_sym_LT_EQ] = ACTIONS(5669),
    [anon_sym_LT] = ACTIONS(6336),
    [anon_sym_LT_LT] = ACTIONS(5669),
    [anon_sym_GT_GT] = ACTIONS(5669),
    [anon_sym_SEMI] = ACTIONS(4028),
    [anon_sym___attribute__] = ACTIONS(5669),
    [anon_sym___attribute] = ACTIONS(5669),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4028),
    [anon_sym_RBRACK] = ACTIONS(4028),
    [anon_sym_EQ] = ACTIONS(5669),
    [anon_sym_COLON] = ACTIONS(5669),
    [anon_sym_QMARK] = ACTIONS(4028),
    [anon_sym_STAR_EQ] = ACTIONS(4028),
    [anon_sym_SLASH_EQ] = ACTIONS(4028),
    [anon_sym_PERCENT_EQ] = ACTIONS(4028),
    [anon_sym_PLUS_EQ] = ACTIONS(4028),
    [anon_sym_DASH_EQ] = ACTIONS(4028),
    [anon_sym_LT_LT_EQ] = ACTIONS(4028),
    [anon_sym_GT_GT_EQ] = ACTIONS(4028),
    [anon_sym_AMP_EQ] = ACTIONS(4028),
    [anon_sym_CARET_EQ] = ACTIONS(4028),
    [anon_sym_PIPE_EQ] = ACTIONS(4028),
    [anon_sym_and_eq] = ACTIONS(5669),
    [anon_sym_or_eq] = ACTIONS(5669),
    [anon_sym_xor_eq] = ACTIONS(5669),
    [anon_sym_LT_EQ_GT] = ACTIONS(4028),
    [anon_sym_or] = ACTIONS(5669),
    [anon_sym_and] = ACTIONS(5669),
    [anon_sym_bitor] = ACTIONS(5669),
    [anon_sym_xor] = ACTIONS(5669),
    [anon_sym_bitand] = ACTIONS(5669),
    [anon_sym_not_eq] = ACTIONS(5669),
    [anon_sym_DASH_DASH] = ACTIONS(4028),
    [anon_sym_PLUS_PLUS] = ACTIONS(4028),
    [anon_sym_DOT] = ACTIONS(5669),
    [anon_sym_DOT_STAR] = ACTIONS(4028),
    [anon_sym_DASH_GT] = ACTIONS(4028),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5669),
    [anon_sym_decltype] = ACTIONS(5669),
    [anon_sym_final] = ACTIONS(5669),
    [anon_sym_override] = ACTIONS(5669),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4028),
  },
  [STATE(2353)] = {
    [sym__declaration_modifiers] = STATE(2256),
    [sym_attribute_specifier] = STATE(2256),
    [sym_attribute_declaration] = STATE(2256),
    [sym_ms_declspec_modifier] = STATE(2256),
    [sym_storage_class_specifier] = STATE(2256),
    [sym_type_qualifier] = STATE(2256),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2256),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2256),
    [sym_identifier] = ACTIONS(5952),
    [anon_sym_LPAREN2] = ACTIONS(5954),
    [anon_sym_TILDE] = ACTIONS(5954),
    [anon_sym_STAR] = ACTIONS(5954),
    [anon_sym_AMP_AMP] = ACTIONS(5954),
    [anon_sym_AMP] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(6338),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5956),
    [anon_sym___host__] = ACTIONS(5956),
    [anon_sym___global__] = ACTIONS(5956),
    [anon_sym___forceinline__] = ACTIONS(5956),
    [anon_sym___noinline__] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5954),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5952),
    [anon_sym___cdecl] = ACTIONS(5952),
    [anon_sym___clrcall] = ACTIONS(5952),
    [anon_sym___stdcall] = ACTIONS(5952),
    [anon_sym___fastcall] = ACTIONS(5952),
    [anon_sym___thiscall] = ACTIONS(5952),
    [anon_sym___vectorcall] = ACTIONS(5952),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5952),
    [anon_sym_operator] = ACTIONS(5952),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2354)] = {
    [sym_type_qualifier] = STATE(2333),
    [sym_alignas_qualifier] = STATE(1719),
    [aux_sym__type_definition_type_repeat1] = STATE(2333),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2470),
    [sym_identifier] = ACTIONS(6340),
    [anon_sym_COMMA] = ACTIONS(5158),
    [anon_sym_RPAREN] = ACTIONS(5158),
    [anon_sym_LPAREN2] = ACTIONS(5158),
    [anon_sym_STAR] = ACTIONS(5158),
    [anon_sym_AMP_AMP] = ACTIONS(5158),
    [anon_sym_AMP] = ACTIONS(5160),
    [anon_sym_SEMI] = ACTIONS(5158),
    [anon_sym___extension__] = ACTIONS(5907),
    [anon_sym___device__] = ACTIONS(5160),
    [anon_sym___host__] = ACTIONS(5160),
    [anon_sym___global__] = ACTIONS(5907),
    [anon_sym___forceinline__] = ACTIONS(5160),
    [anon_sym___noinline__] = ACTIONS(5160),
    [anon_sym_virtual] = ACTIONS(5160),
    [anon_sym_extern] = ACTIONS(5160),
    [anon_sym___attribute__] = ACTIONS(5160),
    [anon_sym___attribute] = ACTIONS(5160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5158),
    [anon_sym___declspec] = ACTIONS(5160),
    [anon_sym_LBRACE] = ACTIONS(5158),
    [anon_sym_signed] = ACTIONS(6342),
    [anon_sym_unsigned] = ACTIONS(6342),
    [anon_sym_long] = ACTIONS(6342),
    [anon_sym_short] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5160),
    [anon_sym_static] = ACTIONS(5160),
    [anon_sym_EQ] = ACTIONS(5158),
    [anon_sym_register] = ACTIONS(5160),
    [anon_sym_inline] = ACTIONS(5160),
    [anon_sym___inline] = ACTIONS(5160),
    [anon_sym___inline__] = ACTIONS(5160),
    [anon_sym___forceinline] = ACTIONS(5160),
    [anon_sym_thread_local] = ACTIONS(5160),
    [anon_sym___thread] = ACTIONS(5160),
    [anon_sym_const] = ACTIONS(5907),
    [anon_sym_constexpr] = ACTIONS(5907),
    [anon_sym_volatile] = ACTIONS(5907),
    [anon_sym_restrict] = ACTIONS(5907),
    [anon_sym___restrict__] = ACTIONS(5907),
    [anon_sym__Atomic] = ACTIONS(5907),
    [anon_sym__Noreturn] = ACTIONS(5907),
    [anon_sym_noreturn] = ACTIONS(5907),
    [anon_sym__Nonnull] = ACTIONS(5907),
    [anon_sym_mutable] = ACTIONS(5907),
    [anon_sym_constinit] = ACTIONS(5907),
    [anon_sym_consteval] = ACTIONS(5907),
    [anon_sym___shared__] = ACTIONS(5907),
    [anon_sym___local__] = ACTIONS(5907),
    [anon_sym___constant__] = ACTIONS(5907),
    [anon_sym___managed__] = ACTIONS(5907),
    [anon_sym___grid_constant__] = ACTIONS(5907),
    [anon_sym_alignas] = ACTIONS(5912),
    [anon_sym__Alignas] = ACTIONS(5912),
    [sym_primitive_type] = ACTIONS(6344),
    [anon_sym_asm] = ACTIONS(5160),
    [anon_sym___asm__] = ACTIONS(5160),
    [anon_sym___asm] = ACTIONS(5160),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5160),
    [anon_sym_decltype] = ACTIONS(5160),
    [anon_sym_final] = ACTIONS(5160),
    [anon_sym_override] = ACTIONS(5160),
    [anon_sym_GT2] = ACTIONS(5158),
    [anon_sym_try] = ACTIONS(5160),
    [anon_sym_requires] = ACTIONS(5160),
    [anon_sym___launch_bounds__] = ACTIONS(5160),
  },
  [STATE(2355)] = {
    [sym_identifier] = ACTIONS(5628),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5630),
    [anon_sym_COMMA] = ACTIONS(5630),
    [anon_sym_RPAREN] = ACTIONS(5630),
    [anon_sym_LPAREN2] = ACTIONS(5630),
    [anon_sym_TILDE] = ACTIONS(5630),
    [anon_sym_STAR] = ACTIONS(5630),
    [anon_sym_AMP_AMP] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5628),
    [anon_sym_SEMI] = ACTIONS(5630),
    [anon_sym___extension__] = ACTIONS(5628),
    [anon_sym___device__] = ACTIONS(5628),
    [anon_sym___host__] = ACTIONS(5628),
    [anon_sym___global__] = ACTIONS(5628),
    [anon_sym___forceinline__] = ACTIONS(5628),
    [anon_sym___noinline__] = ACTIONS(5628),
    [anon_sym_virtual] = ACTIONS(5628),
    [anon_sym_extern] = ACTIONS(5628),
    [anon_sym___attribute__] = ACTIONS(5628),
    [anon_sym___attribute] = ACTIONS(5628),
    [anon_sym_COLON_COLON] = ACTIONS(5630),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5630),
    [anon_sym___declspec] = ACTIONS(5628),
    [anon_sym___based] = ACTIONS(5628),
    [anon_sym___cdecl] = ACTIONS(5628),
    [anon_sym___clrcall] = ACTIONS(5628),
    [anon_sym___stdcall] = ACTIONS(5628),
    [anon_sym___fastcall] = ACTIONS(5628),
    [anon_sym___thiscall] = ACTIONS(5628),
    [anon_sym___vectorcall] = ACTIONS(5628),
    [anon_sym_LBRACE] = ACTIONS(5630),
    [anon_sym_LBRACK] = ACTIONS(5628),
    [anon_sym_static] = ACTIONS(5628),
    [anon_sym_EQ] = ACTIONS(5630),
    [anon_sym_register] = ACTIONS(5628),
    [anon_sym_inline] = ACTIONS(5628),
    [anon_sym___inline] = ACTIONS(5628),
    [anon_sym___inline__] = ACTIONS(5628),
    [anon_sym___forceinline] = ACTIONS(5628),
    [anon_sym_thread_local] = ACTIONS(5628),
    [anon_sym___thread] = ACTIONS(5628),
    [anon_sym_const] = ACTIONS(5628),
    [anon_sym_constexpr] = ACTIONS(5628),
    [anon_sym_volatile] = ACTIONS(5628),
    [anon_sym_restrict] = ACTIONS(5628),
    [anon_sym___restrict__] = ACTIONS(5628),
    [anon_sym__Atomic] = ACTIONS(5628),
    [anon_sym__Noreturn] = ACTIONS(5628),
    [anon_sym_noreturn] = ACTIONS(5628),
    [anon_sym__Nonnull] = ACTIONS(5628),
    [anon_sym_mutable] = ACTIONS(5628),
    [anon_sym_constinit] = ACTIONS(5628),
    [anon_sym_consteval] = ACTIONS(5628),
    [anon_sym___shared__] = ACTIONS(5628),
    [anon_sym___local__] = ACTIONS(5628),
    [anon_sym___constant__] = ACTIONS(5628),
    [anon_sym___managed__] = ACTIONS(5628),
    [anon_sym___grid_constant__] = ACTIONS(5628),
    [anon_sym_alignas] = ACTIONS(5628),
    [anon_sym__Alignas] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(5628),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5628),
    [anon_sym_decltype] = ACTIONS(5628),
    [anon_sym_final] = ACTIONS(5628),
    [anon_sym_override] = ACTIONS(5628),
    [anon_sym_explicit] = ACTIONS(5628),
    [anon_sym_template] = ACTIONS(5628),
    [anon_sym_GT2] = ACTIONS(5630),
    [anon_sym_operator] = ACTIONS(5628),
    [anon_sym___launch_bounds__] = ACTIONS(5628),
  },
  [STATE(2356)] = {
    [sym__declaration_modifiers] = STATE(2256),
    [sym_attribute_specifier] = STATE(2256),
    [sym_attribute_declaration] = STATE(2256),
    [sym_ms_declspec_modifier] = STATE(2256),
    [sym_storage_class_specifier] = STATE(2256),
    [sym_type_qualifier] = STATE(2256),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_decltype_auto] = STATE(2255),
    [sym_launch_bounds] = STATE(2256),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2256),
    [sym_identifier] = ACTIONS(5952),
    [anon_sym_LPAREN2] = ACTIONS(5954),
    [anon_sym_TILDE] = ACTIONS(5954),
    [anon_sym_STAR] = ACTIONS(5954),
    [anon_sym_AMP_AMP] = ACTIONS(5954),
    [anon_sym_AMP] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(6346),
    [anon_sym___extension__] = ACTIONS(5485),
    [anon_sym___device__] = ACTIONS(5956),
    [anon_sym___host__] = ACTIONS(5956),
    [anon_sym___global__] = ACTIONS(5956),
    [anon_sym___forceinline__] = ACTIONS(5956),
    [anon_sym___noinline__] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5954),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5495),
    [anon_sym___declspec] = ACTIONS(5497),
    [anon_sym___based] = ACTIONS(5952),
    [anon_sym___cdecl] = ACTIONS(5952),
    [anon_sym___clrcall] = ACTIONS(5952),
    [anon_sym___stdcall] = ACTIONS(5952),
    [anon_sym___fastcall] = ACTIONS(5952),
    [anon_sym___thiscall] = ACTIONS(5952),
    [anon_sym___vectorcall] = ACTIONS(5952),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_static] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5489),
    [anon_sym_inline] = ACTIONS(5489),
    [anon_sym___inline] = ACTIONS(5489),
    [anon_sym___inline__] = ACTIONS(5489),
    [anon_sym___forceinline] = ACTIONS(5489),
    [anon_sym_thread_local] = ACTIONS(5489),
    [anon_sym___thread] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5485),
    [anon_sym_constexpr] = ACTIONS(5485),
    [anon_sym_volatile] = ACTIONS(5485),
    [anon_sym_restrict] = ACTIONS(5485),
    [anon_sym___restrict__] = ACTIONS(5485),
    [anon_sym__Atomic] = ACTIONS(5485),
    [anon_sym__Noreturn] = ACTIONS(5485),
    [anon_sym_noreturn] = ACTIONS(5485),
    [anon_sym__Nonnull] = ACTIONS(5485),
    [anon_sym_mutable] = ACTIONS(5485),
    [anon_sym_constinit] = ACTIONS(5485),
    [anon_sym_consteval] = ACTIONS(5485),
    [anon_sym___shared__] = ACTIONS(5485),
    [anon_sym___local__] = ACTIONS(5485),
    [anon_sym___constant__] = ACTIONS(5485),
    [anon_sym___managed__] = ACTIONS(5485),
    [anon_sym___grid_constant__] = ACTIONS(5485),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5958),
    [anon_sym_decltype] = ACTIONS(5960),
    [anon_sym_template] = ACTIONS(5952),
    [anon_sym_operator] = ACTIONS(5952),
    [anon_sym___launch_bounds__] = ACTIONS(5501),
  },
  [STATE(2357)] = {
    [sym_argument_list] = STATE(2804),
    [sym_initializer_list] = STATE(2804),
    [sym_decltype_auto] = STATE(2572),
    [sym_new_declarator] = STATE(2583),
    [sym_identifier] = ACTIONS(6348),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6350),
    [anon_sym_COMMA] = ACTIONS(6350),
    [anon_sym_RPAREN] = ACTIONS(6350),
    [aux_sym_preproc_if_token2] = ACTIONS(6350),
    [aux_sym_preproc_else_token1] = ACTIONS(6350),
    [aux_sym_preproc_elif_token1] = ACTIONS(6348),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6350),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6350),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6348),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_STAR] = ACTIONS(6348),
    [anon_sym_SLASH] = ACTIONS(6348),
    [anon_sym_PERCENT] = ACTIONS(6348),
    [anon_sym_PIPE_PIPE] = ACTIONS(6350),
    [anon_sym_AMP_AMP] = ACTIONS(6350),
    [anon_sym_PIPE] = ACTIONS(6348),
    [anon_sym_CARET] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_EQ_EQ] = ACTIONS(6350),
    [anon_sym_BANG_EQ] = ACTIONS(6350),
    [anon_sym_GT] = ACTIONS(6348),
    [anon_sym_GT_EQ] = ACTIONS(6350),
    [anon_sym_LT_EQ] = ACTIONS(6348),
    [anon_sym_LT] = ACTIONS(6348),
    [anon_sym_LT_LT] = ACTIONS(6348),
    [anon_sym_GT_GT] = ACTIONS(6348),
    [anon_sym_SEMI] = ACTIONS(6350),
    [anon_sym___attribute__] = ACTIONS(6348),
    [anon_sym___attribute] = ACTIONS(6348),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(6350),
    [anon_sym_LBRACK] = ACTIONS(6311),
    [anon_sym_RBRACK] = ACTIONS(6350),
    [anon_sym_EQ] = ACTIONS(6348),
    [anon_sym_COLON] = ACTIONS(6350),
    [anon_sym_QMARK] = ACTIONS(6350),
    [anon_sym_STAR_EQ] = ACTIONS(6350),
    [anon_sym_SLASH_EQ] = ACTIONS(6350),
    [anon_sym_PERCENT_EQ] = ACTIONS(6350),
    [anon_sym_PLUS_EQ] = ACTIONS(6350),
    [anon_sym_DASH_EQ] = ACTIONS(6350),
    [anon_sym_LT_LT_EQ] = ACTIONS(6350),
    [anon_sym_GT_GT_EQ] = ACTIONS(6350),
    [anon_sym_AMP_EQ] = ACTIONS(6350),
    [anon_sym_CARET_EQ] = ACTIONS(6350),
    [anon_sym_PIPE_EQ] = ACTIONS(6350),
    [anon_sym_and_eq] = ACTIONS(6348),
    [anon_sym_or_eq] = ACTIONS(6348),
    [anon_sym_xor_eq] = ACTIONS(6348),
    [anon_sym_LT_EQ_GT] = ACTIONS(6350),
    [anon_sym_or] = ACTIONS(6348),
    [anon_sym_and] = ACTIONS(6348),
    [anon_sym_bitor] = ACTIONS(6348),
    [anon_sym_xor] = ACTIONS(6348),
    [anon_sym_bitand] = ACTIONS(6348),
    [anon_sym_not_eq] = ACTIONS(6348),
    [anon_sym_DASH_DASH] = ACTIONS(6350),
    [anon_sym_PLUS_PLUS] = ACTIONS(6350),
    [anon_sym_DOT] = ACTIONS(6348),
    [anon_sym_DOT_STAR] = ACTIONS(6350),
    [anon_sym_DASH_GT] = ACTIONS(6350),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6313),
    [anon_sym_decltype] = ACTIONS(6315),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6350),
  },
  [STATE(2358)] = {
    [sym_string_literal] = STATE(2204),
    [sym_raw_string_literal] = STATE(2204),
    [sym_identifier] = ACTIONS(6352),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6354),
    [anon_sym_COMMA] = ACTIONS(6354),
    [aux_sym_preproc_if_token2] = ACTIONS(6354),
    [aux_sym_preproc_else_token1] = ACTIONS(6354),
    [aux_sym_preproc_elif_token1] = ACTIONS(6352),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6354),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6354),
    [anon_sym_LPAREN2] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6352),
    [anon_sym_STAR] = ACTIONS(6352),
    [anon_sym_SLASH] = ACTIONS(6352),
    [anon_sym_PERCENT] = ACTIONS(6352),
    [anon_sym_PIPE_PIPE] = ACTIONS(6354),
    [anon_sym_AMP_AMP] = ACTIONS(6354),
    [anon_sym_PIPE] = ACTIONS(6352),
    [anon_sym_CARET] = ACTIONS(6352),
    [anon_sym_AMP] = ACTIONS(6352),
    [anon_sym_EQ_EQ] = ACTIONS(6354),
    [anon_sym_BANG_EQ] = ACTIONS(6354),
    [anon_sym_GT] = ACTIONS(6352),
    [anon_sym_GT_EQ] = ACTIONS(6354),
    [anon_sym_LT_EQ] = ACTIONS(6352),
    [anon_sym_LT] = ACTIONS(6352),
    [anon_sym_LT_LT] = ACTIONS(6352),
    [anon_sym_GT_GT] = ACTIONS(6352),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [anon_sym_EQ] = ACTIONS(6352),
    [anon_sym_QMARK] = ACTIONS(6354),
    [anon_sym_STAR_EQ] = ACTIONS(6354),
    [anon_sym_SLASH_EQ] = ACTIONS(6354),
    [anon_sym_PERCENT_EQ] = ACTIONS(6354),
    [anon_sym_PLUS_EQ] = ACTIONS(6354),
    [anon_sym_DASH_EQ] = ACTIONS(6354),
    [anon_sym_LT_LT_EQ] = ACTIONS(6354),
    [anon_sym_GT_GT_EQ] = ACTIONS(6354),
    [anon_sym_AMP_EQ] = ACTIONS(6354),
    [anon_sym_CARET_EQ] = ACTIONS(6354),
    [anon_sym_PIPE_EQ] = ACTIONS(6354),
    [anon_sym_and_eq] = ACTIONS(6352),
    [anon_sym_or_eq] = ACTIONS(6352),
    [anon_sym_xor_eq] = ACTIONS(6352),
    [anon_sym_LT_EQ_GT] = ACTIONS(6354),
    [anon_sym_or] = ACTIONS(6352),
    [anon_sym_and] = ACTIONS(6352),
    [anon_sym_bitor] = ACTIONS(6352),
    [anon_sym_xor] = ACTIONS(6352),
    [anon_sym_bitand] = ACTIONS(6352),
    [anon_sym_not_eq] = ACTIONS(6352),
    [anon_sym_DASH_DASH] = ACTIONS(6354),
    [anon_sym_PLUS_PLUS] = ACTIONS(6354),
    [anon_sym_DOT] = ACTIONS(6352),
    [anon_sym_DOT_STAR] = ACTIONS(6354),
    [anon_sym_DASH_GT] = ACTIONS(6354),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [sym_literal_suffix] = ACTIONS(6352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6354),
  },
  [STATE(2359)] = {
    [sym_identifier] = ACTIONS(5688),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5690),
    [anon_sym_COMMA] = ACTIONS(5690),
    [anon_sym_RPAREN] = ACTIONS(5690),
    [aux_sym_preproc_if_token2] = ACTIONS(5690),
    [aux_sym_preproc_else_token1] = ACTIONS(5690),
    [aux_sym_preproc_elif_token1] = ACTIONS(5688),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5690),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5690),
    [anon_sym_LPAREN2] = ACTIONS(5690),
    [anon_sym_DASH] = ACTIONS(5688),
    [anon_sym_PLUS] = ACTIONS(5688),
    [anon_sym_STAR] = ACTIONS(5688),
    [anon_sym_SLASH] = ACTIONS(5688),
    [anon_sym_PERCENT] = ACTIONS(5688),
    [anon_sym_PIPE_PIPE] = ACTIONS(5690),
    [anon_sym_AMP_AMP] = ACTIONS(5690),
    [anon_sym_PIPE] = ACTIONS(5688),
    [anon_sym_CARET] = ACTIONS(5688),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_EQ_EQ] = ACTIONS(5690),
    [anon_sym_BANG_EQ] = ACTIONS(5690),
    [anon_sym_GT] = ACTIONS(5688),
    [anon_sym_GT_EQ] = ACTIONS(5690),
    [anon_sym_LT_EQ] = ACTIONS(5688),
    [anon_sym_LT] = ACTIONS(5688),
    [anon_sym_LT_LT] = ACTIONS(5688),
    [anon_sym_GT_GT] = ACTIONS(5688),
    [anon_sym_SEMI] = ACTIONS(5690),
    [anon_sym___attribute__] = ACTIONS(5688),
    [anon_sym___attribute] = ACTIONS(5688),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACE] = ACTIONS(5690),
    [anon_sym_RBRACE] = ACTIONS(5690),
    [anon_sym_LBRACK] = ACTIONS(5690),
    [anon_sym_RBRACK] = ACTIONS(5690),
    [anon_sym_EQ] = ACTIONS(5688),
    [anon_sym_COLON] = ACTIONS(5688),
    [anon_sym_QMARK] = ACTIONS(5690),
    [anon_sym_STAR_EQ] = ACTIONS(5690),
    [anon_sym_SLASH_EQ] = ACTIONS(5690),
    [anon_sym_PERCENT_EQ] = ACTIONS(5690),
    [anon_sym_PLUS_EQ] = ACTIONS(5690),
    [anon_sym_DASH_EQ] = ACTIONS(5690),
    [anon_sym_LT_LT_EQ] = ACTIONS(5690),
    [anon_sym_GT_GT_EQ] = ACTIONS(5690),
    [anon_sym_AMP_EQ] = ACTIONS(5690),
    [anon_sym_CARET_EQ] = ACTIONS(5690),
    [anon_sym_PIPE_EQ] = ACTIONS(5690),
    [anon_sym_and_eq] = ACTIONS(5688),
    [anon_sym_or_eq] = ACTIONS(5688),
    [anon_sym_xor_eq] = ACTIONS(5688),
    [anon_sym_LT_EQ_GT] = ACTIONS(5690),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_and] = ACTIONS(5688),
    [anon_sym_bitor] = ACTIONS(5688),
    [anon_sym_xor] = ACTIONS(5688),
    [anon_sym_bitand] = ACTIONS(5688),
    [anon_sym_not_eq] = ACTIONS(5688),
    [anon_sym_DASH_DASH] = ACTIONS(5690),
    [anon_sym_PLUS_PLUS] = ACTIONS(5690),
    [anon_sym_DOT] = ACTIONS(5688),
    [anon_sym_DOT_STAR] = ACTIONS(5690),
    [anon_sym_DASH_GT] = ACTIONS(5690),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5688),
    [anon_sym_decltype] = ACTIONS(5688),
    [anon_sym_final] = ACTIONS(5688),
    [anon_sym_override] = ACTIONS(5688),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5690),
  },
  [STATE(2360)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4560),
    [anon_sym_COMMA] = ACTIONS(4560),
    [anon_sym_RPAREN] = ACTIONS(4560),
    [anon_sym_LPAREN2] = ACTIONS(4560),
    [anon_sym_TILDE] = ACTIONS(4560),
    [anon_sym_STAR] = ACTIONS(4560),
    [anon_sym_AMP_AMP] = ACTIONS(4560),
    [anon_sym_AMP] = ACTIONS(4553),
    [anon_sym_SEMI] = ACTIONS(4560),
    [anon_sym___extension__] = ACTIONS(4553),
    [anon_sym___device__] = ACTIONS(4553),
    [anon_sym___host__] = ACTIONS(4553),
    [anon_sym___global__] = ACTIONS(4553),
    [anon_sym___forceinline__] = ACTIONS(4553),
    [anon_sym___noinline__] = ACTIONS(4553),
    [anon_sym_virtual] = ACTIONS(4553),
    [anon_sym_extern] = ACTIONS(4553),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4560),
    [anon_sym___declspec] = ACTIONS(4553),
    [anon_sym___based] = ACTIONS(4553),
    [anon_sym___cdecl] = ACTIONS(4553),
    [anon_sym___clrcall] = ACTIONS(4553),
    [anon_sym___stdcall] = ACTIONS(4553),
    [anon_sym___fastcall] = ACTIONS(4553),
    [anon_sym___thiscall] = ACTIONS(4553),
    [anon_sym___vectorcall] = ACTIONS(4553),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4553),
    [anon_sym_static] = ACTIONS(4553),
    [anon_sym_EQ] = ACTIONS(4560),
    [anon_sym_register] = ACTIONS(4553),
    [anon_sym_inline] = ACTIONS(4553),
    [anon_sym___inline] = ACTIONS(4553),
    [anon_sym___inline__] = ACTIONS(4553),
    [anon_sym___forceinline] = ACTIONS(4553),
    [anon_sym_thread_local] = ACTIONS(4553),
    [anon_sym___thread] = ACTIONS(4553),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4553),
    [anon_sym_volatile] = ACTIONS(4553),
    [anon_sym_restrict] = ACTIONS(4553),
    [anon_sym___restrict__] = ACTIONS(4553),
    [anon_sym__Atomic] = ACTIONS(4553),
    [anon_sym__Noreturn] = ACTIONS(4553),
    [anon_sym_noreturn] = ACTIONS(4553),
    [anon_sym__Nonnull] = ACTIONS(4553),
    [anon_sym_mutable] = ACTIONS(4553),
    [anon_sym_constinit] = ACTIONS(4553),
    [anon_sym_consteval] = ACTIONS(4553),
    [anon_sym___shared__] = ACTIONS(4553),
    [anon_sym___local__] = ACTIONS(4553),
    [anon_sym___constant__] = ACTIONS(4553),
    [anon_sym___managed__] = ACTIONS(4553),
    [anon_sym___grid_constant__] = ACTIONS(4553),
    [anon_sym_alignas] = ACTIONS(4553),
    [anon_sym__Alignas] = ACTIONS(4553),
    [anon_sym_COLON] = ACTIONS(4553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_final] = ACTIONS(4553),
    [anon_sym_override] = ACTIONS(4553),
    [anon_sym_template] = ACTIONS(4553),
    [anon_sym_GT2] = ACTIONS(4560),
    [anon_sym_operator] = ACTIONS(4553),
    [anon_sym___launch_bounds__] = ACTIONS(4553),
  },
  [STATE(2361)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_DASH] = ACTIONS(5143),
    [anon_sym_PLUS] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5145),
    [anon_sym_SLASH] = ACTIONS(5143),
    [anon_sym_PERCENT] = ACTIONS(5145),
    [anon_sym_PIPE_PIPE] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_PIPE] = ACTIONS(5143),
    [anon_sym_CARET] = ACTIONS(5145),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_GT] = ACTIONS(5143),
    [anon_sym_GT_EQ] = ACTIONS(5145),
    [anon_sym_LT_EQ] = ACTIONS(5143),
    [anon_sym_LT] = ACTIONS(5143),
    [anon_sym_LT_LT] = ACTIONS(5143),
    [anon_sym_GT_GT] = ACTIONS(5143),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5143),
    [anon_sym_unsigned] = ACTIONS(5143),
    [anon_sym_long] = ACTIONS(5143),
    [anon_sym_short] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [sym_primitive_type] = ACTIONS(5143),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_LT_EQ_GT] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5143),
    [anon_sym_and] = ACTIONS(5143),
    [anon_sym_bitor] = ACTIONS(5143),
    [anon_sym_xor] = ACTIONS(5143),
    [anon_sym_bitand] = ACTIONS(5143),
    [anon_sym_not_eq] = ACTIONS(5143),
    [anon_sym_DASH_DASH] = ACTIONS(5145),
    [anon_sym_PLUS_PLUS] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5143),
    [anon_sym_DOT_STAR] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5143),
    [anon_sym_decltype] = ACTIONS(5143),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5145),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5145),
  },
  [STATE(2362)] = {
    [sym_identifier] = ACTIONS(5143),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_RPAREN] = ACTIONS(5145),
    [anon_sym_LPAREN2] = ACTIONS(5145),
    [anon_sym_TILDE] = ACTIONS(5145),
    [anon_sym_STAR] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5145),
    [anon_sym_AMP] = ACTIONS(5143),
    [anon_sym_SEMI] = ACTIONS(5145),
    [anon_sym___extension__] = ACTIONS(5143),
    [anon_sym___device__] = ACTIONS(5143),
    [anon_sym___host__] = ACTIONS(5143),
    [anon_sym___global__] = ACTIONS(5143),
    [anon_sym___forceinline__] = ACTIONS(5143),
    [anon_sym___noinline__] = ACTIONS(5143),
    [anon_sym_virtual] = ACTIONS(5143),
    [anon_sym_extern] = ACTIONS(5143),
    [anon_sym___attribute__] = ACTIONS(5143),
    [anon_sym___attribute] = ACTIONS(5143),
    [anon_sym_COLON_COLON] = ACTIONS(5145),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5145),
    [anon_sym___declspec] = ACTIONS(5143),
    [anon_sym___based] = ACTIONS(5143),
    [anon_sym___cdecl] = ACTIONS(5143),
    [anon_sym___clrcall] = ACTIONS(5143),
    [anon_sym___stdcall] = ACTIONS(5143),
    [anon_sym___fastcall] = ACTIONS(5143),
    [anon_sym___thiscall] = ACTIONS(5143),
    [anon_sym___vectorcall] = ACTIONS(5143),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_LBRACK] = ACTIONS(5143),
    [anon_sym_static] = ACTIONS(5143),
    [anon_sym_EQ] = ACTIONS(5145),
    [anon_sym_register] = ACTIONS(5143),
    [anon_sym_inline] = ACTIONS(5143),
    [anon_sym___inline] = ACTIONS(5143),
    [anon_sym___inline__] = ACTIONS(5143),
    [anon_sym___forceinline] = ACTIONS(5143),
    [anon_sym_thread_local] = ACTIONS(5143),
    [anon_sym___thread] = ACTIONS(5143),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_constexpr] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_restrict] = ACTIONS(5143),
    [anon_sym___restrict__] = ACTIONS(5143),
    [anon_sym__Atomic] = ACTIONS(5143),
    [anon_sym__Noreturn] = ACTIONS(5143),
    [anon_sym_noreturn] = ACTIONS(5143),
    [anon_sym__Nonnull] = ACTIONS(5143),
    [anon_sym_mutable] = ACTIONS(5143),
    [anon_sym_constinit] = ACTIONS(5143),
    [anon_sym_consteval] = ACTIONS(5143),
    [anon_sym___shared__] = ACTIONS(5143),
    [anon_sym___local__] = ACTIONS(5143),
    [anon_sym___constant__] = ACTIONS(5143),
    [anon_sym___managed__] = ACTIONS(5143),
    [anon_sym___grid_constant__] = ACTIONS(5143),
    [anon_sym_alignas] = ACTIONS(5143),
    [anon_sym__Alignas] = ACTIONS(5143),
    [anon_sym_COLON] = ACTIONS(5143),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5143),
    [anon_sym_final] = ACTIONS(5143),
    [anon_sym_override] = ACTIONS(5143),
    [anon_sym_explicit] = ACTIONS(5143),
    [anon_sym_template] = ACTIONS(5143),
    [anon_sym_GT2] = ACTIONS(5145),
    [anon_sym_operator] = ACTIONS(5143),
    [anon_sym___launch_bounds__] = ACTIONS(5143),
  },
  [STATE(2363)] = {
    [sym_identifier] = ACTIONS(4553),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4560),
    [anon_sym_COMMA] = ACTIONS(4560),
    [anon_sym_RPAREN] = ACTIONS(4560),
    [aux_sym_preproc_if_token2] = ACTIONS(4560),
    [aux_sym_preproc_else_token1] = ACTIONS(4560),
    [aux_sym_preproc_elif_token1] = ACTIONS(4553),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4560),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4560),
    [anon_sym_LPAREN2] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4553),
    [anon_sym_PLUS] = ACTIONS(4553),
    [anon_sym_STAR] = ACTIONS(4553),
    [anon_sym_SLASH] = ACTIONS(4553),
    [anon_sym_PERCENT] = ACTIONS(4553),
    [anon_sym_PIPE_PIPE] = ACTIONS(4560),
    [anon_sym_AMP_AMP] = ACTIONS(4560),
    [anon_sym_PIPE] = ACTIONS(4553),
    [anon_sym_CARET] = ACTIONS(4553),
    [anon_sym_AMP] = ACTIONS(4553),
    [anon_sym_EQ_EQ] = ACTIONS(4560),
    [anon_sym_BANG_EQ] = ACTIONS(4560),
    [anon_sym_GT] = ACTIONS(4553),
    [anon_sym_GT_EQ] = ACTIONS(4560),
    [anon_sym_LT_EQ] = ACTIONS(4553),
    [anon_sym_LT] = ACTIONS(4553),
    [anon_sym_LT_LT] = ACTIONS(4553),
    [anon_sym_GT_GT] = ACTIONS(4553),
    [anon_sym_SEMI] = ACTIONS(4560),
    [anon_sym___attribute__] = ACTIONS(4553),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_RBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4560),
    [anon_sym_RBRACK] = ACTIONS(4560),
    [anon_sym_EQ] = ACTIONS(4553),
    [anon_sym_COLON] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4560),
    [anon_sym_STAR_EQ] = ACTIONS(4560),
    [anon_sym_SLASH_EQ] = ACTIONS(4560),
    [anon_sym_PERCENT_EQ] = ACTIONS(4560),
    [anon_sym_PLUS_EQ] = ACTIONS(4560),
    [anon_sym_DASH_EQ] = ACTIONS(4560),
    [anon_sym_LT_LT_EQ] = ACTIONS(4560),
    [anon_sym_GT_GT_EQ] = ACTIONS(4560),
    [anon_sym_AMP_EQ] = ACTIONS(4560),
    [anon_sym_CARET_EQ] = ACTIONS(4560),
    [anon_sym_PIPE_EQ] = ACTIONS(4560),
    [anon_sym_and_eq] = ACTIONS(4553),
    [anon_sym_or_eq] = ACTIONS(4553),
    [anon_sym_xor_eq] = ACTIONS(4553),
    [anon_sym_LT_EQ_GT] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4553),
    [anon_sym_and] = ACTIONS(4553),
    [anon_sym_bitor] = ACTIONS(4553),
    [anon_sym_xor] = ACTIONS(4553),
    [anon_sym_bitand] = ACTIONS(4553),
    [anon_sym_not_eq] = ACTIONS(4553),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_DOT] = ACTIONS(4553),
    [anon_sym_DOT_STAR] = ACTIONS(4560),
    [anon_sym_DASH_GT] = ACTIONS(4560),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4553),
    [anon_sym_decltype] = ACTIONS(4553),
    [anon_sym_final] = ACTIONS(4553),
    [anon_sym_override] = ACTIONS(4553),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4560),
  },
  [STATE(2364)] = {
    [sym_identifier] = ACTIONS(5665),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5667),
    [anon_sym_COMMA] = ACTIONS(5667),
    [anon_sym_RPAREN] = ACTIONS(5667),
    [aux_sym_preproc_if_token2] = ACTIONS(5667),
    [aux_sym_preproc_else_token1] = ACTIONS(5667),
    [aux_sym_preproc_elif_token1] = ACTIONS(5665),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5667),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5667),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5665),
    [anon_sym_PLUS] = ACTIONS(5665),
    [anon_sym_STAR] = ACTIONS(5665),
    [anon_sym_SLASH] = ACTIONS(5665),
    [anon_sym_PERCENT] = ACTIONS(5665),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_PIPE] = ACTIONS(5665),
    [anon_sym_CARET] = ACTIONS(5665),
    [anon_sym_AMP] = ACTIONS(5665),
    [anon_sym_EQ_EQ] = ACTIONS(5667),
    [anon_sym_BANG_EQ] = ACTIONS(5667),
    [anon_sym_GT] = ACTIONS(5665),
    [anon_sym_GT_EQ] = ACTIONS(5667),
    [anon_sym_LT_EQ] = ACTIONS(5665),
    [anon_sym_LT] = ACTIONS(5665),
    [anon_sym_LT_LT] = ACTIONS(5665),
    [anon_sym_GT_GT] = ACTIONS(5665),
    [anon_sym_SEMI] = ACTIONS(5667),
    [anon_sym___attribute__] = ACTIONS(5665),
    [anon_sym___attribute] = ACTIONS(5665),
    [anon_sym_COLON_COLON] = ACTIONS(5667),
    [anon_sym_LBRACE] = ACTIONS(5667),
    [anon_sym_RBRACE] = ACTIONS(5667),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [anon_sym_RBRACK] = ACTIONS(5667),
    [anon_sym_EQ] = ACTIONS(5665),
    [anon_sym_COLON] = ACTIONS(5665),
    [anon_sym_QMARK] = ACTIONS(5667),
    [anon_sym_STAR_EQ] = ACTIONS(5667),
    [anon_sym_SLASH_EQ] = ACTIONS(5667),
    [anon_sym_PERCENT_EQ] = ACTIONS(5667),
    [anon_sym_PLUS_EQ] = ACTIONS(5667),
    [anon_sym_DASH_EQ] = ACTIONS(5667),
    [anon_sym_LT_LT_EQ] = ACTIONS(5667),
    [anon_sym_GT_GT_EQ] = ACTIONS(5667),
    [anon_sym_AMP_EQ] = ACTIONS(5667),
    [anon_sym_CARET_EQ] = ACTIONS(5667),
    [anon_sym_PIPE_EQ] = ACTIONS(5667),
    [anon_sym_and_eq] = ACTIONS(5665),
    [anon_sym_or_eq] = ACTIONS(5665),
    [anon_sym_xor_eq] = ACTIONS(5665),
    [anon_sym_LT_EQ_GT] = ACTIONS(5667),
    [anon_sym_or] = ACTIONS(5665),
    [anon_sym_and] = ACTIONS(5665),
    [anon_sym_bitor] = ACTIONS(5665),
    [anon_sym_xor] = ACTIONS(5665),
    [anon_sym_bitand] = ACTIONS(5665),
    [anon_sym_not_eq] = ACTIONS(5665),
    [anon_sym_DASH_DASH] = ACTIONS(5667),
    [anon_sym_PLUS_PLUS] = ACTIONS(5667),
    [anon_sym_DOT] = ACTIONS(5665),
    [anon_sym_DOT_STAR] = ACTIONS(5667),
    [anon_sym_DASH_GT] = ACTIONS(5667),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5665),
    [anon_sym_decltype] = ACTIONS(5665),
    [anon_sym_final] = ACTIONS(5665),
    [anon_sym_override] = ACTIONS(5665),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5667),
  },
  [STATE(2365)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [aux_sym_preproc_if_token2] = ACTIONS(5661),
    [aux_sym_preproc_else_token1] = ACTIONS(5661),
    [aux_sym_preproc_elif_token1] = ACTIONS(5659),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5661),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5659),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5659),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5659),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5659),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_RBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_RBRACK] = ACTIONS(5661),
    [anon_sym_EQ] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_STAR_EQ] = ACTIONS(5661),
    [anon_sym_SLASH_EQ] = ACTIONS(5661),
    [anon_sym_PERCENT_EQ] = ACTIONS(5661),
    [anon_sym_PLUS_EQ] = ACTIONS(5661),
    [anon_sym_DASH_EQ] = ACTIONS(5661),
    [anon_sym_LT_LT_EQ] = ACTIONS(5661),
    [anon_sym_GT_GT_EQ] = ACTIONS(5661),
    [anon_sym_AMP_EQ] = ACTIONS(5661),
    [anon_sym_CARET_EQ] = ACTIONS(5661),
    [anon_sym_PIPE_EQ] = ACTIONS(5661),
    [anon_sym_and_eq] = ACTIONS(5659),
    [anon_sym_or_eq] = ACTIONS(5659),
    [anon_sym_xor_eq] = ACTIONS(5659),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_bitor] = ACTIONS(5659),
    [anon_sym_xor] = ACTIONS(5659),
    [anon_sym_bitand] = ACTIONS(5659),
    [anon_sym_not_eq] = ACTIONS(5659),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(2366)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [aux_sym_preproc_if_token2] = ACTIONS(5661),
    [aux_sym_preproc_else_token1] = ACTIONS(5661),
    [aux_sym_preproc_elif_token1] = ACTIONS(5659),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5661),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5659),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5659),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5659),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5659),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_RBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_RBRACK] = ACTIONS(5661),
    [anon_sym_EQ] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_STAR_EQ] = ACTIONS(5661),
    [anon_sym_SLASH_EQ] = ACTIONS(5661),
    [anon_sym_PERCENT_EQ] = ACTIONS(5661),
    [anon_sym_PLUS_EQ] = ACTIONS(5661),
    [anon_sym_DASH_EQ] = ACTIONS(5661),
    [anon_sym_LT_LT_EQ] = ACTIONS(5661),
    [anon_sym_GT_GT_EQ] = ACTIONS(5661),
    [anon_sym_AMP_EQ] = ACTIONS(5661),
    [anon_sym_CARET_EQ] = ACTIONS(5661),
    [anon_sym_PIPE_EQ] = ACTIONS(5661),
    [anon_sym_and_eq] = ACTIONS(5659),
    [anon_sym_or_eq] = ACTIONS(5659),
    [anon_sym_xor_eq] = ACTIONS(5659),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_bitor] = ACTIONS(5659),
    [anon_sym_xor] = ACTIONS(5659),
    [anon_sym_bitand] = ACTIONS(5659),
    [anon_sym_not_eq] = ACTIONS(5659),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(2367)] = {
    [sym_identifier] = ACTIONS(6356),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6358),
    [anon_sym_COMMA] = ACTIONS(6358),
    [anon_sym_RPAREN] = ACTIONS(6358),
    [anon_sym_LPAREN2] = ACTIONS(6358),
    [anon_sym_TILDE] = ACTIONS(6358),
    [anon_sym_STAR] = ACTIONS(6358),
    [anon_sym_AMP_AMP] = ACTIONS(6358),
    [anon_sym_AMP] = ACTIONS(6356),
    [anon_sym_SEMI] = ACTIONS(6358),
    [anon_sym___extension__] = ACTIONS(6356),
    [anon_sym___device__] = ACTIONS(6356),
    [anon_sym___host__] = ACTIONS(6356),
    [anon_sym___global__] = ACTIONS(6356),
    [anon_sym___forceinline__] = ACTIONS(6356),
    [anon_sym___noinline__] = ACTIONS(6356),
    [anon_sym_virtual] = ACTIONS(6356),
    [anon_sym_extern] = ACTIONS(6356),
    [anon_sym___attribute__] = ACTIONS(6356),
    [anon_sym___attribute] = ACTIONS(6356),
    [anon_sym_COLON_COLON] = ACTIONS(6358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6358),
    [anon_sym___declspec] = ACTIONS(6356),
    [anon_sym___based] = ACTIONS(6356),
    [anon_sym___cdecl] = ACTIONS(6356),
    [anon_sym___clrcall] = ACTIONS(6356),
    [anon_sym___stdcall] = ACTIONS(6356),
    [anon_sym___fastcall] = ACTIONS(6356),
    [anon_sym___thiscall] = ACTIONS(6356),
    [anon_sym___vectorcall] = ACTIONS(6356),
    [anon_sym_LBRACE] = ACTIONS(6358),
    [anon_sym_LBRACK] = ACTIONS(6356),
    [anon_sym_static] = ACTIONS(6356),
    [anon_sym_EQ] = ACTIONS(6358),
    [anon_sym_register] = ACTIONS(6356),
    [anon_sym_inline] = ACTIONS(6356),
    [anon_sym___inline] = ACTIONS(6356),
    [anon_sym___inline__] = ACTIONS(6356),
    [anon_sym___forceinline] = ACTIONS(6356),
    [anon_sym_thread_local] = ACTIONS(6356),
    [anon_sym___thread] = ACTIONS(6356),
    [anon_sym_const] = ACTIONS(6356),
    [anon_sym_constexpr] = ACTIONS(6356),
    [anon_sym_volatile] = ACTIONS(6356),
    [anon_sym_restrict] = ACTIONS(6356),
    [anon_sym___restrict__] = ACTIONS(6356),
    [anon_sym__Atomic] = ACTIONS(6356),
    [anon_sym__Noreturn] = ACTIONS(6356),
    [anon_sym_noreturn] = ACTIONS(6356),
    [anon_sym__Nonnull] = ACTIONS(6356),
    [anon_sym_mutable] = ACTIONS(6356),
    [anon_sym_constinit] = ACTIONS(6356),
    [anon_sym_consteval] = ACTIONS(6356),
    [anon_sym___shared__] = ACTIONS(6356),
    [anon_sym___local__] = ACTIONS(6356),
    [anon_sym___constant__] = ACTIONS(6356),
    [anon_sym___managed__] = ACTIONS(6356),
    [anon_sym___grid_constant__] = ACTIONS(6356),
    [anon_sym_alignas] = ACTIONS(6356),
    [anon_sym__Alignas] = ACTIONS(6356),
    [anon_sym_COLON] = ACTIONS(6356),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6356),
    [anon_sym_final] = ACTIONS(6356),
    [anon_sym_override] = ACTIONS(6356),
    [anon_sym_explicit] = ACTIONS(6356),
    [anon_sym_template] = ACTIONS(6356),
    [anon_sym_GT2] = ACTIONS(6358),
    [anon_sym_operator] = ACTIONS(6356),
    [anon_sym___launch_bounds__] = ACTIONS(6356),
  },
  [STATE(2368)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1959),
    [anon_sym_PIPE_PIPE] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1959),
    [anon_sym_BANG_EQ] = ACTIONS(1959),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1959),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(1959),
    [anon_sym_LT_EQ_GT] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1959),
    [anon_sym_PLUS_PLUS] = ACTIONS(1959),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1959),
    [anon_sym_DASH_GT] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(1959),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(1959),
  },
  [STATE(2369)] = {
    [sym_attribute_specifier] = STATE(2228),
    [sym_enumerator_list] = STATE(2555),
    [sym_identifier] = ACTIONS(6185),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6183),
    [anon_sym_COMMA] = ACTIONS(6183),
    [anon_sym_RPAREN] = ACTIONS(6183),
    [anon_sym_LPAREN2] = ACTIONS(6183),
    [anon_sym_TILDE] = ACTIONS(6183),
    [anon_sym_STAR] = ACTIONS(6183),
    [anon_sym_AMP_AMP] = ACTIONS(6183),
    [anon_sym_AMP] = ACTIONS(6185),
    [anon_sym_SEMI] = ACTIONS(6183),
    [anon_sym___extension__] = ACTIONS(6185),
    [anon_sym___device__] = ACTIONS(6185),
    [anon_sym___host__] = ACTIONS(6185),
    [anon_sym___global__] = ACTIONS(6185),
    [anon_sym___forceinline__] = ACTIONS(6185),
    [anon_sym___noinline__] = ACTIONS(6185),
    [anon_sym_virtual] = ACTIONS(6185),
    [anon_sym_extern] = ACTIONS(6185),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6183),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6183),
    [anon_sym___declspec] = ACTIONS(6185),
    [anon_sym___based] = ACTIONS(6185),
    [anon_sym___cdecl] = ACTIONS(6185),
    [anon_sym___clrcall] = ACTIONS(6185),
    [anon_sym___stdcall] = ACTIONS(6185),
    [anon_sym___fastcall] = ACTIONS(6185),
    [anon_sym___thiscall] = ACTIONS(6185),
    [anon_sym___vectorcall] = ACTIONS(6185),
    [anon_sym_LBRACE] = ACTIONS(6360),
    [anon_sym_LBRACK] = ACTIONS(6185),
    [anon_sym_static] = ACTIONS(6185),
    [anon_sym_EQ] = ACTIONS(6183),
    [anon_sym_register] = ACTIONS(6185),
    [anon_sym_inline] = ACTIONS(6185),
    [anon_sym___inline] = ACTIONS(6185),
    [anon_sym___inline__] = ACTIONS(6185),
    [anon_sym___forceinline] = ACTIONS(6185),
    [anon_sym_thread_local] = ACTIONS(6185),
    [anon_sym___thread] = ACTIONS(6185),
    [anon_sym_const] = ACTIONS(6185),
    [anon_sym_constexpr] = ACTIONS(6185),
    [anon_sym_volatile] = ACTIONS(6185),
    [anon_sym_restrict] = ACTIONS(6185),
    [anon_sym___restrict__] = ACTIONS(6185),
    [anon_sym__Atomic] = ACTIONS(6185),
    [anon_sym__Noreturn] = ACTIONS(6185),
    [anon_sym_noreturn] = ACTIONS(6185),
    [anon_sym__Nonnull] = ACTIONS(6185),
    [anon_sym_mutable] = ACTIONS(6185),
    [anon_sym_constinit] = ACTIONS(6185),
    [anon_sym_consteval] = ACTIONS(6185),
    [anon_sym___shared__] = ACTIONS(6185),
    [anon_sym___local__] = ACTIONS(6185),
    [anon_sym___constant__] = ACTIONS(6185),
    [anon_sym___managed__] = ACTIONS(6185),
    [anon_sym___grid_constant__] = ACTIONS(6185),
    [anon_sym_alignas] = ACTIONS(6185),
    [anon_sym__Alignas] = ACTIONS(6185),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6185),
    [anon_sym_decltype] = ACTIONS(6185),
    [anon_sym_template] = ACTIONS(6185),
    [anon_sym_GT2] = ACTIONS(6183),
    [anon_sym_operator] = ACTIONS(6185),
    [anon_sym___launch_bounds__] = ACTIONS(6185),
  },
  [STATE(2370)] = {
    [sym_attribute_specifier] = STATE(2570),
    [sym_enumerator_list] = STATE(2463),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6177),
    [anon_sym_COMMA] = ACTIONS(6177),
    [anon_sym_LPAREN2] = ACTIONS(6177),
    [anon_sym_DASH] = ACTIONS(6179),
    [anon_sym_PLUS] = ACTIONS(6179),
    [anon_sym_STAR] = ACTIONS(6177),
    [anon_sym_SLASH] = ACTIONS(6179),
    [anon_sym_PERCENT] = ACTIONS(6177),
    [anon_sym_PIPE_PIPE] = ACTIONS(6177),
    [anon_sym_AMP_AMP] = ACTIONS(6177),
    [anon_sym_PIPE] = ACTIONS(6179),
    [anon_sym_CARET] = ACTIONS(6177),
    [anon_sym_AMP] = ACTIONS(6179),
    [anon_sym_EQ_EQ] = ACTIONS(6177),
    [anon_sym_BANG_EQ] = ACTIONS(6177),
    [anon_sym_GT] = ACTIONS(6179),
    [anon_sym_GT_EQ] = ACTIONS(6179),
    [anon_sym_LT_EQ] = ACTIONS(6179),
    [anon_sym_LT] = ACTIONS(6179),
    [anon_sym_LT_LT] = ACTIONS(6179),
    [anon_sym_GT_GT] = ACTIONS(6179),
    [anon_sym___extension__] = ACTIONS(6177),
    [anon_sym___global__] = ACTIONS(6177),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6362),
    [anon_sym_LBRACK] = ACTIONS(6177),
    [anon_sym_const] = ACTIONS(6179),
    [anon_sym_constexpr] = ACTIONS(6177),
    [anon_sym_volatile] = ACTIONS(6177),
    [anon_sym_restrict] = ACTIONS(6177),
    [anon_sym___restrict__] = ACTIONS(6177),
    [anon_sym__Atomic] = ACTIONS(6177),
    [anon_sym__Noreturn] = ACTIONS(6177),
    [anon_sym_noreturn] = ACTIONS(6177),
    [anon_sym__Nonnull] = ACTIONS(6177),
    [anon_sym_mutable] = ACTIONS(6177),
    [anon_sym_constinit] = ACTIONS(6177),
    [anon_sym_consteval] = ACTIONS(6177),
    [anon_sym___shared__] = ACTIONS(6177),
    [anon_sym___local__] = ACTIONS(6177),
    [anon_sym___constant__] = ACTIONS(6177),
    [anon_sym___managed__] = ACTIONS(6177),
    [anon_sym___grid_constant__] = ACTIONS(6177),
    [anon_sym_alignas] = ACTIONS(6177),
    [anon_sym__Alignas] = ACTIONS(6177),
    [anon_sym_QMARK] = ACTIONS(6177),
    [anon_sym_LT_EQ_GT] = ACTIONS(6177),
    [anon_sym_or] = ACTIONS(6177),
    [anon_sym_and] = ACTIONS(6177),
    [anon_sym_bitor] = ACTIONS(6177),
    [anon_sym_xor] = ACTIONS(6177),
    [anon_sym_bitand] = ACTIONS(6177),
    [anon_sym_not_eq] = ACTIONS(6177),
    [anon_sym_DASH_DASH] = ACTIONS(6177),
    [anon_sym_PLUS_PLUS] = ACTIONS(6177),
    [anon_sym_DOT] = ACTIONS(6179),
    [anon_sym_DOT_STAR] = ACTIONS(6177),
    [anon_sym_DASH_GT] = ACTIONS(6177),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6177),
    [anon_sym_decltype] = ACTIONS(6177),
    [anon_sym_final] = ACTIONS(6177),
    [anon_sym_override] = ACTIONS(6177),
    [anon_sym_GT2] = ACTIONS(6177),
    [anon_sym_requires] = ACTIONS(6177),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6177),
  },
  [STATE(2371)] = {
    [sym_string_literal] = STATE(2433),
    [sym_template_argument_list] = STATE(3338),
    [sym_raw_string_literal] = STATE(2433),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(6364),
    [anon_sym_LPAREN2] = ACTIONS(6364),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5096),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5099),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(6367),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4012),
    [anon_sym_L_DQUOTE] = ACTIONS(5103),
    [anon_sym_u_DQUOTE] = ACTIONS(5103),
    [anon_sym_U_DQUOTE] = ACTIONS(5103),
    [anon_sym_u8_DQUOTE] = ACTIONS(5103),
    [anon_sym_DQUOTE] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5105),
    [anon_sym_LR_DQUOTE] = ACTIONS(5105),
    [anon_sym_uR_DQUOTE] = ACTIONS(5105),
    [anon_sym_UR_DQUOTE] = ACTIONS(5105),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5105),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2372)] = {
    [sym_string_literal] = STATE(2402),
    [sym_raw_string_literal] = STATE(2402),
    [aux_sym_concatenated_string_repeat1] = STATE(2402),
    [sym_identifier] = ACTIONS(6370),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6002),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_LPAREN2] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_STAR] = ACTIONS(6004),
    [anon_sym_SLASH] = ACTIONS(6004),
    [anon_sym_PERCENT] = ACTIONS(6004),
    [anon_sym_PIPE_PIPE] = ACTIONS(6002),
    [anon_sym_AMP_AMP] = ACTIONS(6002),
    [anon_sym_PIPE] = ACTIONS(6004),
    [anon_sym_CARET] = ACTIONS(6004),
    [anon_sym_AMP] = ACTIONS(6004),
    [anon_sym_EQ_EQ] = ACTIONS(6002),
    [anon_sym_BANG_EQ] = ACTIONS(6002),
    [anon_sym_GT] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(6002),
    [anon_sym_LT_EQ] = ACTIONS(6004),
    [anon_sym_LT] = ACTIONS(6004),
    [anon_sym_LT_LT] = ACTIONS(6004),
    [anon_sym_GT_GT] = ACTIONS(6004),
    [anon_sym_SEMI] = ACTIONS(6002),
    [anon_sym___attribute__] = ACTIONS(6004),
    [anon_sym___attribute] = ACTIONS(6004),
    [anon_sym_LBRACK] = ACTIONS(6002),
    [anon_sym_EQ] = ACTIONS(6004),
    [anon_sym_QMARK] = ACTIONS(6002),
    [anon_sym_STAR_EQ] = ACTIONS(6002),
    [anon_sym_SLASH_EQ] = ACTIONS(6002),
    [anon_sym_PERCENT_EQ] = ACTIONS(6002),
    [anon_sym_PLUS_EQ] = ACTIONS(6002),
    [anon_sym_DASH_EQ] = ACTIONS(6002),
    [anon_sym_LT_LT_EQ] = ACTIONS(6002),
    [anon_sym_GT_GT_EQ] = ACTIONS(6002),
    [anon_sym_AMP_EQ] = ACTIONS(6002),
    [anon_sym_CARET_EQ] = ACTIONS(6002),
    [anon_sym_PIPE_EQ] = ACTIONS(6002),
    [anon_sym_and_eq] = ACTIONS(6004),
    [anon_sym_or_eq] = ACTIONS(6004),
    [anon_sym_xor_eq] = ACTIONS(6004),
    [anon_sym_LT_EQ_GT] = ACTIONS(6002),
    [anon_sym_or] = ACTIONS(6004),
    [anon_sym_and] = ACTIONS(6004),
    [anon_sym_bitor] = ACTIONS(6004),
    [anon_sym_xor] = ACTIONS(6004),
    [anon_sym_bitand] = ACTIONS(6004),
    [anon_sym_not_eq] = ACTIONS(6004),
    [anon_sym_DASH_DASH] = ACTIONS(6002),
    [anon_sym_PLUS_PLUS] = ACTIONS(6002),
    [anon_sym_DOT] = ACTIONS(6004),
    [anon_sym_DOT_STAR] = ACTIONS(6002),
    [anon_sym_DASH_GT] = ACTIONS(6002),
    [anon_sym_L_DQUOTE] = ACTIONS(6372),
    [anon_sym_u_DQUOTE] = ACTIONS(6372),
    [anon_sym_U_DQUOTE] = ACTIONS(6372),
    [anon_sym_u8_DQUOTE] = ACTIONS(6372),
    [anon_sym_DQUOTE] = ACTIONS(6372),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6374),
    [anon_sym_LR_DQUOTE] = ACTIONS(6374),
    [anon_sym_uR_DQUOTE] = ACTIONS(6374),
    [anon_sym_UR_DQUOTE] = ACTIONS(6374),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6374),
    [sym_literal_suffix] = ACTIONS(6004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6002),
  },
  [STATE(2373)] = {
    [sym_string_literal] = STATE(2372),
    [sym_template_argument_list] = STATE(2672),
    [sym_raw_string_literal] = STATE(2372),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5857),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___attribute__] = ACTIONS(4004),
    [anon_sym___attribute] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(6372),
    [anon_sym_u_DQUOTE] = ACTIONS(6372),
    [anon_sym_U_DQUOTE] = ACTIONS(6372),
    [anon_sym_u8_DQUOTE] = ACTIONS(6372),
    [anon_sym_DQUOTE] = ACTIONS(6372),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6374),
    [anon_sym_LR_DQUOTE] = ACTIONS(6374),
    [anon_sym_uR_DQUOTE] = ACTIONS(6374),
    [anon_sym_UR_DQUOTE] = ACTIONS(6374),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6374),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2374)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_signed] = ACTIONS(5684),
    [anon_sym_unsigned] = ACTIONS(5684),
    [anon_sym_long] = ACTIONS(5684),
    [anon_sym_short] = ACTIONS(5684),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_primitive_type] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_asm] = ACTIONS(5684),
    [anon_sym___asm__] = ACTIONS(5684),
    [anon_sym___asm] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_final] = ACTIONS(5684),
    [anon_sym_override] = ACTIONS(5684),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_try] = ACTIONS(5684),
    [anon_sym_requires] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2375)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6376),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2376)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6378),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2377)] = {
    [sym_string_literal] = STATE(2204),
    [sym_template_argument_list] = STATE(3182),
    [sym_raw_string_literal] = STATE(2204),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(6364),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(6380),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5099),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4004),
    [anon_sym_LBRACK] = ACTIONS(6367),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2378)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5659),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5659),
    [anon_sym___extension__] = ACTIONS(5661),
    [anon_sym___global__] = ACTIONS(5661),
    [anon_sym___attribute__] = ACTIONS(5661),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5661),
    [anon_sym_volatile] = ACTIONS(5661),
    [anon_sym_restrict] = ACTIONS(5661),
    [anon_sym___restrict__] = ACTIONS(5661),
    [anon_sym__Atomic] = ACTIONS(5661),
    [anon_sym__Noreturn] = ACTIONS(5661),
    [anon_sym_noreturn] = ACTIONS(5661),
    [anon_sym__Nonnull] = ACTIONS(5661),
    [anon_sym_mutable] = ACTIONS(5661),
    [anon_sym_constinit] = ACTIONS(5661),
    [anon_sym_consteval] = ACTIONS(5661),
    [anon_sym___shared__] = ACTIONS(5661),
    [anon_sym___local__] = ACTIONS(5661),
    [anon_sym___constant__] = ACTIONS(5661),
    [anon_sym___managed__] = ACTIONS(5661),
    [anon_sym___grid_constant__] = ACTIONS(5661),
    [anon_sym_alignas] = ACTIONS(5661),
    [anon_sym__Alignas] = ACTIONS(5661),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5661),
    [anon_sym_and] = ACTIONS(5661),
    [anon_sym_bitor] = ACTIONS(5661),
    [anon_sym_xor] = ACTIONS(5661),
    [anon_sym_bitand] = ACTIONS(5661),
    [anon_sym_not_eq] = ACTIONS(5661),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5661),
    [anon_sym_decltype] = ACTIONS(5661),
    [anon_sym_final] = ACTIONS(5661),
    [anon_sym_override] = ACTIONS(5661),
    [anon_sym_GT2] = ACTIONS(5661),
    [anon_sym_requires] = ACTIONS(5661),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(2379)] = {
    [sym_string_literal] = STATE(2204),
    [sym_template_argument_list] = STATE(2672),
    [sym_raw_string_literal] = STATE(2204),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(6383),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5857),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6383),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4004),
    [anon_sym_LBRACK] = ACTIONS(6385),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2380)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6387),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2381)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6389),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2382)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6391),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2383)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6393),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2384)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6395),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2385)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5690),
    [anon_sym_COMMA] = ACTIONS(5690),
    [anon_sym_LPAREN2] = ACTIONS(5690),
    [anon_sym_DASH] = ACTIONS(5688),
    [anon_sym_PLUS] = ACTIONS(5688),
    [anon_sym_STAR] = ACTIONS(5690),
    [anon_sym_SLASH] = ACTIONS(5688),
    [anon_sym_PERCENT] = ACTIONS(5690),
    [anon_sym_PIPE_PIPE] = ACTIONS(5690),
    [anon_sym_AMP_AMP] = ACTIONS(5690),
    [anon_sym_PIPE] = ACTIONS(5688),
    [anon_sym_CARET] = ACTIONS(5690),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_EQ_EQ] = ACTIONS(5690),
    [anon_sym_BANG_EQ] = ACTIONS(5690),
    [anon_sym_GT] = ACTIONS(5688),
    [anon_sym_GT_EQ] = ACTIONS(5688),
    [anon_sym_LT_EQ] = ACTIONS(5688),
    [anon_sym_LT] = ACTIONS(5688),
    [anon_sym_LT_LT] = ACTIONS(5688),
    [anon_sym_GT_GT] = ACTIONS(5688),
    [anon_sym___extension__] = ACTIONS(5690),
    [anon_sym___global__] = ACTIONS(5690),
    [anon_sym___attribute__] = ACTIONS(5690),
    [anon_sym___attribute] = ACTIONS(5688),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACE] = ACTIONS(5690),
    [anon_sym_LBRACK] = ACTIONS(5690),
    [anon_sym_const] = ACTIONS(5688),
    [anon_sym_constexpr] = ACTIONS(5690),
    [anon_sym_volatile] = ACTIONS(5690),
    [anon_sym_restrict] = ACTIONS(5690),
    [anon_sym___restrict__] = ACTIONS(5690),
    [anon_sym__Atomic] = ACTIONS(5690),
    [anon_sym__Noreturn] = ACTIONS(5690),
    [anon_sym_noreturn] = ACTIONS(5690),
    [anon_sym__Nonnull] = ACTIONS(5690),
    [anon_sym_mutable] = ACTIONS(5690),
    [anon_sym_constinit] = ACTIONS(5690),
    [anon_sym_consteval] = ACTIONS(5690),
    [anon_sym___shared__] = ACTIONS(5690),
    [anon_sym___local__] = ACTIONS(5690),
    [anon_sym___constant__] = ACTIONS(5690),
    [anon_sym___managed__] = ACTIONS(5690),
    [anon_sym___grid_constant__] = ACTIONS(5690),
    [anon_sym_alignas] = ACTIONS(5690),
    [anon_sym__Alignas] = ACTIONS(5690),
    [anon_sym_COLON] = ACTIONS(5688),
    [anon_sym_QMARK] = ACTIONS(5690),
    [anon_sym_LT_EQ_GT] = ACTIONS(5690),
    [anon_sym_or] = ACTIONS(5690),
    [anon_sym_and] = ACTIONS(5690),
    [anon_sym_bitor] = ACTIONS(5690),
    [anon_sym_xor] = ACTIONS(5690),
    [anon_sym_bitand] = ACTIONS(5690),
    [anon_sym_not_eq] = ACTIONS(5690),
    [anon_sym_DASH_DASH] = ACTIONS(5690),
    [anon_sym_PLUS_PLUS] = ACTIONS(5690),
    [anon_sym_DOT] = ACTIONS(5688),
    [anon_sym_DOT_STAR] = ACTIONS(5690),
    [anon_sym_DASH_GT] = ACTIONS(5690),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5690),
    [anon_sym_decltype] = ACTIONS(5690),
    [anon_sym_final] = ACTIONS(5690),
    [anon_sym_override] = ACTIONS(5690),
    [anon_sym_GT2] = ACTIONS(5690),
    [anon_sym_requires] = ACTIONS(5690),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5690),
  },
  [STATE(2386)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6397),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2387)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4004),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2388)] = {
    [sym_attribute_specifier] = STATE(2542),
    [sym_enumerator_list] = STATE(2451),
    [sym_identifier] = ACTIONS(6179),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6177),
    [anon_sym_COMMA] = ACTIONS(6177),
    [anon_sym_RPAREN] = ACTIONS(6177),
    [aux_sym_preproc_if_token2] = ACTIONS(6177),
    [aux_sym_preproc_else_token1] = ACTIONS(6177),
    [aux_sym_preproc_elif_token1] = ACTIONS(6179),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6177),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6177),
    [anon_sym_LPAREN2] = ACTIONS(6177),
    [anon_sym_DASH] = ACTIONS(6179),
    [anon_sym_PLUS] = ACTIONS(6179),
    [anon_sym_STAR] = ACTIONS(6179),
    [anon_sym_SLASH] = ACTIONS(6179),
    [anon_sym_PERCENT] = ACTIONS(6179),
    [anon_sym_PIPE_PIPE] = ACTIONS(6177),
    [anon_sym_AMP_AMP] = ACTIONS(6177),
    [anon_sym_PIPE] = ACTIONS(6179),
    [anon_sym_CARET] = ACTIONS(6179),
    [anon_sym_AMP] = ACTIONS(6179),
    [anon_sym_EQ_EQ] = ACTIONS(6177),
    [anon_sym_BANG_EQ] = ACTIONS(6177),
    [anon_sym_GT] = ACTIONS(6179),
    [anon_sym_GT_EQ] = ACTIONS(6177),
    [anon_sym_LT_EQ] = ACTIONS(6179),
    [anon_sym_LT] = ACTIONS(6179),
    [anon_sym_LT_LT] = ACTIONS(6179),
    [anon_sym_GT_GT] = ACTIONS(6179),
    [anon_sym_SEMI] = ACTIONS(6177),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6399),
    [anon_sym_RBRACE] = ACTIONS(6177),
    [anon_sym_LBRACK] = ACTIONS(6177),
    [anon_sym_RBRACK] = ACTIONS(6177),
    [anon_sym_EQ] = ACTIONS(6179),
    [anon_sym_COLON] = ACTIONS(6177),
    [anon_sym_QMARK] = ACTIONS(6177),
    [anon_sym_STAR_EQ] = ACTIONS(6177),
    [anon_sym_SLASH_EQ] = ACTIONS(6177),
    [anon_sym_PERCENT_EQ] = ACTIONS(6177),
    [anon_sym_PLUS_EQ] = ACTIONS(6177),
    [anon_sym_DASH_EQ] = ACTIONS(6177),
    [anon_sym_LT_LT_EQ] = ACTIONS(6177),
    [anon_sym_GT_GT_EQ] = ACTIONS(6177),
    [anon_sym_AMP_EQ] = ACTIONS(6177),
    [anon_sym_CARET_EQ] = ACTIONS(6177),
    [anon_sym_PIPE_EQ] = ACTIONS(6177),
    [anon_sym_and_eq] = ACTIONS(6179),
    [anon_sym_or_eq] = ACTIONS(6179),
    [anon_sym_xor_eq] = ACTIONS(6179),
    [anon_sym_LT_EQ_GT] = ACTIONS(6177),
    [anon_sym_or] = ACTIONS(6179),
    [anon_sym_and] = ACTIONS(6179),
    [anon_sym_bitor] = ACTIONS(6179),
    [anon_sym_xor] = ACTIONS(6179),
    [anon_sym_bitand] = ACTIONS(6179),
    [anon_sym_not_eq] = ACTIONS(6179),
    [anon_sym_DASH_DASH] = ACTIONS(6177),
    [anon_sym_PLUS_PLUS] = ACTIONS(6177),
    [anon_sym_DOT] = ACTIONS(6179),
    [anon_sym_DOT_STAR] = ACTIONS(6177),
    [anon_sym_DASH_GT] = ACTIONS(6177),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6179),
    [anon_sym_decltype] = ACTIONS(6179),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6177),
  },
  [STATE(2389)] = {
    [sym_template_argument_list] = STATE(1659),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2654),
    [anon_sym_COMMA] = ACTIONS(6074),
    [anon_sym_RPAREN] = ACTIONS(6074),
    [anon_sym_LPAREN2] = ACTIONS(6074),
    [anon_sym_STAR] = ACTIONS(6074),
    [anon_sym_AMP_AMP] = ACTIONS(6074),
    [anon_sym_AMP] = ACTIONS(6072),
    [anon_sym_LT] = ACTIONS(6076),
    [anon_sym_SEMI] = ACTIONS(6074),
    [anon_sym___extension__] = ACTIONS(6074),
    [anon_sym___device__] = ACTIONS(6074),
    [anon_sym___host__] = ACTIONS(6074),
    [anon_sym___global__] = ACTIONS(6074),
    [anon_sym___forceinline__] = ACTIONS(6074),
    [anon_sym___noinline__] = ACTIONS(6074),
    [anon_sym_virtual] = ACTIONS(6074),
    [anon_sym_extern] = ACTIONS(6074),
    [anon_sym___attribute__] = ACTIONS(6074),
    [anon_sym___attribute] = ACTIONS(6072),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6074),
    [anon_sym___declspec] = ACTIONS(6074),
    [anon_sym_LBRACE] = ACTIONS(6074),
    [anon_sym_signed] = ACTIONS(6401),
    [anon_sym_unsigned] = ACTIONS(6401),
    [anon_sym_long] = ACTIONS(6401),
    [anon_sym_short] = ACTIONS(6401),
    [anon_sym_LBRACK] = ACTIONS(6072),
    [anon_sym_static] = ACTIONS(6074),
    [anon_sym_EQ] = ACTIONS(6074),
    [anon_sym_register] = ACTIONS(6074),
    [anon_sym_inline] = ACTIONS(6074),
    [anon_sym___inline] = ACTIONS(6072),
    [anon_sym___inline__] = ACTIONS(6074),
    [anon_sym___forceinline] = ACTIONS(6072),
    [anon_sym_thread_local] = ACTIONS(6074),
    [anon_sym___thread] = ACTIONS(6074),
    [anon_sym_const] = ACTIONS(6072),
    [anon_sym_constexpr] = ACTIONS(6074),
    [anon_sym_volatile] = ACTIONS(6074),
    [anon_sym_restrict] = ACTIONS(6074),
    [anon_sym___restrict__] = ACTIONS(6074),
    [anon_sym__Atomic] = ACTIONS(6074),
    [anon_sym__Noreturn] = ACTIONS(6074),
    [anon_sym_noreturn] = ACTIONS(6074),
    [anon_sym__Nonnull] = ACTIONS(6074),
    [anon_sym_mutable] = ACTIONS(6074),
    [anon_sym_constinit] = ACTIONS(6074),
    [anon_sym_consteval] = ACTIONS(6074),
    [anon_sym___shared__] = ACTIONS(6074),
    [anon_sym___local__] = ACTIONS(6074),
    [anon_sym___constant__] = ACTIONS(6074),
    [anon_sym___managed__] = ACTIONS(6074),
    [anon_sym___grid_constant__] = ACTIONS(6074),
    [anon_sym_alignas] = ACTIONS(6074),
    [anon_sym__Alignas] = ACTIONS(6074),
    [anon_sym_asm] = ACTIONS(6074),
    [anon_sym___asm__] = ACTIONS(6074),
    [anon_sym___asm] = ACTIONS(6072),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6074),
    [anon_sym_decltype] = ACTIONS(6074),
    [anon_sym_final] = ACTIONS(6074),
    [anon_sym_override] = ACTIONS(6074),
    [anon_sym_GT2] = ACTIONS(6074),
    [anon_sym_try] = ACTIONS(6074),
    [anon_sym_requires] = ACTIONS(6074),
    [anon_sym___launch_bounds__] = ACTIONS(6074),
  },
  [STATE(2390)] = {
    [sym_string_literal] = STATE(3462),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(3462),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym___attribute__] = ACTIONS(4004),
    [anon_sym___attribute] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(6403),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(6405),
    [anon_sym_SLASH_EQ] = ACTIONS(6405),
    [anon_sym_PERCENT_EQ] = ACTIONS(6405),
    [anon_sym_PLUS_EQ] = ACTIONS(6405),
    [anon_sym_DASH_EQ] = ACTIONS(6405),
    [anon_sym_LT_LT_EQ] = ACTIONS(6405),
    [anon_sym_GT_GT_EQ] = ACTIONS(6405),
    [anon_sym_AMP_EQ] = ACTIONS(6405),
    [anon_sym_CARET_EQ] = ACTIONS(6405),
    [anon_sym_PIPE_EQ] = ACTIONS(6405),
    [anon_sym_and_eq] = ACTIONS(6405),
    [anon_sym_or_eq] = ACTIONS(6405),
    [anon_sym_xor_eq] = ACTIONS(6405),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(6407),
    [anon_sym_u_DQUOTE] = ACTIONS(6407),
    [anon_sym_U_DQUOTE] = ACTIONS(6407),
    [anon_sym_u8_DQUOTE] = ACTIONS(6407),
    [anon_sym_DQUOTE] = ACTIONS(6407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6409),
    [anon_sym_LR_DQUOTE] = ACTIONS(6409),
    [anon_sym_uR_DQUOTE] = ACTIONS(6409),
    [anon_sym_UR_DQUOTE] = ACTIONS(6409),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6409),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2391)] = {
    [sym_string_literal] = STATE(2433),
    [sym_template_argument_list] = STATE(3610),
    [sym_raw_string_literal] = STATE(2433),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(6383),
    [anon_sym_LPAREN2] = ACTIONS(6383),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5107),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6383),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(6385),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4012),
    [anon_sym_L_DQUOTE] = ACTIONS(5103),
    [anon_sym_u_DQUOTE] = ACTIONS(5103),
    [anon_sym_U_DQUOTE] = ACTIONS(5103),
    [anon_sym_u8_DQUOTE] = ACTIONS(5103),
    [anon_sym_DQUOTE] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5105),
    [anon_sym_LR_DQUOTE] = ACTIONS(5105),
    [anon_sym_uR_DQUOTE] = ACTIONS(5105),
    [anon_sym_UR_DQUOTE] = ACTIONS(5105),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5105),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2392)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(6383),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6383),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4004),
    [anon_sym_LBRACK] = ACTIONS(6385),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2393)] = {
    [sym_template_argument_list] = STATE(1659),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(6072),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6074),
    [anon_sym_COMMA] = ACTIONS(6074),
    [aux_sym_preproc_if_token2] = ACTIONS(6074),
    [aux_sym_preproc_else_token1] = ACTIONS(6074),
    [aux_sym_preproc_elif_token1] = ACTIONS(6072),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6074),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6074),
    [anon_sym_LPAREN2] = ACTIONS(6074),
    [anon_sym_DASH] = ACTIONS(6072),
    [anon_sym_PLUS] = ACTIONS(6072),
    [anon_sym_STAR] = ACTIONS(6072),
    [anon_sym_SLASH] = ACTIONS(6072),
    [anon_sym_PERCENT] = ACTIONS(6072),
    [anon_sym_PIPE_PIPE] = ACTIONS(6074),
    [anon_sym_AMP_AMP] = ACTIONS(6074),
    [anon_sym_PIPE] = ACTIONS(6072),
    [anon_sym_CARET] = ACTIONS(6072),
    [anon_sym_AMP] = ACTIONS(6072),
    [anon_sym_EQ_EQ] = ACTIONS(6074),
    [anon_sym_BANG_EQ] = ACTIONS(6074),
    [anon_sym_GT] = ACTIONS(6072),
    [anon_sym_GT_EQ] = ACTIONS(6074),
    [anon_sym_LT_EQ] = ACTIONS(6072),
    [anon_sym_LT] = ACTIONS(6072),
    [anon_sym_LT_LT] = ACTIONS(6072),
    [anon_sym_GT_GT] = ACTIONS(6072),
    [anon_sym___attribute__] = ACTIONS(6072),
    [anon_sym___attribute] = ACTIONS(6072),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(6074),
    [anon_sym_signed] = ACTIONS(6411),
    [anon_sym_unsigned] = ACTIONS(6411),
    [anon_sym_long] = ACTIONS(6411),
    [anon_sym_short] = ACTIONS(6411),
    [anon_sym_LBRACK] = ACTIONS(6074),
    [anon_sym_EQ] = ACTIONS(6072),
    [anon_sym_QMARK] = ACTIONS(6074),
    [anon_sym_STAR_EQ] = ACTIONS(6074),
    [anon_sym_SLASH_EQ] = ACTIONS(6074),
    [anon_sym_PERCENT_EQ] = ACTIONS(6074),
    [anon_sym_PLUS_EQ] = ACTIONS(6074),
    [anon_sym_DASH_EQ] = ACTIONS(6074),
    [anon_sym_LT_LT_EQ] = ACTIONS(6074),
    [anon_sym_GT_GT_EQ] = ACTIONS(6074),
    [anon_sym_AMP_EQ] = ACTIONS(6074),
    [anon_sym_CARET_EQ] = ACTIONS(6074),
    [anon_sym_PIPE_EQ] = ACTIONS(6074),
    [anon_sym_and_eq] = ACTIONS(6072),
    [anon_sym_or_eq] = ACTIONS(6072),
    [anon_sym_xor_eq] = ACTIONS(6072),
    [anon_sym_LT_EQ_GT] = ACTIONS(6074),
    [anon_sym_or] = ACTIONS(6072),
    [anon_sym_and] = ACTIONS(6072),
    [anon_sym_bitor] = ACTIONS(6072),
    [anon_sym_xor] = ACTIONS(6072),
    [anon_sym_bitand] = ACTIONS(6072),
    [anon_sym_not_eq] = ACTIONS(6072),
    [anon_sym_DASH_DASH] = ACTIONS(6074),
    [anon_sym_PLUS_PLUS] = ACTIONS(6074),
    [anon_sym_DOT] = ACTIONS(6072),
    [anon_sym_DOT_STAR] = ACTIONS(6074),
    [anon_sym_DASH_GT] = ACTIONS(6074),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6072),
    [anon_sym_decltype] = ACTIONS(6072),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6074),
  },
  [STATE(2394)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5659),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5659),
    [anon_sym___extension__] = ACTIONS(5661),
    [anon_sym___global__] = ACTIONS(5661),
    [anon_sym___attribute__] = ACTIONS(5661),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5661),
    [anon_sym_volatile] = ACTIONS(5661),
    [anon_sym_restrict] = ACTIONS(5661),
    [anon_sym___restrict__] = ACTIONS(5661),
    [anon_sym__Atomic] = ACTIONS(5661),
    [anon_sym__Noreturn] = ACTIONS(5661),
    [anon_sym_noreturn] = ACTIONS(5661),
    [anon_sym__Nonnull] = ACTIONS(5661),
    [anon_sym_mutable] = ACTIONS(5661),
    [anon_sym_constinit] = ACTIONS(5661),
    [anon_sym_consteval] = ACTIONS(5661),
    [anon_sym___shared__] = ACTIONS(5661),
    [anon_sym___local__] = ACTIONS(5661),
    [anon_sym___constant__] = ACTIONS(5661),
    [anon_sym___managed__] = ACTIONS(5661),
    [anon_sym___grid_constant__] = ACTIONS(5661),
    [anon_sym_alignas] = ACTIONS(5661),
    [anon_sym__Alignas] = ACTIONS(5661),
    [anon_sym_COLON] = ACTIONS(5659),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5661),
    [anon_sym_and] = ACTIONS(5661),
    [anon_sym_bitor] = ACTIONS(5661),
    [anon_sym_xor] = ACTIONS(5661),
    [anon_sym_bitand] = ACTIONS(5661),
    [anon_sym_not_eq] = ACTIONS(5661),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5661),
    [anon_sym_decltype] = ACTIONS(5661),
    [anon_sym_final] = ACTIONS(5661),
    [anon_sym_override] = ACTIONS(5661),
    [anon_sym_GT2] = ACTIONS(5661),
    [anon_sym_requires] = ACTIONS(5661),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(2395)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6413),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2396)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4332),
    [anon_sym_COMMA] = ACTIONS(4332),
    [anon_sym_LPAREN2] = ACTIONS(4332),
    [anon_sym_DASH] = ACTIONS(4330),
    [anon_sym_PLUS] = ACTIONS(4330),
    [anon_sym_STAR] = ACTIONS(4332),
    [anon_sym_SLASH] = ACTIONS(4330),
    [anon_sym_PERCENT] = ACTIONS(4332),
    [anon_sym_PIPE_PIPE] = ACTIONS(4332),
    [anon_sym_AMP_AMP] = ACTIONS(4332),
    [anon_sym_PIPE] = ACTIONS(4330),
    [anon_sym_CARET] = ACTIONS(4332),
    [anon_sym_AMP] = ACTIONS(4330),
    [anon_sym_EQ_EQ] = ACTIONS(4332),
    [anon_sym_BANG_EQ] = ACTIONS(4332),
    [anon_sym_GT] = ACTIONS(4330),
    [anon_sym_GT_EQ] = ACTIONS(4330),
    [anon_sym_LT_EQ] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4330),
    [anon_sym_LT_LT] = ACTIONS(4330),
    [anon_sym_GT_GT] = ACTIONS(4330),
    [anon_sym___extension__] = ACTIONS(4332),
    [anon_sym___global__] = ACTIONS(4332),
    [anon_sym___attribute__] = ACTIONS(4332),
    [anon_sym___attribute] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(4332),
    [anon_sym_LBRACE] = ACTIONS(4332),
    [anon_sym_LBRACK] = ACTIONS(4332),
    [anon_sym_const] = ACTIONS(4330),
    [anon_sym_constexpr] = ACTIONS(4332),
    [anon_sym_volatile] = ACTIONS(4332),
    [anon_sym_restrict] = ACTIONS(4332),
    [anon_sym___restrict__] = ACTIONS(4332),
    [anon_sym__Atomic] = ACTIONS(4332),
    [anon_sym__Noreturn] = ACTIONS(4332),
    [anon_sym_noreturn] = ACTIONS(4332),
    [anon_sym__Nonnull] = ACTIONS(4332),
    [anon_sym_mutable] = ACTIONS(4332),
    [anon_sym_constinit] = ACTIONS(4332),
    [anon_sym_consteval] = ACTIONS(4332),
    [anon_sym___shared__] = ACTIONS(4332),
    [anon_sym___local__] = ACTIONS(4332),
    [anon_sym___constant__] = ACTIONS(4332),
    [anon_sym___managed__] = ACTIONS(4332),
    [anon_sym___grid_constant__] = ACTIONS(4332),
    [anon_sym_alignas] = ACTIONS(4332),
    [anon_sym__Alignas] = ACTIONS(4332),
    [anon_sym_COLON] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(4332),
    [anon_sym_LT_EQ_GT] = ACTIONS(4332),
    [anon_sym_or] = ACTIONS(4332),
    [anon_sym_and] = ACTIONS(4332),
    [anon_sym_bitor] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4332),
    [anon_sym_bitand] = ACTIONS(4332),
    [anon_sym_not_eq] = ACTIONS(4332),
    [anon_sym_DASH_DASH] = ACTIONS(4332),
    [anon_sym_PLUS_PLUS] = ACTIONS(4332),
    [anon_sym_DOT] = ACTIONS(4330),
    [anon_sym_DOT_STAR] = ACTIONS(4332),
    [anon_sym_DASH_GT] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4332),
    [anon_sym_decltype] = ACTIONS(4332),
    [anon_sym_final] = ACTIONS(4332),
    [anon_sym_override] = ACTIONS(4332),
    [anon_sym_GT2] = ACTIONS(4332),
    [anon_sym_requires] = ACTIONS(4332),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4332),
  },
  [STATE(2397)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5667),
    [anon_sym_COMMA] = ACTIONS(5667),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5665),
    [anon_sym_PLUS] = ACTIONS(5665),
    [anon_sym_STAR] = ACTIONS(5667),
    [anon_sym_SLASH] = ACTIONS(5665),
    [anon_sym_PERCENT] = ACTIONS(5667),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_PIPE] = ACTIONS(5665),
    [anon_sym_CARET] = ACTIONS(5667),
    [anon_sym_AMP] = ACTIONS(5665),
    [anon_sym_EQ_EQ] = ACTIONS(5667),
    [anon_sym_BANG_EQ] = ACTIONS(5667),
    [anon_sym_GT] = ACTIONS(5665),
    [anon_sym_GT_EQ] = ACTIONS(5665),
    [anon_sym_LT_EQ] = ACTIONS(5665),
    [anon_sym_LT] = ACTIONS(5665),
    [anon_sym_LT_LT] = ACTIONS(5665),
    [anon_sym_GT_GT] = ACTIONS(5665),
    [anon_sym___extension__] = ACTIONS(5667),
    [anon_sym___global__] = ACTIONS(5667),
    [anon_sym___attribute__] = ACTIONS(5667),
    [anon_sym___attribute] = ACTIONS(5665),
    [anon_sym_COLON_COLON] = ACTIONS(5667),
    [anon_sym_LBRACE] = ACTIONS(5667),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [anon_sym_const] = ACTIONS(5665),
    [anon_sym_constexpr] = ACTIONS(5667),
    [anon_sym_volatile] = ACTIONS(5667),
    [anon_sym_restrict] = ACTIONS(5667),
    [anon_sym___restrict__] = ACTIONS(5667),
    [anon_sym__Atomic] = ACTIONS(5667),
    [anon_sym__Noreturn] = ACTIONS(5667),
    [anon_sym_noreturn] = ACTIONS(5667),
    [anon_sym__Nonnull] = ACTIONS(5667),
    [anon_sym_mutable] = ACTIONS(5667),
    [anon_sym_constinit] = ACTIONS(5667),
    [anon_sym_consteval] = ACTIONS(5667),
    [anon_sym___shared__] = ACTIONS(5667),
    [anon_sym___local__] = ACTIONS(5667),
    [anon_sym___constant__] = ACTIONS(5667),
    [anon_sym___managed__] = ACTIONS(5667),
    [anon_sym___grid_constant__] = ACTIONS(5667),
    [anon_sym_alignas] = ACTIONS(5667),
    [anon_sym__Alignas] = ACTIONS(5667),
    [anon_sym_COLON] = ACTIONS(5665),
    [anon_sym_QMARK] = ACTIONS(5667),
    [anon_sym_LT_EQ_GT] = ACTIONS(5667),
    [anon_sym_or] = ACTIONS(5667),
    [anon_sym_and] = ACTIONS(5667),
    [anon_sym_bitor] = ACTIONS(5667),
    [anon_sym_xor] = ACTIONS(5667),
    [anon_sym_bitand] = ACTIONS(5667),
    [anon_sym_not_eq] = ACTIONS(5667),
    [anon_sym_DASH_DASH] = ACTIONS(5667),
    [anon_sym_PLUS_PLUS] = ACTIONS(5667),
    [anon_sym_DOT] = ACTIONS(5665),
    [anon_sym_DOT_STAR] = ACTIONS(5667),
    [anon_sym_DASH_GT] = ACTIONS(5667),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5667),
    [anon_sym_decltype] = ACTIONS(5667),
    [anon_sym_final] = ACTIONS(5667),
    [anon_sym_override] = ACTIONS(5667),
    [anon_sym_GT2] = ACTIONS(5667),
    [anon_sym_requires] = ACTIONS(5667),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5667),
  },
  [STATE(2398)] = {
    [sym_string_literal] = STATE(2204),
    [sym_raw_string_literal] = STATE(2204),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6354),
    [anon_sym_COMMA] = ACTIONS(6354),
    [anon_sym_RPAREN] = ACTIONS(6354),
    [anon_sym_LPAREN2] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6352),
    [anon_sym_STAR] = ACTIONS(6352),
    [anon_sym_SLASH] = ACTIONS(6352),
    [anon_sym_PERCENT] = ACTIONS(6352),
    [anon_sym_PIPE_PIPE] = ACTIONS(6354),
    [anon_sym_AMP_AMP] = ACTIONS(6354),
    [anon_sym_PIPE] = ACTIONS(6352),
    [anon_sym_CARET] = ACTIONS(6352),
    [anon_sym_AMP] = ACTIONS(6352),
    [anon_sym_EQ_EQ] = ACTIONS(6354),
    [anon_sym_BANG_EQ] = ACTIONS(6354),
    [anon_sym_GT] = ACTIONS(6352),
    [anon_sym_GT_EQ] = ACTIONS(6354),
    [anon_sym_LT_EQ] = ACTIONS(6352),
    [anon_sym_LT] = ACTIONS(6352),
    [anon_sym_LT_LT] = ACTIONS(6352),
    [anon_sym_GT_GT] = ACTIONS(6352),
    [anon_sym_SEMI] = ACTIONS(6354),
    [anon_sym_RBRACE] = ACTIONS(6354),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [anon_sym_RBRACK] = ACTIONS(6354),
    [anon_sym_EQ] = ACTIONS(6352),
    [anon_sym_COLON] = ACTIONS(6354),
    [anon_sym_QMARK] = ACTIONS(6354),
    [anon_sym_STAR_EQ] = ACTIONS(6354),
    [anon_sym_SLASH_EQ] = ACTIONS(6354),
    [anon_sym_PERCENT_EQ] = ACTIONS(6354),
    [anon_sym_PLUS_EQ] = ACTIONS(6354),
    [anon_sym_DASH_EQ] = ACTIONS(6354),
    [anon_sym_LT_LT_EQ] = ACTIONS(6354),
    [anon_sym_GT_GT_EQ] = ACTIONS(6354),
    [anon_sym_AMP_EQ] = ACTIONS(6354),
    [anon_sym_CARET_EQ] = ACTIONS(6354),
    [anon_sym_PIPE_EQ] = ACTIONS(6354),
    [anon_sym_and_eq] = ACTIONS(6352),
    [anon_sym_or_eq] = ACTIONS(6352),
    [anon_sym_xor_eq] = ACTIONS(6352),
    [anon_sym_LT_EQ_GT] = ACTIONS(6354),
    [anon_sym_or] = ACTIONS(6352),
    [anon_sym_and] = ACTIONS(6352),
    [anon_sym_bitor] = ACTIONS(6352),
    [anon_sym_xor] = ACTIONS(6352),
    [anon_sym_bitand] = ACTIONS(6352),
    [anon_sym_not_eq] = ACTIONS(6352),
    [anon_sym_DASH_DASH] = ACTIONS(6354),
    [anon_sym_PLUS_PLUS] = ACTIONS(6354),
    [anon_sym_DOT] = ACTIONS(6352),
    [anon_sym_DOT_STAR] = ACTIONS(6354),
    [anon_sym_DASH_GT] = ACTIONS(6354),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [sym_literal_suffix] = ACTIONS(6352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6354),
  },
  [STATE(2399)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6415),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2400)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6417),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2401)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6419),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2402)] = {
    [sym_string_literal] = STATE(2410),
    [sym_raw_string_literal] = STATE(2410),
    [aux_sym_concatenated_string_repeat1] = STATE(2410),
    [sym_identifier] = ACTIONS(6421),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6016),
    [anon_sym_COMMA] = ACTIONS(6016),
    [anon_sym_LPAREN2] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6018),
    [anon_sym_STAR] = ACTIONS(6018),
    [anon_sym_SLASH] = ACTIONS(6018),
    [anon_sym_PERCENT] = ACTIONS(6018),
    [anon_sym_PIPE_PIPE] = ACTIONS(6016),
    [anon_sym_AMP_AMP] = ACTIONS(6016),
    [anon_sym_PIPE] = ACTIONS(6018),
    [anon_sym_CARET] = ACTIONS(6018),
    [anon_sym_AMP] = ACTIONS(6018),
    [anon_sym_EQ_EQ] = ACTIONS(6016),
    [anon_sym_BANG_EQ] = ACTIONS(6016),
    [anon_sym_GT] = ACTIONS(6018),
    [anon_sym_GT_EQ] = ACTIONS(6016),
    [anon_sym_LT_EQ] = ACTIONS(6018),
    [anon_sym_LT] = ACTIONS(6018),
    [anon_sym_LT_LT] = ACTIONS(6018),
    [anon_sym_GT_GT] = ACTIONS(6018),
    [anon_sym_SEMI] = ACTIONS(6016),
    [anon_sym___attribute__] = ACTIONS(6018),
    [anon_sym___attribute] = ACTIONS(6018),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [anon_sym_EQ] = ACTIONS(6018),
    [anon_sym_QMARK] = ACTIONS(6016),
    [anon_sym_STAR_EQ] = ACTIONS(6016),
    [anon_sym_SLASH_EQ] = ACTIONS(6016),
    [anon_sym_PERCENT_EQ] = ACTIONS(6016),
    [anon_sym_PLUS_EQ] = ACTIONS(6016),
    [anon_sym_DASH_EQ] = ACTIONS(6016),
    [anon_sym_LT_LT_EQ] = ACTIONS(6016),
    [anon_sym_GT_GT_EQ] = ACTIONS(6016),
    [anon_sym_AMP_EQ] = ACTIONS(6016),
    [anon_sym_CARET_EQ] = ACTIONS(6016),
    [anon_sym_PIPE_EQ] = ACTIONS(6016),
    [anon_sym_and_eq] = ACTIONS(6018),
    [anon_sym_or_eq] = ACTIONS(6018),
    [anon_sym_xor_eq] = ACTIONS(6018),
    [anon_sym_LT_EQ_GT] = ACTIONS(6016),
    [anon_sym_or] = ACTIONS(6018),
    [anon_sym_and] = ACTIONS(6018),
    [anon_sym_bitor] = ACTIONS(6018),
    [anon_sym_xor] = ACTIONS(6018),
    [anon_sym_bitand] = ACTIONS(6018),
    [anon_sym_not_eq] = ACTIONS(6018),
    [anon_sym_DASH_DASH] = ACTIONS(6016),
    [anon_sym_PLUS_PLUS] = ACTIONS(6016),
    [anon_sym_DOT] = ACTIONS(6018),
    [anon_sym_DOT_STAR] = ACTIONS(6016),
    [anon_sym_DASH_GT] = ACTIONS(6016),
    [anon_sym_L_DQUOTE] = ACTIONS(6372),
    [anon_sym_u_DQUOTE] = ACTIONS(6372),
    [anon_sym_U_DQUOTE] = ACTIONS(6372),
    [anon_sym_u8_DQUOTE] = ACTIONS(6372),
    [anon_sym_DQUOTE] = ACTIONS(6372),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6374),
    [anon_sym_LR_DQUOTE] = ACTIONS(6374),
    [anon_sym_uR_DQUOTE] = ACTIONS(6374),
    [anon_sym_UR_DQUOTE] = ACTIONS(6374),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6374),
    [sym_literal_suffix] = ACTIONS(6018),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6016),
  },
  [STATE(2403)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4398),
    [anon_sym_COMMA] = ACTIONS(4398),
    [anon_sym_LPAREN2] = ACTIONS(4398),
    [anon_sym_DASH] = ACTIONS(4396),
    [anon_sym_PLUS] = ACTIONS(4396),
    [anon_sym_STAR] = ACTIONS(4398),
    [anon_sym_SLASH] = ACTIONS(4396),
    [anon_sym_PERCENT] = ACTIONS(4398),
    [anon_sym_PIPE_PIPE] = ACTIONS(4398),
    [anon_sym_AMP_AMP] = ACTIONS(4398),
    [anon_sym_PIPE] = ACTIONS(4396),
    [anon_sym_CARET] = ACTIONS(4398),
    [anon_sym_AMP] = ACTIONS(4396),
    [anon_sym_EQ_EQ] = ACTIONS(4398),
    [anon_sym_BANG_EQ] = ACTIONS(4398),
    [anon_sym_GT] = ACTIONS(4396),
    [anon_sym_GT_EQ] = ACTIONS(4396),
    [anon_sym_LT_EQ] = ACTIONS(4396),
    [anon_sym_LT] = ACTIONS(4396),
    [anon_sym_LT_LT] = ACTIONS(4396),
    [anon_sym_GT_GT] = ACTIONS(4396),
    [anon_sym___extension__] = ACTIONS(4398),
    [anon_sym___global__] = ACTIONS(4398),
    [anon_sym___attribute__] = ACTIONS(4398),
    [anon_sym___attribute] = ACTIONS(4396),
    [anon_sym_COLON_COLON] = ACTIONS(4398),
    [anon_sym_LBRACE] = ACTIONS(4398),
    [anon_sym_LBRACK] = ACTIONS(4398),
    [anon_sym_const] = ACTIONS(4396),
    [anon_sym_constexpr] = ACTIONS(4398),
    [anon_sym_volatile] = ACTIONS(4398),
    [anon_sym_restrict] = ACTIONS(4398),
    [anon_sym___restrict__] = ACTIONS(4398),
    [anon_sym__Atomic] = ACTIONS(4398),
    [anon_sym__Noreturn] = ACTIONS(4398),
    [anon_sym_noreturn] = ACTIONS(4398),
    [anon_sym__Nonnull] = ACTIONS(4398),
    [anon_sym_mutable] = ACTIONS(4398),
    [anon_sym_constinit] = ACTIONS(4398),
    [anon_sym_consteval] = ACTIONS(4398),
    [anon_sym___shared__] = ACTIONS(4398),
    [anon_sym___local__] = ACTIONS(4398),
    [anon_sym___constant__] = ACTIONS(4398),
    [anon_sym___managed__] = ACTIONS(4398),
    [anon_sym___grid_constant__] = ACTIONS(4398),
    [anon_sym_alignas] = ACTIONS(4398),
    [anon_sym__Alignas] = ACTIONS(4398),
    [anon_sym_COLON] = ACTIONS(4396),
    [anon_sym_QMARK] = ACTIONS(4398),
    [anon_sym_LT_EQ_GT] = ACTIONS(4398),
    [anon_sym_or] = ACTIONS(4398),
    [anon_sym_and] = ACTIONS(4398),
    [anon_sym_bitor] = ACTIONS(4398),
    [anon_sym_xor] = ACTIONS(4398),
    [anon_sym_bitand] = ACTIONS(4398),
    [anon_sym_not_eq] = ACTIONS(4398),
    [anon_sym_DASH_DASH] = ACTIONS(4398),
    [anon_sym_PLUS_PLUS] = ACTIONS(4398),
    [anon_sym_DOT] = ACTIONS(4396),
    [anon_sym_DOT_STAR] = ACTIONS(4398),
    [anon_sym_DASH_GT] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4398),
    [anon_sym_decltype] = ACTIONS(4398),
    [anon_sym_final] = ACTIONS(4398),
    [anon_sym_override] = ACTIONS(4398),
    [anon_sym_GT2] = ACTIONS(4398),
    [anon_sym_requires] = ACTIONS(4398),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4398),
  },
  [STATE(2404)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4404),
    [anon_sym_COMMA] = ACTIONS(4404),
    [anon_sym_LPAREN2] = ACTIONS(4404),
    [anon_sym_DASH] = ACTIONS(4402),
    [anon_sym_PLUS] = ACTIONS(4402),
    [anon_sym_STAR] = ACTIONS(4404),
    [anon_sym_SLASH] = ACTIONS(4402),
    [anon_sym_PERCENT] = ACTIONS(4404),
    [anon_sym_PIPE_PIPE] = ACTIONS(4404),
    [anon_sym_AMP_AMP] = ACTIONS(4404),
    [anon_sym_PIPE] = ACTIONS(4402),
    [anon_sym_CARET] = ACTIONS(4404),
    [anon_sym_AMP] = ACTIONS(4402),
    [anon_sym_EQ_EQ] = ACTIONS(4404),
    [anon_sym_BANG_EQ] = ACTIONS(4404),
    [anon_sym_GT] = ACTIONS(4402),
    [anon_sym_GT_EQ] = ACTIONS(4402),
    [anon_sym_LT_EQ] = ACTIONS(4402),
    [anon_sym_LT] = ACTIONS(4402),
    [anon_sym_LT_LT] = ACTIONS(4402),
    [anon_sym_GT_GT] = ACTIONS(4402),
    [anon_sym___extension__] = ACTIONS(4404),
    [anon_sym___global__] = ACTIONS(4404),
    [anon_sym___attribute__] = ACTIONS(4404),
    [anon_sym___attribute] = ACTIONS(4402),
    [anon_sym_COLON_COLON] = ACTIONS(4404),
    [anon_sym_LBRACE] = ACTIONS(4404),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_const] = ACTIONS(4402),
    [anon_sym_constexpr] = ACTIONS(4404),
    [anon_sym_volatile] = ACTIONS(4404),
    [anon_sym_restrict] = ACTIONS(4404),
    [anon_sym___restrict__] = ACTIONS(4404),
    [anon_sym__Atomic] = ACTIONS(4404),
    [anon_sym__Noreturn] = ACTIONS(4404),
    [anon_sym_noreturn] = ACTIONS(4404),
    [anon_sym__Nonnull] = ACTIONS(4404),
    [anon_sym_mutable] = ACTIONS(4404),
    [anon_sym_constinit] = ACTIONS(4404),
    [anon_sym_consteval] = ACTIONS(4404),
    [anon_sym___shared__] = ACTIONS(4404),
    [anon_sym___local__] = ACTIONS(4404),
    [anon_sym___constant__] = ACTIONS(4404),
    [anon_sym___managed__] = ACTIONS(4404),
    [anon_sym___grid_constant__] = ACTIONS(4404),
    [anon_sym_alignas] = ACTIONS(4404),
    [anon_sym__Alignas] = ACTIONS(4404),
    [anon_sym_COLON] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_LT_EQ_GT] = ACTIONS(4404),
    [anon_sym_or] = ACTIONS(4404),
    [anon_sym_and] = ACTIONS(4404),
    [anon_sym_bitor] = ACTIONS(4404),
    [anon_sym_xor] = ACTIONS(4404),
    [anon_sym_bitand] = ACTIONS(4404),
    [anon_sym_not_eq] = ACTIONS(4404),
    [anon_sym_DASH_DASH] = ACTIONS(4404),
    [anon_sym_PLUS_PLUS] = ACTIONS(4404),
    [anon_sym_DOT] = ACTIONS(4402),
    [anon_sym_DOT_STAR] = ACTIONS(4404),
    [anon_sym_DASH_GT] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4404),
    [anon_sym_decltype] = ACTIONS(4404),
    [anon_sym_final] = ACTIONS(4404),
    [anon_sym_override] = ACTIONS(4404),
    [anon_sym_GT2] = ACTIONS(4404),
    [anon_sym_requires] = ACTIONS(4404),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4404),
  },
  [STATE(2405)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4410),
    [anon_sym_COMMA] = ACTIONS(4410),
    [anon_sym_LPAREN2] = ACTIONS(4410),
    [anon_sym_DASH] = ACTIONS(4408),
    [anon_sym_PLUS] = ACTIONS(4408),
    [anon_sym_STAR] = ACTIONS(4410),
    [anon_sym_SLASH] = ACTIONS(4408),
    [anon_sym_PERCENT] = ACTIONS(4410),
    [anon_sym_PIPE_PIPE] = ACTIONS(4410),
    [anon_sym_AMP_AMP] = ACTIONS(4410),
    [anon_sym_PIPE] = ACTIONS(4408),
    [anon_sym_CARET] = ACTIONS(4410),
    [anon_sym_AMP] = ACTIONS(4408),
    [anon_sym_EQ_EQ] = ACTIONS(4410),
    [anon_sym_BANG_EQ] = ACTIONS(4410),
    [anon_sym_GT] = ACTIONS(4408),
    [anon_sym_GT_EQ] = ACTIONS(4408),
    [anon_sym_LT_EQ] = ACTIONS(4408),
    [anon_sym_LT] = ACTIONS(4408),
    [anon_sym_LT_LT] = ACTIONS(4408),
    [anon_sym_GT_GT] = ACTIONS(4408),
    [anon_sym___extension__] = ACTIONS(4410),
    [anon_sym___global__] = ACTIONS(4410),
    [anon_sym___attribute__] = ACTIONS(4410),
    [anon_sym___attribute] = ACTIONS(4408),
    [anon_sym_COLON_COLON] = ACTIONS(4410),
    [anon_sym_LBRACE] = ACTIONS(4410),
    [anon_sym_LBRACK] = ACTIONS(4410),
    [anon_sym_const] = ACTIONS(4408),
    [anon_sym_constexpr] = ACTIONS(4410),
    [anon_sym_volatile] = ACTIONS(4410),
    [anon_sym_restrict] = ACTIONS(4410),
    [anon_sym___restrict__] = ACTIONS(4410),
    [anon_sym__Atomic] = ACTIONS(4410),
    [anon_sym__Noreturn] = ACTIONS(4410),
    [anon_sym_noreturn] = ACTIONS(4410),
    [anon_sym__Nonnull] = ACTIONS(4410),
    [anon_sym_mutable] = ACTIONS(4410),
    [anon_sym_constinit] = ACTIONS(4410),
    [anon_sym_consteval] = ACTIONS(4410),
    [anon_sym___shared__] = ACTIONS(4410),
    [anon_sym___local__] = ACTIONS(4410),
    [anon_sym___constant__] = ACTIONS(4410),
    [anon_sym___managed__] = ACTIONS(4410),
    [anon_sym___grid_constant__] = ACTIONS(4410),
    [anon_sym_alignas] = ACTIONS(4410),
    [anon_sym__Alignas] = ACTIONS(4410),
    [anon_sym_COLON] = ACTIONS(4408),
    [anon_sym_QMARK] = ACTIONS(4410),
    [anon_sym_LT_EQ_GT] = ACTIONS(4410),
    [anon_sym_or] = ACTIONS(4410),
    [anon_sym_and] = ACTIONS(4410),
    [anon_sym_bitor] = ACTIONS(4410),
    [anon_sym_xor] = ACTIONS(4410),
    [anon_sym_bitand] = ACTIONS(4410),
    [anon_sym_not_eq] = ACTIONS(4410),
    [anon_sym_DASH_DASH] = ACTIONS(4410),
    [anon_sym_PLUS_PLUS] = ACTIONS(4410),
    [anon_sym_DOT] = ACTIONS(4408),
    [anon_sym_DOT_STAR] = ACTIONS(4410),
    [anon_sym_DASH_GT] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4410),
    [anon_sym_decltype] = ACTIONS(4410),
    [anon_sym_final] = ACTIONS(4410),
    [anon_sym_override] = ACTIONS(4410),
    [anon_sym_GT2] = ACTIONS(4410),
    [anon_sym_requires] = ACTIONS(4410),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4410),
  },
  [STATE(2406)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4560),
    [anon_sym_COMMA] = ACTIONS(4560),
    [anon_sym_LPAREN2] = ACTIONS(4560),
    [anon_sym_DASH] = ACTIONS(4553),
    [anon_sym_PLUS] = ACTIONS(4553),
    [anon_sym_STAR] = ACTIONS(4560),
    [anon_sym_SLASH] = ACTIONS(4553),
    [anon_sym_PERCENT] = ACTIONS(4560),
    [anon_sym_PIPE_PIPE] = ACTIONS(4560),
    [anon_sym_AMP_AMP] = ACTIONS(4560),
    [anon_sym_PIPE] = ACTIONS(4553),
    [anon_sym_CARET] = ACTIONS(4560),
    [anon_sym_AMP] = ACTIONS(4553),
    [anon_sym_EQ_EQ] = ACTIONS(4560),
    [anon_sym_BANG_EQ] = ACTIONS(4560),
    [anon_sym_GT] = ACTIONS(4553),
    [anon_sym_GT_EQ] = ACTIONS(4553),
    [anon_sym_LT_EQ] = ACTIONS(4553),
    [anon_sym_LT] = ACTIONS(4553),
    [anon_sym_LT_LT] = ACTIONS(4553),
    [anon_sym_GT_GT] = ACTIONS(4553),
    [anon_sym___extension__] = ACTIONS(4560),
    [anon_sym___global__] = ACTIONS(4560),
    [anon_sym___attribute__] = ACTIONS(4560),
    [anon_sym___attribute] = ACTIONS(4553),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4560),
    [anon_sym_const] = ACTIONS(4553),
    [anon_sym_constexpr] = ACTIONS(4560),
    [anon_sym_volatile] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym___restrict__] = ACTIONS(4560),
    [anon_sym__Atomic] = ACTIONS(4560),
    [anon_sym__Noreturn] = ACTIONS(4560),
    [anon_sym_noreturn] = ACTIONS(4560),
    [anon_sym__Nonnull] = ACTIONS(4560),
    [anon_sym_mutable] = ACTIONS(4560),
    [anon_sym_constinit] = ACTIONS(4560),
    [anon_sym_consteval] = ACTIONS(4560),
    [anon_sym___shared__] = ACTIONS(4560),
    [anon_sym___local__] = ACTIONS(4560),
    [anon_sym___constant__] = ACTIONS(4560),
    [anon_sym___managed__] = ACTIONS(4560),
    [anon_sym___grid_constant__] = ACTIONS(4560),
    [anon_sym_alignas] = ACTIONS(4560),
    [anon_sym__Alignas] = ACTIONS(4560),
    [anon_sym_COLON] = ACTIONS(4553),
    [anon_sym_QMARK] = ACTIONS(4560),
    [anon_sym_LT_EQ_GT] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4560),
    [anon_sym_and] = ACTIONS(4560),
    [anon_sym_bitor] = ACTIONS(4560),
    [anon_sym_xor] = ACTIONS(4560),
    [anon_sym_bitand] = ACTIONS(4560),
    [anon_sym_not_eq] = ACTIONS(4560),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_DOT] = ACTIONS(4553),
    [anon_sym_DOT_STAR] = ACTIONS(4560),
    [anon_sym_DASH_GT] = ACTIONS(4560),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4560),
    [anon_sym_decltype] = ACTIONS(4560),
    [anon_sym_final] = ACTIONS(4560),
    [anon_sym_override] = ACTIONS(4560),
    [anon_sym_GT2] = ACTIONS(4560),
    [anon_sym_requires] = ACTIONS(4560),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4560),
  },
  [STATE(2407)] = {
    [sym_attribute_specifier] = STATE(2484),
    [sym_enumerator_list] = STATE(2429),
    [sym_identifier] = ACTIONS(6185),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6183),
    [anon_sym_COMMA] = ACTIONS(6183),
    [anon_sym_RPAREN] = ACTIONS(6183),
    [aux_sym_preproc_if_token2] = ACTIONS(6183),
    [aux_sym_preproc_else_token1] = ACTIONS(6183),
    [aux_sym_preproc_elif_token1] = ACTIONS(6185),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6183),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6183),
    [anon_sym_LPAREN2] = ACTIONS(6183),
    [anon_sym_DASH] = ACTIONS(6185),
    [anon_sym_PLUS] = ACTIONS(6185),
    [anon_sym_STAR] = ACTIONS(6185),
    [anon_sym_SLASH] = ACTIONS(6185),
    [anon_sym_PERCENT] = ACTIONS(6185),
    [anon_sym_PIPE_PIPE] = ACTIONS(6183),
    [anon_sym_AMP_AMP] = ACTIONS(6183),
    [anon_sym_PIPE] = ACTIONS(6185),
    [anon_sym_CARET] = ACTIONS(6185),
    [anon_sym_AMP] = ACTIONS(6185),
    [anon_sym_EQ_EQ] = ACTIONS(6183),
    [anon_sym_BANG_EQ] = ACTIONS(6183),
    [anon_sym_GT] = ACTIONS(6185),
    [anon_sym_GT_EQ] = ACTIONS(6183),
    [anon_sym_LT_EQ] = ACTIONS(6185),
    [anon_sym_LT] = ACTIONS(6185),
    [anon_sym_LT_LT] = ACTIONS(6185),
    [anon_sym_GT_GT] = ACTIONS(6185),
    [anon_sym_SEMI] = ACTIONS(6183),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6399),
    [anon_sym_RBRACE] = ACTIONS(6183),
    [anon_sym_LBRACK] = ACTIONS(6183),
    [anon_sym_RBRACK] = ACTIONS(6183),
    [anon_sym_EQ] = ACTIONS(6185),
    [anon_sym_COLON] = ACTIONS(6183),
    [anon_sym_QMARK] = ACTIONS(6183),
    [anon_sym_STAR_EQ] = ACTIONS(6183),
    [anon_sym_SLASH_EQ] = ACTIONS(6183),
    [anon_sym_PERCENT_EQ] = ACTIONS(6183),
    [anon_sym_PLUS_EQ] = ACTIONS(6183),
    [anon_sym_DASH_EQ] = ACTIONS(6183),
    [anon_sym_LT_LT_EQ] = ACTIONS(6183),
    [anon_sym_GT_GT_EQ] = ACTIONS(6183),
    [anon_sym_AMP_EQ] = ACTIONS(6183),
    [anon_sym_CARET_EQ] = ACTIONS(6183),
    [anon_sym_PIPE_EQ] = ACTIONS(6183),
    [anon_sym_and_eq] = ACTIONS(6185),
    [anon_sym_or_eq] = ACTIONS(6185),
    [anon_sym_xor_eq] = ACTIONS(6185),
    [anon_sym_LT_EQ_GT] = ACTIONS(6183),
    [anon_sym_or] = ACTIONS(6185),
    [anon_sym_and] = ACTIONS(6185),
    [anon_sym_bitor] = ACTIONS(6185),
    [anon_sym_xor] = ACTIONS(6185),
    [anon_sym_bitand] = ACTIONS(6185),
    [anon_sym_not_eq] = ACTIONS(6185),
    [anon_sym_DASH_DASH] = ACTIONS(6183),
    [anon_sym_PLUS_PLUS] = ACTIONS(6183),
    [anon_sym_DOT] = ACTIONS(6185),
    [anon_sym_DOT_STAR] = ACTIONS(6183),
    [anon_sym_DASH_GT] = ACTIONS(6183),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6185),
    [anon_sym_decltype] = ACTIONS(6185),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6183),
  },
  [STATE(2408)] = {
    [sym_attribute_specifier] = STATE(2476),
    [sym_enumerator_list] = STATE(2450),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6183),
    [anon_sym_COMMA] = ACTIONS(6183),
    [anon_sym_LPAREN2] = ACTIONS(6183),
    [anon_sym_DASH] = ACTIONS(6185),
    [anon_sym_PLUS] = ACTIONS(6185),
    [anon_sym_STAR] = ACTIONS(6183),
    [anon_sym_SLASH] = ACTIONS(6185),
    [anon_sym_PERCENT] = ACTIONS(6183),
    [anon_sym_PIPE_PIPE] = ACTIONS(6183),
    [anon_sym_AMP_AMP] = ACTIONS(6183),
    [anon_sym_PIPE] = ACTIONS(6185),
    [anon_sym_CARET] = ACTIONS(6183),
    [anon_sym_AMP] = ACTIONS(6185),
    [anon_sym_EQ_EQ] = ACTIONS(6183),
    [anon_sym_BANG_EQ] = ACTIONS(6183),
    [anon_sym_GT] = ACTIONS(6185),
    [anon_sym_GT_EQ] = ACTIONS(6185),
    [anon_sym_LT_EQ] = ACTIONS(6185),
    [anon_sym_LT] = ACTIONS(6185),
    [anon_sym_LT_LT] = ACTIONS(6185),
    [anon_sym_GT_GT] = ACTIONS(6185),
    [anon_sym___extension__] = ACTIONS(6183),
    [anon_sym___global__] = ACTIONS(6183),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6362),
    [anon_sym_LBRACK] = ACTIONS(6183),
    [anon_sym_const] = ACTIONS(6185),
    [anon_sym_constexpr] = ACTIONS(6183),
    [anon_sym_volatile] = ACTIONS(6183),
    [anon_sym_restrict] = ACTIONS(6183),
    [anon_sym___restrict__] = ACTIONS(6183),
    [anon_sym__Atomic] = ACTIONS(6183),
    [anon_sym__Noreturn] = ACTIONS(6183),
    [anon_sym_noreturn] = ACTIONS(6183),
    [anon_sym__Nonnull] = ACTIONS(6183),
    [anon_sym_mutable] = ACTIONS(6183),
    [anon_sym_constinit] = ACTIONS(6183),
    [anon_sym_consteval] = ACTIONS(6183),
    [anon_sym___shared__] = ACTIONS(6183),
    [anon_sym___local__] = ACTIONS(6183),
    [anon_sym___constant__] = ACTIONS(6183),
    [anon_sym___managed__] = ACTIONS(6183),
    [anon_sym___grid_constant__] = ACTIONS(6183),
    [anon_sym_alignas] = ACTIONS(6183),
    [anon_sym__Alignas] = ACTIONS(6183),
    [anon_sym_QMARK] = ACTIONS(6183),
    [anon_sym_LT_EQ_GT] = ACTIONS(6183),
    [anon_sym_or] = ACTIONS(6183),
    [anon_sym_and] = ACTIONS(6183),
    [anon_sym_bitor] = ACTIONS(6183),
    [anon_sym_xor] = ACTIONS(6183),
    [anon_sym_bitand] = ACTIONS(6183),
    [anon_sym_not_eq] = ACTIONS(6183),
    [anon_sym_DASH_DASH] = ACTIONS(6183),
    [anon_sym_PLUS_PLUS] = ACTIONS(6183),
    [anon_sym_DOT] = ACTIONS(6185),
    [anon_sym_DOT_STAR] = ACTIONS(6183),
    [anon_sym_DASH_GT] = ACTIONS(6183),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6183),
    [anon_sym_decltype] = ACTIONS(6183),
    [anon_sym_final] = ACTIONS(6183),
    [anon_sym_override] = ACTIONS(6183),
    [anon_sym_GT2] = ACTIONS(6183),
    [anon_sym_requires] = ACTIONS(6183),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6183),
  },
  [STATE(2409)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [aux_sym_preproc_if_token2] = ACTIONS(5661),
    [aux_sym_preproc_else_token1] = ACTIONS(5661),
    [aux_sym_preproc_elif_token1] = ACTIONS(5659),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5661),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5659),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5659),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5659),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5659),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_RBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_RBRACK] = ACTIONS(5661),
    [anon_sym_EQ] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5661),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_STAR_EQ] = ACTIONS(5661),
    [anon_sym_SLASH_EQ] = ACTIONS(5661),
    [anon_sym_PERCENT_EQ] = ACTIONS(5661),
    [anon_sym_PLUS_EQ] = ACTIONS(5661),
    [anon_sym_DASH_EQ] = ACTIONS(5661),
    [anon_sym_LT_LT_EQ] = ACTIONS(5661),
    [anon_sym_GT_GT_EQ] = ACTIONS(5661),
    [anon_sym_AMP_EQ] = ACTIONS(5661),
    [anon_sym_CARET_EQ] = ACTIONS(5661),
    [anon_sym_PIPE_EQ] = ACTIONS(5661),
    [anon_sym_and_eq] = ACTIONS(5659),
    [anon_sym_or_eq] = ACTIONS(5659),
    [anon_sym_xor_eq] = ACTIONS(5659),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_bitor] = ACTIONS(5659),
    [anon_sym_xor] = ACTIONS(5659),
    [anon_sym_bitand] = ACTIONS(5659),
    [anon_sym_not_eq] = ACTIONS(5659),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(2410)] = {
    [sym_string_literal] = STATE(2410),
    [sym_raw_string_literal] = STATE(2410),
    [aux_sym_concatenated_string_repeat1] = STATE(2410),
    [sym_identifier] = ACTIONS(6423),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5882),
    [anon_sym_COMMA] = ACTIONS(5882),
    [anon_sym_LPAREN2] = ACTIONS(5882),
    [anon_sym_DASH] = ACTIONS(5884),
    [anon_sym_PLUS] = ACTIONS(5884),
    [anon_sym_STAR] = ACTIONS(5884),
    [anon_sym_SLASH] = ACTIONS(5884),
    [anon_sym_PERCENT] = ACTIONS(5884),
    [anon_sym_PIPE_PIPE] = ACTIONS(5882),
    [anon_sym_AMP_AMP] = ACTIONS(5882),
    [anon_sym_PIPE] = ACTIONS(5884),
    [anon_sym_CARET] = ACTIONS(5884),
    [anon_sym_AMP] = ACTIONS(5884),
    [anon_sym_EQ_EQ] = ACTIONS(5882),
    [anon_sym_BANG_EQ] = ACTIONS(5882),
    [anon_sym_GT] = ACTIONS(5884),
    [anon_sym_GT_EQ] = ACTIONS(5882),
    [anon_sym_LT_EQ] = ACTIONS(5884),
    [anon_sym_LT] = ACTIONS(5884),
    [anon_sym_LT_LT] = ACTIONS(5884),
    [anon_sym_GT_GT] = ACTIONS(5884),
    [anon_sym_SEMI] = ACTIONS(5882),
    [anon_sym___attribute__] = ACTIONS(5884),
    [anon_sym___attribute] = ACTIONS(5884),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_EQ] = ACTIONS(5884),
    [anon_sym_QMARK] = ACTIONS(5882),
    [anon_sym_STAR_EQ] = ACTIONS(5882),
    [anon_sym_SLASH_EQ] = ACTIONS(5882),
    [anon_sym_PERCENT_EQ] = ACTIONS(5882),
    [anon_sym_PLUS_EQ] = ACTIONS(5882),
    [anon_sym_DASH_EQ] = ACTIONS(5882),
    [anon_sym_LT_LT_EQ] = ACTIONS(5882),
    [anon_sym_GT_GT_EQ] = ACTIONS(5882),
    [anon_sym_AMP_EQ] = ACTIONS(5882),
    [anon_sym_CARET_EQ] = ACTIONS(5882),
    [anon_sym_PIPE_EQ] = ACTIONS(5882),
    [anon_sym_and_eq] = ACTIONS(5884),
    [anon_sym_or_eq] = ACTIONS(5884),
    [anon_sym_xor_eq] = ACTIONS(5884),
    [anon_sym_LT_EQ_GT] = ACTIONS(5882),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_bitor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_bitand] = ACTIONS(5884),
    [anon_sym_not_eq] = ACTIONS(5884),
    [anon_sym_DASH_DASH] = ACTIONS(5882),
    [anon_sym_PLUS_PLUS] = ACTIONS(5882),
    [anon_sym_DOT] = ACTIONS(5884),
    [anon_sym_DOT_STAR] = ACTIONS(5882),
    [anon_sym_DASH_GT] = ACTIONS(5882),
    [anon_sym_L_DQUOTE] = ACTIONS(6426),
    [anon_sym_u_DQUOTE] = ACTIONS(6426),
    [anon_sym_U_DQUOTE] = ACTIONS(6426),
    [anon_sym_u8_DQUOTE] = ACTIONS(6426),
    [anon_sym_DQUOTE] = ACTIONS(6426),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6429),
    [anon_sym_LR_DQUOTE] = ACTIONS(6429),
    [anon_sym_uR_DQUOTE] = ACTIONS(6429),
    [anon_sym_UR_DQUOTE] = ACTIONS(6429),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6429),
    [sym_literal_suffix] = ACTIONS(5884),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5882),
  },
  [STATE(2411)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4352),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_LPAREN2] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(4350),
    [anon_sym_PLUS] = ACTIONS(4350),
    [anon_sym_STAR] = ACTIONS(4352),
    [anon_sym_SLASH] = ACTIONS(4350),
    [anon_sym_PERCENT] = ACTIONS(4352),
    [anon_sym_PIPE_PIPE] = ACTIONS(4352),
    [anon_sym_AMP_AMP] = ACTIONS(4352),
    [anon_sym_PIPE] = ACTIONS(4350),
    [anon_sym_CARET] = ACTIONS(4352),
    [anon_sym_AMP] = ACTIONS(4350),
    [anon_sym_EQ_EQ] = ACTIONS(4352),
    [anon_sym_BANG_EQ] = ACTIONS(4352),
    [anon_sym_GT] = ACTIONS(4350),
    [anon_sym_GT_EQ] = ACTIONS(4350),
    [anon_sym_LT_EQ] = ACTIONS(4350),
    [anon_sym_LT] = ACTIONS(4350),
    [anon_sym_LT_LT] = ACTIONS(4350),
    [anon_sym_GT_GT] = ACTIONS(4350),
    [anon_sym___extension__] = ACTIONS(4352),
    [anon_sym___global__] = ACTIONS(4352),
    [anon_sym___attribute__] = ACTIONS(4352),
    [anon_sym___attribute] = ACTIONS(4350),
    [anon_sym_COLON_COLON] = ACTIONS(4352),
    [anon_sym_LBRACE] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4352),
    [anon_sym_const] = ACTIONS(4350),
    [anon_sym_constexpr] = ACTIONS(4352),
    [anon_sym_volatile] = ACTIONS(4352),
    [anon_sym_restrict] = ACTIONS(4352),
    [anon_sym___restrict__] = ACTIONS(4352),
    [anon_sym__Atomic] = ACTIONS(4352),
    [anon_sym__Noreturn] = ACTIONS(4352),
    [anon_sym_noreturn] = ACTIONS(4352),
    [anon_sym__Nonnull] = ACTIONS(4352),
    [anon_sym_mutable] = ACTIONS(4352),
    [anon_sym_constinit] = ACTIONS(4352),
    [anon_sym_consteval] = ACTIONS(4352),
    [anon_sym___shared__] = ACTIONS(4352),
    [anon_sym___local__] = ACTIONS(4352),
    [anon_sym___constant__] = ACTIONS(4352),
    [anon_sym___managed__] = ACTIONS(4352),
    [anon_sym___grid_constant__] = ACTIONS(4352),
    [anon_sym_alignas] = ACTIONS(4352),
    [anon_sym__Alignas] = ACTIONS(4352),
    [anon_sym_COLON] = ACTIONS(4350),
    [anon_sym_QMARK] = ACTIONS(4352),
    [anon_sym_LT_EQ_GT] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4352),
    [anon_sym_and] = ACTIONS(4352),
    [anon_sym_bitor] = ACTIONS(4352),
    [anon_sym_xor] = ACTIONS(4352),
    [anon_sym_bitand] = ACTIONS(4352),
    [anon_sym_not_eq] = ACTIONS(4352),
    [anon_sym_DASH_DASH] = ACTIONS(4352),
    [anon_sym_PLUS_PLUS] = ACTIONS(4352),
    [anon_sym_DOT] = ACTIONS(4350),
    [anon_sym_DOT_STAR] = ACTIONS(4352),
    [anon_sym_DASH_GT] = ACTIONS(4352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4352),
    [anon_sym_decltype] = ACTIONS(4352),
    [anon_sym_final] = ACTIONS(4352),
    [anon_sym_override] = ACTIONS(4352),
    [anon_sym_GT2] = ACTIONS(4352),
    [anon_sym_requires] = ACTIONS(4352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4352),
  },
  [STATE(2412)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4358),
    [anon_sym_COMMA] = ACTIONS(4358),
    [anon_sym_LPAREN2] = ACTIONS(4358),
    [anon_sym_DASH] = ACTIONS(4356),
    [anon_sym_PLUS] = ACTIONS(4356),
    [anon_sym_STAR] = ACTIONS(4358),
    [anon_sym_SLASH] = ACTIONS(4356),
    [anon_sym_PERCENT] = ACTIONS(4358),
    [anon_sym_PIPE_PIPE] = ACTIONS(4358),
    [anon_sym_AMP_AMP] = ACTIONS(4358),
    [anon_sym_PIPE] = ACTIONS(4356),
    [anon_sym_CARET] = ACTIONS(4358),
    [anon_sym_AMP] = ACTIONS(4356),
    [anon_sym_EQ_EQ] = ACTIONS(4358),
    [anon_sym_BANG_EQ] = ACTIONS(4358),
    [anon_sym_GT] = ACTIONS(4356),
    [anon_sym_GT_EQ] = ACTIONS(4356),
    [anon_sym_LT_EQ] = ACTIONS(4356),
    [anon_sym_LT] = ACTIONS(4356),
    [anon_sym_LT_LT] = ACTIONS(4356),
    [anon_sym_GT_GT] = ACTIONS(4356),
    [anon_sym___extension__] = ACTIONS(4358),
    [anon_sym___global__] = ACTIONS(4358),
    [anon_sym___attribute__] = ACTIONS(4358),
    [anon_sym___attribute] = ACTIONS(4356),
    [anon_sym_COLON_COLON] = ACTIONS(4358),
    [anon_sym_LBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4358),
    [anon_sym_const] = ACTIONS(4356),
    [anon_sym_constexpr] = ACTIONS(4358),
    [anon_sym_volatile] = ACTIONS(4358),
    [anon_sym_restrict] = ACTIONS(4358),
    [anon_sym___restrict__] = ACTIONS(4358),
    [anon_sym__Atomic] = ACTIONS(4358),
    [anon_sym__Noreturn] = ACTIONS(4358),
    [anon_sym_noreturn] = ACTIONS(4358),
    [anon_sym__Nonnull] = ACTIONS(4358),
    [anon_sym_mutable] = ACTIONS(4358),
    [anon_sym_constinit] = ACTIONS(4358),
    [anon_sym_consteval] = ACTIONS(4358),
    [anon_sym___shared__] = ACTIONS(4358),
    [anon_sym___local__] = ACTIONS(4358),
    [anon_sym___constant__] = ACTIONS(4358),
    [anon_sym___managed__] = ACTIONS(4358),
    [anon_sym___grid_constant__] = ACTIONS(4358),
    [anon_sym_alignas] = ACTIONS(4358),
    [anon_sym__Alignas] = ACTIONS(4358),
    [anon_sym_COLON] = ACTIONS(4356),
    [anon_sym_QMARK] = ACTIONS(4358),
    [anon_sym_LT_EQ_GT] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4358),
    [anon_sym_and] = ACTIONS(4358),
    [anon_sym_bitor] = ACTIONS(4358),
    [anon_sym_xor] = ACTIONS(4358),
    [anon_sym_bitand] = ACTIONS(4358),
    [anon_sym_not_eq] = ACTIONS(4358),
    [anon_sym_DASH_DASH] = ACTIONS(4358),
    [anon_sym_PLUS_PLUS] = ACTIONS(4358),
    [anon_sym_DOT] = ACTIONS(4356),
    [anon_sym_DOT_STAR] = ACTIONS(4358),
    [anon_sym_DASH_GT] = ACTIONS(4358),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4358),
    [anon_sym_decltype] = ACTIONS(4358),
    [anon_sym_final] = ACTIONS(4358),
    [anon_sym_override] = ACTIONS(4358),
    [anon_sym_GT2] = ACTIONS(4358),
    [anon_sym_requires] = ACTIONS(4358),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4358),
  },
  [STATE(2413)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4368),
    [anon_sym_COMMA] = ACTIONS(4368),
    [anon_sym_LPAREN2] = ACTIONS(4368),
    [anon_sym_DASH] = ACTIONS(4366),
    [anon_sym_PLUS] = ACTIONS(4366),
    [anon_sym_STAR] = ACTIONS(4368),
    [anon_sym_SLASH] = ACTIONS(4366),
    [anon_sym_PERCENT] = ACTIONS(4368),
    [anon_sym_PIPE_PIPE] = ACTIONS(4368),
    [anon_sym_AMP_AMP] = ACTIONS(4368),
    [anon_sym_PIPE] = ACTIONS(4366),
    [anon_sym_CARET] = ACTIONS(4368),
    [anon_sym_AMP] = ACTIONS(4366),
    [anon_sym_EQ_EQ] = ACTIONS(4368),
    [anon_sym_BANG_EQ] = ACTIONS(4368),
    [anon_sym_GT] = ACTIONS(4366),
    [anon_sym_GT_EQ] = ACTIONS(4366),
    [anon_sym_LT_EQ] = ACTIONS(4366),
    [anon_sym_LT] = ACTIONS(4366),
    [anon_sym_LT_LT] = ACTIONS(4366),
    [anon_sym_GT_GT] = ACTIONS(4366),
    [anon_sym___extension__] = ACTIONS(4368),
    [anon_sym___global__] = ACTIONS(4368),
    [anon_sym___attribute__] = ACTIONS(4368),
    [anon_sym___attribute] = ACTIONS(4366),
    [anon_sym_COLON_COLON] = ACTIONS(4368),
    [anon_sym_LBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4368),
    [anon_sym_const] = ACTIONS(4366),
    [anon_sym_constexpr] = ACTIONS(4368),
    [anon_sym_volatile] = ACTIONS(4368),
    [anon_sym_restrict] = ACTIONS(4368),
    [anon_sym___restrict__] = ACTIONS(4368),
    [anon_sym__Atomic] = ACTIONS(4368),
    [anon_sym__Noreturn] = ACTIONS(4368),
    [anon_sym_noreturn] = ACTIONS(4368),
    [anon_sym__Nonnull] = ACTIONS(4368),
    [anon_sym_mutable] = ACTIONS(4368),
    [anon_sym_constinit] = ACTIONS(4368),
    [anon_sym_consteval] = ACTIONS(4368),
    [anon_sym___shared__] = ACTIONS(4368),
    [anon_sym___local__] = ACTIONS(4368),
    [anon_sym___constant__] = ACTIONS(4368),
    [anon_sym___managed__] = ACTIONS(4368),
    [anon_sym___grid_constant__] = ACTIONS(4368),
    [anon_sym_alignas] = ACTIONS(4368),
    [anon_sym__Alignas] = ACTIONS(4368),
    [anon_sym_COLON] = ACTIONS(4366),
    [anon_sym_QMARK] = ACTIONS(4368),
    [anon_sym_LT_EQ_GT] = ACTIONS(4368),
    [anon_sym_or] = ACTIONS(4368),
    [anon_sym_and] = ACTIONS(4368),
    [anon_sym_bitor] = ACTIONS(4368),
    [anon_sym_xor] = ACTIONS(4368),
    [anon_sym_bitand] = ACTIONS(4368),
    [anon_sym_not_eq] = ACTIONS(4368),
    [anon_sym_DASH_DASH] = ACTIONS(4368),
    [anon_sym_PLUS_PLUS] = ACTIONS(4368),
    [anon_sym_DOT] = ACTIONS(4366),
    [anon_sym_DOT_STAR] = ACTIONS(4368),
    [anon_sym_DASH_GT] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4368),
    [anon_sym_decltype] = ACTIONS(4368),
    [anon_sym_final] = ACTIONS(4368),
    [anon_sym_override] = ACTIONS(4368),
    [anon_sym_GT2] = ACTIONS(4368),
    [anon_sym_requires] = ACTIONS(4368),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4368),
  },
  [STATE(2414)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6432),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2415)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2510),
    [sym_virtual_specifier] = STATE(7605),
    [sym_base_class_clause] = STATE(8243),
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_TILDE] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6434),
    [anon_sym___extension__] = ACTIONS(6038),
    [anon_sym___device__] = ACTIONS(6038),
    [anon_sym___host__] = ACTIONS(6038),
    [anon_sym___global__] = ACTIONS(6038),
    [anon_sym___forceinline__] = ACTIONS(6038),
    [anon_sym___noinline__] = ACTIONS(6038),
    [anon_sym_virtual] = ACTIONS(6038),
    [anon_sym_extern] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6036),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6038),
    [anon_sym___based] = ACTIONS(6038),
    [anon_sym___cdecl] = ACTIONS(6038),
    [anon_sym___clrcall] = ACTIONS(6038),
    [anon_sym___stdcall] = ACTIONS(6038),
    [anon_sym___fastcall] = ACTIONS(6038),
    [anon_sym___thiscall] = ACTIONS(6038),
    [anon_sym___vectorcall] = ACTIONS(6038),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6038),
    [anon_sym_register] = ACTIONS(6038),
    [anon_sym_inline] = ACTIONS(6038),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6038),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6038),
    [anon_sym___thread] = ACTIONS(6038),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6038),
    [anon_sym_volatile] = ACTIONS(6038),
    [anon_sym_restrict] = ACTIONS(6038),
    [anon_sym___restrict__] = ACTIONS(6038),
    [anon_sym__Atomic] = ACTIONS(6038),
    [anon_sym__Noreturn] = ACTIONS(6038),
    [anon_sym_noreturn] = ACTIONS(6038),
    [anon_sym__Nonnull] = ACTIONS(6038),
    [anon_sym_mutable] = ACTIONS(6038),
    [anon_sym_constinit] = ACTIONS(6038),
    [anon_sym_consteval] = ACTIONS(6038),
    [anon_sym___shared__] = ACTIONS(6038),
    [anon_sym___local__] = ACTIONS(6038),
    [anon_sym___constant__] = ACTIONS(6038),
    [anon_sym___managed__] = ACTIONS(6038),
    [anon_sym___grid_constant__] = ACTIONS(6038),
    [anon_sym_alignas] = ACTIONS(6038),
    [anon_sym__Alignas] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6038),
    [anon_sym_decltype] = ACTIONS(6038),
    [anon_sym_final] = ACTIONS(6151),
    [anon_sym_override] = ACTIONS(6151),
    [anon_sym_template] = ACTIONS(6038),
    [anon_sym_operator] = ACTIONS(6038),
    [anon_sym___launch_bounds__] = ACTIONS(6038),
  },
  [STATE(2416)] = {
    [sym_attribute_specifier] = STATE(2251),
    [sym_enumerator_list] = STATE(2517),
    [sym_identifier] = ACTIONS(6179),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6177),
    [anon_sym_COMMA] = ACTIONS(6177),
    [anon_sym_RPAREN] = ACTIONS(6177),
    [anon_sym_LPAREN2] = ACTIONS(6177),
    [anon_sym_TILDE] = ACTIONS(6177),
    [anon_sym_STAR] = ACTIONS(6177),
    [anon_sym_AMP_AMP] = ACTIONS(6177),
    [anon_sym_AMP] = ACTIONS(6179),
    [anon_sym_SEMI] = ACTIONS(6177),
    [anon_sym___extension__] = ACTIONS(6179),
    [anon_sym___device__] = ACTIONS(6179),
    [anon_sym___host__] = ACTIONS(6179),
    [anon_sym___global__] = ACTIONS(6179),
    [anon_sym___forceinline__] = ACTIONS(6179),
    [anon_sym___noinline__] = ACTIONS(6179),
    [anon_sym_virtual] = ACTIONS(6179),
    [anon_sym_extern] = ACTIONS(6179),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6177),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6177),
    [anon_sym___declspec] = ACTIONS(6179),
    [anon_sym___based] = ACTIONS(6179),
    [anon_sym___cdecl] = ACTIONS(6179),
    [anon_sym___clrcall] = ACTIONS(6179),
    [anon_sym___stdcall] = ACTIONS(6179),
    [anon_sym___fastcall] = ACTIONS(6179),
    [anon_sym___thiscall] = ACTIONS(6179),
    [anon_sym___vectorcall] = ACTIONS(6179),
    [anon_sym_LBRACE] = ACTIONS(6360),
    [anon_sym_LBRACK] = ACTIONS(6179),
    [anon_sym_static] = ACTIONS(6179),
    [anon_sym_EQ] = ACTIONS(6177),
    [anon_sym_register] = ACTIONS(6179),
    [anon_sym_inline] = ACTIONS(6179),
    [anon_sym___inline] = ACTIONS(6179),
    [anon_sym___inline__] = ACTIONS(6179),
    [anon_sym___forceinline] = ACTIONS(6179),
    [anon_sym_thread_local] = ACTIONS(6179),
    [anon_sym___thread] = ACTIONS(6179),
    [anon_sym_const] = ACTIONS(6179),
    [anon_sym_constexpr] = ACTIONS(6179),
    [anon_sym_volatile] = ACTIONS(6179),
    [anon_sym_restrict] = ACTIONS(6179),
    [anon_sym___restrict__] = ACTIONS(6179),
    [anon_sym__Atomic] = ACTIONS(6179),
    [anon_sym__Noreturn] = ACTIONS(6179),
    [anon_sym_noreturn] = ACTIONS(6179),
    [anon_sym__Nonnull] = ACTIONS(6179),
    [anon_sym_mutable] = ACTIONS(6179),
    [anon_sym_constinit] = ACTIONS(6179),
    [anon_sym_consteval] = ACTIONS(6179),
    [anon_sym___shared__] = ACTIONS(6179),
    [anon_sym___local__] = ACTIONS(6179),
    [anon_sym___constant__] = ACTIONS(6179),
    [anon_sym___managed__] = ACTIONS(6179),
    [anon_sym___grid_constant__] = ACTIONS(6179),
    [anon_sym_alignas] = ACTIONS(6179),
    [anon_sym__Alignas] = ACTIONS(6179),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6179),
    [anon_sym_decltype] = ACTIONS(6179),
    [anon_sym_template] = ACTIONS(6179),
    [anon_sym_GT2] = ACTIONS(6177),
    [anon_sym_operator] = ACTIONS(6179),
    [anon_sym___launch_bounds__] = ACTIONS(6179),
  },
  [STATE(2417)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_RBRACE] = ACTIONS(4004),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_COLON] = ACTIONS(6436),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2418)] = {
    [sym_attribute_specifier] = STATE(2554),
    [sym_identifier] = ACTIONS(6264),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6262),
    [anon_sym_COMMA] = ACTIONS(6262),
    [anon_sym_RPAREN] = ACTIONS(6262),
    [aux_sym_preproc_if_token2] = ACTIONS(6262),
    [aux_sym_preproc_else_token1] = ACTIONS(6262),
    [aux_sym_preproc_elif_token1] = ACTIONS(6264),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6262),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6262),
    [anon_sym_LPAREN2] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6264),
    [anon_sym_STAR] = ACTIONS(6264),
    [anon_sym_SLASH] = ACTIONS(6264),
    [anon_sym_PERCENT] = ACTIONS(6264),
    [anon_sym_PIPE_PIPE] = ACTIONS(6262),
    [anon_sym_AMP_AMP] = ACTIONS(6262),
    [anon_sym_PIPE] = ACTIONS(6264),
    [anon_sym_CARET] = ACTIONS(6264),
    [anon_sym_AMP] = ACTIONS(6264),
    [anon_sym_EQ_EQ] = ACTIONS(6262),
    [anon_sym_BANG_EQ] = ACTIONS(6262),
    [anon_sym_GT] = ACTIONS(6264),
    [anon_sym_GT_EQ] = ACTIONS(6262),
    [anon_sym_LT_EQ] = ACTIONS(6264),
    [anon_sym_LT] = ACTIONS(6264),
    [anon_sym_LT_LT] = ACTIONS(6264),
    [anon_sym_GT_GT] = ACTIONS(6264),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6262),
    [anon_sym_RBRACE] = ACTIONS(6262),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [anon_sym_RBRACK] = ACTIONS(6262),
    [anon_sym_EQ] = ACTIONS(6264),
    [anon_sym_COLON] = ACTIONS(6262),
    [anon_sym_QMARK] = ACTIONS(6262),
    [anon_sym_STAR_EQ] = ACTIONS(6262),
    [anon_sym_SLASH_EQ] = ACTIONS(6262),
    [anon_sym_PERCENT_EQ] = ACTIONS(6262),
    [anon_sym_PLUS_EQ] = ACTIONS(6262),
    [anon_sym_DASH_EQ] = ACTIONS(6262),
    [anon_sym_LT_LT_EQ] = ACTIONS(6262),
    [anon_sym_GT_GT_EQ] = ACTIONS(6262),
    [anon_sym_AMP_EQ] = ACTIONS(6262),
    [anon_sym_CARET_EQ] = ACTIONS(6262),
    [anon_sym_PIPE_EQ] = ACTIONS(6262),
    [anon_sym_and_eq] = ACTIONS(6264),
    [anon_sym_or_eq] = ACTIONS(6264),
    [anon_sym_xor_eq] = ACTIONS(6264),
    [anon_sym_LT_EQ_GT] = ACTIONS(6262),
    [anon_sym_or] = ACTIONS(6264),
    [anon_sym_and] = ACTIONS(6264),
    [anon_sym_bitor] = ACTIONS(6264),
    [anon_sym_xor] = ACTIONS(6264),
    [anon_sym_bitand] = ACTIONS(6264),
    [anon_sym_not_eq] = ACTIONS(6264),
    [anon_sym_DASH_DASH] = ACTIONS(6262),
    [anon_sym_PLUS_PLUS] = ACTIONS(6262),
    [anon_sym_DOT] = ACTIONS(6264),
    [anon_sym_DOT_STAR] = ACTIONS(6262),
    [anon_sym_DASH_GT] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6264),
    [anon_sym_decltype] = ACTIONS(6264),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6262),
  },
  [STATE(2419)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5659),
    [anon_sym_PLUS] = ACTIONS(5659),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_SLASH] = ACTIONS(5659),
    [anon_sym_PERCENT] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5659),
    [anon_sym_CARET] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5659),
    [anon_sym_GT_EQ] = ACTIONS(5659),
    [anon_sym_LT_EQ] = ACTIONS(5659),
    [anon_sym_LT] = ACTIONS(5659),
    [anon_sym_LT_LT] = ACTIONS(5659),
    [anon_sym_GT_GT] = ACTIONS(5659),
    [anon_sym___extension__] = ACTIONS(5661),
    [anon_sym___global__] = ACTIONS(5661),
    [anon_sym___attribute__] = ACTIONS(5661),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5661),
    [anon_sym_volatile] = ACTIONS(5661),
    [anon_sym_restrict] = ACTIONS(5661),
    [anon_sym___restrict__] = ACTIONS(5661),
    [anon_sym__Atomic] = ACTIONS(5661),
    [anon_sym__Noreturn] = ACTIONS(5661),
    [anon_sym_noreturn] = ACTIONS(5661),
    [anon_sym__Nonnull] = ACTIONS(5661),
    [anon_sym_mutable] = ACTIONS(5661),
    [anon_sym_constinit] = ACTIONS(5661),
    [anon_sym_consteval] = ACTIONS(5661),
    [anon_sym___shared__] = ACTIONS(5661),
    [anon_sym___local__] = ACTIONS(5661),
    [anon_sym___constant__] = ACTIONS(5661),
    [anon_sym___managed__] = ACTIONS(5661),
    [anon_sym___grid_constant__] = ACTIONS(5661),
    [anon_sym_alignas] = ACTIONS(5661),
    [anon_sym__Alignas] = ACTIONS(5661),
    [anon_sym_COLON] = ACTIONS(5661),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5661),
    [anon_sym_and] = ACTIONS(5661),
    [anon_sym_bitor] = ACTIONS(5661),
    [anon_sym_xor] = ACTIONS(5661),
    [anon_sym_bitand] = ACTIONS(5661),
    [anon_sym_not_eq] = ACTIONS(5661),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5659),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5661),
    [anon_sym_decltype] = ACTIONS(5661),
    [anon_sym_final] = ACTIONS(5661),
    [anon_sym_override] = ACTIONS(5661),
    [anon_sym_GT2] = ACTIONS(5661),
    [anon_sym_requires] = ACTIONS(5661),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5661),
  },
  [STATE(2420)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_COLON] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2421)] = {
    [sym_attribute_declaration] = STATE(2587),
    [sym_parameter_list] = STATE(2589),
    [aux_sym_attributed_declarator_repeat1] = STATE(2587),
    [sym_identifier] = ACTIONS(6438),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6440),
    [anon_sym_COMMA] = ACTIONS(6440),
    [anon_sym_RPAREN] = ACTIONS(6440),
    [aux_sym_preproc_if_token2] = ACTIONS(6440),
    [aux_sym_preproc_else_token1] = ACTIONS(6440),
    [aux_sym_preproc_elif_token1] = ACTIONS(6438),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6440),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6440),
    [anon_sym_LPAREN2] = ACTIONS(6442),
    [anon_sym_DASH] = ACTIONS(6438),
    [anon_sym_PLUS] = ACTIONS(6438),
    [anon_sym_STAR] = ACTIONS(6438),
    [anon_sym_SLASH] = ACTIONS(6438),
    [anon_sym_PERCENT] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_AMP_AMP] = ACTIONS(6440),
    [anon_sym_PIPE] = ACTIONS(6438),
    [anon_sym_CARET] = ACTIONS(6438),
    [anon_sym_AMP] = ACTIONS(6438),
    [anon_sym_EQ_EQ] = ACTIONS(6440),
    [anon_sym_BANG_EQ] = ACTIONS(6440),
    [anon_sym_GT] = ACTIONS(6438),
    [anon_sym_GT_EQ] = ACTIONS(6440),
    [anon_sym_LT_EQ] = ACTIONS(6438),
    [anon_sym_LT] = ACTIONS(6438),
    [anon_sym_LT_LT] = ACTIONS(6438),
    [anon_sym_GT_GT] = ACTIONS(6438),
    [anon_sym_SEMI] = ACTIONS(6440),
    [anon_sym___attribute__] = ACTIONS(6438),
    [anon_sym___attribute] = ACTIONS(6438),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6444),
    [anon_sym_RBRACE] = ACTIONS(6440),
    [anon_sym_LBRACK] = ACTIONS(6446),
    [anon_sym_RBRACK] = ACTIONS(6440),
    [anon_sym_EQ] = ACTIONS(6438),
    [anon_sym_COLON] = ACTIONS(6440),
    [anon_sym_QMARK] = ACTIONS(6440),
    [anon_sym_STAR_EQ] = ACTIONS(6440),
    [anon_sym_SLASH_EQ] = ACTIONS(6440),
    [anon_sym_PERCENT_EQ] = ACTIONS(6440),
    [anon_sym_PLUS_EQ] = ACTIONS(6440),
    [anon_sym_DASH_EQ] = ACTIONS(6440),
    [anon_sym_LT_LT_EQ] = ACTIONS(6440),
    [anon_sym_GT_GT_EQ] = ACTIONS(6440),
    [anon_sym_AMP_EQ] = ACTIONS(6440),
    [anon_sym_CARET_EQ] = ACTIONS(6440),
    [anon_sym_PIPE_EQ] = ACTIONS(6440),
    [anon_sym_and_eq] = ACTIONS(6438),
    [anon_sym_or_eq] = ACTIONS(6438),
    [anon_sym_xor_eq] = ACTIONS(6438),
    [anon_sym_LT_EQ_GT] = ACTIONS(6440),
    [anon_sym_or] = ACTIONS(6438),
    [anon_sym_and] = ACTIONS(6438),
    [anon_sym_bitor] = ACTIONS(6438),
    [anon_sym_xor] = ACTIONS(6438),
    [anon_sym_bitand] = ACTIONS(6438),
    [anon_sym_not_eq] = ACTIONS(6438),
    [anon_sym_DASH_DASH] = ACTIONS(6440),
    [anon_sym_PLUS_PLUS] = ACTIONS(6440),
    [anon_sym_DOT] = ACTIONS(6438),
    [anon_sym_DOT_STAR] = ACTIONS(6440),
    [anon_sym_DASH_GT] = ACTIONS(6440),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6440),
  },
  [STATE(2422)] = {
    [sym_decltype_auto] = STATE(2527),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5675),
    [anon_sym_COMMA] = ACTIONS(5675),
    [anon_sym_LPAREN2] = ACTIONS(5675),
    [anon_sym_DASH] = ACTIONS(5673),
    [anon_sym_PLUS] = ACTIONS(5673),
    [anon_sym_STAR] = ACTIONS(5675),
    [anon_sym_SLASH] = ACTIONS(5673),
    [anon_sym_PERCENT] = ACTIONS(5675),
    [anon_sym_PIPE_PIPE] = ACTIONS(5675),
    [anon_sym_AMP_AMP] = ACTIONS(5675),
    [anon_sym_PIPE] = ACTIONS(5673),
    [anon_sym_CARET] = ACTIONS(5675),
    [anon_sym_AMP] = ACTIONS(5673),
    [anon_sym_EQ_EQ] = ACTIONS(5675),
    [anon_sym_BANG_EQ] = ACTIONS(5675),
    [anon_sym_GT] = ACTIONS(5673),
    [anon_sym_GT_EQ] = ACTIONS(5673),
    [anon_sym_LT_EQ] = ACTIONS(5673),
    [anon_sym_LT] = ACTIONS(5673),
    [anon_sym_LT_LT] = ACTIONS(5673),
    [anon_sym_GT_GT] = ACTIONS(5673),
    [anon_sym___extension__] = ACTIONS(5675),
    [anon_sym___global__] = ACTIONS(5675),
    [anon_sym___attribute__] = ACTIONS(5675),
    [anon_sym___attribute] = ACTIONS(5673),
    [anon_sym_LBRACE] = ACTIONS(5675),
    [anon_sym_LBRACK] = ACTIONS(5675),
    [anon_sym_const] = ACTIONS(5673),
    [anon_sym_constexpr] = ACTIONS(5675),
    [anon_sym_volatile] = ACTIONS(5675),
    [anon_sym_restrict] = ACTIONS(5675),
    [anon_sym___restrict__] = ACTIONS(5675),
    [anon_sym__Atomic] = ACTIONS(5675),
    [anon_sym__Noreturn] = ACTIONS(5675),
    [anon_sym_noreturn] = ACTIONS(5675),
    [anon_sym__Nonnull] = ACTIONS(5675),
    [anon_sym_mutable] = ACTIONS(5675),
    [anon_sym_constinit] = ACTIONS(5675),
    [anon_sym_consteval] = ACTIONS(5675),
    [anon_sym___shared__] = ACTIONS(5675),
    [anon_sym___local__] = ACTIONS(5675),
    [anon_sym___constant__] = ACTIONS(5675),
    [anon_sym___managed__] = ACTIONS(5675),
    [anon_sym___grid_constant__] = ACTIONS(5675),
    [anon_sym_alignas] = ACTIONS(5675),
    [anon_sym__Alignas] = ACTIONS(5675),
    [anon_sym_QMARK] = ACTIONS(5675),
    [anon_sym_LT_EQ_GT] = ACTIONS(5675),
    [anon_sym_or] = ACTIONS(5675),
    [anon_sym_and] = ACTIONS(5675),
    [anon_sym_bitor] = ACTIONS(5675),
    [anon_sym_xor] = ACTIONS(5675),
    [anon_sym_bitand] = ACTIONS(5675),
    [anon_sym_not_eq] = ACTIONS(5675),
    [anon_sym_DASH_DASH] = ACTIONS(5675),
    [anon_sym_PLUS_PLUS] = ACTIONS(5675),
    [anon_sym_DOT] = ACTIONS(5673),
    [anon_sym_DOT_STAR] = ACTIONS(5675),
    [anon_sym_DASH_GT] = ACTIONS(5675),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6448),
    [anon_sym_decltype] = ACTIONS(6450),
    [anon_sym_final] = ACTIONS(5675),
    [anon_sym_override] = ACTIONS(5675),
    [anon_sym_GT2] = ACTIONS(5675),
    [anon_sym_requires] = ACTIONS(5675),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5675),
  },
  [STATE(2423)] = {
    [sym_attribute_declaration] = STATE(2587),
    [sym_parameter_list] = STATE(2589),
    [aux_sym_attributed_declarator_repeat1] = STATE(2587),
    [sym_identifier] = ACTIONS(6452),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6454),
    [anon_sym_COMMA] = ACTIONS(6454),
    [anon_sym_RPAREN] = ACTIONS(6454),
    [aux_sym_preproc_if_token2] = ACTIONS(6454),
    [aux_sym_preproc_else_token1] = ACTIONS(6454),
    [aux_sym_preproc_elif_token1] = ACTIONS(6452),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6454),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6454),
    [anon_sym_LPAREN2] = ACTIONS(6442),
    [anon_sym_DASH] = ACTIONS(6452),
    [anon_sym_PLUS] = ACTIONS(6452),
    [anon_sym_STAR] = ACTIONS(6452),
    [anon_sym_SLASH] = ACTIONS(6452),
    [anon_sym_PERCENT] = ACTIONS(6452),
    [anon_sym_PIPE_PIPE] = ACTIONS(6454),
    [anon_sym_AMP_AMP] = ACTIONS(6454),
    [anon_sym_PIPE] = ACTIONS(6452),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_AMP] = ACTIONS(6452),
    [anon_sym_EQ_EQ] = ACTIONS(6454),
    [anon_sym_BANG_EQ] = ACTIONS(6454),
    [anon_sym_GT] = ACTIONS(6452),
    [anon_sym_GT_EQ] = ACTIONS(6454),
    [anon_sym_LT_EQ] = ACTIONS(6452),
    [anon_sym_LT] = ACTIONS(6452),
    [anon_sym_LT_LT] = ACTIONS(6452),
    [anon_sym_GT_GT] = ACTIONS(6452),
    [anon_sym_SEMI] = ACTIONS(6454),
    [anon_sym___attribute__] = ACTIONS(6452),
    [anon_sym___attribute] = ACTIONS(6452),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6444),
    [anon_sym_RBRACE] = ACTIONS(6454),
    [anon_sym_LBRACK] = ACTIONS(6446),
    [anon_sym_RBRACK] = ACTIONS(6454),
    [anon_sym_EQ] = ACTIONS(6452),
    [anon_sym_COLON] = ACTIONS(6454),
    [anon_sym_QMARK] = ACTIONS(6454),
    [anon_sym_STAR_EQ] = ACTIONS(6454),
    [anon_sym_SLASH_EQ] = ACTIONS(6454),
    [anon_sym_PERCENT_EQ] = ACTIONS(6454),
    [anon_sym_PLUS_EQ] = ACTIONS(6454),
    [anon_sym_DASH_EQ] = ACTIONS(6454),
    [anon_sym_LT_LT_EQ] = ACTIONS(6454),
    [anon_sym_GT_GT_EQ] = ACTIONS(6454),
    [anon_sym_AMP_EQ] = ACTIONS(6454),
    [anon_sym_CARET_EQ] = ACTIONS(6454),
    [anon_sym_PIPE_EQ] = ACTIONS(6454),
    [anon_sym_and_eq] = ACTIONS(6452),
    [anon_sym_or_eq] = ACTIONS(6452),
    [anon_sym_xor_eq] = ACTIONS(6452),
    [anon_sym_LT_EQ_GT] = ACTIONS(6454),
    [anon_sym_or] = ACTIONS(6452),
    [anon_sym_and] = ACTIONS(6452),
    [anon_sym_bitor] = ACTIONS(6452),
    [anon_sym_xor] = ACTIONS(6452),
    [anon_sym_bitand] = ACTIONS(6452),
    [anon_sym_not_eq] = ACTIONS(6452),
    [anon_sym_DASH_DASH] = ACTIONS(6454),
    [anon_sym_PLUS_PLUS] = ACTIONS(6454),
    [anon_sym_DOT] = ACTIONS(6452),
    [anon_sym_DOT_STAR] = ACTIONS(6454),
    [anon_sym_DASH_GT] = ACTIONS(6454),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6454),
  },
  [STATE(2424)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5657),
    [anon_sym_COMMA] = ACTIONS(5657),
    [anon_sym_LPAREN2] = ACTIONS(5657),
    [anon_sym_DASH] = ACTIONS(5655),
    [anon_sym_PLUS] = ACTIONS(5655),
    [anon_sym_STAR] = ACTIONS(5657),
    [anon_sym_SLASH] = ACTIONS(5655),
    [anon_sym_PERCENT] = ACTIONS(5657),
    [anon_sym_PIPE_PIPE] = ACTIONS(5657),
    [anon_sym_AMP_AMP] = ACTIONS(5657),
    [anon_sym_PIPE] = ACTIONS(5655),
    [anon_sym_CARET] = ACTIONS(5657),
    [anon_sym_AMP] = ACTIONS(5655),
    [anon_sym_EQ_EQ] = ACTIONS(5657),
    [anon_sym_BANG_EQ] = ACTIONS(5657),
    [anon_sym_GT] = ACTIONS(5655),
    [anon_sym_GT_EQ] = ACTIONS(5655),
    [anon_sym_LT_EQ] = ACTIONS(5655),
    [anon_sym_LT] = ACTIONS(5655),
    [anon_sym_LT_LT] = ACTIONS(5655),
    [anon_sym_GT_GT] = ACTIONS(5655),
    [anon_sym___extension__] = ACTIONS(5657),
    [anon_sym___global__] = ACTIONS(5657),
    [anon_sym___attribute__] = ACTIONS(5657),
    [anon_sym___attribute] = ACTIONS(5655),
    [anon_sym_COLON_COLON] = ACTIONS(5657),
    [anon_sym_LBRACE] = ACTIONS(5657),
    [anon_sym_LBRACK] = ACTIONS(5657),
    [anon_sym_const] = ACTIONS(5655),
    [anon_sym_constexpr] = ACTIONS(5657),
    [anon_sym_volatile] = ACTIONS(5657),
    [anon_sym_restrict] = ACTIONS(5657),
    [anon_sym___restrict__] = ACTIONS(5657),
    [anon_sym__Atomic] = ACTIONS(5657),
    [anon_sym__Noreturn] = ACTIONS(5657),
    [anon_sym_noreturn] = ACTIONS(5657),
    [anon_sym__Nonnull] = ACTIONS(5657),
    [anon_sym_mutable] = ACTIONS(5657),
    [anon_sym_constinit] = ACTIONS(5657),
    [anon_sym_consteval] = ACTIONS(5657),
    [anon_sym___shared__] = ACTIONS(5657),
    [anon_sym___local__] = ACTIONS(5657),
    [anon_sym___constant__] = ACTIONS(5657),
    [anon_sym___managed__] = ACTIONS(5657),
    [anon_sym___grid_constant__] = ACTIONS(5657),
    [anon_sym_alignas] = ACTIONS(5657),
    [anon_sym__Alignas] = ACTIONS(5657),
    [anon_sym_QMARK] = ACTIONS(5657),
    [anon_sym_LT_EQ_GT] = ACTIONS(5657),
    [anon_sym_or] = ACTIONS(5657),
    [anon_sym_and] = ACTIONS(5657),
    [anon_sym_bitor] = ACTIONS(5657),
    [anon_sym_xor] = ACTIONS(5657),
    [anon_sym_bitand] = ACTIONS(5657),
    [anon_sym_not_eq] = ACTIONS(5657),
    [anon_sym_DASH_DASH] = ACTIONS(5657),
    [anon_sym_PLUS_PLUS] = ACTIONS(5657),
    [anon_sym_DOT] = ACTIONS(5655),
    [anon_sym_DOT_STAR] = ACTIONS(5657),
    [anon_sym_DASH_GT] = ACTIONS(5657),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5657),
    [anon_sym_decltype] = ACTIONS(5657),
    [anon_sym_final] = ACTIONS(5657),
    [anon_sym_override] = ACTIONS(5657),
    [anon_sym_GT2] = ACTIONS(5657),
    [anon_sym_requires] = ACTIONS(5657),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5657),
  },
  [STATE(2425)] = {
    [sym_attribute_specifier] = STATE(2523),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6234),
    [anon_sym_COMMA] = ACTIONS(6234),
    [anon_sym_LPAREN2] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6236),
    [anon_sym_PLUS] = ACTIONS(6236),
    [anon_sym_STAR] = ACTIONS(6234),
    [anon_sym_SLASH] = ACTIONS(6236),
    [anon_sym_PERCENT] = ACTIONS(6234),
    [anon_sym_PIPE_PIPE] = ACTIONS(6234),
    [anon_sym_AMP_AMP] = ACTIONS(6234),
    [anon_sym_PIPE] = ACTIONS(6236),
    [anon_sym_CARET] = ACTIONS(6234),
    [anon_sym_AMP] = ACTIONS(6236),
    [anon_sym_EQ_EQ] = ACTIONS(6234),
    [anon_sym_BANG_EQ] = ACTIONS(6234),
    [anon_sym_GT] = ACTIONS(6236),
    [anon_sym_GT_EQ] = ACTIONS(6236),
    [anon_sym_LT_EQ] = ACTIONS(6236),
    [anon_sym_LT] = ACTIONS(6236),
    [anon_sym_LT_LT] = ACTIONS(6236),
    [anon_sym_GT_GT] = ACTIONS(6236),
    [anon_sym___extension__] = ACTIONS(6234),
    [anon_sym___global__] = ACTIONS(6234),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6234),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [anon_sym_const] = ACTIONS(6236),
    [anon_sym_constexpr] = ACTIONS(6234),
    [anon_sym_volatile] = ACTIONS(6234),
    [anon_sym_restrict] = ACTIONS(6234),
    [anon_sym___restrict__] = ACTIONS(6234),
    [anon_sym__Atomic] = ACTIONS(6234),
    [anon_sym__Noreturn] = ACTIONS(6234),
    [anon_sym_noreturn] = ACTIONS(6234),
    [anon_sym__Nonnull] = ACTIONS(6234),
    [anon_sym_mutable] = ACTIONS(6234),
    [anon_sym_constinit] = ACTIONS(6234),
    [anon_sym_consteval] = ACTIONS(6234),
    [anon_sym___shared__] = ACTIONS(6234),
    [anon_sym___local__] = ACTIONS(6234),
    [anon_sym___constant__] = ACTIONS(6234),
    [anon_sym___managed__] = ACTIONS(6234),
    [anon_sym___grid_constant__] = ACTIONS(6234),
    [anon_sym_alignas] = ACTIONS(6234),
    [anon_sym__Alignas] = ACTIONS(6234),
    [anon_sym_QMARK] = ACTIONS(6234),
    [anon_sym_LT_EQ_GT] = ACTIONS(6234),
    [anon_sym_or] = ACTIONS(6234),
    [anon_sym_and] = ACTIONS(6234),
    [anon_sym_bitor] = ACTIONS(6234),
    [anon_sym_xor] = ACTIONS(6234),
    [anon_sym_bitand] = ACTIONS(6234),
    [anon_sym_not_eq] = ACTIONS(6234),
    [anon_sym_DASH_DASH] = ACTIONS(6234),
    [anon_sym_PLUS_PLUS] = ACTIONS(6234),
    [anon_sym_DOT] = ACTIONS(6236),
    [anon_sym_DOT_STAR] = ACTIONS(6234),
    [anon_sym_DASH_GT] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6234),
    [anon_sym_decltype] = ACTIONS(6234),
    [anon_sym_final] = ACTIONS(6234),
    [anon_sym_override] = ACTIONS(6234),
    [anon_sym_GT2] = ACTIONS(6234),
    [anon_sym_requires] = ACTIONS(6234),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6234),
  },
  [STATE(2426)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_structured_binding_declarator_repeat1] = STATE(7910),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6456),
    [anon_sym_COMMA] = ACTIONS(6459),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_RBRACK] = ACTIONS(6462),
    [anon_sym_EQ] = ACTIONS(6466),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(6468),
    [anon_sym_SLASH_EQ] = ACTIONS(6468),
    [anon_sym_PERCENT_EQ] = ACTIONS(6468),
    [anon_sym_PLUS_EQ] = ACTIONS(6468),
    [anon_sym_DASH_EQ] = ACTIONS(6468),
    [anon_sym_LT_LT_EQ] = ACTIONS(6468),
    [anon_sym_GT_GT_EQ] = ACTIONS(6468),
    [anon_sym_AMP_EQ] = ACTIONS(6468),
    [anon_sym_CARET_EQ] = ACTIONS(6468),
    [anon_sym_PIPE_EQ] = ACTIONS(6468),
    [anon_sym_and_eq] = ACTIONS(6468),
    [anon_sym_or_eq] = ACTIONS(6468),
    [anon_sym_xor_eq] = ACTIONS(6468),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2427)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [aux_sym_preproc_if_token2] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5684),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5686),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5684),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5684),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_EQ] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5684),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_STAR_EQ] = ACTIONS(5686),
    [anon_sym_SLASH_EQ] = ACTIONS(5686),
    [anon_sym_PERCENT_EQ] = ACTIONS(5686),
    [anon_sym_PLUS_EQ] = ACTIONS(5686),
    [anon_sym_DASH_EQ] = ACTIONS(5686),
    [anon_sym_LT_LT_EQ] = ACTIONS(5686),
    [anon_sym_GT_GT_EQ] = ACTIONS(5686),
    [anon_sym_AMP_EQ] = ACTIONS(5686),
    [anon_sym_CARET_EQ] = ACTIONS(5686),
    [anon_sym_PIPE_EQ] = ACTIONS(5686),
    [anon_sym_and_eq] = ACTIONS(5684),
    [anon_sym_or_eq] = ACTIONS(5684),
    [anon_sym_xor_eq] = ACTIONS(5684),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_and] = ACTIONS(5684),
    [anon_sym_bitor] = ACTIONS(5684),
    [anon_sym_xor] = ACTIONS(5684),
    [anon_sym_bitand] = ACTIONS(5684),
    [anon_sym_not_eq] = ACTIONS(5684),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2428)] = {
    [sym_attribute_specifier] = STATE(2541),
    [sym_identifier] = ACTIONS(6218),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6216),
    [anon_sym_COMMA] = ACTIONS(6216),
    [anon_sym_RPAREN] = ACTIONS(6216),
    [aux_sym_preproc_if_token2] = ACTIONS(6216),
    [aux_sym_preproc_else_token1] = ACTIONS(6216),
    [aux_sym_preproc_elif_token1] = ACTIONS(6218),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6216),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6216),
    [anon_sym_LPAREN2] = ACTIONS(6216),
    [anon_sym_DASH] = ACTIONS(6218),
    [anon_sym_PLUS] = ACTIONS(6218),
    [anon_sym_STAR] = ACTIONS(6218),
    [anon_sym_SLASH] = ACTIONS(6218),
    [anon_sym_PERCENT] = ACTIONS(6218),
    [anon_sym_PIPE_PIPE] = ACTIONS(6216),
    [anon_sym_AMP_AMP] = ACTIONS(6216),
    [anon_sym_PIPE] = ACTIONS(6218),
    [anon_sym_CARET] = ACTIONS(6218),
    [anon_sym_AMP] = ACTIONS(6218),
    [anon_sym_EQ_EQ] = ACTIONS(6216),
    [anon_sym_BANG_EQ] = ACTIONS(6216),
    [anon_sym_GT] = ACTIONS(6218),
    [anon_sym_GT_EQ] = ACTIONS(6216),
    [anon_sym_LT_EQ] = ACTIONS(6218),
    [anon_sym_LT] = ACTIONS(6218),
    [anon_sym_LT_LT] = ACTIONS(6218),
    [anon_sym_GT_GT] = ACTIONS(6218),
    [anon_sym_SEMI] = ACTIONS(6216),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6216),
    [anon_sym_RBRACE] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6216),
    [anon_sym_RBRACK] = ACTIONS(6216),
    [anon_sym_EQ] = ACTIONS(6218),
    [anon_sym_COLON] = ACTIONS(6216),
    [anon_sym_QMARK] = ACTIONS(6216),
    [anon_sym_STAR_EQ] = ACTIONS(6216),
    [anon_sym_SLASH_EQ] = ACTIONS(6216),
    [anon_sym_PERCENT_EQ] = ACTIONS(6216),
    [anon_sym_PLUS_EQ] = ACTIONS(6216),
    [anon_sym_DASH_EQ] = ACTIONS(6216),
    [anon_sym_LT_LT_EQ] = ACTIONS(6216),
    [anon_sym_GT_GT_EQ] = ACTIONS(6216),
    [anon_sym_AMP_EQ] = ACTIONS(6216),
    [anon_sym_CARET_EQ] = ACTIONS(6216),
    [anon_sym_PIPE_EQ] = ACTIONS(6216),
    [anon_sym_and_eq] = ACTIONS(6218),
    [anon_sym_or_eq] = ACTIONS(6218),
    [anon_sym_xor_eq] = ACTIONS(6218),
    [anon_sym_LT_EQ_GT] = ACTIONS(6216),
    [anon_sym_or] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6218),
    [anon_sym_bitor] = ACTIONS(6218),
    [anon_sym_xor] = ACTIONS(6218),
    [anon_sym_bitand] = ACTIONS(6218),
    [anon_sym_not_eq] = ACTIONS(6218),
    [anon_sym_DASH_DASH] = ACTIONS(6216),
    [anon_sym_PLUS_PLUS] = ACTIONS(6216),
    [anon_sym_DOT] = ACTIONS(6218),
    [anon_sym_DOT_STAR] = ACTIONS(6216),
    [anon_sym_DASH_GT] = ACTIONS(6216),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6218),
    [anon_sym_decltype] = ACTIONS(6218),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6216),
  },
  [STATE(2429)] = {
    [sym_attribute_specifier] = STATE(2544),
    [sym_identifier] = ACTIONS(6279),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6277),
    [anon_sym_COMMA] = ACTIONS(6277),
    [anon_sym_RPAREN] = ACTIONS(6277),
    [aux_sym_preproc_if_token2] = ACTIONS(6277),
    [aux_sym_preproc_else_token1] = ACTIONS(6277),
    [aux_sym_preproc_elif_token1] = ACTIONS(6279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6277),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6277),
    [anon_sym_LPAREN2] = ACTIONS(6277),
    [anon_sym_DASH] = ACTIONS(6279),
    [anon_sym_PLUS] = ACTIONS(6279),
    [anon_sym_STAR] = ACTIONS(6279),
    [anon_sym_SLASH] = ACTIONS(6279),
    [anon_sym_PERCENT] = ACTIONS(6279),
    [anon_sym_PIPE_PIPE] = ACTIONS(6277),
    [anon_sym_AMP_AMP] = ACTIONS(6277),
    [anon_sym_PIPE] = ACTIONS(6279),
    [anon_sym_CARET] = ACTIONS(6279),
    [anon_sym_AMP] = ACTIONS(6279),
    [anon_sym_EQ_EQ] = ACTIONS(6277),
    [anon_sym_BANG_EQ] = ACTIONS(6277),
    [anon_sym_GT] = ACTIONS(6279),
    [anon_sym_GT_EQ] = ACTIONS(6277),
    [anon_sym_LT_EQ] = ACTIONS(6279),
    [anon_sym_LT] = ACTIONS(6279),
    [anon_sym_LT_LT] = ACTIONS(6279),
    [anon_sym_GT_GT] = ACTIONS(6279),
    [anon_sym_SEMI] = ACTIONS(6277),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6277),
    [anon_sym_RBRACE] = ACTIONS(6277),
    [anon_sym_LBRACK] = ACTIONS(6277),
    [anon_sym_RBRACK] = ACTIONS(6277),
    [anon_sym_EQ] = ACTIONS(6279),
    [anon_sym_COLON] = ACTIONS(6277),
    [anon_sym_QMARK] = ACTIONS(6277),
    [anon_sym_STAR_EQ] = ACTIONS(6277),
    [anon_sym_SLASH_EQ] = ACTIONS(6277),
    [anon_sym_PERCENT_EQ] = ACTIONS(6277),
    [anon_sym_PLUS_EQ] = ACTIONS(6277),
    [anon_sym_DASH_EQ] = ACTIONS(6277),
    [anon_sym_LT_LT_EQ] = ACTIONS(6277),
    [anon_sym_GT_GT_EQ] = ACTIONS(6277),
    [anon_sym_AMP_EQ] = ACTIONS(6277),
    [anon_sym_CARET_EQ] = ACTIONS(6277),
    [anon_sym_PIPE_EQ] = ACTIONS(6277),
    [anon_sym_and_eq] = ACTIONS(6279),
    [anon_sym_or_eq] = ACTIONS(6279),
    [anon_sym_xor_eq] = ACTIONS(6279),
    [anon_sym_LT_EQ_GT] = ACTIONS(6277),
    [anon_sym_or] = ACTIONS(6279),
    [anon_sym_and] = ACTIONS(6279),
    [anon_sym_bitor] = ACTIONS(6279),
    [anon_sym_xor] = ACTIONS(6279),
    [anon_sym_bitand] = ACTIONS(6279),
    [anon_sym_not_eq] = ACTIONS(6279),
    [anon_sym_DASH_DASH] = ACTIONS(6277),
    [anon_sym_PLUS_PLUS] = ACTIONS(6277),
    [anon_sym_DOT] = ACTIONS(6279),
    [anon_sym_DOT_STAR] = ACTIONS(6277),
    [anon_sym_DASH_GT] = ACTIONS(6277),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6279),
    [anon_sym_decltype] = ACTIONS(6279),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6277),
  },
  [STATE(2430)] = {
    [sym_attribute_specifier] = STATE(2546),
    [sym_identifier] = ACTIONS(6250),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6248),
    [anon_sym_COMMA] = ACTIONS(6248),
    [anon_sym_RPAREN] = ACTIONS(6248),
    [aux_sym_preproc_if_token2] = ACTIONS(6248),
    [aux_sym_preproc_else_token1] = ACTIONS(6248),
    [aux_sym_preproc_elif_token1] = ACTIONS(6250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6248),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6248),
    [anon_sym_LPAREN2] = ACTIONS(6248),
    [anon_sym_DASH] = ACTIONS(6250),
    [anon_sym_PLUS] = ACTIONS(6250),
    [anon_sym_STAR] = ACTIONS(6250),
    [anon_sym_SLASH] = ACTIONS(6250),
    [anon_sym_PERCENT] = ACTIONS(6250),
    [anon_sym_PIPE_PIPE] = ACTIONS(6248),
    [anon_sym_AMP_AMP] = ACTIONS(6248),
    [anon_sym_PIPE] = ACTIONS(6250),
    [anon_sym_CARET] = ACTIONS(6250),
    [anon_sym_AMP] = ACTIONS(6250),
    [anon_sym_EQ_EQ] = ACTIONS(6248),
    [anon_sym_BANG_EQ] = ACTIONS(6248),
    [anon_sym_GT] = ACTIONS(6250),
    [anon_sym_GT_EQ] = ACTIONS(6248),
    [anon_sym_LT_EQ] = ACTIONS(6250),
    [anon_sym_LT] = ACTIONS(6250),
    [anon_sym_LT_LT] = ACTIONS(6250),
    [anon_sym_GT_GT] = ACTIONS(6250),
    [anon_sym_SEMI] = ACTIONS(6248),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6248),
    [anon_sym_RBRACE] = ACTIONS(6248),
    [anon_sym_LBRACK] = ACTIONS(6248),
    [anon_sym_RBRACK] = ACTIONS(6248),
    [anon_sym_EQ] = ACTIONS(6250),
    [anon_sym_COLON] = ACTIONS(6248),
    [anon_sym_QMARK] = ACTIONS(6248),
    [anon_sym_STAR_EQ] = ACTIONS(6248),
    [anon_sym_SLASH_EQ] = ACTIONS(6248),
    [anon_sym_PERCENT_EQ] = ACTIONS(6248),
    [anon_sym_PLUS_EQ] = ACTIONS(6248),
    [anon_sym_DASH_EQ] = ACTIONS(6248),
    [anon_sym_LT_LT_EQ] = ACTIONS(6248),
    [anon_sym_GT_GT_EQ] = ACTIONS(6248),
    [anon_sym_AMP_EQ] = ACTIONS(6248),
    [anon_sym_CARET_EQ] = ACTIONS(6248),
    [anon_sym_PIPE_EQ] = ACTIONS(6248),
    [anon_sym_and_eq] = ACTIONS(6250),
    [anon_sym_or_eq] = ACTIONS(6250),
    [anon_sym_xor_eq] = ACTIONS(6250),
    [anon_sym_LT_EQ_GT] = ACTIONS(6248),
    [anon_sym_or] = ACTIONS(6250),
    [anon_sym_and] = ACTIONS(6250),
    [anon_sym_bitor] = ACTIONS(6250),
    [anon_sym_xor] = ACTIONS(6250),
    [anon_sym_bitand] = ACTIONS(6250),
    [anon_sym_not_eq] = ACTIONS(6250),
    [anon_sym_DASH_DASH] = ACTIONS(6248),
    [anon_sym_PLUS_PLUS] = ACTIONS(6248),
    [anon_sym_DOT] = ACTIONS(6250),
    [anon_sym_DOT_STAR] = ACTIONS(6248),
    [anon_sym_DASH_GT] = ACTIONS(6248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6250),
    [anon_sym_decltype] = ACTIONS(6250),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6248),
  },
  [STATE(2431)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_COLON] = ACTIONS(4065),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2432)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_COLON] = ACTIONS(4307),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2433)] = {
    [sym_string_literal] = STATE(2460),
    [sym_raw_string_literal] = STATE(2460),
    [aux_sym_concatenated_string_repeat1] = STATE(2460),
    [sym_identifier] = ACTIONS(6470),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6002),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_RPAREN] = ACTIONS(6002),
    [anon_sym_LPAREN2] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_STAR] = ACTIONS(6004),
    [anon_sym_SLASH] = ACTIONS(6004),
    [anon_sym_PERCENT] = ACTIONS(6004),
    [anon_sym_PIPE_PIPE] = ACTIONS(6002),
    [anon_sym_AMP_AMP] = ACTIONS(6002),
    [anon_sym_PIPE] = ACTIONS(6004),
    [anon_sym_CARET] = ACTIONS(6004),
    [anon_sym_AMP] = ACTIONS(6004),
    [anon_sym_EQ_EQ] = ACTIONS(6002),
    [anon_sym_BANG_EQ] = ACTIONS(6002),
    [anon_sym_GT] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(6002),
    [anon_sym_LT_EQ] = ACTIONS(6004),
    [anon_sym_LT] = ACTIONS(6004),
    [anon_sym_LT_LT] = ACTIONS(6004),
    [anon_sym_GT_GT] = ACTIONS(6004),
    [anon_sym_LBRACK] = ACTIONS(6002),
    [anon_sym_EQ] = ACTIONS(6004),
    [anon_sym_QMARK] = ACTIONS(6002),
    [anon_sym_STAR_EQ] = ACTIONS(6002),
    [anon_sym_SLASH_EQ] = ACTIONS(6002),
    [anon_sym_PERCENT_EQ] = ACTIONS(6002),
    [anon_sym_PLUS_EQ] = ACTIONS(6002),
    [anon_sym_DASH_EQ] = ACTIONS(6002),
    [anon_sym_LT_LT_EQ] = ACTIONS(6002),
    [anon_sym_GT_GT_EQ] = ACTIONS(6002),
    [anon_sym_AMP_EQ] = ACTIONS(6002),
    [anon_sym_CARET_EQ] = ACTIONS(6002),
    [anon_sym_PIPE_EQ] = ACTIONS(6002),
    [anon_sym_and_eq] = ACTIONS(6004),
    [anon_sym_or_eq] = ACTIONS(6004),
    [anon_sym_xor_eq] = ACTIONS(6004),
    [anon_sym_LT_EQ_GT] = ACTIONS(6002),
    [anon_sym_or] = ACTIONS(6004),
    [anon_sym_and] = ACTIONS(6004),
    [anon_sym_bitor] = ACTIONS(6004),
    [anon_sym_xor] = ACTIONS(6004),
    [anon_sym_bitand] = ACTIONS(6004),
    [anon_sym_not_eq] = ACTIONS(6004),
    [anon_sym_DASH_DASH] = ACTIONS(6002),
    [anon_sym_PLUS_PLUS] = ACTIONS(6002),
    [anon_sym_DOT] = ACTIONS(6004),
    [anon_sym_DOT_STAR] = ACTIONS(6002),
    [anon_sym_DASH_GT] = ACTIONS(6004),
    [anon_sym_L_DQUOTE] = ACTIONS(5103),
    [anon_sym_u_DQUOTE] = ACTIONS(5103),
    [anon_sym_U_DQUOTE] = ACTIONS(5103),
    [anon_sym_u8_DQUOTE] = ACTIONS(5103),
    [anon_sym_DQUOTE] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5105),
    [anon_sym_LR_DQUOTE] = ACTIONS(5105),
    [anon_sym_uR_DQUOTE] = ACTIONS(5105),
    [anon_sym_UR_DQUOTE] = ACTIONS(5105),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5105),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6002),
    [sym_literal_suffix] = ACTIONS(6004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6002),
  },
  [STATE(2434)] = {
    [sym_attribute_specifier] = STATE(2535),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6252),
    [anon_sym_COMMA] = ACTIONS(6252),
    [anon_sym_LPAREN2] = ACTIONS(6252),
    [anon_sym_DASH] = ACTIONS(6254),
    [anon_sym_PLUS] = ACTIONS(6254),
    [anon_sym_STAR] = ACTIONS(6252),
    [anon_sym_SLASH] = ACTIONS(6254),
    [anon_sym_PERCENT] = ACTIONS(6252),
    [anon_sym_PIPE_PIPE] = ACTIONS(6252),
    [anon_sym_AMP_AMP] = ACTIONS(6252),
    [anon_sym_PIPE] = ACTIONS(6254),
    [anon_sym_CARET] = ACTIONS(6252),
    [anon_sym_AMP] = ACTIONS(6254),
    [anon_sym_EQ_EQ] = ACTIONS(6252),
    [anon_sym_BANG_EQ] = ACTIONS(6252),
    [anon_sym_GT] = ACTIONS(6254),
    [anon_sym_GT_EQ] = ACTIONS(6254),
    [anon_sym_LT_EQ] = ACTIONS(6254),
    [anon_sym_LT] = ACTIONS(6254),
    [anon_sym_LT_LT] = ACTIONS(6254),
    [anon_sym_GT_GT] = ACTIONS(6254),
    [anon_sym___extension__] = ACTIONS(6252),
    [anon_sym___global__] = ACTIONS(6252),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6252),
    [anon_sym_LBRACK] = ACTIONS(6252),
    [anon_sym_const] = ACTIONS(6254),
    [anon_sym_constexpr] = ACTIONS(6252),
    [anon_sym_volatile] = ACTIONS(6252),
    [anon_sym_restrict] = ACTIONS(6252),
    [anon_sym___restrict__] = ACTIONS(6252),
    [anon_sym__Atomic] = ACTIONS(6252),
    [anon_sym__Noreturn] = ACTIONS(6252),
    [anon_sym_noreturn] = ACTIONS(6252),
    [anon_sym__Nonnull] = ACTIONS(6252),
    [anon_sym_mutable] = ACTIONS(6252),
    [anon_sym_constinit] = ACTIONS(6252),
    [anon_sym_consteval] = ACTIONS(6252),
    [anon_sym___shared__] = ACTIONS(6252),
    [anon_sym___local__] = ACTIONS(6252),
    [anon_sym___constant__] = ACTIONS(6252),
    [anon_sym___managed__] = ACTIONS(6252),
    [anon_sym___grid_constant__] = ACTIONS(6252),
    [anon_sym_alignas] = ACTIONS(6252),
    [anon_sym__Alignas] = ACTIONS(6252),
    [anon_sym_QMARK] = ACTIONS(6252),
    [anon_sym_LT_EQ_GT] = ACTIONS(6252),
    [anon_sym_or] = ACTIONS(6252),
    [anon_sym_and] = ACTIONS(6252),
    [anon_sym_bitor] = ACTIONS(6252),
    [anon_sym_xor] = ACTIONS(6252),
    [anon_sym_bitand] = ACTIONS(6252),
    [anon_sym_not_eq] = ACTIONS(6252),
    [anon_sym_DASH_DASH] = ACTIONS(6252),
    [anon_sym_PLUS_PLUS] = ACTIONS(6252),
    [anon_sym_DOT] = ACTIONS(6254),
    [anon_sym_DOT_STAR] = ACTIONS(6252),
    [anon_sym_DASH_GT] = ACTIONS(6252),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6252),
    [anon_sym_decltype] = ACTIONS(6252),
    [anon_sym_final] = ACTIONS(6252),
    [anon_sym_override] = ACTIONS(6252),
    [anon_sym_GT2] = ACTIONS(6252),
    [anon_sym_requires] = ACTIONS(6252),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6252),
  },
  [STATE(2435)] = {
    [sym_string_literal] = STATE(2433),
    [sym_template_argument_list] = STATE(3610),
    [sym_raw_string_literal] = STATE(2433),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5107),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4012),
    [anon_sym_L_DQUOTE] = ACTIONS(5103),
    [anon_sym_u_DQUOTE] = ACTIONS(5103),
    [anon_sym_U_DQUOTE] = ACTIONS(5103),
    [anon_sym_u8_DQUOTE] = ACTIONS(5103),
    [anon_sym_DQUOTE] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5105),
    [anon_sym_LR_DQUOTE] = ACTIONS(5105),
    [anon_sym_uR_DQUOTE] = ACTIONS(5105),
    [anon_sym_UR_DQUOTE] = ACTIONS(5105),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5105),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2436)] = {
    [sym_identifier] = ACTIONS(5655),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5657),
    [anon_sym_COMMA] = ACTIONS(5657),
    [anon_sym_RPAREN] = ACTIONS(5657),
    [aux_sym_preproc_if_token2] = ACTIONS(5657),
    [aux_sym_preproc_else_token1] = ACTIONS(5657),
    [aux_sym_preproc_elif_token1] = ACTIONS(5655),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5657),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5657),
    [anon_sym_LPAREN2] = ACTIONS(5657),
    [anon_sym_DASH] = ACTIONS(5655),
    [anon_sym_PLUS] = ACTIONS(5655),
    [anon_sym_STAR] = ACTIONS(5655),
    [anon_sym_SLASH] = ACTIONS(5655),
    [anon_sym_PERCENT] = ACTIONS(5655),
    [anon_sym_PIPE_PIPE] = ACTIONS(5657),
    [anon_sym_AMP_AMP] = ACTIONS(5657),
    [anon_sym_PIPE] = ACTIONS(5655),
    [anon_sym_CARET] = ACTIONS(5655),
    [anon_sym_AMP] = ACTIONS(5655),
    [anon_sym_EQ_EQ] = ACTIONS(5657),
    [anon_sym_BANG_EQ] = ACTIONS(5657),
    [anon_sym_GT] = ACTIONS(5655),
    [anon_sym_GT_EQ] = ACTIONS(5657),
    [anon_sym_LT_EQ] = ACTIONS(5655),
    [anon_sym_LT] = ACTIONS(5655),
    [anon_sym_LT_LT] = ACTIONS(5655),
    [anon_sym_GT_GT] = ACTIONS(5655),
    [anon_sym_SEMI] = ACTIONS(5657),
    [anon_sym___attribute__] = ACTIONS(5655),
    [anon_sym___attribute] = ACTIONS(5655),
    [anon_sym_COLON_COLON] = ACTIONS(5657),
    [anon_sym_LBRACE] = ACTIONS(5657),
    [anon_sym_RBRACE] = ACTIONS(5657),
    [anon_sym_LBRACK] = ACTIONS(5657),
    [anon_sym_RBRACK] = ACTIONS(5657),
    [anon_sym_EQ] = ACTIONS(5655),
    [anon_sym_COLON] = ACTIONS(5655),
    [anon_sym_QMARK] = ACTIONS(5657),
    [anon_sym_STAR_EQ] = ACTIONS(5657),
    [anon_sym_SLASH_EQ] = ACTIONS(5657),
    [anon_sym_PERCENT_EQ] = ACTIONS(5657),
    [anon_sym_PLUS_EQ] = ACTIONS(5657),
    [anon_sym_DASH_EQ] = ACTIONS(5657),
    [anon_sym_LT_LT_EQ] = ACTIONS(5657),
    [anon_sym_GT_GT_EQ] = ACTIONS(5657),
    [anon_sym_AMP_EQ] = ACTIONS(5657),
    [anon_sym_CARET_EQ] = ACTIONS(5657),
    [anon_sym_PIPE_EQ] = ACTIONS(5657),
    [anon_sym_and_eq] = ACTIONS(5655),
    [anon_sym_or_eq] = ACTIONS(5655),
    [anon_sym_xor_eq] = ACTIONS(5655),
    [anon_sym_LT_EQ_GT] = ACTIONS(5657),
    [anon_sym_or] = ACTIONS(5655),
    [anon_sym_and] = ACTIONS(5655),
    [anon_sym_bitor] = ACTIONS(5655),
    [anon_sym_xor] = ACTIONS(5655),
    [anon_sym_bitand] = ACTIONS(5655),
    [anon_sym_not_eq] = ACTIONS(5655),
    [anon_sym_DASH_DASH] = ACTIONS(5657),
    [anon_sym_PLUS_PLUS] = ACTIONS(5657),
    [anon_sym_DOT] = ACTIONS(5655),
    [anon_sym_DOT_STAR] = ACTIONS(5657),
    [anon_sym_DASH_GT] = ACTIONS(5657),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5655),
    [anon_sym_decltype] = ACTIONS(5655),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5657),
  },
  [STATE(2437)] = {
    [sym_attribute_specifier] = STATE(2478),
    [sym_identifier] = ACTIONS(6236),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6234),
    [anon_sym_COMMA] = ACTIONS(6234),
    [anon_sym_RPAREN] = ACTIONS(6234),
    [aux_sym_preproc_if_token2] = ACTIONS(6234),
    [aux_sym_preproc_else_token1] = ACTIONS(6234),
    [aux_sym_preproc_elif_token1] = ACTIONS(6236),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6234),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6234),
    [anon_sym_LPAREN2] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6236),
    [anon_sym_PLUS] = ACTIONS(6236),
    [anon_sym_STAR] = ACTIONS(6236),
    [anon_sym_SLASH] = ACTIONS(6236),
    [anon_sym_PERCENT] = ACTIONS(6236),
    [anon_sym_PIPE_PIPE] = ACTIONS(6234),
    [anon_sym_AMP_AMP] = ACTIONS(6234),
    [anon_sym_PIPE] = ACTIONS(6236),
    [anon_sym_CARET] = ACTIONS(6236),
    [anon_sym_AMP] = ACTIONS(6236),
    [anon_sym_EQ_EQ] = ACTIONS(6234),
    [anon_sym_BANG_EQ] = ACTIONS(6234),
    [anon_sym_GT] = ACTIONS(6236),
    [anon_sym_GT_EQ] = ACTIONS(6234),
    [anon_sym_LT_EQ] = ACTIONS(6236),
    [anon_sym_LT] = ACTIONS(6236),
    [anon_sym_LT_LT] = ACTIONS(6236),
    [anon_sym_GT_GT] = ACTIONS(6236),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6234),
    [anon_sym_RBRACE] = ACTIONS(6234),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [anon_sym_RBRACK] = ACTIONS(6234),
    [anon_sym_EQ] = ACTIONS(6236),
    [anon_sym_COLON] = ACTIONS(6234),
    [anon_sym_QMARK] = ACTIONS(6234),
    [anon_sym_STAR_EQ] = ACTIONS(6234),
    [anon_sym_SLASH_EQ] = ACTIONS(6234),
    [anon_sym_PERCENT_EQ] = ACTIONS(6234),
    [anon_sym_PLUS_EQ] = ACTIONS(6234),
    [anon_sym_DASH_EQ] = ACTIONS(6234),
    [anon_sym_LT_LT_EQ] = ACTIONS(6234),
    [anon_sym_GT_GT_EQ] = ACTIONS(6234),
    [anon_sym_AMP_EQ] = ACTIONS(6234),
    [anon_sym_CARET_EQ] = ACTIONS(6234),
    [anon_sym_PIPE_EQ] = ACTIONS(6234),
    [anon_sym_and_eq] = ACTIONS(6236),
    [anon_sym_or_eq] = ACTIONS(6236),
    [anon_sym_xor_eq] = ACTIONS(6236),
    [anon_sym_LT_EQ_GT] = ACTIONS(6234),
    [anon_sym_or] = ACTIONS(6236),
    [anon_sym_and] = ACTIONS(6236),
    [anon_sym_bitor] = ACTIONS(6236),
    [anon_sym_xor] = ACTIONS(6236),
    [anon_sym_bitand] = ACTIONS(6236),
    [anon_sym_not_eq] = ACTIONS(6236),
    [anon_sym_DASH_DASH] = ACTIONS(6234),
    [anon_sym_PLUS_PLUS] = ACTIONS(6234),
    [anon_sym_DOT] = ACTIONS(6236),
    [anon_sym_DOT_STAR] = ACTIONS(6234),
    [anon_sym_DASH_GT] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6236),
    [anon_sym_decltype] = ACTIONS(6236),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6234),
  },
  [STATE(2438)] = {
    [sym_string_literal] = STATE(2712),
    [sym_template_argument_list] = STATE(4044),
    [sym_raw_string_literal] = STATE(2712),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_RPAREN] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(6472),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(6475),
    [anon_sym_or_eq] = ACTIONS(6475),
    [anon_sym_xor_eq] = ACTIONS(6475),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4012),
    [anon_sym_L_DQUOTE] = ACTIONS(4314),
    [anon_sym_u_DQUOTE] = ACTIONS(4314),
    [anon_sym_U_DQUOTE] = ACTIONS(4314),
    [anon_sym_u8_DQUOTE] = ACTIONS(4314),
    [anon_sym_DQUOTE] = ACTIONS(4314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(4316),
    [anon_sym_LR_DQUOTE] = ACTIONS(4316),
    [anon_sym_uR_DQUOTE] = ACTIONS(4316),
    [anon_sym_UR_DQUOTE] = ACTIONS(4316),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4316),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2439)] = {
    [sym_attribute_specifier] = STATE(2483),
    [sym_identifier] = ACTIONS(6254),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6252),
    [anon_sym_COMMA] = ACTIONS(6252),
    [anon_sym_RPAREN] = ACTIONS(6252),
    [aux_sym_preproc_if_token2] = ACTIONS(6252),
    [aux_sym_preproc_else_token1] = ACTIONS(6252),
    [aux_sym_preproc_elif_token1] = ACTIONS(6254),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6252),
    [anon_sym_LPAREN2] = ACTIONS(6252),
    [anon_sym_DASH] = ACTIONS(6254),
    [anon_sym_PLUS] = ACTIONS(6254),
    [anon_sym_STAR] = ACTIONS(6254),
    [anon_sym_SLASH] = ACTIONS(6254),
    [anon_sym_PERCENT] = ACTIONS(6254),
    [anon_sym_PIPE_PIPE] = ACTIONS(6252),
    [anon_sym_AMP_AMP] = ACTIONS(6252),
    [anon_sym_PIPE] = ACTIONS(6254),
    [anon_sym_CARET] = ACTIONS(6254),
    [anon_sym_AMP] = ACTIONS(6254),
    [anon_sym_EQ_EQ] = ACTIONS(6252),
    [anon_sym_BANG_EQ] = ACTIONS(6252),
    [anon_sym_GT] = ACTIONS(6254),
    [anon_sym_GT_EQ] = ACTIONS(6252),
    [anon_sym_LT_EQ] = ACTIONS(6254),
    [anon_sym_LT] = ACTIONS(6254),
    [anon_sym_LT_LT] = ACTIONS(6254),
    [anon_sym_GT_GT] = ACTIONS(6254),
    [anon_sym_SEMI] = ACTIONS(6252),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6252),
    [anon_sym_RBRACE] = ACTIONS(6252),
    [anon_sym_LBRACK] = ACTIONS(6252),
    [anon_sym_RBRACK] = ACTIONS(6252),
    [anon_sym_EQ] = ACTIONS(6254),
    [anon_sym_COLON] = ACTIONS(6252),
    [anon_sym_QMARK] = ACTIONS(6252),
    [anon_sym_STAR_EQ] = ACTIONS(6252),
    [anon_sym_SLASH_EQ] = ACTIONS(6252),
    [anon_sym_PERCENT_EQ] = ACTIONS(6252),
    [anon_sym_PLUS_EQ] = ACTIONS(6252),
    [anon_sym_DASH_EQ] = ACTIONS(6252),
    [anon_sym_LT_LT_EQ] = ACTIONS(6252),
    [anon_sym_GT_GT_EQ] = ACTIONS(6252),
    [anon_sym_AMP_EQ] = ACTIONS(6252),
    [anon_sym_CARET_EQ] = ACTIONS(6252),
    [anon_sym_PIPE_EQ] = ACTIONS(6252),
    [anon_sym_and_eq] = ACTIONS(6254),
    [anon_sym_or_eq] = ACTIONS(6254),
    [anon_sym_xor_eq] = ACTIONS(6254),
    [anon_sym_LT_EQ_GT] = ACTIONS(6252),
    [anon_sym_or] = ACTIONS(6254),
    [anon_sym_and] = ACTIONS(6254),
    [anon_sym_bitor] = ACTIONS(6254),
    [anon_sym_xor] = ACTIONS(6254),
    [anon_sym_bitand] = ACTIONS(6254),
    [anon_sym_not_eq] = ACTIONS(6254),
    [anon_sym_DASH_DASH] = ACTIONS(6252),
    [anon_sym_PLUS_PLUS] = ACTIONS(6252),
    [anon_sym_DOT] = ACTIONS(6254),
    [anon_sym_DOT_STAR] = ACTIONS(6252),
    [anon_sym_DASH_GT] = ACTIONS(6252),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6254),
    [anon_sym_decltype] = ACTIONS(6254),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6252),
  },
  [STATE(2440)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_COLON] = ACTIONS(4305),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2441)] = {
    [sym_attribute_specifier] = STATE(2549),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6210),
    [anon_sym_COMMA] = ACTIONS(6210),
    [anon_sym_LPAREN2] = ACTIONS(6210),
    [anon_sym_DASH] = ACTIONS(6212),
    [anon_sym_PLUS] = ACTIONS(6212),
    [anon_sym_STAR] = ACTIONS(6210),
    [anon_sym_SLASH] = ACTIONS(6212),
    [anon_sym_PERCENT] = ACTIONS(6210),
    [anon_sym_PIPE_PIPE] = ACTIONS(6210),
    [anon_sym_AMP_AMP] = ACTIONS(6210),
    [anon_sym_PIPE] = ACTIONS(6212),
    [anon_sym_CARET] = ACTIONS(6210),
    [anon_sym_AMP] = ACTIONS(6212),
    [anon_sym_EQ_EQ] = ACTIONS(6210),
    [anon_sym_BANG_EQ] = ACTIONS(6210),
    [anon_sym_GT] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6212),
    [anon_sym_LT_EQ] = ACTIONS(6212),
    [anon_sym_LT] = ACTIONS(6212),
    [anon_sym_LT_LT] = ACTIONS(6212),
    [anon_sym_GT_GT] = ACTIONS(6212),
    [anon_sym___extension__] = ACTIONS(6210),
    [anon_sym___global__] = ACTIONS(6210),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6210),
    [anon_sym_LBRACK] = ACTIONS(6210),
    [anon_sym_const] = ACTIONS(6212),
    [anon_sym_constexpr] = ACTIONS(6210),
    [anon_sym_volatile] = ACTIONS(6210),
    [anon_sym_restrict] = ACTIONS(6210),
    [anon_sym___restrict__] = ACTIONS(6210),
    [anon_sym__Atomic] = ACTIONS(6210),
    [anon_sym__Noreturn] = ACTIONS(6210),
    [anon_sym_noreturn] = ACTIONS(6210),
    [anon_sym__Nonnull] = ACTIONS(6210),
    [anon_sym_mutable] = ACTIONS(6210),
    [anon_sym_constinit] = ACTIONS(6210),
    [anon_sym_consteval] = ACTIONS(6210),
    [anon_sym___shared__] = ACTIONS(6210),
    [anon_sym___local__] = ACTIONS(6210),
    [anon_sym___constant__] = ACTIONS(6210),
    [anon_sym___managed__] = ACTIONS(6210),
    [anon_sym___grid_constant__] = ACTIONS(6210),
    [anon_sym_alignas] = ACTIONS(6210),
    [anon_sym__Alignas] = ACTIONS(6210),
    [anon_sym_QMARK] = ACTIONS(6210),
    [anon_sym_LT_EQ_GT] = ACTIONS(6210),
    [anon_sym_or] = ACTIONS(6210),
    [anon_sym_and] = ACTIONS(6210),
    [anon_sym_bitor] = ACTIONS(6210),
    [anon_sym_xor] = ACTIONS(6210),
    [anon_sym_bitand] = ACTIONS(6210),
    [anon_sym_not_eq] = ACTIONS(6210),
    [anon_sym_DASH_DASH] = ACTIONS(6210),
    [anon_sym_PLUS_PLUS] = ACTIONS(6210),
    [anon_sym_DOT] = ACTIONS(6212),
    [anon_sym_DOT_STAR] = ACTIONS(6210),
    [anon_sym_DASH_GT] = ACTIONS(6210),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6210),
    [anon_sym_decltype] = ACTIONS(6210),
    [anon_sym_final] = ACTIONS(6210),
    [anon_sym_override] = ACTIONS(6210),
    [anon_sym_GT2] = ACTIONS(6210),
    [anon_sym_requires] = ACTIONS(6210),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6210),
  },
  [STATE(2442)] = {
    [sym_attribute_specifier] = STATE(2618),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6226),
    [anon_sym_COMMA] = ACTIONS(6226),
    [anon_sym_LPAREN2] = ACTIONS(6226),
    [anon_sym_DASH] = ACTIONS(6228),
    [anon_sym_PLUS] = ACTIONS(6228),
    [anon_sym_STAR] = ACTIONS(6226),
    [anon_sym_SLASH] = ACTIONS(6228),
    [anon_sym_PERCENT] = ACTIONS(6226),
    [anon_sym_PIPE_PIPE] = ACTIONS(6226),
    [anon_sym_AMP_AMP] = ACTIONS(6226),
    [anon_sym_PIPE] = ACTIONS(6228),
    [anon_sym_CARET] = ACTIONS(6226),
    [anon_sym_AMP] = ACTIONS(6228),
    [anon_sym_EQ_EQ] = ACTIONS(6226),
    [anon_sym_BANG_EQ] = ACTIONS(6226),
    [anon_sym_GT] = ACTIONS(6228),
    [anon_sym_GT_EQ] = ACTIONS(6228),
    [anon_sym_LT_EQ] = ACTIONS(6228),
    [anon_sym_LT] = ACTIONS(6228),
    [anon_sym_LT_LT] = ACTIONS(6228),
    [anon_sym_GT_GT] = ACTIONS(6228),
    [anon_sym___extension__] = ACTIONS(6226),
    [anon_sym___global__] = ACTIONS(6226),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6226),
    [anon_sym_LBRACK] = ACTIONS(6226),
    [anon_sym_const] = ACTIONS(6228),
    [anon_sym_constexpr] = ACTIONS(6226),
    [anon_sym_volatile] = ACTIONS(6226),
    [anon_sym_restrict] = ACTIONS(6226),
    [anon_sym___restrict__] = ACTIONS(6226),
    [anon_sym__Atomic] = ACTIONS(6226),
    [anon_sym__Noreturn] = ACTIONS(6226),
    [anon_sym_noreturn] = ACTIONS(6226),
    [anon_sym__Nonnull] = ACTIONS(6226),
    [anon_sym_mutable] = ACTIONS(6226),
    [anon_sym_constinit] = ACTIONS(6226),
    [anon_sym_consteval] = ACTIONS(6226),
    [anon_sym___shared__] = ACTIONS(6226),
    [anon_sym___local__] = ACTIONS(6226),
    [anon_sym___constant__] = ACTIONS(6226),
    [anon_sym___managed__] = ACTIONS(6226),
    [anon_sym___grid_constant__] = ACTIONS(6226),
    [anon_sym_alignas] = ACTIONS(6226),
    [anon_sym__Alignas] = ACTIONS(6226),
    [anon_sym_QMARK] = ACTIONS(6226),
    [anon_sym_LT_EQ_GT] = ACTIONS(6226),
    [anon_sym_or] = ACTIONS(6226),
    [anon_sym_and] = ACTIONS(6226),
    [anon_sym_bitor] = ACTIONS(6226),
    [anon_sym_xor] = ACTIONS(6226),
    [anon_sym_bitand] = ACTIONS(6226),
    [anon_sym_not_eq] = ACTIONS(6226),
    [anon_sym_DASH_DASH] = ACTIONS(6226),
    [anon_sym_PLUS_PLUS] = ACTIONS(6226),
    [anon_sym_DOT] = ACTIONS(6228),
    [anon_sym_DOT_STAR] = ACTIONS(6226),
    [anon_sym_DASH_GT] = ACTIONS(6226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6226),
    [anon_sym_decltype] = ACTIONS(6226),
    [anon_sym_final] = ACTIONS(6226),
    [anon_sym_override] = ACTIONS(6226),
    [anon_sym_GT2] = ACTIONS(6226),
    [anon_sym_requires] = ACTIONS(6226),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6226),
  },
  [STATE(2443)] = {
    [sym_template_argument_list] = STATE(2970),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_LPAREN2] = ACTIONS(4025),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_STAR] = ACTIONS(4010),
    [anon_sym_AMP_AMP] = ACTIONS(4010),
    [anon_sym_AMP] = ACTIONS(4002),
    [anon_sym_LT] = ACTIONS(6076),
    [anon_sym_SEMI] = ACTIONS(4010),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4025),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym___cdecl] = ACTIONS(4002),
    [anon_sym___clrcall] = ACTIONS(4002),
    [anon_sym___stdcall] = ACTIONS(4002),
    [anon_sym___fastcall] = ACTIONS(4002),
    [anon_sym___thiscall] = ACTIONS(4002),
    [anon_sym___vectorcall] = ACTIONS(4002),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(6477),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(2444)] = {
    [sym_attribute_specifier] = STATE(2489),
    [sym_identifier] = ACTIONS(6212),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6210),
    [anon_sym_COMMA] = ACTIONS(6210),
    [anon_sym_RPAREN] = ACTIONS(6210),
    [aux_sym_preproc_if_token2] = ACTIONS(6210),
    [aux_sym_preproc_else_token1] = ACTIONS(6210),
    [aux_sym_preproc_elif_token1] = ACTIONS(6212),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6210),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6210),
    [anon_sym_LPAREN2] = ACTIONS(6210),
    [anon_sym_DASH] = ACTIONS(6212),
    [anon_sym_PLUS] = ACTIONS(6212),
    [anon_sym_STAR] = ACTIONS(6212),
    [anon_sym_SLASH] = ACTIONS(6212),
    [anon_sym_PERCENT] = ACTIONS(6212),
    [anon_sym_PIPE_PIPE] = ACTIONS(6210),
    [anon_sym_AMP_AMP] = ACTIONS(6210),
    [anon_sym_PIPE] = ACTIONS(6212),
    [anon_sym_CARET] = ACTIONS(6212),
    [anon_sym_AMP] = ACTIONS(6212),
    [anon_sym_EQ_EQ] = ACTIONS(6210),
    [anon_sym_BANG_EQ] = ACTIONS(6210),
    [anon_sym_GT] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6210),
    [anon_sym_LT_EQ] = ACTIONS(6212),
    [anon_sym_LT] = ACTIONS(6212),
    [anon_sym_LT_LT] = ACTIONS(6212),
    [anon_sym_GT_GT] = ACTIONS(6212),
    [anon_sym_SEMI] = ACTIONS(6210),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6210),
    [anon_sym_RBRACE] = ACTIONS(6210),
    [anon_sym_LBRACK] = ACTIONS(6210),
    [anon_sym_RBRACK] = ACTIONS(6210),
    [anon_sym_EQ] = ACTIONS(6212),
    [anon_sym_COLON] = ACTIONS(6210),
    [anon_sym_QMARK] = ACTIONS(6210),
    [anon_sym_STAR_EQ] = ACTIONS(6210),
    [anon_sym_SLASH_EQ] = ACTIONS(6210),
    [anon_sym_PERCENT_EQ] = ACTIONS(6210),
    [anon_sym_PLUS_EQ] = ACTIONS(6210),
    [anon_sym_DASH_EQ] = ACTIONS(6210),
    [anon_sym_LT_LT_EQ] = ACTIONS(6210),
    [anon_sym_GT_GT_EQ] = ACTIONS(6210),
    [anon_sym_AMP_EQ] = ACTIONS(6210),
    [anon_sym_CARET_EQ] = ACTIONS(6210),
    [anon_sym_PIPE_EQ] = ACTIONS(6210),
    [anon_sym_and_eq] = ACTIONS(6212),
    [anon_sym_or_eq] = ACTIONS(6212),
    [anon_sym_xor_eq] = ACTIONS(6212),
    [anon_sym_LT_EQ_GT] = ACTIONS(6210),
    [anon_sym_or] = ACTIONS(6212),
    [anon_sym_and] = ACTIONS(6212),
    [anon_sym_bitor] = ACTIONS(6212),
    [anon_sym_xor] = ACTIONS(6212),
    [anon_sym_bitand] = ACTIONS(6212),
    [anon_sym_not_eq] = ACTIONS(6212),
    [anon_sym_DASH_DASH] = ACTIONS(6210),
    [anon_sym_PLUS_PLUS] = ACTIONS(6210),
    [anon_sym_DOT] = ACTIONS(6212),
    [anon_sym_DOT_STAR] = ACTIONS(6210),
    [anon_sym_DASH_GT] = ACTIONS(6210),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6212),
    [anon_sym_decltype] = ACTIONS(6212),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6210),
  },
  [STATE(2445)] = {
    [sym_attribute_specifier] = STATE(2490),
    [sym_identifier] = ACTIONS(6228),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6226),
    [anon_sym_COMMA] = ACTIONS(6226),
    [anon_sym_RPAREN] = ACTIONS(6226),
    [aux_sym_preproc_if_token2] = ACTIONS(6226),
    [aux_sym_preproc_else_token1] = ACTIONS(6226),
    [aux_sym_preproc_elif_token1] = ACTIONS(6228),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6226),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6226),
    [anon_sym_LPAREN2] = ACTIONS(6226),
    [anon_sym_DASH] = ACTIONS(6228),
    [anon_sym_PLUS] = ACTIONS(6228),
    [anon_sym_STAR] = ACTIONS(6228),
    [anon_sym_SLASH] = ACTIONS(6228),
    [anon_sym_PERCENT] = ACTIONS(6228),
    [anon_sym_PIPE_PIPE] = ACTIONS(6226),
    [anon_sym_AMP_AMP] = ACTIONS(6226),
    [anon_sym_PIPE] = ACTIONS(6228),
    [anon_sym_CARET] = ACTIONS(6228),
    [anon_sym_AMP] = ACTIONS(6228),
    [anon_sym_EQ_EQ] = ACTIONS(6226),
    [anon_sym_BANG_EQ] = ACTIONS(6226),
    [anon_sym_GT] = ACTIONS(6228),
    [anon_sym_GT_EQ] = ACTIONS(6226),
    [anon_sym_LT_EQ] = ACTIONS(6228),
    [anon_sym_LT] = ACTIONS(6228),
    [anon_sym_LT_LT] = ACTIONS(6228),
    [anon_sym_GT_GT] = ACTIONS(6228),
    [anon_sym_SEMI] = ACTIONS(6226),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6226),
    [anon_sym_RBRACE] = ACTIONS(6226),
    [anon_sym_LBRACK] = ACTIONS(6226),
    [anon_sym_RBRACK] = ACTIONS(6226),
    [anon_sym_EQ] = ACTIONS(6228),
    [anon_sym_COLON] = ACTIONS(6226),
    [anon_sym_QMARK] = ACTIONS(6226),
    [anon_sym_STAR_EQ] = ACTIONS(6226),
    [anon_sym_SLASH_EQ] = ACTIONS(6226),
    [anon_sym_PERCENT_EQ] = ACTIONS(6226),
    [anon_sym_PLUS_EQ] = ACTIONS(6226),
    [anon_sym_DASH_EQ] = ACTIONS(6226),
    [anon_sym_LT_LT_EQ] = ACTIONS(6226),
    [anon_sym_GT_GT_EQ] = ACTIONS(6226),
    [anon_sym_AMP_EQ] = ACTIONS(6226),
    [anon_sym_CARET_EQ] = ACTIONS(6226),
    [anon_sym_PIPE_EQ] = ACTIONS(6226),
    [anon_sym_and_eq] = ACTIONS(6228),
    [anon_sym_or_eq] = ACTIONS(6228),
    [anon_sym_xor_eq] = ACTIONS(6228),
    [anon_sym_LT_EQ_GT] = ACTIONS(6226),
    [anon_sym_or] = ACTIONS(6228),
    [anon_sym_and] = ACTIONS(6228),
    [anon_sym_bitor] = ACTIONS(6228),
    [anon_sym_xor] = ACTIONS(6228),
    [anon_sym_bitand] = ACTIONS(6228),
    [anon_sym_not_eq] = ACTIONS(6228),
    [anon_sym_DASH_DASH] = ACTIONS(6226),
    [anon_sym_PLUS_PLUS] = ACTIONS(6226),
    [anon_sym_DOT] = ACTIONS(6228),
    [anon_sym_DOT_STAR] = ACTIONS(6226),
    [anon_sym_DASH_GT] = ACTIONS(6226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6228),
    [anon_sym_decltype] = ACTIONS(6228),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6226),
  },
  [STATE(2446)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5684),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym___extension__] = ACTIONS(5686),
    [anon_sym___global__] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5686),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5686),
    [anon_sym_volatile] = ACTIONS(5686),
    [anon_sym_restrict] = ACTIONS(5686),
    [anon_sym___restrict__] = ACTIONS(5686),
    [anon_sym__Atomic] = ACTIONS(5686),
    [anon_sym__Noreturn] = ACTIONS(5686),
    [anon_sym_noreturn] = ACTIONS(5686),
    [anon_sym__Nonnull] = ACTIONS(5686),
    [anon_sym_mutable] = ACTIONS(5686),
    [anon_sym_constinit] = ACTIONS(5686),
    [anon_sym_consteval] = ACTIONS(5686),
    [anon_sym___shared__] = ACTIONS(5686),
    [anon_sym___local__] = ACTIONS(5686),
    [anon_sym___constant__] = ACTIONS(5686),
    [anon_sym___managed__] = ACTIONS(5686),
    [anon_sym___grid_constant__] = ACTIONS(5686),
    [anon_sym_alignas] = ACTIONS(5686),
    [anon_sym__Alignas] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_bitor] = ACTIONS(5686),
    [anon_sym_xor] = ACTIONS(5686),
    [anon_sym_bitand] = ACTIONS(5686),
    [anon_sym_not_eq] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5686),
    [anon_sym_decltype] = ACTIONS(5686),
    [anon_sym_final] = ACTIONS(5686),
    [anon_sym_override] = ACTIONS(5686),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_requires] = ACTIONS(5686),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2447)] = {
    [sym_attribute_specifier] = STATE(2499),
    [sym_identifier] = ACTIONS(6240),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6238),
    [anon_sym_COMMA] = ACTIONS(6238),
    [anon_sym_RPAREN] = ACTIONS(6238),
    [aux_sym_preproc_if_token2] = ACTIONS(6238),
    [aux_sym_preproc_else_token1] = ACTIONS(6238),
    [aux_sym_preproc_elif_token1] = ACTIONS(6240),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6238),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6238),
    [anon_sym_LPAREN2] = ACTIONS(6238),
    [anon_sym_DASH] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6240),
    [anon_sym_STAR] = ACTIONS(6240),
    [anon_sym_SLASH] = ACTIONS(6240),
    [anon_sym_PERCENT] = ACTIONS(6240),
    [anon_sym_PIPE_PIPE] = ACTIONS(6238),
    [anon_sym_AMP_AMP] = ACTIONS(6238),
    [anon_sym_PIPE] = ACTIONS(6240),
    [anon_sym_CARET] = ACTIONS(6240),
    [anon_sym_AMP] = ACTIONS(6240),
    [anon_sym_EQ_EQ] = ACTIONS(6238),
    [anon_sym_BANG_EQ] = ACTIONS(6238),
    [anon_sym_GT] = ACTIONS(6240),
    [anon_sym_GT_EQ] = ACTIONS(6238),
    [anon_sym_LT_EQ] = ACTIONS(6240),
    [anon_sym_LT] = ACTIONS(6240),
    [anon_sym_LT_LT] = ACTIONS(6240),
    [anon_sym_GT_GT] = ACTIONS(6240),
    [anon_sym_SEMI] = ACTIONS(6238),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6238),
    [anon_sym_RBRACE] = ACTIONS(6238),
    [anon_sym_LBRACK] = ACTIONS(6238),
    [anon_sym_RBRACK] = ACTIONS(6238),
    [anon_sym_EQ] = ACTIONS(6240),
    [anon_sym_COLON] = ACTIONS(6238),
    [anon_sym_QMARK] = ACTIONS(6238),
    [anon_sym_STAR_EQ] = ACTIONS(6238),
    [anon_sym_SLASH_EQ] = ACTIONS(6238),
    [anon_sym_PERCENT_EQ] = ACTIONS(6238),
    [anon_sym_PLUS_EQ] = ACTIONS(6238),
    [anon_sym_DASH_EQ] = ACTIONS(6238),
    [anon_sym_LT_LT_EQ] = ACTIONS(6238),
    [anon_sym_GT_GT_EQ] = ACTIONS(6238),
    [anon_sym_AMP_EQ] = ACTIONS(6238),
    [anon_sym_CARET_EQ] = ACTIONS(6238),
    [anon_sym_PIPE_EQ] = ACTIONS(6238),
    [anon_sym_and_eq] = ACTIONS(6240),
    [anon_sym_or_eq] = ACTIONS(6240),
    [anon_sym_xor_eq] = ACTIONS(6240),
    [anon_sym_LT_EQ_GT] = ACTIONS(6238),
    [anon_sym_or] = ACTIONS(6240),
    [anon_sym_and] = ACTIONS(6240),
    [anon_sym_bitor] = ACTIONS(6240),
    [anon_sym_xor] = ACTIONS(6240),
    [anon_sym_bitand] = ACTIONS(6240),
    [anon_sym_not_eq] = ACTIONS(6240),
    [anon_sym_DASH_DASH] = ACTIONS(6238),
    [anon_sym_PLUS_PLUS] = ACTIONS(6238),
    [anon_sym_DOT] = ACTIONS(6240),
    [anon_sym_DOT_STAR] = ACTIONS(6238),
    [anon_sym_DASH_GT] = ACTIONS(6238),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6240),
    [anon_sym_decltype] = ACTIONS(6240),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6238),
  },
  [STATE(2448)] = {
    [sym_attribute_specifier] = STATE(2514),
    [sym_identifier] = ACTIONS(6244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6242),
    [anon_sym_COMMA] = ACTIONS(6242),
    [anon_sym_RPAREN] = ACTIONS(6242),
    [aux_sym_preproc_if_token2] = ACTIONS(6242),
    [aux_sym_preproc_else_token1] = ACTIONS(6242),
    [aux_sym_preproc_elif_token1] = ACTIONS(6244),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6242),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6242),
    [anon_sym_LPAREN2] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6244),
    [anon_sym_PLUS] = ACTIONS(6244),
    [anon_sym_STAR] = ACTIONS(6244),
    [anon_sym_SLASH] = ACTIONS(6244),
    [anon_sym_PERCENT] = ACTIONS(6244),
    [anon_sym_PIPE_PIPE] = ACTIONS(6242),
    [anon_sym_AMP_AMP] = ACTIONS(6242),
    [anon_sym_PIPE] = ACTIONS(6244),
    [anon_sym_CARET] = ACTIONS(6244),
    [anon_sym_AMP] = ACTIONS(6244),
    [anon_sym_EQ_EQ] = ACTIONS(6242),
    [anon_sym_BANG_EQ] = ACTIONS(6242),
    [anon_sym_GT] = ACTIONS(6244),
    [anon_sym_GT_EQ] = ACTIONS(6242),
    [anon_sym_LT_EQ] = ACTIONS(6244),
    [anon_sym_LT] = ACTIONS(6244),
    [anon_sym_LT_LT] = ACTIONS(6244),
    [anon_sym_GT_GT] = ACTIONS(6244),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6242),
    [anon_sym_RBRACE] = ACTIONS(6242),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [anon_sym_RBRACK] = ACTIONS(6242),
    [anon_sym_EQ] = ACTIONS(6244),
    [anon_sym_COLON] = ACTIONS(6242),
    [anon_sym_QMARK] = ACTIONS(6242),
    [anon_sym_STAR_EQ] = ACTIONS(6242),
    [anon_sym_SLASH_EQ] = ACTIONS(6242),
    [anon_sym_PERCENT_EQ] = ACTIONS(6242),
    [anon_sym_PLUS_EQ] = ACTIONS(6242),
    [anon_sym_DASH_EQ] = ACTIONS(6242),
    [anon_sym_LT_LT_EQ] = ACTIONS(6242),
    [anon_sym_GT_GT_EQ] = ACTIONS(6242),
    [anon_sym_AMP_EQ] = ACTIONS(6242),
    [anon_sym_CARET_EQ] = ACTIONS(6242),
    [anon_sym_PIPE_EQ] = ACTIONS(6242),
    [anon_sym_and_eq] = ACTIONS(6244),
    [anon_sym_or_eq] = ACTIONS(6244),
    [anon_sym_xor_eq] = ACTIONS(6244),
    [anon_sym_LT_EQ_GT] = ACTIONS(6242),
    [anon_sym_or] = ACTIONS(6244),
    [anon_sym_and] = ACTIONS(6244),
    [anon_sym_bitor] = ACTIONS(6244),
    [anon_sym_xor] = ACTIONS(6244),
    [anon_sym_bitand] = ACTIONS(6244),
    [anon_sym_not_eq] = ACTIONS(6244),
    [anon_sym_DASH_DASH] = ACTIONS(6242),
    [anon_sym_PLUS_PLUS] = ACTIONS(6242),
    [anon_sym_DOT] = ACTIONS(6244),
    [anon_sym_DOT_STAR] = ACTIONS(6242),
    [anon_sym_DASH_GT] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6244),
    [anon_sym_decltype] = ACTIONS(6244),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6242),
  },
  [STATE(2449)] = {
    [sym_attribute_declaration] = STATE(2587),
    [sym_parameter_list] = STATE(2589),
    [aux_sym_attributed_declarator_repeat1] = STATE(2587),
    [sym_identifier] = ACTIONS(6480),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6482),
    [anon_sym_COMMA] = ACTIONS(6482),
    [anon_sym_RPAREN] = ACTIONS(6482),
    [aux_sym_preproc_if_token2] = ACTIONS(6482),
    [aux_sym_preproc_else_token1] = ACTIONS(6482),
    [aux_sym_preproc_elif_token1] = ACTIONS(6480),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6482),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6482),
    [anon_sym_LPAREN2] = ACTIONS(6442),
    [anon_sym_DASH] = ACTIONS(6480),
    [anon_sym_PLUS] = ACTIONS(6480),
    [anon_sym_STAR] = ACTIONS(6480),
    [anon_sym_SLASH] = ACTIONS(6480),
    [anon_sym_PERCENT] = ACTIONS(6480),
    [anon_sym_PIPE_PIPE] = ACTIONS(6482),
    [anon_sym_AMP_AMP] = ACTIONS(6482),
    [anon_sym_PIPE] = ACTIONS(6480),
    [anon_sym_CARET] = ACTIONS(6480),
    [anon_sym_AMP] = ACTIONS(6480),
    [anon_sym_EQ_EQ] = ACTIONS(6482),
    [anon_sym_BANG_EQ] = ACTIONS(6482),
    [anon_sym_GT] = ACTIONS(6480),
    [anon_sym_GT_EQ] = ACTIONS(6482),
    [anon_sym_LT_EQ] = ACTIONS(6480),
    [anon_sym_LT] = ACTIONS(6480),
    [anon_sym_LT_LT] = ACTIONS(6480),
    [anon_sym_GT_GT] = ACTIONS(6480),
    [anon_sym_SEMI] = ACTIONS(6482),
    [anon_sym___attribute__] = ACTIONS(6480),
    [anon_sym___attribute] = ACTIONS(6480),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6444),
    [anon_sym_RBRACE] = ACTIONS(6482),
    [anon_sym_LBRACK] = ACTIONS(6446),
    [anon_sym_RBRACK] = ACTIONS(6482),
    [anon_sym_EQ] = ACTIONS(6480),
    [anon_sym_COLON] = ACTIONS(6482),
    [anon_sym_QMARK] = ACTIONS(6482),
    [anon_sym_STAR_EQ] = ACTIONS(6482),
    [anon_sym_SLASH_EQ] = ACTIONS(6482),
    [anon_sym_PERCENT_EQ] = ACTIONS(6482),
    [anon_sym_PLUS_EQ] = ACTIONS(6482),
    [anon_sym_DASH_EQ] = ACTIONS(6482),
    [anon_sym_LT_LT_EQ] = ACTIONS(6482),
    [anon_sym_GT_GT_EQ] = ACTIONS(6482),
    [anon_sym_AMP_EQ] = ACTIONS(6482),
    [anon_sym_CARET_EQ] = ACTIONS(6482),
    [anon_sym_PIPE_EQ] = ACTIONS(6482),
    [anon_sym_and_eq] = ACTIONS(6480),
    [anon_sym_or_eq] = ACTIONS(6480),
    [anon_sym_xor_eq] = ACTIONS(6480),
    [anon_sym_LT_EQ_GT] = ACTIONS(6482),
    [anon_sym_or] = ACTIONS(6480),
    [anon_sym_and] = ACTIONS(6480),
    [anon_sym_bitor] = ACTIONS(6480),
    [anon_sym_xor] = ACTIONS(6480),
    [anon_sym_bitand] = ACTIONS(6480),
    [anon_sym_not_eq] = ACTIONS(6480),
    [anon_sym_DASH_DASH] = ACTIONS(6482),
    [anon_sym_PLUS_PLUS] = ACTIONS(6482),
    [anon_sym_DOT] = ACTIONS(6480),
    [anon_sym_DOT_STAR] = ACTIONS(6482),
    [anon_sym_DASH_GT] = ACTIONS(6482),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6482),
  },
  [STATE(2450)] = {
    [sym_attribute_specifier] = STATE(2577),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6277),
    [anon_sym_COMMA] = ACTIONS(6277),
    [anon_sym_LPAREN2] = ACTIONS(6277),
    [anon_sym_DASH] = ACTIONS(6279),
    [anon_sym_PLUS] = ACTIONS(6279),
    [anon_sym_STAR] = ACTIONS(6277),
    [anon_sym_SLASH] = ACTIONS(6279),
    [anon_sym_PERCENT] = ACTIONS(6277),
    [anon_sym_PIPE_PIPE] = ACTIONS(6277),
    [anon_sym_AMP_AMP] = ACTIONS(6277),
    [anon_sym_PIPE] = ACTIONS(6279),
    [anon_sym_CARET] = ACTIONS(6277),
    [anon_sym_AMP] = ACTIONS(6279),
    [anon_sym_EQ_EQ] = ACTIONS(6277),
    [anon_sym_BANG_EQ] = ACTIONS(6277),
    [anon_sym_GT] = ACTIONS(6279),
    [anon_sym_GT_EQ] = ACTIONS(6279),
    [anon_sym_LT_EQ] = ACTIONS(6279),
    [anon_sym_LT] = ACTIONS(6279),
    [anon_sym_LT_LT] = ACTIONS(6279),
    [anon_sym_GT_GT] = ACTIONS(6279),
    [anon_sym___extension__] = ACTIONS(6277),
    [anon_sym___global__] = ACTIONS(6277),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6277),
    [anon_sym_LBRACK] = ACTIONS(6277),
    [anon_sym_const] = ACTIONS(6279),
    [anon_sym_constexpr] = ACTIONS(6277),
    [anon_sym_volatile] = ACTIONS(6277),
    [anon_sym_restrict] = ACTIONS(6277),
    [anon_sym___restrict__] = ACTIONS(6277),
    [anon_sym__Atomic] = ACTIONS(6277),
    [anon_sym__Noreturn] = ACTIONS(6277),
    [anon_sym_noreturn] = ACTIONS(6277),
    [anon_sym__Nonnull] = ACTIONS(6277),
    [anon_sym_mutable] = ACTIONS(6277),
    [anon_sym_constinit] = ACTIONS(6277),
    [anon_sym_consteval] = ACTIONS(6277),
    [anon_sym___shared__] = ACTIONS(6277),
    [anon_sym___local__] = ACTIONS(6277),
    [anon_sym___constant__] = ACTIONS(6277),
    [anon_sym___managed__] = ACTIONS(6277),
    [anon_sym___grid_constant__] = ACTIONS(6277),
    [anon_sym_alignas] = ACTIONS(6277),
    [anon_sym__Alignas] = ACTIONS(6277),
    [anon_sym_QMARK] = ACTIONS(6277),
    [anon_sym_LT_EQ_GT] = ACTIONS(6277),
    [anon_sym_or] = ACTIONS(6277),
    [anon_sym_and] = ACTIONS(6277),
    [anon_sym_bitor] = ACTIONS(6277),
    [anon_sym_xor] = ACTIONS(6277),
    [anon_sym_bitand] = ACTIONS(6277),
    [anon_sym_not_eq] = ACTIONS(6277),
    [anon_sym_DASH_DASH] = ACTIONS(6277),
    [anon_sym_PLUS_PLUS] = ACTIONS(6277),
    [anon_sym_DOT] = ACTIONS(6279),
    [anon_sym_DOT_STAR] = ACTIONS(6277),
    [anon_sym_DASH_GT] = ACTIONS(6277),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6277),
    [anon_sym_decltype] = ACTIONS(6277),
    [anon_sym_final] = ACTIONS(6277),
    [anon_sym_override] = ACTIONS(6277),
    [anon_sym_GT2] = ACTIONS(6277),
    [anon_sym_requires] = ACTIONS(6277),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6277),
  },
  [STATE(2451)] = {
    [sym_attribute_specifier] = STATE(2573),
    [sym_identifier] = ACTIONS(6260),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6258),
    [anon_sym_COMMA] = ACTIONS(6258),
    [anon_sym_RPAREN] = ACTIONS(6258),
    [aux_sym_preproc_if_token2] = ACTIONS(6258),
    [aux_sym_preproc_else_token1] = ACTIONS(6258),
    [aux_sym_preproc_elif_token1] = ACTIONS(6260),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6258),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6258),
    [anon_sym_LPAREN2] = ACTIONS(6258),
    [anon_sym_DASH] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6260),
    [anon_sym_STAR] = ACTIONS(6260),
    [anon_sym_SLASH] = ACTIONS(6260),
    [anon_sym_PERCENT] = ACTIONS(6260),
    [anon_sym_PIPE_PIPE] = ACTIONS(6258),
    [anon_sym_AMP_AMP] = ACTIONS(6258),
    [anon_sym_PIPE] = ACTIONS(6260),
    [anon_sym_CARET] = ACTIONS(6260),
    [anon_sym_AMP] = ACTIONS(6260),
    [anon_sym_EQ_EQ] = ACTIONS(6258),
    [anon_sym_BANG_EQ] = ACTIONS(6258),
    [anon_sym_GT] = ACTIONS(6260),
    [anon_sym_GT_EQ] = ACTIONS(6258),
    [anon_sym_LT_EQ] = ACTIONS(6260),
    [anon_sym_LT] = ACTIONS(6260),
    [anon_sym_LT_LT] = ACTIONS(6260),
    [anon_sym_GT_GT] = ACTIONS(6260),
    [anon_sym_SEMI] = ACTIONS(6258),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6258),
    [anon_sym_RBRACE] = ACTIONS(6258),
    [anon_sym_LBRACK] = ACTIONS(6258),
    [anon_sym_RBRACK] = ACTIONS(6258),
    [anon_sym_EQ] = ACTIONS(6260),
    [anon_sym_COLON] = ACTIONS(6258),
    [anon_sym_QMARK] = ACTIONS(6258),
    [anon_sym_STAR_EQ] = ACTIONS(6258),
    [anon_sym_SLASH_EQ] = ACTIONS(6258),
    [anon_sym_PERCENT_EQ] = ACTIONS(6258),
    [anon_sym_PLUS_EQ] = ACTIONS(6258),
    [anon_sym_DASH_EQ] = ACTIONS(6258),
    [anon_sym_LT_LT_EQ] = ACTIONS(6258),
    [anon_sym_GT_GT_EQ] = ACTIONS(6258),
    [anon_sym_AMP_EQ] = ACTIONS(6258),
    [anon_sym_CARET_EQ] = ACTIONS(6258),
    [anon_sym_PIPE_EQ] = ACTIONS(6258),
    [anon_sym_and_eq] = ACTIONS(6260),
    [anon_sym_or_eq] = ACTIONS(6260),
    [anon_sym_xor_eq] = ACTIONS(6260),
    [anon_sym_LT_EQ_GT] = ACTIONS(6258),
    [anon_sym_or] = ACTIONS(6260),
    [anon_sym_and] = ACTIONS(6260),
    [anon_sym_bitor] = ACTIONS(6260),
    [anon_sym_xor] = ACTIONS(6260),
    [anon_sym_bitand] = ACTIONS(6260),
    [anon_sym_not_eq] = ACTIONS(6260),
    [anon_sym_DASH_DASH] = ACTIONS(6258),
    [anon_sym_PLUS_PLUS] = ACTIONS(6258),
    [anon_sym_DOT] = ACTIONS(6260),
    [anon_sym_DOT_STAR] = ACTIONS(6258),
    [anon_sym_DASH_GT] = ACTIONS(6258),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6260),
    [anon_sym_decltype] = ACTIONS(6260),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6258),
  },
  [STATE(2452)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_COLON] = ACTIONS(4069),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2453)] = {
    [sym_template_argument_list] = STATE(1659),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2641),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6074),
    [anon_sym_COMMA] = ACTIONS(6074),
    [anon_sym_RPAREN] = ACTIONS(6074),
    [anon_sym_LPAREN2] = ACTIONS(6074),
    [anon_sym_DASH] = ACTIONS(6072),
    [anon_sym_PLUS] = ACTIONS(6072),
    [anon_sym_STAR] = ACTIONS(6072),
    [anon_sym_SLASH] = ACTIONS(6072),
    [anon_sym_PERCENT] = ACTIONS(6072),
    [anon_sym_PIPE_PIPE] = ACTIONS(6074),
    [anon_sym_AMP_AMP] = ACTIONS(6074),
    [anon_sym_PIPE] = ACTIONS(6072),
    [anon_sym_CARET] = ACTIONS(6072),
    [anon_sym_AMP] = ACTIONS(6072),
    [anon_sym_EQ_EQ] = ACTIONS(6074),
    [anon_sym_BANG_EQ] = ACTIONS(6074),
    [anon_sym_GT] = ACTIONS(6072),
    [anon_sym_GT_EQ] = ACTIONS(6074),
    [anon_sym_LT_EQ] = ACTIONS(6072),
    [anon_sym_LT] = ACTIONS(6072),
    [anon_sym_LT_LT] = ACTIONS(6072),
    [anon_sym_GT_GT] = ACTIONS(6072),
    [anon_sym_SEMI] = ACTIONS(6074),
    [anon_sym___attribute__] = ACTIONS(6074),
    [anon_sym___attribute] = ACTIONS(6072),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(6074),
    [anon_sym_RBRACE] = ACTIONS(6074),
    [anon_sym_signed] = ACTIONS(6484),
    [anon_sym_unsigned] = ACTIONS(6484),
    [anon_sym_long] = ACTIONS(6484),
    [anon_sym_short] = ACTIONS(6484),
    [anon_sym_LBRACK] = ACTIONS(6074),
    [anon_sym_RBRACK] = ACTIONS(6074),
    [anon_sym_EQ] = ACTIONS(6072),
    [anon_sym_COLON] = ACTIONS(6072),
    [anon_sym_QMARK] = ACTIONS(6074),
    [anon_sym_STAR_EQ] = ACTIONS(6074),
    [anon_sym_SLASH_EQ] = ACTIONS(6074),
    [anon_sym_PERCENT_EQ] = ACTIONS(6074),
    [anon_sym_PLUS_EQ] = ACTIONS(6074),
    [anon_sym_DASH_EQ] = ACTIONS(6074),
    [anon_sym_LT_LT_EQ] = ACTIONS(6074),
    [anon_sym_GT_GT_EQ] = ACTIONS(6074),
    [anon_sym_AMP_EQ] = ACTIONS(6074),
    [anon_sym_CARET_EQ] = ACTIONS(6074),
    [anon_sym_PIPE_EQ] = ACTIONS(6074),
    [anon_sym_and_eq] = ACTIONS(6074),
    [anon_sym_or_eq] = ACTIONS(6074),
    [anon_sym_xor_eq] = ACTIONS(6074),
    [anon_sym_LT_EQ_GT] = ACTIONS(6074),
    [anon_sym_or] = ACTIONS(6072),
    [anon_sym_and] = ACTIONS(6072),
    [anon_sym_bitor] = ACTIONS(6074),
    [anon_sym_xor] = ACTIONS(6072),
    [anon_sym_bitand] = ACTIONS(6074),
    [anon_sym_not_eq] = ACTIONS(6074),
    [anon_sym_DASH_DASH] = ACTIONS(6074),
    [anon_sym_PLUS_PLUS] = ACTIONS(6074),
    [anon_sym_DOT] = ACTIONS(6072),
    [anon_sym_DOT_STAR] = ACTIONS(6074),
    [anon_sym_DASH_GT] = ACTIONS(6074),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6074),
    [anon_sym_decltype] = ACTIONS(6074),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6074),
  },
  [STATE(2454)] = {
    [sym_attribute_specifier] = STATE(2580),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6248),
    [anon_sym_COMMA] = ACTIONS(6248),
    [anon_sym_LPAREN2] = ACTIONS(6248),
    [anon_sym_DASH] = ACTIONS(6250),
    [anon_sym_PLUS] = ACTIONS(6250),
    [anon_sym_STAR] = ACTIONS(6248),
    [anon_sym_SLASH] = ACTIONS(6250),
    [anon_sym_PERCENT] = ACTIONS(6248),
    [anon_sym_PIPE_PIPE] = ACTIONS(6248),
    [anon_sym_AMP_AMP] = ACTIONS(6248),
    [anon_sym_PIPE] = ACTIONS(6250),
    [anon_sym_CARET] = ACTIONS(6248),
    [anon_sym_AMP] = ACTIONS(6250),
    [anon_sym_EQ_EQ] = ACTIONS(6248),
    [anon_sym_BANG_EQ] = ACTIONS(6248),
    [anon_sym_GT] = ACTIONS(6250),
    [anon_sym_GT_EQ] = ACTIONS(6250),
    [anon_sym_LT_EQ] = ACTIONS(6250),
    [anon_sym_LT] = ACTIONS(6250),
    [anon_sym_LT_LT] = ACTIONS(6250),
    [anon_sym_GT_GT] = ACTIONS(6250),
    [anon_sym___extension__] = ACTIONS(6248),
    [anon_sym___global__] = ACTIONS(6248),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6248),
    [anon_sym_LBRACK] = ACTIONS(6248),
    [anon_sym_const] = ACTIONS(6250),
    [anon_sym_constexpr] = ACTIONS(6248),
    [anon_sym_volatile] = ACTIONS(6248),
    [anon_sym_restrict] = ACTIONS(6248),
    [anon_sym___restrict__] = ACTIONS(6248),
    [anon_sym__Atomic] = ACTIONS(6248),
    [anon_sym__Noreturn] = ACTIONS(6248),
    [anon_sym_noreturn] = ACTIONS(6248),
    [anon_sym__Nonnull] = ACTIONS(6248),
    [anon_sym_mutable] = ACTIONS(6248),
    [anon_sym_constinit] = ACTIONS(6248),
    [anon_sym_consteval] = ACTIONS(6248),
    [anon_sym___shared__] = ACTIONS(6248),
    [anon_sym___local__] = ACTIONS(6248),
    [anon_sym___constant__] = ACTIONS(6248),
    [anon_sym___managed__] = ACTIONS(6248),
    [anon_sym___grid_constant__] = ACTIONS(6248),
    [anon_sym_alignas] = ACTIONS(6248),
    [anon_sym__Alignas] = ACTIONS(6248),
    [anon_sym_QMARK] = ACTIONS(6248),
    [anon_sym_LT_EQ_GT] = ACTIONS(6248),
    [anon_sym_or] = ACTIONS(6248),
    [anon_sym_and] = ACTIONS(6248),
    [anon_sym_bitor] = ACTIONS(6248),
    [anon_sym_xor] = ACTIONS(6248),
    [anon_sym_bitand] = ACTIONS(6248),
    [anon_sym_not_eq] = ACTIONS(6248),
    [anon_sym_DASH_DASH] = ACTIONS(6248),
    [anon_sym_PLUS_PLUS] = ACTIONS(6248),
    [anon_sym_DOT] = ACTIONS(6250),
    [anon_sym_DOT_STAR] = ACTIONS(6248),
    [anon_sym_DASH_GT] = ACTIONS(6248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6248),
    [anon_sym_decltype] = ACTIONS(6248),
    [anon_sym_final] = ACTIONS(6248),
    [anon_sym_override] = ACTIONS(6248),
    [anon_sym_GT2] = ACTIONS(6248),
    [anon_sym_requires] = ACTIONS(6248),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6248),
  },
  [STATE(2455)] = {
    [sym_attribute_specifier] = STATE(2574),
    [sym_identifier] = ACTIONS(6268),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6266),
    [anon_sym_COMMA] = ACTIONS(6266),
    [anon_sym_RPAREN] = ACTIONS(6266),
    [aux_sym_preproc_if_token2] = ACTIONS(6266),
    [aux_sym_preproc_else_token1] = ACTIONS(6266),
    [aux_sym_preproc_elif_token1] = ACTIONS(6268),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6266),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6266),
    [anon_sym_LPAREN2] = ACTIONS(6266),
    [anon_sym_DASH] = ACTIONS(6268),
    [anon_sym_PLUS] = ACTIONS(6268),
    [anon_sym_STAR] = ACTIONS(6268),
    [anon_sym_SLASH] = ACTIONS(6268),
    [anon_sym_PERCENT] = ACTIONS(6268),
    [anon_sym_PIPE_PIPE] = ACTIONS(6266),
    [anon_sym_AMP_AMP] = ACTIONS(6266),
    [anon_sym_PIPE] = ACTIONS(6268),
    [anon_sym_CARET] = ACTIONS(6268),
    [anon_sym_AMP] = ACTIONS(6268),
    [anon_sym_EQ_EQ] = ACTIONS(6266),
    [anon_sym_BANG_EQ] = ACTIONS(6266),
    [anon_sym_GT] = ACTIONS(6268),
    [anon_sym_GT_EQ] = ACTIONS(6266),
    [anon_sym_LT_EQ] = ACTIONS(6268),
    [anon_sym_LT] = ACTIONS(6268),
    [anon_sym_LT_LT] = ACTIONS(6268),
    [anon_sym_GT_GT] = ACTIONS(6268),
    [anon_sym_SEMI] = ACTIONS(6266),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6266),
    [anon_sym_RBRACE] = ACTIONS(6266),
    [anon_sym_LBRACK] = ACTIONS(6266),
    [anon_sym_RBRACK] = ACTIONS(6266),
    [anon_sym_EQ] = ACTIONS(6268),
    [anon_sym_COLON] = ACTIONS(6266),
    [anon_sym_QMARK] = ACTIONS(6266),
    [anon_sym_STAR_EQ] = ACTIONS(6266),
    [anon_sym_SLASH_EQ] = ACTIONS(6266),
    [anon_sym_PERCENT_EQ] = ACTIONS(6266),
    [anon_sym_PLUS_EQ] = ACTIONS(6266),
    [anon_sym_DASH_EQ] = ACTIONS(6266),
    [anon_sym_LT_LT_EQ] = ACTIONS(6266),
    [anon_sym_GT_GT_EQ] = ACTIONS(6266),
    [anon_sym_AMP_EQ] = ACTIONS(6266),
    [anon_sym_CARET_EQ] = ACTIONS(6266),
    [anon_sym_PIPE_EQ] = ACTIONS(6266),
    [anon_sym_and_eq] = ACTIONS(6268),
    [anon_sym_or_eq] = ACTIONS(6268),
    [anon_sym_xor_eq] = ACTIONS(6268),
    [anon_sym_LT_EQ_GT] = ACTIONS(6266),
    [anon_sym_or] = ACTIONS(6268),
    [anon_sym_and] = ACTIONS(6268),
    [anon_sym_bitor] = ACTIONS(6268),
    [anon_sym_xor] = ACTIONS(6268),
    [anon_sym_bitand] = ACTIONS(6268),
    [anon_sym_not_eq] = ACTIONS(6268),
    [anon_sym_DASH_DASH] = ACTIONS(6266),
    [anon_sym_PLUS_PLUS] = ACTIONS(6266),
    [anon_sym_DOT] = ACTIONS(6268),
    [anon_sym_DOT_STAR] = ACTIONS(6266),
    [anon_sym_DASH_GT] = ACTIONS(6266),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6268),
    [anon_sym_decltype] = ACTIONS(6268),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6266),
  },
  [STATE(2456)] = {
    [sym_attribute_specifier] = STATE(2584),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6262),
    [anon_sym_COMMA] = ACTIONS(6262),
    [anon_sym_LPAREN2] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6264),
    [anon_sym_STAR] = ACTIONS(6262),
    [anon_sym_SLASH] = ACTIONS(6264),
    [anon_sym_PERCENT] = ACTIONS(6262),
    [anon_sym_PIPE_PIPE] = ACTIONS(6262),
    [anon_sym_AMP_AMP] = ACTIONS(6262),
    [anon_sym_PIPE] = ACTIONS(6264),
    [anon_sym_CARET] = ACTIONS(6262),
    [anon_sym_AMP] = ACTIONS(6264),
    [anon_sym_EQ_EQ] = ACTIONS(6262),
    [anon_sym_BANG_EQ] = ACTIONS(6262),
    [anon_sym_GT] = ACTIONS(6264),
    [anon_sym_GT_EQ] = ACTIONS(6264),
    [anon_sym_LT_EQ] = ACTIONS(6264),
    [anon_sym_LT] = ACTIONS(6264),
    [anon_sym_LT_LT] = ACTIONS(6264),
    [anon_sym_GT_GT] = ACTIONS(6264),
    [anon_sym___extension__] = ACTIONS(6262),
    [anon_sym___global__] = ACTIONS(6262),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6262),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [anon_sym_const] = ACTIONS(6264),
    [anon_sym_constexpr] = ACTIONS(6262),
    [anon_sym_volatile] = ACTIONS(6262),
    [anon_sym_restrict] = ACTIONS(6262),
    [anon_sym___restrict__] = ACTIONS(6262),
    [anon_sym__Atomic] = ACTIONS(6262),
    [anon_sym__Noreturn] = ACTIONS(6262),
    [anon_sym_noreturn] = ACTIONS(6262),
    [anon_sym__Nonnull] = ACTIONS(6262),
    [anon_sym_mutable] = ACTIONS(6262),
    [anon_sym_constinit] = ACTIONS(6262),
    [anon_sym_consteval] = ACTIONS(6262),
    [anon_sym___shared__] = ACTIONS(6262),
    [anon_sym___local__] = ACTIONS(6262),
    [anon_sym___constant__] = ACTIONS(6262),
    [anon_sym___managed__] = ACTIONS(6262),
    [anon_sym___grid_constant__] = ACTIONS(6262),
    [anon_sym_alignas] = ACTIONS(6262),
    [anon_sym__Alignas] = ACTIONS(6262),
    [anon_sym_QMARK] = ACTIONS(6262),
    [anon_sym_LT_EQ_GT] = ACTIONS(6262),
    [anon_sym_or] = ACTIONS(6262),
    [anon_sym_and] = ACTIONS(6262),
    [anon_sym_bitor] = ACTIONS(6262),
    [anon_sym_xor] = ACTIONS(6262),
    [anon_sym_bitand] = ACTIONS(6262),
    [anon_sym_not_eq] = ACTIONS(6262),
    [anon_sym_DASH_DASH] = ACTIONS(6262),
    [anon_sym_PLUS_PLUS] = ACTIONS(6262),
    [anon_sym_DOT] = ACTIONS(6264),
    [anon_sym_DOT_STAR] = ACTIONS(6262),
    [anon_sym_DASH_GT] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6262),
    [anon_sym_decltype] = ACTIONS(6262),
    [anon_sym_final] = ACTIONS(6262),
    [anon_sym_override] = ACTIONS(6262),
    [anon_sym_GT2] = ACTIONS(6262),
    [anon_sym_requires] = ACTIONS(6262),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6262),
  },
  [STATE(2457)] = {
    [sym_decltype_auto] = STATE(2572),
    [sym_identifier] = ACTIONS(5673),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5675),
    [anon_sym_COMMA] = ACTIONS(5675),
    [anon_sym_RPAREN] = ACTIONS(5675),
    [aux_sym_preproc_if_token2] = ACTIONS(5675),
    [aux_sym_preproc_else_token1] = ACTIONS(5675),
    [aux_sym_preproc_elif_token1] = ACTIONS(5673),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5675),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5675),
    [anon_sym_LPAREN2] = ACTIONS(5675),
    [anon_sym_DASH] = ACTIONS(5673),
    [anon_sym_PLUS] = ACTIONS(5673),
    [anon_sym_STAR] = ACTIONS(5673),
    [anon_sym_SLASH] = ACTIONS(5673),
    [anon_sym_PERCENT] = ACTIONS(5673),
    [anon_sym_PIPE_PIPE] = ACTIONS(5675),
    [anon_sym_AMP_AMP] = ACTIONS(5675),
    [anon_sym_PIPE] = ACTIONS(5673),
    [anon_sym_CARET] = ACTIONS(5673),
    [anon_sym_AMP] = ACTIONS(5673),
    [anon_sym_EQ_EQ] = ACTIONS(5675),
    [anon_sym_BANG_EQ] = ACTIONS(5675),
    [anon_sym_GT] = ACTIONS(5673),
    [anon_sym_GT_EQ] = ACTIONS(5675),
    [anon_sym_LT_EQ] = ACTIONS(5673),
    [anon_sym_LT] = ACTIONS(5673),
    [anon_sym_LT_LT] = ACTIONS(5673),
    [anon_sym_GT_GT] = ACTIONS(5673),
    [anon_sym_SEMI] = ACTIONS(5675),
    [anon_sym___attribute__] = ACTIONS(5673),
    [anon_sym___attribute] = ACTIONS(5673),
    [anon_sym_LBRACE] = ACTIONS(5675),
    [anon_sym_RBRACE] = ACTIONS(5675),
    [anon_sym_LBRACK] = ACTIONS(5675),
    [anon_sym_RBRACK] = ACTIONS(5675),
    [anon_sym_EQ] = ACTIONS(5673),
    [anon_sym_COLON] = ACTIONS(5675),
    [anon_sym_QMARK] = ACTIONS(5675),
    [anon_sym_STAR_EQ] = ACTIONS(5675),
    [anon_sym_SLASH_EQ] = ACTIONS(5675),
    [anon_sym_PERCENT_EQ] = ACTIONS(5675),
    [anon_sym_PLUS_EQ] = ACTIONS(5675),
    [anon_sym_DASH_EQ] = ACTIONS(5675),
    [anon_sym_LT_LT_EQ] = ACTIONS(5675),
    [anon_sym_GT_GT_EQ] = ACTIONS(5675),
    [anon_sym_AMP_EQ] = ACTIONS(5675),
    [anon_sym_CARET_EQ] = ACTIONS(5675),
    [anon_sym_PIPE_EQ] = ACTIONS(5675),
    [anon_sym_and_eq] = ACTIONS(5673),
    [anon_sym_or_eq] = ACTIONS(5673),
    [anon_sym_xor_eq] = ACTIONS(5673),
    [anon_sym_LT_EQ_GT] = ACTIONS(5675),
    [anon_sym_or] = ACTIONS(5673),
    [anon_sym_and] = ACTIONS(5673),
    [anon_sym_bitor] = ACTIONS(5673),
    [anon_sym_xor] = ACTIONS(5673),
    [anon_sym_bitand] = ACTIONS(5673),
    [anon_sym_not_eq] = ACTIONS(5673),
    [anon_sym_DASH_DASH] = ACTIONS(5675),
    [anon_sym_PLUS_PLUS] = ACTIONS(5675),
    [anon_sym_DOT] = ACTIONS(5673),
    [anon_sym_DOT_STAR] = ACTIONS(5675),
    [anon_sym_DASH_GT] = ACTIONS(5675),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6313),
    [anon_sym_decltype] = ACTIONS(6315),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5675),
  },
  [STATE(2458)] = {
    [sym_template_argument_list] = STATE(2360),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_LPAREN2] = ACTIONS(4010),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_STAR] = ACTIONS(4010),
    [anon_sym_AMP_AMP] = ACTIONS(4010),
    [anon_sym_AMP] = ACTIONS(4002),
    [anon_sym_LT] = ACTIONS(6076),
    [anon_sym_SEMI] = ACTIONS(4028),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym___cdecl] = ACTIONS(4002),
    [anon_sym___clrcall] = ACTIONS(4002),
    [anon_sym___stdcall] = ACTIONS(4002),
    [anon_sym___fastcall] = ACTIONS(4002),
    [anon_sym___thiscall] = ACTIONS(4002),
    [anon_sym___vectorcall] = ACTIONS(4002),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4002),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(2459)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [aux_sym_structured_binding_declarator_repeat1] = STATE(7910),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(6486),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_RBRACK] = ACTIONS(6488),
    [anon_sym_EQ] = ACTIONS(6491),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(6468),
    [anon_sym_SLASH_EQ] = ACTIONS(6468),
    [anon_sym_PERCENT_EQ] = ACTIONS(6468),
    [anon_sym_PLUS_EQ] = ACTIONS(6468),
    [anon_sym_DASH_EQ] = ACTIONS(6468),
    [anon_sym_LT_LT_EQ] = ACTIONS(6468),
    [anon_sym_GT_GT_EQ] = ACTIONS(6468),
    [anon_sym_AMP_EQ] = ACTIONS(6468),
    [anon_sym_CARET_EQ] = ACTIONS(6468),
    [anon_sym_PIPE_EQ] = ACTIONS(6468),
    [anon_sym_and_eq] = ACTIONS(6468),
    [anon_sym_or_eq] = ACTIONS(6468),
    [anon_sym_xor_eq] = ACTIONS(6468),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2460)] = {
    [sym_string_literal] = STATE(2464),
    [sym_raw_string_literal] = STATE(2464),
    [aux_sym_concatenated_string_repeat1] = STATE(2464),
    [sym_identifier] = ACTIONS(6493),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6016),
    [anon_sym_COMMA] = ACTIONS(6016),
    [anon_sym_RPAREN] = ACTIONS(6016),
    [anon_sym_LPAREN2] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6018),
    [anon_sym_STAR] = ACTIONS(6018),
    [anon_sym_SLASH] = ACTIONS(6018),
    [anon_sym_PERCENT] = ACTIONS(6018),
    [anon_sym_PIPE_PIPE] = ACTIONS(6016),
    [anon_sym_AMP_AMP] = ACTIONS(6016),
    [anon_sym_PIPE] = ACTIONS(6018),
    [anon_sym_CARET] = ACTIONS(6018),
    [anon_sym_AMP] = ACTIONS(6018),
    [anon_sym_EQ_EQ] = ACTIONS(6016),
    [anon_sym_BANG_EQ] = ACTIONS(6016),
    [anon_sym_GT] = ACTIONS(6018),
    [anon_sym_GT_EQ] = ACTIONS(6016),
    [anon_sym_LT_EQ] = ACTIONS(6018),
    [anon_sym_LT] = ACTIONS(6018),
    [anon_sym_LT_LT] = ACTIONS(6018),
    [anon_sym_GT_GT] = ACTIONS(6018),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [anon_sym_EQ] = ACTIONS(6018),
    [anon_sym_QMARK] = ACTIONS(6016),
    [anon_sym_STAR_EQ] = ACTIONS(6016),
    [anon_sym_SLASH_EQ] = ACTIONS(6016),
    [anon_sym_PERCENT_EQ] = ACTIONS(6016),
    [anon_sym_PLUS_EQ] = ACTIONS(6016),
    [anon_sym_DASH_EQ] = ACTIONS(6016),
    [anon_sym_LT_LT_EQ] = ACTIONS(6016),
    [anon_sym_GT_GT_EQ] = ACTIONS(6016),
    [anon_sym_AMP_EQ] = ACTIONS(6016),
    [anon_sym_CARET_EQ] = ACTIONS(6016),
    [anon_sym_PIPE_EQ] = ACTIONS(6016),
    [anon_sym_and_eq] = ACTIONS(6018),
    [anon_sym_or_eq] = ACTIONS(6018),
    [anon_sym_xor_eq] = ACTIONS(6018),
    [anon_sym_LT_EQ_GT] = ACTIONS(6016),
    [anon_sym_or] = ACTIONS(6018),
    [anon_sym_and] = ACTIONS(6018),
    [anon_sym_bitor] = ACTIONS(6018),
    [anon_sym_xor] = ACTIONS(6018),
    [anon_sym_bitand] = ACTIONS(6018),
    [anon_sym_not_eq] = ACTIONS(6018),
    [anon_sym_DASH_DASH] = ACTIONS(6016),
    [anon_sym_PLUS_PLUS] = ACTIONS(6016),
    [anon_sym_DOT] = ACTIONS(6018),
    [anon_sym_DOT_STAR] = ACTIONS(6016),
    [anon_sym_DASH_GT] = ACTIONS(6018),
    [anon_sym_L_DQUOTE] = ACTIONS(5103),
    [anon_sym_u_DQUOTE] = ACTIONS(5103),
    [anon_sym_U_DQUOTE] = ACTIONS(5103),
    [anon_sym_u8_DQUOTE] = ACTIONS(5103),
    [anon_sym_DQUOTE] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5105),
    [anon_sym_LR_DQUOTE] = ACTIONS(5105),
    [anon_sym_uR_DQUOTE] = ACTIONS(5105),
    [anon_sym_UR_DQUOTE] = ACTIONS(5105),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5105),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6016),
    [sym_literal_suffix] = ACTIONS(6018),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6016),
  },
  [STATE(2461)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_SEMI] = ACTIONS(4004),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4036),
    [anon_sym_COLON] = ACTIONS(4060),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4040),
    [anon_sym_SLASH_EQ] = ACTIONS(4040),
    [anon_sym_PERCENT_EQ] = ACTIONS(4040),
    [anon_sym_PLUS_EQ] = ACTIONS(4040),
    [anon_sym_DASH_EQ] = ACTIONS(4040),
    [anon_sym_LT_LT_EQ] = ACTIONS(4040),
    [anon_sym_GT_GT_EQ] = ACTIONS(4040),
    [anon_sym_AMP_EQ] = ACTIONS(4040),
    [anon_sym_CARET_EQ] = ACTIONS(4040),
    [anon_sym_PIPE_EQ] = ACTIONS(4040),
    [anon_sym_and_eq] = ACTIONS(4040),
    [anon_sym_or_eq] = ACTIONS(4040),
    [anon_sym_xor_eq] = ACTIONS(4040),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2462)] = {
    [sym_template_argument_list] = STATE(2360),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_LPAREN2] = ACTIONS(4010),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_STAR] = ACTIONS(4010),
    [anon_sym_AMP_AMP] = ACTIONS(4010),
    [anon_sym_AMP] = ACTIONS(4002),
    [anon_sym_LT] = ACTIONS(6076),
    [anon_sym_SEMI] = ACTIONS(4010),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym___cdecl] = ACTIONS(4002),
    [anon_sym___clrcall] = ACTIONS(4002),
    [anon_sym___stdcall] = ACTIONS(4002),
    [anon_sym___fastcall] = ACTIONS(4002),
    [anon_sym___thiscall] = ACTIONS(4002),
    [anon_sym___vectorcall] = ACTIONS(4002),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4002),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(2463)] = {
    [sym_attribute_specifier] = STATE(2596),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6258),
    [anon_sym_COMMA] = ACTIONS(6258),
    [anon_sym_LPAREN2] = ACTIONS(6258),
    [anon_sym_DASH] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6260),
    [anon_sym_STAR] = ACTIONS(6258),
    [anon_sym_SLASH] = ACTIONS(6260),
    [anon_sym_PERCENT] = ACTIONS(6258),
    [anon_sym_PIPE_PIPE] = ACTIONS(6258),
    [anon_sym_AMP_AMP] = ACTIONS(6258),
    [anon_sym_PIPE] = ACTIONS(6260),
    [anon_sym_CARET] = ACTIONS(6258),
    [anon_sym_AMP] = ACTIONS(6260),
    [anon_sym_EQ_EQ] = ACTIONS(6258),
    [anon_sym_BANG_EQ] = ACTIONS(6258),
    [anon_sym_GT] = ACTIONS(6260),
    [anon_sym_GT_EQ] = ACTIONS(6260),
    [anon_sym_LT_EQ] = ACTIONS(6260),
    [anon_sym_LT] = ACTIONS(6260),
    [anon_sym_LT_LT] = ACTIONS(6260),
    [anon_sym_GT_GT] = ACTIONS(6260),
    [anon_sym___extension__] = ACTIONS(6258),
    [anon_sym___global__] = ACTIONS(6258),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6258),
    [anon_sym_LBRACK] = ACTIONS(6258),
    [anon_sym_const] = ACTIONS(6260),
    [anon_sym_constexpr] = ACTIONS(6258),
    [anon_sym_volatile] = ACTIONS(6258),
    [anon_sym_restrict] = ACTIONS(6258),
    [anon_sym___restrict__] = ACTIONS(6258),
    [anon_sym__Atomic] = ACTIONS(6258),
    [anon_sym__Noreturn] = ACTIONS(6258),
    [anon_sym_noreturn] = ACTIONS(6258),
    [anon_sym__Nonnull] = ACTIONS(6258),
    [anon_sym_mutable] = ACTIONS(6258),
    [anon_sym_constinit] = ACTIONS(6258),
    [anon_sym_consteval] = ACTIONS(6258),
    [anon_sym___shared__] = ACTIONS(6258),
    [anon_sym___local__] = ACTIONS(6258),
    [anon_sym___constant__] = ACTIONS(6258),
    [anon_sym___managed__] = ACTIONS(6258),
    [anon_sym___grid_constant__] = ACTIONS(6258),
    [anon_sym_alignas] = ACTIONS(6258),
    [anon_sym__Alignas] = ACTIONS(6258),
    [anon_sym_QMARK] = ACTIONS(6258),
    [anon_sym_LT_EQ_GT] = ACTIONS(6258),
    [anon_sym_or] = ACTIONS(6258),
    [anon_sym_and] = ACTIONS(6258),
    [anon_sym_bitor] = ACTIONS(6258),
    [anon_sym_xor] = ACTIONS(6258),
    [anon_sym_bitand] = ACTIONS(6258),
    [anon_sym_not_eq] = ACTIONS(6258),
    [anon_sym_DASH_DASH] = ACTIONS(6258),
    [anon_sym_PLUS_PLUS] = ACTIONS(6258),
    [anon_sym_DOT] = ACTIONS(6260),
    [anon_sym_DOT_STAR] = ACTIONS(6258),
    [anon_sym_DASH_GT] = ACTIONS(6258),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6258),
    [anon_sym_decltype] = ACTIONS(6258),
    [anon_sym_final] = ACTIONS(6258),
    [anon_sym_override] = ACTIONS(6258),
    [anon_sym_GT2] = ACTIONS(6258),
    [anon_sym_requires] = ACTIONS(6258),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6258),
  },
  [STATE(2464)] = {
    [sym_string_literal] = STATE(2464),
    [sym_raw_string_literal] = STATE(2464),
    [aux_sym_concatenated_string_repeat1] = STATE(2464),
    [sym_identifier] = ACTIONS(6495),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5882),
    [anon_sym_COMMA] = ACTIONS(5882),
    [anon_sym_RPAREN] = ACTIONS(5882),
    [anon_sym_LPAREN2] = ACTIONS(5882),
    [anon_sym_DASH] = ACTIONS(5884),
    [anon_sym_PLUS] = ACTIONS(5884),
    [anon_sym_STAR] = ACTIONS(5884),
    [anon_sym_SLASH] = ACTIONS(5884),
    [anon_sym_PERCENT] = ACTIONS(5884),
    [anon_sym_PIPE_PIPE] = ACTIONS(5882),
    [anon_sym_AMP_AMP] = ACTIONS(5882),
    [anon_sym_PIPE] = ACTIONS(5884),
    [anon_sym_CARET] = ACTIONS(5884),
    [anon_sym_AMP] = ACTIONS(5884),
    [anon_sym_EQ_EQ] = ACTIONS(5882),
    [anon_sym_BANG_EQ] = ACTIONS(5882),
    [anon_sym_GT] = ACTIONS(5884),
    [anon_sym_GT_EQ] = ACTIONS(5882),
    [anon_sym_LT_EQ] = ACTIONS(5884),
    [anon_sym_LT] = ACTIONS(5884),
    [anon_sym_LT_LT] = ACTIONS(5884),
    [anon_sym_GT_GT] = ACTIONS(5884),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_EQ] = ACTIONS(5884),
    [anon_sym_QMARK] = ACTIONS(5882),
    [anon_sym_STAR_EQ] = ACTIONS(5882),
    [anon_sym_SLASH_EQ] = ACTIONS(5882),
    [anon_sym_PERCENT_EQ] = ACTIONS(5882),
    [anon_sym_PLUS_EQ] = ACTIONS(5882),
    [anon_sym_DASH_EQ] = ACTIONS(5882),
    [anon_sym_LT_LT_EQ] = ACTIONS(5882),
    [anon_sym_GT_GT_EQ] = ACTIONS(5882),
    [anon_sym_AMP_EQ] = ACTIONS(5882),
    [anon_sym_CARET_EQ] = ACTIONS(5882),
    [anon_sym_PIPE_EQ] = ACTIONS(5882),
    [anon_sym_and_eq] = ACTIONS(5884),
    [anon_sym_or_eq] = ACTIONS(5884),
    [anon_sym_xor_eq] = ACTIONS(5884),
    [anon_sym_LT_EQ_GT] = ACTIONS(5882),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_bitor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_bitand] = ACTIONS(5884),
    [anon_sym_not_eq] = ACTIONS(5884),
    [anon_sym_DASH_DASH] = ACTIONS(5882),
    [anon_sym_PLUS_PLUS] = ACTIONS(5882),
    [anon_sym_DOT] = ACTIONS(5884),
    [anon_sym_DOT_STAR] = ACTIONS(5882),
    [anon_sym_DASH_GT] = ACTIONS(5884),
    [anon_sym_L_DQUOTE] = ACTIONS(6498),
    [anon_sym_u_DQUOTE] = ACTIONS(6498),
    [anon_sym_U_DQUOTE] = ACTIONS(6498),
    [anon_sym_u8_DQUOTE] = ACTIONS(6498),
    [anon_sym_DQUOTE] = ACTIONS(6498),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6501),
    [anon_sym_LR_DQUOTE] = ACTIONS(6501),
    [anon_sym_uR_DQUOTE] = ACTIONS(6501),
    [anon_sym_UR_DQUOTE] = ACTIONS(6501),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6501),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5882),
    [sym_literal_suffix] = ACTIONS(5884),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5882),
  },
  [STATE(2465)] = {
    [sym_attribute_specifier] = STATE(2603),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6266),
    [anon_sym_COMMA] = ACTIONS(6266),
    [anon_sym_LPAREN2] = ACTIONS(6266),
    [anon_sym_DASH] = ACTIONS(6268),
    [anon_sym_PLUS] = ACTIONS(6268),
    [anon_sym_STAR] = ACTIONS(6266),
    [anon_sym_SLASH] = ACTIONS(6268),
    [anon_sym_PERCENT] = ACTIONS(6266),
    [anon_sym_PIPE_PIPE] = ACTIONS(6266),
    [anon_sym_AMP_AMP] = ACTIONS(6266),
    [anon_sym_PIPE] = ACTIONS(6268),
    [anon_sym_CARET] = ACTIONS(6266),
    [anon_sym_AMP] = ACTIONS(6268),
    [anon_sym_EQ_EQ] = ACTIONS(6266),
    [anon_sym_BANG_EQ] = ACTIONS(6266),
    [anon_sym_GT] = ACTIONS(6268),
    [anon_sym_GT_EQ] = ACTIONS(6268),
    [anon_sym_LT_EQ] = ACTIONS(6268),
    [anon_sym_LT] = ACTIONS(6268),
    [anon_sym_LT_LT] = ACTIONS(6268),
    [anon_sym_GT_GT] = ACTIONS(6268),
    [anon_sym___extension__] = ACTIONS(6266),
    [anon_sym___global__] = ACTIONS(6266),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6266),
    [anon_sym_LBRACK] = ACTIONS(6266),
    [anon_sym_const] = ACTIONS(6268),
    [anon_sym_constexpr] = ACTIONS(6266),
    [anon_sym_volatile] = ACTIONS(6266),
    [anon_sym_restrict] = ACTIONS(6266),
    [anon_sym___restrict__] = ACTIONS(6266),
    [anon_sym__Atomic] = ACTIONS(6266),
    [anon_sym__Noreturn] = ACTIONS(6266),
    [anon_sym_noreturn] = ACTIONS(6266),
    [anon_sym__Nonnull] = ACTIONS(6266),
    [anon_sym_mutable] = ACTIONS(6266),
    [anon_sym_constinit] = ACTIONS(6266),
    [anon_sym_consteval] = ACTIONS(6266),
    [anon_sym___shared__] = ACTIONS(6266),
    [anon_sym___local__] = ACTIONS(6266),
    [anon_sym___constant__] = ACTIONS(6266),
    [anon_sym___managed__] = ACTIONS(6266),
    [anon_sym___grid_constant__] = ACTIONS(6266),
    [anon_sym_alignas] = ACTIONS(6266),
    [anon_sym__Alignas] = ACTIONS(6266),
    [anon_sym_QMARK] = ACTIONS(6266),
    [anon_sym_LT_EQ_GT] = ACTIONS(6266),
    [anon_sym_or] = ACTIONS(6266),
    [anon_sym_and] = ACTIONS(6266),
    [anon_sym_bitor] = ACTIONS(6266),
    [anon_sym_xor] = ACTIONS(6266),
    [anon_sym_bitand] = ACTIONS(6266),
    [anon_sym_not_eq] = ACTIONS(6266),
    [anon_sym_DASH_DASH] = ACTIONS(6266),
    [anon_sym_PLUS_PLUS] = ACTIONS(6266),
    [anon_sym_DOT] = ACTIONS(6268),
    [anon_sym_DOT_STAR] = ACTIONS(6266),
    [anon_sym_DASH_GT] = ACTIONS(6266),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6266),
    [anon_sym_decltype] = ACTIONS(6266),
    [anon_sym_final] = ACTIONS(6266),
    [anon_sym_override] = ACTIONS(6266),
    [anon_sym_GT2] = ACTIONS(6266),
    [anon_sym_requires] = ACTIONS(6266),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6266),
  },
  [STATE(2466)] = {
    [sym_attribute_declaration] = STATE(2587),
    [sym_parameter_list] = STATE(2589),
    [aux_sym_attributed_declarator_repeat1] = STATE(2587),
    [sym_identifier] = ACTIONS(6504),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6506),
    [anon_sym_COMMA] = ACTIONS(6506),
    [anon_sym_RPAREN] = ACTIONS(6506),
    [aux_sym_preproc_if_token2] = ACTIONS(6506),
    [aux_sym_preproc_else_token1] = ACTIONS(6506),
    [aux_sym_preproc_elif_token1] = ACTIONS(6504),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6506),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6506),
    [anon_sym_LPAREN2] = ACTIONS(6442),
    [anon_sym_DASH] = ACTIONS(6504),
    [anon_sym_PLUS] = ACTIONS(6504),
    [anon_sym_STAR] = ACTIONS(6504),
    [anon_sym_SLASH] = ACTIONS(6504),
    [anon_sym_PERCENT] = ACTIONS(6504),
    [anon_sym_PIPE_PIPE] = ACTIONS(6506),
    [anon_sym_AMP_AMP] = ACTIONS(6506),
    [anon_sym_PIPE] = ACTIONS(6504),
    [anon_sym_CARET] = ACTIONS(6504),
    [anon_sym_AMP] = ACTIONS(6504),
    [anon_sym_EQ_EQ] = ACTIONS(6506),
    [anon_sym_BANG_EQ] = ACTIONS(6506),
    [anon_sym_GT] = ACTIONS(6504),
    [anon_sym_GT_EQ] = ACTIONS(6506),
    [anon_sym_LT_EQ] = ACTIONS(6504),
    [anon_sym_LT] = ACTIONS(6504),
    [anon_sym_LT_LT] = ACTIONS(6504),
    [anon_sym_GT_GT] = ACTIONS(6504),
    [anon_sym_SEMI] = ACTIONS(6506),
    [anon_sym___attribute__] = ACTIONS(6504),
    [anon_sym___attribute] = ACTIONS(6504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6444),
    [anon_sym_RBRACE] = ACTIONS(6506),
    [anon_sym_LBRACK] = ACTIONS(6446),
    [anon_sym_RBRACK] = ACTIONS(6506),
    [anon_sym_EQ] = ACTIONS(6504),
    [anon_sym_COLON] = ACTIONS(6506),
    [anon_sym_QMARK] = ACTIONS(6506),
    [anon_sym_STAR_EQ] = ACTIONS(6506),
    [anon_sym_SLASH_EQ] = ACTIONS(6506),
    [anon_sym_PERCENT_EQ] = ACTIONS(6506),
    [anon_sym_PLUS_EQ] = ACTIONS(6506),
    [anon_sym_DASH_EQ] = ACTIONS(6506),
    [anon_sym_LT_LT_EQ] = ACTIONS(6506),
    [anon_sym_GT_GT_EQ] = ACTIONS(6506),
    [anon_sym_AMP_EQ] = ACTIONS(6506),
    [anon_sym_CARET_EQ] = ACTIONS(6506),
    [anon_sym_PIPE_EQ] = ACTIONS(6506),
    [anon_sym_and_eq] = ACTIONS(6504),
    [anon_sym_or_eq] = ACTIONS(6504),
    [anon_sym_xor_eq] = ACTIONS(6504),
    [anon_sym_LT_EQ_GT] = ACTIONS(6506),
    [anon_sym_or] = ACTIONS(6504),
    [anon_sym_and] = ACTIONS(6504),
    [anon_sym_bitor] = ACTIONS(6504),
    [anon_sym_xor] = ACTIONS(6504),
    [anon_sym_bitand] = ACTIONS(6504),
    [anon_sym_not_eq] = ACTIONS(6504),
    [anon_sym_DASH_DASH] = ACTIONS(6506),
    [anon_sym_PLUS_PLUS] = ACTIONS(6506),
    [anon_sym_DOT] = ACTIONS(6504),
    [anon_sym_DOT_STAR] = ACTIONS(6506),
    [anon_sym_DASH_GT] = ACTIONS(6506),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6506),
  },
  [STATE(2467)] = {
    [sym_attribute_declaration] = STATE(2587),
    [sym_parameter_list] = STATE(2589),
    [aux_sym_attributed_declarator_repeat1] = STATE(2587),
    [sym_identifier] = ACTIONS(6508),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6510),
    [anon_sym_COMMA] = ACTIONS(6510),
    [anon_sym_RPAREN] = ACTIONS(6510),
    [aux_sym_preproc_if_token2] = ACTIONS(6510),
    [aux_sym_preproc_else_token1] = ACTIONS(6510),
    [aux_sym_preproc_elif_token1] = ACTIONS(6508),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6510),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6510),
    [anon_sym_LPAREN2] = ACTIONS(6442),
    [anon_sym_DASH] = ACTIONS(6508),
    [anon_sym_PLUS] = ACTIONS(6508),
    [anon_sym_STAR] = ACTIONS(6508),
    [anon_sym_SLASH] = ACTIONS(6508),
    [anon_sym_PERCENT] = ACTIONS(6508),
    [anon_sym_PIPE_PIPE] = ACTIONS(6510),
    [anon_sym_AMP_AMP] = ACTIONS(6510),
    [anon_sym_PIPE] = ACTIONS(6508),
    [anon_sym_CARET] = ACTIONS(6508),
    [anon_sym_AMP] = ACTIONS(6508),
    [anon_sym_EQ_EQ] = ACTIONS(6510),
    [anon_sym_BANG_EQ] = ACTIONS(6510),
    [anon_sym_GT] = ACTIONS(6508),
    [anon_sym_GT_EQ] = ACTIONS(6510),
    [anon_sym_LT_EQ] = ACTIONS(6508),
    [anon_sym_LT] = ACTIONS(6508),
    [anon_sym_LT_LT] = ACTIONS(6508),
    [anon_sym_GT_GT] = ACTIONS(6508),
    [anon_sym_SEMI] = ACTIONS(6510),
    [anon_sym___attribute__] = ACTIONS(6508),
    [anon_sym___attribute] = ACTIONS(6508),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6444),
    [anon_sym_RBRACE] = ACTIONS(6510),
    [anon_sym_LBRACK] = ACTIONS(6446),
    [anon_sym_RBRACK] = ACTIONS(6510),
    [anon_sym_EQ] = ACTIONS(6508),
    [anon_sym_COLON] = ACTIONS(6510),
    [anon_sym_QMARK] = ACTIONS(6510),
    [anon_sym_STAR_EQ] = ACTIONS(6510),
    [anon_sym_SLASH_EQ] = ACTIONS(6510),
    [anon_sym_PERCENT_EQ] = ACTIONS(6510),
    [anon_sym_PLUS_EQ] = ACTIONS(6510),
    [anon_sym_DASH_EQ] = ACTIONS(6510),
    [anon_sym_LT_LT_EQ] = ACTIONS(6510),
    [anon_sym_GT_GT_EQ] = ACTIONS(6510),
    [anon_sym_AMP_EQ] = ACTIONS(6510),
    [anon_sym_CARET_EQ] = ACTIONS(6510),
    [anon_sym_PIPE_EQ] = ACTIONS(6510),
    [anon_sym_and_eq] = ACTIONS(6508),
    [anon_sym_or_eq] = ACTIONS(6508),
    [anon_sym_xor_eq] = ACTIONS(6508),
    [anon_sym_LT_EQ_GT] = ACTIONS(6510),
    [anon_sym_or] = ACTIONS(6508),
    [anon_sym_and] = ACTIONS(6508),
    [anon_sym_bitor] = ACTIONS(6508),
    [anon_sym_xor] = ACTIONS(6508),
    [anon_sym_bitand] = ACTIONS(6508),
    [anon_sym_not_eq] = ACTIONS(6508),
    [anon_sym_DASH_DASH] = ACTIONS(6510),
    [anon_sym_PLUS_PLUS] = ACTIONS(6510),
    [anon_sym_DOT] = ACTIONS(6508),
    [anon_sym_DOT_STAR] = ACTIONS(6510),
    [anon_sym_DASH_GT] = ACTIONS(6510),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6510),
  },
  [STATE(2468)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym__declarator] = STATE(6947),
    [sym__abstract_declarator] = STATE(7137),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(4415),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3007),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(4415),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(5925),
    [anon_sym_RPAREN] = ACTIONS(5925),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(5927),
    [anon_sym_AMP_AMP] = ACTIONS(5929),
    [anon_sym_AMP] = ACTIONS(5931),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(5933),
    [anon_sym___attribute] = ACTIONS(5933),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_EQ] = ACTIONS(5925),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(5925),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2469)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym__declarator] = STATE(6954),
    [sym__abstract_declarator] = STATE(7152),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(4415),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3007),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(4415),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(6512),
    [anon_sym_RPAREN] = ACTIONS(6512),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(5927),
    [anon_sym_AMP_AMP] = ACTIONS(5929),
    [anon_sym_AMP] = ACTIONS(5931),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(6514),
    [anon_sym___attribute] = ACTIONS(6514),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_EQ] = ACTIONS(6512),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(6512),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2470)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_COMMA] = ACTIONS(5354),
    [anon_sym_RPAREN] = ACTIONS(5354),
    [anon_sym_LPAREN2] = ACTIONS(5354),
    [anon_sym_STAR] = ACTIONS(5354),
    [anon_sym_AMP_AMP] = ACTIONS(5354),
    [anon_sym_AMP] = ACTIONS(5351),
    [anon_sym_SEMI] = ACTIONS(5354),
    [anon_sym___extension__] = ACTIONS(5351),
    [anon_sym___device__] = ACTIONS(5351),
    [anon_sym___host__] = ACTIONS(5351),
    [anon_sym___global__] = ACTIONS(5351),
    [anon_sym___forceinline__] = ACTIONS(5351),
    [anon_sym___noinline__] = ACTIONS(5351),
    [anon_sym_virtual] = ACTIONS(5351),
    [anon_sym_extern] = ACTIONS(5351),
    [anon_sym___attribute__] = ACTIONS(5351),
    [anon_sym___attribute] = ACTIONS(5351),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5354),
    [anon_sym___declspec] = ACTIONS(5351),
    [anon_sym_LBRACE] = ACTIONS(5354),
    [anon_sym_signed] = ACTIONS(5650),
    [anon_sym_unsigned] = ACTIONS(5650),
    [anon_sym_long] = ACTIONS(5650),
    [anon_sym_short] = ACTIONS(5650),
    [anon_sym_LBRACK] = ACTIONS(5351),
    [anon_sym_static] = ACTIONS(5351),
    [anon_sym_EQ] = ACTIONS(5354),
    [anon_sym_register] = ACTIONS(5351),
    [anon_sym_inline] = ACTIONS(5351),
    [anon_sym___inline] = ACTIONS(5351),
    [anon_sym___inline__] = ACTIONS(5351),
    [anon_sym___forceinline] = ACTIONS(5351),
    [anon_sym_thread_local] = ACTIONS(5351),
    [anon_sym___thread] = ACTIONS(5351),
    [anon_sym_const] = ACTIONS(5351),
    [anon_sym_constexpr] = ACTIONS(5351),
    [anon_sym_volatile] = ACTIONS(5351),
    [anon_sym_restrict] = ACTIONS(5351),
    [anon_sym___restrict__] = ACTIONS(5351),
    [anon_sym__Atomic] = ACTIONS(5351),
    [anon_sym__Noreturn] = ACTIONS(5351),
    [anon_sym_noreturn] = ACTIONS(5351),
    [anon_sym__Nonnull] = ACTIONS(5351),
    [anon_sym_mutable] = ACTIONS(5351),
    [anon_sym_constinit] = ACTIONS(5351),
    [anon_sym_consteval] = ACTIONS(5351),
    [anon_sym___shared__] = ACTIONS(5351),
    [anon_sym___local__] = ACTIONS(5351),
    [anon_sym___constant__] = ACTIONS(5351),
    [anon_sym___managed__] = ACTIONS(5351),
    [anon_sym___grid_constant__] = ACTIONS(5351),
    [anon_sym_alignas] = ACTIONS(5351),
    [anon_sym__Alignas] = ACTIONS(5351),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_asm] = ACTIONS(5351),
    [anon_sym___asm__] = ACTIONS(5351),
    [anon_sym___asm] = ACTIONS(5351),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5351),
    [anon_sym_decltype] = ACTIONS(5351),
    [anon_sym_final] = ACTIONS(5351),
    [anon_sym_override] = ACTIONS(5351),
    [anon_sym_GT2] = ACTIONS(5354),
    [anon_sym_try] = ACTIONS(5351),
    [anon_sym_requires] = ACTIONS(5351),
    [anon_sym___launch_bounds__] = ACTIONS(5351),
  },
  [STATE(2471)] = {
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_STAR] = ACTIONS(5661),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_AMP] = ACTIONS(5659),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___extension__] = ACTIONS(5659),
    [anon_sym___device__] = ACTIONS(5659),
    [anon_sym___host__] = ACTIONS(5659),
    [anon_sym___global__] = ACTIONS(5659),
    [anon_sym___forceinline__] = ACTIONS(5659),
    [anon_sym___noinline__] = ACTIONS(5659),
    [anon_sym_virtual] = ACTIONS(5659),
    [anon_sym_extern] = ACTIONS(5659),
    [anon_sym___attribute__] = ACTIONS(5659),
    [anon_sym___attribute] = ACTIONS(5659),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5661),
    [anon_sym___declspec] = ACTIONS(5659),
    [anon_sym___based] = ACTIONS(5659),
    [anon_sym_LBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [anon_sym_static] = ACTIONS(5659),
    [anon_sym_EQ] = ACTIONS(5661),
    [anon_sym_register] = ACTIONS(5659),
    [anon_sym_inline] = ACTIONS(5659),
    [anon_sym___inline] = ACTIONS(5659),
    [anon_sym___inline__] = ACTIONS(5659),
    [anon_sym___forceinline] = ACTIONS(5659),
    [anon_sym_thread_local] = ACTIONS(5659),
    [anon_sym___thread] = ACTIONS(5659),
    [anon_sym_const] = ACTIONS(5659),
    [anon_sym_constexpr] = ACTIONS(5659),
    [anon_sym_volatile] = ACTIONS(5659),
    [anon_sym_restrict] = ACTIONS(5659),
    [anon_sym___restrict__] = ACTIONS(5659),
    [anon_sym__Atomic] = ACTIONS(5659),
    [anon_sym__Noreturn] = ACTIONS(5659),
    [anon_sym_noreturn] = ACTIONS(5659),
    [anon_sym__Nonnull] = ACTIONS(5659),
    [anon_sym_mutable] = ACTIONS(5659),
    [anon_sym_constinit] = ACTIONS(5659),
    [anon_sym_consteval] = ACTIONS(5659),
    [anon_sym___shared__] = ACTIONS(5659),
    [anon_sym___local__] = ACTIONS(5659),
    [anon_sym___constant__] = ACTIONS(5659),
    [anon_sym___managed__] = ACTIONS(5659),
    [anon_sym___grid_constant__] = ACTIONS(5659),
    [anon_sym_alignas] = ACTIONS(5659),
    [anon_sym__Alignas] = ACTIONS(5659),
    [anon_sym_COLON] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5659),
    [anon_sym_and] = ACTIONS(5659),
    [anon_sym_asm] = ACTIONS(5659),
    [anon_sym___asm__] = ACTIONS(5659),
    [anon_sym___asm] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5659),
    [anon_sym_decltype] = ACTIONS(5659),
    [anon_sym_final] = ACTIONS(5659),
    [anon_sym_override] = ACTIONS(5659),
    [anon_sym_GT2] = ACTIONS(5661),
    [anon_sym_operator] = ACTIONS(5659),
    [anon_sym_try] = ACTIONS(5659),
    [anon_sym_requires] = ACTIONS(5659),
    [anon_sym___launch_bounds__] = ACTIONS(5659),
  },
  [STATE(2472)] = {
    [sym_template_argument_list] = STATE(2363),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2641),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4010),
    [anon_sym_COMMA] = ACTIONS(4010),
    [anon_sym_RPAREN] = ACTIONS(4010),
    [anon_sym_LPAREN2] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4002),
    [anon_sym_PLUS] = ACTIONS(4002),
    [anon_sym_STAR] = ACTIONS(4002),
    [anon_sym_SLASH] = ACTIONS(4002),
    [anon_sym_PERCENT] = ACTIONS(4002),
    [anon_sym_PIPE_PIPE] = ACTIONS(4010),
    [anon_sym_AMP_AMP] = ACTIONS(4010),
    [anon_sym_PIPE] = ACTIONS(4002),
    [anon_sym_CARET] = ACTIONS(4002),
    [anon_sym_AMP] = ACTIONS(4002),
    [anon_sym_EQ_EQ] = ACTIONS(4010),
    [anon_sym_BANG_EQ] = ACTIONS(4010),
    [anon_sym_GT] = ACTIONS(4002),
    [anon_sym_GT_EQ] = ACTIONS(4010),
    [anon_sym_LT_EQ] = ACTIONS(4002),
    [anon_sym_LT] = ACTIONS(6336),
    [anon_sym_LT_LT] = ACTIONS(4002),
    [anon_sym_GT_GT] = ACTIONS(4002),
    [anon_sym_SEMI] = ACTIONS(4010),
    [anon_sym___attribute__] = ACTIONS(4010),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4010),
    [anon_sym_RBRACE] = ACTIONS(4010),
    [anon_sym_signed] = ACTIONS(6484),
    [anon_sym_unsigned] = ACTIONS(6484),
    [anon_sym_long] = ACTIONS(6484),
    [anon_sym_short] = ACTIONS(6484),
    [anon_sym_LBRACK] = ACTIONS(4010),
    [anon_sym_RBRACK] = ACTIONS(4010),
    [anon_sym_EQ] = ACTIONS(4002),
    [anon_sym_COLON] = ACTIONS(4002),
    [anon_sym_QMARK] = ACTIONS(4010),
    [anon_sym_STAR_EQ] = ACTIONS(4010),
    [anon_sym_SLASH_EQ] = ACTIONS(4010),
    [anon_sym_PERCENT_EQ] = ACTIONS(4010),
    [anon_sym_PLUS_EQ] = ACTIONS(4010),
    [anon_sym_DASH_EQ] = ACTIONS(4010),
    [anon_sym_LT_LT_EQ] = ACTIONS(4010),
    [anon_sym_GT_GT_EQ] = ACTIONS(4010),
    [anon_sym_AMP_EQ] = ACTIONS(4010),
    [anon_sym_CARET_EQ] = ACTIONS(4010),
    [anon_sym_PIPE_EQ] = ACTIONS(4010),
    [anon_sym_and_eq] = ACTIONS(4010),
    [anon_sym_or_eq] = ACTIONS(4010),
    [anon_sym_xor_eq] = ACTIONS(4010),
    [anon_sym_LT_EQ_GT] = ACTIONS(4010),
    [anon_sym_or] = ACTIONS(4002),
    [anon_sym_and] = ACTIONS(4002),
    [anon_sym_bitor] = ACTIONS(4010),
    [anon_sym_xor] = ACTIONS(4002),
    [anon_sym_bitand] = ACTIONS(4010),
    [anon_sym_not_eq] = ACTIONS(4010),
    [anon_sym_DASH_DASH] = ACTIONS(4010),
    [anon_sym_PLUS_PLUS] = ACTIONS(4010),
    [anon_sym_DOT] = ACTIONS(4002),
    [anon_sym_DOT_STAR] = ACTIONS(4010),
    [anon_sym_DASH_GT] = ACTIONS(4010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4010),
    [anon_sym_decltype] = ACTIONS(4010),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4010),
  },
  [STATE(2473)] = {
    [sym_attribute_specifier] = STATE(2493),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6238),
    [anon_sym_COMMA] = ACTIONS(6238),
    [anon_sym_LPAREN2] = ACTIONS(6238),
    [anon_sym_DASH] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6240),
    [anon_sym_STAR] = ACTIONS(6238),
    [anon_sym_SLASH] = ACTIONS(6240),
    [anon_sym_PERCENT] = ACTIONS(6238),
    [anon_sym_PIPE_PIPE] = ACTIONS(6238),
    [anon_sym_AMP_AMP] = ACTIONS(6238),
    [anon_sym_PIPE] = ACTIONS(6240),
    [anon_sym_CARET] = ACTIONS(6238),
    [anon_sym_AMP] = ACTIONS(6240),
    [anon_sym_EQ_EQ] = ACTIONS(6238),
    [anon_sym_BANG_EQ] = ACTIONS(6238),
    [anon_sym_GT] = ACTIONS(6240),
    [anon_sym_GT_EQ] = ACTIONS(6240),
    [anon_sym_LT_EQ] = ACTIONS(6240),
    [anon_sym_LT] = ACTIONS(6240),
    [anon_sym_LT_LT] = ACTIONS(6240),
    [anon_sym_GT_GT] = ACTIONS(6240),
    [anon_sym___extension__] = ACTIONS(6238),
    [anon_sym___global__] = ACTIONS(6238),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6238),
    [anon_sym_LBRACK] = ACTIONS(6238),
    [anon_sym_const] = ACTIONS(6240),
    [anon_sym_constexpr] = ACTIONS(6238),
    [anon_sym_volatile] = ACTIONS(6238),
    [anon_sym_restrict] = ACTIONS(6238),
    [anon_sym___restrict__] = ACTIONS(6238),
    [anon_sym__Atomic] = ACTIONS(6238),
    [anon_sym__Noreturn] = ACTIONS(6238),
    [anon_sym_noreturn] = ACTIONS(6238),
    [anon_sym__Nonnull] = ACTIONS(6238),
    [anon_sym_mutable] = ACTIONS(6238),
    [anon_sym_constinit] = ACTIONS(6238),
    [anon_sym_consteval] = ACTIONS(6238),
    [anon_sym___shared__] = ACTIONS(6238),
    [anon_sym___local__] = ACTIONS(6238),
    [anon_sym___constant__] = ACTIONS(6238),
    [anon_sym___managed__] = ACTIONS(6238),
    [anon_sym___grid_constant__] = ACTIONS(6238),
    [anon_sym_alignas] = ACTIONS(6238),
    [anon_sym__Alignas] = ACTIONS(6238),
    [anon_sym_QMARK] = ACTIONS(6238),
    [anon_sym_LT_EQ_GT] = ACTIONS(6238),
    [anon_sym_or] = ACTIONS(6238),
    [anon_sym_and] = ACTIONS(6238),
    [anon_sym_bitor] = ACTIONS(6238),
    [anon_sym_xor] = ACTIONS(6238),
    [anon_sym_bitand] = ACTIONS(6238),
    [anon_sym_not_eq] = ACTIONS(6238),
    [anon_sym_DASH_DASH] = ACTIONS(6238),
    [anon_sym_PLUS_PLUS] = ACTIONS(6238),
    [anon_sym_DOT] = ACTIONS(6240),
    [anon_sym_DOT_STAR] = ACTIONS(6238),
    [anon_sym_DASH_GT] = ACTIONS(6238),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6238),
    [anon_sym_decltype] = ACTIONS(6238),
    [anon_sym_final] = ACTIONS(6238),
    [anon_sym_override] = ACTIONS(6238),
    [anon_sym_GT2] = ACTIONS(6238),
    [anon_sym_requires] = ACTIONS(6238),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6238),
  },
  [STATE(2474)] = {
    [sym_attribute_specifier] = STATE(2507),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6242),
    [anon_sym_COMMA] = ACTIONS(6242),
    [anon_sym_LPAREN2] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6244),
    [anon_sym_PLUS] = ACTIONS(6244),
    [anon_sym_STAR] = ACTIONS(6242),
    [anon_sym_SLASH] = ACTIONS(6244),
    [anon_sym_PERCENT] = ACTIONS(6242),
    [anon_sym_PIPE_PIPE] = ACTIONS(6242),
    [anon_sym_AMP_AMP] = ACTIONS(6242),
    [anon_sym_PIPE] = ACTIONS(6244),
    [anon_sym_CARET] = ACTIONS(6242),
    [anon_sym_AMP] = ACTIONS(6244),
    [anon_sym_EQ_EQ] = ACTIONS(6242),
    [anon_sym_BANG_EQ] = ACTIONS(6242),
    [anon_sym_GT] = ACTIONS(6244),
    [anon_sym_GT_EQ] = ACTIONS(6244),
    [anon_sym_LT_EQ] = ACTIONS(6244),
    [anon_sym_LT] = ACTIONS(6244),
    [anon_sym_LT_LT] = ACTIONS(6244),
    [anon_sym_GT_GT] = ACTIONS(6244),
    [anon_sym___extension__] = ACTIONS(6242),
    [anon_sym___global__] = ACTIONS(6242),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6242),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [anon_sym_const] = ACTIONS(6244),
    [anon_sym_constexpr] = ACTIONS(6242),
    [anon_sym_volatile] = ACTIONS(6242),
    [anon_sym_restrict] = ACTIONS(6242),
    [anon_sym___restrict__] = ACTIONS(6242),
    [anon_sym__Atomic] = ACTIONS(6242),
    [anon_sym__Noreturn] = ACTIONS(6242),
    [anon_sym_noreturn] = ACTIONS(6242),
    [anon_sym__Nonnull] = ACTIONS(6242),
    [anon_sym_mutable] = ACTIONS(6242),
    [anon_sym_constinit] = ACTIONS(6242),
    [anon_sym_consteval] = ACTIONS(6242),
    [anon_sym___shared__] = ACTIONS(6242),
    [anon_sym___local__] = ACTIONS(6242),
    [anon_sym___constant__] = ACTIONS(6242),
    [anon_sym___managed__] = ACTIONS(6242),
    [anon_sym___grid_constant__] = ACTIONS(6242),
    [anon_sym_alignas] = ACTIONS(6242),
    [anon_sym__Alignas] = ACTIONS(6242),
    [anon_sym_QMARK] = ACTIONS(6242),
    [anon_sym_LT_EQ_GT] = ACTIONS(6242),
    [anon_sym_or] = ACTIONS(6242),
    [anon_sym_and] = ACTIONS(6242),
    [anon_sym_bitor] = ACTIONS(6242),
    [anon_sym_xor] = ACTIONS(6242),
    [anon_sym_bitand] = ACTIONS(6242),
    [anon_sym_not_eq] = ACTIONS(6242),
    [anon_sym_DASH_DASH] = ACTIONS(6242),
    [anon_sym_PLUS_PLUS] = ACTIONS(6242),
    [anon_sym_DOT] = ACTIONS(6244),
    [anon_sym_DOT_STAR] = ACTIONS(6242),
    [anon_sym_DASH_GT] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6242),
    [anon_sym_decltype] = ACTIONS(6242),
    [anon_sym_final] = ACTIONS(6242),
    [anon_sym_override] = ACTIONS(6242),
    [anon_sym_GT2] = ACTIONS(6242),
    [anon_sym_requires] = ACTIONS(6242),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6242),
  },
  [STATE(2475)] = {
    [sym_attribute_specifier] = STATE(2566),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6216),
    [anon_sym_COMMA] = ACTIONS(6216),
    [anon_sym_LPAREN2] = ACTIONS(6216),
    [anon_sym_DASH] = ACTIONS(6218),
    [anon_sym_PLUS] = ACTIONS(6218),
    [anon_sym_STAR] = ACTIONS(6216),
    [anon_sym_SLASH] = ACTIONS(6218),
    [anon_sym_PERCENT] = ACTIONS(6216),
    [anon_sym_PIPE_PIPE] = ACTIONS(6216),
    [anon_sym_AMP_AMP] = ACTIONS(6216),
    [anon_sym_PIPE] = ACTIONS(6218),
    [anon_sym_CARET] = ACTIONS(6216),
    [anon_sym_AMP] = ACTIONS(6218),
    [anon_sym_EQ_EQ] = ACTIONS(6216),
    [anon_sym_BANG_EQ] = ACTIONS(6216),
    [anon_sym_GT] = ACTIONS(6218),
    [anon_sym_GT_EQ] = ACTIONS(6218),
    [anon_sym_LT_EQ] = ACTIONS(6218),
    [anon_sym_LT] = ACTIONS(6218),
    [anon_sym_LT_LT] = ACTIONS(6218),
    [anon_sym_GT_GT] = ACTIONS(6218),
    [anon_sym___extension__] = ACTIONS(6216),
    [anon_sym___global__] = ACTIONS(6216),
    [anon_sym___attribute__] = ACTIONS(6202),
    [anon_sym___attribute] = ACTIONS(6204),
    [anon_sym_LBRACE] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6216),
    [anon_sym_const] = ACTIONS(6218),
    [anon_sym_constexpr] = ACTIONS(6216),
    [anon_sym_volatile] = ACTIONS(6216),
    [anon_sym_restrict] = ACTIONS(6216),
    [anon_sym___restrict__] = ACTIONS(6216),
    [anon_sym__Atomic] = ACTIONS(6216),
    [anon_sym__Noreturn] = ACTIONS(6216),
    [anon_sym_noreturn] = ACTIONS(6216),
    [anon_sym__Nonnull] = ACTIONS(6216),
    [anon_sym_mutable] = ACTIONS(6216),
    [anon_sym_constinit] = ACTIONS(6216),
    [anon_sym_consteval] = ACTIONS(6216),
    [anon_sym___shared__] = ACTIONS(6216),
    [anon_sym___local__] = ACTIONS(6216),
    [anon_sym___constant__] = ACTIONS(6216),
    [anon_sym___managed__] = ACTIONS(6216),
    [anon_sym___grid_constant__] = ACTIONS(6216),
    [anon_sym_alignas] = ACTIONS(6216),
    [anon_sym__Alignas] = ACTIONS(6216),
    [anon_sym_QMARK] = ACTIONS(6216),
    [anon_sym_LT_EQ_GT] = ACTIONS(6216),
    [anon_sym_or] = ACTIONS(6216),
    [anon_sym_and] = ACTIONS(6216),
    [anon_sym_bitor] = ACTIONS(6216),
    [anon_sym_xor] = ACTIONS(6216),
    [anon_sym_bitand] = ACTIONS(6216),
    [anon_sym_not_eq] = ACTIONS(6216),
    [anon_sym_DASH_DASH] = ACTIONS(6216),
    [anon_sym_PLUS_PLUS] = ACTIONS(6216),
    [anon_sym_DOT] = ACTIONS(6218),
    [anon_sym_DOT_STAR] = ACTIONS(6216),
    [anon_sym_DASH_GT] = ACTIONS(6216),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6216),
    [anon_sym_decltype] = ACTIONS(6216),
    [anon_sym_final] = ACTIONS(6216),
    [anon_sym_override] = ACTIONS(6216),
    [anon_sym_GT2] = ACTIONS(6216),
    [anon_sym_requires] = ACTIONS(6216),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6216),
  },
  [STATE(2476)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5855),
    [anon_sym_COMMA] = ACTIONS(5855),
    [anon_sym_LPAREN2] = ACTIONS(5855),
    [anon_sym_DASH] = ACTIONS(5853),
    [anon_sym_PLUS] = ACTIONS(5853),
    [anon_sym_STAR] = ACTIONS(5855),
    [anon_sym_SLASH] = ACTIONS(5853),
    [anon_sym_PERCENT] = ACTIONS(5855),
    [anon_sym_PIPE_PIPE] = ACTIONS(5855),
    [anon_sym_AMP_AMP] = ACTIONS(5855),
    [anon_sym_PIPE] = ACTIONS(5853),
    [anon_sym_CARET] = ACTIONS(5855),
    [anon_sym_AMP] = ACTIONS(5853),
    [anon_sym_EQ_EQ] = ACTIONS(5855),
    [anon_sym_BANG_EQ] = ACTIONS(5855),
    [anon_sym_GT] = ACTIONS(5853),
    [anon_sym_GT_EQ] = ACTIONS(5853),
    [anon_sym_LT_EQ] = ACTIONS(5853),
    [anon_sym_LT] = ACTIONS(5853),
    [anon_sym_LT_LT] = ACTIONS(5853),
    [anon_sym_GT_GT] = ACTIONS(5853),
    [anon_sym___extension__] = ACTIONS(5855),
    [anon_sym___global__] = ACTIONS(5855),
    [anon_sym___attribute__] = ACTIONS(5855),
    [anon_sym___attribute] = ACTIONS(5853),
    [anon_sym_LBRACE] = ACTIONS(5855),
    [anon_sym_LBRACK] = ACTIONS(5855),
    [anon_sym_const] = ACTIONS(5853),
    [anon_sym_constexpr] = ACTIONS(5855),
    [anon_sym_volatile] = ACTIONS(5855),
    [anon_sym_restrict] = ACTIONS(5855),
    [anon_sym___restrict__] = ACTIONS(5855),
    [anon_sym__Atomic] = ACTIONS(5855),
    [anon_sym__Noreturn] = ACTIONS(5855),
    [anon_sym_noreturn] = ACTIONS(5855),
    [anon_sym__Nonnull] = ACTIONS(5855),
    [anon_sym_mutable] = ACTIONS(5855),
    [anon_sym_constinit] = ACTIONS(5855),
    [anon_sym_consteval] = ACTIONS(5855),
    [anon_sym___shared__] = ACTIONS(5855),
    [anon_sym___local__] = ACTIONS(5855),
    [anon_sym___constant__] = ACTIONS(5855),
    [anon_sym___managed__] = ACTIONS(5855),
    [anon_sym___grid_constant__] = ACTIONS(5855),
    [anon_sym_alignas] = ACTIONS(5855),
    [anon_sym__Alignas] = ACTIONS(5855),
    [anon_sym_QMARK] = ACTIONS(5855),
    [anon_sym_LT_EQ_GT] = ACTIONS(5855),
    [anon_sym_or] = ACTIONS(5855),
    [anon_sym_and] = ACTIONS(5855),
    [anon_sym_bitor] = ACTIONS(5855),
    [anon_sym_xor] = ACTIONS(5855),
    [anon_sym_bitand] = ACTIONS(5855),
    [anon_sym_not_eq] = ACTIONS(5855),
    [anon_sym_DASH_DASH] = ACTIONS(5855),
    [anon_sym_PLUS_PLUS] = ACTIONS(5855),
    [anon_sym_DOT] = ACTIONS(5853),
    [anon_sym_DOT_STAR] = ACTIONS(5855),
    [anon_sym_DASH_GT] = ACTIONS(5855),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5855),
    [anon_sym_decltype] = ACTIONS(5855),
    [anon_sym_final] = ACTIONS(5855),
    [anon_sym_override] = ACTIONS(5855),
    [anon_sym_GT2] = ACTIONS(5855),
    [anon_sym_requires] = ACTIONS(5855),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5855),
  },
  [STATE(2477)] = {
    [sym_identifier] = ACTIONS(5714),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5716),
    [anon_sym_COMMA] = ACTIONS(5716),
    [anon_sym_RPAREN] = ACTIONS(5716),
    [aux_sym_preproc_if_token2] = ACTIONS(5716),
    [aux_sym_preproc_else_token1] = ACTIONS(5716),
    [aux_sym_preproc_elif_token1] = ACTIONS(5714),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5716),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5716),
    [anon_sym_LPAREN2] = ACTIONS(5716),
    [anon_sym_DASH] = ACTIONS(5714),
    [anon_sym_PLUS] = ACTIONS(5714),
    [anon_sym_STAR] = ACTIONS(5714),
    [anon_sym_SLASH] = ACTIONS(5714),
    [anon_sym_PERCENT] = ACTIONS(5714),
    [anon_sym_PIPE_PIPE] = ACTIONS(5716),
    [anon_sym_AMP_AMP] = ACTIONS(5716),
    [anon_sym_PIPE] = ACTIONS(5714),
    [anon_sym_CARET] = ACTIONS(5714),
    [anon_sym_AMP] = ACTIONS(5714),
    [anon_sym_EQ_EQ] = ACTIONS(5716),
    [anon_sym_BANG_EQ] = ACTIONS(5716),
    [anon_sym_GT] = ACTIONS(5714),
    [anon_sym_GT_EQ] = ACTIONS(5716),
    [anon_sym_LT_EQ] = ACTIONS(5714),
    [anon_sym_LT] = ACTIONS(5714),
    [anon_sym_LT_LT] = ACTIONS(5714),
    [anon_sym_GT_GT] = ACTIONS(5714),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym___attribute__] = ACTIONS(5714),
    [anon_sym___attribute] = ACTIONS(5714),
    [anon_sym_LBRACE] = ACTIONS(5716),
    [anon_sym_RBRACE] = ACTIONS(5716),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_RBRACK] = ACTIONS(5716),
    [anon_sym_EQ] = ACTIONS(5714),
    [anon_sym_COLON] = ACTIONS(5716),
    [anon_sym_QMARK] = ACTIONS(5716),
    [anon_sym_STAR_EQ] = ACTIONS(5716),
    [anon_sym_SLASH_EQ] = ACTIONS(5716),
    [anon_sym_PERCENT_EQ] = ACTIONS(5716),
    [anon_sym_PLUS_EQ] = ACTIONS(5716),
    [anon_sym_DASH_EQ] = ACTIONS(5716),
    [anon_sym_LT_LT_EQ] = ACTIONS(5716),
    [anon_sym_GT_GT_EQ] = ACTIONS(5716),
    [anon_sym_AMP_EQ] = ACTIONS(5716),
    [anon_sym_CARET_EQ] = ACTIONS(5716),
    [anon_sym_PIPE_EQ] = ACTIONS(5716),
    [anon_sym_and_eq] = ACTIONS(5714),
    [anon_sym_or_eq] = ACTIONS(5714),
    [anon_sym_xor_eq] = ACTIONS(5714),
    [anon_sym_LT_EQ_GT] = ACTIONS(5716),
    [anon_sym_or] = ACTIONS(5714),
    [anon_sym_and] = ACTIONS(5714),
    [anon_sym_bitor] = ACTIONS(5714),
    [anon_sym_xor] = ACTIONS(5714),
    [anon_sym_bitand] = ACTIONS(5714),
    [anon_sym_not_eq] = ACTIONS(5714),
    [anon_sym_DASH_DASH] = ACTIONS(5716),
    [anon_sym_PLUS_PLUS] = ACTIONS(5716),
    [anon_sym_DOT] = ACTIONS(5714),
    [anon_sym_DOT_STAR] = ACTIONS(5716),
    [anon_sym_DASH_GT] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5714),
    [anon_sym_decltype] = ACTIONS(5714),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5716),
  },
  [STATE(2478)] = {
    [sym_identifier] = ACTIONS(5797),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5799),
    [anon_sym_COMMA] = ACTIONS(5799),
    [anon_sym_RPAREN] = ACTIONS(5799),
    [aux_sym_preproc_if_token2] = ACTIONS(5799),
    [aux_sym_preproc_else_token1] = ACTIONS(5799),
    [aux_sym_preproc_elif_token1] = ACTIONS(5797),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5799),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5799),
    [anon_sym_LPAREN2] = ACTIONS(5799),
    [anon_sym_DASH] = ACTIONS(5797),
    [anon_sym_PLUS] = ACTIONS(5797),
    [anon_sym_STAR] = ACTIONS(5797),
    [anon_sym_SLASH] = ACTIONS(5797),
    [anon_sym_PERCENT] = ACTIONS(5797),
    [anon_sym_PIPE_PIPE] = ACTIONS(5799),
    [anon_sym_AMP_AMP] = ACTIONS(5799),
    [anon_sym_PIPE] = ACTIONS(5797),
    [anon_sym_CARET] = ACTIONS(5797),
    [anon_sym_AMP] = ACTIONS(5797),
    [anon_sym_EQ_EQ] = ACTIONS(5799),
    [anon_sym_BANG_EQ] = ACTIONS(5799),
    [anon_sym_GT] = ACTIONS(5797),
    [anon_sym_GT_EQ] = ACTIONS(5799),
    [anon_sym_LT_EQ] = ACTIONS(5797),
    [anon_sym_LT] = ACTIONS(5797),
    [anon_sym_LT_LT] = ACTIONS(5797),
    [anon_sym_GT_GT] = ACTIONS(5797),
    [anon_sym_SEMI] = ACTIONS(5799),
    [anon_sym___attribute__] = ACTIONS(5797),
    [anon_sym___attribute] = ACTIONS(5797),
    [anon_sym_LBRACE] = ACTIONS(5799),
    [anon_sym_RBRACE] = ACTIONS(5799),
    [anon_sym_LBRACK] = ACTIONS(5799),
    [anon_sym_RBRACK] = ACTIONS(5799),
    [anon_sym_EQ] = ACTIONS(5797),
    [anon_sym_COLON] = ACTIONS(5799),
    [anon_sym_QMARK] = ACTIONS(5799),
    [anon_sym_STAR_EQ] = ACTIONS(5799),
    [anon_sym_SLASH_EQ] = ACTIONS(5799),
    [anon_sym_PERCENT_EQ] = ACTIONS(5799),
    [anon_sym_PLUS_EQ] = ACTIONS(5799),
    [anon_sym_DASH_EQ] = ACTIONS(5799),
    [anon_sym_LT_LT_EQ] = ACTIONS(5799),
    [anon_sym_GT_GT_EQ] = ACTIONS(5799),
    [anon_sym_AMP_EQ] = ACTIONS(5799),
    [anon_sym_CARET_EQ] = ACTIONS(5799),
    [anon_sym_PIPE_EQ] = ACTIONS(5799),
    [anon_sym_and_eq] = ACTIONS(5797),
    [anon_sym_or_eq] = ACTIONS(5797),
    [anon_sym_xor_eq] = ACTIONS(5797),
    [anon_sym_LT_EQ_GT] = ACTIONS(5799),
    [anon_sym_or] = ACTIONS(5797),
    [anon_sym_and] = ACTIONS(5797),
    [anon_sym_bitor] = ACTIONS(5797),
    [anon_sym_xor] = ACTIONS(5797),
    [anon_sym_bitand] = ACTIONS(5797),
    [anon_sym_not_eq] = ACTIONS(5797),
    [anon_sym_DASH_DASH] = ACTIONS(5799),
    [anon_sym_PLUS_PLUS] = ACTIONS(5799),
    [anon_sym_DOT] = ACTIONS(5797),
    [anon_sym_DOT_STAR] = ACTIONS(5799),
    [anon_sym_DASH_GT] = ACTIONS(5799),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5797),
    [anon_sym_decltype] = ACTIONS(5797),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5799),
  },
  [STATE(2479)] = {
    [sym_identifier] = ACTIONS(5809),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5811),
    [anon_sym_COMMA] = ACTIONS(5811),
    [anon_sym_RPAREN] = ACTIONS(5811),
    [aux_sym_preproc_if_token2] = ACTIONS(5811),
    [aux_sym_preproc_else_token1] = ACTIONS(5811),
    [aux_sym_preproc_elif_token1] = ACTIONS(5809),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5811),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5811),
    [anon_sym_LPAREN2] = ACTIONS(5811),
    [anon_sym_DASH] = ACTIONS(5809),
    [anon_sym_PLUS] = ACTIONS(5809),
    [anon_sym_STAR] = ACTIONS(5809),
    [anon_sym_SLASH] = ACTIONS(5809),
    [anon_sym_PERCENT] = ACTIONS(5809),
    [anon_sym_PIPE_PIPE] = ACTIONS(5811),
    [anon_sym_AMP_AMP] = ACTIONS(5811),
    [anon_sym_PIPE] = ACTIONS(5809),
    [anon_sym_CARET] = ACTIONS(5809),
    [anon_sym_AMP] = ACTIONS(5809),
    [anon_sym_EQ_EQ] = ACTIONS(5811),
    [anon_sym_BANG_EQ] = ACTIONS(5811),
    [anon_sym_GT] = ACTIONS(5809),
    [anon_sym_GT_EQ] = ACTIONS(5811),
    [anon_sym_LT_EQ] = ACTIONS(5809),
    [anon_sym_LT] = ACTIONS(5809),
    [anon_sym_LT_LT] = ACTIONS(5809),
    [anon_sym_GT_GT] = ACTIONS(5809),
    [anon_sym_SEMI] = ACTIONS(5811),
    [anon_sym___attribute__] = ACTIONS(5809),
    [anon_sym___attribute] = ACTIONS(5809),
    [anon_sym_LBRACE] = ACTIONS(5811),
    [anon_sym_RBRACE] = ACTIONS(5811),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [anon_sym_RBRACK] = ACTIONS(5811),
    [anon_sym_EQ] = ACTIONS(5809),
    [anon_sym_COLON] = ACTIONS(5811),
    [anon_sym_QMARK] = ACTIONS(5811),
    [anon_sym_STAR_EQ] = ACTIONS(5811),
    [anon_sym_SLASH_EQ] = ACTIONS(5811),
    [anon_sym_PERCENT_EQ] = ACTIONS(5811),
    [anon_sym_PLUS_EQ] = ACTIONS(5811),
    [anon_sym_DASH_EQ] = ACTIONS(5811),
    [anon_sym_LT_LT_EQ] = ACTIONS(5811),
    [anon_sym_GT_GT_EQ] = ACTIONS(5811),
    [anon_sym_AMP_EQ] = ACTIONS(5811),
    [anon_sym_CARET_EQ] = ACTIONS(5811),
    [anon_sym_PIPE_EQ] = ACTIONS(5811),
    [anon_sym_and_eq] = ACTIONS(5809),
    [anon_sym_or_eq] = ACTIONS(5809),
    [anon_sym_xor_eq] = ACTIONS(5809),
    [anon_sym_LT_EQ_GT] = ACTIONS(5811),
    [anon_sym_or] = ACTIONS(5809),
    [anon_sym_and] = ACTIONS(5809),
    [anon_sym_bitor] = ACTIONS(5809),
    [anon_sym_xor] = ACTIONS(5809),
    [anon_sym_bitand] = ACTIONS(5809),
    [anon_sym_not_eq] = ACTIONS(5809),
    [anon_sym_DASH_DASH] = ACTIONS(5811),
    [anon_sym_PLUS_PLUS] = ACTIONS(5811),
    [anon_sym_DOT] = ACTIONS(5809),
    [anon_sym_DOT_STAR] = ACTIONS(5811),
    [anon_sym_DASH_GT] = ACTIONS(5811),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5809),
    [anon_sym_decltype] = ACTIONS(5809),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5811),
  },
  [STATE(2480)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2537),
    [sym_identifier] = ACTIONS(6008),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6006),
    [anon_sym_COMMA] = ACTIONS(6006),
    [aux_sym_preproc_if_token2] = ACTIONS(6006),
    [aux_sym_preproc_else_token1] = ACTIONS(6006),
    [aux_sym_preproc_elif_token1] = ACTIONS(6008),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6006),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6006),
    [anon_sym_LPAREN2] = ACTIONS(6006),
    [anon_sym_DASH] = ACTIONS(6008),
    [anon_sym_PLUS] = ACTIONS(6008),
    [anon_sym_STAR] = ACTIONS(6008),
    [anon_sym_SLASH] = ACTIONS(6008),
    [anon_sym_PERCENT] = ACTIONS(6008),
    [anon_sym_PIPE_PIPE] = ACTIONS(6006),
    [anon_sym_AMP_AMP] = ACTIONS(6006),
    [anon_sym_PIPE] = ACTIONS(6008),
    [anon_sym_CARET] = ACTIONS(6008),
    [anon_sym_AMP] = ACTIONS(6008),
    [anon_sym_EQ_EQ] = ACTIONS(6006),
    [anon_sym_BANG_EQ] = ACTIONS(6006),
    [anon_sym_GT] = ACTIONS(6008),
    [anon_sym_GT_EQ] = ACTIONS(6006),
    [anon_sym_LT_EQ] = ACTIONS(6008),
    [anon_sym_LT] = ACTIONS(6008),
    [anon_sym_LT_LT] = ACTIONS(6008),
    [anon_sym_GT_GT] = ACTIONS(6008),
    [anon_sym___attribute__] = ACTIONS(6008),
    [anon_sym___attribute] = ACTIONS(6008),
    [anon_sym_LBRACE] = ACTIONS(6006),
    [anon_sym_signed] = ACTIONS(6516),
    [anon_sym_unsigned] = ACTIONS(6516),
    [anon_sym_long] = ACTIONS(6516),
    [anon_sym_short] = ACTIONS(6516),
    [anon_sym_LBRACK] = ACTIONS(6006),
    [anon_sym_EQ] = ACTIONS(6008),
    [anon_sym_QMARK] = ACTIONS(6006),
    [anon_sym_STAR_EQ] = ACTIONS(6006),
    [anon_sym_SLASH_EQ] = ACTIONS(6006),
    [anon_sym_PERCENT_EQ] = ACTIONS(6006),
    [anon_sym_PLUS_EQ] = ACTIONS(6006),
    [anon_sym_DASH_EQ] = ACTIONS(6006),
    [anon_sym_LT_LT_EQ] = ACTIONS(6006),
    [anon_sym_GT_GT_EQ] = ACTIONS(6006),
    [anon_sym_AMP_EQ] = ACTIONS(6006),
    [anon_sym_CARET_EQ] = ACTIONS(6006),
    [anon_sym_PIPE_EQ] = ACTIONS(6006),
    [anon_sym_and_eq] = ACTIONS(6008),
    [anon_sym_or_eq] = ACTIONS(6008),
    [anon_sym_xor_eq] = ACTIONS(6008),
    [anon_sym_LT_EQ_GT] = ACTIONS(6006),
    [anon_sym_or] = ACTIONS(6008),
    [anon_sym_and] = ACTIONS(6008),
    [anon_sym_bitor] = ACTIONS(6008),
    [anon_sym_xor] = ACTIONS(6008),
    [anon_sym_bitand] = ACTIONS(6008),
    [anon_sym_not_eq] = ACTIONS(6008),
    [anon_sym_DASH_DASH] = ACTIONS(6006),
    [anon_sym_PLUS_PLUS] = ACTIONS(6006),
    [anon_sym_DOT] = ACTIONS(6008),
    [anon_sym_DOT_STAR] = ACTIONS(6006),
    [anon_sym_DASH_GT] = ACTIONS(6006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6008),
    [anon_sym_decltype] = ACTIONS(6008),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6006),
  },
  [STATE(2481)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2568),
    [sym_identifier] = ACTIONS(5770),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [aux_sym_preproc_if_token2] = ACTIONS(5772),
    [aux_sym_preproc_else_token1] = ACTIONS(5772),
    [aux_sym_preproc_elif_token1] = ACTIONS(5770),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5772),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_DASH] = ACTIONS(5770),
    [anon_sym_PLUS] = ACTIONS(5770),
    [anon_sym_STAR] = ACTIONS(5770),
    [anon_sym_SLASH] = ACTIONS(5770),
    [anon_sym_PERCENT] = ACTIONS(5770),
    [anon_sym_PIPE_PIPE] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_PIPE] = ACTIONS(5770),
    [anon_sym_CARET] = ACTIONS(5770),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_EQ_EQ] = ACTIONS(5772),
    [anon_sym_BANG_EQ] = ACTIONS(5772),
    [anon_sym_GT] = ACTIONS(5770),
    [anon_sym_GT_EQ] = ACTIONS(5772),
    [anon_sym_LT_EQ] = ACTIONS(5770),
    [anon_sym_LT] = ACTIONS(5770),
    [anon_sym_LT_LT] = ACTIONS(5770),
    [anon_sym_GT_GT] = ACTIONS(5770),
    [anon_sym___attribute__] = ACTIONS(5770),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_signed] = ACTIONS(6518),
    [anon_sym_unsigned] = ACTIONS(6518),
    [anon_sym_long] = ACTIONS(6518),
    [anon_sym_short] = ACTIONS(6518),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_EQ] = ACTIONS(5770),
    [anon_sym_QMARK] = ACTIONS(5772),
    [anon_sym_STAR_EQ] = ACTIONS(5772),
    [anon_sym_SLASH_EQ] = ACTIONS(5772),
    [anon_sym_PERCENT_EQ] = ACTIONS(5772),
    [anon_sym_PLUS_EQ] = ACTIONS(5772),
    [anon_sym_DASH_EQ] = ACTIONS(5772),
    [anon_sym_LT_LT_EQ] = ACTIONS(5772),
    [anon_sym_GT_GT_EQ] = ACTIONS(5772),
    [anon_sym_AMP_EQ] = ACTIONS(5772),
    [anon_sym_CARET_EQ] = ACTIONS(5772),
    [anon_sym_PIPE_EQ] = ACTIONS(5772),
    [anon_sym_and_eq] = ACTIONS(5770),
    [anon_sym_or_eq] = ACTIONS(5770),
    [anon_sym_xor_eq] = ACTIONS(5770),
    [anon_sym_LT_EQ_GT] = ACTIONS(5772),
    [anon_sym_or] = ACTIONS(5770),
    [anon_sym_and] = ACTIONS(5770),
    [anon_sym_bitor] = ACTIONS(5770),
    [anon_sym_xor] = ACTIONS(5770),
    [anon_sym_bitand] = ACTIONS(5770),
    [anon_sym_not_eq] = ACTIONS(5770),
    [anon_sym_DASH_DASH] = ACTIONS(5772),
    [anon_sym_PLUS_PLUS] = ACTIONS(5772),
    [anon_sym_DOT] = ACTIONS(5770),
    [anon_sym_DOT_STAR] = ACTIONS(5772),
    [anon_sym_DASH_GT] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5770),
    [anon_sym_decltype] = ACTIONS(5770),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5772),
  },
  [STATE(2482)] = {
    [sym_identifier] = ACTIONS(5770),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_RPAREN] = ACTIONS(5772),
    [aux_sym_preproc_if_token2] = ACTIONS(5772),
    [aux_sym_preproc_else_token1] = ACTIONS(5772),
    [aux_sym_preproc_elif_token1] = ACTIONS(5770),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5772),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_DASH] = ACTIONS(5770),
    [anon_sym_PLUS] = ACTIONS(5770),
    [anon_sym_STAR] = ACTIONS(5770),
    [anon_sym_SLASH] = ACTIONS(5770),
    [anon_sym_PERCENT] = ACTIONS(5770),
    [anon_sym_PIPE_PIPE] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_PIPE] = ACTIONS(5770),
    [anon_sym_CARET] = ACTIONS(5770),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_EQ_EQ] = ACTIONS(5772),
    [anon_sym_BANG_EQ] = ACTIONS(5772),
    [anon_sym_GT] = ACTIONS(5770),
    [anon_sym_GT_EQ] = ACTIONS(5772),
    [anon_sym_LT_EQ] = ACTIONS(5770),
    [anon_sym_LT] = ACTIONS(5770),
    [anon_sym_LT_LT] = ACTIONS(5770),
    [anon_sym_GT_GT] = ACTIONS(5770),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym___attribute__] = ACTIONS(5770),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_RBRACE] = ACTIONS(5772),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_RBRACK] = ACTIONS(5772),
    [anon_sym_EQ] = ACTIONS(5770),
    [anon_sym_COLON] = ACTIONS(5772),
    [anon_sym_QMARK] = ACTIONS(5772),
    [anon_sym_STAR_EQ] = ACTIONS(5772),
    [anon_sym_SLASH_EQ] = ACTIONS(5772),
    [anon_sym_PERCENT_EQ] = ACTIONS(5772),
    [anon_sym_PLUS_EQ] = ACTIONS(5772),
    [anon_sym_DASH_EQ] = ACTIONS(5772),
    [anon_sym_LT_LT_EQ] = ACTIONS(5772),
    [anon_sym_GT_GT_EQ] = ACTIONS(5772),
    [anon_sym_AMP_EQ] = ACTIONS(5772),
    [anon_sym_CARET_EQ] = ACTIONS(5772),
    [anon_sym_PIPE_EQ] = ACTIONS(5772),
    [anon_sym_and_eq] = ACTIONS(5770),
    [anon_sym_or_eq] = ACTIONS(5770),
    [anon_sym_xor_eq] = ACTIONS(5770),
    [anon_sym_LT_EQ_GT] = ACTIONS(5772),
    [anon_sym_or] = ACTIONS(5770),
    [anon_sym_and] = ACTIONS(5770),
    [anon_sym_bitor] = ACTIONS(5770),
    [anon_sym_xor] = ACTIONS(5770),
    [anon_sym_bitand] = ACTIONS(5770),
    [anon_sym_not_eq] = ACTIONS(5770),
    [anon_sym_DASH_DASH] = ACTIONS(5772),
    [anon_sym_PLUS_PLUS] = ACTIONS(5772),
    [anon_sym_DOT] = ACTIONS(5770),
    [anon_sym_DOT_STAR] = ACTIONS(5772),
    [anon_sym_DASH_GT] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5770),
    [anon_sym_decltype] = ACTIONS(5770),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5772),
  },
  [STATE(2483)] = {
    [sym_identifier] = ACTIONS(5774),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5776),
    [anon_sym_COMMA] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5776),
    [aux_sym_preproc_if_token2] = ACTIONS(5776),
    [aux_sym_preproc_else_token1] = ACTIONS(5776),
    [aux_sym_preproc_elif_token1] = ACTIONS(5774),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5776),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5776),
    [anon_sym_LPAREN2] = ACTIONS(5776),
    [anon_sym_DASH] = ACTIONS(5774),
    [anon_sym_PLUS] = ACTIONS(5774),
    [anon_sym_STAR] = ACTIONS(5774),
    [anon_sym_SLASH] = ACTIONS(5774),
    [anon_sym_PERCENT] = ACTIONS(5774),
    [anon_sym_PIPE_PIPE] = ACTIONS(5776),
    [anon_sym_AMP_AMP] = ACTIONS(5776),
    [anon_sym_PIPE] = ACTIONS(5774),
    [anon_sym_CARET] = ACTIONS(5774),
    [anon_sym_AMP] = ACTIONS(5774),
    [anon_sym_EQ_EQ] = ACTIONS(5776),
    [anon_sym_BANG_EQ] = ACTIONS(5776),
    [anon_sym_GT] = ACTIONS(5774),
    [anon_sym_GT_EQ] = ACTIONS(5776),
    [anon_sym_LT_EQ] = ACTIONS(5774),
    [anon_sym_LT] = ACTIONS(5774),
    [anon_sym_LT_LT] = ACTIONS(5774),
    [anon_sym_GT_GT] = ACTIONS(5774),
    [anon_sym_SEMI] = ACTIONS(5776),
    [anon_sym___attribute__] = ACTIONS(5774),
    [anon_sym___attribute] = ACTIONS(5774),
    [anon_sym_LBRACE] = ACTIONS(5776),
    [anon_sym_RBRACE] = ACTIONS(5776),
    [anon_sym_LBRACK] = ACTIONS(5776),
    [anon_sym_RBRACK] = ACTIONS(5776),
    [anon_sym_EQ] = ACTIONS(5774),
    [anon_sym_COLON] = ACTIONS(5776),
    [anon_sym_QMARK] = ACTIONS(5776),
    [anon_sym_STAR_EQ] = ACTIONS(5776),
    [anon_sym_SLASH_EQ] = ACTIONS(5776),
    [anon_sym_PERCENT_EQ] = ACTIONS(5776),
    [anon_sym_PLUS_EQ] = ACTIONS(5776),
    [anon_sym_DASH_EQ] = ACTIONS(5776),
    [anon_sym_LT_LT_EQ] = ACTIONS(5776),
    [anon_sym_GT_GT_EQ] = ACTIONS(5776),
    [anon_sym_AMP_EQ] = ACTIONS(5776),
    [anon_sym_CARET_EQ] = ACTIONS(5776),
    [anon_sym_PIPE_EQ] = ACTIONS(5776),
    [anon_sym_and_eq] = ACTIONS(5774),
    [anon_sym_or_eq] = ACTIONS(5774),
    [anon_sym_xor_eq] = ACTIONS(5774),
    [anon_sym_LT_EQ_GT] = ACTIONS(5776),
    [anon_sym_or] = ACTIONS(5774),
    [anon_sym_and] = ACTIONS(5774),
    [anon_sym_bitor] = ACTIONS(5774),
    [anon_sym_xor] = ACTIONS(5774),
    [anon_sym_bitand] = ACTIONS(5774),
    [anon_sym_not_eq] = ACTIONS(5774),
    [anon_sym_DASH_DASH] = ACTIONS(5776),
    [anon_sym_PLUS_PLUS] = ACTIONS(5776),
    [anon_sym_DOT] = ACTIONS(5774),
    [anon_sym_DOT_STAR] = ACTIONS(5776),
    [anon_sym_DASH_GT] = ACTIONS(5776),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5774),
    [anon_sym_decltype] = ACTIONS(5774),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5776),
  },
  [STATE(2484)] = {
    [sym_identifier] = ACTIONS(5853),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5855),
    [anon_sym_COMMA] = ACTIONS(5855),
    [anon_sym_RPAREN] = ACTIONS(5855),
    [aux_sym_preproc_if_token2] = ACTIONS(5855),
    [aux_sym_preproc_else_token1] = ACTIONS(5855),
    [aux_sym_preproc_elif_token1] = ACTIONS(5853),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5855),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5855),
    [anon_sym_LPAREN2] = ACTIONS(5855),
    [anon_sym_DASH] = ACTIONS(5853),
    [anon_sym_PLUS] = ACTIONS(5853),
    [anon_sym_STAR] = ACTIONS(5853),
    [anon_sym_SLASH] = ACTIONS(5853),
    [anon_sym_PERCENT] = ACTIONS(5853),
    [anon_sym_PIPE_PIPE] = ACTIONS(5855),
    [anon_sym_AMP_AMP] = ACTIONS(5855),
    [anon_sym_PIPE] = ACTIONS(5853),
    [anon_sym_CARET] = ACTIONS(5853),
    [anon_sym_AMP] = ACTIONS(5853),
    [anon_sym_EQ_EQ] = ACTIONS(5855),
    [anon_sym_BANG_EQ] = ACTIONS(5855),
    [anon_sym_GT] = ACTIONS(5853),
    [anon_sym_GT_EQ] = ACTIONS(5855),
    [anon_sym_LT_EQ] = ACTIONS(5853),
    [anon_sym_LT] = ACTIONS(5853),
    [anon_sym_LT_LT] = ACTIONS(5853),
    [anon_sym_GT_GT] = ACTIONS(5853),
    [anon_sym_SEMI] = ACTIONS(5855),
    [anon_sym___attribute__] = ACTIONS(5853),
    [anon_sym___attribute] = ACTIONS(5853),
    [anon_sym_LBRACE] = ACTIONS(5855),
    [anon_sym_RBRACE] = ACTIONS(5855),
    [anon_sym_LBRACK] = ACTIONS(5855),
    [anon_sym_RBRACK] = ACTIONS(5855),
    [anon_sym_EQ] = ACTIONS(5853),
    [anon_sym_COLON] = ACTIONS(5855),
    [anon_sym_QMARK] = ACTIONS(5855),
    [anon_sym_STAR_EQ] = ACTIONS(5855),
    [anon_sym_SLASH_EQ] = ACTIONS(5855),
    [anon_sym_PERCENT_EQ] = ACTIONS(5855),
    [anon_sym_PLUS_EQ] = ACTIONS(5855),
    [anon_sym_DASH_EQ] = ACTIONS(5855),
    [anon_sym_LT_LT_EQ] = ACTIONS(5855),
    [anon_sym_GT_GT_EQ] = ACTIONS(5855),
    [anon_sym_AMP_EQ] = ACTIONS(5855),
    [anon_sym_CARET_EQ] = ACTIONS(5855),
    [anon_sym_PIPE_EQ] = ACTIONS(5855),
    [anon_sym_and_eq] = ACTIONS(5853),
    [anon_sym_or_eq] = ACTIONS(5853),
    [anon_sym_xor_eq] = ACTIONS(5853),
    [anon_sym_LT_EQ_GT] = ACTIONS(5855),
    [anon_sym_or] = ACTIONS(5853),
    [anon_sym_and] = ACTIONS(5853),
    [anon_sym_bitor] = ACTIONS(5853),
    [anon_sym_xor] = ACTIONS(5853),
    [anon_sym_bitand] = ACTIONS(5853),
    [anon_sym_not_eq] = ACTIONS(5853),
    [anon_sym_DASH_DASH] = ACTIONS(5855),
    [anon_sym_PLUS_PLUS] = ACTIONS(5855),
    [anon_sym_DOT] = ACTIONS(5853),
    [anon_sym_DOT_STAR] = ACTIONS(5855),
    [anon_sym_DASH_GT] = ACTIONS(5855),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5853),
    [anon_sym_decltype] = ACTIONS(5853),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5855),
  },
  [STATE(2485)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2537),
    [sym_identifier] = ACTIONS(6026),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6024),
    [anon_sym_COMMA] = ACTIONS(6024),
    [aux_sym_preproc_if_token2] = ACTIONS(6024),
    [aux_sym_preproc_else_token1] = ACTIONS(6024),
    [aux_sym_preproc_elif_token1] = ACTIONS(6026),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6024),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6024),
    [anon_sym_LPAREN2] = ACTIONS(6024),
    [anon_sym_DASH] = ACTIONS(6026),
    [anon_sym_PLUS] = ACTIONS(6026),
    [anon_sym_STAR] = ACTIONS(6026),
    [anon_sym_SLASH] = ACTIONS(6026),
    [anon_sym_PERCENT] = ACTIONS(6026),
    [anon_sym_PIPE_PIPE] = ACTIONS(6024),
    [anon_sym_AMP_AMP] = ACTIONS(6024),
    [anon_sym_PIPE] = ACTIONS(6026),
    [anon_sym_CARET] = ACTIONS(6026),
    [anon_sym_AMP] = ACTIONS(6026),
    [anon_sym_EQ_EQ] = ACTIONS(6024),
    [anon_sym_BANG_EQ] = ACTIONS(6024),
    [anon_sym_GT] = ACTIONS(6026),
    [anon_sym_GT_EQ] = ACTIONS(6024),
    [anon_sym_LT_EQ] = ACTIONS(6026),
    [anon_sym_LT] = ACTIONS(6026),
    [anon_sym_LT_LT] = ACTIONS(6026),
    [anon_sym_GT_GT] = ACTIONS(6026),
    [anon_sym___attribute__] = ACTIONS(6026),
    [anon_sym___attribute] = ACTIONS(6026),
    [anon_sym_LBRACE] = ACTIONS(6024),
    [anon_sym_signed] = ACTIONS(6516),
    [anon_sym_unsigned] = ACTIONS(6516),
    [anon_sym_long] = ACTIONS(6516),
    [anon_sym_short] = ACTIONS(6516),
    [anon_sym_LBRACK] = ACTIONS(6024),
    [anon_sym_EQ] = ACTIONS(6026),
    [anon_sym_QMARK] = ACTIONS(6024),
    [anon_sym_STAR_EQ] = ACTIONS(6024),
    [anon_sym_SLASH_EQ] = ACTIONS(6024),
    [anon_sym_PERCENT_EQ] = ACTIONS(6024),
    [anon_sym_PLUS_EQ] = ACTIONS(6024),
    [anon_sym_DASH_EQ] = ACTIONS(6024),
    [anon_sym_LT_LT_EQ] = ACTIONS(6024),
    [anon_sym_GT_GT_EQ] = ACTIONS(6024),
    [anon_sym_AMP_EQ] = ACTIONS(6024),
    [anon_sym_CARET_EQ] = ACTIONS(6024),
    [anon_sym_PIPE_EQ] = ACTIONS(6024),
    [anon_sym_and_eq] = ACTIONS(6026),
    [anon_sym_or_eq] = ACTIONS(6026),
    [anon_sym_xor_eq] = ACTIONS(6026),
    [anon_sym_LT_EQ_GT] = ACTIONS(6024),
    [anon_sym_or] = ACTIONS(6026),
    [anon_sym_and] = ACTIONS(6026),
    [anon_sym_bitor] = ACTIONS(6026),
    [anon_sym_xor] = ACTIONS(6026),
    [anon_sym_bitand] = ACTIONS(6026),
    [anon_sym_not_eq] = ACTIONS(6026),
    [anon_sym_DASH_DASH] = ACTIONS(6024),
    [anon_sym_PLUS_PLUS] = ACTIONS(6024),
    [anon_sym_DOT] = ACTIONS(6026),
    [anon_sym_DOT_STAR] = ACTIONS(6024),
    [anon_sym_DASH_GT] = ACTIONS(6024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6026),
    [anon_sym_decltype] = ACTIONS(6026),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6024),
  },
  [STATE(2486)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2537),
    [sym_identifier] = ACTIONS(5964),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5962),
    [anon_sym_COMMA] = ACTIONS(5962),
    [aux_sym_preproc_if_token2] = ACTIONS(5962),
    [aux_sym_preproc_else_token1] = ACTIONS(5962),
    [aux_sym_preproc_elif_token1] = ACTIONS(5964),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5962),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5962),
    [anon_sym_LPAREN2] = ACTIONS(5962),
    [anon_sym_DASH] = ACTIONS(5964),
    [anon_sym_PLUS] = ACTIONS(5964),
    [anon_sym_STAR] = ACTIONS(5964),
    [anon_sym_SLASH] = ACTIONS(5964),
    [anon_sym_PERCENT] = ACTIONS(5964),
    [anon_sym_PIPE_PIPE] = ACTIONS(5962),
    [anon_sym_AMP_AMP] = ACTIONS(5962),
    [anon_sym_PIPE] = ACTIONS(5964),
    [anon_sym_CARET] = ACTIONS(5964),
    [anon_sym_AMP] = ACTIONS(5964),
    [anon_sym_EQ_EQ] = ACTIONS(5962),
    [anon_sym_BANG_EQ] = ACTIONS(5962),
    [anon_sym_GT] = ACTIONS(5964),
    [anon_sym_GT_EQ] = ACTIONS(5962),
    [anon_sym_LT_EQ] = ACTIONS(5964),
    [anon_sym_LT] = ACTIONS(5964),
    [anon_sym_LT_LT] = ACTIONS(5964),
    [anon_sym_GT_GT] = ACTIONS(5964),
    [anon_sym___attribute__] = ACTIONS(5964),
    [anon_sym___attribute] = ACTIONS(5964),
    [anon_sym_LBRACE] = ACTIONS(5962),
    [anon_sym_signed] = ACTIONS(6516),
    [anon_sym_unsigned] = ACTIONS(6516),
    [anon_sym_long] = ACTIONS(6516),
    [anon_sym_short] = ACTIONS(6516),
    [anon_sym_LBRACK] = ACTIONS(5962),
    [anon_sym_EQ] = ACTIONS(5964),
    [anon_sym_QMARK] = ACTIONS(5962),
    [anon_sym_STAR_EQ] = ACTIONS(5962),
    [anon_sym_SLASH_EQ] = ACTIONS(5962),
    [anon_sym_PERCENT_EQ] = ACTIONS(5962),
    [anon_sym_PLUS_EQ] = ACTIONS(5962),
    [anon_sym_DASH_EQ] = ACTIONS(5962),
    [anon_sym_LT_LT_EQ] = ACTIONS(5962),
    [anon_sym_GT_GT_EQ] = ACTIONS(5962),
    [anon_sym_AMP_EQ] = ACTIONS(5962),
    [anon_sym_CARET_EQ] = ACTIONS(5962),
    [anon_sym_PIPE_EQ] = ACTIONS(5962),
    [anon_sym_and_eq] = ACTIONS(5964),
    [anon_sym_or_eq] = ACTIONS(5964),
    [anon_sym_xor_eq] = ACTIONS(5964),
    [anon_sym_LT_EQ_GT] = ACTIONS(5962),
    [anon_sym_or] = ACTIONS(5964),
    [anon_sym_and] = ACTIONS(5964),
    [anon_sym_bitor] = ACTIONS(5964),
    [anon_sym_xor] = ACTIONS(5964),
    [anon_sym_bitand] = ACTIONS(5964),
    [anon_sym_not_eq] = ACTIONS(5964),
    [anon_sym_DASH_DASH] = ACTIONS(5962),
    [anon_sym_PLUS_PLUS] = ACTIONS(5962),
    [anon_sym_DOT] = ACTIONS(5964),
    [anon_sym_DOT_STAR] = ACTIONS(5962),
    [anon_sym_DASH_GT] = ACTIONS(5962),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5964),
    [anon_sym_decltype] = ACTIONS(5964),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5962),
  },
  [STATE(2487)] = {
    [sym_identifier] = ACTIONS(5821),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5823),
    [anon_sym_COMMA] = ACTIONS(5823),
    [anon_sym_RPAREN] = ACTIONS(5823),
    [aux_sym_preproc_if_token2] = ACTIONS(5823),
    [aux_sym_preproc_else_token1] = ACTIONS(5823),
    [aux_sym_preproc_elif_token1] = ACTIONS(5821),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5823),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5823),
    [anon_sym_LPAREN2] = ACTIONS(5823),
    [anon_sym_DASH] = ACTIONS(5821),
    [anon_sym_PLUS] = ACTIONS(5821),
    [anon_sym_STAR] = ACTIONS(5821),
    [anon_sym_SLASH] = ACTIONS(5821),
    [anon_sym_PERCENT] = ACTIONS(5821),
    [anon_sym_PIPE_PIPE] = ACTIONS(5823),
    [anon_sym_AMP_AMP] = ACTIONS(5823),
    [anon_sym_PIPE] = ACTIONS(5821),
    [anon_sym_CARET] = ACTIONS(5821),
    [anon_sym_AMP] = ACTIONS(5821),
    [anon_sym_EQ_EQ] = ACTIONS(5823),
    [anon_sym_BANG_EQ] = ACTIONS(5823),
    [anon_sym_GT] = ACTIONS(5821),
    [anon_sym_GT_EQ] = ACTIONS(5823),
    [anon_sym_LT_EQ] = ACTIONS(5821),
    [anon_sym_LT] = ACTIONS(5821),
    [anon_sym_LT_LT] = ACTIONS(5821),
    [anon_sym_GT_GT] = ACTIONS(5821),
    [anon_sym_SEMI] = ACTIONS(5823),
    [anon_sym___attribute__] = ACTIONS(5821),
    [anon_sym___attribute] = ACTIONS(5821),
    [anon_sym_LBRACE] = ACTIONS(5823),
    [anon_sym_RBRACE] = ACTIONS(5823),
    [anon_sym_LBRACK] = ACTIONS(5823),
    [anon_sym_RBRACK] = ACTIONS(5823),
    [anon_sym_EQ] = ACTIONS(5821),
    [anon_sym_COLON] = ACTIONS(5823),
    [anon_sym_QMARK] = ACTIONS(5823),
    [anon_sym_STAR_EQ] = ACTIONS(5823),
    [anon_sym_SLASH_EQ] = ACTIONS(5823),
    [anon_sym_PERCENT_EQ] = ACTIONS(5823),
    [anon_sym_PLUS_EQ] = ACTIONS(5823),
    [anon_sym_DASH_EQ] = ACTIONS(5823),
    [anon_sym_LT_LT_EQ] = ACTIONS(5823),
    [anon_sym_GT_GT_EQ] = ACTIONS(5823),
    [anon_sym_AMP_EQ] = ACTIONS(5823),
    [anon_sym_CARET_EQ] = ACTIONS(5823),
    [anon_sym_PIPE_EQ] = ACTIONS(5823),
    [anon_sym_and_eq] = ACTIONS(5821),
    [anon_sym_or_eq] = ACTIONS(5821),
    [anon_sym_xor_eq] = ACTIONS(5821),
    [anon_sym_LT_EQ_GT] = ACTIONS(5823),
    [anon_sym_or] = ACTIONS(5821),
    [anon_sym_and] = ACTIONS(5821),
    [anon_sym_bitor] = ACTIONS(5821),
    [anon_sym_xor] = ACTIONS(5821),
    [anon_sym_bitand] = ACTIONS(5821),
    [anon_sym_not_eq] = ACTIONS(5821),
    [anon_sym_DASH_DASH] = ACTIONS(5823),
    [anon_sym_PLUS_PLUS] = ACTIONS(5823),
    [anon_sym_DOT] = ACTIONS(5821),
    [anon_sym_DOT_STAR] = ACTIONS(5823),
    [anon_sym_DASH_GT] = ACTIONS(5823),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5821),
    [anon_sym_decltype] = ACTIONS(5821),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5823),
  },
  [STATE(2488)] = {
    [sym_identifier] = ACTIONS(5696),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5698),
    [anon_sym_COMMA] = ACTIONS(5698),
    [anon_sym_RPAREN] = ACTIONS(5698),
    [aux_sym_preproc_if_token2] = ACTIONS(5698),
    [aux_sym_preproc_else_token1] = ACTIONS(5698),
    [aux_sym_preproc_elif_token1] = ACTIONS(5696),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5698),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5698),
    [anon_sym_LPAREN2] = ACTIONS(5698),
    [anon_sym_DASH] = ACTIONS(5696),
    [anon_sym_PLUS] = ACTIONS(5696),
    [anon_sym_STAR] = ACTIONS(5696),
    [anon_sym_SLASH] = ACTIONS(5696),
    [anon_sym_PERCENT] = ACTIONS(5696),
    [anon_sym_PIPE_PIPE] = ACTIONS(5698),
    [anon_sym_AMP_AMP] = ACTIONS(5698),
    [anon_sym_PIPE] = ACTIONS(5696),
    [anon_sym_CARET] = ACTIONS(5696),
    [anon_sym_AMP] = ACTIONS(5696),
    [anon_sym_EQ_EQ] = ACTIONS(5698),
    [anon_sym_BANG_EQ] = ACTIONS(5698),
    [anon_sym_GT] = ACTIONS(5696),
    [anon_sym_GT_EQ] = ACTIONS(5698),
    [anon_sym_LT_EQ] = ACTIONS(5696),
    [anon_sym_LT] = ACTIONS(5696),
    [anon_sym_LT_LT] = ACTIONS(5696),
    [anon_sym_GT_GT] = ACTIONS(5696),
    [anon_sym_SEMI] = ACTIONS(5698),
    [anon_sym___attribute__] = ACTIONS(5696),
    [anon_sym___attribute] = ACTIONS(5696),
    [anon_sym_LBRACE] = ACTIONS(5698),
    [anon_sym_RBRACE] = ACTIONS(5698),
    [anon_sym_LBRACK] = ACTIONS(5698),
    [anon_sym_RBRACK] = ACTIONS(5698),
    [anon_sym_EQ] = ACTIONS(5696),
    [anon_sym_COLON] = ACTIONS(5698),
    [anon_sym_QMARK] = ACTIONS(5698),
    [anon_sym_STAR_EQ] = ACTIONS(5698),
    [anon_sym_SLASH_EQ] = ACTIONS(5698),
    [anon_sym_PERCENT_EQ] = ACTIONS(5698),
    [anon_sym_PLUS_EQ] = ACTIONS(5698),
    [anon_sym_DASH_EQ] = ACTIONS(5698),
    [anon_sym_LT_LT_EQ] = ACTIONS(5698),
    [anon_sym_GT_GT_EQ] = ACTIONS(5698),
    [anon_sym_AMP_EQ] = ACTIONS(5698),
    [anon_sym_CARET_EQ] = ACTIONS(5698),
    [anon_sym_PIPE_EQ] = ACTIONS(5698),
    [anon_sym_and_eq] = ACTIONS(5696),
    [anon_sym_or_eq] = ACTIONS(5696),
    [anon_sym_xor_eq] = ACTIONS(5696),
    [anon_sym_LT_EQ_GT] = ACTIONS(5698),
    [anon_sym_or] = ACTIONS(5696),
    [anon_sym_and] = ACTIONS(5696),
    [anon_sym_bitor] = ACTIONS(5696),
    [anon_sym_xor] = ACTIONS(5696),
    [anon_sym_bitand] = ACTIONS(5696),
    [anon_sym_not_eq] = ACTIONS(5696),
    [anon_sym_DASH_DASH] = ACTIONS(5698),
    [anon_sym_PLUS_PLUS] = ACTIONS(5698),
    [anon_sym_DOT] = ACTIONS(5696),
    [anon_sym_DOT_STAR] = ACTIONS(5698),
    [anon_sym_DASH_GT] = ACTIONS(5698),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5696),
    [anon_sym_decltype] = ACTIONS(5696),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5698),
  },
  [STATE(2489)] = {
    [sym_identifier] = ACTIONS(5801),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5803),
    [anon_sym_COMMA] = ACTIONS(5803),
    [anon_sym_RPAREN] = ACTIONS(5803),
    [aux_sym_preproc_if_token2] = ACTIONS(5803),
    [aux_sym_preproc_else_token1] = ACTIONS(5803),
    [aux_sym_preproc_elif_token1] = ACTIONS(5801),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5803),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5803),
    [anon_sym_LPAREN2] = ACTIONS(5803),
    [anon_sym_DASH] = ACTIONS(5801),
    [anon_sym_PLUS] = ACTIONS(5801),
    [anon_sym_STAR] = ACTIONS(5801),
    [anon_sym_SLASH] = ACTIONS(5801),
    [anon_sym_PERCENT] = ACTIONS(5801),
    [anon_sym_PIPE_PIPE] = ACTIONS(5803),
    [anon_sym_AMP_AMP] = ACTIONS(5803),
    [anon_sym_PIPE] = ACTIONS(5801),
    [anon_sym_CARET] = ACTIONS(5801),
    [anon_sym_AMP] = ACTIONS(5801),
    [anon_sym_EQ_EQ] = ACTIONS(5803),
    [anon_sym_BANG_EQ] = ACTIONS(5803),
    [anon_sym_GT] = ACTIONS(5801),
    [anon_sym_GT_EQ] = ACTIONS(5803),
    [anon_sym_LT_EQ] = ACTIONS(5801),
    [anon_sym_LT] = ACTIONS(5801),
    [anon_sym_LT_LT] = ACTIONS(5801),
    [anon_sym_GT_GT] = ACTIONS(5801),
    [anon_sym_SEMI] = ACTIONS(5803),
    [anon_sym___attribute__] = ACTIONS(5801),
    [anon_sym___attribute] = ACTIONS(5801),
    [anon_sym_LBRACE] = ACTIONS(5803),
    [anon_sym_RBRACE] = ACTIONS(5803),
    [anon_sym_LBRACK] = ACTIONS(5803),
    [anon_sym_RBRACK] = ACTIONS(5803),
    [anon_sym_EQ] = ACTIONS(5801),
    [anon_sym_COLON] = ACTIONS(5803),
    [anon_sym_QMARK] = ACTIONS(5803),
    [anon_sym_STAR_EQ] = ACTIONS(5803),
    [anon_sym_SLASH_EQ] = ACTIONS(5803),
    [anon_sym_PERCENT_EQ] = ACTIONS(5803),
    [anon_sym_PLUS_EQ] = ACTIONS(5803),
    [anon_sym_DASH_EQ] = ACTIONS(5803),
    [anon_sym_LT_LT_EQ] = ACTIONS(5803),
    [anon_sym_GT_GT_EQ] = ACTIONS(5803),
    [anon_sym_AMP_EQ] = ACTIONS(5803),
    [anon_sym_CARET_EQ] = ACTIONS(5803),
    [anon_sym_PIPE_EQ] = ACTIONS(5803),
    [anon_sym_and_eq] = ACTIONS(5801),
    [anon_sym_or_eq] = ACTIONS(5801),
    [anon_sym_xor_eq] = ACTIONS(5801),
    [anon_sym_LT_EQ_GT] = ACTIONS(5803),
    [anon_sym_or] = ACTIONS(5801),
    [anon_sym_and] = ACTIONS(5801),
    [anon_sym_bitor] = ACTIONS(5801),
    [anon_sym_xor] = ACTIONS(5801),
    [anon_sym_bitand] = ACTIONS(5801),
    [anon_sym_not_eq] = ACTIONS(5801),
    [anon_sym_DASH_DASH] = ACTIONS(5803),
    [anon_sym_PLUS_PLUS] = ACTIONS(5803),
    [anon_sym_DOT] = ACTIONS(5801),
    [anon_sym_DOT_STAR] = ACTIONS(5803),
    [anon_sym_DASH_GT] = ACTIONS(5803),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5801),
    [anon_sym_decltype] = ACTIONS(5801),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5803),
  },
  [STATE(2490)] = {
    [sym_identifier] = ACTIONS(5817),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5819),
    [anon_sym_COMMA] = ACTIONS(5819),
    [anon_sym_RPAREN] = ACTIONS(5819),
    [aux_sym_preproc_if_token2] = ACTIONS(5819),
    [aux_sym_preproc_else_token1] = ACTIONS(5819),
    [aux_sym_preproc_elif_token1] = ACTIONS(5817),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5819),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5819),
    [anon_sym_LPAREN2] = ACTIONS(5819),
    [anon_sym_DASH] = ACTIONS(5817),
    [anon_sym_PLUS] = ACTIONS(5817),
    [anon_sym_STAR] = ACTIONS(5817),
    [anon_sym_SLASH] = ACTIONS(5817),
    [anon_sym_PERCENT] = ACTIONS(5817),
    [anon_sym_PIPE_PIPE] = ACTIONS(5819),
    [anon_sym_AMP_AMP] = ACTIONS(5819),
    [anon_sym_PIPE] = ACTIONS(5817),
    [anon_sym_CARET] = ACTIONS(5817),
    [anon_sym_AMP] = ACTIONS(5817),
    [anon_sym_EQ_EQ] = ACTIONS(5819),
    [anon_sym_BANG_EQ] = ACTIONS(5819),
    [anon_sym_GT] = ACTIONS(5817),
    [anon_sym_GT_EQ] = ACTIONS(5819),
    [anon_sym_LT_EQ] = ACTIONS(5817),
    [anon_sym_LT] = ACTIONS(5817),
    [anon_sym_LT_LT] = ACTIONS(5817),
    [anon_sym_GT_GT] = ACTIONS(5817),
    [anon_sym_SEMI] = ACTIONS(5819),
    [anon_sym___attribute__] = ACTIONS(5817),
    [anon_sym___attribute] = ACTIONS(5817),
    [anon_sym_LBRACE] = ACTIONS(5819),
    [anon_sym_RBRACE] = ACTIONS(5819),
    [anon_sym_LBRACK] = ACTIONS(5819),
    [anon_sym_RBRACK] = ACTIONS(5819),
    [anon_sym_EQ] = ACTIONS(5817),
    [anon_sym_COLON] = ACTIONS(5819),
    [anon_sym_QMARK] = ACTIONS(5819),
    [anon_sym_STAR_EQ] = ACTIONS(5819),
    [anon_sym_SLASH_EQ] = ACTIONS(5819),
    [anon_sym_PERCENT_EQ] = ACTIONS(5819),
    [anon_sym_PLUS_EQ] = ACTIONS(5819),
    [anon_sym_DASH_EQ] = ACTIONS(5819),
    [anon_sym_LT_LT_EQ] = ACTIONS(5819),
    [anon_sym_GT_GT_EQ] = ACTIONS(5819),
    [anon_sym_AMP_EQ] = ACTIONS(5819),
    [anon_sym_CARET_EQ] = ACTIONS(5819),
    [anon_sym_PIPE_EQ] = ACTIONS(5819),
    [anon_sym_and_eq] = ACTIONS(5817),
    [anon_sym_or_eq] = ACTIONS(5817),
    [anon_sym_xor_eq] = ACTIONS(5817),
    [anon_sym_LT_EQ_GT] = ACTIONS(5819),
    [anon_sym_or] = ACTIONS(5817),
    [anon_sym_and] = ACTIONS(5817),
    [anon_sym_bitor] = ACTIONS(5817),
    [anon_sym_xor] = ACTIONS(5817),
    [anon_sym_bitand] = ACTIONS(5817),
    [anon_sym_not_eq] = ACTIONS(5817),
    [anon_sym_DASH_DASH] = ACTIONS(5819),
    [anon_sym_PLUS_PLUS] = ACTIONS(5819),
    [anon_sym_DOT] = ACTIONS(5817),
    [anon_sym_DOT_STAR] = ACTIONS(5819),
    [anon_sym_DASH_GT] = ACTIONS(5819),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5817),
    [anon_sym_decltype] = ACTIONS(5817),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5819),
  },
  [STATE(2491)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5780),
    [anon_sym_COMMA] = ACTIONS(5780),
    [anon_sym_LPAREN2] = ACTIONS(5780),
    [anon_sym_DASH] = ACTIONS(5778),
    [anon_sym_PLUS] = ACTIONS(5778),
    [anon_sym_STAR] = ACTIONS(5780),
    [anon_sym_SLASH] = ACTIONS(5778),
    [anon_sym_PERCENT] = ACTIONS(5780),
    [anon_sym_PIPE_PIPE] = ACTIONS(5780),
    [anon_sym_AMP_AMP] = ACTIONS(5780),
    [anon_sym_PIPE] = ACTIONS(5778),
    [anon_sym_CARET] = ACTIONS(5780),
    [anon_sym_AMP] = ACTIONS(5778),
    [anon_sym_EQ_EQ] = ACTIONS(5780),
    [anon_sym_BANG_EQ] = ACTIONS(5780),
    [anon_sym_GT] = ACTIONS(5778),
    [anon_sym_GT_EQ] = ACTIONS(5778),
    [anon_sym_LT_EQ] = ACTIONS(5778),
    [anon_sym_LT] = ACTIONS(5778),
    [anon_sym_LT_LT] = ACTIONS(5778),
    [anon_sym_GT_GT] = ACTIONS(5778),
    [anon_sym___extension__] = ACTIONS(5780),
    [anon_sym___global__] = ACTIONS(5780),
    [anon_sym___attribute__] = ACTIONS(5780),
    [anon_sym___attribute] = ACTIONS(5778),
    [anon_sym_LBRACE] = ACTIONS(5780),
    [anon_sym_LBRACK] = ACTIONS(5780),
    [anon_sym_const] = ACTIONS(5778),
    [anon_sym_constexpr] = ACTIONS(5780),
    [anon_sym_volatile] = ACTIONS(5780),
    [anon_sym_restrict] = ACTIONS(5780),
    [anon_sym___restrict__] = ACTIONS(5780),
    [anon_sym__Atomic] = ACTIONS(5780),
    [anon_sym__Noreturn] = ACTIONS(5780),
    [anon_sym_noreturn] = ACTIONS(5780),
    [anon_sym__Nonnull] = ACTIONS(5780),
    [anon_sym_mutable] = ACTIONS(5780),
    [anon_sym_constinit] = ACTIONS(5780),
    [anon_sym_consteval] = ACTIONS(5780),
    [anon_sym___shared__] = ACTIONS(5780),
    [anon_sym___local__] = ACTIONS(5780),
    [anon_sym___constant__] = ACTIONS(5780),
    [anon_sym___managed__] = ACTIONS(5780),
    [anon_sym___grid_constant__] = ACTIONS(5780),
    [anon_sym_alignas] = ACTIONS(5780),
    [anon_sym__Alignas] = ACTIONS(5780),
    [anon_sym_QMARK] = ACTIONS(5780),
    [anon_sym_LT_EQ_GT] = ACTIONS(5780),
    [anon_sym_or] = ACTIONS(5780),
    [anon_sym_and] = ACTIONS(5780),
    [anon_sym_bitor] = ACTIONS(5780),
    [anon_sym_xor] = ACTIONS(5780),
    [anon_sym_bitand] = ACTIONS(5780),
    [anon_sym_not_eq] = ACTIONS(5780),
    [anon_sym_DASH_DASH] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5780),
    [anon_sym_DOT] = ACTIONS(5778),
    [anon_sym_DOT_STAR] = ACTIONS(5780),
    [anon_sym_DASH_GT] = ACTIONS(5780),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5780),
    [anon_sym_decltype] = ACTIONS(5780),
    [anon_sym_final] = ACTIONS(5780),
    [anon_sym_override] = ACTIONS(5780),
    [anon_sym_GT2] = ACTIONS(5780),
    [anon_sym_requires] = ACTIONS(5780),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5780),
  },
  [STATE(2492)] = {
    [sym_identifier] = ACTIONS(5696),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5698),
    [anon_sym_COMMA] = ACTIONS(5698),
    [anon_sym_RPAREN] = ACTIONS(5698),
    [aux_sym_preproc_if_token2] = ACTIONS(5698),
    [aux_sym_preproc_else_token1] = ACTIONS(5698),
    [aux_sym_preproc_elif_token1] = ACTIONS(5696),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5698),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5698),
    [anon_sym_LPAREN2] = ACTIONS(5698),
    [anon_sym_DASH] = ACTIONS(5696),
    [anon_sym_PLUS] = ACTIONS(5696),
    [anon_sym_STAR] = ACTIONS(5696),
    [anon_sym_SLASH] = ACTIONS(5696),
    [anon_sym_PERCENT] = ACTIONS(5696),
    [anon_sym_PIPE_PIPE] = ACTIONS(5698),
    [anon_sym_AMP_AMP] = ACTIONS(5698),
    [anon_sym_PIPE] = ACTIONS(5696),
    [anon_sym_CARET] = ACTIONS(5696),
    [anon_sym_AMP] = ACTIONS(5696),
    [anon_sym_EQ_EQ] = ACTIONS(5698),
    [anon_sym_BANG_EQ] = ACTIONS(5698),
    [anon_sym_GT] = ACTIONS(5696),
    [anon_sym_GT_EQ] = ACTIONS(5698),
    [anon_sym_LT_EQ] = ACTIONS(5696),
    [anon_sym_LT] = ACTIONS(5696),
    [anon_sym_LT_LT] = ACTIONS(5696),
    [anon_sym_GT_GT] = ACTIONS(5696),
    [anon_sym_SEMI] = ACTIONS(5698),
    [anon_sym___attribute__] = ACTIONS(5696),
    [anon_sym___attribute] = ACTIONS(5696),
    [anon_sym_LBRACE] = ACTIONS(5698),
    [anon_sym_RBRACE] = ACTIONS(5698),
    [anon_sym_LBRACK] = ACTIONS(5698),
    [anon_sym_RBRACK] = ACTIONS(5698),
    [anon_sym_EQ] = ACTIONS(5696),
    [anon_sym_COLON] = ACTIONS(5698),
    [anon_sym_QMARK] = ACTIONS(5698),
    [anon_sym_STAR_EQ] = ACTIONS(5698),
    [anon_sym_SLASH_EQ] = ACTIONS(5698),
    [anon_sym_PERCENT_EQ] = ACTIONS(5698),
    [anon_sym_PLUS_EQ] = ACTIONS(5698),
    [anon_sym_DASH_EQ] = ACTIONS(5698),
    [anon_sym_LT_LT_EQ] = ACTIONS(5698),
    [anon_sym_GT_GT_EQ] = ACTIONS(5698),
    [anon_sym_AMP_EQ] = ACTIONS(5698),
    [anon_sym_CARET_EQ] = ACTIONS(5698),
    [anon_sym_PIPE_EQ] = ACTIONS(5698),
    [anon_sym_and_eq] = ACTIONS(5696),
    [anon_sym_or_eq] = ACTIONS(5696),
    [anon_sym_xor_eq] = ACTIONS(5696),
    [anon_sym_LT_EQ_GT] = ACTIONS(5698),
    [anon_sym_or] = ACTIONS(5696),
    [anon_sym_and] = ACTIONS(5696),
    [anon_sym_bitor] = ACTIONS(5696),
    [anon_sym_xor] = ACTIONS(5696),
    [anon_sym_bitand] = ACTIONS(5696),
    [anon_sym_not_eq] = ACTIONS(5696),
    [anon_sym_DASH_DASH] = ACTIONS(5698),
    [anon_sym_PLUS_PLUS] = ACTIONS(5698),
    [anon_sym_DOT] = ACTIONS(5696),
    [anon_sym_DOT_STAR] = ACTIONS(5698),
    [anon_sym_DASH_GT] = ACTIONS(5698),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5696),
    [anon_sym_decltype] = ACTIONS(5696),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5698),
  },
  [STATE(2493)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5694),
    [anon_sym_COMMA] = ACTIONS(5694),
    [anon_sym_LPAREN2] = ACTIONS(5694),
    [anon_sym_DASH] = ACTIONS(5692),
    [anon_sym_PLUS] = ACTIONS(5692),
    [anon_sym_STAR] = ACTIONS(5694),
    [anon_sym_SLASH] = ACTIONS(5692),
    [anon_sym_PERCENT] = ACTIONS(5694),
    [anon_sym_PIPE_PIPE] = ACTIONS(5694),
    [anon_sym_AMP_AMP] = ACTIONS(5694),
    [anon_sym_PIPE] = ACTIONS(5692),
    [anon_sym_CARET] = ACTIONS(5694),
    [anon_sym_AMP] = ACTIONS(5692),
    [anon_sym_EQ_EQ] = ACTIONS(5694),
    [anon_sym_BANG_EQ] = ACTIONS(5694),
    [anon_sym_GT] = ACTIONS(5692),
    [anon_sym_GT_EQ] = ACTIONS(5692),
    [anon_sym_LT_EQ] = ACTIONS(5692),
    [anon_sym_LT] = ACTIONS(5692),
    [anon_sym_LT_LT] = ACTIONS(5692),
    [anon_sym_GT_GT] = ACTIONS(5692),
    [anon_sym___extension__] = ACTIONS(5694),
    [anon_sym___global__] = ACTIONS(5694),
    [anon_sym___attribute__] = ACTIONS(5694),
    [anon_sym___attribute] = ACTIONS(5692),
    [anon_sym_LBRACE] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5694),
    [anon_sym_const] = ACTIONS(5692),
    [anon_sym_constexpr] = ACTIONS(5694),
    [anon_sym_volatile] = ACTIONS(5694),
    [anon_sym_restrict] = ACTIONS(5694),
    [anon_sym___restrict__] = ACTIONS(5694),
    [anon_sym__Atomic] = ACTIONS(5694),
    [anon_sym__Noreturn] = ACTIONS(5694),
    [anon_sym_noreturn] = ACTIONS(5694),
    [anon_sym__Nonnull] = ACTIONS(5694),
    [anon_sym_mutable] = ACTIONS(5694),
    [anon_sym_constinit] = ACTIONS(5694),
    [anon_sym_consteval] = ACTIONS(5694),
    [anon_sym___shared__] = ACTIONS(5694),
    [anon_sym___local__] = ACTIONS(5694),
    [anon_sym___constant__] = ACTIONS(5694),
    [anon_sym___managed__] = ACTIONS(5694),
    [anon_sym___grid_constant__] = ACTIONS(5694),
    [anon_sym_alignas] = ACTIONS(5694),
    [anon_sym__Alignas] = ACTIONS(5694),
    [anon_sym_QMARK] = ACTIONS(5694),
    [anon_sym_LT_EQ_GT] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5694),
    [anon_sym_and] = ACTIONS(5694),
    [anon_sym_bitor] = ACTIONS(5694),
    [anon_sym_xor] = ACTIONS(5694),
    [anon_sym_bitand] = ACTIONS(5694),
    [anon_sym_not_eq] = ACTIONS(5694),
    [anon_sym_DASH_DASH] = ACTIONS(5694),
    [anon_sym_PLUS_PLUS] = ACTIONS(5694),
    [anon_sym_DOT] = ACTIONS(5692),
    [anon_sym_DOT_STAR] = ACTIONS(5694),
    [anon_sym_DASH_GT] = ACTIONS(5694),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5694),
    [anon_sym_decltype] = ACTIONS(5694),
    [anon_sym_final] = ACTIONS(5694),
    [anon_sym_override] = ACTIONS(5694),
    [anon_sym_GT2] = ACTIONS(5694),
    [anon_sym_requires] = ACTIONS(5694),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5694),
  },
  [STATE(2494)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5740),
    [anon_sym_COMMA] = ACTIONS(5740),
    [anon_sym_LPAREN2] = ACTIONS(5740),
    [anon_sym_DASH] = ACTIONS(5738),
    [anon_sym_PLUS] = ACTIONS(5738),
    [anon_sym_STAR] = ACTIONS(5740),
    [anon_sym_SLASH] = ACTIONS(5738),
    [anon_sym_PERCENT] = ACTIONS(5740),
    [anon_sym_PIPE_PIPE] = ACTIONS(5740),
    [anon_sym_AMP_AMP] = ACTIONS(5740),
    [anon_sym_PIPE] = ACTIONS(5738),
    [anon_sym_CARET] = ACTIONS(5740),
    [anon_sym_AMP] = ACTIONS(5738),
    [anon_sym_EQ_EQ] = ACTIONS(5740),
    [anon_sym_BANG_EQ] = ACTIONS(5740),
    [anon_sym_GT] = ACTIONS(5738),
    [anon_sym_GT_EQ] = ACTIONS(5738),
    [anon_sym_LT_EQ] = ACTIONS(5738),
    [anon_sym_LT] = ACTIONS(5738),
    [anon_sym_LT_LT] = ACTIONS(5738),
    [anon_sym_GT_GT] = ACTIONS(5738),
    [anon_sym___extension__] = ACTIONS(5740),
    [anon_sym___global__] = ACTIONS(5740),
    [anon_sym___attribute__] = ACTIONS(5740),
    [anon_sym___attribute] = ACTIONS(5738),
    [anon_sym_LBRACE] = ACTIONS(5740),
    [anon_sym_LBRACK] = ACTIONS(5740),
    [anon_sym_const] = ACTIONS(5738),
    [anon_sym_constexpr] = ACTIONS(5740),
    [anon_sym_volatile] = ACTIONS(5740),
    [anon_sym_restrict] = ACTIONS(5740),
    [anon_sym___restrict__] = ACTIONS(5740),
    [anon_sym__Atomic] = ACTIONS(5740),
    [anon_sym__Noreturn] = ACTIONS(5740),
    [anon_sym_noreturn] = ACTIONS(5740),
    [anon_sym__Nonnull] = ACTIONS(5740),
    [anon_sym_mutable] = ACTIONS(5740),
    [anon_sym_constinit] = ACTIONS(5740),
    [anon_sym_consteval] = ACTIONS(5740),
    [anon_sym___shared__] = ACTIONS(5740),
    [anon_sym___local__] = ACTIONS(5740),
    [anon_sym___constant__] = ACTIONS(5740),
    [anon_sym___managed__] = ACTIONS(5740),
    [anon_sym___grid_constant__] = ACTIONS(5740),
    [anon_sym_alignas] = ACTIONS(5740),
    [anon_sym__Alignas] = ACTIONS(5740),
    [anon_sym_QMARK] = ACTIONS(5740),
    [anon_sym_LT_EQ_GT] = ACTIONS(5740),
    [anon_sym_or] = ACTIONS(5740),
    [anon_sym_and] = ACTIONS(5740),
    [anon_sym_bitor] = ACTIONS(5740),
    [anon_sym_xor] = ACTIONS(5740),
    [anon_sym_bitand] = ACTIONS(5740),
    [anon_sym_not_eq] = ACTIONS(5740),
    [anon_sym_DASH_DASH] = ACTIONS(5740),
    [anon_sym_PLUS_PLUS] = ACTIONS(5740),
    [anon_sym_DOT] = ACTIONS(5738),
    [anon_sym_DOT_STAR] = ACTIONS(5740),
    [anon_sym_DASH_GT] = ACTIONS(5740),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5740),
    [anon_sym_decltype] = ACTIONS(5740),
    [anon_sym_final] = ACTIONS(5740),
    [anon_sym_override] = ACTIONS(5740),
    [anon_sym_GT2] = ACTIONS(5740),
    [anon_sym_requires] = ACTIONS(5740),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5740),
  },
  [STATE(2495)] = {
    [sym_identifier] = ACTIONS(5782),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5784),
    [anon_sym_COMMA] = ACTIONS(5784),
    [anon_sym_RPAREN] = ACTIONS(5784),
    [aux_sym_preproc_if_token2] = ACTIONS(5784),
    [aux_sym_preproc_else_token1] = ACTIONS(5784),
    [aux_sym_preproc_elif_token1] = ACTIONS(5782),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5784),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5784),
    [anon_sym_LPAREN2] = ACTIONS(5784),
    [anon_sym_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(5782),
    [anon_sym_STAR] = ACTIONS(5782),
    [anon_sym_SLASH] = ACTIONS(5782),
    [anon_sym_PERCENT] = ACTIONS(5782),
    [anon_sym_PIPE_PIPE] = ACTIONS(5784),
    [anon_sym_AMP_AMP] = ACTIONS(5784),
    [anon_sym_PIPE] = ACTIONS(5782),
    [anon_sym_CARET] = ACTIONS(5782),
    [anon_sym_AMP] = ACTIONS(5782),
    [anon_sym_EQ_EQ] = ACTIONS(5784),
    [anon_sym_BANG_EQ] = ACTIONS(5784),
    [anon_sym_GT] = ACTIONS(5782),
    [anon_sym_GT_EQ] = ACTIONS(5784),
    [anon_sym_LT_EQ] = ACTIONS(5782),
    [anon_sym_LT] = ACTIONS(5782),
    [anon_sym_LT_LT] = ACTIONS(5782),
    [anon_sym_GT_GT] = ACTIONS(5782),
    [anon_sym_SEMI] = ACTIONS(5784),
    [anon_sym___attribute__] = ACTIONS(5782),
    [anon_sym___attribute] = ACTIONS(5782),
    [anon_sym_LBRACE] = ACTIONS(5784),
    [anon_sym_RBRACE] = ACTIONS(5784),
    [anon_sym_LBRACK] = ACTIONS(5784),
    [anon_sym_RBRACK] = ACTIONS(5784),
    [anon_sym_EQ] = ACTIONS(5782),
    [anon_sym_COLON] = ACTIONS(5784),
    [anon_sym_QMARK] = ACTIONS(5784),
    [anon_sym_STAR_EQ] = ACTIONS(5784),
    [anon_sym_SLASH_EQ] = ACTIONS(5784),
    [anon_sym_PERCENT_EQ] = ACTIONS(5784),
    [anon_sym_PLUS_EQ] = ACTIONS(5784),
    [anon_sym_DASH_EQ] = ACTIONS(5784),
    [anon_sym_LT_LT_EQ] = ACTIONS(5784),
    [anon_sym_GT_GT_EQ] = ACTIONS(5784),
    [anon_sym_AMP_EQ] = ACTIONS(5784),
    [anon_sym_CARET_EQ] = ACTIONS(5784),
    [anon_sym_PIPE_EQ] = ACTIONS(5784),
    [anon_sym_and_eq] = ACTIONS(5782),
    [anon_sym_or_eq] = ACTIONS(5782),
    [anon_sym_xor_eq] = ACTIONS(5782),
    [anon_sym_LT_EQ_GT] = ACTIONS(5784),
    [anon_sym_or] = ACTIONS(5782),
    [anon_sym_and] = ACTIONS(5782),
    [anon_sym_bitor] = ACTIONS(5782),
    [anon_sym_xor] = ACTIONS(5782),
    [anon_sym_bitand] = ACTIONS(5782),
    [anon_sym_not_eq] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5784),
    [anon_sym_PLUS_PLUS] = ACTIONS(5784),
    [anon_sym_DOT] = ACTIONS(5782),
    [anon_sym_DOT_STAR] = ACTIONS(5784),
    [anon_sym_DASH_GT] = ACTIONS(5784),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5782),
    [anon_sym_decltype] = ACTIONS(5782),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5784),
  },
  [STATE(2496)] = {
    [sym_identifier] = ACTIONS(5766),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5768),
    [anon_sym_COMMA] = ACTIONS(5768),
    [anon_sym_RPAREN] = ACTIONS(5768),
    [aux_sym_preproc_if_token2] = ACTIONS(5768),
    [aux_sym_preproc_else_token1] = ACTIONS(5768),
    [aux_sym_preproc_elif_token1] = ACTIONS(5766),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5768),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5768),
    [anon_sym_LPAREN2] = ACTIONS(5768),
    [anon_sym_DASH] = ACTIONS(5766),
    [anon_sym_PLUS] = ACTIONS(5766),
    [anon_sym_STAR] = ACTIONS(5766),
    [anon_sym_SLASH] = ACTIONS(5766),
    [anon_sym_PERCENT] = ACTIONS(5766),
    [anon_sym_PIPE_PIPE] = ACTIONS(5768),
    [anon_sym_AMP_AMP] = ACTIONS(5768),
    [anon_sym_PIPE] = ACTIONS(5766),
    [anon_sym_CARET] = ACTIONS(5766),
    [anon_sym_AMP] = ACTIONS(5766),
    [anon_sym_EQ_EQ] = ACTIONS(5768),
    [anon_sym_BANG_EQ] = ACTIONS(5768),
    [anon_sym_GT] = ACTIONS(5766),
    [anon_sym_GT_EQ] = ACTIONS(5768),
    [anon_sym_LT_EQ] = ACTIONS(5766),
    [anon_sym_LT] = ACTIONS(5766),
    [anon_sym_LT_LT] = ACTIONS(5766),
    [anon_sym_GT_GT] = ACTIONS(5766),
    [anon_sym_SEMI] = ACTIONS(5768),
    [anon_sym___attribute__] = ACTIONS(5766),
    [anon_sym___attribute] = ACTIONS(5766),
    [anon_sym_LBRACE] = ACTIONS(5768),
    [anon_sym_RBRACE] = ACTIONS(5768),
    [anon_sym_LBRACK] = ACTIONS(5768),
    [anon_sym_RBRACK] = ACTIONS(5768),
    [anon_sym_EQ] = ACTIONS(5766),
    [anon_sym_COLON] = ACTIONS(5768),
    [anon_sym_QMARK] = ACTIONS(5768),
    [anon_sym_STAR_EQ] = ACTIONS(5768),
    [anon_sym_SLASH_EQ] = ACTIONS(5768),
    [anon_sym_PERCENT_EQ] = ACTIONS(5768),
    [anon_sym_PLUS_EQ] = ACTIONS(5768),
    [anon_sym_DASH_EQ] = ACTIONS(5768),
    [anon_sym_LT_LT_EQ] = ACTIONS(5768),
    [anon_sym_GT_GT_EQ] = ACTIONS(5768),
    [anon_sym_AMP_EQ] = ACTIONS(5768),
    [anon_sym_CARET_EQ] = ACTIONS(5768),
    [anon_sym_PIPE_EQ] = ACTIONS(5768),
    [anon_sym_and_eq] = ACTIONS(5766),
    [anon_sym_or_eq] = ACTIONS(5766),
    [anon_sym_xor_eq] = ACTIONS(5766),
    [anon_sym_LT_EQ_GT] = ACTIONS(5768),
    [anon_sym_or] = ACTIONS(5766),
    [anon_sym_and] = ACTIONS(5766),
    [anon_sym_bitor] = ACTIONS(5766),
    [anon_sym_xor] = ACTIONS(5766),
    [anon_sym_bitand] = ACTIONS(5766),
    [anon_sym_not_eq] = ACTIONS(5766),
    [anon_sym_DASH_DASH] = ACTIONS(5768),
    [anon_sym_PLUS_PLUS] = ACTIONS(5768),
    [anon_sym_DOT] = ACTIONS(5766),
    [anon_sym_DOT_STAR] = ACTIONS(5768),
    [anon_sym_DASH_GT] = ACTIONS(5768),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5766),
    [anon_sym_decltype] = ACTIONS(5766),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5768),
  },
  [STATE(2497)] = {
    [sym_string_literal] = STATE(2533),
    [sym_raw_string_literal] = STATE(2533),
    [aux_sym_concatenated_string_repeat1] = STATE(2533),
    [sym_identifier] = ACTIONS(6520),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6016),
    [anon_sym_COMMA] = ACTIONS(6016),
    [anon_sym_LPAREN2] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6018),
    [anon_sym_STAR] = ACTIONS(6018),
    [anon_sym_SLASH] = ACTIONS(6018),
    [anon_sym_PERCENT] = ACTIONS(6018),
    [anon_sym_PIPE_PIPE] = ACTIONS(6016),
    [anon_sym_AMP_AMP] = ACTIONS(6016),
    [anon_sym_PIPE] = ACTIONS(6018),
    [anon_sym_CARET] = ACTIONS(6018),
    [anon_sym_AMP] = ACTIONS(6018),
    [anon_sym_EQ_EQ] = ACTIONS(6016),
    [anon_sym_BANG_EQ] = ACTIONS(6016),
    [anon_sym_GT] = ACTIONS(6018),
    [anon_sym_GT_EQ] = ACTIONS(6016),
    [anon_sym_LT_EQ] = ACTIONS(6018),
    [anon_sym_LT] = ACTIONS(6018),
    [anon_sym_LT_LT] = ACTIONS(6018),
    [anon_sym_GT_GT] = ACTIONS(6018),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [anon_sym_EQ] = ACTIONS(6018),
    [anon_sym_QMARK] = ACTIONS(6016),
    [anon_sym_STAR_EQ] = ACTIONS(6016),
    [anon_sym_SLASH_EQ] = ACTIONS(6016),
    [anon_sym_PERCENT_EQ] = ACTIONS(6016),
    [anon_sym_PLUS_EQ] = ACTIONS(6016),
    [anon_sym_DASH_EQ] = ACTIONS(6016),
    [anon_sym_LT_LT_EQ] = ACTIONS(6016),
    [anon_sym_GT_GT_EQ] = ACTIONS(6016),
    [anon_sym_AMP_EQ] = ACTIONS(6016),
    [anon_sym_CARET_EQ] = ACTIONS(6016),
    [anon_sym_PIPE_EQ] = ACTIONS(6016),
    [anon_sym_and_eq] = ACTIONS(6018),
    [anon_sym_or_eq] = ACTIONS(6018),
    [anon_sym_xor_eq] = ACTIONS(6018),
    [anon_sym_LT_EQ_GT] = ACTIONS(6016),
    [anon_sym_or] = ACTIONS(6018),
    [anon_sym_and] = ACTIONS(6018),
    [anon_sym_bitor] = ACTIONS(6018),
    [anon_sym_xor] = ACTIONS(6018),
    [anon_sym_bitand] = ACTIONS(6018),
    [anon_sym_not_eq] = ACTIONS(6018),
    [anon_sym_DASH_DASH] = ACTIONS(6016),
    [anon_sym_PLUS_PLUS] = ACTIONS(6016),
    [anon_sym_DOT] = ACTIONS(6018),
    [anon_sym_DOT_STAR] = ACTIONS(6016),
    [anon_sym_DASH_GT] = ACTIONS(6016),
    [anon_sym_L_DQUOTE] = ACTIONS(6522),
    [anon_sym_u_DQUOTE] = ACTIONS(6522),
    [anon_sym_U_DQUOTE] = ACTIONS(6522),
    [anon_sym_u8_DQUOTE] = ACTIONS(6522),
    [anon_sym_DQUOTE] = ACTIONS(6522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6524),
    [anon_sym_LR_DQUOTE] = ACTIONS(6524),
    [anon_sym_uR_DQUOTE] = ACTIONS(6524),
    [anon_sym_UR_DQUOTE] = ACTIONS(6524),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6524),
    [sym_literal_suffix] = ACTIONS(6018),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6016),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(6016),
  },
  [STATE(2498)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5815),
    [anon_sym_COMMA] = ACTIONS(5815),
    [anon_sym_LPAREN2] = ACTIONS(5815),
    [anon_sym_DASH] = ACTIONS(5813),
    [anon_sym_PLUS] = ACTIONS(5813),
    [anon_sym_STAR] = ACTIONS(5815),
    [anon_sym_SLASH] = ACTIONS(5813),
    [anon_sym_PERCENT] = ACTIONS(5815),
    [anon_sym_PIPE_PIPE] = ACTIONS(5815),
    [anon_sym_AMP_AMP] = ACTIONS(5815),
    [anon_sym_PIPE] = ACTIONS(5813),
    [anon_sym_CARET] = ACTIONS(5815),
    [anon_sym_AMP] = ACTIONS(5813),
    [anon_sym_EQ_EQ] = ACTIONS(5815),
    [anon_sym_BANG_EQ] = ACTIONS(5815),
    [anon_sym_GT] = ACTIONS(5813),
    [anon_sym_GT_EQ] = ACTIONS(5813),
    [anon_sym_LT_EQ] = ACTIONS(5813),
    [anon_sym_LT] = ACTIONS(5813),
    [anon_sym_LT_LT] = ACTIONS(5813),
    [anon_sym_GT_GT] = ACTIONS(5813),
    [anon_sym___extension__] = ACTIONS(5815),
    [anon_sym___global__] = ACTIONS(5815),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym___attribute] = ACTIONS(5813),
    [anon_sym_LBRACE] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(5815),
    [anon_sym_const] = ACTIONS(5813),
    [anon_sym_constexpr] = ACTIONS(5815),
    [anon_sym_volatile] = ACTIONS(5815),
    [anon_sym_restrict] = ACTIONS(5815),
    [anon_sym___restrict__] = ACTIONS(5815),
    [anon_sym__Atomic] = ACTIONS(5815),
    [anon_sym__Noreturn] = ACTIONS(5815),
    [anon_sym_noreturn] = ACTIONS(5815),
    [anon_sym__Nonnull] = ACTIONS(5815),
    [anon_sym_mutable] = ACTIONS(5815),
    [anon_sym_constinit] = ACTIONS(5815),
    [anon_sym_consteval] = ACTIONS(5815),
    [anon_sym___shared__] = ACTIONS(5815),
    [anon_sym___local__] = ACTIONS(5815),
    [anon_sym___constant__] = ACTIONS(5815),
    [anon_sym___managed__] = ACTIONS(5815),
    [anon_sym___grid_constant__] = ACTIONS(5815),
    [anon_sym_alignas] = ACTIONS(5815),
    [anon_sym__Alignas] = ACTIONS(5815),
    [anon_sym_QMARK] = ACTIONS(5815),
    [anon_sym_LT_EQ_GT] = ACTIONS(5815),
    [anon_sym_or] = ACTIONS(5815),
    [anon_sym_and] = ACTIONS(5815),
    [anon_sym_bitor] = ACTIONS(5815),
    [anon_sym_xor] = ACTIONS(5815),
    [anon_sym_bitand] = ACTIONS(5815),
    [anon_sym_not_eq] = ACTIONS(5815),
    [anon_sym_DASH_DASH] = ACTIONS(5815),
    [anon_sym_PLUS_PLUS] = ACTIONS(5815),
    [anon_sym_DOT] = ACTIONS(5813),
    [anon_sym_DOT_STAR] = ACTIONS(5815),
    [anon_sym_DASH_GT] = ACTIONS(5815),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5815),
    [anon_sym_decltype] = ACTIONS(5815),
    [anon_sym_final] = ACTIONS(5815),
    [anon_sym_override] = ACTIONS(5815),
    [anon_sym_GT2] = ACTIONS(5815),
    [anon_sym_requires] = ACTIONS(5815),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5815),
  },
  [STATE(2499)] = {
    [sym_identifier] = ACTIONS(5692),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5694),
    [anon_sym_COMMA] = ACTIONS(5694),
    [anon_sym_RPAREN] = ACTIONS(5694),
    [aux_sym_preproc_if_token2] = ACTIONS(5694),
    [aux_sym_preproc_else_token1] = ACTIONS(5694),
    [aux_sym_preproc_elif_token1] = ACTIONS(5692),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5694),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5694),
    [anon_sym_LPAREN2] = ACTIONS(5694),
    [anon_sym_DASH] = ACTIONS(5692),
    [anon_sym_PLUS] = ACTIONS(5692),
    [anon_sym_STAR] = ACTIONS(5692),
    [anon_sym_SLASH] = ACTIONS(5692),
    [anon_sym_PERCENT] = ACTIONS(5692),
    [anon_sym_PIPE_PIPE] = ACTIONS(5694),
    [anon_sym_AMP_AMP] = ACTIONS(5694),
    [anon_sym_PIPE] = ACTIONS(5692),
    [anon_sym_CARET] = ACTIONS(5692),
    [anon_sym_AMP] = ACTIONS(5692),
    [anon_sym_EQ_EQ] = ACTIONS(5694),
    [anon_sym_BANG_EQ] = ACTIONS(5694),
    [anon_sym_GT] = ACTIONS(5692),
    [anon_sym_GT_EQ] = ACTIONS(5694),
    [anon_sym_LT_EQ] = ACTIONS(5692),
    [anon_sym_LT] = ACTIONS(5692),
    [anon_sym_LT_LT] = ACTIONS(5692),
    [anon_sym_GT_GT] = ACTIONS(5692),
    [anon_sym_SEMI] = ACTIONS(5694),
    [anon_sym___attribute__] = ACTIONS(5692),
    [anon_sym___attribute] = ACTIONS(5692),
    [anon_sym_LBRACE] = ACTIONS(5694),
    [anon_sym_RBRACE] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5694),
    [anon_sym_RBRACK] = ACTIONS(5694),
    [anon_sym_EQ] = ACTIONS(5692),
    [anon_sym_COLON] = ACTIONS(5694),
    [anon_sym_QMARK] = ACTIONS(5694),
    [anon_sym_STAR_EQ] = ACTIONS(5694),
    [anon_sym_SLASH_EQ] = ACTIONS(5694),
    [anon_sym_PERCENT_EQ] = ACTIONS(5694),
    [anon_sym_PLUS_EQ] = ACTIONS(5694),
    [anon_sym_DASH_EQ] = ACTIONS(5694),
    [anon_sym_LT_LT_EQ] = ACTIONS(5694),
    [anon_sym_GT_GT_EQ] = ACTIONS(5694),
    [anon_sym_AMP_EQ] = ACTIONS(5694),
    [anon_sym_CARET_EQ] = ACTIONS(5694),
    [anon_sym_PIPE_EQ] = ACTIONS(5694),
    [anon_sym_and_eq] = ACTIONS(5692),
    [anon_sym_or_eq] = ACTIONS(5692),
    [anon_sym_xor_eq] = ACTIONS(5692),
    [anon_sym_LT_EQ_GT] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5692),
    [anon_sym_and] = ACTIONS(5692),
    [anon_sym_bitor] = ACTIONS(5692),
    [anon_sym_xor] = ACTIONS(5692),
    [anon_sym_bitand] = ACTIONS(5692),
    [anon_sym_not_eq] = ACTIONS(5692),
    [anon_sym_DASH_DASH] = ACTIONS(5694),
    [anon_sym_PLUS_PLUS] = ACTIONS(5694),
    [anon_sym_DOT] = ACTIONS(5692),
    [anon_sym_DOT_STAR] = ACTIONS(5694),
    [anon_sym_DASH_GT] = ACTIONS(5694),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5692),
    [anon_sym_decltype] = ACTIONS(5692),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5694),
  },
  [STATE(2500)] = {
    [sym_identifier] = ACTIONS(5730),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5732),
    [anon_sym_COMMA] = ACTIONS(5732),
    [anon_sym_RPAREN] = ACTIONS(5732),
    [aux_sym_preproc_if_token2] = ACTIONS(5732),
    [aux_sym_preproc_else_token1] = ACTIONS(5732),
    [aux_sym_preproc_elif_token1] = ACTIONS(5730),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5732),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5732),
    [anon_sym_LPAREN2] = ACTIONS(5732),
    [anon_sym_DASH] = ACTIONS(5730),
    [anon_sym_PLUS] = ACTIONS(5730),
    [anon_sym_STAR] = ACTIONS(5730),
    [anon_sym_SLASH] = ACTIONS(5730),
    [anon_sym_PERCENT] = ACTIONS(5730),
    [anon_sym_PIPE_PIPE] = ACTIONS(5732),
    [anon_sym_AMP_AMP] = ACTIONS(5732),
    [anon_sym_PIPE] = ACTIONS(5730),
    [anon_sym_CARET] = ACTIONS(5730),
    [anon_sym_AMP] = ACTIONS(5730),
    [anon_sym_EQ_EQ] = ACTIONS(5732),
    [anon_sym_BANG_EQ] = ACTIONS(5732),
    [anon_sym_GT] = ACTIONS(5730),
    [anon_sym_GT_EQ] = ACTIONS(5732),
    [anon_sym_LT_EQ] = ACTIONS(5730),
    [anon_sym_LT] = ACTIONS(5730),
    [anon_sym_LT_LT] = ACTIONS(5730),
    [anon_sym_GT_GT] = ACTIONS(5730),
    [anon_sym_SEMI] = ACTIONS(5732),
    [anon_sym___attribute__] = ACTIONS(5730),
    [anon_sym___attribute] = ACTIONS(5730),
    [anon_sym_LBRACE] = ACTIONS(5732),
    [anon_sym_RBRACE] = ACTIONS(5732),
    [anon_sym_LBRACK] = ACTIONS(5732),
    [anon_sym_RBRACK] = ACTIONS(5732),
    [anon_sym_EQ] = ACTIONS(5730),
    [anon_sym_COLON] = ACTIONS(5732),
    [anon_sym_QMARK] = ACTIONS(5732),
    [anon_sym_STAR_EQ] = ACTIONS(5732),
    [anon_sym_SLASH_EQ] = ACTIONS(5732),
    [anon_sym_PERCENT_EQ] = ACTIONS(5732),
    [anon_sym_PLUS_EQ] = ACTIONS(5732),
    [anon_sym_DASH_EQ] = ACTIONS(5732),
    [anon_sym_LT_LT_EQ] = ACTIONS(5732),
    [anon_sym_GT_GT_EQ] = ACTIONS(5732),
    [anon_sym_AMP_EQ] = ACTIONS(5732),
    [anon_sym_CARET_EQ] = ACTIONS(5732),
    [anon_sym_PIPE_EQ] = ACTIONS(5732),
    [anon_sym_and_eq] = ACTIONS(5730),
    [anon_sym_or_eq] = ACTIONS(5730),
    [anon_sym_xor_eq] = ACTIONS(5730),
    [anon_sym_LT_EQ_GT] = ACTIONS(5732),
    [anon_sym_or] = ACTIONS(5730),
    [anon_sym_and] = ACTIONS(5730),
    [anon_sym_bitor] = ACTIONS(5730),
    [anon_sym_xor] = ACTIONS(5730),
    [anon_sym_bitand] = ACTIONS(5730),
    [anon_sym_not_eq] = ACTIONS(5730),
    [anon_sym_DASH_DASH] = ACTIONS(5732),
    [anon_sym_PLUS_PLUS] = ACTIONS(5732),
    [anon_sym_DOT] = ACTIONS(5730),
    [anon_sym_DOT_STAR] = ACTIONS(5732),
    [anon_sym_DASH_GT] = ACTIONS(5732),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5730),
    [anon_sym_decltype] = ACTIONS(5730),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5732),
  },
  [STATE(2501)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5748),
    [anon_sym_COMMA] = ACTIONS(5748),
    [anon_sym_LPAREN2] = ACTIONS(5748),
    [anon_sym_DASH] = ACTIONS(5746),
    [anon_sym_PLUS] = ACTIONS(5746),
    [anon_sym_STAR] = ACTIONS(5748),
    [anon_sym_SLASH] = ACTIONS(5746),
    [anon_sym_PERCENT] = ACTIONS(5748),
    [anon_sym_PIPE_PIPE] = ACTIONS(5748),
    [anon_sym_AMP_AMP] = ACTIONS(5748),
    [anon_sym_PIPE] = ACTIONS(5746),
    [anon_sym_CARET] = ACTIONS(5748),
    [anon_sym_AMP] = ACTIONS(5746),
    [anon_sym_EQ_EQ] = ACTIONS(5748),
    [anon_sym_BANG_EQ] = ACTIONS(5748),
    [anon_sym_GT] = ACTIONS(5746),
    [anon_sym_GT_EQ] = ACTIONS(5746),
    [anon_sym_LT_EQ] = ACTIONS(5746),
    [anon_sym_LT] = ACTIONS(5746),
    [anon_sym_LT_LT] = ACTIONS(5746),
    [anon_sym_GT_GT] = ACTIONS(5746),
    [anon_sym___extension__] = ACTIONS(5748),
    [anon_sym___global__] = ACTIONS(5748),
    [anon_sym___attribute__] = ACTIONS(5748),
    [anon_sym___attribute] = ACTIONS(5746),
    [anon_sym_LBRACE] = ACTIONS(5748),
    [anon_sym_LBRACK] = ACTIONS(5748),
    [anon_sym_const] = ACTIONS(5746),
    [anon_sym_constexpr] = ACTIONS(5748),
    [anon_sym_volatile] = ACTIONS(5748),
    [anon_sym_restrict] = ACTIONS(5748),
    [anon_sym___restrict__] = ACTIONS(5748),
    [anon_sym__Atomic] = ACTIONS(5748),
    [anon_sym__Noreturn] = ACTIONS(5748),
    [anon_sym_noreturn] = ACTIONS(5748),
    [anon_sym__Nonnull] = ACTIONS(5748),
    [anon_sym_mutable] = ACTIONS(5748),
    [anon_sym_constinit] = ACTIONS(5748),
    [anon_sym_consteval] = ACTIONS(5748),
    [anon_sym___shared__] = ACTIONS(5748),
    [anon_sym___local__] = ACTIONS(5748),
    [anon_sym___constant__] = ACTIONS(5748),
    [anon_sym___managed__] = ACTIONS(5748),
    [anon_sym___grid_constant__] = ACTIONS(5748),
    [anon_sym_alignas] = ACTIONS(5748),
    [anon_sym__Alignas] = ACTIONS(5748),
    [anon_sym_QMARK] = ACTIONS(5748),
    [anon_sym_LT_EQ_GT] = ACTIONS(5748),
    [anon_sym_or] = ACTIONS(5748),
    [anon_sym_and] = ACTIONS(5748),
    [anon_sym_bitor] = ACTIONS(5748),
    [anon_sym_xor] = ACTIONS(5748),
    [anon_sym_bitand] = ACTIONS(5748),
    [anon_sym_not_eq] = ACTIONS(5748),
    [anon_sym_DASH_DASH] = ACTIONS(5748),
    [anon_sym_PLUS_PLUS] = ACTIONS(5748),
    [anon_sym_DOT] = ACTIONS(5746),
    [anon_sym_DOT_STAR] = ACTIONS(5748),
    [anon_sym_DASH_GT] = ACTIONS(5748),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5748),
    [anon_sym_decltype] = ACTIONS(5748),
    [anon_sym_final] = ACTIONS(5748),
    [anon_sym_override] = ACTIONS(5748),
    [anon_sym_GT2] = ACTIONS(5748),
    [anon_sym_requires] = ACTIONS(5748),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5748),
  },
  [STATE(2502)] = {
    [sym_string_literal] = STATE(3794),
    [sym_template_argument_list] = STATE(5304),
    [sym_raw_string_literal] = STATE(3794),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(6526),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(6529),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(6531),
    [anon_sym_SLASH_EQ] = ACTIONS(6531),
    [anon_sym_PERCENT_EQ] = ACTIONS(6531),
    [anon_sym_PLUS_EQ] = ACTIONS(6531),
    [anon_sym_DASH_EQ] = ACTIONS(6531),
    [anon_sym_LT_LT_EQ] = ACTIONS(6531),
    [anon_sym_GT_GT_EQ] = ACTIONS(6531),
    [anon_sym_AMP_EQ] = ACTIONS(6531),
    [anon_sym_CARET_EQ] = ACTIONS(6531),
    [anon_sym_PIPE_EQ] = ACTIONS(6531),
    [anon_sym_and_eq] = ACTIONS(6531),
    [anon_sym_or_eq] = ACTIONS(6531),
    [anon_sym_xor_eq] = ACTIONS(6531),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(6533),
    [anon_sym_u_DQUOTE] = ACTIONS(6533),
    [anon_sym_U_DQUOTE] = ACTIONS(6533),
    [anon_sym_u8_DQUOTE] = ACTIONS(6533),
    [anon_sym_DQUOTE] = ACTIONS(6533),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6535),
    [anon_sym_LR_DQUOTE] = ACTIONS(6535),
    [anon_sym_uR_DQUOTE] = ACTIONS(6535),
    [anon_sym_UR_DQUOTE] = ACTIONS(6535),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6535),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(4004),
  },
  [STATE(2503)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5752),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5750),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5750),
    [anon_sym___extension__] = ACTIONS(5752),
    [anon_sym___global__] = ACTIONS(5752),
    [anon_sym___attribute__] = ACTIONS(5752),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5752),
    [anon_sym_volatile] = ACTIONS(5752),
    [anon_sym_restrict] = ACTIONS(5752),
    [anon_sym___restrict__] = ACTIONS(5752),
    [anon_sym__Atomic] = ACTIONS(5752),
    [anon_sym__Noreturn] = ACTIONS(5752),
    [anon_sym_noreturn] = ACTIONS(5752),
    [anon_sym__Nonnull] = ACTIONS(5752),
    [anon_sym_mutable] = ACTIONS(5752),
    [anon_sym_constinit] = ACTIONS(5752),
    [anon_sym_consteval] = ACTIONS(5752),
    [anon_sym___shared__] = ACTIONS(5752),
    [anon_sym___local__] = ACTIONS(5752),
    [anon_sym___constant__] = ACTIONS(5752),
    [anon_sym___managed__] = ACTIONS(5752),
    [anon_sym___grid_constant__] = ACTIONS(5752),
    [anon_sym_alignas] = ACTIONS(5752),
    [anon_sym__Alignas] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5752),
    [anon_sym_and] = ACTIONS(5752),
    [anon_sym_bitor] = ACTIONS(5752),
    [anon_sym_xor] = ACTIONS(5752),
    [anon_sym_bitand] = ACTIONS(5752),
    [anon_sym_not_eq] = ACTIONS(5752),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5752),
    [anon_sym_decltype] = ACTIONS(5752),
    [anon_sym_final] = ACTIONS(5752),
    [anon_sym_override] = ACTIONS(5752),
    [anon_sym_GT2] = ACTIONS(5752),
    [anon_sym_requires] = ACTIONS(5752),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2504)] = {
    [sym_identifier] = ACTIONS(5738),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5740),
    [anon_sym_COMMA] = ACTIONS(5740),
    [anon_sym_RPAREN] = ACTIONS(5740),
    [aux_sym_preproc_if_token2] = ACTIONS(5740),
    [aux_sym_preproc_else_token1] = ACTIONS(5740),
    [aux_sym_preproc_elif_token1] = ACTIONS(5738),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5740),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5740),
    [anon_sym_LPAREN2] = ACTIONS(5740),
    [anon_sym_DASH] = ACTIONS(5738),
    [anon_sym_PLUS] = ACTIONS(5738),
    [anon_sym_STAR] = ACTIONS(5738),
    [anon_sym_SLASH] = ACTIONS(5738),
    [anon_sym_PERCENT] = ACTIONS(5738),
    [anon_sym_PIPE_PIPE] = ACTIONS(5740),
    [anon_sym_AMP_AMP] = ACTIONS(5740),
    [anon_sym_PIPE] = ACTIONS(5738),
    [anon_sym_CARET] = ACTIONS(5738),
    [anon_sym_AMP] = ACTIONS(5738),
    [anon_sym_EQ_EQ] = ACTIONS(5740),
    [anon_sym_BANG_EQ] = ACTIONS(5740),
    [anon_sym_GT] = ACTIONS(5738),
    [anon_sym_GT_EQ] = ACTIONS(5740),
    [anon_sym_LT_EQ] = ACTIONS(5738),
    [anon_sym_LT] = ACTIONS(5738),
    [anon_sym_LT_LT] = ACTIONS(5738),
    [anon_sym_GT_GT] = ACTIONS(5738),
    [anon_sym_SEMI] = ACTIONS(5740),
    [anon_sym___attribute__] = ACTIONS(5738),
    [anon_sym___attribute] = ACTIONS(5738),
    [anon_sym_LBRACE] = ACTIONS(5740),
    [anon_sym_RBRACE] = ACTIONS(5740),
    [anon_sym_LBRACK] = ACTIONS(5740),
    [anon_sym_RBRACK] = ACTIONS(5740),
    [anon_sym_EQ] = ACTIONS(5738),
    [anon_sym_COLON] = ACTIONS(5740),
    [anon_sym_QMARK] = ACTIONS(5740),
    [anon_sym_STAR_EQ] = ACTIONS(5740),
    [anon_sym_SLASH_EQ] = ACTIONS(5740),
    [anon_sym_PERCENT_EQ] = ACTIONS(5740),
    [anon_sym_PLUS_EQ] = ACTIONS(5740),
    [anon_sym_DASH_EQ] = ACTIONS(5740),
    [anon_sym_LT_LT_EQ] = ACTIONS(5740),
    [anon_sym_GT_GT_EQ] = ACTIONS(5740),
    [anon_sym_AMP_EQ] = ACTIONS(5740),
    [anon_sym_CARET_EQ] = ACTIONS(5740),
    [anon_sym_PIPE_EQ] = ACTIONS(5740),
    [anon_sym_and_eq] = ACTIONS(5738),
    [anon_sym_or_eq] = ACTIONS(5738),
    [anon_sym_xor_eq] = ACTIONS(5738),
    [anon_sym_LT_EQ_GT] = ACTIONS(5740),
    [anon_sym_or] = ACTIONS(5738),
    [anon_sym_and] = ACTIONS(5738),
    [anon_sym_bitor] = ACTIONS(5738),
    [anon_sym_xor] = ACTIONS(5738),
    [anon_sym_bitand] = ACTIONS(5738),
    [anon_sym_not_eq] = ACTIONS(5738),
    [anon_sym_DASH_DASH] = ACTIONS(5740),
    [anon_sym_PLUS_PLUS] = ACTIONS(5740),
    [anon_sym_DOT] = ACTIONS(5738),
    [anon_sym_DOT_STAR] = ACTIONS(5740),
    [anon_sym_DASH_GT] = ACTIONS(5740),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5738),
    [anon_sym_decltype] = ACTIONS(5738),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5740),
  },
  [STATE(2505)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6161),
    [anon_sym_COMMA] = ACTIONS(6161),
    [anon_sym_RPAREN] = ACTIONS(6161),
    [anon_sym_LPAREN2] = ACTIONS(6161),
    [anon_sym_DASH] = ACTIONS(6159),
    [anon_sym_PLUS] = ACTIONS(6159),
    [anon_sym_STAR] = ACTIONS(6159),
    [anon_sym_SLASH] = ACTIONS(6159),
    [anon_sym_PERCENT] = ACTIONS(6159),
    [anon_sym_PIPE_PIPE] = ACTIONS(6161),
    [anon_sym_AMP_AMP] = ACTIONS(6161),
    [anon_sym_PIPE] = ACTIONS(6159),
    [anon_sym_CARET] = ACTIONS(6159),
    [anon_sym_AMP] = ACTIONS(6159),
    [anon_sym_EQ_EQ] = ACTIONS(6161),
    [anon_sym_BANG_EQ] = ACTIONS(6161),
    [anon_sym_GT] = ACTIONS(6159),
    [anon_sym_GT_EQ] = ACTIONS(6161),
    [anon_sym_LT_EQ] = ACTIONS(6159),
    [anon_sym_LT] = ACTIONS(6159),
    [anon_sym_LT_LT] = ACTIONS(6159),
    [anon_sym_GT_GT] = ACTIONS(6159),
    [anon_sym_SEMI] = ACTIONS(6161),
    [anon_sym_RBRACE] = ACTIONS(6161),
    [anon_sym_LBRACK] = ACTIONS(6161),
    [anon_sym_RBRACK] = ACTIONS(6161),
    [anon_sym_EQ] = ACTIONS(6159),
    [anon_sym_COLON] = ACTIONS(6161),
    [anon_sym_QMARK] = ACTIONS(6161),
    [anon_sym_STAR_EQ] = ACTIONS(6161),
    [anon_sym_SLASH_EQ] = ACTIONS(6161),
    [anon_sym_PERCENT_EQ] = ACTIONS(6161),
    [anon_sym_PLUS_EQ] = ACTIONS(6161),
    [anon_sym_DASH_EQ] = ACTIONS(6161),
    [anon_sym_LT_LT_EQ] = ACTIONS(6161),
    [anon_sym_GT_GT_EQ] = ACTIONS(6161),
    [anon_sym_AMP_EQ] = ACTIONS(6161),
    [anon_sym_CARET_EQ] = ACTIONS(6161),
    [anon_sym_PIPE_EQ] = ACTIONS(6161),
    [anon_sym_and_eq] = ACTIONS(6159),
    [anon_sym_or_eq] = ACTIONS(6159),
    [anon_sym_xor_eq] = ACTIONS(6159),
    [anon_sym_LT_EQ_GT] = ACTIONS(6161),
    [anon_sym_or] = ACTIONS(6159),
    [anon_sym_and] = ACTIONS(6159),
    [anon_sym_bitor] = ACTIONS(6159),
    [anon_sym_xor] = ACTIONS(6159),
    [anon_sym_bitand] = ACTIONS(6159),
    [anon_sym_not_eq] = ACTIONS(6159),
    [anon_sym_DASH_DASH] = ACTIONS(6161),
    [anon_sym_PLUS_PLUS] = ACTIONS(6161),
    [anon_sym_DOT] = ACTIONS(6159),
    [anon_sym_DOT_STAR] = ACTIONS(6161),
    [anon_sym_DASH_GT] = ACTIONS(6161),
    [anon_sym_L_DQUOTE] = ACTIONS(6161),
    [anon_sym_u_DQUOTE] = ACTIONS(6161),
    [anon_sym_U_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8_DQUOTE] = ACTIONS(6161),
    [anon_sym_DQUOTE] = ACTIONS(6161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6161),
    [anon_sym_LR_DQUOTE] = ACTIONS(6161),
    [anon_sym_uR_DQUOTE] = ACTIONS(6161),
    [anon_sym_UR_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6161),
    [sym_literal_suffix] = ACTIONS(6159),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6161),
  },
  [STATE(2506)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [aux_sym_preproc_if_token2] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5684),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5686),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5684),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5684),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_EQ] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_STAR_EQ] = ACTIONS(5686),
    [anon_sym_SLASH_EQ] = ACTIONS(5686),
    [anon_sym_PERCENT_EQ] = ACTIONS(5686),
    [anon_sym_PLUS_EQ] = ACTIONS(5686),
    [anon_sym_DASH_EQ] = ACTIONS(5686),
    [anon_sym_LT_LT_EQ] = ACTIONS(5686),
    [anon_sym_GT_GT_EQ] = ACTIONS(5686),
    [anon_sym_AMP_EQ] = ACTIONS(5686),
    [anon_sym_CARET_EQ] = ACTIONS(5686),
    [anon_sym_PIPE_EQ] = ACTIONS(5686),
    [anon_sym_and_eq] = ACTIONS(5684),
    [anon_sym_or_eq] = ACTIONS(5684),
    [anon_sym_xor_eq] = ACTIONS(5684),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_and] = ACTIONS(5684),
    [anon_sym_bitor] = ACTIONS(5684),
    [anon_sym_xor] = ACTIONS(5684),
    [anon_sym_bitand] = ACTIONS(5684),
    [anon_sym_not_eq] = ACTIONS(5684),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2507)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5788),
    [anon_sym_COMMA] = ACTIONS(5788),
    [anon_sym_LPAREN2] = ACTIONS(5788),
    [anon_sym_DASH] = ACTIONS(5786),
    [anon_sym_PLUS] = ACTIONS(5786),
    [anon_sym_STAR] = ACTIONS(5788),
    [anon_sym_SLASH] = ACTIONS(5786),
    [anon_sym_PERCENT] = ACTIONS(5788),
    [anon_sym_PIPE_PIPE] = ACTIONS(5788),
    [anon_sym_AMP_AMP] = ACTIONS(5788),
    [anon_sym_PIPE] = ACTIONS(5786),
    [anon_sym_CARET] = ACTIONS(5788),
    [anon_sym_AMP] = ACTIONS(5786),
    [anon_sym_EQ_EQ] = ACTIONS(5788),
    [anon_sym_BANG_EQ] = ACTIONS(5788),
    [anon_sym_GT] = ACTIONS(5786),
    [anon_sym_GT_EQ] = ACTIONS(5786),
    [anon_sym_LT_EQ] = ACTIONS(5786),
    [anon_sym_LT] = ACTIONS(5786),
    [anon_sym_LT_LT] = ACTIONS(5786),
    [anon_sym_GT_GT] = ACTIONS(5786),
    [anon_sym___extension__] = ACTIONS(5788),
    [anon_sym___global__] = ACTIONS(5788),
    [anon_sym___attribute__] = ACTIONS(5788),
    [anon_sym___attribute] = ACTIONS(5786),
    [anon_sym_LBRACE] = ACTIONS(5788),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_constexpr] = ACTIONS(5788),
    [anon_sym_volatile] = ACTIONS(5788),
    [anon_sym_restrict] = ACTIONS(5788),
    [anon_sym___restrict__] = ACTIONS(5788),
    [anon_sym__Atomic] = ACTIONS(5788),
    [anon_sym__Noreturn] = ACTIONS(5788),
    [anon_sym_noreturn] = ACTIONS(5788),
    [anon_sym__Nonnull] = ACTIONS(5788),
    [anon_sym_mutable] = ACTIONS(5788),
    [anon_sym_constinit] = ACTIONS(5788),
    [anon_sym_consteval] = ACTIONS(5788),
    [anon_sym___shared__] = ACTIONS(5788),
    [anon_sym___local__] = ACTIONS(5788),
    [anon_sym___constant__] = ACTIONS(5788),
    [anon_sym___managed__] = ACTIONS(5788),
    [anon_sym___grid_constant__] = ACTIONS(5788),
    [anon_sym_alignas] = ACTIONS(5788),
    [anon_sym__Alignas] = ACTIONS(5788),
    [anon_sym_QMARK] = ACTIONS(5788),
    [anon_sym_LT_EQ_GT] = ACTIONS(5788),
    [anon_sym_or] = ACTIONS(5788),
    [anon_sym_and] = ACTIONS(5788),
    [anon_sym_bitor] = ACTIONS(5788),
    [anon_sym_xor] = ACTIONS(5788),
    [anon_sym_bitand] = ACTIONS(5788),
    [anon_sym_not_eq] = ACTIONS(5788),
    [anon_sym_DASH_DASH] = ACTIONS(5788),
    [anon_sym_PLUS_PLUS] = ACTIONS(5788),
    [anon_sym_DOT] = ACTIONS(5786),
    [anon_sym_DOT_STAR] = ACTIONS(5788),
    [anon_sym_DASH_GT] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5788),
    [anon_sym_decltype] = ACTIONS(5788),
    [anon_sym_final] = ACTIONS(5788),
    [anon_sym_override] = ACTIONS(5788),
    [anon_sym_GT2] = ACTIONS(5788),
    [anon_sym_requires] = ACTIONS(5788),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5788),
  },
  [STATE(2508)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5807),
    [anon_sym_COMMA] = ACTIONS(5807),
    [anon_sym_LPAREN2] = ACTIONS(5807),
    [anon_sym_DASH] = ACTIONS(5805),
    [anon_sym_PLUS] = ACTIONS(5805),
    [anon_sym_STAR] = ACTIONS(5807),
    [anon_sym_SLASH] = ACTIONS(5805),
    [anon_sym_PERCENT] = ACTIONS(5807),
    [anon_sym_PIPE_PIPE] = ACTIONS(5807),
    [anon_sym_AMP_AMP] = ACTIONS(5807),
    [anon_sym_PIPE] = ACTIONS(5805),
    [anon_sym_CARET] = ACTIONS(5807),
    [anon_sym_AMP] = ACTIONS(5805),
    [anon_sym_EQ_EQ] = ACTIONS(5807),
    [anon_sym_BANG_EQ] = ACTIONS(5807),
    [anon_sym_GT] = ACTIONS(5805),
    [anon_sym_GT_EQ] = ACTIONS(5805),
    [anon_sym_LT_EQ] = ACTIONS(5805),
    [anon_sym_LT] = ACTIONS(5805),
    [anon_sym_LT_LT] = ACTIONS(5805),
    [anon_sym_GT_GT] = ACTIONS(5805),
    [anon_sym___extension__] = ACTIONS(5807),
    [anon_sym___global__] = ACTIONS(5807),
    [anon_sym___attribute__] = ACTIONS(5807),
    [anon_sym___attribute] = ACTIONS(5805),
    [anon_sym_LBRACE] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5807),
    [anon_sym_const] = ACTIONS(5805),
    [anon_sym_constexpr] = ACTIONS(5807),
    [anon_sym_volatile] = ACTIONS(5807),
    [anon_sym_restrict] = ACTIONS(5807),
    [anon_sym___restrict__] = ACTIONS(5807),
    [anon_sym__Atomic] = ACTIONS(5807),
    [anon_sym__Noreturn] = ACTIONS(5807),
    [anon_sym_noreturn] = ACTIONS(5807),
    [anon_sym__Nonnull] = ACTIONS(5807),
    [anon_sym_mutable] = ACTIONS(5807),
    [anon_sym_constinit] = ACTIONS(5807),
    [anon_sym_consteval] = ACTIONS(5807),
    [anon_sym___shared__] = ACTIONS(5807),
    [anon_sym___local__] = ACTIONS(5807),
    [anon_sym___constant__] = ACTIONS(5807),
    [anon_sym___managed__] = ACTIONS(5807),
    [anon_sym___grid_constant__] = ACTIONS(5807),
    [anon_sym_alignas] = ACTIONS(5807),
    [anon_sym__Alignas] = ACTIONS(5807),
    [anon_sym_QMARK] = ACTIONS(5807),
    [anon_sym_LT_EQ_GT] = ACTIONS(5807),
    [anon_sym_or] = ACTIONS(5807),
    [anon_sym_and] = ACTIONS(5807),
    [anon_sym_bitor] = ACTIONS(5807),
    [anon_sym_xor] = ACTIONS(5807),
    [anon_sym_bitand] = ACTIONS(5807),
    [anon_sym_not_eq] = ACTIONS(5807),
    [anon_sym_DASH_DASH] = ACTIONS(5807),
    [anon_sym_PLUS_PLUS] = ACTIONS(5807),
    [anon_sym_DOT] = ACTIONS(5805),
    [anon_sym_DOT_STAR] = ACTIONS(5807),
    [anon_sym_DASH_GT] = ACTIONS(5807),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5807),
    [anon_sym_decltype] = ACTIONS(5807),
    [anon_sym_final] = ACTIONS(5807),
    [anon_sym_override] = ACTIONS(5807),
    [anon_sym_GT2] = ACTIONS(5807),
    [anon_sym_requires] = ACTIONS(5807),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5807),
  },
  [STATE(2509)] = {
    [sym_string_literal] = STATE(2204),
    [sym_template_argument_list] = STATE(2672),
    [sym_raw_string_literal] = STATE(2204),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6456),
    [anon_sym_COMMA] = ACTIONS(6537),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5857),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_RBRACK] = ACTIONS(6539),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(2663),
    [anon_sym_u_DQUOTE] = ACTIONS(2663),
    [anon_sym_U_DQUOTE] = ACTIONS(2663),
    [anon_sym_u8_DQUOTE] = ACTIONS(2663),
    [anon_sym_DQUOTE] = ACTIONS(2663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(2673),
    [anon_sym_LR_DQUOTE] = ACTIONS(2673),
    [anon_sym_uR_DQUOTE] = ACTIONS(2673),
    [anon_sym_UR_DQUOTE] = ACTIONS(2673),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2673),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2510)] = {
    [sym_attribute_specifier] = STATE(2231),
    [sym_identifier] = ACTIONS(6212),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6210),
    [anon_sym_COMMA] = ACTIONS(6210),
    [anon_sym_RPAREN] = ACTIONS(6210),
    [anon_sym_LPAREN2] = ACTIONS(6210),
    [anon_sym_TILDE] = ACTIONS(6210),
    [anon_sym_STAR] = ACTIONS(6210),
    [anon_sym_AMP_AMP] = ACTIONS(6210),
    [anon_sym_AMP] = ACTIONS(6212),
    [anon_sym_SEMI] = ACTIONS(6210),
    [anon_sym___extension__] = ACTIONS(6212),
    [anon_sym___device__] = ACTIONS(6212),
    [anon_sym___host__] = ACTIONS(6212),
    [anon_sym___global__] = ACTIONS(6212),
    [anon_sym___forceinline__] = ACTIONS(6212),
    [anon_sym___noinline__] = ACTIONS(6212),
    [anon_sym_virtual] = ACTIONS(6212),
    [anon_sym_extern] = ACTIONS(6212),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6210),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6210),
    [anon_sym___declspec] = ACTIONS(6212),
    [anon_sym___based] = ACTIONS(6212),
    [anon_sym___cdecl] = ACTIONS(6212),
    [anon_sym___clrcall] = ACTIONS(6212),
    [anon_sym___stdcall] = ACTIONS(6212),
    [anon_sym___fastcall] = ACTIONS(6212),
    [anon_sym___thiscall] = ACTIONS(6212),
    [anon_sym___vectorcall] = ACTIONS(6212),
    [anon_sym_LBRACK] = ACTIONS(6212),
    [anon_sym_static] = ACTIONS(6212),
    [anon_sym_EQ] = ACTIONS(6210),
    [anon_sym_register] = ACTIONS(6212),
    [anon_sym_inline] = ACTIONS(6212),
    [anon_sym___inline] = ACTIONS(6212),
    [anon_sym___inline__] = ACTIONS(6212),
    [anon_sym___forceinline] = ACTIONS(6212),
    [anon_sym_thread_local] = ACTIONS(6212),
    [anon_sym___thread] = ACTIONS(6212),
    [anon_sym_const] = ACTIONS(6212),
    [anon_sym_constexpr] = ACTIONS(6212),
    [anon_sym_volatile] = ACTIONS(6212),
    [anon_sym_restrict] = ACTIONS(6212),
    [anon_sym___restrict__] = ACTIONS(6212),
    [anon_sym__Atomic] = ACTIONS(6212),
    [anon_sym__Noreturn] = ACTIONS(6212),
    [anon_sym_noreturn] = ACTIONS(6212),
    [anon_sym__Nonnull] = ACTIONS(6212),
    [anon_sym_mutable] = ACTIONS(6212),
    [anon_sym_constinit] = ACTIONS(6212),
    [anon_sym_consteval] = ACTIONS(6212),
    [anon_sym___shared__] = ACTIONS(6212),
    [anon_sym___local__] = ACTIONS(6212),
    [anon_sym___constant__] = ACTIONS(6212),
    [anon_sym___managed__] = ACTIONS(6212),
    [anon_sym___grid_constant__] = ACTIONS(6212),
    [anon_sym_alignas] = ACTIONS(6212),
    [anon_sym__Alignas] = ACTIONS(6212),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6212),
    [anon_sym_decltype] = ACTIONS(6212),
    [anon_sym_template] = ACTIONS(6212),
    [anon_sym_GT2] = ACTIONS(6210),
    [anon_sym_operator] = ACTIONS(6212),
    [anon_sym___launch_bounds__] = ACTIONS(6212),
  },
  [STATE(2511)] = {
    [sym_attribute_specifier] = STATE(2232),
    [sym_identifier] = ACTIONS(6228),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6226),
    [anon_sym_COMMA] = ACTIONS(6226),
    [anon_sym_RPAREN] = ACTIONS(6226),
    [anon_sym_LPAREN2] = ACTIONS(6226),
    [anon_sym_TILDE] = ACTIONS(6226),
    [anon_sym_STAR] = ACTIONS(6226),
    [anon_sym_AMP_AMP] = ACTIONS(6226),
    [anon_sym_AMP] = ACTIONS(6228),
    [anon_sym_SEMI] = ACTIONS(6226),
    [anon_sym___extension__] = ACTIONS(6228),
    [anon_sym___device__] = ACTIONS(6228),
    [anon_sym___host__] = ACTIONS(6228),
    [anon_sym___global__] = ACTIONS(6228),
    [anon_sym___forceinline__] = ACTIONS(6228),
    [anon_sym___noinline__] = ACTIONS(6228),
    [anon_sym_virtual] = ACTIONS(6228),
    [anon_sym_extern] = ACTIONS(6228),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6226),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6226),
    [anon_sym___declspec] = ACTIONS(6228),
    [anon_sym___based] = ACTIONS(6228),
    [anon_sym___cdecl] = ACTIONS(6228),
    [anon_sym___clrcall] = ACTIONS(6228),
    [anon_sym___stdcall] = ACTIONS(6228),
    [anon_sym___fastcall] = ACTIONS(6228),
    [anon_sym___thiscall] = ACTIONS(6228),
    [anon_sym___vectorcall] = ACTIONS(6228),
    [anon_sym_LBRACK] = ACTIONS(6228),
    [anon_sym_static] = ACTIONS(6228),
    [anon_sym_EQ] = ACTIONS(6226),
    [anon_sym_register] = ACTIONS(6228),
    [anon_sym_inline] = ACTIONS(6228),
    [anon_sym___inline] = ACTIONS(6228),
    [anon_sym___inline__] = ACTIONS(6228),
    [anon_sym___forceinline] = ACTIONS(6228),
    [anon_sym_thread_local] = ACTIONS(6228),
    [anon_sym___thread] = ACTIONS(6228),
    [anon_sym_const] = ACTIONS(6228),
    [anon_sym_constexpr] = ACTIONS(6228),
    [anon_sym_volatile] = ACTIONS(6228),
    [anon_sym_restrict] = ACTIONS(6228),
    [anon_sym___restrict__] = ACTIONS(6228),
    [anon_sym__Atomic] = ACTIONS(6228),
    [anon_sym__Noreturn] = ACTIONS(6228),
    [anon_sym_noreturn] = ACTIONS(6228),
    [anon_sym__Nonnull] = ACTIONS(6228),
    [anon_sym_mutable] = ACTIONS(6228),
    [anon_sym_constinit] = ACTIONS(6228),
    [anon_sym_consteval] = ACTIONS(6228),
    [anon_sym___shared__] = ACTIONS(6228),
    [anon_sym___local__] = ACTIONS(6228),
    [anon_sym___constant__] = ACTIONS(6228),
    [anon_sym___managed__] = ACTIONS(6228),
    [anon_sym___grid_constant__] = ACTIONS(6228),
    [anon_sym_alignas] = ACTIONS(6228),
    [anon_sym__Alignas] = ACTIONS(6228),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6228),
    [anon_sym_decltype] = ACTIONS(6228),
    [anon_sym_template] = ACTIONS(6228),
    [anon_sym_GT2] = ACTIONS(6226),
    [anon_sym_operator] = ACTIONS(6228),
    [anon_sym___launch_bounds__] = ACTIONS(6228),
  },
  [STATE(2512)] = {
    [sym_identifier] = ACTIONS(5746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5748),
    [anon_sym_COMMA] = ACTIONS(5748),
    [anon_sym_RPAREN] = ACTIONS(5748),
    [aux_sym_preproc_if_token2] = ACTIONS(5748),
    [aux_sym_preproc_else_token1] = ACTIONS(5748),
    [aux_sym_preproc_elif_token1] = ACTIONS(5746),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5748),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5748),
    [anon_sym_LPAREN2] = ACTIONS(5748),
    [anon_sym_DASH] = ACTIONS(5746),
    [anon_sym_PLUS] = ACTIONS(5746),
    [anon_sym_STAR] = ACTIONS(5746),
    [anon_sym_SLASH] = ACTIONS(5746),
    [anon_sym_PERCENT] = ACTIONS(5746),
    [anon_sym_PIPE_PIPE] = ACTIONS(5748),
    [anon_sym_AMP_AMP] = ACTIONS(5748),
    [anon_sym_PIPE] = ACTIONS(5746),
    [anon_sym_CARET] = ACTIONS(5746),
    [anon_sym_AMP] = ACTIONS(5746),
    [anon_sym_EQ_EQ] = ACTIONS(5748),
    [anon_sym_BANG_EQ] = ACTIONS(5748),
    [anon_sym_GT] = ACTIONS(5746),
    [anon_sym_GT_EQ] = ACTIONS(5748),
    [anon_sym_LT_EQ] = ACTIONS(5746),
    [anon_sym_LT] = ACTIONS(5746),
    [anon_sym_LT_LT] = ACTIONS(5746),
    [anon_sym_GT_GT] = ACTIONS(5746),
    [anon_sym_SEMI] = ACTIONS(5748),
    [anon_sym___attribute__] = ACTIONS(5746),
    [anon_sym___attribute] = ACTIONS(5746),
    [anon_sym_LBRACE] = ACTIONS(5748),
    [anon_sym_RBRACE] = ACTIONS(5748),
    [anon_sym_LBRACK] = ACTIONS(5748),
    [anon_sym_RBRACK] = ACTIONS(5748),
    [anon_sym_EQ] = ACTIONS(5746),
    [anon_sym_COLON] = ACTIONS(5748),
    [anon_sym_QMARK] = ACTIONS(5748),
    [anon_sym_STAR_EQ] = ACTIONS(5748),
    [anon_sym_SLASH_EQ] = ACTIONS(5748),
    [anon_sym_PERCENT_EQ] = ACTIONS(5748),
    [anon_sym_PLUS_EQ] = ACTIONS(5748),
    [anon_sym_DASH_EQ] = ACTIONS(5748),
    [anon_sym_LT_LT_EQ] = ACTIONS(5748),
    [anon_sym_GT_GT_EQ] = ACTIONS(5748),
    [anon_sym_AMP_EQ] = ACTIONS(5748),
    [anon_sym_CARET_EQ] = ACTIONS(5748),
    [anon_sym_PIPE_EQ] = ACTIONS(5748),
    [anon_sym_and_eq] = ACTIONS(5746),
    [anon_sym_or_eq] = ACTIONS(5746),
    [anon_sym_xor_eq] = ACTIONS(5746),
    [anon_sym_LT_EQ_GT] = ACTIONS(5748),
    [anon_sym_or] = ACTIONS(5746),
    [anon_sym_and] = ACTIONS(5746),
    [anon_sym_bitor] = ACTIONS(5746),
    [anon_sym_xor] = ACTIONS(5746),
    [anon_sym_bitand] = ACTIONS(5746),
    [anon_sym_not_eq] = ACTIONS(5746),
    [anon_sym_DASH_DASH] = ACTIONS(5748),
    [anon_sym_PLUS_PLUS] = ACTIONS(5748),
    [anon_sym_DOT] = ACTIONS(5746),
    [anon_sym_DOT_STAR] = ACTIONS(5748),
    [anon_sym_DASH_GT] = ACTIONS(5748),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5746),
    [anon_sym_decltype] = ACTIONS(5746),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5748),
  },
  [STATE(2513)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [aux_sym_preproc_if_token2] = ACTIONS(5752),
    [aux_sym_preproc_else_token1] = ACTIONS(5752),
    [aux_sym_preproc_elif_token1] = ACTIONS(5750),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5752),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5750),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5750),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5750),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5752),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5750),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_RBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_RBRACK] = ACTIONS(5752),
    [anon_sym_EQ] = ACTIONS(5750),
    [anon_sym_COLON] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_STAR_EQ] = ACTIONS(5752),
    [anon_sym_SLASH_EQ] = ACTIONS(5752),
    [anon_sym_PERCENT_EQ] = ACTIONS(5752),
    [anon_sym_PLUS_EQ] = ACTIONS(5752),
    [anon_sym_DASH_EQ] = ACTIONS(5752),
    [anon_sym_LT_LT_EQ] = ACTIONS(5752),
    [anon_sym_GT_GT_EQ] = ACTIONS(5752),
    [anon_sym_AMP_EQ] = ACTIONS(5752),
    [anon_sym_CARET_EQ] = ACTIONS(5752),
    [anon_sym_PIPE_EQ] = ACTIONS(5752),
    [anon_sym_and_eq] = ACTIONS(5750),
    [anon_sym_or_eq] = ACTIONS(5750),
    [anon_sym_xor_eq] = ACTIONS(5750),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5750),
    [anon_sym_and] = ACTIONS(5750),
    [anon_sym_bitor] = ACTIONS(5750),
    [anon_sym_xor] = ACTIONS(5750),
    [anon_sym_bitand] = ACTIONS(5750),
    [anon_sym_not_eq] = ACTIONS(5750),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2514)] = {
    [sym_identifier] = ACTIONS(5786),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5788),
    [anon_sym_COMMA] = ACTIONS(5788),
    [anon_sym_RPAREN] = ACTIONS(5788),
    [aux_sym_preproc_if_token2] = ACTIONS(5788),
    [aux_sym_preproc_else_token1] = ACTIONS(5788),
    [aux_sym_preproc_elif_token1] = ACTIONS(5786),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5788),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5788),
    [anon_sym_LPAREN2] = ACTIONS(5788),
    [anon_sym_DASH] = ACTIONS(5786),
    [anon_sym_PLUS] = ACTIONS(5786),
    [anon_sym_STAR] = ACTIONS(5786),
    [anon_sym_SLASH] = ACTIONS(5786),
    [anon_sym_PERCENT] = ACTIONS(5786),
    [anon_sym_PIPE_PIPE] = ACTIONS(5788),
    [anon_sym_AMP_AMP] = ACTIONS(5788),
    [anon_sym_PIPE] = ACTIONS(5786),
    [anon_sym_CARET] = ACTIONS(5786),
    [anon_sym_AMP] = ACTIONS(5786),
    [anon_sym_EQ_EQ] = ACTIONS(5788),
    [anon_sym_BANG_EQ] = ACTIONS(5788),
    [anon_sym_GT] = ACTIONS(5786),
    [anon_sym_GT_EQ] = ACTIONS(5788),
    [anon_sym_LT_EQ] = ACTIONS(5786),
    [anon_sym_LT] = ACTIONS(5786),
    [anon_sym_LT_LT] = ACTIONS(5786),
    [anon_sym_GT_GT] = ACTIONS(5786),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym___attribute__] = ACTIONS(5786),
    [anon_sym___attribute] = ACTIONS(5786),
    [anon_sym_LBRACE] = ACTIONS(5788),
    [anon_sym_RBRACE] = ACTIONS(5788),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_RBRACK] = ACTIONS(5788),
    [anon_sym_EQ] = ACTIONS(5786),
    [anon_sym_COLON] = ACTIONS(5788),
    [anon_sym_QMARK] = ACTIONS(5788),
    [anon_sym_STAR_EQ] = ACTIONS(5788),
    [anon_sym_SLASH_EQ] = ACTIONS(5788),
    [anon_sym_PERCENT_EQ] = ACTIONS(5788),
    [anon_sym_PLUS_EQ] = ACTIONS(5788),
    [anon_sym_DASH_EQ] = ACTIONS(5788),
    [anon_sym_LT_LT_EQ] = ACTIONS(5788),
    [anon_sym_GT_GT_EQ] = ACTIONS(5788),
    [anon_sym_AMP_EQ] = ACTIONS(5788),
    [anon_sym_CARET_EQ] = ACTIONS(5788),
    [anon_sym_PIPE_EQ] = ACTIONS(5788),
    [anon_sym_and_eq] = ACTIONS(5786),
    [anon_sym_or_eq] = ACTIONS(5786),
    [anon_sym_xor_eq] = ACTIONS(5786),
    [anon_sym_LT_EQ_GT] = ACTIONS(5788),
    [anon_sym_or] = ACTIONS(5786),
    [anon_sym_and] = ACTIONS(5786),
    [anon_sym_bitor] = ACTIONS(5786),
    [anon_sym_xor] = ACTIONS(5786),
    [anon_sym_bitand] = ACTIONS(5786),
    [anon_sym_not_eq] = ACTIONS(5786),
    [anon_sym_DASH_DASH] = ACTIONS(5788),
    [anon_sym_PLUS_PLUS] = ACTIONS(5788),
    [anon_sym_DOT] = ACTIONS(5786),
    [anon_sym_DOT_STAR] = ACTIONS(5788),
    [anon_sym_DASH_GT] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5786),
    [anon_sym_decltype] = ACTIONS(5786),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5788),
  },
  [STATE(2515)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5752),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5750),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5750),
    [anon_sym___extension__] = ACTIONS(5752),
    [anon_sym___global__] = ACTIONS(5752),
    [anon_sym___attribute__] = ACTIONS(5752),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5752),
    [anon_sym_volatile] = ACTIONS(5752),
    [anon_sym_restrict] = ACTIONS(5752),
    [anon_sym___restrict__] = ACTIONS(5752),
    [anon_sym__Atomic] = ACTIONS(5752),
    [anon_sym__Noreturn] = ACTIONS(5752),
    [anon_sym_noreturn] = ACTIONS(5752),
    [anon_sym__Nonnull] = ACTIONS(5752),
    [anon_sym_mutable] = ACTIONS(5752),
    [anon_sym_constinit] = ACTIONS(5752),
    [anon_sym_consteval] = ACTIONS(5752),
    [anon_sym___shared__] = ACTIONS(5752),
    [anon_sym___local__] = ACTIONS(5752),
    [anon_sym___constant__] = ACTIONS(5752),
    [anon_sym___managed__] = ACTIONS(5752),
    [anon_sym___grid_constant__] = ACTIONS(5752),
    [anon_sym_alignas] = ACTIONS(5752),
    [anon_sym__Alignas] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5752),
    [anon_sym_and] = ACTIONS(5752),
    [anon_sym_bitor] = ACTIONS(5752),
    [anon_sym_xor] = ACTIONS(5752),
    [anon_sym_bitand] = ACTIONS(5752),
    [anon_sym_not_eq] = ACTIONS(5752),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5752),
    [anon_sym_decltype] = ACTIONS(5752),
    [anon_sym_final] = ACTIONS(5752),
    [anon_sym_override] = ACTIONS(5752),
    [anon_sym_GT2] = ACTIONS(5752),
    [anon_sym_requires] = ACTIONS(5752),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2516)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5752),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5752),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5752),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5750),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5750),
    [anon_sym___extension__] = ACTIONS(5752),
    [anon_sym___global__] = ACTIONS(5752),
    [anon_sym___attribute__] = ACTIONS(5752),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_const] = ACTIONS(5750),
    [anon_sym_constexpr] = ACTIONS(5752),
    [anon_sym_volatile] = ACTIONS(5752),
    [anon_sym_restrict] = ACTIONS(5752),
    [anon_sym___restrict__] = ACTIONS(5752),
    [anon_sym__Atomic] = ACTIONS(5752),
    [anon_sym__Noreturn] = ACTIONS(5752),
    [anon_sym_noreturn] = ACTIONS(5752),
    [anon_sym__Nonnull] = ACTIONS(5752),
    [anon_sym_mutable] = ACTIONS(5752),
    [anon_sym_constinit] = ACTIONS(5752),
    [anon_sym_consteval] = ACTIONS(5752),
    [anon_sym___shared__] = ACTIONS(5752),
    [anon_sym___local__] = ACTIONS(5752),
    [anon_sym___constant__] = ACTIONS(5752),
    [anon_sym___managed__] = ACTIONS(5752),
    [anon_sym___grid_constant__] = ACTIONS(5752),
    [anon_sym_alignas] = ACTIONS(5752),
    [anon_sym__Alignas] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5752),
    [anon_sym_and] = ACTIONS(5752),
    [anon_sym_bitor] = ACTIONS(5752),
    [anon_sym_xor] = ACTIONS(5752),
    [anon_sym_bitand] = ACTIONS(5752),
    [anon_sym_not_eq] = ACTIONS(5752),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5752),
    [anon_sym_decltype] = ACTIONS(5752),
    [anon_sym_final] = ACTIONS(5752),
    [anon_sym_override] = ACTIONS(5752),
    [anon_sym_GT2] = ACTIONS(5752),
    [anon_sym_requires] = ACTIONS(5752),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2517)] = {
    [sym_attribute_specifier] = STATE(2268),
    [sym_identifier] = ACTIONS(6260),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6258),
    [anon_sym_COMMA] = ACTIONS(6258),
    [anon_sym_RPAREN] = ACTIONS(6258),
    [anon_sym_LPAREN2] = ACTIONS(6258),
    [anon_sym_TILDE] = ACTIONS(6258),
    [anon_sym_STAR] = ACTIONS(6258),
    [anon_sym_AMP_AMP] = ACTIONS(6258),
    [anon_sym_AMP] = ACTIONS(6260),
    [anon_sym_SEMI] = ACTIONS(6258),
    [anon_sym___extension__] = ACTIONS(6260),
    [anon_sym___device__] = ACTIONS(6260),
    [anon_sym___host__] = ACTIONS(6260),
    [anon_sym___global__] = ACTIONS(6260),
    [anon_sym___forceinline__] = ACTIONS(6260),
    [anon_sym___noinline__] = ACTIONS(6260),
    [anon_sym_virtual] = ACTIONS(6260),
    [anon_sym_extern] = ACTIONS(6260),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6258),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6258),
    [anon_sym___declspec] = ACTIONS(6260),
    [anon_sym___based] = ACTIONS(6260),
    [anon_sym___cdecl] = ACTIONS(6260),
    [anon_sym___clrcall] = ACTIONS(6260),
    [anon_sym___stdcall] = ACTIONS(6260),
    [anon_sym___fastcall] = ACTIONS(6260),
    [anon_sym___thiscall] = ACTIONS(6260),
    [anon_sym___vectorcall] = ACTIONS(6260),
    [anon_sym_LBRACK] = ACTIONS(6260),
    [anon_sym_static] = ACTIONS(6260),
    [anon_sym_EQ] = ACTIONS(6258),
    [anon_sym_register] = ACTIONS(6260),
    [anon_sym_inline] = ACTIONS(6260),
    [anon_sym___inline] = ACTIONS(6260),
    [anon_sym___inline__] = ACTIONS(6260),
    [anon_sym___forceinline] = ACTIONS(6260),
    [anon_sym_thread_local] = ACTIONS(6260),
    [anon_sym___thread] = ACTIONS(6260),
    [anon_sym_const] = ACTIONS(6260),
    [anon_sym_constexpr] = ACTIONS(6260),
    [anon_sym_volatile] = ACTIONS(6260),
    [anon_sym_restrict] = ACTIONS(6260),
    [anon_sym___restrict__] = ACTIONS(6260),
    [anon_sym__Atomic] = ACTIONS(6260),
    [anon_sym__Noreturn] = ACTIONS(6260),
    [anon_sym_noreturn] = ACTIONS(6260),
    [anon_sym__Nonnull] = ACTIONS(6260),
    [anon_sym_mutable] = ACTIONS(6260),
    [anon_sym_constinit] = ACTIONS(6260),
    [anon_sym_consteval] = ACTIONS(6260),
    [anon_sym___shared__] = ACTIONS(6260),
    [anon_sym___local__] = ACTIONS(6260),
    [anon_sym___constant__] = ACTIONS(6260),
    [anon_sym___managed__] = ACTIONS(6260),
    [anon_sym___grid_constant__] = ACTIONS(6260),
    [anon_sym_alignas] = ACTIONS(6260),
    [anon_sym__Alignas] = ACTIONS(6260),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6260),
    [anon_sym_decltype] = ACTIONS(6260),
    [anon_sym_template] = ACTIONS(6260),
    [anon_sym_GT2] = ACTIONS(6258),
    [anon_sym_operator] = ACTIONS(6260),
    [anon_sym___launch_bounds__] = ACTIONS(6260),
  },
  [STATE(2518)] = {
    [sym_identifier] = ACTIONS(5805),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5807),
    [anon_sym_COMMA] = ACTIONS(5807),
    [anon_sym_RPAREN] = ACTIONS(5807),
    [aux_sym_preproc_if_token2] = ACTIONS(5807),
    [aux_sym_preproc_else_token1] = ACTIONS(5807),
    [aux_sym_preproc_elif_token1] = ACTIONS(5805),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5807),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5807),
    [anon_sym_LPAREN2] = ACTIONS(5807),
    [anon_sym_DASH] = ACTIONS(5805),
    [anon_sym_PLUS] = ACTIONS(5805),
    [anon_sym_STAR] = ACTIONS(5805),
    [anon_sym_SLASH] = ACTIONS(5805),
    [anon_sym_PERCENT] = ACTIONS(5805),
    [anon_sym_PIPE_PIPE] = ACTIONS(5807),
    [anon_sym_AMP_AMP] = ACTIONS(5807),
    [anon_sym_PIPE] = ACTIONS(5805),
    [anon_sym_CARET] = ACTIONS(5805),
    [anon_sym_AMP] = ACTIONS(5805),
    [anon_sym_EQ_EQ] = ACTIONS(5807),
    [anon_sym_BANG_EQ] = ACTIONS(5807),
    [anon_sym_GT] = ACTIONS(5805),
    [anon_sym_GT_EQ] = ACTIONS(5807),
    [anon_sym_LT_EQ] = ACTIONS(5805),
    [anon_sym_LT] = ACTIONS(5805),
    [anon_sym_LT_LT] = ACTIONS(5805),
    [anon_sym_GT_GT] = ACTIONS(5805),
    [anon_sym_SEMI] = ACTIONS(5807),
    [anon_sym___attribute__] = ACTIONS(5805),
    [anon_sym___attribute] = ACTIONS(5805),
    [anon_sym_LBRACE] = ACTIONS(5807),
    [anon_sym_RBRACE] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5807),
    [anon_sym_RBRACK] = ACTIONS(5807),
    [anon_sym_EQ] = ACTIONS(5805),
    [anon_sym_COLON] = ACTIONS(5807),
    [anon_sym_QMARK] = ACTIONS(5807),
    [anon_sym_STAR_EQ] = ACTIONS(5807),
    [anon_sym_SLASH_EQ] = ACTIONS(5807),
    [anon_sym_PERCENT_EQ] = ACTIONS(5807),
    [anon_sym_PLUS_EQ] = ACTIONS(5807),
    [anon_sym_DASH_EQ] = ACTIONS(5807),
    [anon_sym_LT_LT_EQ] = ACTIONS(5807),
    [anon_sym_GT_GT_EQ] = ACTIONS(5807),
    [anon_sym_AMP_EQ] = ACTIONS(5807),
    [anon_sym_CARET_EQ] = ACTIONS(5807),
    [anon_sym_PIPE_EQ] = ACTIONS(5807),
    [anon_sym_and_eq] = ACTIONS(5805),
    [anon_sym_or_eq] = ACTIONS(5805),
    [anon_sym_xor_eq] = ACTIONS(5805),
    [anon_sym_LT_EQ_GT] = ACTIONS(5807),
    [anon_sym_or] = ACTIONS(5805),
    [anon_sym_and] = ACTIONS(5805),
    [anon_sym_bitor] = ACTIONS(5805),
    [anon_sym_xor] = ACTIONS(5805),
    [anon_sym_bitand] = ACTIONS(5805),
    [anon_sym_not_eq] = ACTIONS(5805),
    [anon_sym_DASH_DASH] = ACTIONS(5807),
    [anon_sym_PLUS_PLUS] = ACTIONS(5807),
    [anon_sym_DOT] = ACTIONS(5805),
    [anon_sym_DOT_STAR] = ACTIONS(5807),
    [anon_sym_DASH_GT] = ACTIONS(5807),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5805),
    [anon_sym_decltype] = ACTIONS(5805),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5807),
  },
  [STATE(2519)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [aux_sym_preproc_if_token2] = ACTIONS(5752),
    [aux_sym_preproc_else_token1] = ACTIONS(5752),
    [aux_sym_preproc_elif_token1] = ACTIONS(5750),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5752),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5750),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5750),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5750),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5752),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5750),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_RBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_RBRACK] = ACTIONS(5752),
    [anon_sym_EQ] = ACTIONS(5750),
    [anon_sym_COLON] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_STAR_EQ] = ACTIONS(5752),
    [anon_sym_SLASH_EQ] = ACTIONS(5752),
    [anon_sym_PERCENT_EQ] = ACTIONS(5752),
    [anon_sym_PLUS_EQ] = ACTIONS(5752),
    [anon_sym_DASH_EQ] = ACTIONS(5752),
    [anon_sym_LT_LT_EQ] = ACTIONS(5752),
    [anon_sym_GT_GT_EQ] = ACTIONS(5752),
    [anon_sym_AMP_EQ] = ACTIONS(5752),
    [anon_sym_CARET_EQ] = ACTIONS(5752),
    [anon_sym_PIPE_EQ] = ACTIONS(5752),
    [anon_sym_and_eq] = ACTIONS(5750),
    [anon_sym_or_eq] = ACTIONS(5750),
    [anon_sym_xor_eq] = ACTIONS(5750),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5750),
    [anon_sym_and] = ACTIONS(5750),
    [anon_sym_bitor] = ACTIONS(5750),
    [anon_sym_xor] = ACTIONS(5750),
    [anon_sym_bitand] = ACTIONS(5750),
    [anon_sym_not_eq] = ACTIONS(5750),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2520)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5630),
    [anon_sym_COMMA] = ACTIONS(5630),
    [anon_sym_LPAREN2] = ACTIONS(5630),
    [anon_sym_DASH] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(5628),
    [anon_sym_STAR] = ACTIONS(5630),
    [anon_sym_SLASH] = ACTIONS(5628),
    [anon_sym_PERCENT] = ACTIONS(5630),
    [anon_sym_PIPE_PIPE] = ACTIONS(5630),
    [anon_sym_AMP_AMP] = ACTIONS(5630),
    [anon_sym_PIPE] = ACTIONS(5628),
    [anon_sym_CARET] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5628),
    [anon_sym_EQ_EQ] = ACTIONS(5630),
    [anon_sym_BANG_EQ] = ACTIONS(5630),
    [anon_sym_GT] = ACTIONS(5628),
    [anon_sym_GT_EQ] = ACTIONS(5628),
    [anon_sym_LT_EQ] = ACTIONS(5628),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_LT_LT] = ACTIONS(5628),
    [anon_sym_GT_GT] = ACTIONS(5628),
    [anon_sym___extension__] = ACTIONS(5630),
    [anon_sym___global__] = ACTIONS(5630),
    [anon_sym___attribute__] = ACTIONS(5630),
    [anon_sym___attribute] = ACTIONS(5628),
    [anon_sym_LBRACE] = ACTIONS(5630),
    [anon_sym_LBRACK] = ACTIONS(5630),
    [anon_sym_const] = ACTIONS(5628),
    [anon_sym_constexpr] = ACTIONS(5630),
    [anon_sym_volatile] = ACTIONS(5630),
    [anon_sym_restrict] = ACTIONS(5630),
    [anon_sym___restrict__] = ACTIONS(5630),
    [anon_sym__Atomic] = ACTIONS(5630),
    [anon_sym__Noreturn] = ACTIONS(5630),
    [anon_sym_noreturn] = ACTIONS(5630),
    [anon_sym__Nonnull] = ACTIONS(5630),
    [anon_sym_mutable] = ACTIONS(5630),
    [anon_sym_constinit] = ACTIONS(5630),
    [anon_sym_consteval] = ACTIONS(5630),
    [anon_sym___shared__] = ACTIONS(5630),
    [anon_sym___local__] = ACTIONS(5630),
    [anon_sym___constant__] = ACTIONS(5630),
    [anon_sym___managed__] = ACTIONS(5630),
    [anon_sym___grid_constant__] = ACTIONS(5630),
    [anon_sym_alignas] = ACTIONS(5630),
    [anon_sym__Alignas] = ACTIONS(5630),
    [anon_sym_QMARK] = ACTIONS(5630),
    [anon_sym_LT_EQ_GT] = ACTIONS(5630),
    [anon_sym_or] = ACTIONS(5630),
    [anon_sym_and] = ACTIONS(5630),
    [anon_sym_bitor] = ACTIONS(5630),
    [anon_sym_xor] = ACTIONS(5630),
    [anon_sym_bitand] = ACTIONS(5630),
    [anon_sym_not_eq] = ACTIONS(5630),
    [anon_sym_DASH_DASH] = ACTIONS(5630),
    [anon_sym_PLUS_PLUS] = ACTIONS(5630),
    [anon_sym_DOT] = ACTIONS(5628),
    [anon_sym_DOT_STAR] = ACTIONS(5630),
    [anon_sym_DASH_GT] = ACTIONS(5630),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5630),
    [anon_sym_decltype] = ACTIONS(5630),
    [anon_sym_final] = ACTIONS(5630),
    [anon_sym_override] = ACTIONS(5630),
    [anon_sym_GT2] = ACTIONS(5630),
    [anon_sym_requires] = ACTIONS(5630),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5630),
  },
  [STATE(2521)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5716),
    [anon_sym_COMMA] = ACTIONS(5716),
    [anon_sym_LPAREN2] = ACTIONS(5716),
    [anon_sym_DASH] = ACTIONS(5714),
    [anon_sym_PLUS] = ACTIONS(5714),
    [anon_sym_STAR] = ACTIONS(5716),
    [anon_sym_SLASH] = ACTIONS(5714),
    [anon_sym_PERCENT] = ACTIONS(5716),
    [anon_sym_PIPE_PIPE] = ACTIONS(5716),
    [anon_sym_AMP_AMP] = ACTIONS(5716),
    [anon_sym_PIPE] = ACTIONS(5714),
    [anon_sym_CARET] = ACTIONS(5716),
    [anon_sym_AMP] = ACTIONS(5714),
    [anon_sym_EQ_EQ] = ACTIONS(5716),
    [anon_sym_BANG_EQ] = ACTIONS(5716),
    [anon_sym_GT] = ACTIONS(5714),
    [anon_sym_GT_EQ] = ACTIONS(5714),
    [anon_sym_LT_EQ] = ACTIONS(5714),
    [anon_sym_LT] = ACTIONS(5714),
    [anon_sym_LT_LT] = ACTIONS(5714),
    [anon_sym_GT_GT] = ACTIONS(5714),
    [anon_sym___extension__] = ACTIONS(5716),
    [anon_sym___global__] = ACTIONS(5716),
    [anon_sym___attribute__] = ACTIONS(5716),
    [anon_sym___attribute] = ACTIONS(5714),
    [anon_sym_LBRACE] = ACTIONS(5716),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_constexpr] = ACTIONS(5716),
    [anon_sym_volatile] = ACTIONS(5716),
    [anon_sym_restrict] = ACTIONS(5716),
    [anon_sym___restrict__] = ACTIONS(5716),
    [anon_sym__Atomic] = ACTIONS(5716),
    [anon_sym__Noreturn] = ACTIONS(5716),
    [anon_sym_noreturn] = ACTIONS(5716),
    [anon_sym__Nonnull] = ACTIONS(5716),
    [anon_sym_mutable] = ACTIONS(5716),
    [anon_sym_constinit] = ACTIONS(5716),
    [anon_sym_consteval] = ACTIONS(5716),
    [anon_sym___shared__] = ACTIONS(5716),
    [anon_sym___local__] = ACTIONS(5716),
    [anon_sym___constant__] = ACTIONS(5716),
    [anon_sym___managed__] = ACTIONS(5716),
    [anon_sym___grid_constant__] = ACTIONS(5716),
    [anon_sym_alignas] = ACTIONS(5716),
    [anon_sym__Alignas] = ACTIONS(5716),
    [anon_sym_QMARK] = ACTIONS(5716),
    [anon_sym_LT_EQ_GT] = ACTIONS(5716),
    [anon_sym_or] = ACTIONS(5716),
    [anon_sym_and] = ACTIONS(5716),
    [anon_sym_bitor] = ACTIONS(5716),
    [anon_sym_xor] = ACTIONS(5716),
    [anon_sym_bitand] = ACTIONS(5716),
    [anon_sym_not_eq] = ACTIONS(5716),
    [anon_sym_DASH_DASH] = ACTIONS(5716),
    [anon_sym_PLUS_PLUS] = ACTIONS(5716),
    [anon_sym_DOT] = ACTIONS(5714),
    [anon_sym_DOT_STAR] = ACTIONS(5716),
    [anon_sym_DASH_GT] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5716),
    [anon_sym_decltype] = ACTIONS(5716),
    [anon_sym_final] = ACTIONS(5716),
    [anon_sym_override] = ACTIONS(5716),
    [anon_sym_GT2] = ACTIONS(5716),
    [anon_sym_requires] = ACTIONS(5716),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5716),
  },
  [STATE(2522)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [aux_sym_preproc_if_token2] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5684),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5686),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5684),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5684),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_EQ] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_STAR_EQ] = ACTIONS(5686),
    [anon_sym_SLASH_EQ] = ACTIONS(5686),
    [anon_sym_PERCENT_EQ] = ACTIONS(5686),
    [anon_sym_PLUS_EQ] = ACTIONS(5686),
    [anon_sym_DASH_EQ] = ACTIONS(5686),
    [anon_sym_LT_LT_EQ] = ACTIONS(5686),
    [anon_sym_GT_GT_EQ] = ACTIONS(5686),
    [anon_sym_AMP_EQ] = ACTIONS(5686),
    [anon_sym_CARET_EQ] = ACTIONS(5686),
    [anon_sym_PIPE_EQ] = ACTIONS(5686),
    [anon_sym_and_eq] = ACTIONS(5684),
    [anon_sym_or_eq] = ACTIONS(5684),
    [anon_sym_xor_eq] = ACTIONS(5684),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_and] = ACTIONS(5684),
    [anon_sym_bitor] = ACTIONS(5684),
    [anon_sym_xor] = ACTIONS(5684),
    [anon_sym_bitand] = ACTIONS(5684),
    [anon_sym_not_eq] = ACTIONS(5684),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2523)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5799),
    [anon_sym_COMMA] = ACTIONS(5799),
    [anon_sym_LPAREN2] = ACTIONS(5799),
    [anon_sym_DASH] = ACTIONS(5797),
    [anon_sym_PLUS] = ACTIONS(5797),
    [anon_sym_STAR] = ACTIONS(5799),
    [anon_sym_SLASH] = ACTIONS(5797),
    [anon_sym_PERCENT] = ACTIONS(5799),
    [anon_sym_PIPE_PIPE] = ACTIONS(5799),
    [anon_sym_AMP_AMP] = ACTIONS(5799),
    [anon_sym_PIPE] = ACTIONS(5797),
    [anon_sym_CARET] = ACTIONS(5799),
    [anon_sym_AMP] = ACTIONS(5797),
    [anon_sym_EQ_EQ] = ACTIONS(5799),
    [anon_sym_BANG_EQ] = ACTIONS(5799),
    [anon_sym_GT] = ACTIONS(5797),
    [anon_sym_GT_EQ] = ACTIONS(5797),
    [anon_sym_LT_EQ] = ACTIONS(5797),
    [anon_sym_LT] = ACTIONS(5797),
    [anon_sym_LT_LT] = ACTIONS(5797),
    [anon_sym_GT_GT] = ACTIONS(5797),
    [anon_sym___extension__] = ACTIONS(5799),
    [anon_sym___global__] = ACTIONS(5799),
    [anon_sym___attribute__] = ACTIONS(5799),
    [anon_sym___attribute] = ACTIONS(5797),
    [anon_sym_LBRACE] = ACTIONS(5799),
    [anon_sym_LBRACK] = ACTIONS(5799),
    [anon_sym_const] = ACTIONS(5797),
    [anon_sym_constexpr] = ACTIONS(5799),
    [anon_sym_volatile] = ACTIONS(5799),
    [anon_sym_restrict] = ACTIONS(5799),
    [anon_sym___restrict__] = ACTIONS(5799),
    [anon_sym__Atomic] = ACTIONS(5799),
    [anon_sym__Noreturn] = ACTIONS(5799),
    [anon_sym_noreturn] = ACTIONS(5799),
    [anon_sym__Nonnull] = ACTIONS(5799),
    [anon_sym_mutable] = ACTIONS(5799),
    [anon_sym_constinit] = ACTIONS(5799),
    [anon_sym_consteval] = ACTIONS(5799),
    [anon_sym___shared__] = ACTIONS(5799),
    [anon_sym___local__] = ACTIONS(5799),
    [anon_sym___constant__] = ACTIONS(5799),
    [anon_sym___managed__] = ACTIONS(5799),
    [anon_sym___grid_constant__] = ACTIONS(5799),
    [anon_sym_alignas] = ACTIONS(5799),
    [anon_sym__Alignas] = ACTIONS(5799),
    [anon_sym_QMARK] = ACTIONS(5799),
    [anon_sym_LT_EQ_GT] = ACTIONS(5799),
    [anon_sym_or] = ACTIONS(5799),
    [anon_sym_and] = ACTIONS(5799),
    [anon_sym_bitor] = ACTIONS(5799),
    [anon_sym_xor] = ACTIONS(5799),
    [anon_sym_bitand] = ACTIONS(5799),
    [anon_sym_not_eq] = ACTIONS(5799),
    [anon_sym_DASH_DASH] = ACTIONS(5799),
    [anon_sym_PLUS_PLUS] = ACTIONS(5799),
    [anon_sym_DOT] = ACTIONS(5797),
    [anon_sym_DOT_STAR] = ACTIONS(5799),
    [anon_sym_DASH_GT] = ACTIONS(5799),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5799),
    [anon_sym_decltype] = ACTIONS(5799),
    [anon_sym_final] = ACTIONS(5799),
    [anon_sym_override] = ACTIONS(5799),
    [anon_sym_GT2] = ACTIONS(5799),
    [anon_sym_requires] = ACTIONS(5799),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5799),
  },
  [STATE(2524)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5811),
    [anon_sym_COMMA] = ACTIONS(5811),
    [anon_sym_LPAREN2] = ACTIONS(5811),
    [anon_sym_DASH] = ACTIONS(5809),
    [anon_sym_PLUS] = ACTIONS(5809),
    [anon_sym_STAR] = ACTIONS(5811),
    [anon_sym_SLASH] = ACTIONS(5809),
    [anon_sym_PERCENT] = ACTIONS(5811),
    [anon_sym_PIPE_PIPE] = ACTIONS(5811),
    [anon_sym_AMP_AMP] = ACTIONS(5811),
    [anon_sym_PIPE] = ACTIONS(5809),
    [anon_sym_CARET] = ACTIONS(5811),
    [anon_sym_AMP] = ACTIONS(5809),
    [anon_sym_EQ_EQ] = ACTIONS(5811),
    [anon_sym_BANG_EQ] = ACTIONS(5811),
    [anon_sym_GT] = ACTIONS(5809),
    [anon_sym_GT_EQ] = ACTIONS(5809),
    [anon_sym_LT_EQ] = ACTIONS(5809),
    [anon_sym_LT] = ACTIONS(5809),
    [anon_sym_LT_LT] = ACTIONS(5809),
    [anon_sym_GT_GT] = ACTIONS(5809),
    [anon_sym___extension__] = ACTIONS(5811),
    [anon_sym___global__] = ACTIONS(5811),
    [anon_sym___attribute__] = ACTIONS(5811),
    [anon_sym___attribute] = ACTIONS(5809),
    [anon_sym_LBRACE] = ACTIONS(5811),
    [anon_sym_LBRACK] = ACTIONS(5811),
    [anon_sym_const] = ACTIONS(5809),
    [anon_sym_constexpr] = ACTIONS(5811),
    [anon_sym_volatile] = ACTIONS(5811),
    [anon_sym_restrict] = ACTIONS(5811),
    [anon_sym___restrict__] = ACTIONS(5811),
    [anon_sym__Atomic] = ACTIONS(5811),
    [anon_sym__Noreturn] = ACTIONS(5811),
    [anon_sym_noreturn] = ACTIONS(5811),
    [anon_sym__Nonnull] = ACTIONS(5811),
    [anon_sym_mutable] = ACTIONS(5811),
    [anon_sym_constinit] = ACTIONS(5811),
    [anon_sym_consteval] = ACTIONS(5811),
    [anon_sym___shared__] = ACTIONS(5811),
    [anon_sym___local__] = ACTIONS(5811),
    [anon_sym___constant__] = ACTIONS(5811),
    [anon_sym___managed__] = ACTIONS(5811),
    [anon_sym___grid_constant__] = ACTIONS(5811),
    [anon_sym_alignas] = ACTIONS(5811),
    [anon_sym__Alignas] = ACTIONS(5811),
    [anon_sym_QMARK] = ACTIONS(5811),
    [anon_sym_LT_EQ_GT] = ACTIONS(5811),
    [anon_sym_or] = ACTIONS(5811),
    [anon_sym_and] = ACTIONS(5811),
    [anon_sym_bitor] = ACTIONS(5811),
    [anon_sym_xor] = ACTIONS(5811),
    [anon_sym_bitand] = ACTIONS(5811),
    [anon_sym_not_eq] = ACTIONS(5811),
    [anon_sym_DASH_DASH] = ACTIONS(5811),
    [anon_sym_PLUS_PLUS] = ACTIONS(5811),
    [anon_sym_DOT] = ACTIONS(5809),
    [anon_sym_DOT_STAR] = ACTIONS(5811),
    [anon_sym_DASH_GT] = ACTIONS(5811),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5811),
    [anon_sym_decltype] = ACTIONS(5811),
    [anon_sym_final] = ACTIONS(5811),
    [anon_sym_override] = ACTIONS(5811),
    [anon_sym_GT2] = ACTIONS(5811),
    [anon_sym_requires] = ACTIONS(5811),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5811),
  },
  [STATE(2525)] = {
    [sym_template_argument_list] = STATE(2672),
    [sym_identifier] = ACTIONS(4521),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4514),
    [anon_sym_COMMA] = ACTIONS(4514),
    [anon_sym_RPAREN] = ACTIONS(4514),
    [aux_sym_preproc_if_token2] = ACTIONS(4514),
    [aux_sym_preproc_else_token1] = ACTIONS(4514),
    [aux_sym_preproc_elif_token1] = ACTIONS(4521),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4514),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4514),
    [anon_sym_LPAREN2] = ACTIONS(4514),
    [anon_sym_DASH] = ACTIONS(4521),
    [anon_sym_PLUS] = ACTIONS(4521),
    [anon_sym_STAR] = ACTIONS(4521),
    [anon_sym_SLASH] = ACTIONS(4521),
    [anon_sym_PERCENT] = ACTIONS(4521),
    [anon_sym_PIPE_PIPE] = ACTIONS(4514),
    [anon_sym_AMP_AMP] = ACTIONS(4514),
    [anon_sym_PIPE] = ACTIONS(4521),
    [anon_sym_CARET] = ACTIONS(4521),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_EQ_EQ] = ACTIONS(4514),
    [anon_sym_BANG_EQ] = ACTIONS(4514),
    [anon_sym_GT] = ACTIONS(4521),
    [anon_sym_GT_EQ] = ACTIONS(4514),
    [anon_sym_LT_EQ] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(5868),
    [anon_sym_LT_LT] = ACTIONS(4521),
    [anon_sym_GT_GT] = ACTIONS(4521),
    [anon_sym_SEMI] = ACTIONS(4514),
    [anon_sym___attribute__] = ACTIONS(4521),
    [anon_sym___attribute] = ACTIONS(4521),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_RBRACE] = ACTIONS(4514),
    [anon_sym_LBRACK] = ACTIONS(4514),
    [anon_sym_RBRACK] = ACTIONS(4514),
    [anon_sym_EQ] = ACTIONS(4521),
    [anon_sym_COLON] = ACTIONS(4521),
    [anon_sym_QMARK] = ACTIONS(4514),
    [anon_sym_STAR_EQ] = ACTIONS(4514),
    [anon_sym_SLASH_EQ] = ACTIONS(4514),
    [anon_sym_PERCENT_EQ] = ACTIONS(4514),
    [anon_sym_PLUS_EQ] = ACTIONS(4514),
    [anon_sym_DASH_EQ] = ACTIONS(4514),
    [anon_sym_LT_LT_EQ] = ACTIONS(4514),
    [anon_sym_GT_GT_EQ] = ACTIONS(4514),
    [anon_sym_AMP_EQ] = ACTIONS(4514),
    [anon_sym_CARET_EQ] = ACTIONS(4514),
    [anon_sym_PIPE_EQ] = ACTIONS(4514),
    [anon_sym_and_eq] = ACTIONS(4521),
    [anon_sym_or_eq] = ACTIONS(4521),
    [anon_sym_xor_eq] = ACTIONS(4521),
    [anon_sym_LT_EQ_GT] = ACTIONS(4514),
    [anon_sym_or] = ACTIONS(4521),
    [anon_sym_and] = ACTIONS(4521),
    [anon_sym_bitor] = ACTIONS(4521),
    [anon_sym_xor] = ACTIONS(4521),
    [anon_sym_bitand] = ACTIONS(4521),
    [anon_sym_not_eq] = ACTIONS(4521),
    [anon_sym_DASH_DASH] = ACTIONS(4514),
    [anon_sym_PLUS_PLUS] = ACTIONS(4514),
    [anon_sym_DOT] = ACTIONS(4521),
    [anon_sym_DOT_STAR] = ACTIONS(4514),
    [anon_sym_DASH_GT] = ACTIONS(4514),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4514),
  },
  [STATE(2526)] = {
    [sym_identifier] = ACTIONS(5750),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5752),
    [anon_sym_COMMA] = ACTIONS(5752),
    [anon_sym_RPAREN] = ACTIONS(5752),
    [aux_sym_preproc_if_token2] = ACTIONS(5752),
    [aux_sym_preproc_else_token1] = ACTIONS(5752),
    [aux_sym_preproc_elif_token1] = ACTIONS(5750),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5752),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5752),
    [anon_sym_LPAREN2] = ACTIONS(5752),
    [anon_sym_DASH] = ACTIONS(5750),
    [anon_sym_PLUS] = ACTIONS(5750),
    [anon_sym_STAR] = ACTIONS(5750),
    [anon_sym_SLASH] = ACTIONS(5750),
    [anon_sym_PERCENT] = ACTIONS(5750),
    [anon_sym_PIPE_PIPE] = ACTIONS(5752),
    [anon_sym_AMP_AMP] = ACTIONS(5752),
    [anon_sym_PIPE] = ACTIONS(5750),
    [anon_sym_CARET] = ACTIONS(5750),
    [anon_sym_AMP] = ACTIONS(5750),
    [anon_sym_EQ_EQ] = ACTIONS(5752),
    [anon_sym_BANG_EQ] = ACTIONS(5752),
    [anon_sym_GT] = ACTIONS(5750),
    [anon_sym_GT_EQ] = ACTIONS(5752),
    [anon_sym_LT_EQ] = ACTIONS(5750),
    [anon_sym_LT] = ACTIONS(5750),
    [anon_sym_LT_LT] = ACTIONS(5750),
    [anon_sym_GT_GT] = ACTIONS(5750),
    [anon_sym_SEMI] = ACTIONS(5752),
    [anon_sym___attribute__] = ACTIONS(5750),
    [anon_sym___attribute] = ACTIONS(5750),
    [anon_sym_LBRACE] = ACTIONS(5752),
    [anon_sym_RBRACE] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5752),
    [anon_sym_RBRACK] = ACTIONS(5752),
    [anon_sym_EQ] = ACTIONS(5750),
    [anon_sym_COLON] = ACTIONS(5752),
    [anon_sym_QMARK] = ACTIONS(5752),
    [anon_sym_STAR_EQ] = ACTIONS(5752),
    [anon_sym_SLASH_EQ] = ACTIONS(5752),
    [anon_sym_PERCENT_EQ] = ACTIONS(5752),
    [anon_sym_PLUS_EQ] = ACTIONS(5752),
    [anon_sym_DASH_EQ] = ACTIONS(5752),
    [anon_sym_LT_LT_EQ] = ACTIONS(5752),
    [anon_sym_GT_GT_EQ] = ACTIONS(5752),
    [anon_sym_AMP_EQ] = ACTIONS(5752),
    [anon_sym_CARET_EQ] = ACTIONS(5752),
    [anon_sym_PIPE_EQ] = ACTIONS(5752),
    [anon_sym_and_eq] = ACTIONS(5750),
    [anon_sym_or_eq] = ACTIONS(5750),
    [anon_sym_xor_eq] = ACTIONS(5750),
    [anon_sym_LT_EQ_GT] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5750),
    [anon_sym_and] = ACTIONS(5750),
    [anon_sym_bitor] = ACTIONS(5750),
    [anon_sym_xor] = ACTIONS(5750),
    [anon_sym_bitand] = ACTIONS(5750),
    [anon_sym_not_eq] = ACTIONS(5750),
    [anon_sym_DASH_DASH] = ACTIONS(5752),
    [anon_sym_PLUS_PLUS] = ACTIONS(5752),
    [anon_sym_DOT] = ACTIONS(5750),
    [anon_sym_DOT_STAR] = ACTIONS(5752),
    [anon_sym_DASH_GT] = ACTIONS(5752),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5750),
    [anon_sym_decltype] = ACTIONS(5750),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5752),
  },
  [STATE(2527)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5844),
    [anon_sym_COMMA] = ACTIONS(5844),
    [anon_sym_LPAREN2] = ACTIONS(5844),
    [anon_sym_DASH] = ACTIONS(5842),
    [anon_sym_PLUS] = ACTIONS(5842),
    [anon_sym_STAR] = ACTIONS(5844),
    [anon_sym_SLASH] = ACTIONS(5842),
    [anon_sym_PERCENT] = ACTIONS(5844),
    [anon_sym_PIPE_PIPE] = ACTIONS(5844),
    [anon_sym_AMP_AMP] = ACTIONS(5844),
    [anon_sym_PIPE] = ACTIONS(5842),
    [anon_sym_CARET] = ACTIONS(5844),
    [anon_sym_AMP] = ACTIONS(5842),
    [anon_sym_EQ_EQ] = ACTIONS(5844),
    [anon_sym_BANG_EQ] = ACTIONS(5844),
    [anon_sym_GT] = ACTIONS(5842),
    [anon_sym_GT_EQ] = ACTIONS(5842),
    [anon_sym_LT_EQ] = ACTIONS(5842),
    [anon_sym_LT] = ACTIONS(5842),
    [anon_sym_LT_LT] = ACTIONS(5842),
    [anon_sym_GT_GT] = ACTIONS(5842),
    [anon_sym___extension__] = ACTIONS(5844),
    [anon_sym___global__] = ACTIONS(5844),
    [anon_sym___attribute__] = ACTIONS(5844),
    [anon_sym___attribute] = ACTIONS(5842),
    [anon_sym_LBRACE] = ACTIONS(5844),
    [anon_sym_LBRACK] = ACTIONS(5844),
    [anon_sym_const] = ACTIONS(5842),
    [anon_sym_constexpr] = ACTIONS(5844),
    [anon_sym_volatile] = ACTIONS(5844),
    [anon_sym_restrict] = ACTIONS(5844),
    [anon_sym___restrict__] = ACTIONS(5844),
    [anon_sym__Atomic] = ACTIONS(5844),
    [anon_sym__Noreturn] = ACTIONS(5844),
    [anon_sym_noreturn] = ACTIONS(5844),
    [anon_sym__Nonnull] = ACTIONS(5844),
    [anon_sym_mutable] = ACTIONS(5844),
    [anon_sym_constinit] = ACTIONS(5844),
    [anon_sym_consteval] = ACTIONS(5844),
    [anon_sym___shared__] = ACTIONS(5844),
    [anon_sym___local__] = ACTIONS(5844),
    [anon_sym___constant__] = ACTIONS(5844),
    [anon_sym___managed__] = ACTIONS(5844),
    [anon_sym___grid_constant__] = ACTIONS(5844),
    [anon_sym_alignas] = ACTIONS(5844),
    [anon_sym__Alignas] = ACTIONS(5844),
    [anon_sym_QMARK] = ACTIONS(5844),
    [anon_sym_LT_EQ_GT] = ACTIONS(5844),
    [anon_sym_or] = ACTIONS(5844),
    [anon_sym_and] = ACTIONS(5844),
    [anon_sym_bitor] = ACTIONS(5844),
    [anon_sym_xor] = ACTIONS(5844),
    [anon_sym_bitand] = ACTIONS(5844),
    [anon_sym_not_eq] = ACTIONS(5844),
    [anon_sym_DASH_DASH] = ACTIONS(5844),
    [anon_sym_PLUS_PLUS] = ACTIONS(5844),
    [anon_sym_DOT] = ACTIONS(5842),
    [anon_sym_DOT_STAR] = ACTIONS(5844),
    [anon_sym_DASH_GT] = ACTIONS(5844),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5844),
    [anon_sym_decltype] = ACTIONS(5844),
    [anon_sym_final] = ACTIONS(5844),
    [anon_sym_override] = ACTIONS(5844),
    [anon_sym_GT2] = ACTIONS(5844),
    [anon_sym_requires] = ACTIONS(5844),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5844),
  },
  [STATE(2528)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5831),
    [anon_sym_COMMA] = ACTIONS(5831),
    [anon_sym_LPAREN2] = ACTIONS(5831),
    [anon_sym_DASH] = ACTIONS(5829),
    [anon_sym_PLUS] = ACTIONS(5829),
    [anon_sym_STAR] = ACTIONS(5831),
    [anon_sym_SLASH] = ACTIONS(5829),
    [anon_sym_PERCENT] = ACTIONS(5831),
    [anon_sym_PIPE_PIPE] = ACTIONS(5831),
    [anon_sym_AMP_AMP] = ACTIONS(5831),
    [anon_sym_PIPE] = ACTIONS(5829),
    [anon_sym_CARET] = ACTIONS(5831),
    [anon_sym_AMP] = ACTIONS(5829),
    [anon_sym_EQ_EQ] = ACTIONS(5831),
    [anon_sym_BANG_EQ] = ACTIONS(5831),
    [anon_sym_GT] = ACTIONS(5829),
    [anon_sym_GT_EQ] = ACTIONS(5829),
    [anon_sym_LT_EQ] = ACTIONS(5829),
    [anon_sym_LT] = ACTIONS(5829),
    [anon_sym_LT_LT] = ACTIONS(5829),
    [anon_sym_GT_GT] = ACTIONS(5829),
    [anon_sym___extension__] = ACTIONS(5831),
    [anon_sym___global__] = ACTIONS(5831),
    [anon_sym___attribute__] = ACTIONS(5831),
    [anon_sym___attribute] = ACTIONS(5829),
    [anon_sym_LBRACE] = ACTIONS(5831),
    [anon_sym_LBRACK] = ACTIONS(5831),
    [anon_sym_const] = ACTIONS(5829),
    [anon_sym_constexpr] = ACTIONS(5831),
    [anon_sym_volatile] = ACTIONS(5831),
    [anon_sym_restrict] = ACTIONS(5831),
    [anon_sym___restrict__] = ACTIONS(5831),
    [anon_sym__Atomic] = ACTIONS(5831),
    [anon_sym__Noreturn] = ACTIONS(5831),
    [anon_sym_noreturn] = ACTIONS(5831),
    [anon_sym__Nonnull] = ACTIONS(5831),
    [anon_sym_mutable] = ACTIONS(5831),
    [anon_sym_constinit] = ACTIONS(5831),
    [anon_sym_consteval] = ACTIONS(5831),
    [anon_sym___shared__] = ACTIONS(5831),
    [anon_sym___local__] = ACTIONS(5831),
    [anon_sym___constant__] = ACTIONS(5831),
    [anon_sym___managed__] = ACTIONS(5831),
    [anon_sym___grid_constant__] = ACTIONS(5831),
    [anon_sym_alignas] = ACTIONS(5831),
    [anon_sym__Alignas] = ACTIONS(5831),
    [anon_sym_QMARK] = ACTIONS(5831),
    [anon_sym_LT_EQ_GT] = ACTIONS(5831),
    [anon_sym_or] = ACTIONS(5831),
    [anon_sym_and] = ACTIONS(5831),
    [anon_sym_bitor] = ACTIONS(5831),
    [anon_sym_xor] = ACTIONS(5831),
    [anon_sym_bitand] = ACTIONS(5831),
    [anon_sym_not_eq] = ACTIONS(5831),
    [anon_sym_DASH_DASH] = ACTIONS(5831),
    [anon_sym_PLUS_PLUS] = ACTIONS(5831),
    [anon_sym_DOT] = ACTIONS(5829),
    [anon_sym_DOT_STAR] = ACTIONS(5831),
    [anon_sym_DASH_GT] = ACTIONS(5831),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5831),
    [anon_sym_decltype] = ACTIONS(5831),
    [anon_sym_final] = ACTIONS(5831),
    [anon_sym_override] = ACTIONS(5831),
    [anon_sym_GT2] = ACTIONS(5831),
    [anon_sym_requires] = ACTIONS(5831),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5831),
  },
  [STATE(2529)] = {
    [sym_identifier] = ACTIONS(5825),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5827),
    [anon_sym_COMMA] = ACTIONS(5827),
    [anon_sym_RPAREN] = ACTIONS(5827),
    [aux_sym_preproc_if_token2] = ACTIONS(5827),
    [aux_sym_preproc_else_token1] = ACTIONS(5827),
    [aux_sym_preproc_elif_token1] = ACTIONS(5825),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5827),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5827),
    [anon_sym_LPAREN2] = ACTIONS(5827),
    [anon_sym_DASH] = ACTIONS(5825),
    [anon_sym_PLUS] = ACTIONS(5825),
    [anon_sym_STAR] = ACTIONS(5825),
    [anon_sym_SLASH] = ACTIONS(5825),
    [anon_sym_PERCENT] = ACTIONS(5825),
    [anon_sym_PIPE_PIPE] = ACTIONS(5827),
    [anon_sym_AMP_AMP] = ACTIONS(5827),
    [anon_sym_PIPE] = ACTIONS(5825),
    [anon_sym_CARET] = ACTIONS(5825),
    [anon_sym_AMP] = ACTIONS(5825),
    [anon_sym_EQ_EQ] = ACTIONS(5827),
    [anon_sym_BANG_EQ] = ACTIONS(5827),
    [anon_sym_GT] = ACTIONS(5825),
    [anon_sym_GT_EQ] = ACTIONS(5827),
    [anon_sym_LT_EQ] = ACTIONS(5825),
    [anon_sym_LT] = ACTIONS(5825),
    [anon_sym_LT_LT] = ACTIONS(5825),
    [anon_sym_GT_GT] = ACTIONS(5825),
    [anon_sym_SEMI] = ACTIONS(5827),
    [anon_sym___attribute__] = ACTIONS(5825),
    [anon_sym___attribute] = ACTIONS(5825),
    [anon_sym_LBRACE] = ACTIONS(5827),
    [anon_sym_RBRACE] = ACTIONS(5827),
    [anon_sym_LBRACK] = ACTIONS(5827),
    [anon_sym_RBRACK] = ACTIONS(5827),
    [anon_sym_EQ] = ACTIONS(5825),
    [anon_sym_COLON] = ACTIONS(5827),
    [anon_sym_QMARK] = ACTIONS(5827),
    [anon_sym_STAR_EQ] = ACTIONS(5827),
    [anon_sym_SLASH_EQ] = ACTIONS(5827),
    [anon_sym_PERCENT_EQ] = ACTIONS(5827),
    [anon_sym_PLUS_EQ] = ACTIONS(5827),
    [anon_sym_DASH_EQ] = ACTIONS(5827),
    [anon_sym_LT_LT_EQ] = ACTIONS(5827),
    [anon_sym_GT_GT_EQ] = ACTIONS(5827),
    [anon_sym_AMP_EQ] = ACTIONS(5827),
    [anon_sym_CARET_EQ] = ACTIONS(5827),
    [anon_sym_PIPE_EQ] = ACTIONS(5827),
    [anon_sym_and_eq] = ACTIONS(5825),
    [anon_sym_or_eq] = ACTIONS(5825),
    [anon_sym_xor_eq] = ACTIONS(5825),
    [anon_sym_LT_EQ_GT] = ACTIONS(5827),
    [anon_sym_or] = ACTIONS(5825),
    [anon_sym_and] = ACTIONS(5825),
    [anon_sym_bitor] = ACTIONS(5825),
    [anon_sym_xor] = ACTIONS(5825),
    [anon_sym_bitand] = ACTIONS(5825),
    [anon_sym_not_eq] = ACTIONS(5825),
    [anon_sym_DASH_DASH] = ACTIONS(5827),
    [anon_sym_PLUS_PLUS] = ACTIONS(5827),
    [anon_sym_DOT] = ACTIONS(5825),
    [anon_sym_DOT_STAR] = ACTIONS(5827),
    [anon_sym_DASH_GT] = ACTIONS(5827),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5825),
    [anon_sym_decltype] = ACTIONS(5825),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5827),
  },
  [STATE(2530)] = {
    [sym_identifier] = ACTIONS(5829),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5831),
    [anon_sym_COMMA] = ACTIONS(5831),
    [anon_sym_RPAREN] = ACTIONS(5831),
    [aux_sym_preproc_if_token2] = ACTIONS(5831),
    [aux_sym_preproc_else_token1] = ACTIONS(5831),
    [aux_sym_preproc_elif_token1] = ACTIONS(5829),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5831),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5831),
    [anon_sym_LPAREN2] = ACTIONS(5831),
    [anon_sym_DASH] = ACTIONS(5829),
    [anon_sym_PLUS] = ACTIONS(5829),
    [anon_sym_STAR] = ACTIONS(5829),
    [anon_sym_SLASH] = ACTIONS(5829),
    [anon_sym_PERCENT] = ACTIONS(5829),
    [anon_sym_PIPE_PIPE] = ACTIONS(5831),
    [anon_sym_AMP_AMP] = ACTIONS(5831),
    [anon_sym_PIPE] = ACTIONS(5829),
    [anon_sym_CARET] = ACTIONS(5829),
    [anon_sym_AMP] = ACTIONS(5829),
    [anon_sym_EQ_EQ] = ACTIONS(5831),
    [anon_sym_BANG_EQ] = ACTIONS(5831),
    [anon_sym_GT] = ACTIONS(5829),
    [anon_sym_GT_EQ] = ACTIONS(5831),
    [anon_sym_LT_EQ] = ACTIONS(5829),
    [anon_sym_LT] = ACTIONS(5829),
    [anon_sym_LT_LT] = ACTIONS(5829),
    [anon_sym_GT_GT] = ACTIONS(5829),
    [anon_sym_SEMI] = ACTIONS(5831),
    [anon_sym___attribute__] = ACTIONS(5829),
    [anon_sym___attribute] = ACTIONS(5829),
    [anon_sym_LBRACE] = ACTIONS(5831),
    [anon_sym_RBRACE] = ACTIONS(5831),
    [anon_sym_LBRACK] = ACTIONS(5831),
    [anon_sym_RBRACK] = ACTIONS(5831),
    [anon_sym_EQ] = ACTIONS(5829),
    [anon_sym_COLON] = ACTIONS(5831),
    [anon_sym_QMARK] = ACTIONS(5831),
    [anon_sym_STAR_EQ] = ACTIONS(5831),
    [anon_sym_SLASH_EQ] = ACTIONS(5831),
    [anon_sym_PERCENT_EQ] = ACTIONS(5831),
    [anon_sym_PLUS_EQ] = ACTIONS(5831),
    [anon_sym_DASH_EQ] = ACTIONS(5831),
    [anon_sym_LT_LT_EQ] = ACTIONS(5831),
    [anon_sym_GT_GT_EQ] = ACTIONS(5831),
    [anon_sym_AMP_EQ] = ACTIONS(5831),
    [anon_sym_CARET_EQ] = ACTIONS(5831),
    [anon_sym_PIPE_EQ] = ACTIONS(5831),
    [anon_sym_and_eq] = ACTIONS(5829),
    [anon_sym_or_eq] = ACTIONS(5829),
    [anon_sym_xor_eq] = ACTIONS(5829),
    [anon_sym_LT_EQ_GT] = ACTIONS(5831),
    [anon_sym_or] = ACTIONS(5829),
    [anon_sym_and] = ACTIONS(5829),
    [anon_sym_bitor] = ACTIONS(5829),
    [anon_sym_xor] = ACTIONS(5829),
    [anon_sym_bitand] = ACTIONS(5829),
    [anon_sym_not_eq] = ACTIONS(5829),
    [anon_sym_DASH_DASH] = ACTIONS(5831),
    [anon_sym_PLUS_PLUS] = ACTIONS(5831),
    [anon_sym_DOT] = ACTIONS(5829),
    [anon_sym_DOT_STAR] = ACTIONS(5831),
    [anon_sym_DASH_GT] = ACTIONS(5831),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5829),
    [anon_sym_decltype] = ACTIONS(5829),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5831),
  },
  [STATE(2531)] = {
    [sym_identifier] = ACTIONS(5778),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5780),
    [anon_sym_COMMA] = ACTIONS(5780),
    [anon_sym_RPAREN] = ACTIONS(5780),
    [aux_sym_preproc_if_token2] = ACTIONS(5780),
    [aux_sym_preproc_else_token1] = ACTIONS(5780),
    [aux_sym_preproc_elif_token1] = ACTIONS(5778),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5780),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5780),
    [anon_sym_LPAREN2] = ACTIONS(5780),
    [anon_sym_DASH] = ACTIONS(5778),
    [anon_sym_PLUS] = ACTIONS(5778),
    [anon_sym_STAR] = ACTIONS(5778),
    [anon_sym_SLASH] = ACTIONS(5778),
    [anon_sym_PERCENT] = ACTIONS(5778),
    [anon_sym_PIPE_PIPE] = ACTIONS(5780),
    [anon_sym_AMP_AMP] = ACTIONS(5780),
    [anon_sym_PIPE] = ACTIONS(5778),
    [anon_sym_CARET] = ACTIONS(5778),
    [anon_sym_AMP] = ACTIONS(5778),
    [anon_sym_EQ_EQ] = ACTIONS(5780),
    [anon_sym_BANG_EQ] = ACTIONS(5780),
    [anon_sym_GT] = ACTIONS(5778),
    [anon_sym_GT_EQ] = ACTIONS(5780),
    [anon_sym_LT_EQ] = ACTIONS(5778),
    [anon_sym_LT] = ACTIONS(5778),
    [anon_sym_LT_LT] = ACTIONS(5778),
    [anon_sym_GT_GT] = ACTIONS(5778),
    [anon_sym_SEMI] = ACTIONS(5780),
    [anon_sym___attribute__] = ACTIONS(5778),
    [anon_sym___attribute] = ACTIONS(5778),
    [anon_sym_LBRACE] = ACTIONS(5780),
    [anon_sym_RBRACE] = ACTIONS(5780),
    [anon_sym_LBRACK] = ACTIONS(5780),
    [anon_sym_RBRACK] = ACTIONS(5780),
    [anon_sym_EQ] = ACTIONS(5778),
    [anon_sym_COLON] = ACTIONS(5780),
    [anon_sym_QMARK] = ACTIONS(5780),
    [anon_sym_STAR_EQ] = ACTIONS(5780),
    [anon_sym_SLASH_EQ] = ACTIONS(5780),
    [anon_sym_PERCENT_EQ] = ACTIONS(5780),
    [anon_sym_PLUS_EQ] = ACTIONS(5780),
    [anon_sym_DASH_EQ] = ACTIONS(5780),
    [anon_sym_LT_LT_EQ] = ACTIONS(5780),
    [anon_sym_GT_GT_EQ] = ACTIONS(5780),
    [anon_sym_AMP_EQ] = ACTIONS(5780),
    [anon_sym_CARET_EQ] = ACTIONS(5780),
    [anon_sym_PIPE_EQ] = ACTIONS(5780),
    [anon_sym_and_eq] = ACTIONS(5778),
    [anon_sym_or_eq] = ACTIONS(5778),
    [anon_sym_xor_eq] = ACTIONS(5778),
    [anon_sym_LT_EQ_GT] = ACTIONS(5780),
    [anon_sym_or] = ACTIONS(5778),
    [anon_sym_and] = ACTIONS(5778),
    [anon_sym_bitor] = ACTIONS(5778),
    [anon_sym_xor] = ACTIONS(5778),
    [anon_sym_bitand] = ACTIONS(5778),
    [anon_sym_not_eq] = ACTIONS(5778),
    [anon_sym_DASH_DASH] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5780),
    [anon_sym_DOT] = ACTIONS(5778),
    [anon_sym_DOT_STAR] = ACTIONS(5780),
    [anon_sym_DASH_GT] = ACTIONS(5780),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5778),
    [anon_sym_decltype] = ACTIONS(5778),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5780),
  },
  [STATE(2532)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6169),
    [anon_sym_COMMA] = ACTIONS(6169),
    [anon_sym_RPAREN] = ACTIONS(6169),
    [anon_sym_LPAREN2] = ACTIONS(6169),
    [anon_sym_DASH] = ACTIONS(6167),
    [anon_sym_PLUS] = ACTIONS(6167),
    [anon_sym_STAR] = ACTIONS(6167),
    [anon_sym_SLASH] = ACTIONS(6167),
    [anon_sym_PERCENT] = ACTIONS(6167),
    [anon_sym_PIPE_PIPE] = ACTIONS(6169),
    [anon_sym_AMP_AMP] = ACTIONS(6169),
    [anon_sym_PIPE] = ACTIONS(6167),
    [anon_sym_CARET] = ACTIONS(6167),
    [anon_sym_AMP] = ACTIONS(6167),
    [anon_sym_EQ_EQ] = ACTIONS(6169),
    [anon_sym_BANG_EQ] = ACTIONS(6169),
    [anon_sym_GT] = ACTIONS(6167),
    [anon_sym_GT_EQ] = ACTIONS(6169),
    [anon_sym_LT_EQ] = ACTIONS(6167),
    [anon_sym_LT] = ACTIONS(6167),
    [anon_sym_LT_LT] = ACTIONS(6167),
    [anon_sym_GT_GT] = ACTIONS(6167),
    [anon_sym_SEMI] = ACTIONS(6169),
    [anon_sym_RBRACE] = ACTIONS(6169),
    [anon_sym_LBRACK] = ACTIONS(6169),
    [anon_sym_RBRACK] = ACTIONS(6169),
    [anon_sym_EQ] = ACTIONS(6167),
    [anon_sym_COLON] = ACTIONS(6169),
    [anon_sym_QMARK] = ACTIONS(6169),
    [anon_sym_STAR_EQ] = ACTIONS(6169),
    [anon_sym_SLASH_EQ] = ACTIONS(6169),
    [anon_sym_PERCENT_EQ] = ACTIONS(6169),
    [anon_sym_PLUS_EQ] = ACTIONS(6169),
    [anon_sym_DASH_EQ] = ACTIONS(6169),
    [anon_sym_LT_LT_EQ] = ACTIONS(6169),
    [anon_sym_GT_GT_EQ] = ACTIONS(6169),
    [anon_sym_AMP_EQ] = ACTIONS(6169),
    [anon_sym_CARET_EQ] = ACTIONS(6169),
    [anon_sym_PIPE_EQ] = ACTIONS(6169),
    [anon_sym_and_eq] = ACTIONS(6167),
    [anon_sym_or_eq] = ACTIONS(6167),
    [anon_sym_xor_eq] = ACTIONS(6167),
    [anon_sym_LT_EQ_GT] = ACTIONS(6169),
    [anon_sym_or] = ACTIONS(6167),
    [anon_sym_and] = ACTIONS(6167),
    [anon_sym_bitor] = ACTIONS(6167),
    [anon_sym_xor] = ACTIONS(6167),
    [anon_sym_bitand] = ACTIONS(6167),
    [anon_sym_not_eq] = ACTIONS(6167),
    [anon_sym_DASH_DASH] = ACTIONS(6169),
    [anon_sym_PLUS_PLUS] = ACTIONS(6169),
    [anon_sym_DOT] = ACTIONS(6167),
    [anon_sym_DOT_STAR] = ACTIONS(6169),
    [anon_sym_DASH_GT] = ACTIONS(6169),
    [anon_sym_L_DQUOTE] = ACTIONS(6169),
    [anon_sym_u_DQUOTE] = ACTIONS(6169),
    [anon_sym_U_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8_DQUOTE] = ACTIONS(6169),
    [anon_sym_DQUOTE] = ACTIONS(6169),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6169),
    [anon_sym_LR_DQUOTE] = ACTIONS(6169),
    [anon_sym_uR_DQUOTE] = ACTIONS(6169),
    [anon_sym_UR_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6169),
    [sym_literal_suffix] = ACTIONS(6167),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6169),
  },
  [STATE(2533)] = {
    [sym_string_literal] = STATE(2533),
    [sym_raw_string_literal] = STATE(2533),
    [aux_sym_concatenated_string_repeat1] = STATE(2533),
    [sym_identifier] = ACTIONS(6542),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5882),
    [anon_sym_COMMA] = ACTIONS(5882),
    [anon_sym_LPAREN2] = ACTIONS(5882),
    [anon_sym_DASH] = ACTIONS(5884),
    [anon_sym_PLUS] = ACTIONS(5884),
    [anon_sym_STAR] = ACTIONS(5884),
    [anon_sym_SLASH] = ACTIONS(5884),
    [anon_sym_PERCENT] = ACTIONS(5884),
    [anon_sym_PIPE_PIPE] = ACTIONS(5882),
    [anon_sym_AMP_AMP] = ACTIONS(5882),
    [anon_sym_PIPE] = ACTIONS(5884),
    [anon_sym_CARET] = ACTIONS(5884),
    [anon_sym_AMP] = ACTIONS(5884),
    [anon_sym_EQ_EQ] = ACTIONS(5882),
    [anon_sym_BANG_EQ] = ACTIONS(5882),
    [anon_sym_GT] = ACTIONS(5884),
    [anon_sym_GT_EQ] = ACTIONS(5882),
    [anon_sym_LT_EQ] = ACTIONS(5884),
    [anon_sym_LT] = ACTIONS(5884),
    [anon_sym_LT_LT] = ACTIONS(5884),
    [anon_sym_GT_GT] = ACTIONS(5884),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_EQ] = ACTIONS(5884),
    [anon_sym_QMARK] = ACTIONS(5882),
    [anon_sym_STAR_EQ] = ACTIONS(5882),
    [anon_sym_SLASH_EQ] = ACTIONS(5882),
    [anon_sym_PERCENT_EQ] = ACTIONS(5882),
    [anon_sym_PLUS_EQ] = ACTIONS(5882),
    [anon_sym_DASH_EQ] = ACTIONS(5882),
    [anon_sym_LT_LT_EQ] = ACTIONS(5882),
    [anon_sym_GT_GT_EQ] = ACTIONS(5882),
    [anon_sym_AMP_EQ] = ACTIONS(5882),
    [anon_sym_CARET_EQ] = ACTIONS(5882),
    [anon_sym_PIPE_EQ] = ACTIONS(5882),
    [anon_sym_and_eq] = ACTIONS(5884),
    [anon_sym_or_eq] = ACTIONS(5884),
    [anon_sym_xor_eq] = ACTIONS(5884),
    [anon_sym_LT_EQ_GT] = ACTIONS(5882),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_bitor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_bitand] = ACTIONS(5884),
    [anon_sym_not_eq] = ACTIONS(5884),
    [anon_sym_DASH_DASH] = ACTIONS(5882),
    [anon_sym_PLUS_PLUS] = ACTIONS(5882),
    [anon_sym_DOT] = ACTIONS(5884),
    [anon_sym_DOT_STAR] = ACTIONS(5882),
    [anon_sym_DASH_GT] = ACTIONS(5882),
    [anon_sym_L_DQUOTE] = ACTIONS(6545),
    [anon_sym_u_DQUOTE] = ACTIONS(6545),
    [anon_sym_U_DQUOTE] = ACTIONS(6545),
    [anon_sym_u8_DQUOTE] = ACTIONS(6545),
    [anon_sym_DQUOTE] = ACTIONS(6545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6548),
    [anon_sym_LR_DQUOTE] = ACTIONS(6548),
    [anon_sym_uR_DQUOTE] = ACTIONS(6548),
    [anon_sym_UR_DQUOTE] = ACTIONS(6548),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6548),
    [sym_literal_suffix] = ACTIONS(5884),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5882),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(5882),
  },
  [STATE(2534)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_DASH] = ACTIONS(5770),
    [anon_sym_PLUS] = ACTIONS(5770),
    [anon_sym_STAR] = ACTIONS(5772),
    [anon_sym_SLASH] = ACTIONS(5770),
    [anon_sym_PERCENT] = ACTIONS(5772),
    [anon_sym_PIPE_PIPE] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_PIPE] = ACTIONS(5770),
    [anon_sym_CARET] = ACTIONS(5772),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_EQ_EQ] = ACTIONS(5772),
    [anon_sym_BANG_EQ] = ACTIONS(5772),
    [anon_sym_GT] = ACTIONS(5770),
    [anon_sym_GT_EQ] = ACTIONS(5770),
    [anon_sym_LT_EQ] = ACTIONS(5770),
    [anon_sym_LT] = ACTIONS(5770),
    [anon_sym_LT_LT] = ACTIONS(5770),
    [anon_sym_GT_GT] = ACTIONS(5770),
    [anon_sym___extension__] = ACTIONS(5772),
    [anon_sym___global__] = ACTIONS(5772),
    [anon_sym___attribute__] = ACTIONS(5772),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_constexpr] = ACTIONS(5772),
    [anon_sym_volatile] = ACTIONS(5772),
    [anon_sym_restrict] = ACTIONS(5772),
    [anon_sym___restrict__] = ACTIONS(5772),
    [anon_sym__Atomic] = ACTIONS(5772),
    [anon_sym__Noreturn] = ACTIONS(5772),
    [anon_sym_noreturn] = ACTIONS(5772),
    [anon_sym__Nonnull] = ACTIONS(5772),
    [anon_sym_mutable] = ACTIONS(5772),
    [anon_sym_constinit] = ACTIONS(5772),
    [anon_sym_consteval] = ACTIONS(5772),
    [anon_sym___shared__] = ACTIONS(5772),
    [anon_sym___local__] = ACTIONS(5772),
    [anon_sym___constant__] = ACTIONS(5772),
    [anon_sym___managed__] = ACTIONS(5772),
    [anon_sym___grid_constant__] = ACTIONS(5772),
    [anon_sym_alignas] = ACTIONS(5772),
    [anon_sym__Alignas] = ACTIONS(5772),
    [anon_sym_QMARK] = ACTIONS(5772),
    [anon_sym_LT_EQ_GT] = ACTIONS(5772),
    [anon_sym_or] = ACTIONS(5772),
    [anon_sym_and] = ACTIONS(5772),
    [anon_sym_bitor] = ACTIONS(5772),
    [anon_sym_xor] = ACTIONS(5772),
    [anon_sym_bitand] = ACTIONS(5772),
    [anon_sym_not_eq] = ACTIONS(5772),
    [anon_sym_DASH_DASH] = ACTIONS(5772),
    [anon_sym_PLUS_PLUS] = ACTIONS(5772),
    [anon_sym_DOT] = ACTIONS(5770),
    [anon_sym_DOT_STAR] = ACTIONS(5772),
    [anon_sym_DASH_GT] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5772),
    [anon_sym_decltype] = ACTIONS(5772),
    [anon_sym_final] = ACTIONS(5772),
    [anon_sym_override] = ACTIONS(5772),
    [anon_sym_GT2] = ACTIONS(5772),
    [anon_sym_requires] = ACTIONS(5772),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5772),
  },
  [STATE(2535)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5776),
    [anon_sym_COMMA] = ACTIONS(5776),
    [anon_sym_LPAREN2] = ACTIONS(5776),
    [anon_sym_DASH] = ACTIONS(5774),
    [anon_sym_PLUS] = ACTIONS(5774),
    [anon_sym_STAR] = ACTIONS(5776),
    [anon_sym_SLASH] = ACTIONS(5774),
    [anon_sym_PERCENT] = ACTIONS(5776),
    [anon_sym_PIPE_PIPE] = ACTIONS(5776),
    [anon_sym_AMP_AMP] = ACTIONS(5776),
    [anon_sym_PIPE] = ACTIONS(5774),
    [anon_sym_CARET] = ACTIONS(5776),
    [anon_sym_AMP] = ACTIONS(5774),
    [anon_sym_EQ_EQ] = ACTIONS(5776),
    [anon_sym_BANG_EQ] = ACTIONS(5776),
    [anon_sym_GT] = ACTIONS(5774),
    [anon_sym_GT_EQ] = ACTIONS(5774),
    [anon_sym_LT_EQ] = ACTIONS(5774),
    [anon_sym_LT] = ACTIONS(5774),
    [anon_sym_LT_LT] = ACTIONS(5774),
    [anon_sym_GT_GT] = ACTIONS(5774),
    [anon_sym___extension__] = ACTIONS(5776),
    [anon_sym___global__] = ACTIONS(5776),
    [anon_sym___attribute__] = ACTIONS(5776),
    [anon_sym___attribute] = ACTIONS(5774),
    [anon_sym_LBRACE] = ACTIONS(5776),
    [anon_sym_LBRACK] = ACTIONS(5776),
    [anon_sym_const] = ACTIONS(5774),
    [anon_sym_constexpr] = ACTIONS(5776),
    [anon_sym_volatile] = ACTIONS(5776),
    [anon_sym_restrict] = ACTIONS(5776),
    [anon_sym___restrict__] = ACTIONS(5776),
    [anon_sym__Atomic] = ACTIONS(5776),
    [anon_sym__Noreturn] = ACTIONS(5776),
    [anon_sym_noreturn] = ACTIONS(5776),
    [anon_sym__Nonnull] = ACTIONS(5776),
    [anon_sym_mutable] = ACTIONS(5776),
    [anon_sym_constinit] = ACTIONS(5776),
    [anon_sym_consteval] = ACTIONS(5776),
    [anon_sym___shared__] = ACTIONS(5776),
    [anon_sym___local__] = ACTIONS(5776),
    [anon_sym___constant__] = ACTIONS(5776),
    [anon_sym___managed__] = ACTIONS(5776),
    [anon_sym___grid_constant__] = ACTIONS(5776),
    [anon_sym_alignas] = ACTIONS(5776),
    [anon_sym__Alignas] = ACTIONS(5776),
    [anon_sym_QMARK] = ACTIONS(5776),
    [anon_sym_LT_EQ_GT] = ACTIONS(5776),
    [anon_sym_or] = ACTIONS(5776),
    [anon_sym_and] = ACTIONS(5776),
    [anon_sym_bitor] = ACTIONS(5776),
    [anon_sym_xor] = ACTIONS(5776),
    [anon_sym_bitand] = ACTIONS(5776),
    [anon_sym_not_eq] = ACTIONS(5776),
    [anon_sym_DASH_DASH] = ACTIONS(5776),
    [anon_sym_PLUS_PLUS] = ACTIONS(5776),
    [anon_sym_DOT] = ACTIONS(5774),
    [anon_sym_DOT_STAR] = ACTIONS(5776),
    [anon_sym_DASH_GT] = ACTIONS(5776),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5776),
    [anon_sym_decltype] = ACTIONS(5776),
    [anon_sym_final] = ACTIONS(5776),
    [anon_sym_override] = ACTIONS(5776),
    [anon_sym_GT2] = ACTIONS(5776),
    [anon_sym_requires] = ACTIONS(5776),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5776),
  },
  [STATE(2536)] = {
    [sym_string_literal] = STATE(2497),
    [sym_raw_string_literal] = STATE(2497),
    [aux_sym_concatenated_string_repeat1] = STATE(2497),
    [sym_identifier] = ACTIONS(6551),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6002),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_LPAREN2] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_STAR] = ACTIONS(6004),
    [anon_sym_SLASH] = ACTIONS(6004),
    [anon_sym_PERCENT] = ACTIONS(6004),
    [anon_sym_PIPE_PIPE] = ACTIONS(6002),
    [anon_sym_AMP_AMP] = ACTIONS(6002),
    [anon_sym_PIPE] = ACTIONS(6004),
    [anon_sym_CARET] = ACTIONS(6004),
    [anon_sym_AMP] = ACTIONS(6004),
    [anon_sym_EQ_EQ] = ACTIONS(6002),
    [anon_sym_BANG_EQ] = ACTIONS(6002),
    [anon_sym_GT] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(6002),
    [anon_sym_LT_EQ] = ACTIONS(6004),
    [anon_sym_LT] = ACTIONS(6004),
    [anon_sym_LT_LT] = ACTIONS(6004),
    [anon_sym_GT_GT] = ACTIONS(6004),
    [anon_sym_LBRACK] = ACTIONS(6002),
    [anon_sym_EQ] = ACTIONS(6004),
    [anon_sym_QMARK] = ACTIONS(6002),
    [anon_sym_STAR_EQ] = ACTIONS(6002),
    [anon_sym_SLASH_EQ] = ACTIONS(6002),
    [anon_sym_PERCENT_EQ] = ACTIONS(6002),
    [anon_sym_PLUS_EQ] = ACTIONS(6002),
    [anon_sym_DASH_EQ] = ACTIONS(6002),
    [anon_sym_LT_LT_EQ] = ACTIONS(6002),
    [anon_sym_GT_GT_EQ] = ACTIONS(6002),
    [anon_sym_AMP_EQ] = ACTIONS(6002),
    [anon_sym_CARET_EQ] = ACTIONS(6002),
    [anon_sym_PIPE_EQ] = ACTIONS(6002),
    [anon_sym_and_eq] = ACTIONS(6004),
    [anon_sym_or_eq] = ACTIONS(6004),
    [anon_sym_xor_eq] = ACTIONS(6004),
    [anon_sym_LT_EQ_GT] = ACTIONS(6002),
    [anon_sym_or] = ACTIONS(6004),
    [anon_sym_and] = ACTIONS(6004),
    [anon_sym_bitor] = ACTIONS(6004),
    [anon_sym_xor] = ACTIONS(6004),
    [anon_sym_bitand] = ACTIONS(6004),
    [anon_sym_not_eq] = ACTIONS(6004),
    [anon_sym_DASH_DASH] = ACTIONS(6002),
    [anon_sym_PLUS_PLUS] = ACTIONS(6002),
    [anon_sym_DOT] = ACTIONS(6004),
    [anon_sym_DOT_STAR] = ACTIONS(6002),
    [anon_sym_DASH_GT] = ACTIONS(6002),
    [anon_sym_L_DQUOTE] = ACTIONS(6522),
    [anon_sym_u_DQUOTE] = ACTIONS(6522),
    [anon_sym_U_DQUOTE] = ACTIONS(6522),
    [anon_sym_u8_DQUOTE] = ACTIONS(6522),
    [anon_sym_DQUOTE] = ACTIONS(6522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6524),
    [anon_sym_LR_DQUOTE] = ACTIONS(6524),
    [anon_sym_uR_DQUOTE] = ACTIONS(6524),
    [anon_sym_UR_DQUOTE] = ACTIONS(6524),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6524),
    [sym_literal_suffix] = ACTIONS(6004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6002),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(6002),
  },
  [STATE(2537)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2537),
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [aux_sym_preproc_if_token2] = ACTIONS(5135),
    [aux_sym_preproc_else_token1] = ACTIONS(5135),
    [aux_sym_preproc_elif_token1] = ACTIONS(5133),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5135),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym___attribute] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(6553),
    [anon_sym_unsigned] = ACTIONS(6553),
    [anon_sym_long] = ACTIONS(6553),
    [anon_sym_short] = ACTIONS(6553),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5135),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_and_eq] = ACTIONS(5133),
    [anon_sym_or_eq] = ACTIONS(5133),
    [anon_sym_xor_eq] = ACTIONS(5133),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5135),
  },
  [STATE(2538)] = {
    [sym_identifier] = ACTIONS(5813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5815),
    [anon_sym_COMMA] = ACTIONS(5815),
    [anon_sym_RPAREN] = ACTIONS(5815),
    [aux_sym_preproc_if_token2] = ACTIONS(5815),
    [aux_sym_preproc_else_token1] = ACTIONS(5815),
    [aux_sym_preproc_elif_token1] = ACTIONS(5813),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5815),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5815),
    [anon_sym_LPAREN2] = ACTIONS(5815),
    [anon_sym_DASH] = ACTIONS(5813),
    [anon_sym_PLUS] = ACTIONS(5813),
    [anon_sym_STAR] = ACTIONS(5813),
    [anon_sym_SLASH] = ACTIONS(5813),
    [anon_sym_PERCENT] = ACTIONS(5813),
    [anon_sym_PIPE_PIPE] = ACTIONS(5815),
    [anon_sym_AMP_AMP] = ACTIONS(5815),
    [anon_sym_PIPE] = ACTIONS(5813),
    [anon_sym_CARET] = ACTIONS(5813),
    [anon_sym_AMP] = ACTIONS(5813),
    [anon_sym_EQ_EQ] = ACTIONS(5815),
    [anon_sym_BANG_EQ] = ACTIONS(5815),
    [anon_sym_GT] = ACTIONS(5813),
    [anon_sym_GT_EQ] = ACTIONS(5815),
    [anon_sym_LT_EQ] = ACTIONS(5813),
    [anon_sym_LT] = ACTIONS(5813),
    [anon_sym_LT_LT] = ACTIONS(5813),
    [anon_sym_GT_GT] = ACTIONS(5813),
    [anon_sym_SEMI] = ACTIONS(5815),
    [anon_sym___attribute__] = ACTIONS(5813),
    [anon_sym___attribute] = ACTIONS(5813),
    [anon_sym_LBRACE] = ACTIONS(5815),
    [anon_sym_RBRACE] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(5815),
    [anon_sym_RBRACK] = ACTIONS(5815),
    [anon_sym_EQ] = ACTIONS(5813),
    [anon_sym_COLON] = ACTIONS(5815),
    [anon_sym_QMARK] = ACTIONS(5815),
    [anon_sym_STAR_EQ] = ACTIONS(5815),
    [anon_sym_SLASH_EQ] = ACTIONS(5815),
    [anon_sym_PERCENT_EQ] = ACTIONS(5815),
    [anon_sym_PLUS_EQ] = ACTIONS(5815),
    [anon_sym_DASH_EQ] = ACTIONS(5815),
    [anon_sym_LT_LT_EQ] = ACTIONS(5815),
    [anon_sym_GT_GT_EQ] = ACTIONS(5815),
    [anon_sym_AMP_EQ] = ACTIONS(5815),
    [anon_sym_CARET_EQ] = ACTIONS(5815),
    [anon_sym_PIPE_EQ] = ACTIONS(5815),
    [anon_sym_and_eq] = ACTIONS(5813),
    [anon_sym_or_eq] = ACTIONS(5813),
    [anon_sym_xor_eq] = ACTIONS(5813),
    [anon_sym_LT_EQ_GT] = ACTIONS(5815),
    [anon_sym_or] = ACTIONS(5813),
    [anon_sym_and] = ACTIONS(5813),
    [anon_sym_bitor] = ACTIONS(5813),
    [anon_sym_xor] = ACTIONS(5813),
    [anon_sym_bitand] = ACTIONS(5813),
    [anon_sym_not_eq] = ACTIONS(5813),
    [anon_sym_DASH_DASH] = ACTIONS(5815),
    [anon_sym_PLUS_PLUS] = ACTIONS(5815),
    [anon_sym_DOT] = ACTIONS(5813),
    [anon_sym_DOT_STAR] = ACTIONS(5815),
    [anon_sym_DASH_GT] = ACTIONS(5815),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5813),
    [anon_sym_decltype] = ACTIONS(5813),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5815),
  },
  [STATE(2539)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5823),
    [anon_sym_COMMA] = ACTIONS(5823),
    [anon_sym_LPAREN2] = ACTIONS(5823),
    [anon_sym_DASH] = ACTIONS(5821),
    [anon_sym_PLUS] = ACTIONS(5821),
    [anon_sym_STAR] = ACTIONS(5823),
    [anon_sym_SLASH] = ACTIONS(5821),
    [anon_sym_PERCENT] = ACTIONS(5823),
    [anon_sym_PIPE_PIPE] = ACTIONS(5823),
    [anon_sym_AMP_AMP] = ACTIONS(5823),
    [anon_sym_PIPE] = ACTIONS(5821),
    [anon_sym_CARET] = ACTIONS(5823),
    [anon_sym_AMP] = ACTIONS(5821),
    [anon_sym_EQ_EQ] = ACTIONS(5823),
    [anon_sym_BANG_EQ] = ACTIONS(5823),
    [anon_sym_GT] = ACTIONS(5821),
    [anon_sym_GT_EQ] = ACTIONS(5821),
    [anon_sym_LT_EQ] = ACTIONS(5821),
    [anon_sym_LT] = ACTIONS(5821),
    [anon_sym_LT_LT] = ACTIONS(5821),
    [anon_sym_GT_GT] = ACTIONS(5821),
    [anon_sym___extension__] = ACTIONS(5823),
    [anon_sym___global__] = ACTIONS(5823),
    [anon_sym___attribute__] = ACTIONS(5823),
    [anon_sym___attribute] = ACTIONS(5821),
    [anon_sym_LBRACE] = ACTIONS(5823),
    [anon_sym_LBRACK] = ACTIONS(5823),
    [anon_sym_const] = ACTIONS(5821),
    [anon_sym_constexpr] = ACTIONS(5823),
    [anon_sym_volatile] = ACTIONS(5823),
    [anon_sym_restrict] = ACTIONS(5823),
    [anon_sym___restrict__] = ACTIONS(5823),
    [anon_sym__Atomic] = ACTIONS(5823),
    [anon_sym__Noreturn] = ACTIONS(5823),
    [anon_sym_noreturn] = ACTIONS(5823),
    [anon_sym__Nonnull] = ACTIONS(5823),
    [anon_sym_mutable] = ACTIONS(5823),
    [anon_sym_constinit] = ACTIONS(5823),
    [anon_sym_consteval] = ACTIONS(5823),
    [anon_sym___shared__] = ACTIONS(5823),
    [anon_sym___local__] = ACTIONS(5823),
    [anon_sym___constant__] = ACTIONS(5823),
    [anon_sym___managed__] = ACTIONS(5823),
    [anon_sym___grid_constant__] = ACTIONS(5823),
    [anon_sym_alignas] = ACTIONS(5823),
    [anon_sym__Alignas] = ACTIONS(5823),
    [anon_sym_QMARK] = ACTIONS(5823),
    [anon_sym_LT_EQ_GT] = ACTIONS(5823),
    [anon_sym_or] = ACTIONS(5823),
    [anon_sym_and] = ACTIONS(5823),
    [anon_sym_bitor] = ACTIONS(5823),
    [anon_sym_xor] = ACTIONS(5823),
    [anon_sym_bitand] = ACTIONS(5823),
    [anon_sym_not_eq] = ACTIONS(5823),
    [anon_sym_DASH_DASH] = ACTIONS(5823),
    [anon_sym_PLUS_PLUS] = ACTIONS(5823),
    [anon_sym_DOT] = ACTIONS(5821),
    [anon_sym_DOT_STAR] = ACTIONS(5823),
    [anon_sym_DASH_GT] = ACTIONS(5823),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5823),
    [anon_sym_decltype] = ACTIONS(5823),
    [anon_sym_final] = ACTIONS(5823),
    [anon_sym_override] = ACTIONS(5823),
    [anon_sym_GT2] = ACTIONS(5823),
    [anon_sym_requires] = ACTIONS(5823),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5823),
  },
  [STATE(2540)] = {
    [sym_identifier] = ACTIONS(5710),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5712),
    [anon_sym_COMMA] = ACTIONS(5712),
    [anon_sym_RPAREN] = ACTIONS(5712),
    [aux_sym_preproc_if_token2] = ACTIONS(5712),
    [aux_sym_preproc_else_token1] = ACTIONS(5712),
    [aux_sym_preproc_elif_token1] = ACTIONS(5710),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5712),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5712),
    [anon_sym_LPAREN2] = ACTIONS(5712),
    [anon_sym_DASH] = ACTIONS(5710),
    [anon_sym_PLUS] = ACTIONS(5710),
    [anon_sym_STAR] = ACTIONS(5710),
    [anon_sym_SLASH] = ACTIONS(5710),
    [anon_sym_PERCENT] = ACTIONS(5710),
    [anon_sym_PIPE_PIPE] = ACTIONS(5712),
    [anon_sym_AMP_AMP] = ACTIONS(5712),
    [anon_sym_PIPE] = ACTIONS(5710),
    [anon_sym_CARET] = ACTIONS(5710),
    [anon_sym_AMP] = ACTIONS(5710),
    [anon_sym_EQ_EQ] = ACTIONS(5712),
    [anon_sym_BANG_EQ] = ACTIONS(5712),
    [anon_sym_GT] = ACTIONS(5710),
    [anon_sym_GT_EQ] = ACTIONS(5712),
    [anon_sym_LT_EQ] = ACTIONS(5710),
    [anon_sym_LT] = ACTIONS(5710),
    [anon_sym_LT_LT] = ACTIONS(5710),
    [anon_sym_GT_GT] = ACTIONS(5710),
    [anon_sym_SEMI] = ACTIONS(5712),
    [anon_sym___attribute__] = ACTIONS(5710),
    [anon_sym___attribute] = ACTIONS(5710),
    [anon_sym_LBRACE] = ACTIONS(5712),
    [anon_sym_RBRACE] = ACTIONS(5712),
    [anon_sym_LBRACK] = ACTIONS(5712),
    [anon_sym_RBRACK] = ACTIONS(5712),
    [anon_sym_EQ] = ACTIONS(5710),
    [anon_sym_COLON] = ACTIONS(5712),
    [anon_sym_QMARK] = ACTIONS(5712),
    [anon_sym_STAR_EQ] = ACTIONS(5712),
    [anon_sym_SLASH_EQ] = ACTIONS(5712),
    [anon_sym_PERCENT_EQ] = ACTIONS(5712),
    [anon_sym_PLUS_EQ] = ACTIONS(5712),
    [anon_sym_DASH_EQ] = ACTIONS(5712),
    [anon_sym_LT_LT_EQ] = ACTIONS(5712),
    [anon_sym_GT_GT_EQ] = ACTIONS(5712),
    [anon_sym_AMP_EQ] = ACTIONS(5712),
    [anon_sym_CARET_EQ] = ACTIONS(5712),
    [anon_sym_PIPE_EQ] = ACTIONS(5712),
    [anon_sym_and_eq] = ACTIONS(5710),
    [anon_sym_or_eq] = ACTIONS(5710),
    [anon_sym_xor_eq] = ACTIONS(5710),
    [anon_sym_LT_EQ_GT] = ACTIONS(5712),
    [anon_sym_or] = ACTIONS(5710),
    [anon_sym_and] = ACTIONS(5710),
    [anon_sym_bitor] = ACTIONS(5710),
    [anon_sym_xor] = ACTIONS(5710),
    [anon_sym_bitand] = ACTIONS(5710),
    [anon_sym_not_eq] = ACTIONS(5710),
    [anon_sym_DASH_DASH] = ACTIONS(5712),
    [anon_sym_PLUS_PLUS] = ACTIONS(5712),
    [anon_sym_DOT] = ACTIONS(5710),
    [anon_sym_DOT_STAR] = ACTIONS(5712),
    [anon_sym_DASH_GT] = ACTIONS(5712),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5710),
    [anon_sym_decltype] = ACTIONS(5710),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5712),
  },
  [STATE(2541)] = {
    [sym_identifier] = ACTIONS(5726),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5728),
    [anon_sym_COMMA] = ACTIONS(5728),
    [anon_sym_RPAREN] = ACTIONS(5728),
    [aux_sym_preproc_if_token2] = ACTIONS(5728),
    [aux_sym_preproc_else_token1] = ACTIONS(5728),
    [aux_sym_preproc_elif_token1] = ACTIONS(5726),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5728),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5728),
    [anon_sym_LPAREN2] = ACTIONS(5728),
    [anon_sym_DASH] = ACTIONS(5726),
    [anon_sym_PLUS] = ACTIONS(5726),
    [anon_sym_STAR] = ACTIONS(5726),
    [anon_sym_SLASH] = ACTIONS(5726),
    [anon_sym_PERCENT] = ACTIONS(5726),
    [anon_sym_PIPE_PIPE] = ACTIONS(5728),
    [anon_sym_AMP_AMP] = ACTIONS(5728),
    [anon_sym_PIPE] = ACTIONS(5726),
    [anon_sym_CARET] = ACTIONS(5726),
    [anon_sym_AMP] = ACTIONS(5726),
    [anon_sym_EQ_EQ] = ACTIONS(5728),
    [anon_sym_BANG_EQ] = ACTIONS(5728),
    [anon_sym_GT] = ACTIONS(5726),
    [anon_sym_GT_EQ] = ACTIONS(5728),
    [anon_sym_LT_EQ] = ACTIONS(5726),
    [anon_sym_LT] = ACTIONS(5726),
    [anon_sym_LT_LT] = ACTIONS(5726),
    [anon_sym_GT_GT] = ACTIONS(5726),
    [anon_sym_SEMI] = ACTIONS(5728),
    [anon_sym___attribute__] = ACTIONS(5726),
    [anon_sym___attribute] = ACTIONS(5726),
    [anon_sym_LBRACE] = ACTIONS(5728),
    [anon_sym_RBRACE] = ACTIONS(5728),
    [anon_sym_LBRACK] = ACTIONS(5728),
    [anon_sym_RBRACK] = ACTIONS(5728),
    [anon_sym_EQ] = ACTIONS(5726),
    [anon_sym_COLON] = ACTIONS(5728),
    [anon_sym_QMARK] = ACTIONS(5728),
    [anon_sym_STAR_EQ] = ACTIONS(5728),
    [anon_sym_SLASH_EQ] = ACTIONS(5728),
    [anon_sym_PERCENT_EQ] = ACTIONS(5728),
    [anon_sym_PLUS_EQ] = ACTIONS(5728),
    [anon_sym_DASH_EQ] = ACTIONS(5728),
    [anon_sym_LT_LT_EQ] = ACTIONS(5728),
    [anon_sym_GT_GT_EQ] = ACTIONS(5728),
    [anon_sym_AMP_EQ] = ACTIONS(5728),
    [anon_sym_CARET_EQ] = ACTIONS(5728),
    [anon_sym_PIPE_EQ] = ACTIONS(5728),
    [anon_sym_and_eq] = ACTIONS(5726),
    [anon_sym_or_eq] = ACTIONS(5726),
    [anon_sym_xor_eq] = ACTIONS(5726),
    [anon_sym_LT_EQ_GT] = ACTIONS(5728),
    [anon_sym_or] = ACTIONS(5726),
    [anon_sym_and] = ACTIONS(5726),
    [anon_sym_bitor] = ACTIONS(5726),
    [anon_sym_xor] = ACTIONS(5726),
    [anon_sym_bitand] = ACTIONS(5726),
    [anon_sym_not_eq] = ACTIONS(5726),
    [anon_sym_DASH_DASH] = ACTIONS(5728),
    [anon_sym_PLUS_PLUS] = ACTIONS(5728),
    [anon_sym_DOT] = ACTIONS(5726),
    [anon_sym_DOT_STAR] = ACTIONS(5728),
    [anon_sym_DASH_GT] = ACTIONS(5728),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5726),
    [anon_sym_decltype] = ACTIONS(5726),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5728),
  },
  [STATE(2542)] = {
    [sym_identifier] = ACTIONS(5734),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5736),
    [anon_sym_COMMA] = ACTIONS(5736),
    [anon_sym_RPAREN] = ACTIONS(5736),
    [aux_sym_preproc_if_token2] = ACTIONS(5736),
    [aux_sym_preproc_else_token1] = ACTIONS(5736),
    [aux_sym_preproc_elif_token1] = ACTIONS(5734),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5736),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5736),
    [anon_sym_LPAREN2] = ACTIONS(5736),
    [anon_sym_DASH] = ACTIONS(5734),
    [anon_sym_PLUS] = ACTIONS(5734),
    [anon_sym_STAR] = ACTIONS(5734),
    [anon_sym_SLASH] = ACTIONS(5734),
    [anon_sym_PERCENT] = ACTIONS(5734),
    [anon_sym_PIPE_PIPE] = ACTIONS(5736),
    [anon_sym_AMP_AMP] = ACTIONS(5736),
    [anon_sym_PIPE] = ACTIONS(5734),
    [anon_sym_CARET] = ACTIONS(5734),
    [anon_sym_AMP] = ACTIONS(5734),
    [anon_sym_EQ_EQ] = ACTIONS(5736),
    [anon_sym_BANG_EQ] = ACTIONS(5736),
    [anon_sym_GT] = ACTIONS(5734),
    [anon_sym_GT_EQ] = ACTIONS(5736),
    [anon_sym_LT_EQ] = ACTIONS(5734),
    [anon_sym_LT] = ACTIONS(5734),
    [anon_sym_LT_LT] = ACTIONS(5734),
    [anon_sym_GT_GT] = ACTIONS(5734),
    [anon_sym_SEMI] = ACTIONS(5736),
    [anon_sym___attribute__] = ACTIONS(5734),
    [anon_sym___attribute] = ACTIONS(5734),
    [anon_sym_LBRACE] = ACTIONS(5736),
    [anon_sym_RBRACE] = ACTIONS(5736),
    [anon_sym_LBRACK] = ACTIONS(5736),
    [anon_sym_RBRACK] = ACTIONS(5736),
    [anon_sym_EQ] = ACTIONS(5734),
    [anon_sym_COLON] = ACTIONS(5736),
    [anon_sym_QMARK] = ACTIONS(5736),
    [anon_sym_STAR_EQ] = ACTIONS(5736),
    [anon_sym_SLASH_EQ] = ACTIONS(5736),
    [anon_sym_PERCENT_EQ] = ACTIONS(5736),
    [anon_sym_PLUS_EQ] = ACTIONS(5736),
    [anon_sym_DASH_EQ] = ACTIONS(5736),
    [anon_sym_LT_LT_EQ] = ACTIONS(5736),
    [anon_sym_GT_GT_EQ] = ACTIONS(5736),
    [anon_sym_AMP_EQ] = ACTIONS(5736),
    [anon_sym_CARET_EQ] = ACTIONS(5736),
    [anon_sym_PIPE_EQ] = ACTIONS(5736),
    [anon_sym_and_eq] = ACTIONS(5734),
    [anon_sym_or_eq] = ACTIONS(5734),
    [anon_sym_xor_eq] = ACTIONS(5734),
    [anon_sym_LT_EQ_GT] = ACTIONS(5736),
    [anon_sym_or] = ACTIONS(5734),
    [anon_sym_and] = ACTIONS(5734),
    [anon_sym_bitor] = ACTIONS(5734),
    [anon_sym_xor] = ACTIONS(5734),
    [anon_sym_bitand] = ACTIONS(5734),
    [anon_sym_not_eq] = ACTIONS(5734),
    [anon_sym_DASH_DASH] = ACTIONS(5736),
    [anon_sym_PLUS_PLUS] = ACTIONS(5736),
    [anon_sym_DOT] = ACTIONS(5734),
    [anon_sym_DOT_STAR] = ACTIONS(5736),
    [anon_sym_DASH_GT] = ACTIONS(5736),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5734),
    [anon_sym_decltype] = ACTIONS(5734),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5736),
  },
  [STATE(2543)] = {
    [sym_template_argument_list] = STATE(2360),
    [sym_identifier] = ACTIONS(4512),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_TILDE] = ACTIONS(4519),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4512),
    [anon_sym_LT] = ACTIONS(6076),
    [anon_sym_SEMI] = ACTIONS(4519),
    [anon_sym___extension__] = ACTIONS(4512),
    [anon_sym___device__] = ACTIONS(4512),
    [anon_sym___host__] = ACTIONS(4512),
    [anon_sym___global__] = ACTIONS(4512),
    [anon_sym___forceinline__] = ACTIONS(4512),
    [anon_sym___noinline__] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym___attribute__] = ACTIONS(4512),
    [anon_sym___attribute] = ACTIONS(4512),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4519),
    [anon_sym___declspec] = ACTIONS(4512),
    [anon_sym___based] = ACTIONS(4512),
    [anon_sym___cdecl] = ACTIONS(4512),
    [anon_sym___clrcall] = ACTIONS(4512),
    [anon_sym___stdcall] = ACTIONS(4512),
    [anon_sym___fastcall] = ACTIONS(4512),
    [anon_sym___thiscall] = ACTIONS(4512),
    [anon_sym___vectorcall] = ACTIONS(4512),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_register] = ACTIONS(4512),
    [anon_sym_inline] = ACTIONS(4512),
    [anon_sym___inline] = ACTIONS(4512),
    [anon_sym___inline__] = ACTIONS(4512),
    [anon_sym___forceinline] = ACTIONS(4512),
    [anon_sym_thread_local] = ACTIONS(4512),
    [anon_sym___thread] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4512),
    [anon_sym_volatile] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym___restrict__] = ACTIONS(4512),
    [anon_sym__Atomic] = ACTIONS(4512),
    [anon_sym__Noreturn] = ACTIONS(4512),
    [anon_sym_noreturn] = ACTIONS(4512),
    [anon_sym__Nonnull] = ACTIONS(4512),
    [anon_sym_mutable] = ACTIONS(4512),
    [anon_sym_constinit] = ACTIONS(4512),
    [anon_sym_consteval] = ACTIONS(4512),
    [anon_sym___shared__] = ACTIONS(4512),
    [anon_sym___local__] = ACTIONS(4512),
    [anon_sym___constant__] = ACTIONS(4512),
    [anon_sym___managed__] = ACTIONS(4512),
    [anon_sym___grid_constant__] = ACTIONS(4512),
    [anon_sym_alignas] = ACTIONS(4512),
    [anon_sym__Alignas] = ACTIONS(4512),
    [anon_sym_COLON] = ACTIONS(4512),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4512),
    [anon_sym_decltype] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_override] = ACTIONS(4512),
    [anon_sym_template] = ACTIONS(4512),
    [anon_sym_operator] = ACTIONS(4512),
    [anon_sym___launch_bounds__] = ACTIONS(4512),
  },
  [STATE(2544)] = {
    [sym_identifier] = ACTIONS(5742),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5744),
    [anon_sym_COMMA] = ACTIONS(5744),
    [anon_sym_RPAREN] = ACTIONS(5744),
    [aux_sym_preproc_if_token2] = ACTIONS(5744),
    [aux_sym_preproc_else_token1] = ACTIONS(5744),
    [aux_sym_preproc_elif_token1] = ACTIONS(5742),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5744),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5744),
    [anon_sym_LPAREN2] = ACTIONS(5744),
    [anon_sym_DASH] = ACTIONS(5742),
    [anon_sym_PLUS] = ACTIONS(5742),
    [anon_sym_STAR] = ACTIONS(5742),
    [anon_sym_SLASH] = ACTIONS(5742),
    [anon_sym_PERCENT] = ACTIONS(5742),
    [anon_sym_PIPE_PIPE] = ACTIONS(5744),
    [anon_sym_AMP_AMP] = ACTIONS(5744),
    [anon_sym_PIPE] = ACTIONS(5742),
    [anon_sym_CARET] = ACTIONS(5742),
    [anon_sym_AMP] = ACTIONS(5742),
    [anon_sym_EQ_EQ] = ACTIONS(5744),
    [anon_sym_BANG_EQ] = ACTIONS(5744),
    [anon_sym_GT] = ACTIONS(5742),
    [anon_sym_GT_EQ] = ACTIONS(5744),
    [anon_sym_LT_EQ] = ACTIONS(5742),
    [anon_sym_LT] = ACTIONS(5742),
    [anon_sym_LT_LT] = ACTIONS(5742),
    [anon_sym_GT_GT] = ACTIONS(5742),
    [anon_sym_SEMI] = ACTIONS(5744),
    [anon_sym___attribute__] = ACTIONS(5742),
    [anon_sym___attribute] = ACTIONS(5742),
    [anon_sym_LBRACE] = ACTIONS(5744),
    [anon_sym_RBRACE] = ACTIONS(5744),
    [anon_sym_LBRACK] = ACTIONS(5744),
    [anon_sym_RBRACK] = ACTIONS(5744),
    [anon_sym_EQ] = ACTIONS(5742),
    [anon_sym_COLON] = ACTIONS(5744),
    [anon_sym_QMARK] = ACTIONS(5744),
    [anon_sym_STAR_EQ] = ACTIONS(5744),
    [anon_sym_SLASH_EQ] = ACTIONS(5744),
    [anon_sym_PERCENT_EQ] = ACTIONS(5744),
    [anon_sym_PLUS_EQ] = ACTIONS(5744),
    [anon_sym_DASH_EQ] = ACTIONS(5744),
    [anon_sym_LT_LT_EQ] = ACTIONS(5744),
    [anon_sym_GT_GT_EQ] = ACTIONS(5744),
    [anon_sym_AMP_EQ] = ACTIONS(5744),
    [anon_sym_CARET_EQ] = ACTIONS(5744),
    [anon_sym_PIPE_EQ] = ACTIONS(5744),
    [anon_sym_and_eq] = ACTIONS(5742),
    [anon_sym_or_eq] = ACTIONS(5742),
    [anon_sym_xor_eq] = ACTIONS(5742),
    [anon_sym_LT_EQ_GT] = ACTIONS(5744),
    [anon_sym_or] = ACTIONS(5742),
    [anon_sym_and] = ACTIONS(5742),
    [anon_sym_bitor] = ACTIONS(5742),
    [anon_sym_xor] = ACTIONS(5742),
    [anon_sym_bitand] = ACTIONS(5742),
    [anon_sym_not_eq] = ACTIONS(5742),
    [anon_sym_DASH_DASH] = ACTIONS(5744),
    [anon_sym_PLUS_PLUS] = ACTIONS(5744),
    [anon_sym_DOT] = ACTIONS(5742),
    [anon_sym_DOT_STAR] = ACTIONS(5744),
    [anon_sym_DASH_GT] = ACTIONS(5744),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5742),
    [anon_sym_decltype] = ACTIONS(5742),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5744),
  },
  [STATE(2545)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5698),
    [anon_sym_COMMA] = ACTIONS(5698),
    [anon_sym_LPAREN2] = ACTIONS(5698),
    [anon_sym_DASH] = ACTIONS(5696),
    [anon_sym_PLUS] = ACTIONS(5696),
    [anon_sym_STAR] = ACTIONS(5698),
    [anon_sym_SLASH] = ACTIONS(5696),
    [anon_sym_PERCENT] = ACTIONS(5698),
    [anon_sym_PIPE_PIPE] = ACTIONS(5698),
    [anon_sym_AMP_AMP] = ACTIONS(5698),
    [anon_sym_PIPE] = ACTIONS(5696),
    [anon_sym_CARET] = ACTIONS(5698),
    [anon_sym_AMP] = ACTIONS(5696),
    [anon_sym_EQ_EQ] = ACTIONS(5698),
    [anon_sym_BANG_EQ] = ACTIONS(5698),
    [anon_sym_GT] = ACTIONS(5696),
    [anon_sym_GT_EQ] = ACTIONS(5696),
    [anon_sym_LT_EQ] = ACTIONS(5696),
    [anon_sym_LT] = ACTIONS(5696),
    [anon_sym_LT_LT] = ACTIONS(5696),
    [anon_sym_GT_GT] = ACTIONS(5696),
    [anon_sym___extension__] = ACTIONS(5698),
    [anon_sym___global__] = ACTIONS(5698),
    [anon_sym___attribute__] = ACTIONS(5698),
    [anon_sym___attribute] = ACTIONS(5696),
    [anon_sym_LBRACE] = ACTIONS(5698),
    [anon_sym_LBRACK] = ACTIONS(5698),
    [anon_sym_const] = ACTIONS(5696),
    [anon_sym_constexpr] = ACTIONS(5698),
    [anon_sym_volatile] = ACTIONS(5698),
    [anon_sym_restrict] = ACTIONS(5698),
    [anon_sym___restrict__] = ACTIONS(5698),
    [anon_sym__Atomic] = ACTIONS(5698),
    [anon_sym__Noreturn] = ACTIONS(5698),
    [anon_sym_noreturn] = ACTIONS(5698),
    [anon_sym__Nonnull] = ACTIONS(5698),
    [anon_sym_mutable] = ACTIONS(5698),
    [anon_sym_constinit] = ACTIONS(5698),
    [anon_sym_consteval] = ACTIONS(5698),
    [anon_sym___shared__] = ACTIONS(5698),
    [anon_sym___local__] = ACTIONS(5698),
    [anon_sym___constant__] = ACTIONS(5698),
    [anon_sym___managed__] = ACTIONS(5698),
    [anon_sym___grid_constant__] = ACTIONS(5698),
    [anon_sym_alignas] = ACTIONS(5698),
    [anon_sym__Alignas] = ACTIONS(5698),
    [anon_sym_QMARK] = ACTIONS(5698),
    [anon_sym_LT_EQ_GT] = ACTIONS(5698),
    [anon_sym_or] = ACTIONS(5698),
    [anon_sym_and] = ACTIONS(5698),
    [anon_sym_bitor] = ACTIONS(5698),
    [anon_sym_xor] = ACTIONS(5698),
    [anon_sym_bitand] = ACTIONS(5698),
    [anon_sym_not_eq] = ACTIONS(5698),
    [anon_sym_DASH_DASH] = ACTIONS(5698),
    [anon_sym_PLUS_PLUS] = ACTIONS(5698),
    [anon_sym_DOT] = ACTIONS(5696),
    [anon_sym_DOT_STAR] = ACTIONS(5698),
    [anon_sym_DASH_GT] = ACTIONS(5698),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5698),
    [anon_sym_decltype] = ACTIONS(5698),
    [anon_sym_final] = ACTIONS(5698),
    [anon_sym_override] = ACTIONS(5698),
    [anon_sym_GT2] = ACTIONS(5698),
    [anon_sym_requires] = ACTIONS(5698),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5698),
  },
  [STATE(2546)] = {
    [sym_identifier] = ACTIONS(5722),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5724),
    [anon_sym_COMMA] = ACTIONS(5724),
    [anon_sym_RPAREN] = ACTIONS(5724),
    [aux_sym_preproc_if_token2] = ACTIONS(5724),
    [aux_sym_preproc_else_token1] = ACTIONS(5724),
    [aux_sym_preproc_elif_token1] = ACTIONS(5722),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5724),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5724),
    [anon_sym_LPAREN2] = ACTIONS(5724),
    [anon_sym_DASH] = ACTIONS(5722),
    [anon_sym_PLUS] = ACTIONS(5722),
    [anon_sym_STAR] = ACTIONS(5722),
    [anon_sym_SLASH] = ACTIONS(5722),
    [anon_sym_PERCENT] = ACTIONS(5722),
    [anon_sym_PIPE_PIPE] = ACTIONS(5724),
    [anon_sym_AMP_AMP] = ACTIONS(5724),
    [anon_sym_PIPE] = ACTIONS(5722),
    [anon_sym_CARET] = ACTIONS(5722),
    [anon_sym_AMP] = ACTIONS(5722),
    [anon_sym_EQ_EQ] = ACTIONS(5724),
    [anon_sym_BANG_EQ] = ACTIONS(5724),
    [anon_sym_GT] = ACTIONS(5722),
    [anon_sym_GT_EQ] = ACTIONS(5724),
    [anon_sym_LT_EQ] = ACTIONS(5722),
    [anon_sym_LT] = ACTIONS(5722),
    [anon_sym_LT_LT] = ACTIONS(5722),
    [anon_sym_GT_GT] = ACTIONS(5722),
    [anon_sym_SEMI] = ACTIONS(5724),
    [anon_sym___attribute__] = ACTIONS(5722),
    [anon_sym___attribute] = ACTIONS(5722),
    [anon_sym_LBRACE] = ACTIONS(5724),
    [anon_sym_RBRACE] = ACTIONS(5724),
    [anon_sym_LBRACK] = ACTIONS(5724),
    [anon_sym_RBRACK] = ACTIONS(5724),
    [anon_sym_EQ] = ACTIONS(5722),
    [anon_sym_COLON] = ACTIONS(5724),
    [anon_sym_QMARK] = ACTIONS(5724),
    [anon_sym_STAR_EQ] = ACTIONS(5724),
    [anon_sym_SLASH_EQ] = ACTIONS(5724),
    [anon_sym_PERCENT_EQ] = ACTIONS(5724),
    [anon_sym_PLUS_EQ] = ACTIONS(5724),
    [anon_sym_DASH_EQ] = ACTIONS(5724),
    [anon_sym_LT_LT_EQ] = ACTIONS(5724),
    [anon_sym_GT_GT_EQ] = ACTIONS(5724),
    [anon_sym_AMP_EQ] = ACTIONS(5724),
    [anon_sym_CARET_EQ] = ACTIONS(5724),
    [anon_sym_PIPE_EQ] = ACTIONS(5724),
    [anon_sym_and_eq] = ACTIONS(5722),
    [anon_sym_or_eq] = ACTIONS(5722),
    [anon_sym_xor_eq] = ACTIONS(5722),
    [anon_sym_LT_EQ_GT] = ACTIONS(5724),
    [anon_sym_or] = ACTIONS(5722),
    [anon_sym_and] = ACTIONS(5722),
    [anon_sym_bitor] = ACTIONS(5722),
    [anon_sym_xor] = ACTIONS(5722),
    [anon_sym_bitand] = ACTIONS(5722),
    [anon_sym_not_eq] = ACTIONS(5722),
    [anon_sym_DASH_DASH] = ACTIONS(5724),
    [anon_sym_PLUS_PLUS] = ACTIONS(5724),
    [anon_sym_DOT] = ACTIONS(5722),
    [anon_sym_DOT_STAR] = ACTIONS(5724),
    [anon_sym_DASH_GT] = ACTIONS(5724),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5722),
    [anon_sym_decltype] = ACTIONS(5722),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5724),
  },
  [STATE(2547)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6456),
    [anon_sym_COMMA] = ACTIONS(6556),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_RBRACK] = ACTIONS(6558),
    [anon_sym_EQ] = ACTIONS(6466),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(6468),
    [anon_sym_SLASH_EQ] = ACTIONS(6468),
    [anon_sym_PERCENT_EQ] = ACTIONS(6468),
    [anon_sym_PLUS_EQ] = ACTIONS(6468),
    [anon_sym_DASH_EQ] = ACTIONS(6468),
    [anon_sym_LT_LT_EQ] = ACTIONS(6468),
    [anon_sym_GT_GT_EQ] = ACTIONS(6468),
    [anon_sym_AMP_EQ] = ACTIONS(6468),
    [anon_sym_CARET_EQ] = ACTIONS(6468),
    [anon_sym_PIPE_EQ] = ACTIONS(6468),
    [anon_sym_and_eq] = ACTIONS(6468),
    [anon_sym_or_eq] = ACTIONS(6468),
    [anon_sym_xor_eq] = ACTIONS(6468),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2548)] = {
    [sym_attribute_declaration] = STATE(2548),
    [aux_sym_attributed_declarator_repeat1] = STATE(2548),
    [sym_identifier] = ACTIONS(6561),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6563),
    [anon_sym_COMMA] = ACTIONS(6563),
    [anon_sym_RPAREN] = ACTIONS(6563),
    [aux_sym_preproc_if_token2] = ACTIONS(6563),
    [aux_sym_preproc_else_token1] = ACTIONS(6563),
    [aux_sym_preproc_elif_token1] = ACTIONS(6561),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6563),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6563),
    [anon_sym_LPAREN2] = ACTIONS(6563),
    [anon_sym_DASH] = ACTIONS(6561),
    [anon_sym_PLUS] = ACTIONS(6561),
    [anon_sym_STAR] = ACTIONS(6561),
    [anon_sym_SLASH] = ACTIONS(6561),
    [anon_sym_PERCENT] = ACTIONS(6561),
    [anon_sym_PIPE_PIPE] = ACTIONS(6563),
    [anon_sym_AMP_AMP] = ACTIONS(6563),
    [anon_sym_PIPE] = ACTIONS(6561),
    [anon_sym_CARET] = ACTIONS(6561),
    [anon_sym_AMP] = ACTIONS(6561),
    [anon_sym_EQ_EQ] = ACTIONS(6563),
    [anon_sym_BANG_EQ] = ACTIONS(6563),
    [anon_sym_GT] = ACTIONS(6561),
    [anon_sym_GT_EQ] = ACTIONS(6563),
    [anon_sym_LT_EQ] = ACTIONS(6561),
    [anon_sym_LT] = ACTIONS(6561),
    [anon_sym_LT_LT] = ACTIONS(6561),
    [anon_sym_GT_GT] = ACTIONS(6561),
    [anon_sym_SEMI] = ACTIONS(6563),
    [anon_sym___attribute__] = ACTIONS(6561),
    [anon_sym___attribute] = ACTIONS(6561),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6565),
    [anon_sym_RBRACE] = ACTIONS(6563),
    [anon_sym_LBRACK] = ACTIONS(6561),
    [anon_sym_RBRACK] = ACTIONS(6563),
    [anon_sym_EQ] = ACTIONS(6561),
    [anon_sym_COLON] = ACTIONS(6563),
    [anon_sym_QMARK] = ACTIONS(6563),
    [anon_sym_STAR_EQ] = ACTIONS(6563),
    [anon_sym_SLASH_EQ] = ACTIONS(6563),
    [anon_sym_PERCENT_EQ] = ACTIONS(6563),
    [anon_sym_PLUS_EQ] = ACTIONS(6563),
    [anon_sym_DASH_EQ] = ACTIONS(6563),
    [anon_sym_LT_LT_EQ] = ACTIONS(6563),
    [anon_sym_GT_GT_EQ] = ACTIONS(6563),
    [anon_sym_AMP_EQ] = ACTIONS(6563),
    [anon_sym_CARET_EQ] = ACTIONS(6563),
    [anon_sym_PIPE_EQ] = ACTIONS(6563),
    [anon_sym_and_eq] = ACTIONS(6561),
    [anon_sym_or_eq] = ACTIONS(6561),
    [anon_sym_xor_eq] = ACTIONS(6561),
    [anon_sym_LT_EQ_GT] = ACTIONS(6563),
    [anon_sym_or] = ACTIONS(6561),
    [anon_sym_and] = ACTIONS(6561),
    [anon_sym_bitor] = ACTIONS(6561),
    [anon_sym_xor] = ACTIONS(6561),
    [anon_sym_bitand] = ACTIONS(6561),
    [anon_sym_not_eq] = ACTIONS(6561),
    [anon_sym_DASH_DASH] = ACTIONS(6563),
    [anon_sym_PLUS_PLUS] = ACTIONS(6563),
    [anon_sym_DOT] = ACTIONS(6561),
    [anon_sym_DOT_STAR] = ACTIONS(6563),
    [anon_sym_DASH_GT] = ACTIONS(6563),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6563),
  },
  [STATE(2549)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5803),
    [anon_sym_COMMA] = ACTIONS(5803),
    [anon_sym_LPAREN2] = ACTIONS(5803),
    [anon_sym_DASH] = ACTIONS(5801),
    [anon_sym_PLUS] = ACTIONS(5801),
    [anon_sym_STAR] = ACTIONS(5803),
    [anon_sym_SLASH] = ACTIONS(5801),
    [anon_sym_PERCENT] = ACTIONS(5803),
    [anon_sym_PIPE_PIPE] = ACTIONS(5803),
    [anon_sym_AMP_AMP] = ACTIONS(5803),
    [anon_sym_PIPE] = ACTIONS(5801),
    [anon_sym_CARET] = ACTIONS(5803),
    [anon_sym_AMP] = ACTIONS(5801),
    [anon_sym_EQ_EQ] = ACTIONS(5803),
    [anon_sym_BANG_EQ] = ACTIONS(5803),
    [anon_sym_GT] = ACTIONS(5801),
    [anon_sym_GT_EQ] = ACTIONS(5801),
    [anon_sym_LT_EQ] = ACTIONS(5801),
    [anon_sym_LT] = ACTIONS(5801),
    [anon_sym_LT_LT] = ACTIONS(5801),
    [anon_sym_GT_GT] = ACTIONS(5801),
    [anon_sym___extension__] = ACTIONS(5803),
    [anon_sym___global__] = ACTIONS(5803),
    [anon_sym___attribute__] = ACTIONS(5803),
    [anon_sym___attribute] = ACTIONS(5801),
    [anon_sym_LBRACE] = ACTIONS(5803),
    [anon_sym_LBRACK] = ACTIONS(5803),
    [anon_sym_const] = ACTIONS(5801),
    [anon_sym_constexpr] = ACTIONS(5803),
    [anon_sym_volatile] = ACTIONS(5803),
    [anon_sym_restrict] = ACTIONS(5803),
    [anon_sym___restrict__] = ACTIONS(5803),
    [anon_sym__Atomic] = ACTIONS(5803),
    [anon_sym__Noreturn] = ACTIONS(5803),
    [anon_sym_noreturn] = ACTIONS(5803),
    [anon_sym__Nonnull] = ACTIONS(5803),
    [anon_sym_mutable] = ACTIONS(5803),
    [anon_sym_constinit] = ACTIONS(5803),
    [anon_sym_consteval] = ACTIONS(5803),
    [anon_sym___shared__] = ACTIONS(5803),
    [anon_sym___local__] = ACTIONS(5803),
    [anon_sym___constant__] = ACTIONS(5803),
    [anon_sym___managed__] = ACTIONS(5803),
    [anon_sym___grid_constant__] = ACTIONS(5803),
    [anon_sym_alignas] = ACTIONS(5803),
    [anon_sym__Alignas] = ACTIONS(5803),
    [anon_sym_QMARK] = ACTIONS(5803),
    [anon_sym_LT_EQ_GT] = ACTIONS(5803),
    [anon_sym_or] = ACTIONS(5803),
    [anon_sym_and] = ACTIONS(5803),
    [anon_sym_bitor] = ACTIONS(5803),
    [anon_sym_xor] = ACTIONS(5803),
    [anon_sym_bitand] = ACTIONS(5803),
    [anon_sym_not_eq] = ACTIONS(5803),
    [anon_sym_DASH_DASH] = ACTIONS(5803),
    [anon_sym_PLUS_PLUS] = ACTIONS(5803),
    [anon_sym_DOT] = ACTIONS(5801),
    [anon_sym_DOT_STAR] = ACTIONS(5803),
    [anon_sym_DASH_GT] = ACTIONS(5803),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5803),
    [anon_sym_decltype] = ACTIONS(5803),
    [anon_sym_final] = ACTIONS(5803),
    [anon_sym_override] = ACTIONS(5803),
    [anon_sym_GT2] = ACTIONS(5803),
    [anon_sym_requires] = ACTIONS(5803),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5803),
  },
  [STATE(2550)] = {
    [sym_attribute_specifier] = STATE(2248),
    [sym_identifier] = ACTIONS(6268),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6266),
    [anon_sym_COMMA] = ACTIONS(6266),
    [anon_sym_RPAREN] = ACTIONS(6266),
    [anon_sym_LPAREN2] = ACTIONS(6266),
    [anon_sym_TILDE] = ACTIONS(6266),
    [anon_sym_STAR] = ACTIONS(6266),
    [anon_sym_AMP_AMP] = ACTIONS(6266),
    [anon_sym_AMP] = ACTIONS(6268),
    [anon_sym_SEMI] = ACTIONS(6266),
    [anon_sym___extension__] = ACTIONS(6268),
    [anon_sym___device__] = ACTIONS(6268),
    [anon_sym___host__] = ACTIONS(6268),
    [anon_sym___global__] = ACTIONS(6268),
    [anon_sym___forceinline__] = ACTIONS(6268),
    [anon_sym___noinline__] = ACTIONS(6268),
    [anon_sym_virtual] = ACTIONS(6268),
    [anon_sym_extern] = ACTIONS(6268),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6266),
    [anon_sym___declspec] = ACTIONS(6268),
    [anon_sym___based] = ACTIONS(6268),
    [anon_sym___cdecl] = ACTIONS(6268),
    [anon_sym___clrcall] = ACTIONS(6268),
    [anon_sym___stdcall] = ACTIONS(6268),
    [anon_sym___fastcall] = ACTIONS(6268),
    [anon_sym___thiscall] = ACTIONS(6268),
    [anon_sym___vectorcall] = ACTIONS(6268),
    [anon_sym_LBRACK] = ACTIONS(6268),
    [anon_sym_static] = ACTIONS(6268),
    [anon_sym_EQ] = ACTIONS(6266),
    [anon_sym_register] = ACTIONS(6268),
    [anon_sym_inline] = ACTIONS(6268),
    [anon_sym___inline] = ACTIONS(6268),
    [anon_sym___inline__] = ACTIONS(6268),
    [anon_sym___forceinline] = ACTIONS(6268),
    [anon_sym_thread_local] = ACTIONS(6268),
    [anon_sym___thread] = ACTIONS(6268),
    [anon_sym_const] = ACTIONS(6268),
    [anon_sym_constexpr] = ACTIONS(6268),
    [anon_sym_volatile] = ACTIONS(6268),
    [anon_sym_restrict] = ACTIONS(6268),
    [anon_sym___restrict__] = ACTIONS(6268),
    [anon_sym__Atomic] = ACTIONS(6268),
    [anon_sym__Noreturn] = ACTIONS(6268),
    [anon_sym_noreturn] = ACTIONS(6268),
    [anon_sym__Nonnull] = ACTIONS(6268),
    [anon_sym_mutable] = ACTIONS(6268),
    [anon_sym_constinit] = ACTIONS(6268),
    [anon_sym_consteval] = ACTIONS(6268),
    [anon_sym___shared__] = ACTIONS(6268),
    [anon_sym___local__] = ACTIONS(6268),
    [anon_sym___constant__] = ACTIONS(6268),
    [anon_sym___managed__] = ACTIONS(6268),
    [anon_sym___grid_constant__] = ACTIONS(6268),
    [anon_sym_alignas] = ACTIONS(6268),
    [anon_sym__Alignas] = ACTIONS(6268),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6268),
    [anon_sym_decltype] = ACTIONS(6268),
    [anon_sym_template] = ACTIONS(6268),
    [anon_sym_GT2] = ACTIONS(6266),
    [anon_sym_operator] = ACTIONS(6268),
    [anon_sym___launch_bounds__] = ACTIONS(6268),
  },
  [STATE(2551)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5784),
    [anon_sym_COMMA] = ACTIONS(5784),
    [anon_sym_LPAREN2] = ACTIONS(5784),
    [anon_sym_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(5782),
    [anon_sym_STAR] = ACTIONS(5784),
    [anon_sym_SLASH] = ACTIONS(5782),
    [anon_sym_PERCENT] = ACTIONS(5784),
    [anon_sym_PIPE_PIPE] = ACTIONS(5784),
    [anon_sym_AMP_AMP] = ACTIONS(5784),
    [anon_sym_PIPE] = ACTIONS(5782),
    [anon_sym_CARET] = ACTIONS(5784),
    [anon_sym_AMP] = ACTIONS(5782),
    [anon_sym_EQ_EQ] = ACTIONS(5784),
    [anon_sym_BANG_EQ] = ACTIONS(5784),
    [anon_sym_GT] = ACTIONS(5782),
    [anon_sym_GT_EQ] = ACTIONS(5782),
    [anon_sym_LT_EQ] = ACTIONS(5782),
    [anon_sym_LT] = ACTIONS(5782),
    [anon_sym_LT_LT] = ACTIONS(5782),
    [anon_sym_GT_GT] = ACTIONS(5782),
    [anon_sym___extension__] = ACTIONS(5784),
    [anon_sym___global__] = ACTIONS(5784),
    [anon_sym___attribute__] = ACTIONS(5784),
    [anon_sym___attribute] = ACTIONS(5782),
    [anon_sym_LBRACE] = ACTIONS(5784),
    [anon_sym_LBRACK] = ACTIONS(5784),
    [anon_sym_const] = ACTIONS(5782),
    [anon_sym_constexpr] = ACTIONS(5784),
    [anon_sym_volatile] = ACTIONS(5784),
    [anon_sym_restrict] = ACTIONS(5784),
    [anon_sym___restrict__] = ACTIONS(5784),
    [anon_sym__Atomic] = ACTIONS(5784),
    [anon_sym__Noreturn] = ACTIONS(5784),
    [anon_sym_noreturn] = ACTIONS(5784),
    [anon_sym__Nonnull] = ACTIONS(5784),
    [anon_sym_mutable] = ACTIONS(5784),
    [anon_sym_constinit] = ACTIONS(5784),
    [anon_sym_consteval] = ACTIONS(5784),
    [anon_sym___shared__] = ACTIONS(5784),
    [anon_sym___local__] = ACTIONS(5784),
    [anon_sym___constant__] = ACTIONS(5784),
    [anon_sym___managed__] = ACTIONS(5784),
    [anon_sym___grid_constant__] = ACTIONS(5784),
    [anon_sym_alignas] = ACTIONS(5784),
    [anon_sym__Alignas] = ACTIONS(5784),
    [anon_sym_QMARK] = ACTIONS(5784),
    [anon_sym_LT_EQ_GT] = ACTIONS(5784),
    [anon_sym_or] = ACTIONS(5784),
    [anon_sym_and] = ACTIONS(5784),
    [anon_sym_bitor] = ACTIONS(5784),
    [anon_sym_xor] = ACTIONS(5784),
    [anon_sym_bitand] = ACTIONS(5784),
    [anon_sym_not_eq] = ACTIONS(5784),
    [anon_sym_DASH_DASH] = ACTIONS(5784),
    [anon_sym_PLUS_PLUS] = ACTIONS(5784),
    [anon_sym_DOT] = ACTIONS(5782),
    [anon_sym_DOT_STAR] = ACTIONS(5784),
    [anon_sym_DASH_GT] = ACTIONS(5784),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5784),
    [anon_sym_decltype] = ACTIONS(5784),
    [anon_sym_final] = ACTIONS(5784),
    [anon_sym_override] = ACTIONS(5784),
    [anon_sym_GT2] = ACTIONS(5784),
    [anon_sym_requires] = ACTIONS(5784),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5784),
  },
  [STATE(2552)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5684),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym___extension__] = ACTIONS(5686),
    [anon_sym___global__] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5686),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5686),
    [anon_sym_volatile] = ACTIONS(5686),
    [anon_sym_restrict] = ACTIONS(5686),
    [anon_sym___restrict__] = ACTIONS(5686),
    [anon_sym__Atomic] = ACTIONS(5686),
    [anon_sym__Noreturn] = ACTIONS(5686),
    [anon_sym_noreturn] = ACTIONS(5686),
    [anon_sym__Nonnull] = ACTIONS(5686),
    [anon_sym_mutable] = ACTIONS(5686),
    [anon_sym_constinit] = ACTIONS(5686),
    [anon_sym_consteval] = ACTIONS(5686),
    [anon_sym___shared__] = ACTIONS(5686),
    [anon_sym___local__] = ACTIONS(5686),
    [anon_sym___constant__] = ACTIONS(5686),
    [anon_sym___managed__] = ACTIONS(5686),
    [anon_sym___grid_constant__] = ACTIONS(5686),
    [anon_sym_alignas] = ACTIONS(5686),
    [anon_sym__Alignas] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_bitor] = ACTIONS(5686),
    [anon_sym_xor] = ACTIONS(5686),
    [anon_sym_bitand] = ACTIONS(5686),
    [anon_sym_not_eq] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5686),
    [anon_sym_decltype] = ACTIONS(5686),
    [anon_sym_final] = ACTIONS(5686),
    [anon_sym_override] = ACTIONS(5686),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_requires] = ACTIONS(5686),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2553)] = {
    [sym_attribute_specifier] = STATE(2250),
    [sym_identifier] = ACTIONS(6218),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6216),
    [anon_sym_COMMA] = ACTIONS(6216),
    [anon_sym_RPAREN] = ACTIONS(6216),
    [anon_sym_LPAREN2] = ACTIONS(6216),
    [anon_sym_TILDE] = ACTIONS(6216),
    [anon_sym_STAR] = ACTIONS(6216),
    [anon_sym_AMP_AMP] = ACTIONS(6216),
    [anon_sym_AMP] = ACTIONS(6218),
    [anon_sym_SEMI] = ACTIONS(6216),
    [anon_sym___extension__] = ACTIONS(6218),
    [anon_sym___device__] = ACTIONS(6218),
    [anon_sym___host__] = ACTIONS(6218),
    [anon_sym___global__] = ACTIONS(6218),
    [anon_sym___forceinline__] = ACTIONS(6218),
    [anon_sym___noinline__] = ACTIONS(6218),
    [anon_sym_virtual] = ACTIONS(6218),
    [anon_sym_extern] = ACTIONS(6218),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6216),
    [anon_sym___declspec] = ACTIONS(6218),
    [anon_sym___based] = ACTIONS(6218),
    [anon_sym___cdecl] = ACTIONS(6218),
    [anon_sym___clrcall] = ACTIONS(6218),
    [anon_sym___stdcall] = ACTIONS(6218),
    [anon_sym___fastcall] = ACTIONS(6218),
    [anon_sym___thiscall] = ACTIONS(6218),
    [anon_sym___vectorcall] = ACTIONS(6218),
    [anon_sym_LBRACK] = ACTIONS(6218),
    [anon_sym_static] = ACTIONS(6218),
    [anon_sym_EQ] = ACTIONS(6216),
    [anon_sym_register] = ACTIONS(6218),
    [anon_sym_inline] = ACTIONS(6218),
    [anon_sym___inline] = ACTIONS(6218),
    [anon_sym___inline__] = ACTIONS(6218),
    [anon_sym___forceinline] = ACTIONS(6218),
    [anon_sym_thread_local] = ACTIONS(6218),
    [anon_sym___thread] = ACTIONS(6218),
    [anon_sym_const] = ACTIONS(6218),
    [anon_sym_constexpr] = ACTIONS(6218),
    [anon_sym_volatile] = ACTIONS(6218),
    [anon_sym_restrict] = ACTIONS(6218),
    [anon_sym___restrict__] = ACTIONS(6218),
    [anon_sym__Atomic] = ACTIONS(6218),
    [anon_sym__Noreturn] = ACTIONS(6218),
    [anon_sym_noreturn] = ACTIONS(6218),
    [anon_sym__Nonnull] = ACTIONS(6218),
    [anon_sym_mutable] = ACTIONS(6218),
    [anon_sym_constinit] = ACTIONS(6218),
    [anon_sym_consteval] = ACTIONS(6218),
    [anon_sym___shared__] = ACTIONS(6218),
    [anon_sym___local__] = ACTIONS(6218),
    [anon_sym___constant__] = ACTIONS(6218),
    [anon_sym___managed__] = ACTIONS(6218),
    [anon_sym___grid_constant__] = ACTIONS(6218),
    [anon_sym_alignas] = ACTIONS(6218),
    [anon_sym__Alignas] = ACTIONS(6218),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6218),
    [anon_sym_decltype] = ACTIONS(6218),
    [anon_sym_template] = ACTIONS(6218),
    [anon_sym_GT2] = ACTIONS(6216),
    [anon_sym_operator] = ACTIONS(6218),
    [anon_sym___launch_bounds__] = ACTIONS(6218),
  },
  [STATE(2554)] = {
    [sym_identifier] = ACTIONS(5758),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5760),
    [anon_sym_COMMA] = ACTIONS(5760),
    [anon_sym_RPAREN] = ACTIONS(5760),
    [aux_sym_preproc_if_token2] = ACTIONS(5760),
    [aux_sym_preproc_else_token1] = ACTIONS(5760),
    [aux_sym_preproc_elif_token1] = ACTIONS(5758),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5760),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5760),
    [anon_sym_LPAREN2] = ACTIONS(5760),
    [anon_sym_DASH] = ACTIONS(5758),
    [anon_sym_PLUS] = ACTIONS(5758),
    [anon_sym_STAR] = ACTIONS(5758),
    [anon_sym_SLASH] = ACTIONS(5758),
    [anon_sym_PERCENT] = ACTIONS(5758),
    [anon_sym_PIPE_PIPE] = ACTIONS(5760),
    [anon_sym_AMP_AMP] = ACTIONS(5760),
    [anon_sym_PIPE] = ACTIONS(5758),
    [anon_sym_CARET] = ACTIONS(5758),
    [anon_sym_AMP] = ACTIONS(5758),
    [anon_sym_EQ_EQ] = ACTIONS(5760),
    [anon_sym_BANG_EQ] = ACTIONS(5760),
    [anon_sym_GT] = ACTIONS(5758),
    [anon_sym_GT_EQ] = ACTIONS(5760),
    [anon_sym_LT_EQ] = ACTIONS(5758),
    [anon_sym_LT] = ACTIONS(5758),
    [anon_sym_LT_LT] = ACTIONS(5758),
    [anon_sym_GT_GT] = ACTIONS(5758),
    [anon_sym_SEMI] = ACTIONS(5760),
    [anon_sym___attribute__] = ACTIONS(5758),
    [anon_sym___attribute] = ACTIONS(5758),
    [anon_sym_LBRACE] = ACTIONS(5760),
    [anon_sym_RBRACE] = ACTIONS(5760),
    [anon_sym_LBRACK] = ACTIONS(5760),
    [anon_sym_RBRACK] = ACTIONS(5760),
    [anon_sym_EQ] = ACTIONS(5758),
    [anon_sym_COLON] = ACTIONS(5760),
    [anon_sym_QMARK] = ACTIONS(5760),
    [anon_sym_STAR_EQ] = ACTIONS(5760),
    [anon_sym_SLASH_EQ] = ACTIONS(5760),
    [anon_sym_PERCENT_EQ] = ACTIONS(5760),
    [anon_sym_PLUS_EQ] = ACTIONS(5760),
    [anon_sym_DASH_EQ] = ACTIONS(5760),
    [anon_sym_LT_LT_EQ] = ACTIONS(5760),
    [anon_sym_GT_GT_EQ] = ACTIONS(5760),
    [anon_sym_AMP_EQ] = ACTIONS(5760),
    [anon_sym_CARET_EQ] = ACTIONS(5760),
    [anon_sym_PIPE_EQ] = ACTIONS(5760),
    [anon_sym_and_eq] = ACTIONS(5758),
    [anon_sym_or_eq] = ACTIONS(5758),
    [anon_sym_xor_eq] = ACTIONS(5758),
    [anon_sym_LT_EQ_GT] = ACTIONS(5760),
    [anon_sym_or] = ACTIONS(5758),
    [anon_sym_and] = ACTIONS(5758),
    [anon_sym_bitor] = ACTIONS(5758),
    [anon_sym_xor] = ACTIONS(5758),
    [anon_sym_bitand] = ACTIONS(5758),
    [anon_sym_not_eq] = ACTIONS(5758),
    [anon_sym_DASH_DASH] = ACTIONS(5760),
    [anon_sym_PLUS_PLUS] = ACTIONS(5760),
    [anon_sym_DOT] = ACTIONS(5758),
    [anon_sym_DOT_STAR] = ACTIONS(5760),
    [anon_sym_DASH_GT] = ACTIONS(5760),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5758),
    [anon_sym_decltype] = ACTIONS(5758),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5760),
  },
  [STATE(2555)] = {
    [sym_attribute_specifier] = STATE(2252),
    [sym_identifier] = ACTIONS(6279),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6277),
    [anon_sym_COMMA] = ACTIONS(6277),
    [anon_sym_RPAREN] = ACTIONS(6277),
    [anon_sym_LPAREN2] = ACTIONS(6277),
    [anon_sym_TILDE] = ACTIONS(6277),
    [anon_sym_STAR] = ACTIONS(6277),
    [anon_sym_AMP_AMP] = ACTIONS(6277),
    [anon_sym_AMP] = ACTIONS(6279),
    [anon_sym_SEMI] = ACTIONS(6277),
    [anon_sym___extension__] = ACTIONS(6279),
    [anon_sym___device__] = ACTIONS(6279),
    [anon_sym___host__] = ACTIONS(6279),
    [anon_sym___global__] = ACTIONS(6279),
    [anon_sym___forceinline__] = ACTIONS(6279),
    [anon_sym___noinline__] = ACTIONS(6279),
    [anon_sym_virtual] = ACTIONS(6279),
    [anon_sym_extern] = ACTIONS(6279),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6277),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6277),
    [anon_sym___declspec] = ACTIONS(6279),
    [anon_sym___based] = ACTIONS(6279),
    [anon_sym___cdecl] = ACTIONS(6279),
    [anon_sym___clrcall] = ACTIONS(6279),
    [anon_sym___stdcall] = ACTIONS(6279),
    [anon_sym___fastcall] = ACTIONS(6279),
    [anon_sym___thiscall] = ACTIONS(6279),
    [anon_sym___vectorcall] = ACTIONS(6279),
    [anon_sym_LBRACK] = ACTIONS(6279),
    [anon_sym_static] = ACTIONS(6279),
    [anon_sym_EQ] = ACTIONS(6277),
    [anon_sym_register] = ACTIONS(6279),
    [anon_sym_inline] = ACTIONS(6279),
    [anon_sym___inline] = ACTIONS(6279),
    [anon_sym___inline__] = ACTIONS(6279),
    [anon_sym___forceinline] = ACTIONS(6279),
    [anon_sym_thread_local] = ACTIONS(6279),
    [anon_sym___thread] = ACTIONS(6279),
    [anon_sym_const] = ACTIONS(6279),
    [anon_sym_constexpr] = ACTIONS(6279),
    [anon_sym_volatile] = ACTIONS(6279),
    [anon_sym_restrict] = ACTIONS(6279),
    [anon_sym___restrict__] = ACTIONS(6279),
    [anon_sym__Atomic] = ACTIONS(6279),
    [anon_sym__Noreturn] = ACTIONS(6279),
    [anon_sym_noreturn] = ACTIONS(6279),
    [anon_sym__Nonnull] = ACTIONS(6279),
    [anon_sym_mutable] = ACTIONS(6279),
    [anon_sym_constinit] = ACTIONS(6279),
    [anon_sym_consteval] = ACTIONS(6279),
    [anon_sym___shared__] = ACTIONS(6279),
    [anon_sym___local__] = ACTIONS(6279),
    [anon_sym___constant__] = ACTIONS(6279),
    [anon_sym___managed__] = ACTIONS(6279),
    [anon_sym___grid_constant__] = ACTIONS(6279),
    [anon_sym_alignas] = ACTIONS(6279),
    [anon_sym__Alignas] = ACTIONS(6279),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6279),
    [anon_sym_decltype] = ACTIONS(6279),
    [anon_sym_template] = ACTIONS(6279),
    [anon_sym_GT2] = ACTIONS(6277),
    [anon_sym_operator] = ACTIONS(6279),
    [anon_sym___launch_bounds__] = ACTIONS(6279),
  },
  [STATE(2556)] = {
    [sym_identifier] = ACTIONS(5762),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5764),
    [anon_sym_COMMA] = ACTIONS(5764),
    [anon_sym_RPAREN] = ACTIONS(5764),
    [aux_sym_preproc_if_token2] = ACTIONS(5764),
    [aux_sym_preproc_else_token1] = ACTIONS(5764),
    [aux_sym_preproc_elif_token1] = ACTIONS(5762),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5764),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5764),
    [anon_sym_LPAREN2] = ACTIONS(5764),
    [anon_sym_DASH] = ACTIONS(5762),
    [anon_sym_PLUS] = ACTIONS(5762),
    [anon_sym_STAR] = ACTIONS(5762),
    [anon_sym_SLASH] = ACTIONS(5762),
    [anon_sym_PERCENT] = ACTIONS(5762),
    [anon_sym_PIPE_PIPE] = ACTIONS(5764),
    [anon_sym_AMP_AMP] = ACTIONS(5764),
    [anon_sym_PIPE] = ACTIONS(5762),
    [anon_sym_CARET] = ACTIONS(5762),
    [anon_sym_AMP] = ACTIONS(5762),
    [anon_sym_EQ_EQ] = ACTIONS(5764),
    [anon_sym_BANG_EQ] = ACTIONS(5764),
    [anon_sym_GT] = ACTIONS(5762),
    [anon_sym_GT_EQ] = ACTIONS(5764),
    [anon_sym_LT_EQ] = ACTIONS(5762),
    [anon_sym_LT] = ACTIONS(5762),
    [anon_sym_LT_LT] = ACTIONS(5762),
    [anon_sym_GT_GT] = ACTIONS(5762),
    [anon_sym_SEMI] = ACTIONS(5764),
    [anon_sym___attribute__] = ACTIONS(5762),
    [anon_sym___attribute] = ACTIONS(5762),
    [anon_sym_LBRACE] = ACTIONS(5764),
    [anon_sym_RBRACE] = ACTIONS(5764),
    [anon_sym_LBRACK] = ACTIONS(5764),
    [anon_sym_RBRACK] = ACTIONS(5764),
    [anon_sym_EQ] = ACTIONS(5762),
    [anon_sym_COLON] = ACTIONS(5764),
    [anon_sym_QMARK] = ACTIONS(5764),
    [anon_sym_STAR_EQ] = ACTIONS(5764),
    [anon_sym_SLASH_EQ] = ACTIONS(5764),
    [anon_sym_PERCENT_EQ] = ACTIONS(5764),
    [anon_sym_PLUS_EQ] = ACTIONS(5764),
    [anon_sym_DASH_EQ] = ACTIONS(5764),
    [anon_sym_LT_LT_EQ] = ACTIONS(5764),
    [anon_sym_GT_GT_EQ] = ACTIONS(5764),
    [anon_sym_AMP_EQ] = ACTIONS(5764),
    [anon_sym_CARET_EQ] = ACTIONS(5764),
    [anon_sym_PIPE_EQ] = ACTIONS(5764),
    [anon_sym_and_eq] = ACTIONS(5762),
    [anon_sym_or_eq] = ACTIONS(5762),
    [anon_sym_xor_eq] = ACTIONS(5762),
    [anon_sym_LT_EQ_GT] = ACTIONS(5764),
    [anon_sym_or] = ACTIONS(5762),
    [anon_sym_and] = ACTIONS(5762),
    [anon_sym_bitor] = ACTIONS(5762),
    [anon_sym_xor] = ACTIONS(5762),
    [anon_sym_bitand] = ACTIONS(5762),
    [anon_sym_not_eq] = ACTIONS(5762),
    [anon_sym_DASH_DASH] = ACTIONS(5764),
    [anon_sym_PLUS_PLUS] = ACTIONS(5764),
    [anon_sym_DOT] = ACTIONS(5762),
    [anon_sym_DOT_STAR] = ACTIONS(5764),
    [anon_sym_DASH_GT] = ACTIONS(5764),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5762),
    [anon_sym_decltype] = ACTIONS(5762),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5764),
  },
  [STATE(2557)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6194),
    [anon_sym_COMMA] = ACTIONS(6194),
    [anon_sym_RPAREN] = ACTIONS(6194),
    [anon_sym_LPAREN2] = ACTIONS(6194),
    [anon_sym_DASH] = ACTIONS(6192),
    [anon_sym_PLUS] = ACTIONS(6192),
    [anon_sym_STAR] = ACTIONS(6192),
    [anon_sym_SLASH] = ACTIONS(6192),
    [anon_sym_PERCENT] = ACTIONS(6192),
    [anon_sym_PIPE_PIPE] = ACTIONS(6194),
    [anon_sym_AMP_AMP] = ACTIONS(6194),
    [anon_sym_PIPE] = ACTIONS(6192),
    [anon_sym_CARET] = ACTIONS(6192),
    [anon_sym_AMP] = ACTIONS(6192),
    [anon_sym_EQ_EQ] = ACTIONS(6194),
    [anon_sym_BANG_EQ] = ACTIONS(6194),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_GT_EQ] = ACTIONS(6194),
    [anon_sym_LT_EQ] = ACTIONS(6192),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_LT_LT] = ACTIONS(6192),
    [anon_sym_GT_GT] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [anon_sym_RBRACE] = ACTIONS(6194),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [anon_sym_RBRACK] = ACTIONS(6194),
    [anon_sym_EQ] = ACTIONS(6192),
    [anon_sym_COLON] = ACTIONS(6194),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_STAR_EQ] = ACTIONS(6194),
    [anon_sym_SLASH_EQ] = ACTIONS(6194),
    [anon_sym_PERCENT_EQ] = ACTIONS(6194),
    [anon_sym_PLUS_EQ] = ACTIONS(6194),
    [anon_sym_DASH_EQ] = ACTIONS(6194),
    [anon_sym_LT_LT_EQ] = ACTIONS(6194),
    [anon_sym_GT_GT_EQ] = ACTIONS(6194),
    [anon_sym_AMP_EQ] = ACTIONS(6194),
    [anon_sym_CARET_EQ] = ACTIONS(6194),
    [anon_sym_PIPE_EQ] = ACTIONS(6194),
    [anon_sym_and_eq] = ACTIONS(6192),
    [anon_sym_or_eq] = ACTIONS(6192),
    [anon_sym_xor_eq] = ACTIONS(6192),
    [anon_sym_LT_EQ_GT] = ACTIONS(6194),
    [anon_sym_or] = ACTIONS(6192),
    [anon_sym_and] = ACTIONS(6192),
    [anon_sym_bitor] = ACTIONS(6192),
    [anon_sym_xor] = ACTIONS(6192),
    [anon_sym_bitand] = ACTIONS(6192),
    [anon_sym_not_eq] = ACTIONS(6192),
    [anon_sym_DASH_DASH] = ACTIONS(6194),
    [anon_sym_PLUS_PLUS] = ACTIONS(6194),
    [anon_sym_DOT] = ACTIONS(6192),
    [anon_sym_DOT_STAR] = ACTIONS(6194),
    [anon_sym_DASH_GT] = ACTIONS(6194),
    [anon_sym_L_DQUOTE] = ACTIONS(6194),
    [anon_sym_u_DQUOTE] = ACTIONS(6194),
    [anon_sym_U_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8_DQUOTE] = ACTIONS(6194),
    [anon_sym_DQUOTE] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6194),
    [anon_sym_LR_DQUOTE] = ACTIONS(6194),
    [anon_sym_uR_DQUOTE] = ACTIONS(6194),
    [anon_sym_UR_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6194),
    [sym_literal_suffix] = ACTIONS(6192),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6194),
  },
  [STATE(2558)] = {
    [sym_attribute_specifier] = STATE(2263),
    [sym_identifier] = ACTIONS(6236),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6234),
    [anon_sym_COMMA] = ACTIONS(6234),
    [anon_sym_RPAREN] = ACTIONS(6234),
    [anon_sym_LPAREN2] = ACTIONS(6234),
    [anon_sym_TILDE] = ACTIONS(6234),
    [anon_sym_STAR] = ACTIONS(6234),
    [anon_sym_AMP_AMP] = ACTIONS(6234),
    [anon_sym_AMP] = ACTIONS(6236),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym___extension__] = ACTIONS(6236),
    [anon_sym___device__] = ACTIONS(6236),
    [anon_sym___host__] = ACTIONS(6236),
    [anon_sym___global__] = ACTIONS(6236),
    [anon_sym___forceinline__] = ACTIONS(6236),
    [anon_sym___noinline__] = ACTIONS(6236),
    [anon_sym_virtual] = ACTIONS(6236),
    [anon_sym_extern] = ACTIONS(6236),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6234),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6234),
    [anon_sym___declspec] = ACTIONS(6236),
    [anon_sym___based] = ACTIONS(6236),
    [anon_sym___cdecl] = ACTIONS(6236),
    [anon_sym___clrcall] = ACTIONS(6236),
    [anon_sym___stdcall] = ACTIONS(6236),
    [anon_sym___fastcall] = ACTIONS(6236),
    [anon_sym___thiscall] = ACTIONS(6236),
    [anon_sym___vectorcall] = ACTIONS(6236),
    [anon_sym_LBRACK] = ACTIONS(6236),
    [anon_sym_static] = ACTIONS(6236),
    [anon_sym_EQ] = ACTIONS(6234),
    [anon_sym_register] = ACTIONS(6236),
    [anon_sym_inline] = ACTIONS(6236),
    [anon_sym___inline] = ACTIONS(6236),
    [anon_sym___inline__] = ACTIONS(6236),
    [anon_sym___forceinline] = ACTIONS(6236),
    [anon_sym_thread_local] = ACTIONS(6236),
    [anon_sym___thread] = ACTIONS(6236),
    [anon_sym_const] = ACTIONS(6236),
    [anon_sym_constexpr] = ACTIONS(6236),
    [anon_sym_volatile] = ACTIONS(6236),
    [anon_sym_restrict] = ACTIONS(6236),
    [anon_sym___restrict__] = ACTIONS(6236),
    [anon_sym__Atomic] = ACTIONS(6236),
    [anon_sym__Noreturn] = ACTIONS(6236),
    [anon_sym_noreturn] = ACTIONS(6236),
    [anon_sym__Nonnull] = ACTIONS(6236),
    [anon_sym_mutable] = ACTIONS(6236),
    [anon_sym_constinit] = ACTIONS(6236),
    [anon_sym_consteval] = ACTIONS(6236),
    [anon_sym___shared__] = ACTIONS(6236),
    [anon_sym___local__] = ACTIONS(6236),
    [anon_sym___constant__] = ACTIONS(6236),
    [anon_sym___managed__] = ACTIONS(6236),
    [anon_sym___grid_constant__] = ACTIONS(6236),
    [anon_sym_alignas] = ACTIONS(6236),
    [anon_sym__Alignas] = ACTIONS(6236),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6236),
    [anon_sym_decltype] = ACTIONS(6236),
    [anon_sym_template] = ACTIONS(6236),
    [anon_sym_GT2] = ACTIONS(6234),
    [anon_sym_operator] = ACTIONS(6236),
    [anon_sym___launch_bounds__] = ACTIONS(6236),
  },
  [STATE(2559)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5698),
    [anon_sym_COMMA] = ACTIONS(5698),
    [anon_sym_LPAREN2] = ACTIONS(5698),
    [anon_sym_DASH] = ACTIONS(5696),
    [anon_sym_PLUS] = ACTIONS(5696),
    [anon_sym_STAR] = ACTIONS(5698),
    [anon_sym_SLASH] = ACTIONS(5696),
    [anon_sym_PERCENT] = ACTIONS(5698),
    [anon_sym_PIPE_PIPE] = ACTIONS(5698),
    [anon_sym_AMP_AMP] = ACTIONS(5698),
    [anon_sym_PIPE] = ACTIONS(5696),
    [anon_sym_CARET] = ACTIONS(5698),
    [anon_sym_AMP] = ACTIONS(5696),
    [anon_sym_EQ_EQ] = ACTIONS(5698),
    [anon_sym_BANG_EQ] = ACTIONS(5698),
    [anon_sym_GT] = ACTIONS(5696),
    [anon_sym_GT_EQ] = ACTIONS(5696),
    [anon_sym_LT_EQ] = ACTIONS(5696),
    [anon_sym_LT] = ACTIONS(5696),
    [anon_sym_LT_LT] = ACTIONS(5696),
    [anon_sym_GT_GT] = ACTIONS(5696),
    [anon_sym___extension__] = ACTIONS(5698),
    [anon_sym___global__] = ACTIONS(5698),
    [anon_sym___attribute__] = ACTIONS(5698),
    [anon_sym___attribute] = ACTIONS(5696),
    [anon_sym_LBRACE] = ACTIONS(5698),
    [anon_sym_LBRACK] = ACTIONS(5698),
    [anon_sym_const] = ACTIONS(5696),
    [anon_sym_constexpr] = ACTIONS(5698),
    [anon_sym_volatile] = ACTIONS(5698),
    [anon_sym_restrict] = ACTIONS(5698),
    [anon_sym___restrict__] = ACTIONS(5698),
    [anon_sym__Atomic] = ACTIONS(5698),
    [anon_sym__Noreturn] = ACTIONS(5698),
    [anon_sym_noreturn] = ACTIONS(5698),
    [anon_sym__Nonnull] = ACTIONS(5698),
    [anon_sym_mutable] = ACTIONS(5698),
    [anon_sym_constinit] = ACTIONS(5698),
    [anon_sym_consteval] = ACTIONS(5698),
    [anon_sym___shared__] = ACTIONS(5698),
    [anon_sym___local__] = ACTIONS(5698),
    [anon_sym___constant__] = ACTIONS(5698),
    [anon_sym___managed__] = ACTIONS(5698),
    [anon_sym___grid_constant__] = ACTIONS(5698),
    [anon_sym_alignas] = ACTIONS(5698),
    [anon_sym__Alignas] = ACTIONS(5698),
    [anon_sym_QMARK] = ACTIONS(5698),
    [anon_sym_LT_EQ_GT] = ACTIONS(5698),
    [anon_sym_or] = ACTIONS(5698),
    [anon_sym_and] = ACTIONS(5698),
    [anon_sym_bitor] = ACTIONS(5698),
    [anon_sym_xor] = ACTIONS(5698),
    [anon_sym_bitand] = ACTIONS(5698),
    [anon_sym_not_eq] = ACTIONS(5698),
    [anon_sym_DASH_DASH] = ACTIONS(5698),
    [anon_sym_PLUS_PLUS] = ACTIONS(5698),
    [anon_sym_DOT] = ACTIONS(5696),
    [anon_sym_DOT_STAR] = ACTIONS(5698),
    [anon_sym_DASH_GT] = ACTIONS(5698),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5698),
    [anon_sym_decltype] = ACTIONS(5698),
    [anon_sym_final] = ACTIONS(5698),
    [anon_sym_override] = ACTIONS(5698),
    [anon_sym_GT2] = ACTIONS(5698),
    [anon_sym_requires] = ACTIONS(5698),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5698),
  },
  [STATE(2560)] = {
    [sym_argument_list] = STATE(2829),
    [sym_initializer_list] = STATE(2829),
    [sym_identifier] = ACTIONS(6568),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6570),
    [anon_sym_COMMA] = ACTIONS(6570),
    [anon_sym_RPAREN] = ACTIONS(6570),
    [aux_sym_preproc_if_token2] = ACTIONS(6570),
    [aux_sym_preproc_else_token1] = ACTIONS(6570),
    [aux_sym_preproc_elif_token1] = ACTIONS(6568),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6570),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6570),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6568),
    [anon_sym_PLUS] = ACTIONS(6568),
    [anon_sym_STAR] = ACTIONS(6568),
    [anon_sym_SLASH] = ACTIONS(6568),
    [anon_sym_PERCENT] = ACTIONS(6568),
    [anon_sym_PIPE_PIPE] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6570),
    [anon_sym_PIPE] = ACTIONS(6568),
    [anon_sym_CARET] = ACTIONS(6568),
    [anon_sym_AMP] = ACTIONS(6568),
    [anon_sym_EQ_EQ] = ACTIONS(6570),
    [anon_sym_BANG_EQ] = ACTIONS(6570),
    [anon_sym_GT] = ACTIONS(6568),
    [anon_sym_GT_EQ] = ACTIONS(6570),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_LT] = ACTIONS(6568),
    [anon_sym_LT_LT] = ACTIONS(6568),
    [anon_sym_GT_GT] = ACTIONS(6568),
    [anon_sym_SEMI] = ACTIONS(6570),
    [anon_sym___attribute__] = ACTIONS(6568),
    [anon_sym___attribute] = ACTIONS(6568),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(6570),
    [anon_sym_LBRACK] = ACTIONS(6570),
    [anon_sym_RBRACK] = ACTIONS(6570),
    [anon_sym_EQ] = ACTIONS(6568),
    [anon_sym_COLON] = ACTIONS(6570),
    [anon_sym_QMARK] = ACTIONS(6570),
    [anon_sym_STAR_EQ] = ACTIONS(6570),
    [anon_sym_SLASH_EQ] = ACTIONS(6570),
    [anon_sym_PERCENT_EQ] = ACTIONS(6570),
    [anon_sym_PLUS_EQ] = ACTIONS(6570),
    [anon_sym_DASH_EQ] = ACTIONS(6570),
    [anon_sym_LT_LT_EQ] = ACTIONS(6570),
    [anon_sym_GT_GT_EQ] = ACTIONS(6570),
    [anon_sym_AMP_EQ] = ACTIONS(6570),
    [anon_sym_CARET_EQ] = ACTIONS(6570),
    [anon_sym_PIPE_EQ] = ACTIONS(6570),
    [anon_sym_and_eq] = ACTIONS(6568),
    [anon_sym_or_eq] = ACTIONS(6568),
    [anon_sym_xor_eq] = ACTIONS(6568),
    [anon_sym_LT_EQ_GT] = ACTIONS(6570),
    [anon_sym_or] = ACTIONS(6568),
    [anon_sym_and] = ACTIONS(6568),
    [anon_sym_bitor] = ACTIONS(6568),
    [anon_sym_xor] = ACTIONS(6568),
    [anon_sym_bitand] = ACTIONS(6568),
    [anon_sym_not_eq] = ACTIONS(6568),
    [anon_sym_DASH_DASH] = ACTIONS(6570),
    [anon_sym_PLUS_PLUS] = ACTIONS(6570),
    [anon_sym_DOT] = ACTIONS(6568),
    [anon_sym_DOT_STAR] = ACTIONS(6570),
    [anon_sym_DASH_GT] = ACTIONS(6570),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6570),
  },
  [STATE(2561)] = {
    [sym_template_argument_list] = STATE(2363),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4010),
    [anon_sym_COMMA] = ACTIONS(4010),
    [aux_sym_preproc_if_token2] = ACTIONS(4010),
    [aux_sym_preproc_else_token1] = ACTIONS(4010),
    [aux_sym_preproc_elif_token1] = ACTIONS(4002),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4010),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4010),
    [anon_sym_LPAREN2] = ACTIONS(4010),
    [anon_sym_DASH] = ACTIONS(4002),
    [anon_sym_PLUS] = ACTIONS(4002),
    [anon_sym_STAR] = ACTIONS(4002),
    [anon_sym_SLASH] = ACTIONS(4002),
    [anon_sym_PERCENT] = ACTIONS(4002),
    [anon_sym_PIPE_PIPE] = ACTIONS(4010),
    [anon_sym_AMP_AMP] = ACTIONS(4010),
    [anon_sym_PIPE] = ACTIONS(4002),
    [anon_sym_CARET] = ACTIONS(4002),
    [anon_sym_AMP] = ACTIONS(4002),
    [anon_sym_EQ_EQ] = ACTIONS(4010),
    [anon_sym_BANG_EQ] = ACTIONS(4010),
    [anon_sym_GT] = ACTIONS(4002),
    [anon_sym_GT_EQ] = ACTIONS(4010),
    [anon_sym_LT_EQ] = ACTIONS(4002),
    [anon_sym_LT] = ACTIONS(6336),
    [anon_sym_LT_LT] = ACTIONS(4002),
    [anon_sym_GT_GT] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4010),
    [anon_sym_signed] = ACTIONS(6411),
    [anon_sym_unsigned] = ACTIONS(6411),
    [anon_sym_long] = ACTIONS(6411),
    [anon_sym_short] = ACTIONS(6411),
    [anon_sym_LBRACK] = ACTIONS(4010),
    [anon_sym_EQ] = ACTIONS(4002),
    [anon_sym_QMARK] = ACTIONS(4010),
    [anon_sym_STAR_EQ] = ACTIONS(4010),
    [anon_sym_SLASH_EQ] = ACTIONS(4010),
    [anon_sym_PERCENT_EQ] = ACTIONS(4010),
    [anon_sym_PLUS_EQ] = ACTIONS(4010),
    [anon_sym_DASH_EQ] = ACTIONS(4010),
    [anon_sym_LT_LT_EQ] = ACTIONS(4010),
    [anon_sym_GT_GT_EQ] = ACTIONS(4010),
    [anon_sym_AMP_EQ] = ACTIONS(4010),
    [anon_sym_CARET_EQ] = ACTIONS(4010),
    [anon_sym_PIPE_EQ] = ACTIONS(4010),
    [anon_sym_and_eq] = ACTIONS(4002),
    [anon_sym_or_eq] = ACTIONS(4002),
    [anon_sym_xor_eq] = ACTIONS(4002),
    [anon_sym_LT_EQ_GT] = ACTIONS(4010),
    [anon_sym_or] = ACTIONS(4002),
    [anon_sym_and] = ACTIONS(4002),
    [anon_sym_bitor] = ACTIONS(4002),
    [anon_sym_xor] = ACTIONS(4002),
    [anon_sym_bitand] = ACTIONS(4002),
    [anon_sym_not_eq] = ACTIONS(4002),
    [anon_sym_DASH_DASH] = ACTIONS(4010),
    [anon_sym_PLUS_PLUS] = ACTIONS(4010),
    [anon_sym_DOT] = ACTIONS(4002),
    [anon_sym_DOT_STAR] = ACTIONS(4010),
    [anon_sym_DASH_GT] = ACTIONS(4010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4010),
  },
  [STATE(2562)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6165),
    [anon_sym_COMMA] = ACTIONS(6165),
    [anon_sym_RPAREN] = ACTIONS(6165),
    [anon_sym_LPAREN2] = ACTIONS(6165),
    [anon_sym_DASH] = ACTIONS(6163),
    [anon_sym_PLUS] = ACTIONS(6163),
    [anon_sym_STAR] = ACTIONS(6163),
    [anon_sym_SLASH] = ACTIONS(6163),
    [anon_sym_PERCENT] = ACTIONS(6163),
    [anon_sym_PIPE_PIPE] = ACTIONS(6165),
    [anon_sym_AMP_AMP] = ACTIONS(6165),
    [anon_sym_PIPE] = ACTIONS(6163),
    [anon_sym_CARET] = ACTIONS(6163),
    [anon_sym_AMP] = ACTIONS(6163),
    [anon_sym_EQ_EQ] = ACTIONS(6165),
    [anon_sym_BANG_EQ] = ACTIONS(6165),
    [anon_sym_GT] = ACTIONS(6163),
    [anon_sym_GT_EQ] = ACTIONS(6165),
    [anon_sym_LT_EQ] = ACTIONS(6163),
    [anon_sym_LT] = ACTIONS(6163),
    [anon_sym_LT_LT] = ACTIONS(6163),
    [anon_sym_GT_GT] = ACTIONS(6163),
    [anon_sym_SEMI] = ACTIONS(6165),
    [anon_sym_RBRACE] = ACTIONS(6165),
    [anon_sym_LBRACK] = ACTIONS(6165),
    [anon_sym_RBRACK] = ACTIONS(6165),
    [anon_sym_EQ] = ACTIONS(6163),
    [anon_sym_COLON] = ACTIONS(6165),
    [anon_sym_QMARK] = ACTIONS(6165),
    [anon_sym_STAR_EQ] = ACTIONS(6165),
    [anon_sym_SLASH_EQ] = ACTIONS(6165),
    [anon_sym_PERCENT_EQ] = ACTIONS(6165),
    [anon_sym_PLUS_EQ] = ACTIONS(6165),
    [anon_sym_DASH_EQ] = ACTIONS(6165),
    [anon_sym_LT_LT_EQ] = ACTIONS(6165),
    [anon_sym_GT_GT_EQ] = ACTIONS(6165),
    [anon_sym_AMP_EQ] = ACTIONS(6165),
    [anon_sym_CARET_EQ] = ACTIONS(6165),
    [anon_sym_PIPE_EQ] = ACTIONS(6165),
    [anon_sym_and_eq] = ACTIONS(6163),
    [anon_sym_or_eq] = ACTIONS(6163),
    [anon_sym_xor_eq] = ACTIONS(6163),
    [anon_sym_LT_EQ_GT] = ACTIONS(6165),
    [anon_sym_or] = ACTIONS(6163),
    [anon_sym_and] = ACTIONS(6163),
    [anon_sym_bitor] = ACTIONS(6163),
    [anon_sym_xor] = ACTIONS(6163),
    [anon_sym_bitand] = ACTIONS(6163),
    [anon_sym_not_eq] = ACTIONS(6163),
    [anon_sym_DASH_DASH] = ACTIONS(6165),
    [anon_sym_PLUS_PLUS] = ACTIONS(6165),
    [anon_sym_DOT] = ACTIONS(6163),
    [anon_sym_DOT_STAR] = ACTIONS(6165),
    [anon_sym_DASH_GT] = ACTIONS(6165),
    [anon_sym_L_DQUOTE] = ACTIONS(6165),
    [anon_sym_u_DQUOTE] = ACTIONS(6165),
    [anon_sym_U_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8_DQUOTE] = ACTIONS(6165),
    [anon_sym_DQUOTE] = ACTIONS(6165),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6165),
    [anon_sym_LR_DQUOTE] = ACTIONS(6165),
    [anon_sym_uR_DQUOTE] = ACTIONS(6165),
    [anon_sym_UR_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6165),
    [sym_literal_suffix] = ACTIONS(6163),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6165),
  },
  [STATE(2563)] = {
    [sym_attribute_specifier] = STATE(2227),
    [sym_identifier] = ACTIONS(6254),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6252),
    [anon_sym_COMMA] = ACTIONS(6252),
    [anon_sym_RPAREN] = ACTIONS(6252),
    [anon_sym_LPAREN2] = ACTIONS(6252),
    [anon_sym_TILDE] = ACTIONS(6252),
    [anon_sym_STAR] = ACTIONS(6252),
    [anon_sym_AMP_AMP] = ACTIONS(6252),
    [anon_sym_AMP] = ACTIONS(6254),
    [anon_sym_SEMI] = ACTIONS(6252),
    [anon_sym___extension__] = ACTIONS(6254),
    [anon_sym___device__] = ACTIONS(6254),
    [anon_sym___host__] = ACTIONS(6254),
    [anon_sym___global__] = ACTIONS(6254),
    [anon_sym___forceinline__] = ACTIONS(6254),
    [anon_sym___noinline__] = ACTIONS(6254),
    [anon_sym_virtual] = ACTIONS(6254),
    [anon_sym_extern] = ACTIONS(6254),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6252),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6252),
    [anon_sym___declspec] = ACTIONS(6254),
    [anon_sym___based] = ACTIONS(6254),
    [anon_sym___cdecl] = ACTIONS(6254),
    [anon_sym___clrcall] = ACTIONS(6254),
    [anon_sym___stdcall] = ACTIONS(6254),
    [anon_sym___fastcall] = ACTIONS(6254),
    [anon_sym___thiscall] = ACTIONS(6254),
    [anon_sym___vectorcall] = ACTIONS(6254),
    [anon_sym_LBRACK] = ACTIONS(6254),
    [anon_sym_static] = ACTIONS(6254),
    [anon_sym_EQ] = ACTIONS(6252),
    [anon_sym_register] = ACTIONS(6254),
    [anon_sym_inline] = ACTIONS(6254),
    [anon_sym___inline] = ACTIONS(6254),
    [anon_sym___inline__] = ACTIONS(6254),
    [anon_sym___forceinline] = ACTIONS(6254),
    [anon_sym_thread_local] = ACTIONS(6254),
    [anon_sym___thread] = ACTIONS(6254),
    [anon_sym_const] = ACTIONS(6254),
    [anon_sym_constexpr] = ACTIONS(6254),
    [anon_sym_volatile] = ACTIONS(6254),
    [anon_sym_restrict] = ACTIONS(6254),
    [anon_sym___restrict__] = ACTIONS(6254),
    [anon_sym__Atomic] = ACTIONS(6254),
    [anon_sym__Noreturn] = ACTIONS(6254),
    [anon_sym_noreturn] = ACTIONS(6254),
    [anon_sym__Nonnull] = ACTIONS(6254),
    [anon_sym_mutable] = ACTIONS(6254),
    [anon_sym_constinit] = ACTIONS(6254),
    [anon_sym_consteval] = ACTIONS(6254),
    [anon_sym___shared__] = ACTIONS(6254),
    [anon_sym___local__] = ACTIONS(6254),
    [anon_sym___constant__] = ACTIONS(6254),
    [anon_sym___managed__] = ACTIONS(6254),
    [anon_sym___grid_constant__] = ACTIONS(6254),
    [anon_sym_alignas] = ACTIONS(6254),
    [anon_sym__Alignas] = ACTIONS(6254),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6254),
    [anon_sym_decltype] = ACTIONS(6254),
    [anon_sym_template] = ACTIONS(6254),
    [anon_sym_GT2] = ACTIONS(6252),
    [anon_sym_operator] = ACTIONS(6254),
    [anon_sym___launch_bounds__] = ACTIONS(6254),
  },
  [STATE(2564)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5768),
    [anon_sym_COMMA] = ACTIONS(5768),
    [anon_sym_LPAREN2] = ACTIONS(5768),
    [anon_sym_DASH] = ACTIONS(5766),
    [anon_sym_PLUS] = ACTIONS(5766),
    [anon_sym_STAR] = ACTIONS(5768),
    [anon_sym_SLASH] = ACTIONS(5766),
    [anon_sym_PERCENT] = ACTIONS(5768),
    [anon_sym_PIPE_PIPE] = ACTIONS(5768),
    [anon_sym_AMP_AMP] = ACTIONS(5768),
    [anon_sym_PIPE] = ACTIONS(5766),
    [anon_sym_CARET] = ACTIONS(5768),
    [anon_sym_AMP] = ACTIONS(5766),
    [anon_sym_EQ_EQ] = ACTIONS(5768),
    [anon_sym_BANG_EQ] = ACTIONS(5768),
    [anon_sym_GT] = ACTIONS(5766),
    [anon_sym_GT_EQ] = ACTIONS(5766),
    [anon_sym_LT_EQ] = ACTIONS(5766),
    [anon_sym_LT] = ACTIONS(5766),
    [anon_sym_LT_LT] = ACTIONS(5766),
    [anon_sym_GT_GT] = ACTIONS(5766),
    [anon_sym___extension__] = ACTIONS(5768),
    [anon_sym___global__] = ACTIONS(5768),
    [anon_sym___attribute__] = ACTIONS(5768),
    [anon_sym___attribute] = ACTIONS(5766),
    [anon_sym_LBRACE] = ACTIONS(5768),
    [anon_sym_LBRACK] = ACTIONS(5768),
    [anon_sym_const] = ACTIONS(5766),
    [anon_sym_constexpr] = ACTIONS(5768),
    [anon_sym_volatile] = ACTIONS(5768),
    [anon_sym_restrict] = ACTIONS(5768),
    [anon_sym___restrict__] = ACTIONS(5768),
    [anon_sym__Atomic] = ACTIONS(5768),
    [anon_sym__Noreturn] = ACTIONS(5768),
    [anon_sym_noreturn] = ACTIONS(5768),
    [anon_sym__Nonnull] = ACTIONS(5768),
    [anon_sym_mutable] = ACTIONS(5768),
    [anon_sym_constinit] = ACTIONS(5768),
    [anon_sym_consteval] = ACTIONS(5768),
    [anon_sym___shared__] = ACTIONS(5768),
    [anon_sym___local__] = ACTIONS(5768),
    [anon_sym___constant__] = ACTIONS(5768),
    [anon_sym___managed__] = ACTIONS(5768),
    [anon_sym___grid_constant__] = ACTIONS(5768),
    [anon_sym_alignas] = ACTIONS(5768),
    [anon_sym__Alignas] = ACTIONS(5768),
    [anon_sym_QMARK] = ACTIONS(5768),
    [anon_sym_LT_EQ_GT] = ACTIONS(5768),
    [anon_sym_or] = ACTIONS(5768),
    [anon_sym_and] = ACTIONS(5768),
    [anon_sym_bitor] = ACTIONS(5768),
    [anon_sym_xor] = ACTIONS(5768),
    [anon_sym_bitand] = ACTIONS(5768),
    [anon_sym_not_eq] = ACTIONS(5768),
    [anon_sym_DASH_DASH] = ACTIONS(5768),
    [anon_sym_PLUS_PLUS] = ACTIONS(5768),
    [anon_sym_DOT] = ACTIONS(5766),
    [anon_sym_DOT_STAR] = ACTIONS(5768),
    [anon_sym_DASH_GT] = ACTIONS(5768),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5768),
    [anon_sym_decltype] = ACTIONS(5768),
    [anon_sym_final] = ACTIONS(5768),
    [anon_sym_override] = ACTIONS(5768),
    [anon_sym_GT2] = ACTIONS(5768),
    [anon_sym_requires] = ACTIONS(5768),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5768),
  },
  [STATE(2565)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5712),
    [anon_sym_COMMA] = ACTIONS(5712),
    [anon_sym_LPAREN2] = ACTIONS(5712),
    [anon_sym_DASH] = ACTIONS(5710),
    [anon_sym_PLUS] = ACTIONS(5710),
    [anon_sym_STAR] = ACTIONS(5712),
    [anon_sym_SLASH] = ACTIONS(5710),
    [anon_sym_PERCENT] = ACTIONS(5712),
    [anon_sym_PIPE_PIPE] = ACTIONS(5712),
    [anon_sym_AMP_AMP] = ACTIONS(5712),
    [anon_sym_PIPE] = ACTIONS(5710),
    [anon_sym_CARET] = ACTIONS(5712),
    [anon_sym_AMP] = ACTIONS(5710),
    [anon_sym_EQ_EQ] = ACTIONS(5712),
    [anon_sym_BANG_EQ] = ACTIONS(5712),
    [anon_sym_GT] = ACTIONS(5710),
    [anon_sym_GT_EQ] = ACTIONS(5710),
    [anon_sym_LT_EQ] = ACTIONS(5710),
    [anon_sym_LT] = ACTIONS(5710),
    [anon_sym_LT_LT] = ACTIONS(5710),
    [anon_sym_GT_GT] = ACTIONS(5710),
    [anon_sym___extension__] = ACTIONS(5712),
    [anon_sym___global__] = ACTIONS(5712),
    [anon_sym___attribute__] = ACTIONS(5712),
    [anon_sym___attribute] = ACTIONS(5710),
    [anon_sym_LBRACE] = ACTIONS(5712),
    [anon_sym_LBRACK] = ACTIONS(5712),
    [anon_sym_const] = ACTIONS(5710),
    [anon_sym_constexpr] = ACTIONS(5712),
    [anon_sym_volatile] = ACTIONS(5712),
    [anon_sym_restrict] = ACTIONS(5712),
    [anon_sym___restrict__] = ACTIONS(5712),
    [anon_sym__Atomic] = ACTIONS(5712),
    [anon_sym__Noreturn] = ACTIONS(5712),
    [anon_sym_noreturn] = ACTIONS(5712),
    [anon_sym__Nonnull] = ACTIONS(5712),
    [anon_sym_mutable] = ACTIONS(5712),
    [anon_sym_constinit] = ACTIONS(5712),
    [anon_sym_consteval] = ACTIONS(5712),
    [anon_sym___shared__] = ACTIONS(5712),
    [anon_sym___local__] = ACTIONS(5712),
    [anon_sym___constant__] = ACTIONS(5712),
    [anon_sym___managed__] = ACTIONS(5712),
    [anon_sym___grid_constant__] = ACTIONS(5712),
    [anon_sym_alignas] = ACTIONS(5712),
    [anon_sym__Alignas] = ACTIONS(5712),
    [anon_sym_QMARK] = ACTIONS(5712),
    [anon_sym_LT_EQ_GT] = ACTIONS(5712),
    [anon_sym_or] = ACTIONS(5712),
    [anon_sym_and] = ACTIONS(5712),
    [anon_sym_bitor] = ACTIONS(5712),
    [anon_sym_xor] = ACTIONS(5712),
    [anon_sym_bitand] = ACTIONS(5712),
    [anon_sym_not_eq] = ACTIONS(5712),
    [anon_sym_DASH_DASH] = ACTIONS(5712),
    [anon_sym_PLUS_PLUS] = ACTIONS(5712),
    [anon_sym_DOT] = ACTIONS(5710),
    [anon_sym_DOT_STAR] = ACTIONS(5712),
    [anon_sym_DASH_GT] = ACTIONS(5712),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5712),
    [anon_sym_decltype] = ACTIONS(5712),
    [anon_sym_final] = ACTIONS(5712),
    [anon_sym_override] = ACTIONS(5712),
    [anon_sym_GT2] = ACTIONS(5712),
    [anon_sym_requires] = ACTIONS(5712),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5712),
  },
  [STATE(2566)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5728),
    [anon_sym_COMMA] = ACTIONS(5728),
    [anon_sym_LPAREN2] = ACTIONS(5728),
    [anon_sym_DASH] = ACTIONS(5726),
    [anon_sym_PLUS] = ACTIONS(5726),
    [anon_sym_STAR] = ACTIONS(5728),
    [anon_sym_SLASH] = ACTIONS(5726),
    [anon_sym_PERCENT] = ACTIONS(5728),
    [anon_sym_PIPE_PIPE] = ACTIONS(5728),
    [anon_sym_AMP_AMP] = ACTIONS(5728),
    [anon_sym_PIPE] = ACTIONS(5726),
    [anon_sym_CARET] = ACTIONS(5728),
    [anon_sym_AMP] = ACTIONS(5726),
    [anon_sym_EQ_EQ] = ACTIONS(5728),
    [anon_sym_BANG_EQ] = ACTIONS(5728),
    [anon_sym_GT] = ACTIONS(5726),
    [anon_sym_GT_EQ] = ACTIONS(5726),
    [anon_sym_LT_EQ] = ACTIONS(5726),
    [anon_sym_LT] = ACTIONS(5726),
    [anon_sym_LT_LT] = ACTIONS(5726),
    [anon_sym_GT_GT] = ACTIONS(5726),
    [anon_sym___extension__] = ACTIONS(5728),
    [anon_sym___global__] = ACTIONS(5728),
    [anon_sym___attribute__] = ACTIONS(5728),
    [anon_sym___attribute] = ACTIONS(5726),
    [anon_sym_LBRACE] = ACTIONS(5728),
    [anon_sym_LBRACK] = ACTIONS(5728),
    [anon_sym_const] = ACTIONS(5726),
    [anon_sym_constexpr] = ACTIONS(5728),
    [anon_sym_volatile] = ACTIONS(5728),
    [anon_sym_restrict] = ACTIONS(5728),
    [anon_sym___restrict__] = ACTIONS(5728),
    [anon_sym__Atomic] = ACTIONS(5728),
    [anon_sym__Noreturn] = ACTIONS(5728),
    [anon_sym_noreturn] = ACTIONS(5728),
    [anon_sym__Nonnull] = ACTIONS(5728),
    [anon_sym_mutable] = ACTIONS(5728),
    [anon_sym_constinit] = ACTIONS(5728),
    [anon_sym_consteval] = ACTIONS(5728),
    [anon_sym___shared__] = ACTIONS(5728),
    [anon_sym___local__] = ACTIONS(5728),
    [anon_sym___constant__] = ACTIONS(5728),
    [anon_sym___managed__] = ACTIONS(5728),
    [anon_sym___grid_constant__] = ACTIONS(5728),
    [anon_sym_alignas] = ACTIONS(5728),
    [anon_sym__Alignas] = ACTIONS(5728),
    [anon_sym_QMARK] = ACTIONS(5728),
    [anon_sym_LT_EQ_GT] = ACTIONS(5728),
    [anon_sym_or] = ACTIONS(5728),
    [anon_sym_and] = ACTIONS(5728),
    [anon_sym_bitor] = ACTIONS(5728),
    [anon_sym_xor] = ACTIONS(5728),
    [anon_sym_bitand] = ACTIONS(5728),
    [anon_sym_not_eq] = ACTIONS(5728),
    [anon_sym_DASH_DASH] = ACTIONS(5728),
    [anon_sym_PLUS_PLUS] = ACTIONS(5728),
    [anon_sym_DOT] = ACTIONS(5726),
    [anon_sym_DOT_STAR] = ACTIONS(5728),
    [anon_sym_DASH_GT] = ACTIONS(5728),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5728),
    [anon_sym_decltype] = ACTIONS(5728),
    [anon_sym_final] = ACTIONS(5728),
    [anon_sym_override] = ACTIONS(5728),
    [anon_sym_GT2] = ACTIONS(5728),
    [anon_sym_requires] = ACTIONS(5728),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5728),
  },
  [STATE(2567)] = {
    [sym_template_argument_list] = STATE(2360),
    [sym_identifier] = ACTIONS(5669),
    [anon_sym_LPAREN2] = ACTIONS(4028),
    [anon_sym_TILDE] = ACTIONS(4028),
    [anon_sym_STAR] = ACTIONS(4028),
    [anon_sym_AMP_AMP] = ACTIONS(4028),
    [anon_sym_AMP] = ACTIONS(5669),
    [anon_sym_LT] = ACTIONS(6076),
    [anon_sym_SEMI] = ACTIONS(4028),
    [anon_sym___extension__] = ACTIONS(5669),
    [anon_sym___device__] = ACTIONS(5669),
    [anon_sym___host__] = ACTIONS(5669),
    [anon_sym___global__] = ACTIONS(5669),
    [anon_sym___forceinline__] = ACTIONS(5669),
    [anon_sym___noinline__] = ACTIONS(5669),
    [anon_sym_virtual] = ACTIONS(5669),
    [anon_sym_extern] = ACTIONS(5669),
    [anon_sym___attribute__] = ACTIONS(5669),
    [anon_sym___attribute] = ACTIONS(5669),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4028),
    [anon_sym___declspec] = ACTIONS(5669),
    [anon_sym___based] = ACTIONS(5669),
    [anon_sym___cdecl] = ACTIONS(5669),
    [anon_sym___clrcall] = ACTIONS(5669),
    [anon_sym___stdcall] = ACTIONS(5669),
    [anon_sym___fastcall] = ACTIONS(5669),
    [anon_sym___thiscall] = ACTIONS(5669),
    [anon_sym___vectorcall] = ACTIONS(5669),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(5669),
    [anon_sym_static] = ACTIONS(5669),
    [anon_sym_register] = ACTIONS(5669),
    [anon_sym_inline] = ACTIONS(5669),
    [anon_sym___inline] = ACTIONS(5669),
    [anon_sym___inline__] = ACTIONS(5669),
    [anon_sym___forceinline] = ACTIONS(5669),
    [anon_sym_thread_local] = ACTIONS(5669),
    [anon_sym___thread] = ACTIONS(5669),
    [anon_sym_const] = ACTIONS(5669),
    [anon_sym_constexpr] = ACTIONS(5669),
    [anon_sym_volatile] = ACTIONS(5669),
    [anon_sym_restrict] = ACTIONS(5669),
    [anon_sym___restrict__] = ACTIONS(5669),
    [anon_sym__Atomic] = ACTIONS(5669),
    [anon_sym__Noreturn] = ACTIONS(5669),
    [anon_sym_noreturn] = ACTIONS(5669),
    [anon_sym__Nonnull] = ACTIONS(5669),
    [anon_sym_mutable] = ACTIONS(5669),
    [anon_sym_constinit] = ACTIONS(5669),
    [anon_sym_consteval] = ACTIONS(5669),
    [anon_sym___shared__] = ACTIONS(5669),
    [anon_sym___local__] = ACTIONS(5669),
    [anon_sym___constant__] = ACTIONS(5669),
    [anon_sym___managed__] = ACTIONS(5669),
    [anon_sym___grid_constant__] = ACTIONS(5669),
    [anon_sym_alignas] = ACTIONS(5669),
    [anon_sym__Alignas] = ACTIONS(5669),
    [anon_sym_COLON] = ACTIONS(5669),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5669),
    [anon_sym_decltype] = ACTIONS(5669),
    [anon_sym_final] = ACTIONS(5669),
    [anon_sym_override] = ACTIONS(5669),
    [anon_sym_template] = ACTIONS(5669),
    [anon_sym_operator] = ACTIONS(5669),
    [anon_sym___launch_bounds__] = ACTIONS(5669),
  },
  [STATE(2568)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2537),
    [sym_identifier] = ACTIONS(5900),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5898),
    [anon_sym_COMMA] = ACTIONS(5898),
    [aux_sym_preproc_if_token2] = ACTIONS(5898),
    [aux_sym_preproc_else_token1] = ACTIONS(5898),
    [aux_sym_preproc_elif_token1] = ACTIONS(5900),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5898),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5898),
    [anon_sym_LPAREN2] = ACTIONS(5898),
    [anon_sym_DASH] = ACTIONS(5900),
    [anon_sym_PLUS] = ACTIONS(5900),
    [anon_sym_STAR] = ACTIONS(5900),
    [anon_sym_SLASH] = ACTIONS(5900),
    [anon_sym_PERCENT] = ACTIONS(5900),
    [anon_sym_PIPE_PIPE] = ACTIONS(5898),
    [anon_sym_AMP_AMP] = ACTIONS(5898),
    [anon_sym_PIPE] = ACTIONS(5900),
    [anon_sym_CARET] = ACTIONS(5900),
    [anon_sym_AMP] = ACTIONS(5900),
    [anon_sym_EQ_EQ] = ACTIONS(5898),
    [anon_sym_BANG_EQ] = ACTIONS(5898),
    [anon_sym_GT] = ACTIONS(5900),
    [anon_sym_GT_EQ] = ACTIONS(5898),
    [anon_sym_LT_EQ] = ACTIONS(5900),
    [anon_sym_LT] = ACTIONS(5900),
    [anon_sym_LT_LT] = ACTIONS(5900),
    [anon_sym_GT_GT] = ACTIONS(5900),
    [anon_sym___attribute__] = ACTIONS(5900),
    [anon_sym___attribute] = ACTIONS(5900),
    [anon_sym_LBRACE] = ACTIONS(5898),
    [anon_sym_signed] = ACTIONS(6516),
    [anon_sym_unsigned] = ACTIONS(6516),
    [anon_sym_long] = ACTIONS(6516),
    [anon_sym_short] = ACTIONS(6516),
    [anon_sym_LBRACK] = ACTIONS(5898),
    [anon_sym_EQ] = ACTIONS(5900),
    [anon_sym_QMARK] = ACTIONS(5898),
    [anon_sym_STAR_EQ] = ACTIONS(5898),
    [anon_sym_SLASH_EQ] = ACTIONS(5898),
    [anon_sym_PERCENT_EQ] = ACTIONS(5898),
    [anon_sym_PLUS_EQ] = ACTIONS(5898),
    [anon_sym_DASH_EQ] = ACTIONS(5898),
    [anon_sym_LT_LT_EQ] = ACTIONS(5898),
    [anon_sym_GT_GT_EQ] = ACTIONS(5898),
    [anon_sym_AMP_EQ] = ACTIONS(5898),
    [anon_sym_CARET_EQ] = ACTIONS(5898),
    [anon_sym_PIPE_EQ] = ACTIONS(5898),
    [anon_sym_and_eq] = ACTIONS(5900),
    [anon_sym_or_eq] = ACTIONS(5900),
    [anon_sym_xor_eq] = ACTIONS(5900),
    [anon_sym_LT_EQ_GT] = ACTIONS(5898),
    [anon_sym_or] = ACTIONS(5900),
    [anon_sym_and] = ACTIONS(5900),
    [anon_sym_bitor] = ACTIONS(5900),
    [anon_sym_xor] = ACTIONS(5900),
    [anon_sym_bitand] = ACTIONS(5900),
    [anon_sym_not_eq] = ACTIONS(5900),
    [anon_sym_DASH_DASH] = ACTIONS(5898),
    [anon_sym_PLUS_PLUS] = ACTIONS(5898),
    [anon_sym_DOT] = ACTIONS(5900),
    [anon_sym_DOT_STAR] = ACTIONS(5898),
    [anon_sym_DASH_GT] = ACTIONS(5898),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5900),
    [anon_sym_decltype] = ACTIONS(5900),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5898),
  },
  [STATE(2569)] = {
    [sym_attribute_specifier] = STATE(2240),
    [sym_identifier] = ACTIONS(6240),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6238),
    [anon_sym_COMMA] = ACTIONS(6238),
    [anon_sym_RPAREN] = ACTIONS(6238),
    [anon_sym_LPAREN2] = ACTIONS(6238),
    [anon_sym_TILDE] = ACTIONS(6238),
    [anon_sym_STAR] = ACTIONS(6238),
    [anon_sym_AMP_AMP] = ACTIONS(6238),
    [anon_sym_AMP] = ACTIONS(6240),
    [anon_sym_SEMI] = ACTIONS(6238),
    [anon_sym___extension__] = ACTIONS(6240),
    [anon_sym___device__] = ACTIONS(6240),
    [anon_sym___host__] = ACTIONS(6240),
    [anon_sym___global__] = ACTIONS(6240),
    [anon_sym___forceinline__] = ACTIONS(6240),
    [anon_sym___noinline__] = ACTIONS(6240),
    [anon_sym_virtual] = ACTIONS(6240),
    [anon_sym_extern] = ACTIONS(6240),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6238),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6238),
    [anon_sym___declspec] = ACTIONS(6240),
    [anon_sym___based] = ACTIONS(6240),
    [anon_sym___cdecl] = ACTIONS(6240),
    [anon_sym___clrcall] = ACTIONS(6240),
    [anon_sym___stdcall] = ACTIONS(6240),
    [anon_sym___fastcall] = ACTIONS(6240),
    [anon_sym___thiscall] = ACTIONS(6240),
    [anon_sym___vectorcall] = ACTIONS(6240),
    [anon_sym_LBRACK] = ACTIONS(6240),
    [anon_sym_static] = ACTIONS(6240),
    [anon_sym_EQ] = ACTIONS(6238),
    [anon_sym_register] = ACTIONS(6240),
    [anon_sym_inline] = ACTIONS(6240),
    [anon_sym___inline] = ACTIONS(6240),
    [anon_sym___inline__] = ACTIONS(6240),
    [anon_sym___forceinline] = ACTIONS(6240),
    [anon_sym_thread_local] = ACTIONS(6240),
    [anon_sym___thread] = ACTIONS(6240),
    [anon_sym_const] = ACTIONS(6240),
    [anon_sym_constexpr] = ACTIONS(6240),
    [anon_sym_volatile] = ACTIONS(6240),
    [anon_sym_restrict] = ACTIONS(6240),
    [anon_sym___restrict__] = ACTIONS(6240),
    [anon_sym__Atomic] = ACTIONS(6240),
    [anon_sym__Noreturn] = ACTIONS(6240),
    [anon_sym_noreturn] = ACTIONS(6240),
    [anon_sym__Nonnull] = ACTIONS(6240),
    [anon_sym_mutable] = ACTIONS(6240),
    [anon_sym_constinit] = ACTIONS(6240),
    [anon_sym_consteval] = ACTIONS(6240),
    [anon_sym___shared__] = ACTIONS(6240),
    [anon_sym___local__] = ACTIONS(6240),
    [anon_sym___constant__] = ACTIONS(6240),
    [anon_sym___managed__] = ACTIONS(6240),
    [anon_sym___grid_constant__] = ACTIONS(6240),
    [anon_sym_alignas] = ACTIONS(6240),
    [anon_sym__Alignas] = ACTIONS(6240),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6240),
    [anon_sym_decltype] = ACTIONS(6240),
    [anon_sym_template] = ACTIONS(6240),
    [anon_sym_GT2] = ACTIONS(6238),
    [anon_sym_operator] = ACTIONS(6240),
    [anon_sym___launch_bounds__] = ACTIONS(6240),
  },
  [STATE(2570)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5736),
    [anon_sym_COMMA] = ACTIONS(5736),
    [anon_sym_LPAREN2] = ACTIONS(5736),
    [anon_sym_DASH] = ACTIONS(5734),
    [anon_sym_PLUS] = ACTIONS(5734),
    [anon_sym_STAR] = ACTIONS(5736),
    [anon_sym_SLASH] = ACTIONS(5734),
    [anon_sym_PERCENT] = ACTIONS(5736),
    [anon_sym_PIPE_PIPE] = ACTIONS(5736),
    [anon_sym_AMP_AMP] = ACTIONS(5736),
    [anon_sym_PIPE] = ACTIONS(5734),
    [anon_sym_CARET] = ACTIONS(5736),
    [anon_sym_AMP] = ACTIONS(5734),
    [anon_sym_EQ_EQ] = ACTIONS(5736),
    [anon_sym_BANG_EQ] = ACTIONS(5736),
    [anon_sym_GT] = ACTIONS(5734),
    [anon_sym_GT_EQ] = ACTIONS(5734),
    [anon_sym_LT_EQ] = ACTIONS(5734),
    [anon_sym_LT] = ACTIONS(5734),
    [anon_sym_LT_LT] = ACTIONS(5734),
    [anon_sym_GT_GT] = ACTIONS(5734),
    [anon_sym___extension__] = ACTIONS(5736),
    [anon_sym___global__] = ACTIONS(5736),
    [anon_sym___attribute__] = ACTIONS(5736),
    [anon_sym___attribute] = ACTIONS(5734),
    [anon_sym_LBRACE] = ACTIONS(5736),
    [anon_sym_LBRACK] = ACTIONS(5736),
    [anon_sym_const] = ACTIONS(5734),
    [anon_sym_constexpr] = ACTIONS(5736),
    [anon_sym_volatile] = ACTIONS(5736),
    [anon_sym_restrict] = ACTIONS(5736),
    [anon_sym___restrict__] = ACTIONS(5736),
    [anon_sym__Atomic] = ACTIONS(5736),
    [anon_sym__Noreturn] = ACTIONS(5736),
    [anon_sym_noreturn] = ACTIONS(5736),
    [anon_sym__Nonnull] = ACTIONS(5736),
    [anon_sym_mutable] = ACTIONS(5736),
    [anon_sym_constinit] = ACTIONS(5736),
    [anon_sym_consteval] = ACTIONS(5736),
    [anon_sym___shared__] = ACTIONS(5736),
    [anon_sym___local__] = ACTIONS(5736),
    [anon_sym___constant__] = ACTIONS(5736),
    [anon_sym___managed__] = ACTIONS(5736),
    [anon_sym___grid_constant__] = ACTIONS(5736),
    [anon_sym_alignas] = ACTIONS(5736),
    [anon_sym__Alignas] = ACTIONS(5736),
    [anon_sym_QMARK] = ACTIONS(5736),
    [anon_sym_LT_EQ_GT] = ACTIONS(5736),
    [anon_sym_or] = ACTIONS(5736),
    [anon_sym_and] = ACTIONS(5736),
    [anon_sym_bitor] = ACTIONS(5736),
    [anon_sym_xor] = ACTIONS(5736),
    [anon_sym_bitand] = ACTIONS(5736),
    [anon_sym_not_eq] = ACTIONS(5736),
    [anon_sym_DASH_DASH] = ACTIONS(5736),
    [anon_sym_PLUS_PLUS] = ACTIONS(5736),
    [anon_sym_DOT] = ACTIONS(5734),
    [anon_sym_DOT_STAR] = ACTIONS(5736),
    [anon_sym_DASH_GT] = ACTIONS(5736),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5736),
    [anon_sym_decltype] = ACTIONS(5736),
    [anon_sym_final] = ACTIONS(5736),
    [anon_sym_override] = ACTIONS(5736),
    [anon_sym_GT2] = ACTIONS(5736),
    [anon_sym_requires] = ACTIONS(5736),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5736),
  },
  [STATE(2571)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2537),
    [sym_identifier] = ACTIONS(5986),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5984),
    [anon_sym_COMMA] = ACTIONS(5984),
    [aux_sym_preproc_if_token2] = ACTIONS(5984),
    [aux_sym_preproc_else_token1] = ACTIONS(5984),
    [aux_sym_preproc_elif_token1] = ACTIONS(5986),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5984),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5984),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(5986),
    [anon_sym_PLUS] = ACTIONS(5986),
    [anon_sym_STAR] = ACTIONS(5986),
    [anon_sym_SLASH] = ACTIONS(5986),
    [anon_sym_PERCENT] = ACTIONS(5986),
    [anon_sym_PIPE_PIPE] = ACTIONS(5984),
    [anon_sym_AMP_AMP] = ACTIONS(5984),
    [anon_sym_PIPE] = ACTIONS(5986),
    [anon_sym_CARET] = ACTIONS(5986),
    [anon_sym_AMP] = ACTIONS(5986),
    [anon_sym_EQ_EQ] = ACTIONS(5984),
    [anon_sym_BANG_EQ] = ACTIONS(5984),
    [anon_sym_GT] = ACTIONS(5986),
    [anon_sym_GT_EQ] = ACTIONS(5984),
    [anon_sym_LT_EQ] = ACTIONS(5986),
    [anon_sym_LT] = ACTIONS(5986),
    [anon_sym_LT_LT] = ACTIONS(5986),
    [anon_sym_GT_GT] = ACTIONS(5986),
    [anon_sym___attribute__] = ACTIONS(5986),
    [anon_sym___attribute] = ACTIONS(5986),
    [anon_sym_LBRACE] = ACTIONS(5984),
    [anon_sym_signed] = ACTIONS(6516),
    [anon_sym_unsigned] = ACTIONS(6516),
    [anon_sym_long] = ACTIONS(6516),
    [anon_sym_short] = ACTIONS(6516),
    [anon_sym_LBRACK] = ACTIONS(5984),
    [anon_sym_EQ] = ACTIONS(5986),
    [anon_sym_QMARK] = ACTIONS(5984),
    [anon_sym_STAR_EQ] = ACTIONS(5984),
    [anon_sym_SLASH_EQ] = ACTIONS(5984),
    [anon_sym_PERCENT_EQ] = ACTIONS(5984),
    [anon_sym_PLUS_EQ] = ACTIONS(5984),
    [anon_sym_DASH_EQ] = ACTIONS(5984),
    [anon_sym_LT_LT_EQ] = ACTIONS(5984),
    [anon_sym_GT_GT_EQ] = ACTIONS(5984),
    [anon_sym_AMP_EQ] = ACTIONS(5984),
    [anon_sym_CARET_EQ] = ACTIONS(5984),
    [anon_sym_PIPE_EQ] = ACTIONS(5984),
    [anon_sym_and_eq] = ACTIONS(5986),
    [anon_sym_or_eq] = ACTIONS(5986),
    [anon_sym_xor_eq] = ACTIONS(5986),
    [anon_sym_LT_EQ_GT] = ACTIONS(5984),
    [anon_sym_or] = ACTIONS(5986),
    [anon_sym_and] = ACTIONS(5986),
    [anon_sym_bitor] = ACTIONS(5986),
    [anon_sym_xor] = ACTIONS(5986),
    [anon_sym_bitand] = ACTIONS(5986),
    [anon_sym_not_eq] = ACTIONS(5986),
    [anon_sym_DASH_DASH] = ACTIONS(5984),
    [anon_sym_PLUS_PLUS] = ACTIONS(5984),
    [anon_sym_DOT] = ACTIONS(5986),
    [anon_sym_DOT_STAR] = ACTIONS(5984),
    [anon_sym_DASH_GT] = ACTIONS(5984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5986),
    [anon_sym_decltype] = ACTIONS(5986),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5984),
  },
  [STATE(2572)] = {
    [sym_identifier] = ACTIONS(5842),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5844),
    [anon_sym_COMMA] = ACTIONS(5844),
    [anon_sym_RPAREN] = ACTIONS(5844),
    [aux_sym_preproc_if_token2] = ACTIONS(5844),
    [aux_sym_preproc_else_token1] = ACTIONS(5844),
    [aux_sym_preproc_elif_token1] = ACTIONS(5842),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5844),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5844),
    [anon_sym_LPAREN2] = ACTIONS(5844),
    [anon_sym_DASH] = ACTIONS(5842),
    [anon_sym_PLUS] = ACTIONS(5842),
    [anon_sym_STAR] = ACTIONS(5842),
    [anon_sym_SLASH] = ACTIONS(5842),
    [anon_sym_PERCENT] = ACTIONS(5842),
    [anon_sym_PIPE_PIPE] = ACTIONS(5844),
    [anon_sym_AMP_AMP] = ACTIONS(5844),
    [anon_sym_PIPE] = ACTIONS(5842),
    [anon_sym_CARET] = ACTIONS(5842),
    [anon_sym_AMP] = ACTIONS(5842),
    [anon_sym_EQ_EQ] = ACTIONS(5844),
    [anon_sym_BANG_EQ] = ACTIONS(5844),
    [anon_sym_GT] = ACTIONS(5842),
    [anon_sym_GT_EQ] = ACTIONS(5844),
    [anon_sym_LT_EQ] = ACTIONS(5842),
    [anon_sym_LT] = ACTIONS(5842),
    [anon_sym_LT_LT] = ACTIONS(5842),
    [anon_sym_GT_GT] = ACTIONS(5842),
    [anon_sym_SEMI] = ACTIONS(5844),
    [anon_sym___attribute__] = ACTIONS(5842),
    [anon_sym___attribute] = ACTIONS(5842),
    [anon_sym_LBRACE] = ACTIONS(5844),
    [anon_sym_RBRACE] = ACTIONS(5844),
    [anon_sym_LBRACK] = ACTIONS(5844),
    [anon_sym_RBRACK] = ACTIONS(5844),
    [anon_sym_EQ] = ACTIONS(5842),
    [anon_sym_COLON] = ACTIONS(5844),
    [anon_sym_QMARK] = ACTIONS(5844),
    [anon_sym_STAR_EQ] = ACTIONS(5844),
    [anon_sym_SLASH_EQ] = ACTIONS(5844),
    [anon_sym_PERCENT_EQ] = ACTIONS(5844),
    [anon_sym_PLUS_EQ] = ACTIONS(5844),
    [anon_sym_DASH_EQ] = ACTIONS(5844),
    [anon_sym_LT_LT_EQ] = ACTIONS(5844),
    [anon_sym_GT_GT_EQ] = ACTIONS(5844),
    [anon_sym_AMP_EQ] = ACTIONS(5844),
    [anon_sym_CARET_EQ] = ACTIONS(5844),
    [anon_sym_PIPE_EQ] = ACTIONS(5844),
    [anon_sym_and_eq] = ACTIONS(5842),
    [anon_sym_or_eq] = ACTIONS(5842),
    [anon_sym_xor_eq] = ACTIONS(5842),
    [anon_sym_LT_EQ_GT] = ACTIONS(5844),
    [anon_sym_or] = ACTIONS(5842),
    [anon_sym_and] = ACTIONS(5842),
    [anon_sym_bitor] = ACTIONS(5842),
    [anon_sym_xor] = ACTIONS(5842),
    [anon_sym_bitand] = ACTIONS(5842),
    [anon_sym_not_eq] = ACTIONS(5842),
    [anon_sym_DASH_DASH] = ACTIONS(5844),
    [anon_sym_PLUS_PLUS] = ACTIONS(5844),
    [anon_sym_DOT] = ACTIONS(5842),
    [anon_sym_DOT_STAR] = ACTIONS(5844),
    [anon_sym_DASH_GT] = ACTIONS(5844),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5842),
    [anon_sym_decltype] = ACTIONS(5842),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5844),
  },
  [STATE(2573)] = {
    [sym_identifier] = ACTIONS(5754),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5756),
    [anon_sym_COMMA] = ACTIONS(5756),
    [anon_sym_RPAREN] = ACTIONS(5756),
    [aux_sym_preproc_if_token2] = ACTIONS(5756),
    [aux_sym_preproc_else_token1] = ACTIONS(5756),
    [aux_sym_preproc_elif_token1] = ACTIONS(5754),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5756),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5756),
    [anon_sym_LPAREN2] = ACTIONS(5756),
    [anon_sym_DASH] = ACTIONS(5754),
    [anon_sym_PLUS] = ACTIONS(5754),
    [anon_sym_STAR] = ACTIONS(5754),
    [anon_sym_SLASH] = ACTIONS(5754),
    [anon_sym_PERCENT] = ACTIONS(5754),
    [anon_sym_PIPE_PIPE] = ACTIONS(5756),
    [anon_sym_AMP_AMP] = ACTIONS(5756),
    [anon_sym_PIPE] = ACTIONS(5754),
    [anon_sym_CARET] = ACTIONS(5754),
    [anon_sym_AMP] = ACTIONS(5754),
    [anon_sym_EQ_EQ] = ACTIONS(5756),
    [anon_sym_BANG_EQ] = ACTIONS(5756),
    [anon_sym_GT] = ACTIONS(5754),
    [anon_sym_GT_EQ] = ACTIONS(5756),
    [anon_sym_LT_EQ] = ACTIONS(5754),
    [anon_sym_LT] = ACTIONS(5754),
    [anon_sym_LT_LT] = ACTIONS(5754),
    [anon_sym_GT_GT] = ACTIONS(5754),
    [anon_sym_SEMI] = ACTIONS(5756),
    [anon_sym___attribute__] = ACTIONS(5754),
    [anon_sym___attribute] = ACTIONS(5754),
    [anon_sym_LBRACE] = ACTIONS(5756),
    [anon_sym_RBRACE] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5756),
    [anon_sym_RBRACK] = ACTIONS(5756),
    [anon_sym_EQ] = ACTIONS(5754),
    [anon_sym_COLON] = ACTIONS(5756),
    [anon_sym_QMARK] = ACTIONS(5756),
    [anon_sym_STAR_EQ] = ACTIONS(5756),
    [anon_sym_SLASH_EQ] = ACTIONS(5756),
    [anon_sym_PERCENT_EQ] = ACTIONS(5756),
    [anon_sym_PLUS_EQ] = ACTIONS(5756),
    [anon_sym_DASH_EQ] = ACTIONS(5756),
    [anon_sym_LT_LT_EQ] = ACTIONS(5756),
    [anon_sym_GT_GT_EQ] = ACTIONS(5756),
    [anon_sym_AMP_EQ] = ACTIONS(5756),
    [anon_sym_CARET_EQ] = ACTIONS(5756),
    [anon_sym_PIPE_EQ] = ACTIONS(5756),
    [anon_sym_and_eq] = ACTIONS(5754),
    [anon_sym_or_eq] = ACTIONS(5754),
    [anon_sym_xor_eq] = ACTIONS(5754),
    [anon_sym_LT_EQ_GT] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5754),
    [anon_sym_and] = ACTIONS(5754),
    [anon_sym_bitor] = ACTIONS(5754),
    [anon_sym_xor] = ACTIONS(5754),
    [anon_sym_bitand] = ACTIONS(5754),
    [anon_sym_not_eq] = ACTIONS(5754),
    [anon_sym_DASH_DASH] = ACTIONS(5756),
    [anon_sym_PLUS_PLUS] = ACTIONS(5756),
    [anon_sym_DOT] = ACTIONS(5754),
    [anon_sym_DOT_STAR] = ACTIONS(5756),
    [anon_sym_DASH_GT] = ACTIONS(5756),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5754),
    [anon_sym_decltype] = ACTIONS(5754),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5756),
  },
  [STATE(2574)] = {
    [sym_identifier] = ACTIONS(5718),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5720),
    [anon_sym_COMMA] = ACTIONS(5720),
    [anon_sym_RPAREN] = ACTIONS(5720),
    [aux_sym_preproc_if_token2] = ACTIONS(5720),
    [aux_sym_preproc_else_token1] = ACTIONS(5720),
    [aux_sym_preproc_elif_token1] = ACTIONS(5718),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5720),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5720),
    [anon_sym_LPAREN2] = ACTIONS(5720),
    [anon_sym_DASH] = ACTIONS(5718),
    [anon_sym_PLUS] = ACTIONS(5718),
    [anon_sym_STAR] = ACTIONS(5718),
    [anon_sym_SLASH] = ACTIONS(5718),
    [anon_sym_PERCENT] = ACTIONS(5718),
    [anon_sym_PIPE_PIPE] = ACTIONS(5720),
    [anon_sym_AMP_AMP] = ACTIONS(5720),
    [anon_sym_PIPE] = ACTIONS(5718),
    [anon_sym_CARET] = ACTIONS(5718),
    [anon_sym_AMP] = ACTIONS(5718),
    [anon_sym_EQ_EQ] = ACTIONS(5720),
    [anon_sym_BANG_EQ] = ACTIONS(5720),
    [anon_sym_GT] = ACTIONS(5718),
    [anon_sym_GT_EQ] = ACTIONS(5720),
    [anon_sym_LT_EQ] = ACTIONS(5718),
    [anon_sym_LT] = ACTIONS(5718),
    [anon_sym_LT_LT] = ACTIONS(5718),
    [anon_sym_GT_GT] = ACTIONS(5718),
    [anon_sym_SEMI] = ACTIONS(5720),
    [anon_sym___attribute__] = ACTIONS(5718),
    [anon_sym___attribute] = ACTIONS(5718),
    [anon_sym_LBRACE] = ACTIONS(5720),
    [anon_sym_RBRACE] = ACTIONS(5720),
    [anon_sym_LBRACK] = ACTIONS(5720),
    [anon_sym_RBRACK] = ACTIONS(5720),
    [anon_sym_EQ] = ACTIONS(5718),
    [anon_sym_COLON] = ACTIONS(5720),
    [anon_sym_QMARK] = ACTIONS(5720),
    [anon_sym_STAR_EQ] = ACTIONS(5720),
    [anon_sym_SLASH_EQ] = ACTIONS(5720),
    [anon_sym_PERCENT_EQ] = ACTIONS(5720),
    [anon_sym_PLUS_EQ] = ACTIONS(5720),
    [anon_sym_DASH_EQ] = ACTIONS(5720),
    [anon_sym_LT_LT_EQ] = ACTIONS(5720),
    [anon_sym_GT_GT_EQ] = ACTIONS(5720),
    [anon_sym_AMP_EQ] = ACTIONS(5720),
    [anon_sym_CARET_EQ] = ACTIONS(5720),
    [anon_sym_PIPE_EQ] = ACTIONS(5720),
    [anon_sym_and_eq] = ACTIONS(5718),
    [anon_sym_or_eq] = ACTIONS(5718),
    [anon_sym_xor_eq] = ACTIONS(5718),
    [anon_sym_LT_EQ_GT] = ACTIONS(5720),
    [anon_sym_or] = ACTIONS(5718),
    [anon_sym_and] = ACTIONS(5718),
    [anon_sym_bitor] = ACTIONS(5718),
    [anon_sym_xor] = ACTIONS(5718),
    [anon_sym_bitand] = ACTIONS(5718),
    [anon_sym_not_eq] = ACTIONS(5718),
    [anon_sym_DASH_DASH] = ACTIONS(5720),
    [anon_sym_PLUS_PLUS] = ACTIONS(5720),
    [anon_sym_DOT] = ACTIONS(5718),
    [anon_sym_DOT_STAR] = ACTIONS(5720),
    [anon_sym_DASH_GT] = ACTIONS(5720),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5718),
    [anon_sym_decltype] = ACTIONS(5718),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5720),
  },
  [STATE(2575)] = {
    [sym_identifier] = ACTIONS(5628),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5630),
    [anon_sym_COMMA] = ACTIONS(5630),
    [anon_sym_RPAREN] = ACTIONS(5630),
    [aux_sym_preproc_if_token2] = ACTIONS(5630),
    [aux_sym_preproc_else_token1] = ACTIONS(5630),
    [aux_sym_preproc_elif_token1] = ACTIONS(5628),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5630),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5630),
    [anon_sym_LPAREN2] = ACTIONS(5630),
    [anon_sym_DASH] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(5628),
    [anon_sym_STAR] = ACTIONS(5628),
    [anon_sym_SLASH] = ACTIONS(5628),
    [anon_sym_PERCENT] = ACTIONS(5628),
    [anon_sym_PIPE_PIPE] = ACTIONS(5630),
    [anon_sym_AMP_AMP] = ACTIONS(5630),
    [anon_sym_PIPE] = ACTIONS(5628),
    [anon_sym_CARET] = ACTIONS(5628),
    [anon_sym_AMP] = ACTIONS(5628),
    [anon_sym_EQ_EQ] = ACTIONS(5630),
    [anon_sym_BANG_EQ] = ACTIONS(5630),
    [anon_sym_GT] = ACTIONS(5628),
    [anon_sym_GT_EQ] = ACTIONS(5630),
    [anon_sym_LT_EQ] = ACTIONS(5628),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_LT_LT] = ACTIONS(5628),
    [anon_sym_GT_GT] = ACTIONS(5628),
    [anon_sym_SEMI] = ACTIONS(5630),
    [anon_sym___attribute__] = ACTIONS(5628),
    [anon_sym___attribute] = ACTIONS(5628),
    [anon_sym_LBRACE] = ACTIONS(5630),
    [anon_sym_RBRACE] = ACTIONS(5630),
    [anon_sym_LBRACK] = ACTIONS(5630),
    [anon_sym_RBRACK] = ACTIONS(5630),
    [anon_sym_EQ] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(5630),
    [anon_sym_QMARK] = ACTIONS(5630),
    [anon_sym_STAR_EQ] = ACTIONS(5630),
    [anon_sym_SLASH_EQ] = ACTIONS(5630),
    [anon_sym_PERCENT_EQ] = ACTIONS(5630),
    [anon_sym_PLUS_EQ] = ACTIONS(5630),
    [anon_sym_DASH_EQ] = ACTIONS(5630),
    [anon_sym_LT_LT_EQ] = ACTIONS(5630),
    [anon_sym_GT_GT_EQ] = ACTIONS(5630),
    [anon_sym_AMP_EQ] = ACTIONS(5630),
    [anon_sym_CARET_EQ] = ACTIONS(5630),
    [anon_sym_PIPE_EQ] = ACTIONS(5630),
    [anon_sym_and_eq] = ACTIONS(5628),
    [anon_sym_or_eq] = ACTIONS(5628),
    [anon_sym_xor_eq] = ACTIONS(5628),
    [anon_sym_LT_EQ_GT] = ACTIONS(5630),
    [anon_sym_or] = ACTIONS(5628),
    [anon_sym_and] = ACTIONS(5628),
    [anon_sym_bitor] = ACTIONS(5628),
    [anon_sym_xor] = ACTIONS(5628),
    [anon_sym_bitand] = ACTIONS(5628),
    [anon_sym_not_eq] = ACTIONS(5628),
    [anon_sym_DASH_DASH] = ACTIONS(5630),
    [anon_sym_PLUS_PLUS] = ACTIONS(5630),
    [anon_sym_DOT] = ACTIONS(5628),
    [anon_sym_DOT_STAR] = ACTIONS(5630),
    [anon_sym_DASH_GT] = ACTIONS(5630),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5628),
    [anon_sym_decltype] = ACTIONS(5628),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5630),
  },
  [STATE(2576)] = {
    [sym_string_literal] = STATE(3782),
    [sym_template_argument_list] = STATE(5285),
    [sym_raw_string_literal] = STATE(3782),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4012),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5120),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(5125),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(5127),
    [anon_sym_SLASH_EQ] = ACTIONS(5127),
    [anon_sym_PERCENT_EQ] = ACTIONS(5127),
    [anon_sym_PLUS_EQ] = ACTIONS(5127),
    [anon_sym_DASH_EQ] = ACTIONS(5127),
    [anon_sym_LT_LT_EQ] = ACTIONS(5127),
    [anon_sym_GT_GT_EQ] = ACTIONS(5125),
    [anon_sym_AMP_EQ] = ACTIONS(5127),
    [anon_sym_CARET_EQ] = ACTIONS(5127),
    [anon_sym_PIPE_EQ] = ACTIONS(5127),
    [anon_sym_and_eq] = ACTIONS(5127),
    [anon_sym_or_eq] = ACTIONS(5127),
    [anon_sym_xor_eq] = ACTIONS(5127),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(5129),
    [anon_sym_u_DQUOTE] = ACTIONS(5129),
    [anon_sym_U_DQUOTE] = ACTIONS(5129),
    [anon_sym_u8_DQUOTE] = ACTIONS(5129),
    [anon_sym_DQUOTE] = ACTIONS(5129),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(4004),
    [anon_sym_R_DQUOTE] = ACTIONS(5131),
    [anon_sym_LR_DQUOTE] = ACTIONS(5131),
    [anon_sym_uR_DQUOTE] = ACTIONS(5131),
    [anon_sym_UR_DQUOTE] = ACTIONS(5131),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5131),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2577)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5744),
    [anon_sym_COMMA] = ACTIONS(5744),
    [anon_sym_LPAREN2] = ACTIONS(5744),
    [anon_sym_DASH] = ACTIONS(5742),
    [anon_sym_PLUS] = ACTIONS(5742),
    [anon_sym_STAR] = ACTIONS(5744),
    [anon_sym_SLASH] = ACTIONS(5742),
    [anon_sym_PERCENT] = ACTIONS(5744),
    [anon_sym_PIPE_PIPE] = ACTIONS(5744),
    [anon_sym_AMP_AMP] = ACTIONS(5744),
    [anon_sym_PIPE] = ACTIONS(5742),
    [anon_sym_CARET] = ACTIONS(5744),
    [anon_sym_AMP] = ACTIONS(5742),
    [anon_sym_EQ_EQ] = ACTIONS(5744),
    [anon_sym_BANG_EQ] = ACTIONS(5744),
    [anon_sym_GT] = ACTIONS(5742),
    [anon_sym_GT_EQ] = ACTIONS(5742),
    [anon_sym_LT_EQ] = ACTIONS(5742),
    [anon_sym_LT] = ACTIONS(5742),
    [anon_sym_LT_LT] = ACTIONS(5742),
    [anon_sym_GT_GT] = ACTIONS(5742),
    [anon_sym___extension__] = ACTIONS(5744),
    [anon_sym___global__] = ACTIONS(5744),
    [anon_sym___attribute__] = ACTIONS(5744),
    [anon_sym___attribute] = ACTIONS(5742),
    [anon_sym_LBRACE] = ACTIONS(5744),
    [anon_sym_LBRACK] = ACTIONS(5744),
    [anon_sym_const] = ACTIONS(5742),
    [anon_sym_constexpr] = ACTIONS(5744),
    [anon_sym_volatile] = ACTIONS(5744),
    [anon_sym_restrict] = ACTIONS(5744),
    [anon_sym___restrict__] = ACTIONS(5744),
    [anon_sym__Atomic] = ACTIONS(5744),
    [anon_sym__Noreturn] = ACTIONS(5744),
    [anon_sym_noreturn] = ACTIONS(5744),
    [anon_sym__Nonnull] = ACTIONS(5744),
    [anon_sym_mutable] = ACTIONS(5744),
    [anon_sym_constinit] = ACTIONS(5744),
    [anon_sym_consteval] = ACTIONS(5744),
    [anon_sym___shared__] = ACTIONS(5744),
    [anon_sym___local__] = ACTIONS(5744),
    [anon_sym___constant__] = ACTIONS(5744),
    [anon_sym___managed__] = ACTIONS(5744),
    [anon_sym___grid_constant__] = ACTIONS(5744),
    [anon_sym_alignas] = ACTIONS(5744),
    [anon_sym__Alignas] = ACTIONS(5744),
    [anon_sym_QMARK] = ACTIONS(5744),
    [anon_sym_LT_EQ_GT] = ACTIONS(5744),
    [anon_sym_or] = ACTIONS(5744),
    [anon_sym_and] = ACTIONS(5744),
    [anon_sym_bitor] = ACTIONS(5744),
    [anon_sym_xor] = ACTIONS(5744),
    [anon_sym_bitand] = ACTIONS(5744),
    [anon_sym_not_eq] = ACTIONS(5744),
    [anon_sym_DASH_DASH] = ACTIONS(5744),
    [anon_sym_PLUS_PLUS] = ACTIONS(5744),
    [anon_sym_DOT] = ACTIONS(5742),
    [anon_sym_DOT_STAR] = ACTIONS(5744),
    [anon_sym_DASH_GT] = ACTIONS(5744),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5744),
    [anon_sym_decltype] = ACTIONS(5744),
    [anon_sym_final] = ACTIONS(5744),
    [anon_sym_override] = ACTIONS(5744),
    [anon_sym_GT2] = ACTIONS(5744),
    [anon_sym_requires] = ACTIONS(5744),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5744),
  },
  [STATE(2578)] = {
    [sym_string_literal] = STATE(2536),
    [sym_template_argument_list] = STATE(3760),
    [sym_raw_string_literal] = STATE(2536),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(6572),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4004),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(6522),
    [anon_sym_u_DQUOTE] = ACTIONS(6522),
    [anon_sym_U_DQUOTE] = ACTIONS(6522),
    [anon_sym_u8_DQUOTE] = ACTIONS(6522),
    [anon_sym_DQUOTE] = ACTIONS(6522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6524),
    [anon_sym_LR_DQUOTE] = ACTIONS(6524),
    [anon_sym_uR_DQUOTE] = ACTIONS(6524),
    [anon_sym_UR_DQUOTE] = ACTIONS(6524),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6524),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(4004),
  },
  [STATE(2579)] = {
    [sym_identifier] = ACTIONS(6575),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6577),
    [anon_sym_COMMA] = ACTIONS(6577),
    [anon_sym_RPAREN] = ACTIONS(6577),
    [aux_sym_preproc_if_token2] = ACTIONS(6577),
    [aux_sym_preproc_else_token1] = ACTIONS(6577),
    [aux_sym_preproc_elif_token1] = ACTIONS(6575),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6577),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6577),
    [anon_sym_LPAREN2] = ACTIONS(6577),
    [anon_sym_DASH] = ACTIONS(6575),
    [anon_sym_PLUS] = ACTIONS(6575),
    [anon_sym_STAR] = ACTIONS(6575),
    [anon_sym_SLASH] = ACTIONS(6575),
    [anon_sym_PERCENT] = ACTIONS(6575),
    [anon_sym_PIPE_PIPE] = ACTIONS(6577),
    [anon_sym_AMP_AMP] = ACTIONS(6577),
    [anon_sym_PIPE] = ACTIONS(6575),
    [anon_sym_CARET] = ACTIONS(6575),
    [anon_sym_AMP] = ACTIONS(6575),
    [anon_sym_EQ_EQ] = ACTIONS(6577),
    [anon_sym_BANG_EQ] = ACTIONS(6577),
    [anon_sym_GT] = ACTIONS(6575),
    [anon_sym_GT_EQ] = ACTIONS(6577),
    [anon_sym_LT_EQ] = ACTIONS(6575),
    [anon_sym_LT] = ACTIONS(6575),
    [anon_sym_LT_LT] = ACTIONS(6575),
    [anon_sym_GT_GT] = ACTIONS(6575),
    [anon_sym_SEMI] = ACTIONS(6577),
    [anon_sym___attribute__] = ACTIONS(6575),
    [anon_sym___attribute] = ACTIONS(6575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6577),
    [anon_sym_LBRACE] = ACTIONS(6577),
    [anon_sym_RBRACE] = ACTIONS(6577),
    [anon_sym_LBRACK] = ACTIONS(6575),
    [anon_sym_RBRACK] = ACTIONS(6577),
    [anon_sym_EQ] = ACTIONS(6575),
    [anon_sym_COLON] = ACTIONS(6577),
    [anon_sym_QMARK] = ACTIONS(6577),
    [anon_sym_STAR_EQ] = ACTIONS(6577),
    [anon_sym_SLASH_EQ] = ACTIONS(6577),
    [anon_sym_PERCENT_EQ] = ACTIONS(6577),
    [anon_sym_PLUS_EQ] = ACTIONS(6577),
    [anon_sym_DASH_EQ] = ACTIONS(6577),
    [anon_sym_LT_LT_EQ] = ACTIONS(6577),
    [anon_sym_GT_GT_EQ] = ACTIONS(6577),
    [anon_sym_AMP_EQ] = ACTIONS(6577),
    [anon_sym_CARET_EQ] = ACTIONS(6577),
    [anon_sym_PIPE_EQ] = ACTIONS(6577),
    [anon_sym_and_eq] = ACTIONS(6575),
    [anon_sym_or_eq] = ACTIONS(6575),
    [anon_sym_xor_eq] = ACTIONS(6575),
    [anon_sym_LT_EQ_GT] = ACTIONS(6577),
    [anon_sym_or] = ACTIONS(6575),
    [anon_sym_and] = ACTIONS(6575),
    [anon_sym_bitor] = ACTIONS(6575),
    [anon_sym_xor] = ACTIONS(6575),
    [anon_sym_bitand] = ACTIONS(6575),
    [anon_sym_not_eq] = ACTIONS(6575),
    [anon_sym_DASH_DASH] = ACTIONS(6577),
    [anon_sym_PLUS_PLUS] = ACTIONS(6577),
    [anon_sym_DOT] = ACTIONS(6575),
    [anon_sym_DOT_STAR] = ACTIONS(6577),
    [anon_sym_DASH_GT] = ACTIONS(6577),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6575),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6577),
  },
  [STATE(2580)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5724),
    [anon_sym_COMMA] = ACTIONS(5724),
    [anon_sym_LPAREN2] = ACTIONS(5724),
    [anon_sym_DASH] = ACTIONS(5722),
    [anon_sym_PLUS] = ACTIONS(5722),
    [anon_sym_STAR] = ACTIONS(5724),
    [anon_sym_SLASH] = ACTIONS(5722),
    [anon_sym_PERCENT] = ACTIONS(5724),
    [anon_sym_PIPE_PIPE] = ACTIONS(5724),
    [anon_sym_AMP_AMP] = ACTIONS(5724),
    [anon_sym_PIPE] = ACTIONS(5722),
    [anon_sym_CARET] = ACTIONS(5724),
    [anon_sym_AMP] = ACTIONS(5722),
    [anon_sym_EQ_EQ] = ACTIONS(5724),
    [anon_sym_BANG_EQ] = ACTIONS(5724),
    [anon_sym_GT] = ACTIONS(5722),
    [anon_sym_GT_EQ] = ACTIONS(5722),
    [anon_sym_LT_EQ] = ACTIONS(5722),
    [anon_sym_LT] = ACTIONS(5722),
    [anon_sym_LT_LT] = ACTIONS(5722),
    [anon_sym_GT_GT] = ACTIONS(5722),
    [anon_sym___extension__] = ACTIONS(5724),
    [anon_sym___global__] = ACTIONS(5724),
    [anon_sym___attribute__] = ACTIONS(5724),
    [anon_sym___attribute] = ACTIONS(5722),
    [anon_sym_LBRACE] = ACTIONS(5724),
    [anon_sym_LBRACK] = ACTIONS(5724),
    [anon_sym_const] = ACTIONS(5722),
    [anon_sym_constexpr] = ACTIONS(5724),
    [anon_sym_volatile] = ACTIONS(5724),
    [anon_sym_restrict] = ACTIONS(5724),
    [anon_sym___restrict__] = ACTIONS(5724),
    [anon_sym__Atomic] = ACTIONS(5724),
    [anon_sym__Noreturn] = ACTIONS(5724),
    [anon_sym_noreturn] = ACTIONS(5724),
    [anon_sym__Nonnull] = ACTIONS(5724),
    [anon_sym_mutable] = ACTIONS(5724),
    [anon_sym_constinit] = ACTIONS(5724),
    [anon_sym_consteval] = ACTIONS(5724),
    [anon_sym___shared__] = ACTIONS(5724),
    [anon_sym___local__] = ACTIONS(5724),
    [anon_sym___constant__] = ACTIONS(5724),
    [anon_sym___managed__] = ACTIONS(5724),
    [anon_sym___grid_constant__] = ACTIONS(5724),
    [anon_sym_alignas] = ACTIONS(5724),
    [anon_sym__Alignas] = ACTIONS(5724),
    [anon_sym_QMARK] = ACTIONS(5724),
    [anon_sym_LT_EQ_GT] = ACTIONS(5724),
    [anon_sym_or] = ACTIONS(5724),
    [anon_sym_and] = ACTIONS(5724),
    [anon_sym_bitor] = ACTIONS(5724),
    [anon_sym_xor] = ACTIONS(5724),
    [anon_sym_bitand] = ACTIONS(5724),
    [anon_sym_not_eq] = ACTIONS(5724),
    [anon_sym_DASH_DASH] = ACTIONS(5724),
    [anon_sym_PLUS_PLUS] = ACTIONS(5724),
    [anon_sym_DOT] = ACTIONS(5722),
    [anon_sym_DOT_STAR] = ACTIONS(5724),
    [anon_sym_DASH_GT] = ACTIONS(5724),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5724),
    [anon_sym_decltype] = ACTIONS(5724),
    [anon_sym_final] = ACTIONS(5724),
    [anon_sym_override] = ACTIONS(5724),
    [anon_sym_GT2] = ACTIONS(5724),
    [anon_sym_requires] = ACTIONS(5724),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5724),
  },
  [STATE(2581)] = {
    [sym_attribute_specifier] = STATE(2257),
    [sym_identifier] = ACTIONS(6250),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6248),
    [anon_sym_COMMA] = ACTIONS(6248),
    [anon_sym_RPAREN] = ACTIONS(6248),
    [anon_sym_LPAREN2] = ACTIONS(6248),
    [anon_sym_TILDE] = ACTIONS(6248),
    [anon_sym_STAR] = ACTIONS(6248),
    [anon_sym_AMP_AMP] = ACTIONS(6248),
    [anon_sym_AMP] = ACTIONS(6250),
    [anon_sym_SEMI] = ACTIONS(6248),
    [anon_sym___extension__] = ACTIONS(6250),
    [anon_sym___device__] = ACTIONS(6250),
    [anon_sym___host__] = ACTIONS(6250),
    [anon_sym___global__] = ACTIONS(6250),
    [anon_sym___forceinline__] = ACTIONS(6250),
    [anon_sym___noinline__] = ACTIONS(6250),
    [anon_sym_virtual] = ACTIONS(6250),
    [anon_sym_extern] = ACTIONS(6250),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6248),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6248),
    [anon_sym___declspec] = ACTIONS(6250),
    [anon_sym___based] = ACTIONS(6250),
    [anon_sym___cdecl] = ACTIONS(6250),
    [anon_sym___clrcall] = ACTIONS(6250),
    [anon_sym___stdcall] = ACTIONS(6250),
    [anon_sym___fastcall] = ACTIONS(6250),
    [anon_sym___thiscall] = ACTIONS(6250),
    [anon_sym___vectorcall] = ACTIONS(6250),
    [anon_sym_LBRACK] = ACTIONS(6250),
    [anon_sym_static] = ACTIONS(6250),
    [anon_sym_EQ] = ACTIONS(6248),
    [anon_sym_register] = ACTIONS(6250),
    [anon_sym_inline] = ACTIONS(6250),
    [anon_sym___inline] = ACTIONS(6250),
    [anon_sym___inline__] = ACTIONS(6250),
    [anon_sym___forceinline] = ACTIONS(6250),
    [anon_sym_thread_local] = ACTIONS(6250),
    [anon_sym___thread] = ACTIONS(6250),
    [anon_sym_const] = ACTIONS(6250),
    [anon_sym_constexpr] = ACTIONS(6250),
    [anon_sym_volatile] = ACTIONS(6250),
    [anon_sym_restrict] = ACTIONS(6250),
    [anon_sym___restrict__] = ACTIONS(6250),
    [anon_sym__Atomic] = ACTIONS(6250),
    [anon_sym__Noreturn] = ACTIONS(6250),
    [anon_sym_noreturn] = ACTIONS(6250),
    [anon_sym__Nonnull] = ACTIONS(6250),
    [anon_sym_mutable] = ACTIONS(6250),
    [anon_sym_constinit] = ACTIONS(6250),
    [anon_sym_consteval] = ACTIONS(6250),
    [anon_sym___shared__] = ACTIONS(6250),
    [anon_sym___local__] = ACTIONS(6250),
    [anon_sym___constant__] = ACTIONS(6250),
    [anon_sym___managed__] = ACTIONS(6250),
    [anon_sym___grid_constant__] = ACTIONS(6250),
    [anon_sym_alignas] = ACTIONS(6250),
    [anon_sym__Alignas] = ACTIONS(6250),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6250),
    [anon_sym_decltype] = ACTIONS(6250),
    [anon_sym_template] = ACTIONS(6250),
    [anon_sym_GT2] = ACTIONS(6248),
    [anon_sym_operator] = ACTIONS(6250),
    [anon_sym___launch_bounds__] = ACTIONS(6250),
  },
  [STATE(2582)] = {
    [sym_string_literal] = STATE(2598),
    [sym_raw_string_literal] = STATE(2598),
    [aux_sym_concatenated_string_repeat1] = STATE(2598),
    [sym_identifier] = ACTIONS(6579),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6002),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_LPAREN2] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_STAR] = ACTIONS(6004),
    [anon_sym_SLASH] = ACTIONS(6004),
    [anon_sym_PERCENT] = ACTIONS(6004),
    [anon_sym_PIPE_PIPE] = ACTIONS(6002),
    [anon_sym_AMP_AMP] = ACTIONS(6002),
    [anon_sym_PIPE] = ACTIONS(6004),
    [anon_sym_CARET] = ACTIONS(6004),
    [anon_sym_AMP] = ACTIONS(6004),
    [anon_sym_EQ_EQ] = ACTIONS(6002),
    [anon_sym_BANG_EQ] = ACTIONS(6002),
    [anon_sym_GT] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(6004),
    [anon_sym_LT_EQ] = ACTIONS(6004),
    [anon_sym_LT] = ACTIONS(6004),
    [anon_sym_LT_LT] = ACTIONS(6004),
    [anon_sym_GT_GT] = ACTIONS(6004),
    [anon_sym_LBRACK] = ACTIONS(6002),
    [anon_sym_EQ] = ACTIONS(6004),
    [anon_sym_QMARK] = ACTIONS(6002),
    [anon_sym_STAR_EQ] = ACTIONS(6002),
    [anon_sym_SLASH_EQ] = ACTIONS(6002),
    [anon_sym_PERCENT_EQ] = ACTIONS(6002),
    [anon_sym_PLUS_EQ] = ACTIONS(6002),
    [anon_sym_DASH_EQ] = ACTIONS(6002),
    [anon_sym_LT_LT_EQ] = ACTIONS(6002),
    [anon_sym_GT_GT_EQ] = ACTIONS(6004),
    [anon_sym_AMP_EQ] = ACTIONS(6002),
    [anon_sym_CARET_EQ] = ACTIONS(6002),
    [anon_sym_PIPE_EQ] = ACTIONS(6002),
    [anon_sym_and_eq] = ACTIONS(6004),
    [anon_sym_or_eq] = ACTIONS(6004),
    [anon_sym_xor_eq] = ACTIONS(6004),
    [anon_sym_LT_EQ_GT] = ACTIONS(6002),
    [anon_sym_or] = ACTIONS(6004),
    [anon_sym_and] = ACTIONS(6004),
    [anon_sym_bitor] = ACTIONS(6004),
    [anon_sym_xor] = ACTIONS(6004),
    [anon_sym_bitand] = ACTIONS(6004),
    [anon_sym_not_eq] = ACTIONS(6004),
    [anon_sym_DASH_DASH] = ACTIONS(6002),
    [anon_sym_PLUS_PLUS] = ACTIONS(6002),
    [anon_sym_DOT] = ACTIONS(6004),
    [anon_sym_DOT_STAR] = ACTIONS(6002),
    [anon_sym_DASH_GT] = ACTIONS(6002),
    [anon_sym_L_DQUOTE] = ACTIONS(6581),
    [anon_sym_u_DQUOTE] = ACTIONS(6581),
    [anon_sym_U_DQUOTE] = ACTIONS(6581),
    [anon_sym_u8_DQUOTE] = ACTIONS(6581),
    [anon_sym_DQUOTE] = ACTIONS(6581),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(6002),
    [anon_sym_R_DQUOTE] = ACTIONS(6583),
    [anon_sym_LR_DQUOTE] = ACTIONS(6583),
    [anon_sym_uR_DQUOTE] = ACTIONS(6583),
    [anon_sym_UR_DQUOTE] = ACTIONS(6583),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6583),
    [sym_literal_suffix] = ACTIONS(6004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6002),
  },
  [STATE(2583)] = {
    [sym_argument_list] = STATE(2792),
    [sym_initializer_list] = STATE(2792),
    [sym_identifier] = ACTIONS(6585),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6587),
    [anon_sym_COMMA] = ACTIONS(6587),
    [anon_sym_RPAREN] = ACTIONS(6587),
    [aux_sym_preproc_if_token2] = ACTIONS(6587),
    [aux_sym_preproc_else_token1] = ACTIONS(6587),
    [aux_sym_preproc_elif_token1] = ACTIONS(6585),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6587),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6587),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6585),
    [anon_sym_PLUS] = ACTIONS(6585),
    [anon_sym_STAR] = ACTIONS(6585),
    [anon_sym_SLASH] = ACTIONS(6585),
    [anon_sym_PERCENT] = ACTIONS(6585),
    [anon_sym_PIPE_PIPE] = ACTIONS(6587),
    [anon_sym_AMP_AMP] = ACTIONS(6587),
    [anon_sym_PIPE] = ACTIONS(6585),
    [anon_sym_CARET] = ACTIONS(6585),
    [anon_sym_AMP] = ACTIONS(6585),
    [anon_sym_EQ_EQ] = ACTIONS(6587),
    [anon_sym_BANG_EQ] = ACTIONS(6587),
    [anon_sym_GT] = ACTIONS(6585),
    [anon_sym_GT_EQ] = ACTIONS(6587),
    [anon_sym_LT_EQ] = ACTIONS(6585),
    [anon_sym_LT] = ACTIONS(6585),
    [anon_sym_LT_LT] = ACTIONS(6585),
    [anon_sym_GT_GT] = ACTIONS(6585),
    [anon_sym_SEMI] = ACTIONS(6587),
    [anon_sym___attribute__] = ACTIONS(6585),
    [anon_sym___attribute] = ACTIONS(6585),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(6587),
    [anon_sym_LBRACK] = ACTIONS(6587),
    [anon_sym_RBRACK] = ACTIONS(6587),
    [anon_sym_EQ] = ACTIONS(6585),
    [anon_sym_COLON] = ACTIONS(6587),
    [anon_sym_QMARK] = ACTIONS(6587),
    [anon_sym_STAR_EQ] = ACTIONS(6587),
    [anon_sym_SLASH_EQ] = ACTIONS(6587),
    [anon_sym_PERCENT_EQ] = ACTIONS(6587),
    [anon_sym_PLUS_EQ] = ACTIONS(6587),
    [anon_sym_DASH_EQ] = ACTIONS(6587),
    [anon_sym_LT_LT_EQ] = ACTIONS(6587),
    [anon_sym_GT_GT_EQ] = ACTIONS(6587),
    [anon_sym_AMP_EQ] = ACTIONS(6587),
    [anon_sym_CARET_EQ] = ACTIONS(6587),
    [anon_sym_PIPE_EQ] = ACTIONS(6587),
    [anon_sym_and_eq] = ACTIONS(6585),
    [anon_sym_or_eq] = ACTIONS(6585),
    [anon_sym_xor_eq] = ACTIONS(6585),
    [anon_sym_LT_EQ_GT] = ACTIONS(6587),
    [anon_sym_or] = ACTIONS(6585),
    [anon_sym_and] = ACTIONS(6585),
    [anon_sym_bitor] = ACTIONS(6585),
    [anon_sym_xor] = ACTIONS(6585),
    [anon_sym_bitand] = ACTIONS(6585),
    [anon_sym_not_eq] = ACTIONS(6585),
    [anon_sym_DASH_DASH] = ACTIONS(6587),
    [anon_sym_PLUS_PLUS] = ACTIONS(6587),
    [anon_sym_DOT] = ACTIONS(6585),
    [anon_sym_DOT_STAR] = ACTIONS(6587),
    [anon_sym_DASH_GT] = ACTIONS(6587),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6587),
  },
  [STATE(2584)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5760),
    [anon_sym_COMMA] = ACTIONS(5760),
    [anon_sym_LPAREN2] = ACTIONS(5760),
    [anon_sym_DASH] = ACTIONS(5758),
    [anon_sym_PLUS] = ACTIONS(5758),
    [anon_sym_STAR] = ACTIONS(5760),
    [anon_sym_SLASH] = ACTIONS(5758),
    [anon_sym_PERCENT] = ACTIONS(5760),
    [anon_sym_PIPE_PIPE] = ACTIONS(5760),
    [anon_sym_AMP_AMP] = ACTIONS(5760),
    [anon_sym_PIPE] = ACTIONS(5758),
    [anon_sym_CARET] = ACTIONS(5760),
    [anon_sym_AMP] = ACTIONS(5758),
    [anon_sym_EQ_EQ] = ACTIONS(5760),
    [anon_sym_BANG_EQ] = ACTIONS(5760),
    [anon_sym_GT] = ACTIONS(5758),
    [anon_sym_GT_EQ] = ACTIONS(5758),
    [anon_sym_LT_EQ] = ACTIONS(5758),
    [anon_sym_LT] = ACTIONS(5758),
    [anon_sym_LT_LT] = ACTIONS(5758),
    [anon_sym_GT_GT] = ACTIONS(5758),
    [anon_sym___extension__] = ACTIONS(5760),
    [anon_sym___global__] = ACTIONS(5760),
    [anon_sym___attribute__] = ACTIONS(5760),
    [anon_sym___attribute] = ACTIONS(5758),
    [anon_sym_LBRACE] = ACTIONS(5760),
    [anon_sym_LBRACK] = ACTIONS(5760),
    [anon_sym_const] = ACTIONS(5758),
    [anon_sym_constexpr] = ACTIONS(5760),
    [anon_sym_volatile] = ACTIONS(5760),
    [anon_sym_restrict] = ACTIONS(5760),
    [anon_sym___restrict__] = ACTIONS(5760),
    [anon_sym__Atomic] = ACTIONS(5760),
    [anon_sym__Noreturn] = ACTIONS(5760),
    [anon_sym_noreturn] = ACTIONS(5760),
    [anon_sym__Nonnull] = ACTIONS(5760),
    [anon_sym_mutable] = ACTIONS(5760),
    [anon_sym_constinit] = ACTIONS(5760),
    [anon_sym_consteval] = ACTIONS(5760),
    [anon_sym___shared__] = ACTIONS(5760),
    [anon_sym___local__] = ACTIONS(5760),
    [anon_sym___constant__] = ACTIONS(5760),
    [anon_sym___managed__] = ACTIONS(5760),
    [anon_sym___grid_constant__] = ACTIONS(5760),
    [anon_sym_alignas] = ACTIONS(5760),
    [anon_sym__Alignas] = ACTIONS(5760),
    [anon_sym_QMARK] = ACTIONS(5760),
    [anon_sym_LT_EQ_GT] = ACTIONS(5760),
    [anon_sym_or] = ACTIONS(5760),
    [anon_sym_and] = ACTIONS(5760),
    [anon_sym_bitor] = ACTIONS(5760),
    [anon_sym_xor] = ACTIONS(5760),
    [anon_sym_bitand] = ACTIONS(5760),
    [anon_sym_not_eq] = ACTIONS(5760),
    [anon_sym_DASH_DASH] = ACTIONS(5760),
    [anon_sym_PLUS_PLUS] = ACTIONS(5760),
    [anon_sym_DOT] = ACTIONS(5758),
    [anon_sym_DOT_STAR] = ACTIONS(5760),
    [anon_sym_DASH_GT] = ACTIONS(5760),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5760),
    [anon_sym_decltype] = ACTIONS(5760),
    [anon_sym_final] = ACTIONS(5760),
    [anon_sym_override] = ACTIONS(5760),
    [anon_sym_GT2] = ACTIONS(5760),
    [anon_sym_requires] = ACTIONS(5760),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5760),
  },
  [STATE(2585)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2608),
    [sym_identifier] = ACTIONS(5990),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5988),
    [anon_sym_COMMA] = ACTIONS(5988),
    [aux_sym_preproc_if_token2] = ACTIONS(5988),
    [aux_sym_preproc_else_token1] = ACTIONS(5988),
    [aux_sym_preproc_elif_token1] = ACTIONS(5990),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5988),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5988),
    [anon_sym_LPAREN2] = ACTIONS(5988),
    [anon_sym_DASH] = ACTIONS(5990),
    [anon_sym_PLUS] = ACTIONS(5990),
    [anon_sym_STAR] = ACTIONS(5990),
    [anon_sym_SLASH] = ACTIONS(5990),
    [anon_sym_PERCENT] = ACTIONS(5990),
    [anon_sym_PIPE_PIPE] = ACTIONS(5988),
    [anon_sym_AMP_AMP] = ACTIONS(5988),
    [anon_sym_PIPE] = ACTIONS(5990),
    [anon_sym_CARET] = ACTIONS(5990),
    [anon_sym_AMP] = ACTIONS(5990),
    [anon_sym_EQ_EQ] = ACTIONS(5988),
    [anon_sym_BANG_EQ] = ACTIONS(5988),
    [anon_sym_GT] = ACTIONS(5990),
    [anon_sym_GT_EQ] = ACTIONS(5988),
    [anon_sym_LT_EQ] = ACTIONS(5990),
    [anon_sym_LT] = ACTIONS(5990),
    [anon_sym_LT_LT] = ACTIONS(5990),
    [anon_sym_GT_GT] = ACTIONS(5990),
    [anon_sym___attribute__] = ACTIONS(5990),
    [anon_sym___attribute] = ACTIONS(5990),
    [anon_sym_LBRACE] = ACTIONS(5988),
    [anon_sym_signed] = ACTIONS(6589),
    [anon_sym_unsigned] = ACTIONS(6589),
    [anon_sym_long] = ACTIONS(6589),
    [anon_sym_short] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_EQ] = ACTIONS(5990),
    [anon_sym_QMARK] = ACTIONS(5988),
    [anon_sym_STAR_EQ] = ACTIONS(5988),
    [anon_sym_SLASH_EQ] = ACTIONS(5988),
    [anon_sym_PERCENT_EQ] = ACTIONS(5988),
    [anon_sym_PLUS_EQ] = ACTIONS(5988),
    [anon_sym_DASH_EQ] = ACTIONS(5988),
    [anon_sym_LT_LT_EQ] = ACTIONS(5988),
    [anon_sym_GT_GT_EQ] = ACTIONS(5988),
    [anon_sym_AMP_EQ] = ACTIONS(5988),
    [anon_sym_CARET_EQ] = ACTIONS(5988),
    [anon_sym_PIPE_EQ] = ACTIONS(5988),
    [anon_sym_and_eq] = ACTIONS(5990),
    [anon_sym_or_eq] = ACTIONS(5990),
    [anon_sym_xor_eq] = ACTIONS(5990),
    [anon_sym_LT_EQ_GT] = ACTIONS(5988),
    [anon_sym_or] = ACTIONS(5990),
    [anon_sym_and] = ACTIONS(5990),
    [anon_sym_bitor] = ACTIONS(5990),
    [anon_sym_xor] = ACTIONS(5990),
    [anon_sym_bitand] = ACTIONS(5990),
    [anon_sym_not_eq] = ACTIONS(5990),
    [anon_sym_DASH_DASH] = ACTIONS(5988),
    [anon_sym_PLUS_PLUS] = ACTIONS(5988),
    [anon_sym_DOT] = ACTIONS(5990),
    [anon_sym_DOT_STAR] = ACTIONS(5988),
    [anon_sym_DASH_GT] = ACTIONS(5988),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5990),
    [anon_sym_decltype] = ACTIONS(5990),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5988),
  },
  [STATE(2586)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2612),
    [sym_identifier] = ACTIONS(5919),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5917),
    [anon_sym_COMMA] = ACTIONS(5917),
    [aux_sym_preproc_if_token2] = ACTIONS(5917),
    [aux_sym_preproc_else_token1] = ACTIONS(5917),
    [aux_sym_preproc_elif_token1] = ACTIONS(5919),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5917),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5917),
    [anon_sym_LPAREN2] = ACTIONS(5917),
    [anon_sym_DASH] = ACTIONS(5919),
    [anon_sym_PLUS] = ACTIONS(5919),
    [anon_sym_STAR] = ACTIONS(5919),
    [anon_sym_SLASH] = ACTIONS(5919),
    [anon_sym_PERCENT] = ACTIONS(5919),
    [anon_sym_PIPE_PIPE] = ACTIONS(5917),
    [anon_sym_AMP_AMP] = ACTIONS(5917),
    [anon_sym_PIPE] = ACTIONS(5919),
    [anon_sym_CARET] = ACTIONS(5919),
    [anon_sym_AMP] = ACTIONS(5919),
    [anon_sym_EQ_EQ] = ACTIONS(5917),
    [anon_sym_BANG_EQ] = ACTIONS(5917),
    [anon_sym_GT] = ACTIONS(5919),
    [anon_sym_GT_EQ] = ACTIONS(5917),
    [anon_sym_LT_EQ] = ACTIONS(5919),
    [anon_sym_LT] = ACTIONS(5919),
    [anon_sym_LT_LT] = ACTIONS(5919),
    [anon_sym_GT_GT] = ACTIONS(5919),
    [anon_sym___attribute__] = ACTIONS(5919),
    [anon_sym___attribute] = ACTIONS(5919),
    [anon_sym_LBRACE] = ACTIONS(5917),
    [anon_sym_signed] = ACTIONS(6591),
    [anon_sym_unsigned] = ACTIONS(6591),
    [anon_sym_long] = ACTIONS(6591),
    [anon_sym_short] = ACTIONS(6591),
    [anon_sym_LBRACK] = ACTIONS(5917),
    [anon_sym_EQ] = ACTIONS(5919),
    [anon_sym_QMARK] = ACTIONS(5917),
    [anon_sym_STAR_EQ] = ACTIONS(5917),
    [anon_sym_SLASH_EQ] = ACTIONS(5917),
    [anon_sym_PERCENT_EQ] = ACTIONS(5917),
    [anon_sym_PLUS_EQ] = ACTIONS(5917),
    [anon_sym_DASH_EQ] = ACTIONS(5917),
    [anon_sym_LT_LT_EQ] = ACTIONS(5917),
    [anon_sym_GT_GT_EQ] = ACTIONS(5917),
    [anon_sym_AMP_EQ] = ACTIONS(5917),
    [anon_sym_CARET_EQ] = ACTIONS(5917),
    [anon_sym_PIPE_EQ] = ACTIONS(5917),
    [anon_sym_and_eq] = ACTIONS(5919),
    [anon_sym_or_eq] = ACTIONS(5919),
    [anon_sym_xor_eq] = ACTIONS(5919),
    [anon_sym_LT_EQ_GT] = ACTIONS(5917),
    [anon_sym_or] = ACTIONS(5919),
    [anon_sym_and] = ACTIONS(5919),
    [anon_sym_bitor] = ACTIONS(5919),
    [anon_sym_xor] = ACTIONS(5919),
    [anon_sym_bitand] = ACTIONS(5919),
    [anon_sym_not_eq] = ACTIONS(5919),
    [anon_sym_DASH_DASH] = ACTIONS(5917),
    [anon_sym_PLUS_PLUS] = ACTIONS(5917),
    [anon_sym_DOT] = ACTIONS(5919),
    [anon_sym_DOT_STAR] = ACTIONS(5917),
    [anon_sym_DASH_GT] = ACTIONS(5917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5919),
    [anon_sym_decltype] = ACTIONS(5919),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5917),
  },
  [STATE(2587)] = {
    [sym_attribute_declaration] = STATE(2548),
    [aux_sym_attributed_declarator_repeat1] = STATE(2548),
    [sym_identifier] = ACTIONS(6593),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6595),
    [anon_sym_COMMA] = ACTIONS(6595),
    [anon_sym_RPAREN] = ACTIONS(6595),
    [aux_sym_preproc_if_token2] = ACTIONS(6595),
    [aux_sym_preproc_else_token1] = ACTIONS(6595),
    [aux_sym_preproc_elif_token1] = ACTIONS(6593),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6595),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6595),
    [anon_sym_LPAREN2] = ACTIONS(6595),
    [anon_sym_DASH] = ACTIONS(6593),
    [anon_sym_PLUS] = ACTIONS(6593),
    [anon_sym_STAR] = ACTIONS(6593),
    [anon_sym_SLASH] = ACTIONS(6593),
    [anon_sym_PERCENT] = ACTIONS(6593),
    [anon_sym_PIPE_PIPE] = ACTIONS(6595),
    [anon_sym_AMP_AMP] = ACTIONS(6595),
    [anon_sym_PIPE] = ACTIONS(6593),
    [anon_sym_CARET] = ACTIONS(6593),
    [anon_sym_AMP] = ACTIONS(6593),
    [anon_sym_EQ_EQ] = ACTIONS(6595),
    [anon_sym_BANG_EQ] = ACTIONS(6595),
    [anon_sym_GT] = ACTIONS(6593),
    [anon_sym_GT_EQ] = ACTIONS(6595),
    [anon_sym_LT_EQ] = ACTIONS(6593),
    [anon_sym_LT] = ACTIONS(6593),
    [anon_sym_LT_LT] = ACTIONS(6593),
    [anon_sym_GT_GT] = ACTIONS(6593),
    [anon_sym_SEMI] = ACTIONS(6595),
    [anon_sym___attribute__] = ACTIONS(6593),
    [anon_sym___attribute] = ACTIONS(6593),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6444),
    [anon_sym_RBRACE] = ACTIONS(6595),
    [anon_sym_LBRACK] = ACTIONS(6593),
    [anon_sym_RBRACK] = ACTIONS(6595),
    [anon_sym_EQ] = ACTIONS(6593),
    [anon_sym_COLON] = ACTIONS(6595),
    [anon_sym_QMARK] = ACTIONS(6595),
    [anon_sym_STAR_EQ] = ACTIONS(6595),
    [anon_sym_SLASH_EQ] = ACTIONS(6595),
    [anon_sym_PERCENT_EQ] = ACTIONS(6595),
    [anon_sym_PLUS_EQ] = ACTIONS(6595),
    [anon_sym_DASH_EQ] = ACTIONS(6595),
    [anon_sym_LT_LT_EQ] = ACTIONS(6595),
    [anon_sym_GT_GT_EQ] = ACTIONS(6595),
    [anon_sym_AMP_EQ] = ACTIONS(6595),
    [anon_sym_CARET_EQ] = ACTIONS(6595),
    [anon_sym_PIPE_EQ] = ACTIONS(6595),
    [anon_sym_and_eq] = ACTIONS(6593),
    [anon_sym_or_eq] = ACTIONS(6593),
    [anon_sym_xor_eq] = ACTIONS(6593),
    [anon_sym_LT_EQ_GT] = ACTIONS(6595),
    [anon_sym_or] = ACTIONS(6593),
    [anon_sym_and] = ACTIONS(6593),
    [anon_sym_bitor] = ACTIONS(6593),
    [anon_sym_xor] = ACTIONS(6593),
    [anon_sym_bitand] = ACTIONS(6593),
    [anon_sym_not_eq] = ACTIONS(6593),
    [anon_sym_DASH_DASH] = ACTIONS(6595),
    [anon_sym_PLUS_PLUS] = ACTIONS(6595),
    [anon_sym_DOT] = ACTIONS(6593),
    [anon_sym_DOT_STAR] = ACTIONS(6595),
    [anon_sym_DASH_GT] = ACTIONS(6595),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6595),
  },
  [STATE(2588)] = {
    [sym_attribute_specifier] = STATE(2272),
    [sym_identifier] = ACTIONS(6244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6242),
    [anon_sym_COMMA] = ACTIONS(6242),
    [anon_sym_RPAREN] = ACTIONS(6242),
    [anon_sym_LPAREN2] = ACTIONS(6242),
    [anon_sym_TILDE] = ACTIONS(6242),
    [anon_sym_STAR] = ACTIONS(6242),
    [anon_sym_AMP_AMP] = ACTIONS(6242),
    [anon_sym_AMP] = ACTIONS(6244),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym___extension__] = ACTIONS(6244),
    [anon_sym___device__] = ACTIONS(6244),
    [anon_sym___host__] = ACTIONS(6244),
    [anon_sym___global__] = ACTIONS(6244),
    [anon_sym___forceinline__] = ACTIONS(6244),
    [anon_sym___noinline__] = ACTIONS(6244),
    [anon_sym_virtual] = ACTIONS(6244),
    [anon_sym_extern] = ACTIONS(6244),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6242),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6242),
    [anon_sym___declspec] = ACTIONS(6244),
    [anon_sym___based] = ACTIONS(6244),
    [anon_sym___cdecl] = ACTIONS(6244),
    [anon_sym___clrcall] = ACTIONS(6244),
    [anon_sym___stdcall] = ACTIONS(6244),
    [anon_sym___fastcall] = ACTIONS(6244),
    [anon_sym___thiscall] = ACTIONS(6244),
    [anon_sym___vectorcall] = ACTIONS(6244),
    [anon_sym_LBRACK] = ACTIONS(6244),
    [anon_sym_static] = ACTIONS(6244),
    [anon_sym_EQ] = ACTIONS(6242),
    [anon_sym_register] = ACTIONS(6244),
    [anon_sym_inline] = ACTIONS(6244),
    [anon_sym___inline] = ACTIONS(6244),
    [anon_sym___inline__] = ACTIONS(6244),
    [anon_sym___forceinline] = ACTIONS(6244),
    [anon_sym_thread_local] = ACTIONS(6244),
    [anon_sym___thread] = ACTIONS(6244),
    [anon_sym_const] = ACTIONS(6244),
    [anon_sym_constexpr] = ACTIONS(6244),
    [anon_sym_volatile] = ACTIONS(6244),
    [anon_sym_restrict] = ACTIONS(6244),
    [anon_sym___restrict__] = ACTIONS(6244),
    [anon_sym__Atomic] = ACTIONS(6244),
    [anon_sym__Noreturn] = ACTIONS(6244),
    [anon_sym_noreturn] = ACTIONS(6244),
    [anon_sym__Nonnull] = ACTIONS(6244),
    [anon_sym_mutable] = ACTIONS(6244),
    [anon_sym_constinit] = ACTIONS(6244),
    [anon_sym_consteval] = ACTIONS(6244),
    [anon_sym___shared__] = ACTIONS(6244),
    [anon_sym___local__] = ACTIONS(6244),
    [anon_sym___constant__] = ACTIONS(6244),
    [anon_sym___managed__] = ACTIONS(6244),
    [anon_sym___grid_constant__] = ACTIONS(6244),
    [anon_sym_alignas] = ACTIONS(6244),
    [anon_sym__Alignas] = ACTIONS(6244),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6244),
    [anon_sym_decltype] = ACTIONS(6244),
    [anon_sym_template] = ACTIONS(6244),
    [anon_sym_GT2] = ACTIONS(6242),
    [anon_sym_operator] = ACTIONS(6244),
    [anon_sym___launch_bounds__] = ACTIONS(6244),
  },
  [STATE(2589)] = {
    [sym_identifier] = ACTIONS(6597),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6599),
    [anon_sym_COMMA] = ACTIONS(6599),
    [anon_sym_RPAREN] = ACTIONS(6599),
    [aux_sym_preproc_if_token2] = ACTIONS(6599),
    [aux_sym_preproc_else_token1] = ACTIONS(6599),
    [aux_sym_preproc_elif_token1] = ACTIONS(6597),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6599),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6599),
    [anon_sym_LPAREN2] = ACTIONS(6599),
    [anon_sym_DASH] = ACTIONS(6597),
    [anon_sym_PLUS] = ACTIONS(6597),
    [anon_sym_STAR] = ACTIONS(6597),
    [anon_sym_SLASH] = ACTIONS(6597),
    [anon_sym_PERCENT] = ACTIONS(6597),
    [anon_sym_PIPE_PIPE] = ACTIONS(6599),
    [anon_sym_AMP_AMP] = ACTIONS(6599),
    [anon_sym_PIPE] = ACTIONS(6597),
    [anon_sym_CARET] = ACTIONS(6597),
    [anon_sym_AMP] = ACTIONS(6597),
    [anon_sym_EQ_EQ] = ACTIONS(6599),
    [anon_sym_BANG_EQ] = ACTIONS(6599),
    [anon_sym_GT] = ACTIONS(6597),
    [anon_sym_GT_EQ] = ACTIONS(6599),
    [anon_sym_LT_EQ] = ACTIONS(6597),
    [anon_sym_LT] = ACTIONS(6597),
    [anon_sym_LT_LT] = ACTIONS(6597),
    [anon_sym_GT_GT] = ACTIONS(6597),
    [anon_sym_SEMI] = ACTIONS(6599),
    [anon_sym___attribute__] = ACTIONS(6597),
    [anon_sym___attribute] = ACTIONS(6597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6599),
    [anon_sym_LBRACE] = ACTIONS(6599),
    [anon_sym_RBRACE] = ACTIONS(6599),
    [anon_sym_LBRACK] = ACTIONS(6597),
    [anon_sym_RBRACK] = ACTIONS(6599),
    [anon_sym_EQ] = ACTIONS(6597),
    [anon_sym_COLON] = ACTIONS(6599),
    [anon_sym_QMARK] = ACTIONS(6599),
    [anon_sym_STAR_EQ] = ACTIONS(6599),
    [anon_sym_SLASH_EQ] = ACTIONS(6599),
    [anon_sym_PERCENT_EQ] = ACTIONS(6599),
    [anon_sym_PLUS_EQ] = ACTIONS(6599),
    [anon_sym_DASH_EQ] = ACTIONS(6599),
    [anon_sym_LT_LT_EQ] = ACTIONS(6599),
    [anon_sym_GT_GT_EQ] = ACTIONS(6599),
    [anon_sym_AMP_EQ] = ACTIONS(6599),
    [anon_sym_CARET_EQ] = ACTIONS(6599),
    [anon_sym_PIPE_EQ] = ACTIONS(6599),
    [anon_sym_and_eq] = ACTIONS(6597),
    [anon_sym_or_eq] = ACTIONS(6597),
    [anon_sym_xor_eq] = ACTIONS(6597),
    [anon_sym_LT_EQ_GT] = ACTIONS(6599),
    [anon_sym_or] = ACTIONS(6597),
    [anon_sym_and] = ACTIONS(6597),
    [anon_sym_bitor] = ACTIONS(6597),
    [anon_sym_xor] = ACTIONS(6597),
    [anon_sym_bitand] = ACTIONS(6597),
    [anon_sym_not_eq] = ACTIONS(6597),
    [anon_sym_DASH_DASH] = ACTIONS(6599),
    [anon_sym_PLUS_PLUS] = ACTIONS(6599),
    [anon_sym_DOT] = ACTIONS(6597),
    [anon_sym_DOT_STAR] = ACTIONS(6599),
    [anon_sym_DASH_GT] = ACTIONS(6599),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6597),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6599),
  },
  [STATE(2590)] = {
    [sym_argument_list] = STATE(2756),
    [sym_initializer_list] = STATE(2756),
    [sym_identifier] = ACTIONS(6601),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6603),
    [anon_sym_COMMA] = ACTIONS(6603),
    [anon_sym_RPAREN] = ACTIONS(6603),
    [aux_sym_preproc_if_token2] = ACTIONS(6603),
    [aux_sym_preproc_else_token1] = ACTIONS(6603),
    [aux_sym_preproc_elif_token1] = ACTIONS(6601),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6603),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6603),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6601),
    [anon_sym_PLUS] = ACTIONS(6601),
    [anon_sym_STAR] = ACTIONS(6601),
    [anon_sym_SLASH] = ACTIONS(6601),
    [anon_sym_PERCENT] = ACTIONS(6601),
    [anon_sym_PIPE_PIPE] = ACTIONS(6603),
    [anon_sym_AMP_AMP] = ACTIONS(6603),
    [anon_sym_PIPE] = ACTIONS(6601),
    [anon_sym_CARET] = ACTIONS(6601),
    [anon_sym_AMP] = ACTIONS(6601),
    [anon_sym_EQ_EQ] = ACTIONS(6603),
    [anon_sym_BANG_EQ] = ACTIONS(6603),
    [anon_sym_GT] = ACTIONS(6601),
    [anon_sym_GT_EQ] = ACTIONS(6603),
    [anon_sym_LT_EQ] = ACTIONS(6601),
    [anon_sym_LT] = ACTIONS(6601),
    [anon_sym_LT_LT] = ACTIONS(6601),
    [anon_sym_GT_GT] = ACTIONS(6601),
    [anon_sym_SEMI] = ACTIONS(6603),
    [anon_sym___attribute__] = ACTIONS(6601),
    [anon_sym___attribute] = ACTIONS(6601),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(6603),
    [anon_sym_LBRACK] = ACTIONS(6603),
    [anon_sym_RBRACK] = ACTIONS(6603),
    [anon_sym_EQ] = ACTIONS(6601),
    [anon_sym_COLON] = ACTIONS(6603),
    [anon_sym_QMARK] = ACTIONS(6603),
    [anon_sym_STAR_EQ] = ACTIONS(6603),
    [anon_sym_SLASH_EQ] = ACTIONS(6603),
    [anon_sym_PERCENT_EQ] = ACTIONS(6603),
    [anon_sym_PLUS_EQ] = ACTIONS(6603),
    [anon_sym_DASH_EQ] = ACTIONS(6603),
    [anon_sym_LT_LT_EQ] = ACTIONS(6603),
    [anon_sym_GT_GT_EQ] = ACTIONS(6603),
    [anon_sym_AMP_EQ] = ACTIONS(6603),
    [anon_sym_CARET_EQ] = ACTIONS(6603),
    [anon_sym_PIPE_EQ] = ACTIONS(6603),
    [anon_sym_and_eq] = ACTIONS(6601),
    [anon_sym_or_eq] = ACTIONS(6601),
    [anon_sym_xor_eq] = ACTIONS(6601),
    [anon_sym_LT_EQ_GT] = ACTIONS(6603),
    [anon_sym_or] = ACTIONS(6601),
    [anon_sym_and] = ACTIONS(6601),
    [anon_sym_bitor] = ACTIONS(6601),
    [anon_sym_xor] = ACTIONS(6601),
    [anon_sym_bitand] = ACTIONS(6601),
    [anon_sym_not_eq] = ACTIONS(6601),
    [anon_sym_DASH_DASH] = ACTIONS(6603),
    [anon_sym_PLUS_PLUS] = ACTIONS(6603),
    [anon_sym_DOT] = ACTIONS(6601),
    [anon_sym_DOT_STAR] = ACTIONS(6603),
    [anon_sym_DASH_GT] = ACTIONS(6603),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6603),
  },
  [STATE(2591)] = {
    [sym_identifier] = ACTIONS(6605),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6607),
    [anon_sym_COMMA] = ACTIONS(6607),
    [anon_sym_RPAREN] = ACTIONS(6607),
    [aux_sym_preproc_if_token2] = ACTIONS(6607),
    [aux_sym_preproc_else_token1] = ACTIONS(6607),
    [aux_sym_preproc_elif_token1] = ACTIONS(6605),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6607),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6607),
    [anon_sym_LPAREN2] = ACTIONS(6607),
    [anon_sym_DASH] = ACTIONS(6605),
    [anon_sym_PLUS] = ACTIONS(6605),
    [anon_sym_STAR] = ACTIONS(6605),
    [anon_sym_SLASH] = ACTIONS(6605),
    [anon_sym_PERCENT] = ACTIONS(6605),
    [anon_sym_PIPE_PIPE] = ACTIONS(6607),
    [anon_sym_AMP_AMP] = ACTIONS(6607),
    [anon_sym_PIPE] = ACTIONS(6605),
    [anon_sym_CARET] = ACTIONS(6605),
    [anon_sym_AMP] = ACTIONS(6605),
    [anon_sym_EQ_EQ] = ACTIONS(6607),
    [anon_sym_BANG_EQ] = ACTIONS(6607),
    [anon_sym_GT] = ACTIONS(6605),
    [anon_sym_GT_EQ] = ACTIONS(6607),
    [anon_sym_LT_EQ] = ACTIONS(6605),
    [anon_sym_LT] = ACTIONS(6605),
    [anon_sym_LT_LT] = ACTIONS(6605),
    [anon_sym_GT_GT] = ACTIONS(6605),
    [anon_sym_SEMI] = ACTIONS(6607),
    [anon_sym___attribute__] = ACTIONS(6605),
    [anon_sym___attribute] = ACTIONS(6605),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6607),
    [anon_sym_LBRACE] = ACTIONS(6607),
    [anon_sym_RBRACE] = ACTIONS(6607),
    [anon_sym_LBRACK] = ACTIONS(6605),
    [anon_sym_RBRACK] = ACTIONS(6607),
    [anon_sym_EQ] = ACTIONS(6605),
    [anon_sym_COLON] = ACTIONS(6607),
    [anon_sym_QMARK] = ACTIONS(6607),
    [anon_sym_STAR_EQ] = ACTIONS(6607),
    [anon_sym_SLASH_EQ] = ACTIONS(6607),
    [anon_sym_PERCENT_EQ] = ACTIONS(6607),
    [anon_sym_PLUS_EQ] = ACTIONS(6607),
    [anon_sym_DASH_EQ] = ACTIONS(6607),
    [anon_sym_LT_LT_EQ] = ACTIONS(6607),
    [anon_sym_GT_GT_EQ] = ACTIONS(6607),
    [anon_sym_AMP_EQ] = ACTIONS(6607),
    [anon_sym_CARET_EQ] = ACTIONS(6607),
    [anon_sym_PIPE_EQ] = ACTIONS(6607),
    [anon_sym_and_eq] = ACTIONS(6605),
    [anon_sym_or_eq] = ACTIONS(6605),
    [anon_sym_xor_eq] = ACTIONS(6605),
    [anon_sym_LT_EQ_GT] = ACTIONS(6607),
    [anon_sym_or] = ACTIONS(6605),
    [anon_sym_and] = ACTIONS(6605),
    [anon_sym_bitor] = ACTIONS(6605),
    [anon_sym_xor] = ACTIONS(6605),
    [anon_sym_bitand] = ACTIONS(6605),
    [anon_sym_not_eq] = ACTIONS(6605),
    [anon_sym_DASH_DASH] = ACTIONS(6607),
    [anon_sym_PLUS_PLUS] = ACTIONS(6607),
    [anon_sym_DOT] = ACTIONS(6605),
    [anon_sym_DOT_STAR] = ACTIONS(6607),
    [anon_sym_DASH_GT] = ACTIONS(6607),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6605),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6607),
  },
  [STATE(2592)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5764),
    [anon_sym_COMMA] = ACTIONS(5764),
    [anon_sym_LPAREN2] = ACTIONS(5764),
    [anon_sym_DASH] = ACTIONS(5762),
    [anon_sym_PLUS] = ACTIONS(5762),
    [anon_sym_STAR] = ACTIONS(5764),
    [anon_sym_SLASH] = ACTIONS(5762),
    [anon_sym_PERCENT] = ACTIONS(5764),
    [anon_sym_PIPE_PIPE] = ACTIONS(5764),
    [anon_sym_AMP_AMP] = ACTIONS(5764),
    [anon_sym_PIPE] = ACTIONS(5762),
    [anon_sym_CARET] = ACTIONS(5764),
    [anon_sym_AMP] = ACTIONS(5762),
    [anon_sym_EQ_EQ] = ACTIONS(5764),
    [anon_sym_BANG_EQ] = ACTIONS(5764),
    [anon_sym_GT] = ACTIONS(5762),
    [anon_sym_GT_EQ] = ACTIONS(5762),
    [anon_sym_LT_EQ] = ACTIONS(5762),
    [anon_sym_LT] = ACTIONS(5762),
    [anon_sym_LT_LT] = ACTIONS(5762),
    [anon_sym_GT_GT] = ACTIONS(5762),
    [anon_sym___extension__] = ACTIONS(5764),
    [anon_sym___global__] = ACTIONS(5764),
    [anon_sym___attribute__] = ACTIONS(5764),
    [anon_sym___attribute] = ACTIONS(5762),
    [anon_sym_LBRACE] = ACTIONS(5764),
    [anon_sym_LBRACK] = ACTIONS(5764),
    [anon_sym_const] = ACTIONS(5762),
    [anon_sym_constexpr] = ACTIONS(5764),
    [anon_sym_volatile] = ACTIONS(5764),
    [anon_sym_restrict] = ACTIONS(5764),
    [anon_sym___restrict__] = ACTIONS(5764),
    [anon_sym__Atomic] = ACTIONS(5764),
    [anon_sym__Noreturn] = ACTIONS(5764),
    [anon_sym_noreturn] = ACTIONS(5764),
    [anon_sym__Nonnull] = ACTIONS(5764),
    [anon_sym_mutable] = ACTIONS(5764),
    [anon_sym_constinit] = ACTIONS(5764),
    [anon_sym_consteval] = ACTIONS(5764),
    [anon_sym___shared__] = ACTIONS(5764),
    [anon_sym___local__] = ACTIONS(5764),
    [anon_sym___constant__] = ACTIONS(5764),
    [anon_sym___managed__] = ACTIONS(5764),
    [anon_sym___grid_constant__] = ACTIONS(5764),
    [anon_sym_alignas] = ACTIONS(5764),
    [anon_sym__Alignas] = ACTIONS(5764),
    [anon_sym_QMARK] = ACTIONS(5764),
    [anon_sym_LT_EQ_GT] = ACTIONS(5764),
    [anon_sym_or] = ACTIONS(5764),
    [anon_sym_and] = ACTIONS(5764),
    [anon_sym_bitor] = ACTIONS(5764),
    [anon_sym_xor] = ACTIONS(5764),
    [anon_sym_bitand] = ACTIONS(5764),
    [anon_sym_not_eq] = ACTIONS(5764),
    [anon_sym_DASH_DASH] = ACTIONS(5764),
    [anon_sym_PLUS_PLUS] = ACTIONS(5764),
    [anon_sym_DOT] = ACTIONS(5762),
    [anon_sym_DOT_STAR] = ACTIONS(5764),
    [anon_sym_DASH_GT] = ACTIONS(5764),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5764),
    [anon_sym_decltype] = ACTIONS(5764),
    [anon_sym_final] = ACTIONS(5764),
    [anon_sym_override] = ACTIONS(5764),
    [anon_sym_GT2] = ACTIONS(5764),
    [anon_sym_requires] = ACTIONS(5764),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5764),
  },
  [STATE(2593)] = {
    [sym_identifier] = ACTIONS(6609),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6611),
    [anon_sym_COMMA] = ACTIONS(6611),
    [anon_sym_RPAREN] = ACTIONS(6611),
    [aux_sym_preproc_if_token2] = ACTIONS(6611),
    [aux_sym_preproc_else_token1] = ACTIONS(6611),
    [aux_sym_preproc_elif_token1] = ACTIONS(6609),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6611),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6611),
    [anon_sym_LPAREN2] = ACTIONS(6611),
    [anon_sym_DASH] = ACTIONS(6609),
    [anon_sym_PLUS] = ACTIONS(6609),
    [anon_sym_STAR] = ACTIONS(6609),
    [anon_sym_SLASH] = ACTIONS(6609),
    [anon_sym_PERCENT] = ACTIONS(6609),
    [anon_sym_PIPE_PIPE] = ACTIONS(6611),
    [anon_sym_AMP_AMP] = ACTIONS(6611),
    [anon_sym_PIPE] = ACTIONS(6609),
    [anon_sym_CARET] = ACTIONS(6609),
    [anon_sym_AMP] = ACTIONS(6609),
    [anon_sym_EQ_EQ] = ACTIONS(6611),
    [anon_sym_BANG_EQ] = ACTIONS(6611),
    [anon_sym_GT] = ACTIONS(6609),
    [anon_sym_GT_EQ] = ACTIONS(6611),
    [anon_sym_LT_EQ] = ACTIONS(6609),
    [anon_sym_LT] = ACTIONS(6609),
    [anon_sym_LT_LT] = ACTIONS(6609),
    [anon_sym_GT_GT] = ACTIONS(6609),
    [anon_sym_SEMI] = ACTIONS(6611),
    [anon_sym___attribute__] = ACTIONS(6609),
    [anon_sym___attribute] = ACTIONS(6609),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6611),
    [anon_sym_LBRACE] = ACTIONS(6611),
    [anon_sym_RBRACE] = ACTIONS(6611),
    [anon_sym_LBRACK] = ACTIONS(6609),
    [anon_sym_RBRACK] = ACTIONS(6611),
    [anon_sym_EQ] = ACTIONS(6609),
    [anon_sym_COLON] = ACTIONS(6611),
    [anon_sym_QMARK] = ACTIONS(6611),
    [anon_sym_STAR_EQ] = ACTIONS(6611),
    [anon_sym_SLASH_EQ] = ACTIONS(6611),
    [anon_sym_PERCENT_EQ] = ACTIONS(6611),
    [anon_sym_PLUS_EQ] = ACTIONS(6611),
    [anon_sym_DASH_EQ] = ACTIONS(6611),
    [anon_sym_LT_LT_EQ] = ACTIONS(6611),
    [anon_sym_GT_GT_EQ] = ACTIONS(6611),
    [anon_sym_AMP_EQ] = ACTIONS(6611),
    [anon_sym_CARET_EQ] = ACTIONS(6611),
    [anon_sym_PIPE_EQ] = ACTIONS(6611),
    [anon_sym_and_eq] = ACTIONS(6609),
    [anon_sym_or_eq] = ACTIONS(6609),
    [anon_sym_xor_eq] = ACTIONS(6609),
    [anon_sym_LT_EQ_GT] = ACTIONS(6611),
    [anon_sym_or] = ACTIONS(6609),
    [anon_sym_and] = ACTIONS(6609),
    [anon_sym_bitor] = ACTIONS(6609),
    [anon_sym_xor] = ACTIONS(6609),
    [anon_sym_bitand] = ACTIONS(6609),
    [anon_sym_not_eq] = ACTIONS(6609),
    [anon_sym_DASH_DASH] = ACTIONS(6611),
    [anon_sym_PLUS_PLUS] = ACTIONS(6611),
    [anon_sym_DOT] = ACTIONS(6609),
    [anon_sym_DOT_STAR] = ACTIONS(6611),
    [anon_sym_DASH_GT] = ACTIONS(6611),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6609),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6611),
  },
  [STATE(2594)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(6613),
    [anon_sym_COLON] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(6615),
    [anon_sym_SLASH_EQ] = ACTIONS(6615),
    [anon_sym_PERCENT_EQ] = ACTIONS(6615),
    [anon_sym_PLUS_EQ] = ACTIONS(6615),
    [anon_sym_DASH_EQ] = ACTIONS(6615),
    [anon_sym_LT_LT_EQ] = ACTIONS(6615),
    [anon_sym_GT_GT_EQ] = ACTIONS(6615),
    [anon_sym_AMP_EQ] = ACTIONS(6615),
    [anon_sym_CARET_EQ] = ACTIONS(6615),
    [anon_sym_PIPE_EQ] = ACTIONS(6615),
    [anon_sym_and_eq] = ACTIONS(6615),
    [anon_sym_or_eq] = ACTIONS(6615),
    [anon_sym_xor_eq] = ACTIONS(6615),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2595)] = {
    [sym_identifier] = ACTIONS(6617),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6619),
    [anon_sym_COMMA] = ACTIONS(6619),
    [anon_sym_RPAREN] = ACTIONS(6619),
    [aux_sym_preproc_if_token2] = ACTIONS(6619),
    [aux_sym_preproc_else_token1] = ACTIONS(6619),
    [aux_sym_preproc_elif_token1] = ACTIONS(6617),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6619),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6619),
    [anon_sym_LPAREN2] = ACTIONS(6619),
    [anon_sym_DASH] = ACTIONS(6617),
    [anon_sym_PLUS] = ACTIONS(6617),
    [anon_sym_STAR] = ACTIONS(6617),
    [anon_sym_SLASH] = ACTIONS(6617),
    [anon_sym_PERCENT] = ACTIONS(6617),
    [anon_sym_PIPE_PIPE] = ACTIONS(6619),
    [anon_sym_AMP_AMP] = ACTIONS(6619),
    [anon_sym_PIPE] = ACTIONS(6617),
    [anon_sym_CARET] = ACTIONS(6617),
    [anon_sym_AMP] = ACTIONS(6617),
    [anon_sym_EQ_EQ] = ACTIONS(6619),
    [anon_sym_BANG_EQ] = ACTIONS(6619),
    [anon_sym_GT] = ACTIONS(6617),
    [anon_sym_GT_EQ] = ACTIONS(6619),
    [anon_sym_LT_EQ] = ACTIONS(6617),
    [anon_sym_LT] = ACTIONS(6617),
    [anon_sym_LT_LT] = ACTIONS(6617),
    [anon_sym_GT_GT] = ACTIONS(6617),
    [anon_sym_SEMI] = ACTIONS(6619),
    [anon_sym___attribute__] = ACTIONS(6617),
    [anon_sym___attribute] = ACTIONS(6617),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6619),
    [anon_sym_LBRACE] = ACTIONS(6619),
    [anon_sym_RBRACE] = ACTIONS(6619),
    [anon_sym_LBRACK] = ACTIONS(6617),
    [anon_sym_RBRACK] = ACTIONS(6619),
    [anon_sym_EQ] = ACTIONS(6617),
    [anon_sym_COLON] = ACTIONS(6619),
    [anon_sym_QMARK] = ACTIONS(6619),
    [anon_sym_STAR_EQ] = ACTIONS(6619),
    [anon_sym_SLASH_EQ] = ACTIONS(6619),
    [anon_sym_PERCENT_EQ] = ACTIONS(6619),
    [anon_sym_PLUS_EQ] = ACTIONS(6619),
    [anon_sym_DASH_EQ] = ACTIONS(6619),
    [anon_sym_LT_LT_EQ] = ACTIONS(6619),
    [anon_sym_GT_GT_EQ] = ACTIONS(6619),
    [anon_sym_AMP_EQ] = ACTIONS(6619),
    [anon_sym_CARET_EQ] = ACTIONS(6619),
    [anon_sym_PIPE_EQ] = ACTIONS(6619),
    [anon_sym_and_eq] = ACTIONS(6617),
    [anon_sym_or_eq] = ACTIONS(6617),
    [anon_sym_xor_eq] = ACTIONS(6617),
    [anon_sym_LT_EQ_GT] = ACTIONS(6619),
    [anon_sym_or] = ACTIONS(6617),
    [anon_sym_and] = ACTIONS(6617),
    [anon_sym_bitor] = ACTIONS(6617),
    [anon_sym_xor] = ACTIONS(6617),
    [anon_sym_bitand] = ACTIONS(6617),
    [anon_sym_not_eq] = ACTIONS(6617),
    [anon_sym_DASH_DASH] = ACTIONS(6619),
    [anon_sym_PLUS_PLUS] = ACTIONS(6619),
    [anon_sym_DOT] = ACTIONS(6617),
    [anon_sym_DOT_STAR] = ACTIONS(6619),
    [anon_sym_DASH_GT] = ACTIONS(6619),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6617),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6619),
  },
  [STATE(2596)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5756),
    [anon_sym_COMMA] = ACTIONS(5756),
    [anon_sym_LPAREN2] = ACTIONS(5756),
    [anon_sym_DASH] = ACTIONS(5754),
    [anon_sym_PLUS] = ACTIONS(5754),
    [anon_sym_STAR] = ACTIONS(5756),
    [anon_sym_SLASH] = ACTIONS(5754),
    [anon_sym_PERCENT] = ACTIONS(5756),
    [anon_sym_PIPE_PIPE] = ACTIONS(5756),
    [anon_sym_AMP_AMP] = ACTIONS(5756),
    [anon_sym_PIPE] = ACTIONS(5754),
    [anon_sym_CARET] = ACTIONS(5756),
    [anon_sym_AMP] = ACTIONS(5754),
    [anon_sym_EQ_EQ] = ACTIONS(5756),
    [anon_sym_BANG_EQ] = ACTIONS(5756),
    [anon_sym_GT] = ACTIONS(5754),
    [anon_sym_GT_EQ] = ACTIONS(5754),
    [anon_sym_LT_EQ] = ACTIONS(5754),
    [anon_sym_LT] = ACTIONS(5754),
    [anon_sym_LT_LT] = ACTIONS(5754),
    [anon_sym_GT_GT] = ACTIONS(5754),
    [anon_sym___extension__] = ACTIONS(5756),
    [anon_sym___global__] = ACTIONS(5756),
    [anon_sym___attribute__] = ACTIONS(5756),
    [anon_sym___attribute] = ACTIONS(5754),
    [anon_sym_LBRACE] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5756),
    [anon_sym_const] = ACTIONS(5754),
    [anon_sym_constexpr] = ACTIONS(5756),
    [anon_sym_volatile] = ACTIONS(5756),
    [anon_sym_restrict] = ACTIONS(5756),
    [anon_sym___restrict__] = ACTIONS(5756),
    [anon_sym__Atomic] = ACTIONS(5756),
    [anon_sym__Noreturn] = ACTIONS(5756),
    [anon_sym_noreturn] = ACTIONS(5756),
    [anon_sym__Nonnull] = ACTIONS(5756),
    [anon_sym_mutable] = ACTIONS(5756),
    [anon_sym_constinit] = ACTIONS(5756),
    [anon_sym_consteval] = ACTIONS(5756),
    [anon_sym___shared__] = ACTIONS(5756),
    [anon_sym___local__] = ACTIONS(5756),
    [anon_sym___constant__] = ACTIONS(5756),
    [anon_sym___managed__] = ACTIONS(5756),
    [anon_sym___grid_constant__] = ACTIONS(5756),
    [anon_sym_alignas] = ACTIONS(5756),
    [anon_sym__Alignas] = ACTIONS(5756),
    [anon_sym_QMARK] = ACTIONS(5756),
    [anon_sym_LT_EQ_GT] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5756),
    [anon_sym_and] = ACTIONS(5756),
    [anon_sym_bitor] = ACTIONS(5756),
    [anon_sym_xor] = ACTIONS(5756),
    [anon_sym_bitand] = ACTIONS(5756),
    [anon_sym_not_eq] = ACTIONS(5756),
    [anon_sym_DASH_DASH] = ACTIONS(5756),
    [anon_sym_PLUS_PLUS] = ACTIONS(5756),
    [anon_sym_DOT] = ACTIONS(5754),
    [anon_sym_DOT_STAR] = ACTIONS(5756),
    [anon_sym_DASH_GT] = ACTIONS(5756),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5756),
    [anon_sym_decltype] = ACTIONS(5756),
    [anon_sym_final] = ACTIONS(5756),
    [anon_sym_override] = ACTIONS(5756),
    [anon_sym_GT2] = ACTIONS(5756),
    [anon_sym_requires] = ACTIONS(5756),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5756),
  },
  [STATE(2597)] = {
    [sym_identifier] = ACTIONS(6621),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6623),
    [anon_sym_COMMA] = ACTIONS(6623),
    [anon_sym_RPAREN] = ACTIONS(6623),
    [aux_sym_preproc_if_token2] = ACTIONS(6623),
    [aux_sym_preproc_else_token1] = ACTIONS(6623),
    [aux_sym_preproc_elif_token1] = ACTIONS(6621),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6623),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6623),
    [anon_sym_LPAREN2] = ACTIONS(6623),
    [anon_sym_DASH] = ACTIONS(6621),
    [anon_sym_PLUS] = ACTIONS(6621),
    [anon_sym_STAR] = ACTIONS(6621),
    [anon_sym_SLASH] = ACTIONS(6621),
    [anon_sym_PERCENT] = ACTIONS(6621),
    [anon_sym_PIPE_PIPE] = ACTIONS(6623),
    [anon_sym_AMP_AMP] = ACTIONS(6623),
    [anon_sym_PIPE] = ACTIONS(6621),
    [anon_sym_CARET] = ACTIONS(6621),
    [anon_sym_AMP] = ACTIONS(6621),
    [anon_sym_EQ_EQ] = ACTIONS(6623),
    [anon_sym_BANG_EQ] = ACTIONS(6623),
    [anon_sym_GT] = ACTIONS(6621),
    [anon_sym_GT_EQ] = ACTIONS(6623),
    [anon_sym_LT_EQ] = ACTIONS(6621),
    [anon_sym_LT] = ACTIONS(6621),
    [anon_sym_LT_LT] = ACTIONS(6621),
    [anon_sym_GT_GT] = ACTIONS(6621),
    [anon_sym_SEMI] = ACTIONS(6623),
    [anon_sym___attribute__] = ACTIONS(6621),
    [anon_sym___attribute] = ACTIONS(6621),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6623),
    [anon_sym_LBRACE] = ACTIONS(6623),
    [anon_sym_RBRACE] = ACTIONS(6623),
    [anon_sym_LBRACK] = ACTIONS(6621),
    [anon_sym_RBRACK] = ACTIONS(6623),
    [anon_sym_EQ] = ACTIONS(6621),
    [anon_sym_COLON] = ACTIONS(6623),
    [anon_sym_QMARK] = ACTIONS(6623),
    [anon_sym_STAR_EQ] = ACTIONS(6623),
    [anon_sym_SLASH_EQ] = ACTIONS(6623),
    [anon_sym_PERCENT_EQ] = ACTIONS(6623),
    [anon_sym_PLUS_EQ] = ACTIONS(6623),
    [anon_sym_DASH_EQ] = ACTIONS(6623),
    [anon_sym_LT_LT_EQ] = ACTIONS(6623),
    [anon_sym_GT_GT_EQ] = ACTIONS(6623),
    [anon_sym_AMP_EQ] = ACTIONS(6623),
    [anon_sym_CARET_EQ] = ACTIONS(6623),
    [anon_sym_PIPE_EQ] = ACTIONS(6623),
    [anon_sym_and_eq] = ACTIONS(6621),
    [anon_sym_or_eq] = ACTIONS(6621),
    [anon_sym_xor_eq] = ACTIONS(6621),
    [anon_sym_LT_EQ_GT] = ACTIONS(6623),
    [anon_sym_or] = ACTIONS(6621),
    [anon_sym_and] = ACTIONS(6621),
    [anon_sym_bitor] = ACTIONS(6621),
    [anon_sym_xor] = ACTIONS(6621),
    [anon_sym_bitand] = ACTIONS(6621),
    [anon_sym_not_eq] = ACTIONS(6621),
    [anon_sym_DASH_DASH] = ACTIONS(6623),
    [anon_sym_PLUS_PLUS] = ACTIONS(6623),
    [anon_sym_DOT] = ACTIONS(6621),
    [anon_sym_DOT_STAR] = ACTIONS(6623),
    [anon_sym_DASH_GT] = ACTIONS(6623),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6621),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6623),
  },
  [STATE(2598)] = {
    [sym_string_literal] = STATE(2609),
    [sym_raw_string_literal] = STATE(2609),
    [aux_sym_concatenated_string_repeat1] = STATE(2609),
    [sym_identifier] = ACTIONS(6625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6016),
    [anon_sym_COMMA] = ACTIONS(6016),
    [anon_sym_LPAREN2] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6018),
    [anon_sym_STAR] = ACTIONS(6018),
    [anon_sym_SLASH] = ACTIONS(6018),
    [anon_sym_PERCENT] = ACTIONS(6018),
    [anon_sym_PIPE_PIPE] = ACTIONS(6016),
    [anon_sym_AMP_AMP] = ACTIONS(6016),
    [anon_sym_PIPE] = ACTIONS(6018),
    [anon_sym_CARET] = ACTIONS(6018),
    [anon_sym_AMP] = ACTIONS(6018),
    [anon_sym_EQ_EQ] = ACTIONS(6016),
    [anon_sym_BANG_EQ] = ACTIONS(6016),
    [anon_sym_GT] = ACTIONS(6018),
    [anon_sym_GT_EQ] = ACTIONS(6018),
    [anon_sym_LT_EQ] = ACTIONS(6018),
    [anon_sym_LT] = ACTIONS(6018),
    [anon_sym_LT_LT] = ACTIONS(6018),
    [anon_sym_GT_GT] = ACTIONS(6018),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [anon_sym_EQ] = ACTIONS(6018),
    [anon_sym_QMARK] = ACTIONS(6016),
    [anon_sym_STAR_EQ] = ACTIONS(6016),
    [anon_sym_SLASH_EQ] = ACTIONS(6016),
    [anon_sym_PERCENT_EQ] = ACTIONS(6016),
    [anon_sym_PLUS_EQ] = ACTIONS(6016),
    [anon_sym_DASH_EQ] = ACTIONS(6016),
    [anon_sym_LT_LT_EQ] = ACTIONS(6016),
    [anon_sym_GT_GT_EQ] = ACTIONS(6018),
    [anon_sym_AMP_EQ] = ACTIONS(6016),
    [anon_sym_CARET_EQ] = ACTIONS(6016),
    [anon_sym_PIPE_EQ] = ACTIONS(6016),
    [anon_sym_and_eq] = ACTIONS(6018),
    [anon_sym_or_eq] = ACTIONS(6018),
    [anon_sym_xor_eq] = ACTIONS(6018),
    [anon_sym_LT_EQ_GT] = ACTIONS(6016),
    [anon_sym_or] = ACTIONS(6018),
    [anon_sym_and] = ACTIONS(6018),
    [anon_sym_bitor] = ACTIONS(6018),
    [anon_sym_xor] = ACTIONS(6018),
    [anon_sym_bitand] = ACTIONS(6018),
    [anon_sym_not_eq] = ACTIONS(6018),
    [anon_sym_DASH_DASH] = ACTIONS(6016),
    [anon_sym_PLUS_PLUS] = ACTIONS(6016),
    [anon_sym_DOT] = ACTIONS(6018),
    [anon_sym_DOT_STAR] = ACTIONS(6016),
    [anon_sym_DASH_GT] = ACTIONS(6016),
    [anon_sym_L_DQUOTE] = ACTIONS(6581),
    [anon_sym_u_DQUOTE] = ACTIONS(6581),
    [anon_sym_U_DQUOTE] = ACTIONS(6581),
    [anon_sym_u8_DQUOTE] = ACTIONS(6581),
    [anon_sym_DQUOTE] = ACTIONS(6581),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(6016),
    [anon_sym_R_DQUOTE] = ACTIONS(6583),
    [anon_sym_LR_DQUOTE] = ACTIONS(6583),
    [anon_sym_uR_DQUOTE] = ACTIONS(6583),
    [anon_sym_UR_DQUOTE] = ACTIONS(6583),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6583),
    [sym_literal_suffix] = ACTIONS(6018),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6016),
  },
  [STATE(2599)] = {
    [sym_identifier] = ACTIONS(6627),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6629),
    [anon_sym_COMMA] = ACTIONS(6629),
    [anon_sym_RPAREN] = ACTIONS(6629),
    [aux_sym_preproc_if_token2] = ACTIONS(6629),
    [aux_sym_preproc_else_token1] = ACTIONS(6629),
    [aux_sym_preproc_elif_token1] = ACTIONS(6627),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6629),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6629),
    [anon_sym_LPAREN2] = ACTIONS(6629),
    [anon_sym_DASH] = ACTIONS(6627),
    [anon_sym_PLUS] = ACTIONS(6627),
    [anon_sym_STAR] = ACTIONS(6627),
    [anon_sym_SLASH] = ACTIONS(6627),
    [anon_sym_PERCENT] = ACTIONS(6627),
    [anon_sym_PIPE_PIPE] = ACTIONS(6629),
    [anon_sym_AMP_AMP] = ACTIONS(6629),
    [anon_sym_PIPE] = ACTIONS(6627),
    [anon_sym_CARET] = ACTIONS(6627),
    [anon_sym_AMP] = ACTIONS(6627),
    [anon_sym_EQ_EQ] = ACTIONS(6629),
    [anon_sym_BANG_EQ] = ACTIONS(6629),
    [anon_sym_GT] = ACTIONS(6627),
    [anon_sym_GT_EQ] = ACTIONS(6629),
    [anon_sym_LT_EQ] = ACTIONS(6627),
    [anon_sym_LT] = ACTIONS(6627),
    [anon_sym_LT_LT] = ACTIONS(6627),
    [anon_sym_GT_GT] = ACTIONS(6627),
    [anon_sym_SEMI] = ACTIONS(6629),
    [anon_sym___attribute__] = ACTIONS(6627),
    [anon_sym___attribute] = ACTIONS(6627),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6629),
    [anon_sym_LBRACE] = ACTIONS(6629),
    [anon_sym_RBRACE] = ACTIONS(6629),
    [anon_sym_LBRACK] = ACTIONS(6627),
    [anon_sym_RBRACK] = ACTIONS(6629),
    [anon_sym_EQ] = ACTIONS(6627),
    [anon_sym_COLON] = ACTIONS(6629),
    [anon_sym_QMARK] = ACTIONS(6629),
    [anon_sym_STAR_EQ] = ACTIONS(6629),
    [anon_sym_SLASH_EQ] = ACTIONS(6629),
    [anon_sym_PERCENT_EQ] = ACTIONS(6629),
    [anon_sym_PLUS_EQ] = ACTIONS(6629),
    [anon_sym_DASH_EQ] = ACTIONS(6629),
    [anon_sym_LT_LT_EQ] = ACTIONS(6629),
    [anon_sym_GT_GT_EQ] = ACTIONS(6629),
    [anon_sym_AMP_EQ] = ACTIONS(6629),
    [anon_sym_CARET_EQ] = ACTIONS(6629),
    [anon_sym_PIPE_EQ] = ACTIONS(6629),
    [anon_sym_and_eq] = ACTIONS(6627),
    [anon_sym_or_eq] = ACTIONS(6627),
    [anon_sym_xor_eq] = ACTIONS(6627),
    [anon_sym_LT_EQ_GT] = ACTIONS(6629),
    [anon_sym_or] = ACTIONS(6627),
    [anon_sym_and] = ACTIONS(6627),
    [anon_sym_bitor] = ACTIONS(6627),
    [anon_sym_xor] = ACTIONS(6627),
    [anon_sym_bitand] = ACTIONS(6627),
    [anon_sym_not_eq] = ACTIONS(6627),
    [anon_sym_DASH_DASH] = ACTIONS(6629),
    [anon_sym_PLUS_PLUS] = ACTIONS(6629),
    [anon_sym_DOT] = ACTIONS(6627),
    [anon_sym_DOT_STAR] = ACTIONS(6629),
    [anon_sym_DASH_GT] = ACTIONS(6629),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6627),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6629),
  },
  [STATE(2600)] = {
    [sym_identifier] = ACTIONS(6631),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6633),
    [anon_sym_COMMA] = ACTIONS(6633),
    [anon_sym_RPAREN] = ACTIONS(6633),
    [aux_sym_preproc_if_token2] = ACTIONS(6633),
    [aux_sym_preproc_else_token1] = ACTIONS(6633),
    [aux_sym_preproc_elif_token1] = ACTIONS(6631),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6633),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6633),
    [anon_sym_LPAREN2] = ACTIONS(6633),
    [anon_sym_DASH] = ACTIONS(6631),
    [anon_sym_PLUS] = ACTIONS(6631),
    [anon_sym_STAR] = ACTIONS(6631),
    [anon_sym_SLASH] = ACTIONS(6631),
    [anon_sym_PERCENT] = ACTIONS(6631),
    [anon_sym_PIPE_PIPE] = ACTIONS(6633),
    [anon_sym_AMP_AMP] = ACTIONS(6633),
    [anon_sym_PIPE] = ACTIONS(6631),
    [anon_sym_CARET] = ACTIONS(6631),
    [anon_sym_AMP] = ACTIONS(6631),
    [anon_sym_EQ_EQ] = ACTIONS(6633),
    [anon_sym_BANG_EQ] = ACTIONS(6633),
    [anon_sym_GT] = ACTIONS(6631),
    [anon_sym_GT_EQ] = ACTIONS(6633),
    [anon_sym_LT_EQ] = ACTIONS(6631),
    [anon_sym_LT] = ACTIONS(6631),
    [anon_sym_LT_LT] = ACTIONS(6631),
    [anon_sym_GT_GT] = ACTIONS(6631),
    [anon_sym_SEMI] = ACTIONS(6633),
    [anon_sym___attribute__] = ACTIONS(6631),
    [anon_sym___attribute] = ACTIONS(6631),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6633),
    [anon_sym_LBRACE] = ACTIONS(6633),
    [anon_sym_RBRACE] = ACTIONS(6633),
    [anon_sym_LBRACK] = ACTIONS(6631),
    [anon_sym_RBRACK] = ACTIONS(6633),
    [anon_sym_EQ] = ACTIONS(6631),
    [anon_sym_COLON] = ACTIONS(6633),
    [anon_sym_QMARK] = ACTIONS(6633),
    [anon_sym_STAR_EQ] = ACTIONS(6633),
    [anon_sym_SLASH_EQ] = ACTIONS(6633),
    [anon_sym_PERCENT_EQ] = ACTIONS(6633),
    [anon_sym_PLUS_EQ] = ACTIONS(6633),
    [anon_sym_DASH_EQ] = ACTIONS(6633),
    [anon_sym_LT_LT_EQ] = ACTIONS(6633),
    [anon_sym_GT_GT_EQ] = ACTIONS(6633),
    [anon_sym_AMP_EQ] = ACTIONS(6633),
    [anon_sym_CARET_EQ] = ACTIONS(6633),
    [anon_sym_PIPE_EQ] = ACTIONS(6633),
    [anon_sym_and_eq] = ACTIONS(6631),
    [anon_sym_or_eq] = ACTIONS(6631),
    [anon_sym_xor_eq] = ACTIONS(6631),
    [anon_sym_LT_EQ_GT] = ACTIONS(6633),
    [anon_sym_or] = ACTIONS(6631),
    [anon_sym_and] = ACTIONS(6631),
    [anon_sym_bitor] = ACTIONS(6631),
    [anon_sym_xor] = ACTIONS(6631),
    [anon_sym_bitand] = ACTIONS(6631),
    [anon_sym_not_eq] = ACTIONS(6631),
    [anon_sym_DASH_DASH] = ACTIONS(6633),
    [anon_sym_PLUS_PLUS] = ACTIONS(6633),
    [anon_sym_DOT] = ACTIONS(6631),
    [anon_sym_DOT_STAR] = ACTIONS(6633),
    [anon_sym_DASH_GT] = ACTIONS(6633),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6631),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6633),
  },
  [STATE(2601)] = {
    [sym_identifier] = ACTIONS(6635),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6637),
    [anon_sym_COMMA] = ACTIONS(6637),
    [anon_sym_RPAREN] = ACTIONS(6637),
    [aux_sym_preproc_if_token2] = ACTIONS(6637),
    [aux_sym_preproc_else_token1] = ACTIONS(6637),
    [aux_sym_preproc_elif_token1] = ACTIONS(6635),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6637),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6637),
    [anon_sym_LPAREN2] = ACTIONS(6637),
    [anon_sym_DASH] = ACTIONS(6635),
    [anon_sym_PLUS] = ACTIONS(6635),
    [anon_sym_STAR] = ACTIONS(6635),
    [anon_sym_SLASH] = ACTIONS(6635),
    [anon_sym_PERCENT] = ACTIONS(6635),
    [anon_sym_PIPE_PIPE] = ACTIONS(6637),
    [anon_sym_AMP_AMP] = ACTIONS(6637),
    [anon_sym_PIPE] = ACTIONS(6635),
    [anon_sym_CARET] = ACTIONS(6635),
    [anon_sym_AMP] = ACTIONS(6635),
    [anon_sym_EQ_EQ] = ACTIONS(6637),
    [anon_sym_BANG_EQ] = ACTIONS(6637),
    [anon_sym_GT] = ACTIONS(6635),
    [anon_sym_GT_EQ] = ACTIONS(6637),
    [anon_sym_LT_EQ] = ACTIONS(6635),
    [anon_sym_LT] = ACTIONS(6635),
    [anon_sym_LT_LT] = ACTIONS(6635),
    [anon_sym_GT_GT] = ACTIONS(6635),
    [anon_sym_SEMI] = ACTIONS(6637),
    [anon_sym___attribute__] = ACTIONS(6635),
    [anon_sym___attribute] = ACTIONS(6635),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6637),
    [anon_sym_LBRACE] = ACTIONS(6637),
    [anon_sym_RBRACE] = ACTIONS(6637),
    [anon_sym_LBRACK] = ACTIONS(6635),
    [anon_sym_RBRACK] = ACTIONS(6637),
    [anon_sym_EQ] = ACTIONS(6635),
    [anon_sym_COLON] = ACTIONS(6637),
    [anon_sym_QMARK] = ACTIONS(6637),
    [anon_sym_STAR_EQ] = ACTIONS(6637),
    [anon_sym_SLASH_EQ] = ACTIONS(6637),
    [anon_sym_PERCENT_EQ] = ACTIONS(6637),
    [anon_sym_PLUS_EQ] = ACTIONS(6637),
    [anon_sym_DASH_EQ] = ACTIONS(6637),
    [anon_sym_LT_LT_EQ] = ACTIONS(6637),
    [anon_sym_GT_GT_EQ] = ACTIONS(6637),
    [anon_sym_AMP_EQ] = ACTIONS(6637),
    [anon_sym_CARET_EQ] = ACTIONS(6637),
    [anon_sym_PIPE_EQ] = ACTIONS(6637),
    [anon_sym_and_eq] = ACTIONS(6635),
    [anon_sym_or_eq] = ACTIONS(6635),
    [anon_sym_xor_eq] = ACTIONS(6635),
    [anon_sym_LT_EQ_GT] = ACTIONS(6637),
    [anon_sym_or] = ACTIONS(6635),
    [anon_sym_and] = ACTIONS(6635),
    [anon_sym_bitor] = ACTIONS(6635),
    [anon_sym_xor] = ACTIONS(6635),
    [anon_sym_bitand] = ACTIONS(6635),
    [anon_sym_not_eq] = ACTIONS(6635),
    [anon_sym_DASH_DASH] = ACTIONS(6637),
    [anon_sym_PLUS_PLUS] = ACTIONS(6637),
    [anon_sym_DOT] = ACTIONS(6635),
    [anon_sym_DOT_STAR] = ACTIONS(6637),
    [anon_sym_DASH_GT] = ACTIONS(6637),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6635),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6637),
  },
  [STATE(2602)] = {
    [sym_identifier] = ACTIONS(6639),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6641),
    [anon_sym_COMMA] = ACTIONS(6641),
    [anon_sym_RPAREN] = ACTIONS(6641),
    [aux_sym_preproc_if_token2] = ACTIONS(6641),
    [aux_sym_preproc_else_token1] = ACTIONS(6641),
    [aux_sym_preproc_elif_token1] = ACTIONS(6639),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6641),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6641),
    [anon_sym_LPAREN2] = ACTIONS(6641),
    [anon_sym_DASH] = ACTIONS(6639),
    [anon_sym_PLUS] = ACTIONS(6639),
    [anon_sym_STAR] = ACTIONS(6639),
    [anon_sym_SLASH] = ACTIONS(6639),
    [anon_sym_PERCENT] = ACTIONS(6639),
    [anon_sym_PIPE_PIPE] = ACTIONS(6641),
    [anon_sym_AMP_AMP] = ACTIONS(6641),
    [anon_sym_PIPE] = ACTIONS(6639),
    [anon_sym_CARET] = ACTIONS(6639),
    [anon_sym_AMP] = ACTIONS(6639),
    [anon_sym_EQ_EQ] = ACTIONS(6641),
    [anon_sym_BANG_EQ] = ACTIONS(6641),
    [anon_sym_GT] = ACTIONS(6639),
    [anon_sym_GT_EQ] = ACTIONS(6641),
    [anon_sym_LT_EQ] = ACTIONS(6639),
    [anon_sym_LT] = ACTIONS(6639),
    [anon_sym_LT_LT] = ACTIONS(6639),
    [anon_sym_GT_GT] = ACTIONS(6639),
    [anon_sym_SEMI] = ACTIONS(6641),
    [anon_sym___attribute__] = ACTIONS(6639),
    [anon_sym___attribute] = ACTIONS(6639),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6641),
    [anon_sym_LBRACE] = ACTIONS(6641),
    [anon_sym_RBRACE] = ACTIONS(6641),
    [anon_sym_LBRACK] = ACTIONS(6639),
    [anon_sym_RBRACK] = ACTIONS(6641),
    [anon_sym_EQ] = ACTIONS(6639),
    [anon_sym_COLON] = ACTIONS(6641),
    [anon_sym_QMARK] = ACTIONS(6641),
    [anon_sym_STAR_EQ] = ACTIONS(6641),
    [anon_sym_SLASH_EQ] = ACTIONS(6641),
    [anon_sym_PERCENT_EQ] = ACTIONS(6641),
    [anon_sym_PLUS_EQ] = ACTIONS(6641),
    [anon_sym_DASH_EQ] = ACTIONS(6641),
    [anon_sym_LT_LT_EQ] = ACTIONS(6641),
    [anon_sym_GT_GT_EQ] = ACTIONS(6641),
    [anon_sym_AMP_EQ] = ACTIONS(6641),
    [anon_sym_CARET_EQ] = ACTIONS(6641),
    [anon_sym_PIPE_EQ] = ACTIONS(6641),
    [anon_sym_and_eq] = ACTIONS(6639),
    [anon_sym_or_eq] = ACTIONS(6639),
    [anon_sym_xor_eq] = ACTIONS(6639),
    [anon_sym_LT_EQ_GT] = ACTIONS(6641),
    [anon_sym_or] = ACTIONS(6639),
    [anon_sym_and] = ACTIONS(6639),
    [anon_sym_bitor] = ACTIONS(6639),
    [anon_sym_xor] = ACTIONS(6639),
    [anon_sym_bitand] = ACTIONS(6639),
    [anon_sym_not_eq] = ACTIONS(6639),
    [anon_sym_DASH_DASH] = ACTIONS(6641),
    [anon_sym_PLUS_PLUS] = ACTIONS(6641),
    [anon_sym_DOT] = ACTIONS(6639),
    [anon_sym_DOT_STAR] = ACTIONS(6641),
    [anon_sym_DASH_GT] = ACTIONS(6641),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6639),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6641),
  },
  [STATE(2603)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5720),
    [anon_sym_COMMA] = ACTIONS(5720),
    [anon_sym_LPAREN2] = ACTIONS(5720),
    [anon_sym_DASH] = ACTIONS(5718),
    [anon_sym_PLUS] = ACTIONS(5718),
    [anon_sym_STAR] = ACTIONS(5720),
    [anon_sym_SLASH] = ACTIONS(5718),
    [anon_sym_PERCENT] = ACTIONS(5720),
    [anon_sym_PIPE_PIPE] = ACTIONS(5720),
    [anon_sym_AMP_AMP] = ACTIONS(5720),
    [anon_sym_PIPE] = ACTIONS(5718),
    [anon_sym_CARET] = ACTIONS(5720),
    [anon_sym_AMP] = ACTIONS(5718),
    [anon_sym_EQ_EQ] = ACTIONS(5720),
    [anon_sym_BANG_EQ] = ACTIONS(5720),
    [anon_sym_GT] = ACTIONS(5718),
    [anon_sym_GT_EQ] = ACTIONS(5718),
    [anon_sym_LT_EQ] = ACTIONS(5718),
    [anon_sym_LT] = ACTIONS(5718),
    [anon_sym_LT_LT] = ACTIONS(5718),
    [anon_sym_GT_GT] = ACTIONS(5718),
    [anon_sym___extension__] = ACTIONS(5720),
    [anon_sym___global__] = ACTIONS(5720),
    [anon_sym___attribute__] = ACTIONS(5720),
    [anon_sym___attribute] = ACTIONS(5718),
    [anon_sym_LBRACE] = ACTIONS(5720),
    [anon_sym_LBRACK] = ACTIONS(5720),
    [anon_sym_const] = ACTIONS(5718),
    [anon_sym_constexpr] = ACTIONS(5720),
    [anon_sym_volatile] = ACTIONS(5720),
    [anon_sym_restrict] = ACTIONS(5720),
    [anon_sym___restrict__] = ACTIONS(5720),
    [anon_sym__Atomic] = ACTIONS(5720),
    [anon_sym__Noreturn] = ACTIONS(5720),
    [anon_sym_noreturn] = ACTIONS(5720),
    [anon_sym__Nonnull] = ACTIONS(5720),
    [anon_sym_mutable] = ACTIONS(5720),
    [anon_sym_constinit] = ACTIONS(5720),
    [anon_sym_consteval] = ACTIONS(5720),
    [anon_sym___shared__] = ACTIONS(5720),
    [anon_sym___local__] = ACTIONS(5720),
    [anon_sym___constant__] = ACTIONS(5720),
    [anon_sym___managed__] = ACTIONS(5720),
    [anon_sym___grid_constant__] = ACTIONS(5720),
    [anon_sym_alignas] = ACTIONS(5720),
    [anon_sym__Alignas] = ACTIONS(5720),
    [anon_sym_QMARK] = ACTIONS(5720),
    [anon_sym_LT_EQ_GT] = ACTIONS(5720),
    [anon_sym_or] = ACTIONS(5720),
    [anon_sym_and] = ACTIONS(5720),
    [anon_sym_bitor] = ACTIONS(5720),
    [anon_sym_xor] = ACTIONS(5720),
    [anon_sym_bitand] = ACTIONS(5720),
    [anon_sym_not_eq] = ACTIONS(5720),
    [anon_sym_DASH_DASH] = ACTIONS(5720),
    [anon_sym_PLUS_PLUS] = ACTIONS(5720),
    [anon_sym_DOT] = ACTIONS(5718),
    [anon_sym_DOT_STAR] = ACTIONS(5720),
    [anon_sym_DASH_GT] = ACTIONS(5720),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5720),
    [anon_sym_decltype] = ACTIONS(5720),
    [anon_sym_final] = ACTIONS(5720),
    [anon_sym_override] = ACTIONS(5720),
    [anon_sym_GT2] = ACTIONS(5720),
    [anon_sym_requires] = ACTIONS(5720),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5720),
  },
  [STATE(2604)] = {
    [sym_attribute_specifier] = STATE(2258),
    [sym_identifier] = ACTIONS(6264),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6262),
    [anon_sym_COMMA] = ACTIONS(6262),
    [anon_sym_RPAREN] = ACTIONS(6262),
    [anon_sym_LPAREN2] = ACTIONS(6262),
    [anon_sym_TILDE] = ACTIONS(6262),
    [anon_sym_STAR] = ACTIONS(6262),
    [anon_sym_AMP_AMP] = ACTIONS(6262),
    [anon_sym_AMP] = ACTIONS(6264),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym___extension__] = ACTIONS(6264),
    [anon_sym___device__] = ACTIONS(6264),
    [anon_sym___host__] = ACTIONS(6264),
    [anon_sym___global__] = ACTIONS(6264),
    [anon_sym___forceinline__] = ACTIONS(6264),
    [anon_sym___noinline__] = ACTIONS(6264),
    [anon_sym_virtual] = ACTIONS(6264),
    [anon_sym_extern] = ACTIONS(6264),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6262),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6262),
    [anon_sym___declspec] = ACTIONS(6264),
    [anon_sym___based] = ACTIONS(6264),
    [anon_sym___cdecl] = ACTIONS(6264),
    [anon_sym___clrcall] = ACTIONS(6264),
    [anon_sym___stdcall] = ACTIONS(6264),
    [anon_sym___fastcall] = ACTIONS(6264),
    [anon_sym___thiscall] = ACTIONS(6264),
    [anon_sym___vectorcall] = ACTIONS(6264),
    [anon_sym_LBRACK] = ACTIONS(6264),
    [anon_sym_static] = ACTIONS(6264),
    [anon_sym_EQ] = ACTIONS(6262),
    [anon_sym_register] = ACTIONS(6264),
    [anon_sym_inline] = ACTIONS(6264),
    [anon_sym___inline] = ACTIONS(6264),
    [anon_sym___inline__] = ACTIONS(6264),
    [anon_sym___forceinline] = ACTIONS(6264),
    [anon_sym_thread_local] = ACTIONS(6264),
    [anon_sym___thread] = ACTIONS(6264),
    [anon_sym_const] = ACTIONS(6264),
    [anon_sym_constexpr] = ACTIONS(6264),
    [anon_sym_volatile] = ACTIONS(6264),
    [anon_sym_restrict] = ACTIONS(6264),
    [anon_sym___restrict__] = ACTIONS(6264),
    [anon_sym__Atomic] = ACTIONS(6264),
    [anon_sym__Noreturn] = ACTIONS(6264),
    [anon_sym_noreturn] = ACTIONS(6264),
    [anon_sym__Nonnull] = ACTIONS(6264),
    [anon_sym_mutable] = ACTIONS(6264),
    [anon_sym_constinit] = ACTIONS(6264),
    [anon_sym_consteval] = ACTIONS(6264),
    [anon_sym___shared__] = ACTIONS(6264),
    [anon_sym___local__] = ACTIONS(6264),
    [anon_sym___constant__] = ACTIONS(6264),
    [anon_sym___managed__] = ACTIONS(6264),
    [anon_sym___grid_constant__] = ACTIONS(6264),
    [anon_sym_alignas] = ACTIONS(6264),
    [anon_sym__Alignas] = ACTIONS(6264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6264),
    [anon_sym_decltype] = ACTIONS(6264),
    [anon_sym_template] = ACTIONS(6264),
    [anon_sym_GT2] = ACTIONS(6262),
    [anon_sym_operator] = ACTIONS(6264),
    [anon_sym___launch_bounds__] = ACTIONS(6264),
  },
  [STATE(2605)] = {
    [sym_string_literal] = STATE(2943),
    [sym_template_argument_list] = STATE(4215),
    [sym_raw_string_literal] = STATE(2943),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4004),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(5140),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_RBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(6491),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(6468),
    [anon_sym_SLASH_EQ] = ACTIONS(6468),
    [anon_sym_PERCENT_EQ] = ACTIONS(6468),
    [anon_sym_PLUS_EQ] = ACTIONS(6468),
    [anon_sym_DASH_EQ] = ACTIONS(6468),
    [anon_sym_LT_LT_EQ] = ACTIONS(6468),
    [anon_sym_GT_GT_EQ] = ACTIONS(6468),
    [anon_sym_AMP_EQ] = ACTIONS(6468),
    [anon_sym_CARET_EQ] = ACTIONS(6468),
    [anon_sym_PIPE_EQ] = ACTIONS(6468),
    [anon_sym_and_eq] = ACTIONS(6468),
    [anon_sym_or_eq] = ACTIONS(6468),
    [anon_sym_xor_eq] = ACTIONS(6468),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(3788),
    [anon_sym_u_DQUOTE] = ACTIONS(3788),
    [anon_sym_U_DQUOTE] = ACTIONS(3788),
    [anon_sym_u8_DQUOTE] = ACTIONS(3788),
    [anon_sym_DQUOTE] = ACTIONS(3788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3792),
    [anon_sym_LR_DQUOTE] = ACTIONS(3792),
    [anon_sym_uR_DQUOTE] = ACTIONS(3792),
    [anon_sym_UR_DQUOTE] = ACTIONS(3792),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3792),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2606)] = {
    [sym_string_literal] = STATE(2372),
    [sym_raw_string_literal] = STATE(2372),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6354),
    [anon_sym_COMMA] = ACTIONS(6354),
    [anon_sym_LPAREN2] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6352),
    [anon_sym_STAR] = ACTIONS(6352),
    [anon_sym_SLASH] = ACTIONS(6352),
    [anon_sym_PERCENT] = ACTIONS(6352),
    [anon_sym_PIPE_PIPE] = ACTIONS(6354),
    [anon_sym_AMP_AMP] = ACTIONS(6354),
    [anon_sym_PIPE] = ACTIONS(6352),
    [anon_sym_CARET] = ACTIONS(6352),
    [anon_sym_AMP] = ACTIONS(6352),
    [anon_sym_EQ_EQ] = ACTIONS(6354),
    [anon_sym_BANG_EQ] = ACTIONS(6354),
    [anon_sym_GT] = ACTIONS(6352),
    [anon_sym_GT_EQ] = ACTIONS(6354),
    [anon_sym_LT_EQ] = ACTIONS(6352),
    [anon_sym_LT] = ACTIONS(6352),
    [anon_sym_LT_LT] = ACTIONS(6352),
    [anon_sym_GT_GT] = ACTIONS(6352),
    [anon_sym_SEMI] = ACTIONS(6354),
    [anon_sym___attribute__] = ACTIONS(6352),
    [anon_sym___attribute] = ACTIONS(6352),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [anon_sym_EQ] = ACTIONS(6352),
    [anon_sym_QMARK] = ACTIONS(6354),
    [anon_sym_STAR_EQ] = ACTIONS(6354),
    [anon_sym_SLASH_EQ] = ACTIONS(6354),
    [anon_sym_PERCENT_EQ] = ACTIONS(6354),
    [anon_sym_PLUS_EQ] = ACTIONS(6354),
    [anon_sym_DASH_EQ] = ACTIONS(6354),
    [anon_sym_LT_LT_EQ] = ACTIONS(6354),
    [anon_sym_GT_GT_EQ] = ACTIONS(6354),
    [anon_sym_AMP_EQ] = ACTIONS(6354),
    [anon_sym_CARET_EQ] = ACTIONS(6354),
    [anon_sym_PIPE_EQ] = ACTIONS(6354),
    [anon_sym_and_eq] = ACTIONS(6352),
    [anon_sym_or_eq] = ACTIONS(6352),
    [anon_sym_xor_eq] = ACTIONS(6352),
    [anon_sym_LT_EQ_GT] = ACTIONS(6354),
    [anon_sym_or] = ACTIONS(6352),
    [anon_sym_and] = ACTIONS(6352),
    [anon_sym_bitor] = ACTIONS(6352),
    [anon_sym_xor] = ACTIONS(6352),
    [anon_sym_bitand] = ACTIONS(6352),
    [anon_sym_not_eq] = ACTIONS(6352),
    [anon_sym_DASH_DASH] = ACTIONS(6354),
    [anon_sym_PLUS_PLUS] = ACTIONS(6354),
    [anon_sym_DOT] = ACTIONS(6352),
    [anon_sym_DOT_STAR] = ACTIONS(6354),
    [anon_sym_DASH_GT] = ACTIONS(6354),
    [anon_sym_L_DQUOTE] = ACTIONS(6372),
    [anon_sym_u_DQUOTE] = ACTIONS(6372),
    [anon_sym_U_DQUOTE] = ACTIONS(6372),
    [anon_sym_u8_DQUOTE] = ACTIONS(6372),
    [anon_sym_DQUOTE] = ACTIONS(6372),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6374),
    [anon_sym_LR_DQUOTE] = ACTIONS(6374),
    [anon_sym_uR_DQUOTE] = ACTIONS(6374),
    [anon_sym_UR_DQUOTE] = ACTIONS(6374),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6374),
    [sym_literal_suffix] = ACTIONS(6352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6354),
  },
  [STATE(2607)] = {
    [sym_string_literal] = STATE(2582),
    [sym_template_argument_list] = STATE(3759),
    [sym_raw_string_literal] = STATE(2582),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(4004),
    [anon_sym_LPAREN2] = ACTIONS(4004),
    [anon_sym_DASH] = ACTIONS(4012),
    [anon_sym_PLUS] = ACTIONS(4012),
    [anon_sym_STAR] = ACTIONS(4012),
    [anon_sym_SLASH] = ACTIONS(4012),
    [anon_sym_PERCENT] = ACTIONS(4012),
    [anon_sym_PIPE_PIPE] = ACTIONS(4004),
    [anon_sym_AMP_AMP] = ACTIONS(4004),
    [anon_sym_PIPE] = ACTIONS(4012),
    [anon_sym_CARET] = ACTIONS(4012),
    [anon_sym_AMP] = ACTIONS(4012),
    [anon_sym_EQ_EQ] = ACTIONS(4004),
    [anon_sym_BANG_EQ] = ACTIONS(4004),
    [anon_sym_GT] = ACTIONS(4012),
    [anon_sym_GT_EQ] = ACTIONS(4012),
    [anon_sym_LT_EQ] = ACTIONS(4012),
    [anon_sym_LT] = ACTIONS(6643),
    [anon_sym_LT_LT] = ACTIONS(4012),
    [anon_sym_GT_GT] = ACTIONS(4012),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(4004),
    [anon_sym_EQ] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_STAR_EQ] = ACTIONS(4004),
    [anon_sym_SLASH_EQ] = ACTIONS(4004),
    [anon_sym_PERCENT_EQ] = ACTIONS(4004),
    [anon_sym_PLUS_EQ] = ACTIONS(4004),
    [anon_sym_DASH_EQ] = ACTIONS(4004),
    [anon_sym_LT_LT_EQ] = ACTIONS(4004),
    [anon_sym_GT_GT_EQ] = ACTIONS(4012),
    [anon_sym_AMP_EQ] = ACTIONS(4004),
    [anon_sym_CARET_EQ] = ACTIONS(4004),
    [anon_sym_PIPE_EQ] = ACTIONS(4004),
    [anon_sym_and_eq] = ACTIONS(4004),
    [anon_sym_or_eq] = ACTIONS(4004),
    [anon_sym_xor_eq] = ACTIONS(4004),
    [anon_sym_LT_EQ_GT] = ACTIONS(4004),
    [anon_sym_or] = ACTIONS(4012),
    [anon_sym_and] = ACTIONS(4012),
    [anon_sym_bitor] = ACTIONS(4004),
    [anon_sym_xor] = ACTIONS(4012),
    [anon_sym_bitand] = ACTIONS(4004),
    [anon_sym_not_eq] = ACTIONS(4004),
    [anon_sym_DASH_DASH] = ACTIONS(4004),
    [anon_sym_PLUS_PLUS] = ACTIONS(4004),
    [anon_sym_DOT] = ACTIONS(4012),
    [anon_sym_DOT_STAR] = ACTIONS(4004),
    [anon_sym_DASH_GT] = ACTIONS(4004),
    [anon_sym_L_DQUOTE] = ACTIONS(6581),
    [anon_sym_u_DQUOTE] = ACTIONS(6581),
    [anon_sym_U_DQUOTE] = ACTIONS(6581),
    [anon_sym_u8_DQUOTE] = ACTIONS(6581),
    [anon_sym_DQUOTE] = ACTIONS(6581),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(4004),
    [anon_sym_R_DQUOTE] = ACTIONS(6583),
    [anon_sym_LR_DQUOTE] = ACTIONS(6583),
    [anon_sym_uR_DQUOTE] = ACTIONS(6583),
    [anon_sym_UR_DQUOTE] = ACTIONS(6583),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6583),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4004),
  },
  [STATE(2608)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2537),
    [sym_identifier] = ACTIONS(5982),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5980),
    [anon_sym_COMMA] = ACTIONS(5980),
    [aux_sym_preproc_if_token2] = ACTIONS(5980),
    [aux_sym_preproc_else_token1] = ACTIONS(5980),
    [aux_sym_preproc_elif_token1] = ACTIONS(5982),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5980),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5980),
    [anon_sym_LPAREN2] = ACTIONS(5980),
    [anon_sym_DASH] = ACTIONS(5982),
    [anon_sym_PLUS] = ACTIONS(5982),
    [anon_sym_STAR] = ACTIONS(5982),
    [anon_sym_SLASH] = ACTIONS(5982),
    [anon_sym_PERCENT] = ACTIONS(5982),
    [anon_sym_PIPE_PIPE] = ACTIONS(5980),
    [anon_sym_AMP_AMP] = ACTIONS(5980),
    [anon_sym_PIPE] = ACTIONS(5982),
    [anon_sym_CARET] = ACTIONS(5982),
    [anon_sym_AMP] = ACTIONS(5982),
    [anon_sym_EQ_EQ] = ACTIONS(5980),
    [anon_sym_BANG_EQ] = ACTIONS(5980),
    [anon_sym_GT] = ACTIONS(5982),
    [anon_sym_GT_EQ] = ACTIONS(5980),
    [anon_sym_LT_EQ] = ACTIONS(5982),
    [anon_sym_LT] = ACTIONS(5982),
    [anon_sym_LT_LT] = ACTIONS(5982),
    [anon_sym_GT_GT] = ACTIONS(5982),
    [anon_sym___attribute__] = ACTIONS(5982),
    [anon_sym___attribute] = ACTIONS(5982),
    [anon_sym_LBRACE] = ACTIONS(5980),
    [anon_sym_signed] = ACTIONS(6516),
    [anon_sym_unsigned] = ACTIONS(6516),
    [anon_sym_long] = ACTIONS(6516),
    [anon_sym_short] = ACTIONS(6516),
    [anon_sym_LBRACK] = ACTIONS(5980),
    [anon_sym_EQ] = ACTIONS(5982),
    [anon_sym_QMARK] = ACTIONS(5980),
    [anon_sym_STAR_EQ] = ACTIONS(5980),
    [anon_sym_SLASH_EQ] = ACTIONS(5980),
    [anon_sym_PERCENT_EQ] = ACTIONS(5980),
    [anon_sym_PLUS_EQ] = ACTIONS(5980),
    [anon_sym_DASH_EQ] = ACTIONS(5980),
    [anon_sym_LT_LT_EQ] = ACTIONS(5980),
    [anon_sym_GT_GT_EQ] = ACTIONS(5980),
    [anon_sym_AMP_EQ] = ACTIONS(5980),
    [anon_sym_CARET_EQ] = ACTIONS(5980),
    [anon_sym_PIPE_EQ] = ACTIONS(5980),
    [anon_sym_and_eq] = ACTIONS(5982),
    [anon_sym_or_eq] = ACTIONS(5982),
    [anon_sym_xor_eq] = ACTIONS(5982),
    [anon_sym_LT_EQ_GT] = ACTIONS(5980),
    [anon_sym_or] = ACTIONS(5982),
    [anon_sym_and] = ACTIONS(5982),
    [anon_sym_bitor] = ACTIONS(5982),
    [anon_sym_xor] = ACTIONS(5982),
    [anon_sym_bitand] = ACTIONS(5982),
    [anon_sym_not_eq] = ACTIONS(5982),
    [anon_sym_DASH_DASH] = ACTIONS(5980),
    [anon_sym_PLUS_PLUS] = ACTIONS(5980),
    [anon_sym_DOT] = ACTIONS(5982),
    [anon_sym_DOT_STAR] = ACTIONS(5980),
    [anon_sym_DASH_GT] = ACTIONS(5980),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5982),
    [anon_sym_decltype] = ACTIONS(5982),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5980),
  },
  [STATE(2609)] = {
    [sym_string_literal] = STATE(2609),
    [sym_raw_string_literal] = STATE(2609),
    [aux_sym_concatenated_string_repeat1] = STATE(2609),
    [sym_identifier] = ACTIONS(6646),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5882),
    [anon_sym_COMMA] = ACTIONS(5882),
    [anon_sym_LPAREN2] = ACTIONS(5882),
    [anon_sym_DASH] = ACTIONS(5884),
    [anon_sym_PLUS] = ACTIONS(5884),
    [anon_sym_STAR] = ACTIONS(5884),
    [anon_sym_SLASH] = ACTIONS(5884),
    [anon_sym_PERCENT] = ACTIONS(5884),
    [anon_sym_PIPE_PIPE] = ACTIONS(5882),
    [anon_sym_AMP_AMP] = ACTIONS(5882),
    [anon_sym_PIPE] = ACTIONS(5884),
    [anon_sym_CARET] = ACTIONS(5884),
    [anon_sym_AMP] = ACTIONS(5884),
    [anon_sym_EQ_EQ] = ACTIONS(5882),
    [anon_sym_BANG_EQ] = ACTIONS(5882),
    [anon_sym_GT] = ACTIONS(5884),
    [anon_sym_GT_EQ] = ACTIONS(5884),
    [anon_sym_LT_EQ] = ACTIONS(5884),
    [anon_sym_LT] = ACTIONS(5884),
    [anon_sym_LT_LT] = ACTIONS(5884),
    [anon_sym_GT_GT] = ACTIONS(5884),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_EQ] = ACTIONS(5884),
    [anon_sym_QMARK] = ACTIONS(5882),
    [anon_sym_STAR_EQ] = ACTIONS(5882),
    [anon_sym_SLASH_EQ] = ACTIONS(5882),
    [anon_sym_PERCENT_EQ] = ACTIONS(5882),
    [anon_sym_PLUS_EQ] = ACTIONS(5882),
    [anon_sym_DASH_EQ] = ACTIONS(5882),
    [anon_sym_LT_LT_EQ] = ACTIONS(5882),
    [anon_sym_GT_GT_EQ] = ACTIONS(5884),
    [anon_sym_AMP_EQ] = ACTIONS(5882),
    [anon_sym_CARET_EQ] = ACTIONS(5882),
    [anon_sym_PIPE_EQ] = ACTIONS(5882),
    [anon_sym_and_eq] = ACTIONS(5884),
    [anon_sym_or_eq] = ACTIONS(5884),
    [anon_sym_xor_eq] = ACTIONS(5884),
    [anon_sym_LT_EQ_GT] = ACTIONS(5882),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_bitor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_bitand] = ACTIONS(5884),
    [anon_sym_not_eq] = ACTIONS(5884),
    [anon_sym_DASH_DASH] = ACTIONS(5882),
    [anon_sym_PLUS_PLUS] = ACTIONS(5882),
    [anon_sym_DOT] = ACTIONS(5884),
    [anon_sym_DOT_STAR] = ACTIONS(5882),
    [anon_sym_DASH_GT] = ACTIONS(5882),
    [anon_sym_L_DQUOTE] = ACTIONS(6649),
    [anon_sym_u_DQUOTE] = ACTIONS(6649),
    [anon_sym_U_DQUOTE] = ACTIONS(6649),
    [anon_sym_u8_DQUOTE] = ACTIONS(6649),
    [anon_sym_DQUOTE] = ACTIONS(6649),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(5882),
    [anon_sym_R_DQUOTE] = ACTIONS(6652),
    [anon_sym_LR_DQUOTE] = ACTIONS(6652),
    [anon_sym_uR_DQUOTE] = ACTIONS(6652),
    [anon_sym_UR_DQUOTE] = ACTIONS(6652),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6652),
    [sym_literal_suffix] = ACTIONS(5884),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5882),
  },
  [STATE(2610)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5732),
    [anon_sym_COMMA] = ACTIONS(5732),
    [anon_sym_LPAREN2] = ACTIONS(5732),
    [anon_sym_DASH] = ACTIONS(5730),
    [anon_sym_PLUS] = ACTIONS(5730),
    [anon_sym_STAR] = ACTIONS(5732),
    [anon_sym_SLASH] = ACTIONS(5730),
    [anon_sym_PERCENT] = ACTIONS(5732),
    [anon_sym_PIPE_PIPE] = ACTIONS(5732),
    [anon_sym_AMP_AMP] = ACTIONS(5732),
    [anon_sym_PIPE] = ACTIONS(5730),
    [anon_sym_CARET] = ACTIONS(5732),
    [anon_sym_AMP] = ACTIONS(5730),
    [anon_sym_EQ_EQ] = ACTIONS(5732),
    [anon_sym_BANG_EQ] = ACTIONS(5732),
    [anon_sym_GT] = ACTIONS(5730),
    [anon_sym_GT_EQ] = ACTIONS(5730),
    [anon_sym_LT_EQ] = ACTIONS(5730),
    [anon_sym_LT] = ACTIONS(5730),
    [anon_sym_LT_LT] = ACTIONS(5730),
    [anon_sym_GT_GT] = ACTIONS(5730),
    [anon_sym___extension__] = ACTIONS(5732),
    [anon_sym___global__] = ACTIONS(5732),
    [anon_sym___attribute__] = ACTIONS(5732),
    [anon_sym___attribute] = ACTIONS(5730),
    [anon_sym_LBRACE] = ACTIONS(5732),
    [anon_sym_LBRACK] = ACTIONS(5732),
    [anon_sym_const] = ACTIONS(5730),
    [anon_sym_constexpr] = ACTIONS(5732),
    [anon_sym_volatile] = ACTIONS(5732),
    [anon_sym_restrict] = ACTIONS(5732),
    [anon_sym___restrict__] = ACTIONS(5732),
    [anon_sym__Atomic] = ACTIONS(5732),
    [anon_sym__Noreturn] = ACTIONS(5732),
    [anon_sym_noreturn] = ACTIONS(5732),
    [anon_sym__Nonnull] = ACTIONS(5732),
    [anon_sym_mutable] = ACTIONS(5732),
    [anon_sym_constinit] = ACTIONS(5732),
    [anon_sym_consteval] = ACTIONS(5732),
    [anon_sym___shared__] = ACTIONS(5732),
    [anon_sym___local__] = ACTIONS(5732),
    [anon_sym___constant__] = ACTIONS(5732),
    [anon_sym___managed__] = ACTIONS(5732),
    [anon_sym___grid_constant__] = ACTIONS(5732),
    [anon_sym_alignas] = ACTIONS(5732),
    [anon_sym__Alignas] = ACTIONS(5732),
    [anon_sym_QMARK] = ACTIONS(5732),
    [anon_sym_LT_EQ_GT] = ACTIONS(5732),
    [anon_sym_or] = ACTIONS(5732),
    [anon_sym_and] = ACTIONS(5732),
    [anon_sym_bitor] = ACTIONS(5732),
    [anon_sym_xor] = ACTIONS(5732),
    [anon_sym_bitand] = ACTIONS(5732),
    [anon_sym_not_eq] = ACTIONS(5732),
    [anon_sym_DASH_DASH] = ACTIONS(5732),
    [anon_sym_PLUS_PLUS] = ACTIONS(5732),
    [anon_sym_DOT] = ACTIONS(5730),
    [anon_sym_DOT_STAR] = ACTIONS(5732),
    [anon_sym_DASH_GT] = ACTIONS(5732),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5732),
    [anon_sym_decltype] = ACTIONS(5732),
    [anon_sym_final] = ACTIONS(5732),
    [anon_sym_override] = ACTIONS(5732),
    [anon_sym_GT2] = ACTIONS(5732),
    [anon_sym_requires] = ACTIONS(5732),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5732),
  },
  [STATE(2611)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5684),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym___extension__] = ACTIONS(5686),
    [anon_sym___global__] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5686),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5686),
    [anon_sym_volatile] = ACTIONS(5686),
    [anon_sym_restrict] = ACTIONS(5686),
    [anon_sym___restrict__] = ACTIONS(5686),
    [anon_sym__Atomic] = ACTIONS(5686),
    [anon_sym__Noreturn] = ACTIONS(5686),
    [anon_sym_noreturn] = ACTIONS(5686),
    [anon_sym__Nonnull] = ACTIONS(5686),
    [anon_sym_mutable] = ACTIONS(5686),
    [anon_sym_constinit] = ACTIONS(5686),
    [anon_sym_consteval] = ACTIONS(5686),
    [anon_sym___shared__] = ACTIONS(5686),
    [anon_sym___local__] = ACTIONS(5686),
    [anon_sym___constant__] = ACTIONS(5686),
    [anon_sym___managed__] = ACTIONS(5686),
    [anon_sym___grid_constant__] = ACTIONS(5686),
    [anon_sym_alignas] = ACTIONS(5686),
    [anon_sym__Alignas] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_bitor] = ACTIONS(5686),
    [anon_sym_xor] = ACTIONS(5686),
    [anon_sym_bitand] = ACTIONS(5686),
    [anon_sym_not_eq] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5686),
    [anon_sym_decltype] = ACTIONS(5686),
    [anon_sym_final] = ACTIONS(5686),
    [anon_sym_override] = ACTIONS(5686),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_requires] = ACTIONS(5686),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2612)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2537),
    [sym_identifier] = ACTIONS(6012),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6010),
    [anon_sym_COMMA] = ACTIONS(6010),
    [aux_sym_preproc_if_token2] = ACTIONS(6010),
    [aux_sym_preproc_else_token1] = ACTIONS(6010),
    [aux_sym_preproc_elif_token1] = ACTIONS(6012),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6010),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6010),
    [anon_sym_LPAREN2] = ACTIONS(6010),
    [anon_sym_DASH] = ACTIONS(6012),
    [anon_sym_PLUS] = ACTIONS(6012),
    [anon_sym_STAR] = ACTIONS(6012),
    [anon_sym_SLASH] = ACTIONS(6012),
    [anon_sym_PERCENT] = ACTIONS(6012),
    [anon_sym_PIPE_PIPE] = ACTIONS(6010),
    [anon_sym_AMP_AMP] = ACTIONS(6010),
    [anon_sym_PIPE] = ACTIONS(6012),
    [anon_sym_CARET] = ACTIONS(6012),
    [anon_sym_AMP] = ACTIONS(6012),
    [anon_sym_EQ_EQ] = ACTIONS(6010),
    [anon_sym_BANG_EQ] = ACTIONS(6010),
    [anon_sym_GT] = ACTIONS(6012),
    [anon_sym_GT_EQ] = ACTIONS(6010),
    [anon_sym_LT_EQ] = ACTIONS(6012),
    [anon_sym_LT] = ACTIONS(6012),
    [anon_sym_LT_LT] = ACTIONS(6012),
    [anon_sym_GT_GT] = ACTIONS(6012),
    [anon_sym___attribute__] = ACTIONS(6012),
    [anon_sym___attribute] = ACTIONS(6012),
    [anon_sym_LBRACE] = ACTIONS(6010),
    [anon_sym_signed] = ACTIONS(6516),
    [anon_sym_unsigned] = ACTIONS(6516),
    [anon_sym_long] = ACTIONS(6516),
    [anon_sym_short] = ACTIONS(6516),
    [anon_sym_LBRACK] = ACTIONS(6010),
    [anon_sym_EQ] = ACTIONS(6012),
    [anon_sym_QMARK] = ACTIONS(6010),
    [anon_sym_STAR_EQ] = ACTIONS(6010),
    [anon_sym_SLASH_EQ] = ACTIONS(6010),
    [anon_sym_PERCENT_EQ] = ACTIONS(6010),
    [anon_sym_PLUS_EQ] = ACTIONS(6010),
    [anon_sym_DASH_EQ] = ACTIONS(6010),
    [anon_sym_LT_LT_EQ] = ACTIONS(6010),
    [anon_sym_GT_GT_EQ] = ACTIONS(6010),
    [anon_sym_AMP_EQ] = ACTIONS(6010),
    [anon_sym_CARET_EQ] = ACTIONS(6010),
    [anon_sym_PIPE_EQ] = ACTIONS(6010),
    [anon_sym_and_eq] = ACTIONS(6012),
    [anon_sym_or_eq] = ACTIONS(6012),
    [anon_sym_xor_eq] = ACTIONS(6012),
    [anon_sym_LT_EQ_GT] = ACTIONS(6010),
    [anon_sym_or] = ACTIONS(6012),
    [anon_sym_and] = ACTIONS(6012),
    [anon_sym_bitor] = ACTIONS(6012),
    [anon_sym_xor] = ACTIONS(6012),
    [anon_sym_bitand] = ACTIONS(6012),
    [anon_sym_not_eq] = ACTIONS(6012),
    [anon_sym_DASH_DASH] = ACTIONS(6010),
    [anon_sym_PLUS_PLUS] = ACTIONS(6010),
    [anon_sym_DOT] = ACTIONS(6012),
    [anon_sym_DOT_STAR] = ACTIONS(6010),
    [anon_sym_DASH_GT] = ACTIONS(6010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6012),
    [anon_sym_decltype] = ACTIONS(6012),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6010),
  },
  [STATE(2613)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5827),
    [anon_sym_COMMA] = ACTIONS(5827),
    [anon_sym_LPAREN2] = ACTIONS(5827),
    [anon_sym_DASH] = ACTIONS(5825),
    [anon_sym_PLUS] = ACTIONS(5825),
    [anon_sym_STAR] = ACTIONS(5827),
    [anon_sym_SLASH] = ACTIONS(5825),
    [anon_sym_PERCENT] = ACTIONS(5827),
    [anon_sym_PIPE_PIPE] = ACTIONS(5827),
    [anon_sym_AMP_AMP] = ACTIONS(5827),
    [anon_sym_PIPE] = ACTIONS(5825),
    [anon_sym_CARET] = ACTIONS(5827),
    [anon_sym_AMP] = ACTIONS(5825),
    [anon_sym_EQ_EQ] = ACTIONS(5827),
    [anon_sym_BANG_EQ] = ACTIONS(5827),
    [anon_sym_GT] = ACTIONS(5825),
    [anon_sym_GT_EQ] = ACTIONS(5825),
    [anon_sym_LT_EQ] = ACTIONS(5825),
    [anon_sym_LT] = ACTIONS(5825),
    [anon_sym_LT_LT] = ACTIONS(5825),
    [anon_sym_GT_GT] = ACTIONS(5825),
    [anon_sym___extension__] = ACTIONS(5827),
    [anon_sym___global__] = ACTIONS(5827),
    [anon_sym___attribute__] = ACTIONS(5827),
    [anon_sym___attribute] = ACTIONS(5825),
    [anon_sym_LBRACE] = ACTIONS(5827),
    [anon_sym_LBRACK] = ACTIONS(5827),
    [anon_sym_const] = ACTIONS(5825),
    [anon_sym_constexpr] = ACTIONS(5827),
    [anon_sym_volatile] = ACTIONS(5827),
    [anon_sym_restrict] = ACTIONS(5827),
    [anon_sym___restrict__] = ACTIONS(5827),
    [anon_sym__Atomic] = ACTIONS(5827),
    [anon_sym__Noreturn] = ACTIONS(5827),
    [anon_sym_noreturn] = ACTIONS(5827),
    [anon_sym__Nonnull] = ACTIONS(5827),
    [anon_sym_mutable] = ACTIONS(5827),
    [anon_sym_constinit] = ACTIONS(5827),
    [anon_sym_consteval] = ACTIONS(5827),
    [anon_sym___shared__] = ACTIONS(5827),
    [anon_sym___local__] = ACTIONS(5827),
    [anon_sym___constant__] = ACTIONS(5827),
    [anon_sym___managed__] = ACTIONS(5827),
    [anon_sym___grid_constant__] = ACTIONS(5827),
    [anon_sym_alignas] = ACTIONS(5827),
    [anon_sym__Alignas] = ACTIONS(5827),
    [anon_sym_QMARK] = ACTIONS(5827),
    [anon_sym_LT_EQ_GT] = ACTIONS(5827),
    [anon_sym_or] = ACTIONS(5827),
    [anon_sym_and] = ACTIONS(5827),
    [anon_sym_bitor] = ACTIONS(5827),
    [anon_sym_xor] = ACTIONS(5827),
    [anon_sym_bitand] = ACTIONS(5827),
    [anon_sym_not_eq] = ACTIONS(5827),
    [anon_sym_DASH_DASH] = ACTIONS(5827),
    [anon_sym_PLUS_PLUS] = ACTIONS(5827),
    [anon_sym_DOT] = ACTIONS(5825),
    [anon_sym_DOT_STAR] = ACTIONS(5827),
    [anon_sym_DASH_GT] = ACTIONS(5827),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5827),
    [anon_sym_decltype] = ACTIONS(5827),
    [anon_sym_final] = ACTIONS(5827),
    [anon_sym_override] = ACTIONS(5827),
    [anon_sym_GT2] = ACTIONS(5827),
    [anon_sym_requires] = ACTIONS(5827),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5827),
  },
  [STATE(2614)] = {
    [sym_identifier] = ACTIONS(6655),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6657),
    [anon_sym_COMMA] = ACTIONS(6657),
    [anon_sym_RPAREN] = ACTIONS(6657),
    [aux_sym_preproc_if_token2] = ACTIONS(6657),
    [aux_sym_preproc_else_token1] = ACTIONS(6657),
    [aux_sym_preproc_elif_token1] = ACTIONS(6655),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6657),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6657),
    [anon_sym_LPAREN2] = ACTIONS(6657),
    [anon_sym_DASH] = ACTIONS(6655),
    [anon_sym_PLUS] = ACTIONS(6655),
    [anon_sym_STAR] = ACTIONS(6655),
    [anon_sym_SLASH] = ACTIONS(6655),
    [anon_sym_PERCENT] = ACTIONS(6655),
    [anon_sym_PIPE_PIPE] = ACTIONS(6657),
    [anon_sym_AMP_AMP] = ACTIONS(6657),
    [anon_sym_PIPE] = ACTIONS(6655),
    [anon_sym_CARET] = ACTIONS(6655),
    [anon_sym_AMP] = ACTIONS(6655),
    [anon_sym_EQ_EQ] = ACTIONS(6657),
    [anon_sym_BANG_EQ] = ACTIONS(6657),
    [anon_sym_GT] = ACTIONS(6655),
    [anon_sym_GT_EQ] = ACTIONS(6657),
    [anon_sym_LT_EQ] = ACTIONS(6655),
    [anon_sym_LT] = ACTIONS(6655),
    [anon_sym_LT_LT] = ACTIONS(6655),
    [anon_sym_GT_GT] = ACTIONS(6655),
    [anon_sym_SEMI] = ACTIONS(6657),
    [anon_sym___attribute__] = ACTIONS(6655),
    [anon_sym___attribute] = ACTIONS(6655),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6657),
    [anon_sym_LBRACE] = ACTIONS(6657),
    [anon_sym_RBRACE] = ACTIONS(6657),
    [anon_sym_LBRACK] = ACTIONS(6655),
    [anon_sym_RBRACK] = ACTIONS(6657),
    [anon_sym_EQ] = ACTIONS(6655),
    [anon_sym_COLON] = ACTIONS(6657),
    [anon_sym_QMARK] = ACTIONS(6657),
    [anon_sym_STAR_EQ] = ACTIONS(6657),
    [anon_sym_SLASH_EQ] = ACTIONS(6657),
    [anon_sym_PERCENT_EQ] = ACTIONS(6657),
    [anon_sym_PLUS_EQ] = ACTIONS(6657),
    [anon_sym_DASH_EQ] = ACTIONS(6657),
    [anon_sym_LT_LT_EQ] = ACTIONS(6657),
    [anon_sym_GT_GT_EQ] = ACTIONS(6657),
    [anon_sym_AMP_EQ] = ACTIONS(6657),
    [anon_sym_CARET_EQ] = ACTIONS(6657),
    [anon_sym_PIPE_EQ] = ACTIONS(6657),
    [anon_sym_and_eq] = ACTIONS(6655),
    [anon_sym_or_eq] = ACTIONS(6655),
    [anon_sym_xor_eq] = ACTIONS(6655),
    [anon_sym_LT_EQ_GT] = ACTIONS(6657),
    [anon_sym_or] = ACTIONS(6655),
    [anon_sym_and] = ACTIONS(6655),
    [anon_sym_bitor] = ACTIONS(6655),
    [anon_sym_xor] = ACTIONS(6655),
    [anon_sym_bitand] = ACTIONS(6655),
    [anon_sym_not_eq] = ACTIONS(6655),
    [anon_sym_DASH_DASH] = ACTIONS(6657),
    [anon_sym_PLUS_PLUS] = ACTIONS(6657),
    [anon_sym_DOT] = ACTIONS(6655),
    [anon_sym_DOT_STAR] = ACTIONS(6657),
    [anon_sym_DASH_GT] = ACTIONS(6657),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6655),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6657),
  },
  [STATE(2615)] = {
    [sym_argument_list] = STATE(2805),
    [sym_initializer_list] = STATE(2805),
    [sym_identifier] = ACTIONS(6659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6661),
    [anon_sym_COMMA] = ACTIONS(6661),
    [anon_sym_RPAREN] = ACTIONS(6661),
    [aux_sym_preproc_if_token2] = ACTIONS(6661),
    [aux_sym_preproc_else_token1] = ACTIONS(6661),
    [aux_sym_preproc_elif_token1] = ACTIONS(6659),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6661),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6661),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6659),
    [anon_sym_PLUS] = ACTIONS(6659),
    [anon_sym_STAR] = ACTIONS(6659),
    [anon_sym_SLASH] = ACTIONS(6659),
    [anon_sym_PERCENT] = ACTIONS(6659),
    [anon_sym_PIPE_PIPE] = ACTIONS(6661),
    [anon_sym_AMP_AMP] = ACTIONS(6661),
    [anon_sym_PIPE] = ACTIONS(6659),
    [anon_sym_CARET] = ACTIONS(6659),
    [anon_sym_AMP] = ACTIONS(6659),
    [anon_sym_EQ_EQ] = ACTIONS(6661),
    [anon_sym_BANG_EQ] = ACTIONS(6661),
    [anon_sym_GT] = ACTIONS(6659),
    [anon_sym_GT_EQ] = ACTIONS(6661),
    [anon_sym_LT_EQ] = ACTIONS(6659),
    [anon_sym_LT] = ACTIONS(6659),
    [anon_sym_LT_LT] = ACTIONS(6659),
    [anon_sym_GT_GT] = ACTIONS(6659),
    [anon_sym_SEMI] = ACTIONS(6661),
    [anon_sym___attribute__] = ACTIONS(6659),
    [anon_sym___attribute] = ACTIONS(6659),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(6661),
    [anon_sym_LBRACK] = ACTIONS(6661),
    [anon_sym_RBRACK] = ACTIONS(6661),
    [anon_sym_EQ] = ACTIONS(6659),
    [anon_sym_COLON] = ACTIONS(6661),
    [anon_sym_QMARK] = ACTIONS(6661),
    [anon_sym_STAR_EQ] = ACTIONS(6661),
    [anon_sym_SLASH_EQ] = ACTIONS(6661),
    [anon_sym_PERCENT_EQ] = ACTIONS(6661),
    [anon_sym_PLUS_EQ] = ACTIONS(6661),
    [anon_sym_DASH_EQ] = ACTIONS(6661),
    [anon_sym_LT_LT_EQ] = ACTIONS(6661),
    [anon_sym_GT_GT_EQ] = ACTIONS(6661),
    [anon_sym_AMP_EQ] = ACTIONS(6661),
    [anon_sym_CARET_EQ] = ACTIONS(6661),
    [anon_sym_PIPE_EQ] = ACTIONS(6661),
    [anon_sym_and_eq] = ACTIONS(6659),
    [anon_sym_or_eq] = ACTIONS(6659),
    [anon_sym_xor_eq] = ACTIONS(6659),
    [anon_sym_LT_EQ_GT] = ACTIONS(6661),
    [anon_sym_or] = ACTIONS(6659),
    [anon_sym_and] = ACTIONS(6659),
    [anon_sym_bitor] = ACTIONS(6659),
    [anon_sym_xor] = ACTIONS(6659),
    [anon_sym_bitand] = ACTIONS(6659),
    [anon_sym_not_eq] = ACTIONS(6659),
    [anon_sym_DASH_DASH] = ACTIONS(6661),
    [anon_sym_PLUS_PLUS] = ACTIONS(6661),
    [anon_sym_DOT] = ACTIONS(6659),
    [anon_sym_DOT_STAR] = ACTIONS(6661),
    [anon_sym_DASH_GT] = ACTIONS(6661),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6661),
  },
  [STATE(2616)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2485),
    [sym_identifier] = ACTIONS(5968),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5966),
    [anon_sym_COMMA] = ACTIONS(5966),
    [aux_sym_preproc_if_token2] = ACTIONS(5966),
    [aux_sym_preproc_else_token1] = ACTIONS(5966),
    [aux_sym_preproc_elif_token1] = ACTIONS(5968),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5966),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5966),
    [anon_sym_LPAREN2] = ACTIONS(5966),
    [anon_sym_DASH] = ACTIONS(5968),
    [anon_sym_PLUS] = ACTIONS(5968),
    [anon_sym_STAR] = ACTIONS(5968),
    [anon_sym_SLASH] = ACTIONS(5968),
    [anon_sym_PERCENT] = ACTIONS(5968),
    [anon_sym_PIPE_PIPE] = ACTIONS(5966),
    [anon_sym_AMP_AMP] = ACTIONS(5966),
    [anon_sym_PIPE] = ACTIONS(5968),
    [anon_sym_CARET] = ACTIONS(5968),
    [anon_sym_AMP] = ACTIONS(5968),
    [anon_sym_EQ_EQ] = ACTIONS(5966),
    [anon_sym_BANG_EQ] = ACTIONS(5966),
    [anon_sym_GT] = ACTIONS(5968),
    [anon_sym_GT_EQ] = ACTIONS(5966),
    [anon_sym_LT_EQ] = ACTIONS(5968),
    [anon_sym_LT] = ACTIONS(5968),
    [anon_sym_LT_LT] = ACTIONS(5968),
    [anon_sym_GT_GT] = ACTIONS(5968),
    [anon_sym___attribute__] = ACTIONS(5968),
    [anon_sym___attribute] = ACTIONS(5968),
    [anon_sym_LBRACE] = ACTIONS(5966),
    [anon_sym_signed] = ACTIONS(6663),
    [anon_sym_unsigned] = ACTIONS(6663),
    [anon_sym_long] = ACTIONS(6663),
    [anon_sym_short] = ACTIONS(6663),
    [anon_sym_LBRACK] = ACTIONS(5966),
    [anon_sym_EQ] = ACTIONS(5968),
    [anon_sym_QMARK] = ACTIONS(5966),
    [anon_sym_STAR_EQ] = ACTIONS(5966),
    [anon_sym_SLASH_EQ] = ACTIONS(5966),
    [anon_sym_PERCENT_EQ] = ACTIONS(5966),
    [anon_sym_PLUS_EQ] = ACTIONS(5966),
    [anon_sym_DASH_EQ] = ACTIONS(5966),
    [anon_sym_LT_LT_EQ] = ACTIONS(5966),
    [anon_sym_GT_GT_EQ] = ACTIONS(5966),
    [anon_sym_AMP_EQ] = ACTIONS(5966),
    [anon_sym_CARET_EQ] = ACTIONS(5966),
    [anon_sym_PIPE_EQ] = ACTIONS(5966),
    [anon_sym_and_eq] = ACTIONS(5968),
    [anon_sym_or_eq] = ACTIONS(5968),
    [anon_sym_xor_eq] = ACTIONS(5968),
    [anon_sym_LT_EQ_GT] = ACTIONS(5966),
    [anon_sym_or] = ACTIONS(5968),
    [anon_sym_and] = ACTIONS(5968),
    [anon_sym_bitor] = ACTIONS(5968),
    [anon_sym_xor] = ACTIONS(5968),
    [anon_sym_bitand] = ACTIONS(5968),
    [anon_sym_not_eq] = ACTIONS(5968),
    [anon_sym_DASH_DASH] = ACTIONS(5966),
    [anon_sym_PLUS_PLUS] = ACTIONS(5966),
    [anon_sym_DOT] = ACTIONS(5968),
    [anon_sym_DOT_STAR] = ACTIONS(5966),
    [anon_sym_DASH_GT] = ACTIONS(5966),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5968),
    [anon_sym_decltype] = ACTIONS(5968),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5966),
  },
  [STATE(2617)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2486),
    [sym_identifier] = ACTIONS(5996),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5994),
    [anon_sym_COMMA] = ACTIONS(5994),
    [aux_sym_preproc_if_token2] = ACTIONS(5994),
    [aux_sym_preproc_else_token1] = ACTIONS(5994),
    [aux_sym_preproc_elif_token1] = ACTIONS(5996),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5994),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5994),
    [anon_sym_LPAREN2] = ACTIONS(5994),
    [anon_sym_DASH] = ACTIONS(5996),
    [anon_sym_PLUS] = ACTIONS(5996),
    [anon_sym_STAR] = ACTIONS(5996),
    [anon_sym_SLASH] = ACTIONS(5996),
    [anon_sym_PERCENT] = ACTIONS(5996),
    [anon_sym_PIPE_PIPE] = ACTIONS(5994),
    [anon_sym_AMP_AMP] = ACTIONS(5994),
    [anon_sym_PIPE] = ACTIONS(5996),
    [anon_sym_CARET] = ACTIONS(5996),
    [anon_sym_AMP] = ACTIONS(5996),
    [anon_sym_EQ_EQ] = ACTIONS(5994),
    [anon_sym_BANG_EQ] = ACTIONS(5994),
    [anon_sym_GT] = ACTIONS(5996),
    [anon_sym_GT_EQ] = ACTIONS(5994),
    [anon_sym_LT_EQ] = ACTIONS(5996),
    [anon_sym_LT] = ACTIONS(5996),
    [anon_sym_LT_LT] = ACTIONS(5996),
    [anon_sym_GT_GT] = ACTIONS(5996),
    [anon_sym___attribute__] = ACTIONS(5996),
    [anon_sym___attribute] = ACTIONS(5996),
    [anon_sym_LBRACE] = ACTIONS(5994),
    [anon_sym_signed] = ACTIONS(6665),
    [anon_sym_unsigned] = ACTIONS(6665),
    [anon_sym_long] = ACTIONS(6665),
    [anon_sym_short] = ACTIONS(6665),
    [anon_sym_LBRACK] = ACTIONS(5994),
    [anon_sym_EQ] = ACTIONS(5996),
    [anon_sym_QMARK] = ACTIONS(5994),
    [anon_sym_STAR_EQ] = ACTIONS(5994),
    [anon_sym_SLASH_EQ] = ACTIONS(5994),
    [anon_sym_PERCENT_EQ] = ACTIONS(5994),
    [anon_sym_PLUS_EQ] = ACTIONS(5994),
    [anon_sym_DASH_EQ] = ACTIONS(5994),
    [anon_sym_LT_LT_EQ] = ACTIONS(5994),
    [anon_sym_GT_GT_EQ] = ACTIONS(5994),
    [anon_sym_AMP_EQ] = ACTIONS(5994),
    [anon_sym_CARET_EQ] = ACTIONS(5994),
    [anon_sym_PIPE_EQ] = ACTIONS(5994),
    [anon_sym_and_eq] = ACTIONS(5996),
    [anon_sym_or_eq] = ACTIONS(5996),
    [anon_sym_xor_eq] = ACTIONS(5996),
    [anon_sym_LT_EQ_GT] = ACTIONS(5994),
    [anon_sym_or] = ACTIONS(5996),
    [anon_sym_and] = ACTIONS(5996),
    [anon_sym_bitor] = ACTIONS(5996),
    [anon_sym_xor] = ACTIONS(5996),
    [anon_sym_bitand] = ACTIONS(5996),
    [anon_sym_not_eq] = ACTIONS(5996),
    [anon_sym_DASH_DASH] = ACTIONS(5994),
    [anon_sym_PLUS_PLUS] = ACTIONS(5994),
    [anon_sym_DOT] = ACTIONS(5996),
    [anon_sym_DOT_STAR] = ACTIONS(5994),
    [anon_sym_DASH_GT] = ACTIONS(5994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5996),
    [anon_sym_decltype] = ACTIONS(5996),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5994),
  },
  [STATE(2618)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5819),
    [anon_sym_COMMA] = ACTIONS(5819),
    [anon_sym_LPAREN2] = ACTIONS(5819),
    [anon_sym_DASH] = ACTIONS(5817),
    [anon_sym_PLUS] = ACTIONS(5817),
    [anon_sym_STAR] = ACTIONS(5819),
    [anon_sym_SLASH] = ACTIONS(5817),
    [anon_sym_PERCENT] = ACTIONS(5819),
    [anon_sym_PIPE_PIPE] = ACTIONS(5819),
    [anon_sym_AMP_AMP] = ACTIONS(5819),
    [anon_sym_PIPE] = ACTIONS(5817),
    [anon_sym_CARET] = ACTIONS(5819),
    [anon_sym_AMP] = ACTIONS(5817),
    [anon_sym_EQ_EQ] = ACTIONS(5819),
    [anon_sym_BANG_EQ] = ACTIONS(5819),
    [anon_sym_GT] = ACTIONS(5817),
    [anon_sym_GT_EQ] = ACTIONS(5817),
    [anon_sym_LT_EQ] = ACTIONS(5817),
    [anon_sym_LT] = ACTIONS(5817),
    [anon_sym_LT_LT] = ACTIONS(5817),
    [anon_sym_GT_GT] = ACTIONS(5817),
    [anon_sym___extension__] = ACTIONS(5819),
    [anon_sym___global__] = ACTIONS(5819),
    [anon_sym___attribute__] = ACTIONS(5819),
    [anon_sym___attribute] = ACTIONS(5817),
    [anon_sym_LBRACE] = ACTIONS(5819),
    [anon_sym_LBRACK] = ACTIONS(5819),
    [anon_sym_const] = ACTIONS(5817),
    [anon_sym_constexpr] = ACTIONS(5819),
    [anon_sym_volatile] = ACTIONS(5819),
    [anon_sym_restrict] = ACTIONS(5819),
    [anon_sym___restrict__] = ACTIONS(5819),
    [anon_sym__Atomic] = ACTIONS(5819),
    [anon_sym__Noreturn] = ACTIONS(5819),
    [anon_sym_noreturn] = ACTIONS(5819),
    [anon_sym__Nonnull] = ACTIONS(5819),
    [anon_sym_mutable] = ACTIONS(5819),
    [anon_sym_constinit] = ACTIONS(5819),
    [anon_sym_consteval] = ACTIONS(5819),
    [anon_sym___shared__] = ACTIONS(5819),
    [anon_sym___local__] = ACTIONS(5819),
    [anon_sym___constant__] = ACTIONS(5819),
    [anon_sym___managed__] = ACTIONS(5819),
    [anon_sym___grid_constant__] = ACTIONS(5819),
    [anon_sym_alignas] = ACTIONS(5819),
    [anon_sym__Alignas] = ACTIONS(5819),
    [anon_sym_QMARK] = ACTIONS(5819),
    [anon_sym_LT_EQ_GT] = ACTIONS(5819),
    [anon_sym_or] = ACTIONS(5819),
    [anon_sym_and] = ACTIONS(5819),
    [anon_sym_bitor] = ACTIONS(5819),
    [anon_sym_xor] = ACTIONS(5819),
    [anon_sym_bitand] = ACTIONS(5819),
    [anon_sym_not_eq] = ACTIONS(5819),
    [anon_sym_DASH_DASH] = ACTIONS(5819),
    [anon_sym_PLUS_PLUS] = ACTIONS(5819),
    [anon_sym_DOT] = ACTIONS(5817),
    [anon_sym_DOT_STAR] = ACTIONS(5819),
    [anon_sym_DASH_GT] = ACTIONS(5819),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5819),
    [anon_sym_decltype] = ACTIONS(5819),
    [anon_sym_final] = ACTIONS(5819),
    [anon_sym_override] = ACTIONS(5819),
    [anon_sym_GT2] = ACTIONS(5819),
    [anon_sym_requires] = ACTIONS(5819),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5819),
  },
  [STATE(2619)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2691),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5684),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5684),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5686),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_signed] = ACTIONS(6667),
    [anon_sym_unsigned] = ACTIONS(6667),
    [anon_sym_long] = ACTIONS(6667),
    [anon_sym_short] = ACTIONS(6667),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_EQ] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_STAR_EQ] = ACTIONS(5686),
    [anon_sym_SLASH_EQ] = ACTIONS(5686),
    [anon_sym_PERCENT_EQ] = ACTIONS(5686),
    [anon_sym_PLUS_EQ] = ACTIONS(5686),
    [anon_sym_DASH_EQ] = ACTIONS(5686),
    [anon_sym_LT_LT_EQ] = ACTIONS(5686),
    [anon_sym_GT_GT_EQ] = ACTIONS(5686),
    [anon_sym_AMP_EQ] = ACTIONS(5686),
    [anon_sym_CARET_EQ] = ACTIONS(5686),
    [anon_sym_PIPE_EQ] = ACTIONS(5686),
    [anon_sym_and_eq] = ACTIONS(5686),
    [anon_sym_or_eq] = ACTIONS(5686),
    [anon_sym_xor_eq] = ACTIONS(5686),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_and] = ACTIONS(5684),
    [anon_sym_bitor] = ACTIONS(5686),
    [anon_sym_xor] = ACTIONS(5684),
    [anon_sym_bitand] = ACTIONS(5686),
    [anon_sym_not_eq] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5686),
    [anon_sym_decltype] = ACTIONS(5686),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2620)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2645),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_RPAREN] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_STAR] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym___extension__] = ACTIONS(5772),
    [anon_sym___device__] = ACTIONS(5772),
    [anon_sym___host__] = ACTIONS(5772),
    [anon_sym___global__] = ACTIONS(5772),
    [anon_sym___forceinline__] = ACTIONS(5772),
    [anon_sym___noinline__] = ACTIONS(5772),
    [anon_sym_virtual] = ACTIONS(5772),
    [anon_sym_extern] = ACTIONS(5772),
    [anon_sym___attribute__] = ACTIONS(5772),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5772),
    [anon_sym___declspec] = ACTIONS(5772),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_signed] = ACTIONS(6669),
    [anon_sym_unsigned] = ACTIONS(6669),
    [anon_sym_long] = ACTIONS(6669),
    [anon_sym_short] = ACTIONS(6669),
    [anon_sym_LBRACK] = ACTIONS(5770),
    [anon_sym_static] = ACTIONS(5772),
    [anon_sym_EQ] = ACTIONS(5772),
    [anon_sym_register] = ACTIONS(5772),
    [anon_sym_inline] = ACTIONS(5772),
    [anon_sym___inline] = ACTIONS(5770),
    [anon_sym___inline__] = ACTIONS(5772),
    [anon_sym___forceinline] = ACTIONS(5770),
    [anon_sym_thread_local] = ACTIONS(5772),
    [anon_sym___thread] = ACTIONS(5772),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_constexpr] = ACTIONS(5772),
    [anon_sym_volatile] = ACTIONS(5772),
    [anon_sym_restrict] = ACTIONS(5772),
    [anon_sym___restrict__] = ACTIONS(5772),
    [anon_sym__Atomic] = ACTIONS(5772),
    [anon_sym__Noreturn] = ACTIONS(5772),
    [anon_sym_noreturn] = ACTIONS(5772),
    [anon_sym__Nonnull] = ACTIONS(5772),
    [anon_sym_mutable] = ACTIONS(5772),
    [anon_sym_constinit] = ACTIONS(5772),
    [anon_sym_consteval] = ACTIONS(5772),
    [anon_sym___shared__] = ACTIONS(5772),
    [anon_sym___local__] = ACTIONS(5772),
    [anon_sym___constant__] = ACTIONS(5772),
    [anon_sym___managed__] = ACTIONS(5772),
    [anon_sym___grid_constant__] = ACTIONS(5772),
    [anon_sym_alignas] = ACTIONS(5772),
    [anon_sym__Alignas] = ACTIONS(5772),
    [anon_sym_asm] = ACTIONS(5772),
    [anon_sym___asm__] = ACTIONS(5772),
    [anon_sym___asm] = ACTIONS(5770),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5772),
    [anon_sym_decltype] = ACTIONS(5772),
    [anon_sym_final] = ACTIONS(5772),
    [anon_sym_override] = ACTIONS(5772),
    [anon_sym_GT2] = ACTIONS(5772),
    [anon_sym_try] = ACTIONS(5772),
    [anon_sym_requires] = ACTIONS(5772),
    [anon_sym___launch_bounds__] = ACTIONS(5772),
  },
  [STATE(2621)] = {
    [sym_attribute_specifier] = STATE(2504),
    [sym_enumerator_list] = STATE(2439),
    [sym__enum_base_clause] = STATE(2407),
    [sym_identifier] = ACTIONS(6671),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6673),
    [anon_sym_COMMA] = ACTIONS(6673),
    [aux_sym_preproc_if_token2] = ACTIONS(6673),
    [aux_sym_preproc_else_token1] = ACTIONS(6673),
    [aux_sym_preproc_elif_token1] = ACTIONS(6671),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6673),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6673),
    [anon_sym_LPAREN2] = ACTIONS(6673),
    [anon_sym_DASH] = ACTIONS(6671),
    [anon_sym_PLUS] = ACTIONS(6671),
    [anon_sym_STAR] = ACTIONS(6671),
    [anon_sym_SLASH] = ACTIONS(6671),
    [anon_sym_PERCENT] = ACTIONS(6671),
    [anon_sym_PIPE_PIPE] = ACTIONS(6673),
    [anon_sym_AMP_AMP] = ACTIONS(6673),
    [anon_sym_PIPE] = ACTIONS(6671),
    [anon_sym_CARET] = ACTIONS(6671),
    [anon_sym_AMP] = ACTIONS(6671),
    [anon_sym_EQ_EQ] = ACTIONS(6673),
    [anon_sym_BANG_EQ] = ACTIONS(6673),
    [anon_sym_GT] = ACTIONS(6671),
    [anon_sym_GT_EQ] = ACTIONS(6673),
    [anon_sym_LT_EQ] = ACTIONS(6671),
    [anon_sym_LT] = ACTIONS(6671),
    [anon_sym_LT_LT] = ACTIONS(6671),
    [anon_sym_GT_GT] = ACTIONS(6671),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6399),
    [anon_sym_LBRACK] = ACTIONS(6673),
    [anon_sym_EQ] = ACTIONS(6671),
    [anon_sym_COLON] = ACTIONS(6675),
    [anon_sym_QMARK] = ACTIONS(6673),
    [anon_sym_STAR_EQ] = ACTIONS(6673),
    [anon_sym_SLASH_EQ] = ACTIONS(6673),
    [anon_sym_PERCENT_EQ] = ACTIONS(6673),
    [anon_sym_PLUS_EQ] = ACTIONS(6673),
    [anon_sym_DASH_EQ] = ACTIONS(6673),
    [anon_sym_LT_LT_EQ] = ACTIONS(6673),
    [anon_sym_GT_GT_EQ] = ACTIONS(6673),
    [anon_sym_AMP_EQ] = ACTIONS(6673),
    [anon_sym_CARET_EQ] = ACTIONS(6673),
    [anon_sym_PIPE_EQ] = ACTIONS(6673),
    [anon_sym_and_eq] = ACTIONS(6671),
    [anon_sym_or_eq] = ACTIONS(6671),
    [anon_sym_xor_eq] = ACTIONS(6671),
    [anon_sym_LT_EQ_GT] = ACTIONS(6673),
    [anon_sym_or] = ACTIONS(6671),
    [anon_sym_and] = ACTIONS(6671),
    [anon_sym_bitor] = ACTIONS(6671),
    [anon_sym_xor] = ACTIONS(6671),
    [anon_sym_bitand] = ACTIONS(6671),
    [anon_sym_not_eq] = ACTIONS(6671),
    [anon_sym_DASH_DASH] = ACTIONS(6673),
    [anon_sym_PLUS_PLUS] = ACTIONS(6673),
    [anon_sym_DOT] = ACTIONS(6671),
    [anon_sym_DOT_STAR] = ACTIONS(6673),
    [anon_sym_DASH_GT] = ACTIONS(6673),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6671),
    [anon_sym_decltype] = ACTIONS(6671),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6673),
  },
  [STATE(2622)] = {
    [sym_attribute_specifier] = STATE(2479),
    [sym_enumerator_list] = STATE(2428),
    [sym__enum_base_clause] = STATE(2388),
    [sym_identifier] = ACTIONS(6677),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6679),
    [anon_sym_COMMA] = ACTIONS(6679),
    [aux_sym_preproc_if_token2] = ACTIONS(6679),
    [aux_sym_preproc_else_token1] = ACTIONS(6679),
    [aux_sym_preproc_elif_token1] = ACTIONS(6677),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6679),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6679),
    [anon_sym_LPAREN2] = ACTIONS(6679),
    [anon_sym_DASH] = ACTIONS(6677),
    [anon_sym_PLUS] = ACTIONS(6677),
    [anon_sym_STAR] = ACTIONS(6677),
    [anon_sym_SLASH] = ACTIONS(6677),
    [anon_sym_PERCENT] = ACTIONS(6677),
    [anon_sym_PIPE_PIPE] = ACTIONS(6679),
    [anon_sym_AMP_AMP] = ACTIONS(6679),
    [anon_sym_PIPE] = ACTIONS(6677),
    [anon_sym_CARET] = ACTIONS(6677),
    [anon_sym_AMP] = ACTIONS(6677),
    [anon_sym_EQ_EQ] = ACTIONS(6679),
    [anon_sym_BANG_EQ] = ACTIONS(6679),
    [anon_sym_GT] = ACTIONS(6677),
    [anon_sym_GT_EQ] = ACTIONS(6679),
    [anon_sym_LT_EQ] = ACTIONS(6677),
    [anon_sym_LT] = ACTIONS(6677),
    [anon_sym_LT_LT] = ACTIONS(6677),
    [anon_sym_GT_GT] = ACTIONS(6677),
    [anon_sym___attribute__] = ACTIONS(6196),
    [anon_sym___attribute] = ACTIONS(6196),
    [anon_sym_LBRACE] = ACTIONS(6399),
    [anon_sym_LBRACK] = ACTIONS(6679),
    [anon_sym_EQ] = ACTIONS(6677),
    [anon_sym_COLON] = ACTIONS(6675),
    [anon_sym_QMARK] = ACTIONS(6679),
    [anon_sym_STAR_EQ] = ACTIONS(6679),
    [anon_sym_SLASH_EQ] = ACTIONS(6679),
    [anon_sym_PERCENT_EQ] = ACTIONS(6679),
    [anon_sym_PLUS_EQ] = ACTIONS(6679),
    [anon_sym_DASH_EQ] = ACTIONS(6679),
    [anon_sym_LT_LT_EQ] = ACTIONS(6679),
    [anon_sym_GT_GT_EQ] = ACTIONS(6679),
    [anon_sym_AMP_EQ] = ACTIONS(6679),
    [anon_sym_CARET_EQ] = ACTIONS(6679),
    [anon_sym_PIPE_EQ] = ACTIONS(6679),
    [anon_sym_and_eq] = ACTIONS(6677),
    [anon_sym_or_eq] = ACTIONS(6677),
    [anon_sym_xor_eq] = ACTIONS(6677),
    [anon_sym_LT_EQ_GT] = ACTIONS(6679),
    [anon_sym_or] = ACTIONS(6677),
    [anon_sym_and] = ACTIONS(6677),
    [anon_sym_bitor] = ACTIONS(6677),
    [anon_sym_xor] = ACTIONS(6677),
    [anon_sym_bitand] = ACTIONS(6677),
    [anon_sym_not_eq] = ACTIONS(6677),
    [anon_sym_DASH_DASH] = ACTIONS(6679),
    [anon_sym_PLUS_PLUS] = ACTIONS(6679),
    [anon_sym_DOT] = ACTIONS(6677),
    [anon_sym_DOT_STAR] = ACTIONS(6679),
    [anon_sym_DASH_GT] = ACTIONS(6679),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6677),
    [anon_sym_decltype] = ACTIONS(6677),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6679),
  },
  [STATE(2623)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6024),
    [anon_sym_COMMA] = ACTIONS(6024),
    [anon_sym_RPAREN] = ACTIONS(6024),
    [anon_sym_LPAREN2] = ACTIONS(6024),
    [anon_sym_DASH] = ACTIONS(6026),
    [anon_sym_PLUS] = ACTIONS(6026),
    [anon_sym_STAR] = ACTIONS(6026),
    [anon_sym_SLASH] = ACTIONS(6026),
    [anon_sym_PERCENT] = ACTIONS(6026),
    [anon_sym_PIPE_PIPE] = ACTIONS(6024),
    [anon_sym_AMP_AMP] = ACTIONS(6024),
    [anon_sym_PIPE] = ACTIONS(6026),
    [anon_sym_CARET] = ACTIONS(6026),
    [anon_sym_AMP] = ACTIONS(6026),
    [anon_sym_EQ_EQ] = ACTIONS(6024),
    [anon_sym_BANG_EQ] = ACTIONS(6024),
    [anon_sym_GT] = ACTIONS(6026),
    [anon_sym_GT_EQ] = ACTIONS(6024),
    [anon_sym_LT_EQ] = ACTIONS(6026),
    [anon_sym_LT] = ACTIONS(6026),
    [anon_sym_LT_LT] = ACTIONS(6026),
    [anon_sym_GT_GT] = ACTIONS(6026),
    [anon_sym_SEMI] = ACTIONS(6024),
    [anon_sym___attribute__] = ACTIONS(6024),
    [anon_sym___attribute] = ACTIONS(6026),
    [anon_sym_LBRACE] = ACTIONS(6024),
    [anon_sym_RBRACE] = ACTIONS(6024),
    [anon_sym_signed] = ACTIONS(6681),
    [anon_sym_unsigned] = ACTIONS(6681),
    [anon_sym_long] = ACTIONS(6681),
    [anon_sym_short] = ACTIONS(6681),
    [anon_sym_LBRACK] = ACTIONS(6024),
    [anon_sym_RBRACK] = ACTIONS(6024),
    [anon_sym_EQ] = ACTIONS(6026),
    [anon_sym_COLON] = ACTIONS(6024),
    [anon_sym_QMARK] = ACTIONS(6024),
    [anon_sym_STAR_EQ] = ACTIONS(6024),
    [anon_sym_SLASH_EQ] = ACTIONS(6024),
    [anon_sym_PERCENT_EQ] = ACTIONS(6024),
    [anon_sym_PLUS_EQ] = ACTIONS(6024),
    [anon_sym_DASH_EQ] = ACTIONS(6024),
    [anon_sym_LT_LT_EQ] = ACTIONS(6024),
    [anon_sym_GT_GT_EQ] = ACTIONS(6024),
    [anon_sym_AMP_EQ] = ACTIONS(6024),
    [anon_sym_CARET_EQ] = ACTIONS(6024),
    [anon_sym_PIPE_EQ] = ACTIONS(6024),
    [anon_sym_and_eq] = ACTIONS(6024),
    [anon_sym_or_eq] = ACTIONS(6024),
    [anon_sym_xor_eq] = ACTIONS(6024),
    [anon_sym_LT_EQ_GT] = ACTIONS(6024),
    [anon_sym_or] = ACTIONS(6026),
    [anon_sym_and] = ACTIONS(6026),
    [anon_sym_bitor] = ACTIONS(6024),
    [anon_sym_xor] = ACTIONS(6026),
    [anon_sym_bitand] = ACTIONS(6024),
    [anon_sym_not_eq] = ACTIONS(6024),
    [anon_sym_DASH_DASH] = ACTIONS(6024),
    [anon_sym_PLUS_PLUS] = ACTIONS(6024),
    [anon_sym_DOT] = ACTIONS(6026),
    [anon_sym_DOT_STAR] = ACTIONS(6024),
    [anon_sym_DASH_GT] = ACTIONS(6024),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6024),
    [anon_sym_decltype] = ACTIONS(6024),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6024),
  },
  [STATE(2624)] = {
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym_namespace] = ACTIONS(6683),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2625)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_TILDE] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5686),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym___cdecl] = ACTIONS(5684),
    [anon_sym___clrcall] = ACTIONS(5684),
    [anon_sym___stdcall] = ACTIONS(5684),
    [anon_sym___fastcall] = ACTIONS(5684),
    [anon_sym___thiscall] = ACTIONS(5684),
    [anon_sym___vectorcall] = ACTIONS(5684),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_template] = ACTIONS(5684),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_operator] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2626)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_friend] = ACTIONS(6685),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2627)] = {
    [sym_argument_list] = STATE(2794),
    [sym_subscript_argument_list] = STATE(2795),
    [sym_kernel_call_syntax] = STATE(8417),
    [sym_identifier] = ACTIONS(6687),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6689),
    [anon_sym_COMMA] = ACTIONS(6689),
    [anon_sym_RPAREN] = ACTIONS(6689),
    [aux_sym_preproc_if_token2] = ACTIONS(6689),
    [aux_sym_preproc_else_token1] = ACTIONS(6689),
    [aux_sym_preproc_elif_token1] = ACTIONS(6687),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6689),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6689),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6687),
    [anon_sym_PLUS] = ACTIONS(6687),
    [anon_sym_STAR] = ACTIONS(6687),
    [anon_sym_SLASH] = ACTIONS(6687),
    [anon_sym_PERCENT] = ACTIONS(6687),
    [anon_sym_PIPE_PIPE] = ACTIONS(6689),
    [anon_sym_AMP_AMP] = ACTIONS(6689),
    [anon_sym_PIPE] = ACTIONS(6687),
    [anon_sym_CARET] = ACTIONS(6687),
    [anon_sym_AMP] = ACTIONS(6687),
    [anon_sym_EQ_EQ] = ACTIONS(6689),
    [anon_sym_BANG_EQ] = ACTIONS(6689),
    [anon_sym_GT] = ACTIONS(6687),
    [anon_sym_GT_EQ] = ACTIONS(6689),
    [anon_sym_LT_EQ] = ACTIONS(6687),
    [anon_sym_LT] = ACTIONS(6687),
    [anon_sym_LT_LT] = ACTIONS(6687),
    [anon_sym_GT_GT] = ACTIONS(6687),
    [anon_sym_SEMI] = ACTIONS(6689),
    [anon_sym___attribute__] = ACTIONS(6687),
    [anon_sym___attribute] = ACTIONS(6687),
    [anon_sym_RBRACE] = ACTIONS(6689),
    [anon_sym_LBRACK] = ACTIONS(6691),
    [anon_sym_RBRACK] = ACTIONS(6689),
    [anon_sym_EQ] = ACTIONS(6687),
    [anon_sym_QMARK] = ACTIONS(6689),
    [anon_sym_STAR_EQ] = ACTIONS(6689),
    [anon_sym_SLASH_EQ] = ACTIONS(6689),
    [anon_sym_PERCENT_EQ] = ACTIONS(6689),
    [anon_sym_PLUS_EQ] = ACTIONS(6689),
    [anon_sym_DASH_EQ] = ACTIONS(6689),
    [anon_sym_LT_LT_EQ] = ACTIONS(6689),
    [anon_sym_GT_GT_EQ] = ACTIONS(6689),
    [anon_sym_AMP_EQ] = ACTIONS(6689),
    [anon_sym_CARET_EQ] = ACTIONS(6689),
    [anon_sym_PIPE_EQ] = ACTIONS(6689),
    [anon_sym_and_eq] = ACTIONS(6687),
    [anon_sym_or_eq] = ACTIONS(6687),
    [anon_sym_xor_eq] = ACTIONS(6687),
    [anon_sym_LT_EQ_GT] = ACTIONS(6689),
    [anon_sym_or] = ACTIONS(6687),
    [anon_sym_and] = ACTIONS(6687),
    [anon_sym_bitor] = ACTIONS(6687),
    [anon_sym_xor] = ACTIONS(6687),
    [anon_sym_bitand] = ACTIONS(6687),
    [anon_sym_not_eq] = ACTIONS(6687),
    [anon_sym_DASH_DASH] = ACTIONS(6689),
    [anon_sym_PLUS_PLUS] = ACTIONS(6689),
    [anon_sym_DOT] = ACTIONS(6693),
    [anon_sym_DOT_STAR] = ACTIONS(6695),
    [anon_sym_DASH_GT] = ACTIONS(6695),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6689),
  },
  [STATE(2628)] = {
    [sym_argument_list] = STATE(2794),
    [sym_subscript_argument_list] = STATE(2795),
    [sym_kernel_call_syntax] = STATE(8417),
    [sym_identifier] = ACTIONS(6697),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6699),
    [anon_sym_COMMA] = ACTIONS(6699),
    [anon_sym_RPAREN] = ACTIONS(6699),
    [aux_sym_preproc_if_token2] = ACTIONS(6699),
    [aux_sym_preproc_else_token1] = ACTIONS(6699),
    [aux_sym_preproc_elif_token1] = ACTIONS(6697),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6699),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6699),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6697),
    [anon_sym_PLUS] = ACTIONS(6697),
    [anon_sym_STAR] = ACTIONS(6697),
    [anon_sym_SLASH] = ACTIONS(6697),
    [anon_sym_PERCENT] = ACTIONS(6697),
    [anon_sym_PIPE_PIPE] = ACTIONS(6699),
    [anon_sym_AMP_AMP] = ACTIONS(6699),
    [anon_sym_PIPE] = ACTIONS(6697),
    [anon_sym_CARET] = ACTIONS(6697),
    [anon_sym_AMP] = ACTIONS(6697),
    [anon_sym_EQ_EQ] = ACTIONS(6699),
    [anon_sym_BANG_EQ] = ACTIONS(6699),
    [anon_sym_GT] = ACTIONS(6697),
    [anon_sym_GT_EQ] = ACTIONS(6699),
    [anon_sym_LT_EQ] = ACTIONS(6697),
    [anon_sym_LT] = ACTIONS(6697),
    [anon_sym_LT_LT] = ACTIONS(6697),
    [anon_sym_GT_GT] = ACTIONS(6697),
    [anon_sym_SEMI] = ACTIONS(6699),
    [anon_sym___attribute__] = ACTIONS(6697),
    [anon_sym___attribute] = ACTIONS(6697),
    [anon_sym_RBRACE] = ACTIONS(6699),
    [anon_sym_LBRACK] = ACTIONS(6691),
    [anon_sym_RBRACK] = ACTIONS(6699),
    [anon_sym_EQ] = ACTIONS(6697),
    [anon_sym_QMARK] = ACTIONS(6699),
    [anon_sym_STAR_EQ] = ACTIONS(6699),
    [anon_sym_SLASH_EQ] = ACTIONS(6699),
    [anon_sym_PERCENT_EQ] = ACTIONS(6699),
    [anon_sym_PLUS_EQ] = ACTIONS(6699),
    [anon_sym_DASH_EQ] = ACTIONS(6699),
    [anon_sym_LT_LT_EQ] = ACTIONS(6699),
    [anon_sym_GT_GT_EQ] = ACTIONS(6699),
    [anon_sym_AMP_EQ] = ACTIONS(6699),
    [anon_sym_CARET_EQ] = ACTIONS(6699),
    [anon_sym_PIPE_EQ] = ACTIONS(6699),
    [anon_sym_and_eq] = ACTIONS(6697),
    [anon_sym_or_eq] = ACTIONS(6697),
    [anon_sym_xor_eq] = ACTIONS(6697),
    [anon_sym_LT_EQ_GT] = ACTIONS(6699),
    [anon_sym_or] = ACTIONS(6697),
    [anon_sym_and] = ACTIONS(6697),
    [anon_sym_bitor] = ACTIONS(6697),
    [anon_sym_xor] = ACTIONS(6697),
    [anon_sym_bitand] = ACTIONS(6697),
    [anon_sym_not_eq] = ACTIONS(6697),
    [anon_sym_DASH_DASH] = ACTIONS(6699),
    [anon_sym_PLUS_PLUS] = ACTIONS(6699),
    [anon_sym_DOT] = ACTIONS(6693),
    [anon_sym_DOT_STAR] = ACTIONS(6695),
    [anon_sym_DASH_GT] = ACTIONS(6695),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6699),
  },
  [STATE(2629)] = {
    [sym_argument_list] = STATE(3942),
    [sym_initializer_list] = STATE(4395),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2309),
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(6701),
    [anon_sym_TILDE] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5686),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(3558),
    [anon_sym_signed] = ACTIONS(6190),
    [anon_sym_unsigned] = ACTIONS(6190),
    [anon_sym_long] = ACTIONS(6190),
    [anon_sym_short] = ACTIONS(6190),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_template] = ACTIONS(5684),
    [anon_sym_operator] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2630)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1959),
    [anon_sym_COMMA] = ACTIONS(1959),
    [anon_sym_RPAREN] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym___cdecl] = ACTIONS(1969),
    [anon_sym___clrcall] = ACTIONS(1969),
    [anon_sym___stdcall] = ACTIONS(1969),
    [anon_sym___fastcall] = ACTIONS(1969),
    [anon_sym___thiscall] = ACTIONS(1969),
    [anon_sym___vectorcall] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_EQ] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_GT2] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2631)] = {
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym_namespace] = ACTIONS(6704),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2632)] = {
    [sym_argument_list] = STATE(2794),
    [sym_subscript_argument_list] = STATE(2795),
    [sym_kernel_call_syntax] = STATE(8417),
    [sym_identifier] = ACTIONS(6706),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6708),
    [anon_sym_COMMA] = ACTIONS(6708),
    [anon_sym_RPAREN] = ACTIONS(6708),
    [aux_sym_preproc_if_token2] = ACTIONS(6708),
    [aux_sym_preproc_else_token1] = ACTIONS(6708),
    [aux_sym_preproc_elif_token1] = ACTIONS(6706),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6708),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6708),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6706),
    [anon_sym_PLUS] = ACTIONS(6706),
    [anon_sym_STAR] = ACTIONS(6706),
    [anon_sym_SLASH] = ACTIONS(6706),
    [anon_sym_PERCENT] = ACTIONS(6706),
    [anon_sym_PIPE_PIPE] = ACTIONS(6708),
    [anon_sym_AMP_AMP] = ACTIONS(6708),
    [anon_sym_PIPE] = ACTIONS(6706),
    [anon_sym_CARET] = ACTIONS(6706),
    [anon_sym_AMP] = ACTIONS(6706),
    [anon_sym_EQ_EQ] = ACTIONS(6708),
    [anon_sym_BANG_EQ] = ACTIONS(6708),
    [anon_sym_GT] = ACTIONS(6706),
    [anon_sym_GT_EQ] = ACTIONS(6708),
    [anon_sym_LT_EQ] = ACTIONS(6706),
    [anon_sym_LT] = ACTIONS(6706),
    [anon_sym_LT_LT] = ACTIONS(6706),
    [anon_sym_GT_GT] = ACTIONS(6706),
    [anon_sym_SEMI] = ACTIONS(6708),
    [anon_sym___attribute__] = ACTIONS(6706),
    [anon_sym___attribute] = ACTIONS(6706),
    [anon_sym_RBRACE] = ACTIONS(6708),
    [anon_sym_LBRACK] = ACTIONS(6691),
    [anon_sym_RBRACK] = ACTIONS(6708),
    [anon_sym_EQ] = ACTIONS(6706),
    [anon_sym_QMARK] = ACTIONS(6708),
    [anon_sym_STAR_EQ] = ACTIONS(6708),
    [anon_sym_SLASH_EQ] = ACTIONS(6708),
    [anon_sym_PERCENT_EQ] = ACTIONS(6708),
    [anon_sym_PLUS_EQ] = ACTIONS(6708),
    [anon_sym_DASH_EQ] = ACTIONS(6708),
    [anon_sym_LT_LT_EQ] = ACTIONS(6708),
    [anon_sym_GT_GT_EQ] = ACTIONS(6708),
    [anon_sym_AMP_EQ] = ACTIONS(6708),
    [anon_sym_CARET_EQ] = ACTIONS(6708),
    [anon_sym_PIPE_EQ] = ACTIONS(6708),
    [anon_sym_and_eq] = ACTIONS(6706),
    [anon_sym_or_eq] = ACTIONS(6706),
    [anon_sym_xor_eq] = ACTIONS(6706),
    [anon_sym_LT_EQ_GT] = ACTIONS(6708),
    [anon_sym_or] = ACTIONS(6706),
    [anon_sym_and] = ACTIONS(6706),
    [anon_sym_bitor] = ACTIONS(6706),
    [anon_sym_xor] = ACTIONS(6706),
    [anon_sym_bitand] = ACTIONS(6706),
    [anon_sym_not_eq] = ACTIONS(6706),
    [anon_sym_DASH_DASH] = ACTIONS(6710),
    [anon_sym_PLUS_PLUS] = ACTIONS(6710),
    [anon_sym_DOT] = ACTIONS(6693),
    [anon_sym_DOT_STAR] = ACTIONS(6695),
    [anon_sym_DASH_GT] = ACTIONS(6695),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6708),
  },
  [STATE(2633)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5994),
    [anon_sym_COMMA] = ACTIONS(5994),
    [anon_sym_RPAREN] = ACTIONS(5994),
    [anon_sym_LPAREN2] = ACTIONS(5994),
    [anon_sym_DASH] = ACTIONS(5996),
    [anon_sym_PLUS] = ACTIONS(5996),
    [anon_sym_STAR] = ACTIONS(5996),
    [anon_sym_SLASH] = ACTIONS(5996),
    [anon_sym_PERCENT] = ACTIONS(5996),
    [anon_sym_PIPE_PIPE] = ACTIONS(5994),
    [anon_sym_AMP_AMP] = ACTIONS(5994),
    [anon_sym_PIPE] = ACTIONS(5996),
    [anon_sym_CARET] = ACTIONS(5996),
    [anon_sym_AMP] = ACTIONS(5996),
    [anon_sym_EQ_EQ] = ACTIONS(5994),
    [anon_sym_BANG_EQ] = ACTIONS(5994),
    [anon_sym_GT] = ACTIONS(5996),
    [anon_sym_GT_EQ] = ACTIONS(5994),
    [anon_sym_LT_EQ] = ACTIONS(5996),
    [anon_sym_LT] = ACTIONS(5996),
    [anon_sym_LT_LT] = ACTIONS(5996),
    [anon_sym_GT_GT] = ACTIONS(5996),
    [anon_sym_SEMI] = ACTIONS(5994),
    [anon_sym___attribute__] = ACTIONS(5994),
    [anon_sym___attribute] = ACTIONS(5996),
    [anon_sym_LBRACE] = ACTIONS(5994),
    [anon_sym_RBRACE] = ACTIONS(5994),
    [anon_sym_signed] = ACTIONS(6712),
    [anon_sym_unsigned] = ACTIONS(6712),
    [anon_sym_long] = ACTIONS(6712),
    [anon_sym_short] = ACTIONS(6712),
    [anon_sym_LBRACK] = ACTIONS(5994),
    [anon_sym_RBRACK] = ACTIONS(5994),
    [anon_sym_EQ] = ACTIONS(5996),
    [anon_sym_COLON] = ACTIONS(5994),
    [anon_sym_QMARK] = ACTIONS(5994),
    [anon_sym_STAR_EQ] = ACTIONS(5994),
    [anon_sym_SLASH_EQ] = ACTIONS(5994),
    [anon_sym_PERCENT_EQ] = ACTIONS(5994),
    [anon_sym_PLUS_EQ] = ACTIONS(5994),
    [anon_sym_DASH_EQ] = ACTIONS(5994),
    [anon_sym_LT_LT_EQ] = ACTIONS(5994),
    [anon_sym_GT_GT_EQ] = ACTIONS(5994),
    [anon_sym_AMP_EQ] = ACTIONS(5994),
    [anon_sym_CARET_EQ] = ACTIONS(5994),
    [anon_sym_PIPE_EQ] = ACTIONS(5994),
    [anon_sym_and_eq] = ACTIONS(5994),
    [anon_sym_or_eq] = ACTIONS(5994),
    [anon_sym_xor_eq] = ACTIONS(5994),
    [anon_sym_LT_EQ_GT] = ACTIONS(5994),
    [anon_sym_or] = ACTIONS(5996),
    [anon_sym_and] = ACTIONS(5996),
    [anon_sym_bitor] = ACTIONS(5994),
    [anon_sym_xor] = ACTIONS(5996),
    [anon_sym_bitand] = ACTIONS(5994),
    [anon_sym_not_eq] = ACTIONS(5994),
    [anon_sym_DASH_DASH] = ACTIONS(5994),
    [anon_sym_PLUS_PLUS] = ACTIONS(5994),
    [anon_sym_DOT] = ACTIONS(5996),
    [anon_sym_DOT_STAR] = ACTIONS(5994),
    [anon_sym_DASH_GT] = ACTIONS(5994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5994),
    [anon_sym_decltype] = ACTIONS(5994),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5994),
  },
  [STATE(2634)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_typedef] = ACTIONS(6714),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2635)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_friend] = ACTIONS(6716),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2636)] = {
    [sym_string_literal] = STATE(2433),
    [sym_raw_string_literal] = STATE(2433),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6354),
    [anon_sym_COMMA] = ACTIONS(6354),
    [anon_sym_RPAREN] = ACTIONS(6354),
    [anon_sym_LPAREN2] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6352),
    [anon_sym_STAR] = ACTIONS(6352),
    [anon_sym_SLASH] = ACTIONS(6352),
    [anon_sym_PERCENT] = ACTIONS(6352),
    [anon_sym_PIPE_PIPE] = ACTIONS(6354),
    [anon_sym_AMP_AMP] = ACTIONS(6354),
    [anon_sym_PIPE] = ACTIONS(6352),
    [anon_sym_CARET] = ACTIONS(6352),
    [anon_sym_AMP] = ACTIONS(6352),
    [anon_sym_EQ_EQ] = ACTIONS(6354),
    [anon_sym_BANG_EQ] = ACTIONS(6354),
    [anon_sym_GT] = ACTIONS(6352),
    [anon_sym_GT_EQ] = ACTIONS(6354),
    [anon_sym_LT_EQ] = ACTIONS(6352),
    [anon_sym_LT] = ACTIONS(6352),
    [anon_sym_LT_LT] = ACTIONS(6352),
    [anon_sym_GT_GT] = ACTIONS(6352),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [anon_sym_EQ] = ACTIONS(6352),
    [anon_sym_QMARK] = ACTIONS(6354),
    [anon_sym_STAR_EQ] = ACTIONS(6354),
    [anon_sym_SLASH_EQ] = ACTIONS(6354),
    [anon_sym_PERCENT_EQ] = ACTIONS(6354),
    [anon_sym_PLUS_EQ] = ACTIONS(6354),
    [anon_sym_DASH_EQ] = ACTIONS(6354),
    [anon_sym_LT_LT_EQ] = ACTIONS(6354),
    [anon_sym_GT_GT_EQ] = ACTIONS(6354),
    [anon_sym_AMP_EQ] = ACTIONS(6354),
    [anon_sym_CARET_EQ] = ACTIONS(6354),
    [anon_sym_PIPE_EQ] = ACTIONS(6354),
    [anon_sym_and_eq] = ACTIONS(6352),
    [anon_sym_or_eq] = ACTIONS(6352),
    [anon_sym_xor_eq] = ACTIONS(6352),
    [anon_sym_LT_EQ_GT] = ACTIONS(6354),
    [anon_sym_or] = ACTIONS(6352),
    [anon_sym_and] = ACTIONS(6352),
    [anon_sym_bitor] = ACTIONS(6352),
    [anon_sym_xor] = ACTIONS(6352),
    [anon_sym_bitand] = ACTIONS(6352),
    [anon_sym_not_eq] = ACTIONS(6352),
    [anon_sym_DASH_DASH] = ACTIONS(6354),
    [anon_sym_PLUS_PLUS] = ACTIONS(6354),
    [anon_sym_DOT] = ACTIONS(6352),
    [anon_sym_DOT_STAR] = ACTIONS(6354),
    [anon_sym_DASH_GT] = ACTIONS(6352),
    [anon_sym_L_DQUOTE] = ACTIONS(5103),
    [anon_sym_u_DQUOTE] = ACTIONS(5103),
    [anon_sym_U_DQUOTE] = ACTIONS(5103),
    [anon_sym_u8_DQUOTE] = ACTIONS(5103),
    [anon_sym_DQUOTE] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5105),
    [anon_sym_LR_DQUOTE] = ACTIONS(5105),
    [anon_sym_uR_DQUOTE] = ACTIONS(5105),
    [anon_sym_UR_DQUOTE] = ACTIONS(5105),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5105),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6354),
    [sym_literal_suffix] = ACTIONS(6352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6354),
  },
  [STATE(2637)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6006),
    [anon_sym_COMMA] = ACTIONS(6006),
    [anon_sym_RPAREN] = ACTIONS(6006),
    [anon_sym_LPAREN2] = ACTIONS(6006),
    [anon_sym_DASH] = ACTIONS(6008),
    [anon_sym_PLUS] = ACTIONS(6008),
    [anon_sym_STAR] = ACTIONS(6008),
    [anon_sym_SLASH] = ACTIONS(6008),
    [anon_sym_PERCENT] = ACTIONS(6008),
    [anon_sym_PIPE_PIPE] = ACTIONS(6006),
    [anon_sym_AMP_AMP] = ACTIONS(6006),
    [anon_sym_PIPE] = ACTIONS(6008),
    [anon_sym_CARET] = ACTIONS(6008),
    [anon_sym_AMP] = ACTIONS(6008),
    [anon_sym_EQ_EQ] = ACTIONS(6006),
    [anon_sym_BANG_EQ] = ACTIONS(6006),
    [anon_sym_GT] = ACTIONS(6008),
    [anon_sym_GT_EQ] = ACTIONS(6006),
    [anon_sym_LT_EQ] = ACTIONS(6008),
    [anon_sym_LT] = ACTIONS(6008),
    [anon_sym_LT_LT] = ACTIONS(6008),
    [anon_sym_GT_GT] = ACTIONS(6008),
    [anon_sym_SEMI] = ACTIONS(6006),
    [anon_sym___attribute__] = ACTIONS(6006),
    [anon_sym___attribute] = ACTIONS(6008),
    [anon_sym_LBRACE] = ACTIONS(6006),
    [anon_sym_RBRACE] = ACTIONS(6006),
    [anon_sym_signed] = ACTIONS(6681),
    [anon_sym_unsigned] = ACTIONS(6681),
    [anon_sym_long] = ACTIONS(6681),
    [anon_sym_short] = ACTIONS(6681),
    [anon_sym_LBRACK] = ACTIONS(6006),
    [anon_sym_RBRACK] = ACTIONS(6006),
    [anon_sym_EQ] = ACTIONS(6008),
    [anon_sym_COLON] = ACTIONS(6006),
    [anon_sym_QMARK] = ACTIONS(6006),
    [anon_sym_STAR_EQ] = ACTIONS(6006),
    [anon_sym_SLASH_EQ] = ACTIONS(6006),
    [anon_sym_PERCENT_EQ] = ACTIONS(6006),
    [anon_sym_PLUS_EQ] = ACTIONS(6006),
    [anon_sym_DASH_EQ] = ACTIONS(6006),
    [anon_sym_LT_LT_EQ] = ACTIONS(6006),
    [anon_sym_GT_GT_EQ] = ACTIONS(6006),
    [anon_sym_AMP_EQ] = ACTIONS(6006),
    [anon_sym_CARET_EQ] = ACTIONS(6006),
    [anon_sym_PIPE_EQ] = ACTIONS(6006),
    [anon_sym_and_eq] = ACTIONS(6006),
    [anon_sym_or_eq] = ACTIONS(6006),
    [anon_sym_xor_eq] = ACTIONS(6006),
    [anon_sym_LT_EQ_GT] = ACTIONS(6006),
    [anon_sym_or] = ACTIONS(6008),
    [anon_sym_and] = ACTIONS(6008),
    [anon_sym_bitor] = ACTIONS(6006),
    [anon_sym_xor] = ACTIONS(6008),
    [anon_sym_bitand] = ACTIONS(6006),
    [anon_sym_not_eq] = ACTIONS(6006),
    [anon_sym_DASH_DASH] = ACTIONS(6006),
    [anon_sym_PLUS_PLUS] = ACTIONS(6006),
    [anon_sym_DOT] = ACTIONS(6008),
    [anon_sym_DOT_STAR] = ACTIONS(6006),
    [anon_sym_DASH_GT] = ACTIONS(6006),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6006),
    [anon_sym_decltype] = ACTIONS(6006),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6006),
  },
  [STATE(2638)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [anon_sym_COMMA] = ACTIONS(6006),
    [anon_sym_RPAREN] = ACTIONS(6006),
    [anon_sym_LPAREN2] = ACTIONS(6006),
    [anon_sym_STAR] = ACTIONS(6006),
    [anon_sym_AMP_AMP] = ACTIONS(6006),
    [anon_sym_AMP] = ACTIONS(6008),
    [anon_sym_SEMI] = ACTIONS(6006),
    [anon_sym___extension__] = ACTIONS(6006),
    [anon_sym___device__] = ACTIONS(6006),
    [anon_sym___host__] = ACTIONS(6006),
    [anon_sym___global__] = ACTIONS(6006),
    [anon_sym___forceinline__] = ACTIONS(6006),
    [anon_sym___noinline__] = ACTIONS(6006),
    [anon_sym_virtual] = ACTIONS(6006),
    [anon_sym_extern] = ACTIONS(6006),
    [anon_sym___attribute__] = ACTIONS(6006),
    [anon_sym___attribute] = ACTIONS(6008),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6006),
    [anon_sym___declspec] = ACTIONS(6006),
    [anon_sym_LBRACE] = ACTIONS(6006),
    [anon_sym_signed] = ACTIONS(6718),
    [anon_sym_unsigned] = ACTIONS(6718),
    [anon_sym_long] = ACTIONS(6718),
    [anon_sym_short] = ACTIONS(6718),
    [anon_sym_LBRACK] = ACTIONS(6008),
    [anon_sym_static] = ACTIONS(6006),
    [anon_sym_EQ] = ACTIONS(6006),
    [anon_sym_register] = ACTIONS(6006),
    [anon_sym_inline] = ACTIONS(6006),
    [anon_sym___inline] = ACTIONS(6008),
    [anon_sym___inline__] = ACTIONS(6006),
    [anon_sym___forceinline] = ACTIONS(6008),
    [anon_sym_thread_local] = ACTIONS(6006),
    [anon_sym___thread] = ACTIONS(6006),
    [anon_sym_const] = ACTIONS(6008),
    [anon_sym_constexpr] = ACTIONS(6006),
    [anon_sym_volatile] = ACTIONS(6006),
    [anon_sym_restrict] = ACTIONS(6006),
    [anon_sym___restrict__] = ACTIONS(6006),
    [anon_sym__Atomic] = ACTIONS(6006),
    [anon_sym__Noreturn] = ACTIONS(6006),
    [anon_sym_noreturn] = ACTIONS(6006),
    [anon_sym__Nonnull] = ACTIONS(6006),
    [anon_sym_mutable] = ACTIONS(6006),
    [anon_sym_constinit] = ACTIONS(6006),
    [anon_sym_consteval] = ACTIONS(6006),
    [anon_sym___shared__] = ACTIONS(6006),
    [anon_sym___local__] = ACTIONS(6006),
    [anon_sym___constant__] = ACTIONS(6006),
    [anon_sym___managed__] = ACTIONS(6006),
    [anon_sym___grid_constant__] = ACTIONS(6006),
    [anon_sym_alignas] = ACTIONS(6006),
    [anon_sym__Alignas] = ACTIONS(6006),
    [anon_sym_asm] = ACTIONS(6006),
    [anon_sym___asm__] = ACTIONS(6006),
    [anon_sym___asm] = ACTIONS(6008),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6006),
    [anon_sym_decltype] = ACTIONS(6006),
    [anon_sym_final] = ACTIONS(6006),
    [anon_sym_override] = ACTIONS(6006),
    [anon_sym_GT2] = ACTIONS(6006),
    [anon_sym_try] = ACTIONS(6006),
    [anon_sym_requires] = ACTIONS(6006),
    [anon_sym___launch_bounds__] = ACTIONS(6006),
  },
  [STATE(2639)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_friend] = ACTIONS(6720),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2640)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2645),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5686),
    [anon_sym___device__] = ACTIONS(5686),
    [anon_sym___host__] = ACTIONS(5686),
    [anon_sym___global__] = ACTIONS(5686),
    [anon_sym___forceinline__] = ACTIONS(5686),
    [anon_sym___noinline__] = ACTIONS(5686),
    [anon_sym_virtual] = ACTIONS(5686),
    [anon_sym_extern] = ACTIONS(5686),
    [anon_sym___attribute__] = ACTIONS(5686),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5686),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_signed] = ACTIONS(6669),
    [anon_sym_unsigned] = ACTIONS(6669),
    [anon_sym_long] = ACTIONS(6669),
    [anon_sym_short] = ACTIONS(6669),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5686),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5686),
    [anon_sym_inline] = ACTIONS(5686),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5686),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5686),
    [anon_sym___thread] = ACTIONS(5686),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5686),
    [anon_sym_volatile] = ACTIONS(5686),
    [anon_sym_restrict] = ACTIONS(5686),
    [anon_sym___restrict__] = ACTIONS(5686),
    [anon_sym__Atomic] = ACTIONS(5686),
    [anon_sym__Noreturn] = ACTIONS(5686),
    [anon_sym_noreturn] = ACTIONS(5686),
    [anon_sym__Nonnull] = ACTIONS(5686),
    [anon_sym_mutable] = ACTIONS(5686),
    [anon_sym_constinit] = ACTIONS(5686),
    [anon_sym_consteval] = ACTIONS(5686),
    [anon_sym___shared__] = ACTIONS(5686),
    [anon_sym___local__] = ACTIONS(5686),
    [anon_sym___constant__] = ACTIONS(5686),
    [anon_sym___managed__] = ACTIONS(5686),
    [anon_sym___grid_constant__] = ACTIONS(5686),
    [anon_sym_alignas] = ACTIONS(5686),
    [anon_sym__Alignas] = ACTIONS(5686),
    [anon_sym_asm] = ACTIONS(5686),
    [anon_sym___asm__] = ACTIONS(5686),
    [anon_sym___asm] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5686),
    [anon_sym_decltype] = ACTIONS(5686),
    [anon_sym_final] = ACTIONS(5686),
    [anon_sym_override] = ACTIONS(5686),
    [anon_sym_GT2] = ACTIONS(5686),
    [anon_sym_try] = ACTIONS(5686),
    [anon_sym_requires] = ACTIONS(5686),
    [anon_sym___launch_bounds__] = ACTIONS(5686),
  },
  [STATE(2641)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5984),
    [anon_sym_COMMA] = ACTIONS(5984),
    [anon_sym_RPAREN] = ACTIONS(5984),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(5986),
    [anon_sym_PLUS] = ACTIONS(5986),
    [anon_sym_STAR] = ACTIONS(5986),
    [anon_sym_SLASH] = ACTIONS(5986),
    [anon_sym_PERCENT] = ACTIONS(5986),
    [anon_sym_PIPE_PIPE] = ACTIONS(5984),
    [anon_sym_AMP_AMP] = ACTIONS(5984),
    [anon_sym_PIPE] = ACTIONS(5986),
    [anon_sym_CARET] = ACTIONS(5986),
    [anon_sym_AMP] = ACTIONS(5986),
    [anon_sym_EQ_EQ] = ACTIONS(5984),
    [anon_sym_BANG_EQ] = ACTIONS(5984),
    [anon_sym_GT] = ACTIONS(5986),
    [anon_sym_GT_EQ] = ACTIONS(5984),
    [anon_sym_LT_EQ] = ACTIONS(5986),
    [anon_sym_LT] = ACTIONS(5986),
    [anon_sym_LT_LT] = ACTIONS(5986),
    [anon_sym_GT_GT] = ACTIONS(5986),
    [anon_sym_SEMI] = ACTIONS(5984),
    [anon_sym___attribute__] = ACTIONS(5984),
    [anon_sym___attribute] = ACTIONS(5986),
    [anon_sym_LBRACE] = ACTIONS(5984),
    [anon_sym_RBRACE] = ACTIONS(5984),
    [anon_sym_signed] = ACTIONS(6681),
    [anon_sym_unsigned] = ACTIONS(6681),
    [anon_sym_long] = ACTIONS(6681),
    [anon_sym_short] = ACTIONS(6681),
    [anon_sym_LBRACK] = ACTIONS(5984),
    [anon_sym_RBRACK] = ACTIONS(5984),
    [anon_sym_EQ] = ACTIONS(5986),
    [anon_sym_COLON] = ACTIONS(5984),
    [anon_sym_QMARK] = ACTIONS(5984),
    [anon_sym_STAR_EQ] = ACTIONS(5984),
    [anon_sym_SLASH_EQ] = ACTIONS(5984),
    [anon_sym_PERCENT_EQ] = ACTIONS(5984),
    [anon_sym_PLUS_EQ] = ACTIONS(5984),
    [anon_sym_DASH_EQ] = ACTIONS(5984),
    [anon_sym_LT_LT_EQ] = ACTIONS(5984),
    [anon_sym_GT_GT_EQ] = ACTIONS(5984),
    [anon_sym_AMP_EQ] = ACTIONS(5984),
    [anon_sym_CARET_EQ] = ACTIONS(5984),
    [anon_sym_PIPE_EQ] = ACTIONS(5984),
    [anon_sym_and_eq] = ACTIONS(5984),
    [anon_sym_or_eq] = ACTIONS(5984),
    [anon_sym_xor_eq] = ACTIONS(5984),
    [anon_sym_LT_EQ_GT] = ACTIONS(5984),
    [anon_sym_or] = ACTIONS(5986),
    [anon_sym_and] = ACTIONS(5986),
    [anon_sym_bitor] = ACTIONS(5984),
    [anon_sym_xor] = ACTIONS(5986),
    [anon_sym_bitand] = ACTIONS(5984),
    [anon_sym_not_eq] = ACTIONS(5984),
    [anon_sym_DASH_DASH] = ACTIONS(5984),
    [anon_sym_PLUS_PLUS] = ACTIONS(5984),
    [anon_sym_DOT] = ACTIONS(5986),
    [anon_sym_DOT_STAR] = ACTIONS(5984),
    [anon_sym_DASH_GT] = ACTIONS(5984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5984),
    [anon_sym_decltype] = ACTIONS(5984),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5984),
  },
  [STATE(2642)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5962),
    [anon_sym_COMMA] = ACTIONS(5962),
    [anon_sym_RPAREN] = ACTIONS(5962),
    [anon_sym_LPAREN2] = ACTIONS(5962),
    [anon_sym_DASH] = ACTIONS(5964),
    [anon_sym_PLUS] = ACTIONS(5964),
    [anon_sym_STAR] = ACTIONS(5964),
    [anon_sym_SLASH] = ACTIONS(5964),
    [anon_sym_PERCENT] = ACTIONS(5964),
    [anon_sym_PIPE_PIPE] = ACTIONS(5962),
    [anon_sym_AMP_AMP] = ACTIONS(5962),
    [anon_sym_PIPE] = ACTIONS(5964),
    [anon_sym_CARET] = ACTIONS(5964),
    [anon_sym_AMP] = ACTIONS(5964),
    [anon_sym_EQ_EQ] = ACTIONS(5962),
    [anon_sym_BANG_EQ] = ACTIONS(5962),
    [anon_sym_GT] = ACTIONS(5964),
    [anon_sym_GT_EQ] = ACTIONS(5962),
    [anon_sym_LT_EQ] = ACTIONS(5964),
    [anon_sym_LT] = ACTIONS(5964),
    [anon_sym_LT_LT] = ACTIONS(5964),
    [anon_sym_GT_GT] = ACTIONS(5964),
    [anon_sym_SEMI] = ACTIONS(5962),
    [anon_sym___attribute__] = ACTIONS(5962),
    [anon_sym___attribute] = ACTIONS(5964),
    [anon_sym_LBRACE] = ACTIONS(5962),
    [anon_sym_RBRACE] = ACTIONS(5962),
    [anon_sym_signed] = ACTIONS(6681),
    [anon_sym_unsigned] = ACTIONS(6681),
    [anon_sym_long] = ACTIONS(6681),
    [anon_sym_short] = ACTIONS(6681),
    [anon_sym_LBRACK] = ACTIONS(5962),
    [anon_sym_RBRACK] = ACTIONS(5962),
    [anon_sym_EQ] = ACTIONS(5964),
    [anon_sym_COLON] = ACTIONS(5962),
    [anon_sym_QMARK] = ACTIONS(5962),
    [anon_sym_STAR_EQ] = ACTIONS(5962),
    [anon_sym_SLASH_EQ] = ACTIONS(5962),
    [anon_sym_PERCENT_EQ] = ACTIONS(5962),
    [anon_sym_PLUS_EQ] = ACTIONS(5962),
    [anon_sym_DASH_EQ] = ACTIONS(5962),
    [anon_sym_LT_LT_EQ] = ACTIONS(5962),
    [anon_sym_GT_GT_EQ] = ACTIONS(5962),
    [anon_sym_AMP_EQ] = ACTIONS(5962),
    [anon_sym_CARET_EQ] = ACTIONS(5962),
    [anon_sym_PIPE_EQ] = ACTIONS(5962),
    [anon_sym_and_eq] = ACTIONS(5962),
    [anon_sym_or_eq] = ACTIONS(5962),
    [anon_sym_xor_eq] = ACTIONS(5962),
    [anon_sym_LT_EQ_GT] = ACTIONS(5962),
    [anon_sym_or] = ACTIONS(5964),
    [anon_sym_and] = ACTIONS(5964),
    [anon_sym_bitor] = ACTIONS(5962),
    [anon_sym_xor] = ACTIONS(5964),
    [anon_sym_bitand] = ACTIONS(5962),
    [anon_sym_not_eq] = ACTIONS(5962),
    [anon_sym_DASH_DASH] = ACTIONS(5962),
    [anon_sym_PLUS_PLUS] = ACTIONS(5962),
    [anon_sym_DOT] = ACTIONS(5964),
    [anon_sym_DOT_STAR] = ACTIONS(5962),
    [anon_sym_DASH_GT] = ACTIONS(5962),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5962),
    [anon_sym_decltype] = ACTIONS(5962),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5962),
  },
  [STATE(2643)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_friend] = ACTIONS(6722),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2644)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_friend] = ACTIONS(6724),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2645)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [anon_sym_COMMA] = ACTIONS(5898),
    [anon_sym_RPAREN] = ACTIONS(5898),
    [anon_sym_LPAREN2] = ACTIONS(5898),
    [anon_sym_STAR] = ACTIONS(5898),
    [anon_sym_AMP_AMP] = ACTIONS(5898),
    [anon_sym_AMP] = ACTIONS(5900),
    [anon_sym_SEMI] = ACTIONS(5898),
    [anon_sym___extension__] = ACTIONS(5898),
    [anon_sym___device__] = ACTIONS(5898),
    [anon_sym___host__] = ACTIONS(5898),
    [anon_sym___global__] = ACTIONS(5898),
    [anon_sym___forceinline__] = ACTIONS(5898),
    [anon_sym___noinline__] = ACTIONS(5898),
    [anon_sym_virtual] = ACTIONS(5898),
    [anon_sym_extern] = ACTIONS(5898),
    [anon_sym___attribute__] = ACTIONS(5898),
    [anon_sym___attribute] = ACTIONS(5900),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5898),
    [anon_sym___declspec] = ACTIONS(5898),
    [anon_sym_LBRACE] = ACTIONS(5898),
    [anon_sym_signed] = ACTIONS(6718),
    [anon_sym_unsigned] = ACTIONS(6718),
    [anon_sym_long] = ACTIONS(6718),
    [anon_sym_short] = ACTIONS(6718),
    [anon_sym_LBRACK] = ACTIONS(5900),
    [anon_sym_static] = ACTIONS(5898),
    [anon_sym_EQ] = ACTIONS(5898),
    [anon_sym_register] = ACTIONS(5898),
    [anon_sym_inline] = ACTIONS(5898),
    [anon_sym___inline] = ACTIONS(5900),
    [anon_sym___inline__] = ACTIONS(5898),
    [anon_sym___forceinline] = ACTIONS(5900),
    [anon_sym_thread_local] = ACTIONS(5898),
    [anon_sym___thread] = ACTIONS(5898),
    [anon_sym_const] = ACTIONS(5900),
    [anon_sym_constexpr] = ACTIONS(5898),
    [anon_sym_volatile] = ACTIONS(5898),
    [anon_sym_restrict] = ACTIONS(5898),
    [anon_sym___restrict__] = ACTIONS(5898),
    [anon_sym__Atomic] = ACTIONS(5898),
    [anon_sym__Noreturn] = ACTIONS(5898),
    [anon_sym_noreturn] = ACTIONS(5898),
    [anon_sym__Nonnull] = ACTIONS(5898),
    [anon_sym_mutable] = ACTIONS(5898),
    [anon_sym_constinit] = ACTIONS(5898),
    [anon_sym_consteval] = ACTIONS(5898),
    [anon_sym___shared__] = ACTIONS(5898),
    [anon_sym___local__] = ACTIONS(5898),
    [anon_sym___constant__] = ACTIONS(5898),
    [anon_sym___managed__] = ACTIONS(5898),
    [anon_sym___grid_constant__] = ACTIONS(5898),
    [anon_sym_alignas] = ACTIONS(5898),
    [anon_sym__Alignas] = ACTIONS(5898),
    [anon_sym_asm] = ACTIONS(5898),
    [anon_sym___asm__] = ACTIONS(5898),
    [anon_sym___asm] = ACTIONS(5900),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5898),
    [anon_sym_decltype] = ACTIONS(5898),
    [anon_sym_final] = ACTIONS(5898),
    [anon_sym_override] = ACTIONS(5898),
    [anon_sym_GT2] = ACTIONS(5898),
    [anon_sym_try] = ACTIONS(5898),
    [anon_sym_requires] = ACTIONS(5898),
    [anon_sym___launch_bounds__] = ACTIONS(5898),
  },
  [STATE(2646)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2647),
    [anon_sym_COMMA] = ACTIONS(5966),
    [anon_sym_RPAREN] = ACTIONS(5966),
    [anon_sym_LPAREN2] = ACTIONS(5966),
    [anon_sym_STAR] = ACTIONS(5966),
    [anon_sym_AMP_AMP] = ACTIONS(5966),
    [anon_sym_AMP] = ACTIONS(5968),
    [anon_sym_SEMI] = ACTIONS(5966),
    [anon_sym___extension__] = ACTIONS(5966),
    [anon_sym___device__] = ACTIONS(5966),
    [anon_sym___host__] = ACTIONS(5966),
    [anon_sym___global__] = ACTIONS(5966),
    [anon_sym___forceinline__] = ACTIONS(5966),
    [anon_sym___noinline__] = ACTIONS(5966),
    [anon_sym_virtual] = ACTIONS(5966),
    [anon_sym_extern] = ACTIONS(5966),
    [anon_sym___attribute__] = ACTIONS(5966),
    [anon_sym___attribute] = ACTIONS(5968),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5966),
    [anon_sym___declspec] = ACTIONS(5966),
    [anon_sym_LBRACE] = ACTIONS(5966),
    [anon_sym_signed] = ACTIONS(6726),
    [anon_sym_unsigned] = ACTIONS(6726),
    [anon_sym_long] = ACTIONS(6726),
    [anon_sym_short] = ACTIONS(6726),
    [anon_sym_LBRACK] = ACTIONS(5968),
    [anon_sym_static] = ACTIONS(5966),
    [anon_sym_EQ] = ACTIONS(5966),
    [anon_sym_register] = ACTIONS(5966),
    [anon_sym_inline] = ACTIONS(5966),
    [anon_sym___inline] = ACTIONS(5968),
    [anon_sym___inline__] = ACTIONS(5966),
    [anon_sym___forceinline] = ACTIONS(5968),
    [anon_sym_thread_local] = ACTIONS(5966),
    [anon_sym___thread] = ACTIONS(5966),
    [anon_sym_const] = ACTIONS(5968),
    [anon_sym_constexpr] = ACTIONS(5966),
    [anon_sym_volatile] = ACTIONS(5966),
    [anon_sym_restrict] = ACTIONS(5966),
    [anon_sym___restrict__] = ACTIONS(5966),
    [anon_sym__Atomic] = ACTIONS(5966),
    [anon_sym__Noreturn] = ACTIONS(5966),
    [anon_sym_noreturn] = ACTIONS(5966),
    [anon_sym__Nonnull] = ACTIONS(5966),
    [anon_sym_mutable] = ACTIONS(5966),
    [anon_sym_constinit] = ACTIONS(5966),
    [anon_sym_consteval] = ACTIONS(5966),
    [anon_sym___shared__] = ACTIONS(5966),
    [anon_sym___local__] = ACTIONS(5966),
    [anon_sym___constant__] = ACTIONS(5966),
    [anon_sym___managed__] = ACTIONS(5966),
    [anon_sym___grid_constant__] = ACTIONS(5966),
    [anon_sym_alignas] = ACTIONS(5966),
    [anon_sym__Alignas] = ACTIONS(5966),
    [anon_sym_asm] = ACTIONS(5966),
    [anon_sym___asm__] = ACTIONS(5966),
    [anon_sym___asm] = ACTIONS(5968),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5966),
    [anon_sym_decltype] = ACTIONS(5966),
    [anon_sym_final] = ACTIONS(5966),
    [anon_sym_override] = ACTIONS(5966),
    [anon_sym_GT2] = ACTIONS(5966),
    [anon_sym_try] = ACTIONS(5966),
    [anon_sym_requires] = ACTIONS(5966),
    [anon_sym___launch_bounds__] = ACTIONS(5966),
  },
  [STATE(2647)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [anon_sym_COMMA] = ACTIONS(6024),
    [anon_sym_RPAREN] = ACTIONS(6024),
    [anon_sym_LPAREN2] = ACTIONS(6024),
    [anon_sym_STAR] = ACTIONS(6024),
    [anon_sym_AMP_AMP] = ACTIONS(6024),
    [anon_sym_AMP] = ACTIONS(6026),
    [anon_sym_SEMI] = ACTIONS(6024),
    [anon_sym___extension__] = ACTIONS(6024),
    [anon_sym___device__] = ACTIONS(6024),
    [anon_sym___host__] = ACTIONS(6024),
    [anon_sym___global__] = ACTIONS(6024),
    [anon_sym___forceinline__] = ACTIONS(6024),
    [anon_sym___noinline__] = ACTIONS(6024),
    [anon_sym_virtual] = ACTIONS(6024),
    [anon_sym_extern] = ACTIONS(6024),
    [anon_sym___attribute__] = ACTIONS(6024),
    [anon_sym___attribute] = ACTIONS(6026),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6024),
    [anon_sym___declspec] = ACTIONS(6024),
    [anon_sym_LBRACE] = ACTIONS(6024),
    [anon_sym_signed] = ACTIONS(6718),
    [anon_sym_unsigned] = ACTIONS(6718),
    [anon_sym_long] = ACTIONS(6718),
    [anon_sym_short] = ACTIONS(6718),
    [anon_sym_LBRACK] = ACTIONS(6026),
    [anon_sym_static] = ACTIONS(6024),
    [anon_sym_EQ] = ACTIONS(6024),
    [anon_sym_register] = ACTIONS(6024),
    [anon_sym_inline] = ACTIONS(6024),
    [anon_sym___inline] = ACTIONS(6026),
    [anon_sym___inline__] = ACTIONS(6024),
    [anon_sym___forceinline] = ACTIONS(6026),
    [anon_sym_thread_local] = ACTIONS(6024),
    [anon_sym___thread] = ACTIONS(6024),
    [anon_sym_const] = ACTIONS(6026),
    [anon_sym_constexpr] = ACTIONS(6024),
    [anon_sym_volatile] = ACTIONS(6024),
    [anon_sym_restrict] = ACTIONS(6024),
    [anon_sym___restrict__] = ACTIONS(6024),
    [anon_sym__Atomic] = ACTIONS(6024),
    [anon_sym__Noreturn] = ACTIONS(6024),
    [anon_sym_noreturn] = ACTIONS(6024),
    [anon_sym__Nonnull] = ACTIONS(6024),
    [anon_sym_mutable] = ACTIONS(6024),
    [anon_sym_constinit] = ACTIONS(6024),
    [anon_sym_consteval] = ACTIONS(6024),
    [anon_sym___shared__] = ACTIONS(6024),
    [anon_sym___local__] = ACTIONS(6024),
    [anon_sym___constant__] = ACTIONS(6024),
    [anon_sym___managed__] = ACTIONS(6024),
    [anon_sym___grid_constant__] = ACTIONS(6024),
    [anon_sym_alignas] = ACTIONS(6024),
    [anon_sym__Alignas] = ACTIONS(6024),
    [anon_sym_asm] = ACTIONS(6024),
    [anon_sym___asm__] = ACTIONS(6024),
    [anon_sym___asm] = ACTIONS(6026),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6024),
    [anon_sym_decltype] = ACTIONS(6024),
    [anon_sym_final] = ACTIONS(6024),
    [anon_sym_override] = ACTIONS(6024),
    [anon_sym_GT2] = ACTIONS(6024),
    [anon_sym_try] = ACTIONS(6024),
    [anon_sym_requires] = ACTIONS(6024),
    [anon_sym___launch_bounds__] = ACTIONS(6024),
  },
  [STATE(2648)] = {
    [sym_identifier] = ACTIONS(6728),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6730),
    [anon_sym_COMMA] = ACTIONS(6730),
    [anon_sym_RPAREN] = ACTIONS(6730),
    [anon_sym_LPAREN2] = ACTIONS(6730),
    [anon_sym_TILDE] = ACTIONS(6730),
    [anon_sym_STAR] = ACTIONS(6730),
    [anon_sym_AMP_AMP] = ACTIONS(6730),
    [anon_sym_AMP] = ACTIONS(6728),
    [anon_sym_SEMI] = ACTIONS(6730),
    [anon_sym___extension__] = ACTIONS(6728),
    [anon_sym___device__] = ACTIONS(6728),
    [anon_sym___host__] = ACTIONS(6728),
    [anon_sym___global__] = ACTIONS(6728),
    [anon_sym___forceinline__] = ACTIONS(6728),
    [anon_sym___noinline__] = ACTIONS(6728),
    [anon_sym_virtual] = ACTIONS(6728),
    [anon_sym_extern] = ACTIONS(6728),
    [anon_sym___attribute__] = ACTIONS(6728),
    [anon_sym___attribute] = ACTIONS(6728),
    [anon_sym_COLON_COLON] = ACTIONS(6730),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6730),
    [anon_sym___declspec] = ACTIONS(6728),
    [anon_sym___based] = ACTIONS(6728),
    [anon_sym___cdecl] = ACTIONS(6728),
    [anon_sym___clrcall] = ACTIONS(6728),
    [anon_sym___stdcall] = ACTIONS(6728),
    [anon_sym___fastcall] = ACTIONS(6728),
    [anon_sym___thiscall] = ACTIONS(6728),
    [anon_sym___vectorcall] = ACTIONS(6728),
    [anon_sym_LBRACK] = ACTIONS(6728),
    [anon_sym_static] = ACTIONS(6728),
    [anon_sym_EQ] = ACTIONS(6730),
    [anon_sym_register] = ACTIONS(6728),
    [anon_sym_inline] = ACTIONS(6728),
    [anon_sym___inline] = ACTIONS(6728),
    [anon_sym___inline__] = ACTIONS(6728),
    [anon_sym___forceinline] = ACTIONS(6728),
    [anon_sym_thread_local] = ACTIONS(6728),
    [anon_sym___thread] = ACTIONS(6728),
    [anon_sym_const] = ACTIONS(6728),
    [anon_sym_constexpr] = ACTIONS(6728),
    [anon_sym_volatile] = ACTIONS(6728),
    [anon_sym_restrict] = ACTIONS(6728),
    [anon_sym___restrict__] = ACTIONS(6728),
    [anon_sym__Atomic] = ACTIONS(6728),
    [anon_sym__Noreturn] = ACTIONS(6728),
    [anon_sym_noreturn] = ACTIONS(6728),
    [anon_sym__Nonnull] = ACTIONS(6728),
    [anon_sym_mutable] = ACTIONS(6728),
    [anon_sym_constinit] = ACTIONS(6728),
    [anon_sym_consteval] = ACTIONS(6728),
    [anon_sym___shared__] = ACTIONS(6728),
    [anon_sym___local__] = ACTIONS(6728),
    [anon_sym___constant__] = ACTIONS(6728),
    [anon_sym___managed__] = ACTIONS(6728),
    [anon_sym___grid_constant__] = ACTIONS(6728),
    [anon_sym_alignas] = ACTIONS(6728),
    [anon_sym__Alignas] = ACTIONS(6728),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6728),
    [anon_sym_explicit] = ACTIONS(6728),
    [anon_sym_template] = ACTIONS(6728),
    [anon_sym_GT2] = ACTIONS(6730),
    [anon_sym_operator] = ACTIONS(6728),
    [anon_sym___launch_bounds__] = ACTIONS(6728),
  },
  [STATE(2649)] = {
    [sym_identifier] = ACTIONS(6732),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6734),
    [anon_sym_COMMA] = ACTIONS(6734),
    [anon_sym_RPAREN] = ACTIONS(6734),
    [anon_sym_LPAREN2] = ACTIONS(6734),
    [anon_sym_TILDE] = ACTIONS(6734),
    [anon_sym_STAR] = ACTIONS(6734),
    [anon_sym_AMP_AMP] = ACTIONS(6734),
    [anon_sym_AMP] = ACTIONS(6732),
    [anon_sym_SEMI] = ACTIONS(6734),
    [anon_sym___extension__] = ACTIONS(6732),
    [anon_sym___device__] = ACTIONS(6732),
    [anon_sym___host__] = ACTIONS(6732),
    [anon_sym___global__] = ACTIONS(6732),
    [anon_sym___forceinline__] = ACTIONS(6732),
    [anon_sym___noinline__] = ACTIONS(6732),
    [anon_sym_virtual] = ACTIONS(6732),
    [anon_sym_extern] = ACTIONS(6732),
    [anon_sym___attribute__] = ACTIONS(6732),
    [anon_sym___attribute] = ACTIONS(6732),
    [anon_sym_COLON_COLON] = ACTIONS(6734),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6734),
    [anon_sym___declspec] = ACTIONS(6732),
    [anon_sym___based] = ACTIONS(6732),
    [anon_sym___cdecl] = ACTIONS(6732),
    [anon_sym___clrcall] = ACTIONS(6732),
    [anon_sym___stdcall] = ACTIONS(6732),
    [anon_sym___fastcall] = ACTIONS(6732),
    [anon_sym___thiscall] = ACTIONS(6732),
    [anon_sym___vectorcall] = ACTIONS(6732),
    [anon_sym_LBRACK] = ACTIONS(6732),
    [anon_sym_static] = ACTIONS(6732),
    [anon_sym_EQ] = ACTIONS(6734),
    [anon_sym_register] = ACTIONS(6732),
    [anon_sym_inline] = ACTIONS(6732),
    [anon_sym___inline] = ACTIONS(6732),
    [anon_sym___inline__] = ACTIONS(6732),
    [anon_sym___forceinline] = ACTIONS(6732),
    [anon_sym_thread_local] = ACTIONS(6732),
    [anon_sym___thread] = ACTIONS(6732),
    [anon_sym_const] = ACTIONS(6732),
    [anon_sym_constexpr] = ACTIONS(6732),
    [anon_sym_volatile] = ACTIONS(6732),
    [anon_sym_restrict] = ACTIONS(6732),
    [anon_sym___restrict__] = ACTIONS(6732),
    [anon_sym__Atomic] = ACTIONS(6732),
    [anon_sym__Noreturn] = ACTIONS(6732),
    [anon_sym_noreturn] = ACTIONS(6732),
    [anon_sym__Nonnull] = ACTIONS(6732),
    [anon_sym_mutable] = ACTIONS(6732),
    [anon_sym_constinit] = ACTIONS(6732),
    [anon_sym_consteval] = ACTIONS(6732),
    [anon_sym___shared__] = ACTIONS(6732),
    [anon_sym___local__] = ACTIONS(6732),
    [anon_sym___constant__] = ACTIONS(6732),
    [anon_sym___managed__] = ACTIONS(6732),
    [anon_sym___grid_constant__] = ACTIONS(6732),
    [anon_sym_alignas] = ACTIONS(6732),
    [anon_sym__Alignas] = ACTIONS(6732),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6732),
    [anon_sym_explicit] = ACTIONS(6732),
    [anon_sym_template] = ACTIONS(6732),
    [anon_sym_GT2] = ACTIONS(6734),
    [anon_sym_operator] = ACTIONS(6732),
    [anon_sym___launch_bounds__] = ACTIONS(6732),
  },
  [STATE(2650)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [anon_sym_COMMA] = ACTIONS(5962),
    [anon_sym_RPAREN] = ACTIONS(5962),
    [anon_sym_LPAREN2] = ACTIONS(5962),
    [anon_sym_STAR] = ACTIONS(5962),
    [anon_sym_AMP_AMP] = ACTIONS(5962),
    [anon_sym_AMP] = ACTIONS(5964),
    [anon_sym_SEMI] = ACTIONS(5962),
    [anon_sym___extension__] = ACTIONS(5962),
    [anon_sym___device__] = ACTIONS(5962),
    [anon_sym___host__] = ACTIONS(5962),
    [anon_sym___global__] = ACTIONS(5962),
    [anon_sym___forceinline__] = ACTIONS(5962),
    [anon_sym___noinline__] = ACTIONS(5962),
    [anon_sym_virtual] = ACTIONS(5962),
    [anon_sym_extern] = ACTIONS(5962),
    [anon_sym___attribute__] = ACTIONS(5962),
    [anon_sym___attribute] = ACTIONS(5964),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5962),
    [anon_sym___declspec] = ACTIONS(5962),
    [anon_sym_LBRACE] = ACTIONS(5962),
    [anon_sym_signed] = ACTIONS(6718),
    [anon_sym_unsigned] = ACTIONS(6718),
    [anon_sym_long] = ACTIONS(6718),
    [anon_sym_short] = ACTIONS(6718),
    [anon_sym_LBRACK] = ACTIONS(5964),
    [anon_sym_static] = ACTIONS(5962),
    [anon_sym_EQ] = ACTIONS(5962),
    [anon_sym_register] = ACTIONS(5962),
    [anon_sym_inline] = ACTIONS(5962),
    [anon_sym___inline] = ACTIONS(5964),
    [anon_sym___inline__] = ACTIONS(5962),
    [anon_sym___forceinline] = ACTIONS(5964),
    [anon_sym_thread_local] = ACTIONS(5962),
    [anon_sym___thread] = ACTIONS(5962),
    [anon_sym_const] = ACTIONS(5964),
    [anon_sym_constexpr] = ACTIONS(5962),
    [anon_sym_volatile] = ACTIONS(5962),
    [anon_sym_restrict] = ACTIONS(5962),
    [anon_sym___restrict__] = ACTIONS(5962),
    [anon_sym__Atomic] = ACTIONS(5962),
    [anon_sym__Noreturn] = ACTIONS(5962),
    [anon_sym_noreturn] = ACTIONS(5962),
    [anon_sym__Nonnull] = ACTIONS(5962),
    [anon_sym_mutable] = ACTIONS(5962),
    [anon_sym_constinit] = ACTIONS(5962),
    [anon_sym_consteval] = ACTIONS(5962),
    [anon_sym___shared__] = ACTIONS(5962),
    [anon_sym___local__] = ACTIONS(5962),
    [anon_sym___constant__] = ACTIONS(5962),
    [anon_sym___managed__] = ACTIONS(5962),
    [anon_sym___grid_constant__] = ACTIONS(5962),
    [anon_sym_alignas] = ACTIONS(5962),
    [anon_sym__Alignas] = ACTIONS(5962),
    [anon_sym_asm] = ACTIONS(5962),
    [anon_sym___asm__] = ACTIONS(5962),
    [anon_sym___asm] = ACTIONS(5964),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5962),
    [anon_sym_decltype] = ACTIONS(5962),
    [anon_sym_final] = ACTIONS(5962),
    [anon_sym_override] = ACTIONS(5962),
    [anon_sym_GT2] = ACTIONS(5962),
    [anon_sym_try] = ACTIONS(5962),
    [anon_sym_requires] = ACTIONS(5962),
    [anon_sym___launch_bounds__] = ACTIONS(5962),
  },
  [STATE(2651)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym__declarator] = STATE(6954),
    [sym__abstract_declarator] = STATE(7275),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(4415),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3083),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(4415),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(6512),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(6078),
    [anon_sym_AMP_AMP] = ACTIONS(6080),
    [anon_sym_AMP] = ACTIONS(6082),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(6514),
    [anon_sym___attribute] = ACTIONS(6514),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(6512),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2652)] = {
    [sym_attribute_specifier] = STATE(2247),
    [sym_field_declaration_list] = STATE(2909),
    [sym_virtual_specifier] = STATE(7744),
    [sym_base_class_clause] = STATE(8540),
    [anon_sym_COMMA] = ACTIONS(6036),
    [anon_sym_RPAREN] = ACTIONS(6036),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_STAR] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6036),
    [anon_sym___extension__] = ACTIONS(6036),
    [anon_sym___device__] = ACTIONS(6036),
    [anon_sym___host__] = ACTIONS(6036),
    [anon_sym___global__] = ACTIONS(6036),
    [anon_sym___forceinline__] = ACTIONS(6036),
    [anon_sym___noinline__] = ACTIONS(6036),
    [anon_sym_virtual] = ACTIONS(6036),
    [anon_sym_extern] = ACTIONS(6036),
    [anon_sym___attribute__] = ACTIONS(6736),
    [anon_sym___attribute] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6036),
    [anon_sym___declspec] = ACTIONS(6036),
    [anon_sym_LBRACE] = ACTIONS(6147),
    [anon_sym_LBRACK] = ACTIONS(6038),
    [anon_sym_static] = ACTIONS(6036),
    [anon_sym_EQ] = ACTIONS(6036),
    [anon_sym_register] = ACTIONS(6036),
    [anon_sym_inline] = ACTIONS(6036),
    [anon_sym___inline] = ACTIONS(6038),
    [anon_sym___inline__] = ACTIONS(6036),
    [anon_sym___forceinline] = ACTIONS(6038),
    [anon_sym_thread_local] = ACTIONS(6036),
    [anon_sym___thread] = ACTIONS(6036),
    [anon_sym_const] = ACTIONS(6038),
    [anon_sym_constexpr] = ACTIONS(6036),
    [anon_sym_volatile] = ACTIONS(6036),
    [anon_sym_restrict] = ACTIONS(6036),
    [anon_sym___restrict__] = ACTIONS(6036),
    [anon_sym__Atomic] = ACTIONS(6036),
    [anon_sym__Noreturn] = ACTIONS(6036),
    [anon_sym_noreturn] = ACTIONS(6036),
    [anon_sym__Nonnull] = ACTIONS(6036),
    [anon_sym_mutable] = ACTIONS(6036),
    [anon_sym_constinit] = ACTIONS(6036),
    [anon_sym_consteval] = ACTIONS(6036),
    [anon_sym___shared__] = ACTIONS(6036),
    [anon_sym___local__] = ACTIONS(6036),
    [anon_sym___constant__] = ACTIONS(6036),
    [anon_sym___managed__] = ACTIONS(6036),
    [anon_sym___grid_constant__] = ACTIONS(6036),
    [anon_sym_alignas] = ACTIONS(6036),
    [anon_sym__Alignas] = ACTIONS(6036),
    [anon_sym_COLON] = ACTIONS(6046),
    [anon_sym_asm] = ACTIONS(6036),
    [anon_sym___asm__] = ACTIONS(6036),
    [anon_sym___asm] = ACTIONS(6038),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6036),
    [anon_sym_decltype] = ACTIONS(6036),
    [anon_sym_final] = ACTIONS(6048),
    [anon_sym_override] = ACTIONS(6048),
    [anon_sym_GT2] = ACTIONS(6036),
    [anon_sym_try] = ACTIONS(6036),
    [anon_sym_requires] = ACTIONS(6036),
    [anon_sym___launch_bounds__] = ACTIONS(6036),
  },
  [STATE(2653)] = {
    [sym_new_declarator] = STATE(2723),
    [sym_identifier] = ACTIONS(6738),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6740),
    [anon_sym_COMMA] = ACTIONS(6740),
    [anon_sym_RPAREN] = ACTIONS(6740),
    [aux_sym_preproc_if_token2] = ACTIONS(6740),
    [aux_sym_preproc_else_token1] = ACTIONS(6740),
    [aux_sym_preproc_elif_token1] = ACTIONS(6738),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6740),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6740),
    [anon_sym_LPAREN2] = ACTIONS(6740),
    [anon_sym_DASH] = ACTIONS(6738),
    [anon_sym_PLUS] = ACTIONS(6738),
    [anon_sym_STAR] = ACTIONS(6738),
    [anon_sym_SLASH] = ACTIONS(6738),
    [anon_sym_PERCENT] = ACTIONS(6738),
    [anon_sym_PIPE_PIPE] = ACTIONS(6740),
    [anon_sym_AMP_AMP] = ACTIONS(6740),
    [anon_sym_PIPE] = ACTIONS(6738),
    [anon_sym_CARET] = ACTIONS(6738),
    [anon_sym_AMP] = ACTIONS(6738),
    [anon_sym_EQ_EQ] = ACTIONS(6740),
    [anon_sym_BANG_EQ] = ACTIONS(6740),
    [anon_sym_GT] = ACTIONS(6738),
    [anon_sym_GT_EQ] = ACTIONS(6740),
    [anon_sym_LT_EQ] = ACTIONS(6738),
    [anon_sym_LT] = ACTIONS(6738),
    [anon_sym_LT_LT] = ACTIONS(6738),
    [anon_sym_GT_GT] = ACTIONS(6738),
    [anon_sym_SEMI] = ACTIONS(6740),
    [anon_sym___attribute__] = ACTIONS(6738),
    [anon_sym___attribute] = ACTIONS(6738),
    [anon_sym_LBRACE] = ACTIONS(6740),
    [anon_sym_RBRACE] = ACTIONS(6740),
    [anon_sym_LBRACK] = ACTIONS(6311),
    [anon_sym_RBRACK] = ACTIONS(6740),
    [anon_sym_EQ] = ACTIONS(6738),
    [anon_sym_COLON] = ACTIONS(6740),
    [anon_sym_QMARK] = ACTIONS(6740),
    [anon_sym_STAR_EQ] = ACTIONS(6740),
    [anon_sym_SLASH_EQ] = ACTIONS(6740),
    [anon_sym_PERCENT_EQ] = ACTIONS(6740),
    [anon_sym_PLUS_EQ] = ACTIONS(6740),
    [anon_sym_DASH_EQ] = ACTIONS(6740),
    [anon_sym_LT_LT_EQ] = ACTIONS(6740),
    [anon_sym_GT_GT_EQ] = ACTIONS(6740),
    [anon_sym_AMP_EQ] = ACTIONS(6740),
    [anon_sym_CARET_EQ] = ACTIONS(6740),
    [anon_sym_PIPE_EQ] = ACTIONS(6740),
    [anon_sym_and_eq] = ACTIONS(6738),
    [anon_sym_or_eq] = ACTIONS(6738),
    [anon_sym_xor_eq] = ACTIONS(6738),
    [anon_sym_LT_EQ_GT] = ACTIONS(6740),
    [anon_sym_or] = ACTIONS(6738),
    [anon_sym_and] = ACTIONS(6738),
    [anon_sym_bitor] = ACTIONS(6738),
    [anon_sym_xor] = ACTIONS(6738),
    [anon_sym_bitand] = ACTIONS(6738),
    [anon_sym_not_eq] = ACTIONS(6738),
    [anon_sym_DASH_DASH] = ACTIONS(6740),
    [anon_sym_PLUS_PLUS] = ACTIONS(6740),
    [anon_sym_DOT] = ACTIONS(6738),
    [anon_sym_DOT_STAR] = ACTIONS(6740),
    [anon_sym_DASH_GT] = ACTIONS(6740),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6740),
  },
  [STATE(2654)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [anon_sym_COMMA] = ACTIONS(5984),
    [anon_sym_RPAREN] = ACTIONS(5984),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_STAR] = ACTIONS(5984),
    [anon_sym_AMP_AMP] = ACTIONS(5984),
    [anon_sym_AMP] = ACTIONS(5986),
    [anon_sym_SEMI] = ACTIONS(5984),
    [anon_sym___extension__] = ACTIONS(5984),
    [anon_sym___device__] = ACTIONS(5984),
    [anon_sym___host__] = ACTIONS(5984),
    [anon_sym___global__] = ACTIONS(5984),
    [anon_sym___forceinline__] = ACTIONS(5984),
    [anon_sym___noinline__] = ACTIONS(5984),
    [anon_sym_virtual] = ACTIONS(5984),
    [anon_sym_extern] = ACTIONS(5984),
    [anon_sym___attribute__] = ACTIONS(5984),
    [anon_sym___attribute] = ACTIONS(5986),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5984),
    [anon_sym___declspec] = ACTIONS(5984),
    [anon_sym_LBRACE] = ACTIONS(5984),
    [anon_sym_signed] = ACTIONS(6718),
    [anon_sym_unsigned] = ACTIONS(6718),
    [anon_sym_long] = ACTIONS(6718),
    [anon_sym_short] = ACTIONS(6718),
    [anon_sym_LBRACK] = ACTIONS(5986),
    [anon_sym_static] = ACTIONS(5984),
    [anon_sym_EQ] = ACTIONS(5984),
    [anon_sym_register] = ACTIONS(5984),
    [anon_sym_inline] = ACTIONS(5984),
    [anon_sym___inline] = ACTIONS(5986),
    [anon_sym___inline__] = ACTIONS(5984),
    [anon_sym___forceinline] = ACTIONS(5986),
    [anon_sym_thread_local] = ACTIONS(5984),
    [anon_sym___thread] = ACTIONS(5984),
    [anon_sym_const] = ACTIONS(5986),
    [anon_sym_constexpr] = ACTIONS(5984),
    [anon_sym_volatile] = ACTIONS(5984),
    [anon_sym_restrict] = ACTIONS(5984),
    [anon_sym___restrict__] = ACTIONS(5984),
    [anon_sym__Atomic] = ACTIONS(5984),
    [anon_sym__Noreturn] = ACTIONS(5984),
    [anon_sym_noreturn] = ACTIONS(5984),
    [anon_sym__Nonnull] = ACTIONS(5984),
    [anon_sym_mutable] = ACTIONS(5984),
    [anon_sym_constinit] = ACTIONS(5984),
    [anon_sym_consteval] = ACTIONS(5984),
    [anon_sym___shared__] = ACTIONS(5984),
    [anon_sym___local__] = ACTIONS(5984),
    [anon_sym___constant__] = ACTIONS(5984),
    [anon_sym___managed__] = ACTIONS(5984),
    [anon_sym___grid_constant__] = ACTIONS(5984),
    [anon_sym_alignas] = ACTIONS(5984),
    [anon_sym__Alignas] = ACTIONS(5984),
    [anon_sym_asm] = ACTIONS(5984),
    [anon_sym___asm__] = ACTIONS(5984),
    [anon_sym___asm] = ACTIONS(5986),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5984),
    [anon_sym_decltype] = ACTIONS(5984),
    [anon_sym_final] = ACTIONS(5984),
    [anon_sym_override] = ACTIONS(5984),
    [anon_sym_GT2] = ACTIONS(5984),
    [anon_sym_try] = ACTIONS(5984),
    [anon_sym_requires] = ACTIONS(5984),
    [anon_sym___launch_bounds__] = ACTIONS(5984),
  },
  [STATE(2655)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5980),
    [anon_sym_COMMA] = ACTIONS(5980),
    [anon_sym_RPAREN] = ACTIONS(5980),
    [anon_sym_LPAREN2] = ACTIONS(5980),
    [anon_sym_DASH] = ACTIONS(5982),
    [anon_sym_PLUS] = ACTIONS(5982),
    [anon_sym_STAR] = ACTIONS(5982),
    [anon_sym_SLASH] = ACTIONS(5982),
    [anon_sym_PERCENT] = ACTIONS(5982),
    [anon_sym_PIPE_PIPE] = ACTIONS(5980),
    [anon_sym_AMP_AMP] = ACTIONS(5980),
    [anon_sym_PIPE] = ACTIONS(5982),
    [anon_sym_CARET] = ACTIONS(5982),
    [anon_sym_AMP] = ACTIONS(5982),
    [anon_sym_EQ_EQ] = ACTIONS(5980),
    [anon_sym_BANG_EQ] = ACTIONS(5980),
    [anon_sym_GT] = ACTIONS(5982),
    [anon_sym_GT_EQ] = ACTIONS(5980),
    [anon_sym_LT_EQ] = ACTIONS(5982),
    [anon_sym_LT] = ACTIONS(5982),
    [anon_sym_LT_LT] = ACTIONS(5982),
    [anon_sym_GT_GT] = ACTIONS(5982),
    [anon_sym_SEMI] = ACTIONS(5980),
    [anon_sym___attribute__] = ACTIONS(5980),
    [anon_sym___attribute] = ACTIONS(5982),
    [anon_sym_LBRACE] = ACTIONS(5980),
    [anon_sym_RBRACE] = ACTIONS(5980),
    [anon_sym_signed] = ACTIONS(6681),
    [anon_sym_unsigned] = ACTIONS(6681),
    [anon_sym_long] = ACTIONS(6681),
    [anon_sym_short] = ACTIONS(6681),
    [anon_sym_LBRACK] = ACTIONS(5980),
    [anon_sym_RBRACK] = ACTIONS(5980),
    [anon_sym_EQ] = ACTIONS(5982),
    [anon_sym_COLON] = ACTIONS(5980),
    [anon_sym_QMARK] = ACTIONS(5980),
    [anon_sym_STAR_EQ] = ACTIONS(5980),
    [anon_sym_SLASH_EQ] = ACTIONS(5980),
    [anon_sym_PERCENT_EQ] = ACTIONS(5980),
    [anon_sym_PLUS_EQ] = ACTIONS(5980),
    [anon_sym_DASH_EQ] = ACTIONS(5980),
    [anon_sym_LT_LT_EQ] = ACTIONS(5980),
    [anon_sym_GT_GT_EQ] = ACTIONS(5980),
    [anon_sym_AMP_EQ] = ACTIONS(5980),
    [anon_sym_CARET_EQ] = ACTIONS(5980),
    [anon_sym_PIPE_EQ] = ACTIONS(5980),
    [anon_sym_and_eq] = ACTIONS(5980),
    [anon_sym_or_eq] = ACTIONS(5980),
    [anon_sym_xor_eq] = ACTIONS(5980),
    [anon_sym_LT_EQ_GT] = ACTIONS(5980),
    [anon_sym_or] = ACTIONS(5982),
    [anon_sym_and] = ACTIONS(5982),
    [anon_sym_bitor] = ACTIONS(5980),
    [anon_sym_xor] = ACTIONS(5982),
    [anon_sym_bitand] = ACTIONS(5980),
    [anon_sym_not_eq] = ACTIONS(5980),
    [anon_sym_DASH_DASH] = ACTIONS(5980),
    [anon_sym_PLUS_PLUS] = ACTIONS(5980),
    [anon_sym_DOT] = ACTIONS(5982),
    [anon_sym_DOT_STAR] = ACTIONS(5980),
    [anon_sym_DASH_GT] = ACTIONS(5980),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5980),
    [anon_sym_decltype] = ACTIONS(5980),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5980),
  },
  [STATE(2656)] = {
    [sym_attribute_specifier] = STATE(2246),
    [sym_enumerator_list] = STATE(2553),
    [sym__enum_base_clause] = STATE(2416),
    [sym_identifier] = ACTIONS(6677),
    [anon_sym_LPAREN2] = ACTIONS(6679),
    [anon_sym_TILDE] = ACTIONS(6679),
    [anon_sym_STAR] = ACTIONS(6679),
    [anon_sym_AMP_AMP] = ACTIONS(6679),
    [anon_sym_AMP] = ACTIONS(6677),
    [anon_sym_SEMI] = ACTIONS(6679),
    [anon_sym___extension__] = ACTIONS(6677),
    [anon_sym___device__] = ACTIONS(6677),
    [anon_sym___host__] = ACTIONS(6677),
    [anon_sym___global__] = ACTIONS(6677),
    [anon_sym___forceinline__] = ACTIONS(6677),
    [anon_sym___noinline__] = ACTIONS(6677),
    [anon_sym_virtual] = ACTIONS(6677),
    [anon_sym_extern] = ACTIONS(6677),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6679),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6679),
    [anon_sym___declspec] = ACTIONS(6677),
    [anon_sym___based] = ACTIONS(6677),
    [anon_sym___cdecl] = ACTIONS(6677),
    [anon_sym___clrcall] = ACTIONS(6677),
    [anon_sym___stdcall] = ACTIONS(6677),
    [anon_sym___fastcall] = ACTIONS(6677),
    [anon_sym___thiscall] = ACTIONS(6677),
    [anon_sym___vectorcall] = ACTIONS(6677),
    [anon_sym_LBRACE] = ACTIONS(6360),
    [anon_sym_LBRACK] = ACTIONS(6677),
    [anon_sym_static] = ACTIONS(6677),
    [anon_sym_register] = ACTIONS(6677),
    [anon_sym_inline] = ACTIONS(6677),
    [anon_sym___inline] = ACTIONS(6677),
    [anon_sym___inline__] = ACTIONS(6677),
    [anon_sym___forceinline] = ACTIONS(6677),
    [anon_sym_thread_local] = ACTIONS(6677),
    [anon_sym___thread] = ACTIONS(6677),
    [anon_sym_const] = ACTIONS(6677),
    [anon_sym_constexpr] = ACTIONS(6677),
    [anon_sym_volatile] = ACTIONS(6677),
    [anon_sym_restrict] = ACTIONS(6677),
    [anon_sym___restrict__] = ACTIONS(6677),
    [anon_sym__Atomic] = ACTIONS(6677),
    [anon_sym__Noreturn] = ACTIONS(6677),
    [anon_sym_noreturn] = ACTIONS(6677),
    [anon_sym__Nonnull] = ACTIONS(6677),
    [anon_sym_mutable] = ACTIONS(6677),
    [anon_sym_constinit] = ACTIONS(6677),
    [anon_sym_consteval] = ACTIONS(6677),
    [anon_sym___shared__] = ACTIONS(6677),
    [anon_sym___local__] = ACTIONS(6677),
    [anon_sym___constant__] = ACTIONS(6677),
    [anon_sym___managed__] = ACTIONS(6677),
    [anon_sym___grid_constant__] = ACTIONS(6677),
    [anon_sym_alignas] = ACTIONS(6677),
    [anon_sym__Alignas] = ACTIONS(6677),
    [anon_sym_COLON] = ACTIONS(6742),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6677),
    [anon_sym_decltype] = ACTIONS(6677),
    [anon_sym_template] = ACTIONS(6677),
    [anon_sym_operator] = ACTIONS(6677),
    [anon_sym___launch_bounds__] = ACTIONS(6677),
  },
  [STATE(2657)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym__declarator] = STATE(6947),
    [sym__abstract_declarator] = STATE(7265),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(4415),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3083),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(4415),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(5925),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(6078),
    [anon_sym_AMP_AMP] = ACTIONS(6080),
    [anon_sym_AMP] = ACTIONS(6082),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(5933),
    [anon_sym___attribute] = ACTIONS(5933),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_GT2] = ACTIONS(5925),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2658)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_friend] = ACTIONS(6744),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2659)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2655),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5988),
    [anon_sym_COMMA] = ACTIONS(5988),
    [anon_sym_RPAREN] = ACTIONS(5988),
    [anon_sym_LPAREN2] = ACTIONS(5988),
    [anon_sym_DASH] = ACTIONS(5990),
    [anon_sym_PLUS] = ACTIONS(5990),
    [anon_sym_STAR] = ACTIONS(5990),
    [anon_sym_SLASH] = ACTIONS(5990),
    [anon_sym_PERCENT] = ACTIONS(5990),
    [anon_sym_PIPE_PIPE] = ACTIONS(5988),
    [anon_sym_AMP_AMP] = ACTIONS(5988),
    [anon_sym_PIPE] = ACTIONS(5990),
    [anon_sym_CARET] = ACTIONS(5990),
    [anon_sym_AMP] = ACTIONS(5990),
    [anon_sym_EQ_EQ] = ACTIONS(5988),
    [anon_sym_BANG_EQ] = ACTIONS(5988),
    [anon_sym_GT] = ACTIONS(5990),
    [anon_sym_GT_EQ] = ACTIONS(5988),
    [anon_sym_LT_EQ] = ACTIONS(5990),
    [anon_sym_LT] = ACTIONS(5990),
    [anon_sym_LT_LT] = ACTIONS(5990),
    [anon_sym_GT_GT] = ACTIONS(5990),
    [anon_sym_SEMI] = ACTIONS(5988),
    [anon_sym___attribute__] = ACTIONS(5988),
    [anon_sym___attribute] = ACTIONS(5990),
    [anon_sym_LBRACE] = ACTIONS(5988),
    [anon_sym_RBRACE] = ACTIONS(5988),
    [anon_sym_signed] = ACTIONS(6746),
    [anon_sym_unsigned] = ACTIONS(6746),
    [anon_sym_long] = ACTIONS(6746),
    [anon_sym_short] = ACTIONS(6746),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_RBRACK] = ACTIONS(5988),
    [anon_sym_EQ] = ACTIONS(5990),
    [anon_sym_COLON] = ACTIONS(5988),
    [anon_sym_QMARK] = ACTIONS(5988),
    [anon_sym_STAR_EQ] = ACTIONS(5988),
    [anon_sym_SLASH_EQ] = ACTIONS(5988),
    [anon_sym_PERCENT_EQ] = ACTIONS(5988),
    [anon_sym_PLUS_EQ] = ACTIONS(5988),
    [anon_sym_DASH_EQ] = ACTIONS(5988),
    [anon_sym_LT_LT_EQ] = ACTIONS(5988),
    [anon_sym_GT_GT_EQ] = ACTIONS(5988),
    [anon_sym_AMP_EQ] = ACTIONS(5988),
    [anon_sym_CARET_EQ] = ACTIONS(5988),
    [anon_sym_PIPE_EQ] = ACTIONS(5988),
    [anon_sym_and_eq] = ACTIONS(5988),
    [anon_sym_or_eq] = ACTIONS(5988),
    [anon_sym_xor_eq] = ACTIONS(5988),
    [anon_sym_LT_EQ_GT] = ACTIONS(5988),
    [anon_sym_or] = ACTIONS(5990),
    [anon_sym_and] = ACTIONS(5990),
    [anon_sym_bitor] = ACTIONS(5988),
    [anon_sym_xor] = ACTIONS(5990),
    [anon_sym_bitand] = ACTIONS(5988),
    [anon_sym_not_eq] = ACTIONS(5988),
    [anon_sym_DASH_DASH] = ACTIONS(5988),
    [anon_sym_PLUS_PLUS] = ACTIONS(5988),
    [anon_sym_DOT] = ACTIONS(5990),
    [anon_sym_DOT_STAR] = ACTIONS(5988),
    [anon_sym_DASH_GT] = ACTIONS(5988),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5988),
    [anon_sym_decltype] = ACTIONS(5988),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5988),
  },
  [STATE(2660)] = {
    [sym_identifier] = ACTIONS(6159),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6161),
    [anon_sym_COMMA] = ACTIONS(6161),
    [anon_sym_LPAREN2] = ACTIONS(6161),
    [anon_sym_DASH] = ACTIONS(6159),
    [anon_sym_PLUS] = ACTIONS(6159),
    [anon_sym_STAR] = ACTIONS(6159),
    [anon_sym_SLASH] = ACTIONS(6159),
    [anon_sym_PERCENT] = ACTIONS(6159),
    [anon_sym_PIPE_PIPE] = ACTIONS(6161),
    [anon_sym_AMP_AMP] = ACTIONS(6161),
    [anon_sym_PIPE] = ACTIONS(6159),
    [anon_sym_CARET] = ACTIONS(6159),
    [anon_sym_AMP] = ACTIONS(6159),
    [anon_sym_EQ_EQ] = ACTIONS(6161),
    [anon_sym_BANG_EQ] = ACTIONS(6161),
    [anon_sym_GT] = ACTIONS(6159),
    [anon_sym_GT_EQ] = ACTIONS(6161),
    [anon_sym_LT_EQ] = ACTIONS(6159),
    [anon_sym_LT] = ACTIONS(6159),
    [anon_sym_LT_LT] = ACTIONS(6159),
    [anon_sym_GT_GT] = ACTIONS(6159),
    [anon_sym_SEMI] = ACTIONS(6161),
    [anon_sym___attribute__] = ACTIONS(6159),
    [anon_sym___attribute] = ACTIONS(6159),
    [anon_sym_LBRACK] = ACTIONS(6161),
    [anon_sym_EQ] = ACTIONS(6159),
    [anon_sym_QMARK] = ACTIONS(6161),
    [anon_sym_STAR_EQ] = ACTIONS(6161),
    [anon_sym_SLASH_EQ] = ACTIONS(6161),
    [anon_sym_PERCENT_EQ] = ACTIONS(6161),
    [anon_sym_PLUS_EQ] = ACTIONS(6161),
    [anon_sym_DASH_EQ] = ACTIONS(6161),
    [anon_sym_LT_LT_EQ] = ACTIONS(6161),
    [anon_sym_GT_GT_EQ] = ACTIONS(6161),
    [anon_sym_AMP_EQ] = ACTIONS(6161),
    [anon_sym_CARET_EQ] = ACTIONS(6161),
    [anon_sym_PIPE_EQ] = ACTIONS(6161),
    [anon_sym_and_eq] = ACTIONS(6159),
    [anon_sym_or_eq] = ACTIONS(6159),
    [anon_sym_xor_eq] = ACTIONS(6159),
    [anon_sym_LT_EQ_GT] = ACTIONS(6161),
    [anon_sym_or] = ACTIONS(6159),
    [anon_sym_and] = ACTIONS(6159),
    [anon_sym_bitor] = ACTIONS(6159),
    [anon_sym_xor] = ACTIONS(6159),
    [anon_sym_bitand] = ACTIONS(6159),
    [anon_sym_not_eq] = ACTIONS(6159),
    [anon_sym_DASH_DASH] = ACTIONS(6161),
    [anon_sym_PLUS_PLUS] = ACTIONS(6161),
    [anon_sym_DOT] = ACTIONS(6159),
    [anon_sym_DOT_STAR] = ACTIONS(6161),
    [anon_sym_DASH_GT] = ACTIONS(6161),
    [anon_sym_L_DQUOTE] = ACTIONS(6161),
    [anon_sym_u_DQUOTE] = ACTIONS(6161),
    [anon_sym_U_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8_DQUOTE] = ACTIONS(6161),
    [anon_sym_DQUOTE] = ACTIONS(6161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6161),
    [anon_sym_LR_DQUOTE] = ACTIONS(6161),
    [anon_sym_uR_DQUOTE] = ACTIONS(6161),
    [anon_sym_UR_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6161),
    [sym_literal_suffix] = ACTIONS(6159),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6161),
  },
  [STATE(2661)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [anon_sym_COMMA] = ACTIONS(6010),
    [anon_sym_RPAREN] = ACTIONS(6010),
    [anon_sym_LPAREN2] = ACTIONS(6010),
    [anon_sym_STAR] = ACTIONS(6010),
    [anon_sym_AMP_AMP] = ACTIONS(6010),
    [anon_sym_AMP] = ACTIONS(6012),
    [anon_sym_SEMI] = ACTIONS(6010),
    [anon_sym___extension__] = ACTIONS(6010),
    [anon_sym___device__] = ACTIONS(6010),
    [anon_sym___host__] = ACTIONS(6010),
    [anon_sym___global__] = ACTIONS(6010),
    [anon_sym___forceinline__] = ACTIONS(6010),
    [anon_sym___noinline__] = ACTIONS(6010),
    [anon_sym_virtual] = ACTIONS(6010),
    [anon_sym_extern] = ACTIONS(6010),
    [anon_sym___attribute__] = ACTIONS(6010),
    [anon_sym___attribute] = ACTIONS(6012),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6010),
    [anon_sym___declspec] = ACTIONS(6010),
    [anon_sym_LBRACE] = ACTIONS(6010),
    [anon_sym_signed] = ACTIONS(6718),
    [anon_sym_unsigned] = ACTIONS(6718),
    [anon_sym_long] = ACTIONS(6718),
    [anon_sym_short] = ACTIONS(6718),
    [anon_sym_LBRACK] = ACTIONS(6012),
    [anon_sym_static] = ACTIONS(6010),
    [anon_sym_EQ] = ACTIONS(6010),
    [anon_sym_register] = ACTIONS(6010),
    [anon_sym_inline] = ACTIONS(6010),
    [anon_sym___inline] = ACTIONS(6012),
    [anon_sym___inline__] = ACTIONS(6010),
    [anon_sym___forceinline] = ACTIONS(6012),
    [anon_sym_thread_local] = ACTIONS(6010),
    [anon_sym___thread] = ACTIONS(6010),
    [anon_sym_const] = ACTIONS(6012),
    [anon_sym_constexpr] = ACTIONS(6010),
    [anon_sym_volatile] = ACTIONS(6010),
    [anon_sym_restrict] = ACTIONS(6010),
    [anon_sym___restrict__] = ACTIONS(6010),
    [anon_sym__Atomic] = ACTIONS(6010),
    [anon_sym__Noreturn] = ACTIONS(6010),
    [anon_sym_noreturn] = ACTIONS(6010),
    [anon_sym__Nonnull] = ACTIONS(6010),
    [anon_sym_mutable] = ACTIONS(6010),
    [anon_sym_constinit] = ACTIONS(6010),
    [anon_sym_consteval] = ACTIONS(6010),
    [anon_sym___shared__] = ACTIONS(6010),
    [anon_sym___local__] = ACTIONS(6010),
    [anon_sym___constant__] = ACTIONS(6010),
    [anon_sym___managed__] = ACTIONS(6010),
    [anon_sym___grid_constant__] = ACTIONS(6010),
    [anon_sym_alignas] = ACTIONS(6010),
    [anon_sym__Alignas] = ACTIONS(6010),
    [anon_sym_asm] = ACTIONS(6010),
    [anon_sym___asm__] = ACTIONS(6010),
    [anon_sym___asm] = ACTIONS(6012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6010),
    [anon_sym_decltype] = ACTIONS(6010),
    [anon_sym_final] = ACTIONS(6010),
    [anon_sym_override] = ACTIONS(6010),
    [anon_sym_GT2] = ACTIONS(6010),
    [anon_sym_try] = ACTIONS(6010),
    [anon_sym_requires] = ACTIONS(6010),
    [anon_sym___launch_bounds__] = ACTIONS(6010),
  },
  [STATE(2662)] = {
    [sym_argument_list] = STATE(2794),
    [sym_subscript_argument_list] = STATE(2795),
    [sym_kernel_call_syntax] = STATE(8417),
    [sym_identifier] = ACTIONS(6748),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6750),
    [anon_sym_COMMA] = ACTIONS(6750),
    [anon_sym_RPAREN] = ACTIONS(6750),
    [aux_sym_preproc_if_token2] = ACTIONS(6750),
    [aux_sym_preproc_else_token1] = ACTIONS(6750),
    [aux_sym_preproc_elif_token1] = ACTIONS(6748),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6750),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6750),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6748),
    [anon_sym_PLUS] = ACTIONS(6748),
    [anon_sym_STAR] = ACTIONS(6748),
    [anon_sym_SLASH] = ACTIONS(6748),
    [anon_sym_PERCENT] = ACTIONS(6748),
    [anon_sym_PIPE_PIPE] = ACTIONS(6750),
    [anon_sym_AMP_AMP] = ACTIONS(6750),
    [anon_sym_PIPE] = ACTIONS(6748),
    [anon_sym_CARET] = ACTIONS(6748),
    [anon_sym_AMP] = ACTIONS(6748),
    [anon_sym_EQ_EQ] = ACTIONS(6750),
    [anon_sym_BANG_EQ] = ACTIONS(6750),
    [anon_sym_GT] = ACTIONS(6748),
    [anon_sym_GT_EQ] = ACTIONS(6750),
    [anon_sym_LT_EQ] = ACTIONS(6748),
    [anon_sym_LT] = ACTIONS(6748),
    [anon_sym_LT_LT] = ACTIONS(6748),
    [anon_sym_GT_GT] = ACTIONS(6748),
    [anon_sym_SEMI] = ACTIONS(6750),
    [anon_sym___attribute__] = ACTIONS(6748),
    [anon_sym___attribute] = ACTIONS(6748),
    [anon_sym_RBRACE] = ACTIONS(6750),
    [anon_sym_LBRACK] = ACTIONS(6691),
    [anon_sym_RBRACK] = ACTIONS(6750),
    [anon_sym_EQ] = ACTIONS(6748),
    [anon_sym_QMARK] = ACTIONS(6750),
    [anon_sym_STAR_EQ] = ACTIONS(6750),
    [anon_sym_SLASH_EQ] = ACTIONS(6750),
    [anon_sym_PERCENT_EQ] = ACTIONS(6750),
    [anon_sym_PLUS_EQ] = ACTIONS(6750),
    [anon_sym_DASH_EQ] = ACTIONS(6750),
    [anon_sym_LT_LT_EQ] = ACTIONS(6750),
    [anon_sym_GT_GT_EQ] = ACTIONS(6750),
    [anon_sym_AMP_EQ] = ACTIONS(6750),
    [anon_sym_CARET_EQ] = ACTIONS(6750),
    [anon_sym_PIPE_EQ] = ACTIONS(6750),
    [anon_sym_and_eq] = ACTIONS(6748),
    [anon_sym_or_eq] = ACTIONS(6748),
    [anon_sym_xor_eq] = ACTIONS(6748),
    [anon_sym_LT_EQ_GT] = ACTIONS(6750),
    [anon_sym_or] = ACTIONS(6748),
    [anon_sym_and] = ACTIONS(6748),
    [anon_sym_bitor] = ACTIONS(6748),
    [anon_sym_xor] = ACTIONS(6748),
    [anon_sym_bitand] = ACTIONS(6748),
    [anon_sym_not_eq] = ACTIONS(6748),
    [anon_sym_DASH_DASH] = ACTIONS(6710),
    [anon_sym_PLUS_PLUS] = ACTIONS(6710),
    [anon_sym_DOT] = ACTIONS(6693),
    [anon_sym_DOT_STAR] = ACTIONS(6695),
    [anon_sym_DASH_GT] = ACTIONS(6695),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6750),
  },
  [STATE(2663)] = {
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6288),
    [anon_sym_COMMA] = ACTIONS(6288),
    [anon_sym_RPAREN] = ACTIONS(6288),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym_SEMI] = ACTIONS(6288),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym___cdecl] = ACTIONS(6286),
    [anon_sym___clrcall] = ACTIONS(6286),
    [anon_sym___stdcall] = ACTIONS(6286),
    [anon_sym___fastcall] = ACTIONS(6286),
    [anon_sym___thiscall] = ACTIONS(6286),
    [anon_sym___vectorcall] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_EQ] = ACTIONS(6288),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_GT2] = ACTIONS(6288),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2664)] = {
    [sym_identifier] = ACTIONS(6167),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6169),
    [anon_sym_COMMA] = ACTIONS(6169),
    [anon_sym_LPAREN2] = ACTIONS(6169),
    [anon_sym_DASH] = ACTIONS(6167),
    [anon_sym_PLUS] = ACTIONS(6167),
    [anon_sym_STAR] = ACTIONS(6167),
    [anon_sym_SLASH] = ACTIONS(6167),
    [anon_sym_PERCENT] = ACTIONS(6167),
    [anon_sym_PIPE_PIPE] = ACTIONS(6169),
    [anon_sym_AMP_AMP] = ACTIONS(6169),
    [anon_sym_PIPE] = ACTIONS(6167),
    [anon_sym_CARET] = ACTIONS(6167),
    [anon_sym_AMP] = ACTIONS(6167),
    [anon_sym_EQ_EQ] = ACTIONS(6169),
    [anon_sym_BANG_EQ] = ACTIONS(6169),
    [anon_sym_GT] = ACTIONS(6167),
    [anon_sym_GT_EQ] = ACTIONS(6169),
    [anon_sym_LT_EQ] = ACTIONS(6167),
    [anon_sym_LT] = ACTIONS(6167),
    [anon_sym_LT_LT] = ACTIONS(6167),
    [anon_sym_GT_GT] = ACTIONS(6167),
    [anon_sym_SEMI] = ACTIONS(6169),
    [anon_sym___attribute__] = ACTIONS(6167),
    [anon_sym___attribute] = ACTIONS(6167),
    [anon_sym_LBRACK] = ACTIONS(6169),
    [anon_sym_EQ] = ACTIONS(6167),
    [anon_sym_QMARK] = ACTIONS(6169),
    [anon_sym_STAR_EQ] = ACTIONS(6169),
    [anon_sym_SLASH_EQ] = ACTIONS(6169),
    [anon_sym_PERCENT_EQ] = ACTIONS(6169),
    [anon_sym_PLUS_EQ] = ACTIONS(6169),
    [anon_sym_DASH_EQ] = ACTIONS(6169),
    [anon_sym_LT_LT_EQ] = ACTIONS(6169),
    [anon_sym_GT_GT_EQ] = ACTIONS(6169),
    [anon_sym_AMP_EQ] = ACTIONS(6169),
    [anon_sym_CARET_EQ] = ACTIONS(6169),
    [anon_sym_PIPE_EQ] = ACTIONS(6169),
    [anon_sym_and_eq] = ACTIONS(6167),
    [anon_sym_or_eq] = ACTIONS(6167),
    [anon_sym_xor_eq] = ACTIONS(6167),
    [anon_sym_LT_EQ_GT] = ACTIONS(6169),
    [anon_sym_or] = ACTIONS(6167),
    [anon_sym_and] = ACTIONS(6167),
    [anon_sym_bitor] = ACTIONS(6167),
    [anon_sym_xor] = ACTIONS(6167),
    [anon_sym_bitand] = ACTIONS(6167),
    [anon_sym_not_eq] = ACTIONS(6167),
    [anon_sym_DASH_DASH] = ACTIONS(6169),
    [anon_sym_PLUS_PLUS] = ACTIONS(6169),
    [anon_sym_DOT] = ACTIONS(6167),
    [anon_sym_DOT_STAR] = ACTIONS(6169),
    [anon_sym_DASH_GT] = ACTIONS(6169),
    [anon_sym_L_DQUOTE] = ACTIONS(6169),
    [anon_sym_u_DQUOTE] = ACTIONS(6169),
    [anon_sym_U_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8_DQUOTE] = ACTIONS(6169),
    [anon_sym_DQUOTE] = ACTIONS(6169),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6169),
    [anon_sym_LR_DQUOTE] = ACTIONS(6169),
    [anon_sym_uR_DQUOTE] = ACTIONS(6169),
    [anon_sym_UR_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6169),
    [sym_literal_suffix] = ACTIONS(6167),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6169),
  },
  [STATE(2665)] = {
    [sym_template_argument_list] = STATE(2693),
    [sym_identifier] = ACTIONS(6752),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6754),
    [anon_sym_COMMA] = ACTIONS(6754),
    [anon_sym_RPAREN] = ACTIONS(6754),
    [aux_sym_preproc_if_token2] = ACTIONS(6754),
    [aux_sym_preproc_else_token1] = ACTIONS(6754),
    [aux_sym_preproc_elif_token1] = ACTIONS(6752),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6754),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6754),
    [anon_sym_LPAREN2] = ACTIONS(6754),
    [anon_sym_DASH] = ACTIONS(6752),
    [anon_sym_PLUS] = ACTIONS(6752),
    [anon_sym_STAR] = ACTIONS(6752),
    [anon_sym_SLASH] = ACTIONS(6752),
    [anon_sym_PERCENT] = ACTIONS(6752),
    [anon_sym_PIPE_PIPE] = ACTIONS(6754),
    [anon_sym_AMP_AMP] = ACTIONS(6754),
    [anon_sym_PIPE] = ACTIONS(6752),
    [anon_sym_CARET] = ACTIONS(6752),
    [anon_sym_AMP] = ACTIONS(6752),
    [anon_sym_EQ_EQ] = ACTIONS(6754),
    [anon_sym_BANG_EQ] = ACTIONS(6754),
    [anon_sym_GT] = ACTIONS(6752),
    [anon_sym_GT_EQ] = ACTIONS(6754),
    [anon_sym_LT_EQ] = ACTIONS(6752),
    [anon_sym_LT] = ACTIONS(6756),
    [anon_sym_LT_LT] = ACTIONS(6752),
    [anon_sym_GT_GT] = ACTIONS(6752),
    [anon_sym_SEMI] = ACTIONS(6754),
    [anon_sym___attribute__] = ACTIONS(6752),
    [anon_sym___attribute] = ACTIONS(6752),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_RBRACE] = ACTIONS(6754),
    [anon_sym_LBRACK] = ACTIONS(6754),
    [anon_sym_RBRACK] = ACTIONS(6754),
    [anon_sym_EQ] = ACTIONS(6752),
    [anon_sym_COLON] = ACTIONS(6752),
    [anon_sym_QMARK] = ACTIONS(6754),
    [anon_sym_STAR_EQ] = ACTIONS(6754),
    [anon_sym_SLASH_EQ] = ACTIONS(6754),
    [anon_sym_PERCENT_EQ] = ACTIONS(6754),
    [anon_sym_PLUS_EQ] = ACTIONS(6754),
    [anon_sym_DASH_EQ] = ACTIONS(6754),
    [anon_sym_LT_LT_EQ] = ACTIONS(6754),
    [anon_sym_GT_GT_EQ] = ACTIONS(6754),
    [anon_sym_AMP_EQ] = ACTIONS(6754),
    [anon_sym_CARET_EQ] = ACTIONS(6754),
    [anon_sym_PIPE_EQ] = ACTIONS(6754),
    [anon_sym_and_eq] = ACTIONS(6752),
    [anon_sym_or_eq] = ACTIONS(6752),
    [anon_sym_xor_eq] = ACTIONS(6752),
    [anon_sym_LT_EQ_GT] = ACTIONS(6754),
    [anon_sym_or] = ACTIONS(6752),
    [anon_sym_and] = ACTIONS(6752),
    [anon_sym_bitor] = ACTIONS(6752),
    [anon_sym_xor] = ACTIONS(6752),
    [anon_sym_bitand] = ACTIONS(6752),
    [anon_sym_not_eq] = ACTIONS(6752),
    [anon_sym_DASH_DASH] = ACTIONS(6754),
    [anon_sym_PLUS_PLUS] = ACTIONS(6754),
    [anon_sym_DOT] = ACTIONS(6752),
    [anon_sym_DOT_STAR] = ACTIONS(6754),
    [anon_sym_DASH_GT] = ACTIONS(6754),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6754),
  },
  [STATE(2666)] = {
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym_namespace] = ACTIONS(6759),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2667)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6194),
    [anon_sym_COMMA] = ACTIONS(6194),
    [anon_sym_LPAREN2] = ACTIONS(6194),
    [anon_sym_DASH] = ACTIONS(6192),
    [anon_sym_PLUS] = ACTIONS(6192),
    [anon_sym_STAR] = ACTIONS(6192),
    [anon_sym_SLASH] = ACTIONS(6192),
    [anon_sym_PERCENT] = ACTIONS(6192),
    [anon_sym_PIPE_PIPE] = ACTIONS(6194),
    [anon_sym_AMP_AMP] = ACTIONS(6194),
    [anon_sym_PIPE] = ACTIONS(6192),
    [anon_sym_CARET] = ACTIONS(6192),
    [anon_sym_AMP] = ACTIONS(6192),
    [anon_sym_EQ_EQ] = ACTIONS(6194),
    [anon_sym_BANG_EQ] = ACTIONS(6194),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_GT_EQ] = ACTIONS(6194),
    [anon_sym_LT_EQ] = ACTIONS(6192),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_LT_LT] = ACTIONS(6192),
    [anon_sym_GT_GT] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [anon_sym___attribute__] = ACTIONS(6192),
    [anon_sym___attribute] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [anon_sym_EQ] = ACTIONS(6192),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_STAR_EQ] = ACTIONS(6194),
    [anon_sym_SLASH_EQ] = ACTIONS(6194),
    [anon_sym_PERCENT_EQ] = ACTIONS(6194),
    [anon_sym_PLUS_EQ] = ACTIONS(6194),
    [anon_sym_DASH_EQ] = ACTIONS(6194),
    [anon_sym_LT_LT_EQ] = ACTIONS(6194),
    [anon_sym_GT_GT_EQ] = ACTIONS(6194),
    [anon_sym_AMP_EQ] = ACTIONS(6194),
    [anon_sym_CARET_EQ] = ACTIONS(6194),
    [anon_sym_PIPE_EQ] = ACTIONS(6194),
    [anon_sym_and_eq] = ACTIONS(6192),
    [anon_sym_or_eq] = ACTIONS(6192),
    [anon_sym_xor_eq] = ACTIONS(6192),
    [anon_sym_LT_EQ_GT] = ACTIONS(6194),
    [anon_sym_or] = ACTIONS(6192),
    [anon_sym_and] = ACTIONS(6192),
    [anon_sym_bitor] = ACTIONS(6192),
    [anon_sym_xor] = ACTIONS(6192),
    [anon_sym_bitand] = ACTIONS(6192),
    [anon_sym_not_eq] = ACTIONS(6192),
    [anon_sym_DASH_DASH] = ACTIONS(6194),
    [anon_sym_PLUS_PLUS] = ACTIONS(6194),
    [anon_sym_DOT] = ACTIONS(6192),
    [anon_sym_DOT_STAR] = ACTIONS(6194),
    [anon_sym_DASH_GT] = ACTIONS(6194),
    [anon_sym_L_DQUOTE] = ACTIONS(6194),
    [anon_sym_u_DQUOTE] = ACTIONS(6194),
    [anon_sym_U_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8_DQUOTE] = ACTIONS(6194),
    [anon_sym_DQUOTE] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6194),
    [anon_sym_LR_DQUOTE] = ACTIONS(6194),
    [anon_sym_uR_DQUOTE] = ACTIONS(6194),
    [anon_sym_UR_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6194),
    [sym_literal_suffix] = ACTIONS(6192),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6194),
  },
  [STATE(2668)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6010),
    [anon_sym_COMMA] = ACTIONS(6010),
    [anon_sym_RPAREN] = ACTIONS(6010),
    [anon_sym_LPAREN2] = ACTIONS(6010),
    [anon_sym_DASH] = ACTIONS(6012),
    [anon_sym_PLUS] = ACTIONS(6012),
    [anon_sym_STAR] = ACTIONS(6012),
    [anon_sym_SLASH] = ACTIONS(6012),
    [anon_sym_PERCENT] = ACTIONS(6012),
    [anon_sym_PIPE_PIPE] = ACTIONS(6010),
    [anon_sym_AMP_AMP] = ACTIONS(6010),
    [anon_sym_PIPE] = ACTIONS(6012),
    [anon_sym_CARET] = ACTIONS(6012),
    [anon_sym_AMP] = ACTIONS(6012),
    [anon_sym_EQ_EQ] = ACTIONS(6010),
    [anon_sym_BANG_EQ] = ACTIONS(6010),
    [anon_sym_GT] = ACTIONS(6012),
    [anon_sym_GT_EQ] = ACTIONS(6010),
    [anon_sym_LT_EQ] = ACTIONS(6012),
    [anon_sym_LT] = ACTIONS(6012),
    [anon_sym_LT_LT] = ACTIONS(6012),
    [anon_sym_GT_GT] = ACTIONS(6012),
    [anon_sym_SEMI] = ACTIONS(6010),
    [anon_sym___attribute__] = ACTIONS(6010),
    [anon_sym___attribute] = ACTIONS(6012),
    [anon_sym_LBRACE] = ACTIONS(6010),
    [anon_sym_RBRACE] = ACTIONS(6010),
    [anon_sym_signed] = ACTIONS(6681),
    [anon_sym_unsigned] = ACTIONS(6681),
    [anon_sym_long] = ACTIONS(6681),
    [anon_sym_short] = ACTIONS(6681),
    [anon_sym_LBRACK] = ACTIONS(6010),
    [anon_sym_RBRACK] = ACTIONS(6010),
    [anon_sym_EQ] = ACTIONS(6012),
    [anon_sym_COLON] = ACTIONS(6010),
    [anon_sym_QMARK] = ACTIONS(6010),
    [anon_sym_STAR_EQ] = ACTIONS(6010),
    [anon_sym_SLASH_EQ] = ACTIONS(6010),
    [anon_sym_PERCENT_EQ] = ACTIONS(6010),
    [anon_sym_PLUS_EQ] = ACTIONS(6010),
    [anon_sym_DASH_EQ] = ACTIONS(6010),
    [anon_sym_LT_LT_EQ] = ACTIONS(6010),
    [anon_sym_GT_GT_EQ] = ACTIONS(6010),
    [anon_sym_AMP_EQ] = ACTIONS(6010),
    [anon_sym_CARET_EQ] = ACTIONS(6010),
    [anon_sym_PIPE_EQ] = ACTIONS(6010),
    [anon_sym_and_eq] = ACTIONS(6010),
    [anon_sym_or_eq] = ACTIONS(6010),
    [anon_sym_xor_eq] = ACTIONS(6010),
    [anon_sym_LT_EQ_GT] = ACTIONS(6010),
    [anon_sym_or] = ACTIONS(6012),
    [anon_sym_and] = ACTIONS(6012),
    [anon_sym_bitor] = ACTIONS(6010),
    [anon_sym_xor] = ACTIONS(6012),
    [anon_sym_bitand] = ACTIONS(6010),
    [anon_sym_not_eq] = ACTIONS(6010),
    [anon_sym_DASH_DASH] = ACTIONS(6010),
    [anon_sym_PLUS_PLUS] = ACTIONS(6010),
    [anon_sym_DOT] = ACTIONS(6012),
    [anon_sym_DOT_STAR] = ACTIONS(6010),
    [anon_sym_DASH_GT] = ACTIONS(6010),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6010),
    [anon_sym_decltype] = ACTIONS(6010),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6010),
  },
  [STATE(2669)] = {
    [sym_identifier] = ACTIONS(6163),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6165),
    [anon_sym_COMMA] = ACTIONS(6165),
    [anon_sym_LPAREN2] = ACTIONS(6165),
    [anon_sym_DASH] = ACTIONS(6163),
    [anon_sym_PLUS] = ACTIONS(6163),
    [anon_sym_STAR] = ACTIONS(6163),
    [anon_sym_SLASH] = ACTIONS(6163),
    [anon_sym_PERCENT] = ACTIONS(6163),
    [anon_sym_PIPE_PIPE] = ACTIONS(6165),
    [anon_sym_AMP_AMP] = ACTIONS(6165),
    [anon_sym_PIPE] = ACTIONS(6163),
    [anon_sym_CARET] = ACTIONS(6163),
    [anon_sym_AMP] = ACTIONS(6163),
    [anon_sym_EQ_EQ] = ACTIONS(6165),
    [anon_sym_BANG_EQ] = ACTIONS(6165),
    [anon_sym_GT] = ACTIONS(6163),
    [anon_sym_GT_EQ] = ACTIONS(6165),
    [anon_sym_LT_EQ] = ACTIONS(6163),
    [anon_sym_LT] = ACTIONS(6163),
    [anon_sym_LT_LT] = ACTIONS(6163),
    [anon_sym_GT_GT] = ACTIONS(6163),
    [anon_sym_SEMI] = ACTIONS(6165),
    [anon_sym___attribute__] = ACTIONS(6163),
    [anon_sym___attribute] = ACTIONS(6163),
    [anon_sym_LBRACK] = ACTIONS(6165),
    [anon_sym_EQ] = ACTIONS(6163),
    [anon_sym_QMARK] = ACTIONS(6165),
    [anon_sym_STAR_EQ] = ACTIONS(6165),
    [anon_sym_SLASH_EQ] = ACTIONS(6165),
    [anon_sym_PERCENT_EQ] = ACTIONS(6165),
    [anon_sym_PLUS_EQ] = ACTIONS(6165),
    [anon_sym_DASH_EQ] = ACTIONS(6165),
    [anon_sym_LT_LT_EQ] = ACTIONS(6165),
    [anon_sym_GT_GT_EQ] = ACTIONS(6165),
    [anon_sym_AMP_EQ] = ACTIONS(6165),
    [anon_sym_CARET_EQ] = ACTIONS(6165),
    [anon_sym_PIPE_EQ] = ACTIONS(6165),
    [anon_sym_and_eq] = ACTIONS(6163),
    [anon_sym_or_eq] = ACTIONS(6163),
    [anon_sym_xor_eq] = ACTIONS(6163),
    [anon_sym_LT_EQ_GT] = ACTIONS(6165),
    [anon_sym_or] = ACTIONS(6163),
    [anon_sym_and] = ACTIONS(6163),
    [anon_sym_bitor] = ACTIONS(6163),
    [anon_sym_xor] = ACTIONS(6163),
    [anon_sym_bitand] = ACTIONS(6163),
    [anon_sym_not_eq] = ACTIONS(6163),
    [anon_sym_DASH_DASH] = ACTIONS(6165),
    [anon_sym_PLUS_PLUS] = ACTIONS(6165),
    [anon_sym_DOT] = ACTIONS(6163),
    [anon_sym_DOT_STAR] = ACTIONS(6165),
    [anon_sym_DASH_GT] = ACTIONS(6165),
    [anon_sym_L_DQUOTE] = ACTIONS(6165),
    [anon_sym_u_DQUOTE] = ACTIONS(6165),
    [anon_sym_U_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8_DQUOTE] = ACTIONS(6165),
    [anon_sym_DQUOTE] = ACTIONS(6165),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6165),
    [anon_sym_LR_DQUOTE] = ACTIONS(6165),
    [anon_sym_uR_DQUOTE] = ACTIONS(6165),
    [anon_sym_UR_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6165),
    [sym_literal_suffix] = ACTIONS(6163),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6165),
  },
  [STATE(2670)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2650),
    [anon_sym_COMMA] = ACTIONS(5994),
    [anon_sym_RPAREN] = ACTIONS(5994),
    [anon_sym_LPAREN2] = ACTIONS(5994),
    [anon_sym_STAR] = ACTIONS(5994),
    [anon_sym_AMP_AMP] = ACTIONS(5994),
    [anon_sym_AMP] = ACTIONS(5996),
    [anon_sym_SEMI] = ACTIONS(5994),
    [anon_sym___extension__] = ACTIONS(5994),
    [anon_sym___device__] = ACTIONS(5994),
    [anon_sym___host__] = ACTIONS(5994),
    [anon_sym___global__] = ACTIONS(5994),
    [anon_sym___forceinline__] = ACTIONS(5994),
    [anon_sym___noinline__] = ACTIONS(5994),
    [anon_sym_virtual] = ACTIONS(5994),
    [anon_sym_extern] = ACTIONS(5994),
    [anon_sym___attribute__] = ACTIONS(5994),
    [anon_sym___attribute] = ACTIONS(5996),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5994),
    [anon_sym___declspec] = ACTIONS(5994),
    [anon_sym_LBRACE] = ACTIONS(5994),
    [anon_sym_signed] = ACTIONS(6761),
    [anon_sym_unsigned] = ACTIONS(6761),
    [anon_sym_long] = ACTIONS(6761),
    [anon_sym_short] = ACTIONS(6761),
    [anon_sym_LBRACK] = ACTIONS(5996),
    [anon_sym_static] = ACTIONS(5994),
    [anon_sym_EQ] = ACTIONS(5994),
    [anon_sym_register] = ACTIONS(5994),
    [anon_sym_inline] = ACTIONS(5994),
    [anon_sym___inline] = ACTIONS(5996),
    [anon_sym___inline__] = ACTIONS(5994),
    [anon_sym___forceinline] = ACTIONS(5996),
    [anon_sym_thread_local] = ACTIONS(5994),
    [anon_sym___thread] = ACTIONS(5994),
    [anon_sym_const] = ACTIONS(5996),
    [anon_sym_constexpr] = ACTIONS(5994),
    [anon_sym_volatile] = ACTIONS(5994),
    [anon_sym_restrict] = ACTIONS(5994),
    [anon_sym___restrict__] = ACTIONS(5994),
    [anon_sym__Atomic] = ACTIONS(5994),
    [anon_sym__Noreturn] = ACTIONS(5994),
    [anon_sym_noreturn] = ACTIONS(5994),
    [anon_sym__Nonnull] = ACTIONS(5994),
    [anon_sym_mutable] = ACTIONS(5994),
    [anon_sym_constinit] = ACTIONS(5994),
    [anon_sym_consteval] = ACTIONS(5994),
    [anon_sym___shared__] = ACTIONS(5994),
    [anon_sym___local__] = ACTIONS(5994),
    [anon_sym___constant__] = ACTIONS(5994),
    [anon_sym___managed__] = ACTIONS(5994),
    [anon_sym___grid_constant__] = ACTIONS(5994),
    [anon_sym_alignas] = ACTIONS(5994),
    [anon_sym__Alignas] = ACTIONS(5994),
    [anon_sym_asm] = ACTIONS(5994),
    [anon_sym___asm__] = ACTIONS(5994),
    [anon_sym___asm] = ACTIONS(5996),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5994),
    [anon_sym_decltype] = ACTIONS(5994),
    [anon_sym_final] = ACTIONS(5994),
    [anon_sym_override] = ACTIONS(5994),
    [anon_sym_GT2] = ACTIONS(5994),
    [anon_sym_try] = ACTIONS(5994),
    [anon_sym_requires] = ACTIONS(5994),
    [anon_sym___launch_bounds__] = ACTIONS(5994),
  },
  [STATE(2671)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym__declarator] = STATE(6947),
    [sym__abstract_declarator] = STATE(7260),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(4415),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3094),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(4415),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(5925),
    [anon_sym_RPAREN] = ACTIONS(5925),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(6084),
    [anon_sym_AMP_AMP] = ACTIONS(6086),
    [anon_sym_AMP] = ACTIONS(6088),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(5933),
    [anon_sym___attribute] = ACTIONS(5933),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2672)] = {
    [sym_identifier] = ACTIONS(4562),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4555),
    [anon_sym_COMMA] = ACTIONS(4555),
    [anon_sym_RPAREN] = ACTIONS(4555),
    [aux_sym_preproc_if_token2] = ACTIONS(4555),
    [aux_sym_preproc_else_token1] = ACTIONS(4555),
    [aux_sym_preproc_elif_token1] = ACTIONS(4562),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4555),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4555),
    [anon_sym_LPAREN2] = ACTIONS(4555),
    [anon_sym_DASH] = ACTIONS(4562),
    [anon_sym_PLUS] = ACTIONS(4562),
    [anon_sym_STAR] = ACTIONS(4562),
    [anon_sym_SLASH] = ACTIONS(4562),
    [anon_sym_PERCENT] = ACTIONS(4562),
    [anon_sym_PIPE_PIPE] = ACTIONS(4555),
    [anon_sym_AMP_AMP] = ACTIONS(4555),
    [anon_sym_PIPE] = ACTIONS(4562),
    [anon_sym_CARET] = ACTIONS(4562),
    [anon_sym_AMP] = ACTIONS(4562),
    [anon_sym_EQ_EQ] = ACTIONS(4555),
    [anon_sym_BANG_EQ] = ACTIONS(4555),
    [anon_sym_GT] = ACTIONS(4562),
    [anon_sym_GT_EQ] = ACTIONS(4555),
    [anon_sym_LT_EQ] = ACTIONS(4562),
    [anon_sym_LT] = ACTIONS(4562),
    [anon_sym_LT_LT] = ACTIONS(4562),
    [anon_sym_GT_GT] = ACTIONS(4562),
    [anon_sym_SEMI] = ACTIONS(4555),
    [anon_sym___attribute__] = ACTIONS(4562),
    [anon_sym___attribute] = ACTIONS(4562),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACE] = ACTIONS(4560),
    [anon_sym_RBRACE] = ACTIONS(4555),
    [anon_sym_LBRACK] = ACTIONS(4555),
    [anon_sym_RBRACK] = ACTIONS(4555),
    [anon_sym_EQ] = ACTIONS(4562),
    [anon_sym_COLON] = ACTIONS(4562),
    [anon_sym_QMARK] = ACTIONS(4555),
    [anon_sym_STAR_EQ] = ACTIONS(4555),
    [anon_sym_SLASH_EQ] = ACTIONS(4555),
    [anon_sym_PERCENT_EQ] = ACTIONS(4555),
    [anon_sym_PLUS_EQ] = ACTIONS(4555),
    [anon_sym_DASH_EQ] = ACTIONS(4555),
    [anon_sym_LT_LT_EQ] = ACTIONS(4555),
    [anon_sym_GT_GT_EQ] = ACTIONS(4555),
    [anon_sym_AMP_EQ] = ACTIONS(4555),
    [anon_sym_CARET_EQ] = ACTIONS(4555),
    [anon_sym_PIPE_EQ] = ACTIONS(4555),
    [anon_sym_and_eq] = ACTIONS(4562),
    [anon_sym_or_eq] = ACTIONS(4562),
    [anon_sym_xor_eq] = ACTIONS(4562),
    [anon_sym_LT_EQ_GT] = ACTIONS(4555),
    [anon_sym_or] = ACTIONS(4562),
    [anon_sym_and] = ACTIONS(4562),
    [anon_sym_bitor] = ACTIONS(4562),
    [anon_sym_xor] = ACTIONS(4562),
    [anon_sym_bitand] = ACTIONS(4562),
    [anon_sym_not_eq] = ACTIONS(4562),
    [anon_sym_DASH_DASH] = ACTIONS(4555),
    [anon_sym_PLUS_PLUS] = ACTIONS(4555),
    [anon_sym_DOT] = ACTIONS(4562),
    [anon_sym_DOT_STAR] = ACTIONS(4555),
    [anon_sym_DASH_GT] = ACTIONS(4555),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(4555),
  },
  [STATE(2673)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_typedef] = ACTIONS(6763),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2674)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2668),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5917),
    [anon_sym_COMMA] = ACTIONS(5917),
    [anon_sym_RPAREN] = ACTIONS(5917),
    [anon_sym_LPAREN2] = ACTIONS(5917),
    [anon_sym_DASH] = ACTIONS(5919),
    [anon_sym_PLUS] = ACTIONS(5919),
    [anon_sym_STAR] = ACTIONS(5919),
    [anon_sym_SLASH] = ACTIONS(5919),
    [anon_sym_PERCENT] = ACTIONS(5919),
    [anon_sym_PIPE_PIPE] = ACTIONS(5917),
    [anon_sym_AMP_AMP] = ACTIONS(5917),
    [anon_sym_PIPE] = ACTIONS(5919),
    [anon_sym_CARET] = ACTIONS(5919),
    [anon_sym_AMP] = ACTIONS(5919),
    [anon_sym_EQ_EQ] = ACTIONS(5917),
    [anon_sym_BANG_EQ] = ACTIONS(5917),
    [anon_sym_GT] = ACTIONS(5919),
    [anon_sym_GT_EQ] = ACTIONS(5917),
    [anon_sym_LT_EQ] = ACTIONS(5919),
    [anon_sym_LT] = ACTIONS(5919),
    [anon_sym_LT_LT] = ACTIONS(5919),
    [anon_sym_GT_GT] = ACTIONS(5919),
    [anon_sym_SEMI] = ACTIONS(5917),
    [anon_sym___attribute__] = ACTIONS(5917),
    [anon_sym___attribute] = ACTIONS(5919),
    [anon_sym_LBRACE] = ACTIONS(5917),
    [anon_sym_RBRACE] = ACTIONS(5917),
    [anon_sym_signed] = ACTIONS(6765),
    [anon_sym_unsigned] = ACTIONS(6765),
    [anon_sym_long] = ACTIONS(6765),
    [anon_sym_short] = ACTIONS(6765),
    [anon_sym_LBRACK] = ACTIONS(5917),
    [anon_sym_RBRACK] = ACTIONS(5917),
    [anon_sym_EQ] = ACTIONS(5919),
    [anon_sym_COLON] = ACTIONS(5917),
    [anon_sym_QMARK] = ACTIONS(5917),
    [anon_sym_STAR_EQ] = ACTIONS(5917),
    [anon_sym_SLASH_EQ] = ACTIONS(5917),
    [anon_sym_PERCENT_EQ] = ACTIONS(5917),
    [anon_sym_PLUS_EQ] = ACTIONS(5917),
    [anon_sym_DASH_EQ] = ACTIONS(5917),
    [anon_sym_LT_LT_EQ] = ACTIONS(5917),
    [anon_sym_GT_GT_EQ] = ACTIONS(5917),
    [anon_sym_AMP_EQ] = ACTIONS(5917),
    [anon_sym_CARET_EQ] = ACTIONS(5917),
    [anon_sym_PIPE_EQ] = ACTIONS(5917),
    [anon_sym_and_eq] = ACTIONS(5917),
    [anon_sym_or_eq] = ACTIONS(5917),
    [anon_sym_xor_eq] = ACTIONS(5917),
    [anon_sym_LT_EQ_GT] = ACTIONS(5917),
    [anon_sym_or] = ACTIONS(5919),
    [anon_sym_and] = ACTIONS(5919),
    [anon_sym_bitor] = ACTIONS(5917),
    [anon_sym_xor] = ACTIONS(5919),
    [anon_sym_bitand] = ACTIONS(5917),
    [anon_sym_not_eq] = ACTIONS(5917),
    [anon_sym_DASH_DASH] = ACTIONS(5917),
    [anon_sym_PLUS_PLUS] = ACTIONS(5917),
    [anon_sym_DOT] = ACTIONS(5919),
    [anon_sym_DOT_STAR] = ACTIONS(5917),
    [anon_sym_DASH_GT] = ACTIONS(5917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5917),
    [anon_sym_decltype] = ACTIONS(5917),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5917),
  },
  [STATE(2675)] = {
    [sym_argument_list] = STATE(2794),
    [sym_subscript_argument_list] = STATE(2795),
    [sym_kernel_call_syntax] = STATE(8417),
    [sym_identifier] = ACTIONS(6767),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6769),
    [anon_sym_COMMA] = ACTIONS(6769),
    [anon_sym_RPAREN] = ACTIONS(6769),
    [aux_sym_preproc_if_token2] = ACTIONS(6769),
    [aux_sym_preproc_else_token1] = ACTIONS(6769),
    [aux_sym_preproc_elif_token1] = ACTIONS(6767),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6769),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6769),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6767),
    [anon_sym_PLUS] = ACTIONS(6767),
    [anon_sym_STAR] = ACTIONS(6767),
    [anon_sym_SLASH] = ACTIONS(6767),
    [anon_sym_PERCENT] = ACTIONS(6767),
    [anon_sym_PIPE_PIPE] = ACTIONS(6769),
    [anon_sym_AMP_AMP] = ACTIONS(6769),
    [anon_sym_PIPE] = ACTIONS(6767),
    [anon_sym_CARET] = ACTIONS(6767),
    [anon_sym_AMP] = ACTIONS(6767),
    [anon_sym_EQ_EQ] = ACTIONS(6769),
    [anon_sym_BANG_EQ] = ACTIONS(6769),
    [anon_sym_GT] = ACTIONS(6767),
    [anon_sym_GT_EQ] = ACTIONS(6769),
    [anon_sym_LT_EQ] = ACTIONS(6767),
    [anon_sym_LT] = ACTIONS(6767),
    [anon_sym_LT_LT] = ACTIONS(6767),
    [anon_sym_GT_GT] = ACTIONS(6767),
    [anon_sym_SEMI] = ACTIONS(6769),
    [anon_sym___attribute__] = ACTIONS(6767),
    [anon_sym___attribute] = ACTIONS(6767),
    [anon_sym_RBRACE] = ACTIONS(6769),
    [anon_sym_LBRACK] = ACTIONS(6691),
    [anon_sym_RBRACK] = ACTIONS(6769),
    [anon_sym_EQ] = ACTIONS(6767),
    [anon_sym_QMARK] = ACTIONS(6769),
    [anon_sym_STAR_EQ] = ACTIONS(6769),
    [anon_sym_SLASH_EQ] = ACTIONS(6769),
    [anon_sym_PERCENT_EQ] = ACTIONS(6769),
    [anon_sym_PLUS_EQ] = ACTIONS(6769),
    [anon_sym_DASH_EQ] = ACTIONS(6769),
    [anon_sym_LT_LT_EQ] = ACTIONS(6769),
    [anon_sym_GT_GT_EQ] = ACTIONS(6769),
    [anon_sym_AMP_EQ] = ACTIONS(6769),
    [anon_sym_CARET_EQ] = ACTIONS(6769),
    [anon_sym_PIPE_EQ] = ACTIONS(6769),
    [anon_sym_and_eq] = ACTIONS(6767),
    [anon_sym_or_eq] = ACTIONS(6767),
    [anon_sym_xor_eq] = ACTIONS(6767),
    [anon_sym_LT_EQ_GT] = ACTIONS(6769),
    [anon_sym_or] = ACTIONS(6767),
    [anon_sym_and] = ACTIONS(6767),
    [anon_sym_bitor] = ACTIONS(6767),
    [anon_sym_xor] = ACTIONS(6767),
    [anon_sym_bitand] = ACTIONS(6767),
    [anon_sym_not_eq] = ACTIONS(6767),
    [anon_sym_DASH_DASH] = ACTIONS(6710),
    [anon_sym_PLUS_PLUS] = ACTIONS(6710),
    [anon_sym_DOT] = ACTIONS(6693),
    [anon_sym_DOT_STAR] = ACTIONS(6695),
    [anon_sym_DASH_GT] = ACTIONS(6695),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6769),
  },
  [STATE(2676)] = {
    [sym_argument_list] = STATE(2794),
    [sym_subscript_argument_list] = STATE(2795),
    [sym_kernel_call_syntax] = STATE(8417),
    [sym_identifier] = ACTIONS(6771),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6773),
    [anon_sym_COMMA] = ACTIONS(6773),
    [anon_sym_RPAREN] = ACTIONS(6773),
    [aux_sym_preproc_if_token2] = ACTIONS(6773),
    [aux_sym_preproc_else_token1] = ACTIONS(6773),
    [aux_sym_preproc_elif_token1] = ACTIONS(6771),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6773),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6773),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6771),
    [anon_sym_PLUS] = ACTIONS(6771),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_SLASH] = ACTIONS(6771),
    [anon_sym_PERCENT] = ACTIONS(6771),
    [anon_sym_PIPE_PIPE] = ACTIONS(6773),
    [anon_sym_AMP_AMP] = ACTIONS(6773),
    [anon_sym_PIPE] = ACTIONS(6771),
    [anon_sym_CARET] = ACTIONS(6771),
    [anon_sym_AMP] = ACTIONS(6771),
    [anon_sym_EQ_EQ] = ACTIONS(6773),
    [anon_sym_BANG_EQ] = ACTIONS(6773),
    [anon_sym_GT] = ACTIONS(6771),
    [anon_sym_GT_EQ] = ACTIONS(6773),
    [anon_sym_LT_EQ] = ACTIONS(6771),
    [anon_sym_LT] = ACTIONS(6771),
    [anon_sym_LT_LT] = ACTIONS(6771),
    [anon_sym_GT_GT] = ACTIONS(6771),
    [anon_sym_SEMI] = ACTIONS(6773),
    [anon_sym___attribute__] = ACTIONS(6771),
    [anon_sym___attribute] = ACTIONS(6771),
    [anon_sym_RBRACE] = ACTIONS(6773),
    [anon_sym_LBRACK] = ACTIONS(6691),
    [anon_sym_RBRACK] = ACTIONS(6773),
    [anon_sym_EQ] = ACTIONS(6771),
    [anon_sym_QMARK] = ACTIONS(6773),
    [anon_sym_STAR_EQ] = ACTIONS(6773),
    [anon_sym_SLASH_EQ] = ACTIONS(6773),
    [anon_sym_PERCENT_EQ] = ACTIONS(6773),
    [anon_sym_PLUS_EQ] = ACTIONS(6773),
    [anon_sym_DASH_EQ] = ACTIONS(6773),
    [anon_sym_LT_LT_EQ] = ACTIONS(6773),
    [anon_sym_GT_GT_EQ] = ACTIONS(6773),
    [anon_sym_AMP_EQ] = ACTIONS(6773),
    [anon_sym_CARET_EQ] = ACTIONS(6773),
    [anon_sym_PIPE_EQ] = ACTIONS(6773),
    [anon_sym_and_eq] = ACTIONS(6771),
    [anon_sym_or_eq] = ACTIONS(6771),
    [anon_sym_xor_eq] = ACTIONS(6771),
    [anon_sym_LT_EQ_GT] = ACTIONS(6773),
    [anon_sym_or] = ACTIONS(6771),
    [anon_sym_and] = ACTIONS(6771),
    [anon_sym_bitor] = ACTIONS(6771),
    [anon_sym_xor] = ACTIONS(6771),
    [anon_sym_bitand] = ACTIONS(6771),
    [anon_sym_not_eq] = ACTIONS(6771),
    [anon_sym_DASH_DASH] = ACTIONS(6710),
    [anon_sym_PLUS_PLUS] = ACTIONS(6710),
    [anon_sym_DOT] = ACTIONS(6693),
    [anon_sym_DOT_STAR] = ACTIONS(6695),
    [anon_sym_DASH_GT] = ACTIONS(6695),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6773),
  },
  [STATE(2677)] = {
    [sym_template_argument_list] = STATE(2693),
    [sym_identifier] = ACTIONS(6775),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6777),
    [anon_sym_COMMA] = ACTIONS(6777),
    [anon_sym_RPAREN] = ACTIONS(6777),
    [aux_sym_preproc_if_token2] = ACTIONS(6777),
    [aux_sym_preproc_else_token1] = ACTIONS(6777),
    [aux_sym_preproc_elif_token1] = ACTIONS(6775),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6777),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6777),
    [anon_sym_LPAREN2] = ACTIONS(6777),
    [anon_sym_DASH] = ACTIONS(6775),
    [anon_sym_PLUS] = ACTIONS(6775),
    [anon_sym_STAR] = ACTIONS(6775),
    [anon_sym_SLASH] = ACTIONS(6775),
    [anon_sym_PERCENT] = ACTIONS(6775),
    [anon_sym_PIPE_PIPE] = ACTIONS(6777),
    [anon_sym_AMP_AMP] = ACTIONS(6777),
    [anon_sym_PIPE] = ACTIONS(6775),
    [anon_sym_CARET] = ACTIONS(6775),
    [anon_sym_AMP] = ACTIONS(6775),
    [anon_sym_EQ_EQ] = ACTIONS(6777),
    [anon_sym_BANG_EQ] = ACTIONS(6777),
    [anon_sym_GT] = ACTIONS(6775),
    [anon_sym_GT_EQ] = ACTIONS(6777),
    [anon_sym_LT_EQ] = ACTIONS(6775),
    [anon_sym_LT] = ACTIONS(6779),
    [anon_sym_LT_LT] = ACTIONS(6775),
    [anon_sym_GT_GT] = ACTIONS(6775),
    [anon_sym_SEMI] = ACTIONS(6777),
    [anon_sym___attribute__] = ACTIONS(6775),
    [anon_sym___attribute] = ACTIONS(6775),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_RBRACE] = ACTIONS(6777),
    [anon_sym_LBRACK] = ACTIONS(6777),
    [anon_sym_RBRACK] = ACTIONS(6777),
    [anon_sym_EQ] = ACTIONS(6775),
    [anon_sym_COLON] = ACTIONS(6775),
    [anon_sym_QMARK] = ACTIONS(6777),
    [anon_sym_STAR_EQ] = ACTIONS(6777),
    [anon_sym_SLASH_EQ] = ACTIONS(6777),
    [anon_sym_PERCENT_EQ] = ACTIONS(6777),
    [anon_sym_PLUS_EQ] = ACTIONS(6777),
    [anon_sym_DASH_EQ] = ACTIONS(6777),
    [anon_sym_LT_LT_EQ] = ACTIONS(6777),
    [anon_sym_GT_GT_EQ] = ACTIONS(6777),
    [anon_sym_AMP_EQ] = ACTIONS(6777),
    [anon_sym_CARET_EQ] = ACTIONS(6777),
    [anon_sym_PIPE_EQ] = ACTIONS(6777),
    [anon_sym_and_eq] = ACTIONS(6775),
    [anon_sym_or_eq] = ACTIONS(6775),
    [anon_sym_xor_eq] = ACTIONS(6775),
    [anon_sym_LT_EQ_GT] = ACTIONS(6777),
    [anon_sym_or] = ACTIONS(6775),
    [anon_sym_and] = ACTIONS(6775),
    [anon_sym_bitor] = ACTIONS(6775),
    [anon_sym_xor] = ACTIONS(6775),
    [anon_sym_bitand] = ACTIONS(6775),
    [anon_sym_not_eq] = ACTIONS(6775),
    [anon_sym_DASH_DASH] = ACTIONS(6777),
    [anon_sym_PLUS_PLUS] = ACTIONS(6777),
    [anon_sym_DOT] = ACTIONS(6775),
    [anon_sym_DOT_STAR] = ACTIONS(6777),
    [anon_sym_DASH_GT] = ACTIONS(6777),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6777),
  },
  [STATE(2678)] = {
    [sym_ms_based_modifier] = STATE(8750),
    [sym__declarator] = STATE(6954),
    [sym__abstract_declarator] = STATE(7261),
    [sym_parenthesized_declarator] = STATE(6660),
    [sym_abstract_parenthesized_declarator] = STATE(6618),
    [sym_attributed_declarator] = STATE(6660),
    [sym_pointer_declarator] = STATE(6660),
    [sym_abstract_pointer_declarator] = STATE(6618),
    [sym_function_declarator] = STATE(6660),
    [sym_abstract_function_declarator] = STATE(6618),
    [sym_array_declarator] = STATE(6660),
    [sym_abstract_array_declarator] = STATE(6618),
    [sym_type_qualifier] = STATE(4415),
    [sym_alignas_qualifier] = STATE(4537),
    [sym_parameter_list] = STATE(3094),
    [sym_decltype] = STATE(9247),
    [sym_reference_declarator] = STATE(6660),
    [sym_abstract_reference_declarator] = STATE(6618),
    [sym_structured_binding_declarator] = STATE(6660),
    [sym__function_declarator_seq] = STATE(6667),
    [sym_template_type] = STATE(9247),
    [sym_template_function] = STATE(6660),
    [sym_destructor_name] = STATE(6660),
    [sym_dependent_type_identifier] = STATE(9247),
    [sym__scope_resolution] = STATE(6391),
    [sym_qualified_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6660),
    [aux_sym__type_definition_type_repeat1] = STATE(4415),
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_COMMA] = ACTIONS(6512),
    [anon_sym_RPAREN] = ACTIONS(6512),
    [anon_sym_LPAREN2] = ACTIONS(4197),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_STAR] = ACTIONS(6084),
    [anon_sym_AMP_AMP] = ACTIONS(6086),
    [anon_sym_AMP] = ACTIONS(6088),
    [anon_sym___extension__] = ACTIONS(3127),
    [anon_sym___global__] = ACTIONS(3127),
    [anon_sym___attribute__] = ACTIONS(6514),
    [anon_sym___attribute] = ACTIONS(6514),
    [anon_sym_COLON_COLON] = ACTIONS(5935),
    [anon_sym___based] = ACTIONS(51),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [anon_sym_const] = ACTIONS(3127),
    [anon_sym_constexpr] = ACTIONS(3127),
    [anon_sym_volatile] = ACTIONS(3127),
    [anon_sym_restrict] = ACTIONS(3127),
    [anon_sym___restrict__] = ACTIONS(3127),
    [anon_sym__Atomic] = ACTIONS(3127),
    [anon_sym__Noreturn] = ACTIONS(3127),
    [anon_sym_noreturn] = ACTIONS(3127),
    [anon_sym__Nonnull] = ACTIONS(3127),
    [anon_sym_mutable] = ACTIONS(3127),
    [anon_sym_constinit] = ACTIONS(3127),
    [anon_sym_consteval] = ACTIONS(3127),
    [anon_sym___shared__] = ACTIONS(3127),
    [anon_sym___local__] = ACTIONS(3127),
    [anon_sym___constant__] = ACTIONS(3127),
    [anon_sym___managed__] = ACTIONS(3127),
    [anon_sym___grid_constant__] = ACTIONS(3127),
    [anon_sym_alignas] = ACTIONS(3133),
    [anon_sym__Alignas] = ACTIONS(3133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2669),
    [anon_sym_template] = ACTIONS(1251),
    [anon_sym_operator] = ACTIONS(1914),
  },
  [STATE(2679)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2691),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5772),
    [anon_sym_COMMA] = ACTIONS(5772),
    [anon_sym_RPAREN] = ACTIONS(5772),
    [anon_sym_LPAREN2] = ACTIONS(5772),
    [anon_sym_DASH] = ACTIONS(5770),
    [anon_sym_PLUS] = ACTIONS(5770),
    [anon_sym_STAR] = ACTIONS(5770),
    [anon_sym_SLASH] = ACTIONS(5770),
    [anon_sym_PERCENT] = ACTIONS(5770),
    [anon_sym_PIPE_PIPE] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5772),
    [anon_sym_PIPE] = ACTIONS(5770),
    [anon_sym_CARET] = ACTIONS(5770),
    [anon_sym_AMP] = ACTIONS(5770),
    [anon_sym_EQ_EQ] = ACTIONS(5772),
    [anon_sym_BANG_EQ] = ACTIONS(5772),
    [anon_sym_GT] = ACTIONS(5770),
    [anon_sym_GT_EQ] = ACTIONS(5772),
    [anon_sym_LT_EQ] = ACTIONS(5770),
    [anon_sym_LT] = ACTIONS(5770),
    [anon_sym_LT_LT] = ACTIONS(5770),
    [anon_sym_GT_GT] = ACTIONS(5770),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym___attribute__] = ACTIONS(5772),
    [anon_sym___attribute] = ACTIONS(5770),
    [anon_sym_LBRACE] = ACTIONS(5772),
    [anon_sym_RBRACE] = ACTIONS(5772),
    [anon_sym_signed] = ACTIONS(6667),
    [anon_sym_unsigned] = ACTIONS(6667),
    [anon_sym_long] = ACTIONS(6667),
    [anon_sym_short] = ACTIONS(6667),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_RBRACK] = ACTIONS(5772),
    [anon_sym_EQ] = ACTIONS(5770),
    [anon_sym_COLON] = ACTIONS(5772),
    [anon_sym_QMARK] = ACTIONS(5772),
    [anon_sym_STAR_EQ] = ACTIONS(5772),
    [anon_sym_SLASH_EQ] = ACTIONS(5772),
    [anon_sym_PERCENT_EQ] = ACTIONS(5772),
    [anon_sym_PLUS_EQ] = ACTIONS(5772),
    [anon_sym_DASH_EQ] = ACTIONS(5772),
    [anon_sym_LT_LT_EQ] = ACTIONS(5772),
    [anon_sym_GT_GT_EQ] = ACTIONS(5772),
    [anon_sym_AMP_EQ] = ACTIONS(5772),
    [anon_sym_CARET_EQ] = ACTIONS(5772),
    [anon_sym_PIPE_EQ] = ACTIONS(5772),
    [anon_sym_and_eq] = ACTIONS(5772),
    [anon_sym_or_eq] = ACTIONS(5772),
    [anon_sym_xor_eq] = ACTIONS(5772),
    [anon_sym_LT_EQ_GT] = ACTIONS(5772),
    [anon_sym_or] = ACTIONS(5770),
    [anon_sym_and] = ACTIONS(5770),
    [anon_sym_bitor] = ACTIONS(5772),
    [anon_sym_xor] = ACTIONS(5770),
    [anon_sym_bitand] = ACTIONS(5772),
    [anon_sym_not_eq] = ACTIONS(5772),
    [anon_sym_DASH_DASH] = ACTIONS(5772),
    [anon_sym_PLUS_PLUS] = ACTIONS(5772),
    [anon_sym_DOT] = ACTIONS(5770),
    [anon_sym_DOT_STAR] = ACTIONS(5772),
    [anon_sym_DASH_GT] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5772),
    [anon_sym_decltype] = ACTIONS(5772),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5772),
  },
  [STATE(2680)] = {
    [sym_template_argument_list] = STATE(2360),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4010),
    [anon_sym_COMMA] = ACTIONS(4010),
    [anon_sym_RPAREN] = ACTIONS(4010),
    [anon_sym_LPAREN2] = ACTIONS(4010),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_STAR] = ACTIONS(4010),
    [anon_sym_AMP_AMP] = ACTIONS(4010),
    [anon_sym_AMP] = ACTIONS(4002),
    [anon_sym_LT] = ACTIONS(6782),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4002),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4010),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_GT2] = ACTIONS(4010),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(2681)] = {
    [sym_argument_list] = STATE(2794),
    [sym_subscript_argument_list] = STATE(2795),
    [sym_kernel_call_syntax] = STATE(8417),
    [sym_identifier] = ACTIONS(6784),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6786),
    [anon_sym_COMMA] = ACTIONS(6786),
    [anon_sym_RPAREN] = ACTIONS(6786),
    [aux_sym_preproc_if_token2] = ACTIONS(6786),
    [aux_sym_preproc_else_token1] = ACTIONS(6786),
    [aux_sym_preproc_elif_token1] = ACTIONS(6784),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6786),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6786),
    [anon_sym_LPAREN2] = ACTIONS(6309),
    [anon_sym_DASH] = ACTIONS(6784),
    [anon_sym_PLUS] = ACTIONS(6784),
    [anon_sym_STAR] = ACTIONS(6784),
    [anon_sym_SLASH] = ACTIONS(6784),
    [anon_sym_PERCENT] = ACTIONS(6784),
    [anon_sym_PIPE_PIPE] = ACTIONS(6786),
    [anon_sym_AMP_AMP] = ACTIONS(6786),
    [anon_sym_PIPE] = ACTIONS(6784),
    [anon_sym_CARET] = ACTIONS(6784),
    [anon_sym_AMP] = ACTIONS(6784),
    [anon_sym_EQ_EQ] = ACTIONS(6786),
    [anon_sym_BANG_EQ] = ACTIONS(6786),
    [anon_sym_GT] = ACTIONS(6784),
    [anon_sym_GT_EQ] = ACTIONS(6786),
    [anon_sym_LT_EQ] = ACTIONS(6784),
    [anon_sym_LT] = ACTIONS(6784),
    [anon_sym_LT_LT] = ACTIONS(6784),
    [anon_sym_GT_GT] = ACTIONS(6784),
    [anon_sym_SEMI] = ACTIONS(6786),
    [anon_sym___attribute__] = ACTIONS(6784),
    [anon_sym___attribute] = ACTIONS(6784),
    [anon_sym_RBRACE] = ACTIONS(6786),
    [anon_sym_LBRACK] = ACTIONS(6691),
    [anon_sym_RBRACK] = ACTIONS(6786),
    [anon_sym_EQ] = ACTIONS(6784),
    [anon_sym_QMARK] = ACTIONS(6786),
    [anon_sym_STAR_EQ] = ACTIONS(6786),
    [anon_sym_SLASH_EQ] = ACTIONS(6786),
    [anon_sym_PERCENT_EQ] = ACTIONS(6786),
    [anon_sym_PLUS_EQ] = ACTIONS(6786),
    [anon_sym_DASH_EQ] = ACTIONS(6786),
    [anon_sym_LT_LT_EQ] = ACTIONS(6786),
    [anon_sym_GT_GT_EQ] = ACTIONS(6786),
    [anon_sym_AMP_EQ] = ACTIONS(6786),
    [anon_sym_CARET_EQ] = ACTIONS(6786),
    [anon_sym_PIPE_EQ] = ACTIONS(6786),
    [anon_sym_and_eq] = ACTIONS(6784),
    [anon_sym_or_eq] = ACTIONS(6784),
    [anon_sym_xor_eq] = ACTIONS(6784),
    [anon_sym_LT_EQ_GT] = ACTIONS(6786),
    [anon_sym_or] = ACTIONS(6784),
    [anon_sym_and] = ACTIONS(6784),
    [anon_sym_bitor] = ACTIONS(6784),
    [anon_sym_xor] = ACTIONS(6784),
    [anon_sym_bitand] = ACTIONS(6784),
    [anon_sym_not_eq] = ACTIONS(6784),
    [anon_sym_DASH_DASH] = ACTIONS(6710),
    [anon_sym_PLUS_PLUS] = ACTIONS(6710),
    [anon_sym_DOT] = ACTIONS(6693),
    [anon_sym_DOT_STAR] = ACTIONS(6695),
    [anon_sym_DASH_GT] = ACTIONS(6695),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6786),
  },
  [STATE(2682)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2689),
    [anon_sym_COMMA] = ACTIONS(5988),
    [anon_sym_RPAREN] = ACTIONS(5988),
    [anon_sym_LPAREN2] = ACTIONS(5988),
    [anon_sym_STAR] = ACTIONS(5988),
    [anon_sym_AMP_AMP] = ACTIONS(5988),
    [anon_sym_AMP] = ACTIONS(5990),
    [anon_sym_SEMI] = ACTIONS(5988),
    [anon_sym___extension__] = ACTIONS(5988),
    [anon_sym___device__] = ACTIONS(5988),
    [anon_sym___host__] = ACTIONS(5988),
    [anon_sym___global__] = ACTIONS(5988),
    [anon_sym___forceinline__] = ACTIONS(5988),
    [anon_sym___noinline__] = ACTIONS(5988),
    [anon_sym_virtual] = ACTIONS(5988),
    [anon_sym_extern] = ACTIONS(5988),
    [anon_sym___attribute__] = ACTIONS(5988),
    [anon_sym___attribute] = ACTIONS(5990),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5988),
    [anon_sym___declspec] = ACTIONS(5988),
    [anon_sym_LBRACE] = ACTIONS(5988),
    [anon_sym_signed] = ACTIONS(6788),
    [anon_sym_unsigned] = ACTIONS(6788),
    [anon_sym_long] = ACTIONS(6788),
    [anon_sym_short] = ACTIONS(6788),
    [anon_sym_LBRACK] = ACTIONS(5990),
    [anon_sym_static] = ACTIONS(5988),
    [anon_sym_EQ] = ACTIONS(5988),
    [anon_sym_register] = ACTIONS(5988),
    [anon_sym_inline] = ACTIONS(5988),
    [anon_sym___inline] = ACTIONS(5990),
    [anon_sym___inline__] = ACTIONS(5988),
    [anon_sym___forceinline] = ACTIONS(5990),
    [anon_sym_thread_local] = ACTIONS(5988),
    [anon_sym___thread] = ACTIONS(5988),
    [anon_sym_const] = ACTIONS(5990),
    [anon_sym_constexpr] = ACTIONS(5988),
    [anon_sym_volatile] = ACTIONS(5988),
    [anon_sym_restrict] = ACTIONS(5988),
    [anon_sym___restrict__] = ACTIONS(5988),
    [anon_sym__Atomic] = ACTIONS(5988),
    [anon_sym__Noreturn] = ACTIONS(5988),
    [anon_sym_noreturn] = ACTIONS(5988),
    [anon_sym__Nonnull] = ACTIONS(5988),
    [anon_sym_mutable] = ACTIONS(5988),
    [anon_sym_constinit] = ACTIONS(5988),
    [anon_sym_consteval] = ACTIONS(5988),
    [anon_sym___shared__] = ACTIONS(5988),
    [anon_sym___local__] = ACTIONS(5988),
    [anon_sym___constant__] = ACTIONS(5988),
    [anon_sym___managed__] = ACTIONS(5988),
    [anon_sym___grid_constant__] = ACTIONS(5988),
    [anon_sym_alignas] = ACTIONS(5988),
    [anon_sym__Alignas] = ACTIONS(5988),
    [anon_sym_asm] = ACTIONS(5988),
    [anon_sym___asm__] = ACTIONS(5988),
    [anon_sym___asm] = ACTIONS(5990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5988),
    [anon_sym_decltype] = ACTIONS(5988),
    [anon_sym_final] = ACTIONS(5988),
    [anon_sym_override] = ACTIONS(5988),
    [anon_sym_GT2] = ACTIONS(5988),
    [anon_sym_try] = ACTIONS(5988),
    [anon_sym_requires] = ACTIONS(5988),
    [anon_sym___launch_bounds__] = ACTIONS(5988),
  },
  [STATE(2683)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_TILDE] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5663),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym___cdecl] = ACTIONS(5684),
    [anon_sym___clrcall] = ACTIONS(5684),
    [anon_sym___stdcall] = ACTIONS(5684),
    [anon_sym___fastcall] = ACTIONS(5684),
    [anon_sym___thiscall] = ACTIONS(5684),
    [anon_sym___vectorcall] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5690),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_template] = ACTIONS(5684),
    [anon_sym_operator] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2684)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2623),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5966),
    [anon_sym_COMMA] = ACTIONS(5966),
    [anon_sym_RPAREN] = ACTIONS(5966),
    [anon_sym_LPAREN2] = ACTIONS(5966),
    [anon_sym_DASH] = ACTIONS(5968),
    [anon_sym_PLUS] = ACTIONS(5968),
    [anon_sym_STAR] = ACTIONS(5968),
    [anon_sym_SLASH] = ACTIONS(5968),
    [anon_sym_PERCENT] = ACTIONS(5968),
    [anon_sym_PIPE_PIPE] = ACTIONS(5966),
    [anon_sym_AMP_AMP] = ACTIONS(5966),
    [anon_sym_PIPE] = ACTIONS(5968),
    [anon_sym_CARET] = ACTIONS(5968),
    [anon_sym_AMP] = ACTIONS(5968),
    [anon_sym_EQ_EQ] = ACTIONS(5966),
    [anon_sym_BANG_EQ] = ACTIONS(5966),
    [anon_sym_GT] = ACTIONS(5968),
    [anon_sym_GT_EQ] = ACTIONS(5966),
    [anon_sym_LT_EQ] = ACTIONS(5968),
    [anon_sym_LT] = ACTIONS(5968),
    [anon_sym_LT_LT] = ACTIONS(5968),
    [anon_sym_GT_GT] = ACTIONS(5968),
    [anon_sym_SEMI] = ACTIONS(5966),
    [anon_sym___attribute__] = ACTIONS(5966),
    [anon_sym___attribute] = ACTIONS(5968),
    [anon_sym_LBRACE] = ACTIONS(5966),
    [anon_sym_RBRACE] = ACTIONS(5966),
    [anon_sym_signed] = ACTIONS(6790),
    [anon_sym_unsigned] = ACTIONS(6790),
    [anon_sym_long] = ACTIONS(6790),
    [anon_sym_short] = ACTIONS(6790),
    [anon_sym_LBRACK] = ACTIONS(5966),
    [anon_sym_RBRACK] = ACTIONS(5966),
    [anon_sym_EQ] = ACTIONS(5968),
    [anon_sym_COLON] = ACTIONS(5966),
    [anon_sym_QMARK] = ACTIONS(5966),
    [anon_sym_STAR_EQ] = ACTIONS(5966),
    [anon_sym_SLASH_EQ] = ACTIONS(5966),
    [anon_sym_PERCENT_EQ] = ACTIONS(5966),
    [anon_sym_PLUS_EQ] = ACTIONS(5966),
    [anon_sym_DASH_EQ] = ACTIONS(5966),
    [anon_sym_LT_LT_EQ] = ACTIONS(5966),
    [anon_sym_GT_GT_EQ] = ACTIONS(5966),
    [anon_sym_AMP_EQ] = ACTIONS(5966),
    [anon_sym_CARET_EQ] = ACTIONS(5966),
    [anon_sym_PIPE_EQ] = ACTIONS(5966),
    [anon_sym_and_eq] = ACTIONS(5966),
    [anon_sym_or_eq] = ACTIONS(5966),
    [anon_sym_xor_eq] = ACTIONS(5966),
    [anon_sym_LT_EQ_GT] = ACTIONS(5966),
    [anon_sym_or] = ACTIONS(5968),
    [anon_sym_and] = ACTIONS(5968),
    [anon_sym_bitor] = ACTIONS(5966),
    [anon_sym_xor] = ACTIONS(5968),
    [anon_sym_bitand] = ACTIONS(5966),
    [anon_sym_not_eq] = ACTIONS(5966),
    [anon_sym_DASH_DASH] = ACTIONS(5966),
    [anon_sym_PLUS_PLUS] = ACTIONS(5966),
    [anon_sym_DOT] = ACTIONS(5968),
    [anon_sym_DOT_STAR] = ACTIONS(5966),
    [anon_sym_DASH_GT] = ACTIONS(5966),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5966),
    [anon_sym_decltype] = ACTIONS(5966),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5966),
  },
  [STATE(2685)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_typedef] = ACTIONS(6792),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2686)] = {
    [sym_attribute_specifier] = STATE(2241),
    [sym_enumerator_list] = STATE(2563),
    [sym__enum_base_clause] = STATE(2369),
    [sym_identifier] = ACTIONS(6671),
    [anon_sym_LPAREN2] = ACTIONS(6673),
    [anon_sym_TILDE] = ACTIONS(6673),
    [anon_sym_STAR] = ACTIONS(6673),
    [anon_sym_AMP_AMP] = ACTIONS(6673),
    [anon_sym_AMP] = ACTIONS(6671),
    [anon_sym_SEMI] = ACTIONS(6673),
    [anon_sym___extension__] = ACTIONS(6671),
    [anon_sym___device__] = ACTIONS(6671),
    [anon_sym___host__] = ACTIONS(6671),
    [anon_sym___global__] = ACTIONS(6671),
    [anon_sym___forceinline__] = ACTIONS(6671),
    [anon_sym___noinline__] = ACTIONS(6671),
    [anon_sym_virtual] = ACTIONS(6671),
    [anon_sym_extern] = ACTIONS(6671),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___attribute] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(6673),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6673),
    [anon_sym___declspec] = ACTIONS(6671),
    [anon_sym___based] = ACTIONS(6671),
    [anon_sym___cdecl] = ACTIONS(6671),
    [anon_sym___clrcall] = ACTIONS(6671),
    [anon_sym___stdcall] = ACTIONS(6671),
    [anon_sym___fastcall] = ACTIONS(6671),
    [anon_sym___thiscall] = ACTIONS(6671),
    [anon_sym___vectorcall] = ACTIONS(6671),
    [anon_sym_LBRACE] = ACTIONS(6360),
    [anon_sym_LBRACK] = ACTIONS(6671),
    [anon_sym_static] = ACTIONS(6671),
    [anon_sym_register] = ACTIONS(6671),
    [anon_sym_inline] = ACTIONS(6671),
    [anon_sym___inline] = ACTIONS(6671),
    [anon_sym___inline__] = ACTIONS(6671),
    [anon_sym___forceinline] = ACTIONS(6671),
    [anon_sym_thread_local] = ACTIONS(6671),
    [anon_sym___thread] = ACTIONS(6671),
    [anon_sym_const] = ACTIONS(6671),
    [anon_sym_constexpr] = ACTIONS(6671),
    [anon_sym_volatile] = ACTIONS(6671),
    [anon_sym_restrict] = ACTIONS(6671),
    [anon_sym___restrict__] = ACTIONS(6671),
    [anon_sym__Atomic] = ACTIONS(6671),
    [anon_sym__Noreturn] = ACTIONS(6671),
    [anon_sym_noreturn] = ACTIONS(6671),
    [anon_sym__Nonnull] = ACTIONS(6671),
    [anon_sym_mutable] = ACTIONS(6671),
    [anon_sym_constinit] = ACTIONS(6671),
    [anon_sym_consteval] = ACTIONS(6671),
    [anon_sym___shared__] = ACTIONS(6671),
    [anon_sym___local__] = ACTIONS(6671),
    [anon_sym___constant__] = ACTIONS(6671),
    [anon_sym___managed__] = ACTIONS(6671),
    [anon_sym___grid_constant__] = ACTIONS(6671),
    [anon_sym_alignas] = ACTIONS(6671),
    [anon_sym__Alignas] = ACTIONS(6671),
    [anon_sym_COLON] = ACTIONS(6742),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6671),
    [anon_sym_decltype] = ACTIONS(6671),
    [anon_sym_template] = ACTIONS(6671),
    [anon_sym_operator] = ACTIONS(6671),
    [anon_sym___launch_bounds__] = ACTIONS(6671),
  },
  [STATE(2687)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2661),
    [anon_sym_COMMA] = ACTIONS(5917),
    [anon_sym_RPAREN] = ACTIONS(5917),
    [anon_sym_LPAREN2] = ACTIONS(5917),
    [anon_sym_STAR] = ACTIONS(5917),
    [anon_sym_AMP_AMP] = ACTIONS(5917),
    [anon_sym_AMP] = ACTIONS(5919),
    [anon_sym_SEMI] = ACTIONS(5917),
    [anon_sym___extension__] = ACTIONS(5917),
    [anon_sym___device__] = ACTIONS(5917),
    [anon_sym___host__] = ACTIONS(5917),
    [anon_sym___global__] = ACTIONS(5917),
    [anon_sym___forceinline__] = ACTIONS(5917),
    [anon_sym___noinline__] = ACTIONS(5917),
    [anon_sym_virtual] = ACTIONS(5917),
    [anon_sym_extern] = ACTIONS(5917),
    [anon_sym___attribute__] = ACTIONS(5917),
    [anon_sym___attribute] = ACTIONS(5919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5917),
    [anon_sym___declspec] = ACTIONS(5917),
    [anon_sym_LBRACE] = ACTIONS(5917),
    [anon_sym_signed] = ACTIONS(6794),
    [anon_sym_unsigned] = ACTIONS(6794),
    [anon_sym_long] = ACTIONS(6794),
    [anon_sym_short] = ACTIONS(6794),
    [anon_sym_LBRACK] = ACTIONS(5919),
    [anon_sym_static] = ACTIONS(5917),
    [anon_sym_EQ] = ACTIONS(5917),
    [anon_sym_register] = ACTIONS(5917),
    [anon_sym_inline] = ACTIONS(5917),
    [anon_sym___inline] = ACTIONS(5919),
    [anon_sym___inline__] = ACTIONS(5917),
    [anon_sym___forceinline] = ACTIONS(5919),
    [anon_sym_thread_local] = ACTIONS(5917),
    [anon_sym___thread] = ACTIONS(5917),
    [anon_sym_const] = ACTIONS(5919),
    [anon_sym_constexpr] = ACTIONS(5917),
    [anon_sym_volatile] = ACTIONS(5917),
    [anon_sym_restrict] = ACTIONS(5917),
    [anon_sym___restrict__] = ACTIONS(5917),
    [anon_sym__Atomic] = ACTIONS(5917),
    [anon_sym__Noreturn] = ACTIONS(5917),
    [anon_sym_noreturn] = ACTIONS(5917),
    [anon_sym__Nonnull] = ACTIONS(5917),
    [anon_sym_mutable] = ACTIONS(5917),
    [anon_sym_constinit] = ACTIONS(5917),
    [anon_sym_consteval] = ACTIONS(5917),
    [anon_sym___shared__] = ACTIONS(5917),
    [anon_sym___local__] = ACTIONS(5917),
    [anon_sym___constant__] = ACTIONS(5917),
    [anon_sym___managed__] = ACTIONS(5917),
    [anon_sym___grid_constant__] = ACTIONS(5917),
    [anon_sym_alignas] = ACTIONS(5917),
    [anon_sym__Alignas] = ACTIONS(5917),
    [anon_sym_asm] = ACTIONS(5917),
    [anon_sym___asm__] = ACTIONS(5917),
    [anon_sym___asm] = ACTIONS(5919),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5917),
    [anon_sym_decltype] = ACTIONS(5917),
    [anon_sym_final] = ACTIONS(5917),
    [anon_sym_override] = ACTIONS(5917),
    [anon_sym_GT2] = ACTIONS(5917),
    [anon_sym_try] = ACTIONS(5917),
    [anon_sym_requires] = ACTIONS(5917),
    [anon_sym___launch_bounds__] = ACTIONS(5917),
  },
  [STATE(2688)] = {
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_TILDE] = ACTIONS(5686),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym___extension__] = ACTIONS(5684),
    [anon_sym___device__] = ACTIONS(5684),
    [anon_sym___host__] = ACTIONS(5684),
    [anon_sym___global__] = ACTIONS(5684),
    [anon_sym___forceinline__] = ACTIONS(5684),
    [anon_sym___noinline__] = ACTIONS(5684),
    [anon_sym_virtual] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5684),
    [anon_sym___attribute__] = ACTIONS(5684),
    [anon_sym___attribute] = ACTIONS(5684),
    [anon_sym_COLON_COLON] = ACTIONS(5686),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5686),
    [anon_sym___declspec] = ACTIONS(5684),
    [anon_sym___based] = ACTIONS(5684),
    [anon_sym___cdecl] = ACTIONS(5684),
    [anon_sym___clrcall] = ACTIONS(5684),
    [anon_sym___stdcall] = ACTIONS(5684),
    [anon_sym___fastcall] = ACTIONS(5684),
    [anon_sym___thiscall] = ACTIONS(5684),
    [anon_sym___vectorcall] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5690),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_static] = ACTIONS(5684),
    [anon_sym_EQ] = ACTIONS(5686),
    [anon_sym_register] = ACTIONS(5684),
    [anon_sym_inline] = ACTIONS(5684),
    [anon_sym___inline] = ACTIONS(5684),
    [anon_sym___inline__] = ACTIONS(5684),
    [anon_sym___forceinline] = ACTIONS(5684),
    [anon_sym_thread_local] = ACTIONS(5684),
    [anon_sym___thread] = ACTIONS(5684),
    [anon_sym_const] = ACTIONS(5684),
    [anon_sym_constexpr] = ACTIONS(5684),
    [anon_sym_volatile] = ACTIONS(5684),
    [anon_sym_restrict] = ACTIONS(5684),
    [anon_sym___restrict__] = ACTIONS(5684),
    [anon_sym__Atomic] = ACTIONS(5684),
    [anon_sym__Noreturn] = ACTIONS(5684),
    [anon_sym_noreturn] = ACTIONS(5684),
    [anon_sym__Nonnull] = ACTIONS(5684),
    [anon_sym_mutable] = ACTIONS(5684),
    [anon_sym_constinit] = ACTIONS(5684),
    [anon_sym_consteval] = ACTIONS(5684),
    [anon_sym___shared__] = ACTIONS(5684),
    [anon_sym___local__] = ACTIONS(5684),
    [anon_sym___constant__] = ACTIONS(5684),
    [anon_sym___managed__] = ACTIONS(5684),
    [anon_sym___grid_constant__] = ACTIONS(5684),
    [anon_sym_alignas] = ACTIONS(5684),
    [anon_sym__Alignas] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [anon_sym_template] = ACTIONS(5684),
    [anon_sym_operator] = ACTIONS(5684),
    [anon_sym___launch_bounds__] = ACTIONS(5684),
  },
  [STATE(2689)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1902),
    [anon_sym_COMMA] = ACTIONS(5980),
    [anon_sym_RPAREN] = ACTIONS(5980),
    [anon_sym_LPAREN2] = ACTIONS(5980),
    [anon_sym_STAR] = ACTIONS(5980),
    [anon_sym_AMP_AMP] = ACTIONS(5980),
    [anon_sym_AMP] = ACTIONS(5982),
    [anon_sym_SEMI] = ACTIONS(5980),
    [anon_sym___extension__] = ACTIONS(5980),
    [anon_sym___device__] = ACTIONS(5980),
    [anon_sym___host__] = ACTIONS(5980),
    [anon_sym___global__] = ACTIONS(5980),
    [anon_sym___forceinline__] = ACTIONS(5980),
    [anon_sym___noinline__] = ACTIONS(5980),
    [anon_sym_virtual] = ACTIONS(5980),
    [anon_sym_extern] = ACTIONS(5980),
    [anon_sym___attribute__] = ACTIONS(5980),
    [anon_sym___attribute] = ACTIONS(5982),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5980),
    [anon_sym___declspec] = ACTIONS(5980),
    [anon_sym_LBRACE] = ACTIONS(5980),
    [anon_sym_signed] = ACTIONS(6718),
    [anon_sym_unsigned] = ACTIONS(6718),
    [anon_sym_long] = ACTIONS(6718),
    [anon_sym_short] = ACTIONS(6718),
    [anon_sym_LBRACK] = ACTIONS(5982),
    [anon_sym_static] = ACTIONS(5980),
    [anon_sym_EQ] = ACTIONS(5980),
    [anon_sym_register] = ACTIONS(5980),
    [anon_sym_inline] = ACTIONS(5980),
    [anon_sym___inline] = ACTIONS(5982),
    [anon_sym___inline__] = ACTIONS(5980),
    [anon_sym___forceinline] = ACTIONS(5982),
    [anon_sym_thread_local] = ACTIONS(5980),
    [anon_sym___thread] = ACTIONS(5980),
    [anon_sym_const] = ACTIONS(5982),
    [anon_sym_constexpr] = ACTIONS(5980),
    [anon_sym_volatile] = ACTIONS(5980),
    [anon_sym_restrict] = ACTIONS(5980),
    [anon_sym___restrict__] = ACTIONS(5980),
    [anon_sym__Atomic] = ACTIONS(5980),
    [anon_sym__Noreturn] = ACTIONS(5980),
    [anon_sym_noreturn] = ACTIONS(5980),
    [anon_sym__Nonnull] = ACTIONS(5980),
    [anon_sym_mutable] = ACTIONS(5980),
    [anon_sym_constinit] = ACTIONS(5980),
    [anon_sym_consteval] = ACTIONS(5980),
    [anon_sym___shared__] = ACTIONS(5980),
    [anon_sym___local__] = ACTIONS(5980),
    [anon_sym___constant__] = ACTIONS(5980),
    [anon_sym___managed__] = ACTIONS(5980),
    [anon_sym___grid_constant__] = ACTIONS(5980),
    [anon_sym_alignas] = ACTIONS(5980),
    [anon_sym__Alignas] = ACTIONS(5980),
    [anon_sym_asm] = ACTIONS(5980),
    [anon_sym___asm__] = ACTIONS(5980),
    [anon_sym___asm] = ACTIONS(5982),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5980),
    [anon_sym_decltype] = ACTIONS(5980),
    [anon_sym_final] = ACTIONS(5980),
    [anon_sym_override] = ACTIONS(5980),
    [anon_sym_GT2] = ACTIONS(5980),
    [anon_sym_try] = ACTIONS(5980),
    [anon_sym_requires] = ACTIONS(5980),
    [anon_sym___launch_bounds__] = ACTIONS(5980),
  },
  [STATE(2690)] = {
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym_namespace] = ACTIONS(6796),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2691)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(1654),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5898),
    [anon_sym_COMMA] = ACTIONS(5898),
    [anon_sym_RPAREN] = ACTIONS(5898),
    [anon_sym_LPAREN2] = ACTIONS(5898),
    [anon_sym_DASH] = ACTIONS(5900),
    [anon_sym_PLUS] = ACTIONS(5900),
    [anon_sym_STAR] = ACTIONS(5900),
    [anon_sym_SLASH] = ACTIONS(5900),
    [anon_sym_PERCENT] = ACTIONS(5900),
    [anon_sym_PIPE_PIPE] = ACTIONS(5898),
    [anon_sym_AMP_AMP] = ACTIONS(5898),
    [anon_sym_PIPE] = ACTIONS(5900),
    [anon_sym_CARET] = ACTIONS(5900),
    [anon_sym_AMP] = ACTIONS(5900),
    [anon_sym_EQ_EQ] = ACTIONS(5898),
    [anon_sym_BANG_EQ] = ACTIONS(5898),
    [anon_sym_GT] = ACTIONS(5900),
    [anon_sym_GT_EQ] = ACTIONS(5898),
    [anon_sym_LT_EQ] = ACTIONS(5900),
    [anon_sym_LT] = ACTIONS(5900),
    [anon_sym_LT_LT] = ACTIONS(5900),
    [anon_sym_GT_GT] = ACTIONS(5900),
    [anon_sym_SEMI] = ACTIONS(5898),
    [anon_sym___attribute__] = ACTIONS(5898),
    [anon_sym___attribute] = ACTIONS(5900),
    [anon_sym_LBRACE] = ACTIONS(5898),
    [anon_sym_RBRACE] = ACTIONS(5898),
    [anon_sym_signed] = ACTIONS(6681),
    [anon_sym_unsigned] = ACTIONS(6681),
    [anon_sym_long] = ACTIONS(6681),
    [anon_sym_short] = ACTIONS(6681),
    [anon_sym_LBRACK] = ACTIONS(5898),
    [anon_sym_RBRACK] = ACTIONS(5898),
    [anon_sym_EQ] = ACTIONS(5900),
    [anon_sym_COLON] = ACTIONS(5898),
    [anon_sym_QMARK] = ACTIONS(5898),
    [anon_sym_STAR_EQ] = ACTIONS(5898),
    [anon_sym_SLASH_EQ] = ACTIONS(5898),
    [anon_sym_PERCENT_EQ] = ACTIONS(5898),
    [anon_sym_PLUS_EQ] = ACTIONS(5898),
    [anon_sym_DASH_EQ] = ACTIONS(5898),
    [anon_sym_LT_LT_EQ] = ACTIONS(5898),
    [anon_sym_GT_GT_EQ] = ACTIONS(5898),
    [anon_sym_AMP_EQ] = ACTIONS(5898),
    [anon_sym_CARET_EQ] = ACTIONS(5898),
    [anon_sym_PIPE_EQ] = ACTIONS(5898),
    [anon_sym_and_eq] = ACTIONS(5898),
    [anon_sym_or_eq] = ACTIONS(5898),
    [anon_sym_xor_eq] = ACTIONS(5898),
    [anon_sym_LT_EQ_GT] = ACTIONS(5898),
    [anon_sym_or] = ACTIONS(5900),
    [anon_sym_and] = ACTIONS(5900),
    [anon_sym_bitor] = ACTIONS(5898),
    [anon_sym_xor] = ACTIONS(5900),
    [anon_sym_bitand] = ACTIONS(5898),
    [anon_sym_not_eq] = ACTIONS(5898),
    [anon_sym_DASH_DASH] = ACTIONS(5898),
    [anon_sym_PLUS_PLUS] = ACTIONS(5898),
    [anon_sym_DOT] = ACTIONS(5900),
    [anon_sym_DOT_STAR] = ACTIONS(5898),
    [anon_sym_DASH_GT] = ACTIONS(5898),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5898),
    [anon_sym_decltype] = ACTIONS(5898),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5898),
  },
  [STATE(2692)] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1959),
    [anon_sym_TILDE] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_AMP_AMP] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___device__] = ACTIONS(1969),
    [anon_sym___host__] = ACTIONS(1969),
    [anon_sym___global__] = ACTIONS(1969),
    [anon_sym___forceinline__] = ACTIONS(1969),
    [anon_sym___noinline__] = ACTIONS(1969),
    [anon_sym_virtual] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym___attribute] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1959),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1959),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym__Nonnull] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym___shared__] = ACTIONS(1969),
    [anon_sym___local__] = ACTIONS(1969),
    [anon_sym___constant__] = ACTIONS(1969),
    [anon_sym___managed__] = ACTIONS(1969),
    [anon_sym___grid_constant__] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_friend] = ACTIONS(6798),
    [anon_sym___launch_bounds__] = ACTIONS(1969),
  },
  [STATE(2693)] = {
    [sym_identifier] = ACTIONS(6800),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6802),
    [anon_sym_COMMA] = ACTIONS(6802),
    [anon_sym_RPAREN] = ACTIONS(6802),
    [aux_sym_preproc_if_token2] = ACTIONS(6802),
    [aux_sym_preproc_else_token1] = ACTIONS(6802),
    [aux_sym_preproc_elif_token1] = ACTIONS(6800),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6802),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6802),
    [anon_sym_LPAREN2] = ACTIONS(6802),
    [anon_sym_DASH] = ACTIONS(6800),
    [anon_sym_PLUS] = ACTIONS(6800),
    [anon_sym_STAR] = ACTIONS(6800),
    [anon_sym_SLASH] = ACTIONS(6800),
    [anon_sym_PERCENT] = ACTIONS(6800),
    [anon_sym_PIPE_PIPE] = ACTIONS(6802),
    [anon_sym_AMP_AMP] = ACTIONS(6802),
    [anon_sym_PIPE] = ACTIONS(6800),
    [anon_sym_CARET] = ACTIONS(6800),
    [anon_sym_AMP] = ACTIONS(6800),
    [anon_sym_EQ_EQ] = ACTIONS(6802),
    [anon_sym_BANG_EQ] = ACTIONS(6802),
    [anon_sym_GT] = ACTIONS(6800),
    [anon_sym_GT_EQ] = ACTIONS(6802),
    [anon_sym_LT_EQ] = ACTIONS(6800),
    [anon_sym_LT] = ACTIONS(6800),
    [anon_sym_LT_LT] = ACTIONS(6800),
    [anon_sym_GT_GT] = ACTIONS(6800),
    [anon_sym_SEMI] = ACTIONS(6802),
    [anon_sym___attribute__] = ACTIONS(6800),
    [anon_sym___attribute] = ACTIONS(6800),
    [anon_sym_COLON_COLON] = ACTIONS(4560),
    [anon_sym_LBRACE] = ACTIONS(6802),
    [anon_sym_RBRACE] = ACTIONS(6802),
    [anon_sym_LBRACK] = ACTIONS(6802),
    [anon_sym_RBRACK] = ACTIONS(6802),
    [anon_sym_EQ] = ACTIONS(6800),
    [anon_sym_COLON] = ACTIONS(6800),
    [anon_sym_QMARK] = ACTIONS(6802),
    [anon_sym_STAR_EQ] = ACTIONS(6802),
    [anon_sym_SLASH_EQ] = ACTIONS(6802),
    [anon_sym_PERCENT_EQ] = ACTIONS(6802),
    [anon_sym_PLUS_EQ] = ACTIONS(6802),
    [anon_sym_DASH_EQ] = ACTIONS(6802),
    [anon_sym_LT_LT_EQ] = ACTIONS(6802),
    [anon_sym_GT_GT_EQ] = ACTIONS(6802),
    [anon_sym_AMP_EQ] = ACTIONS(6802),
    [anon_sym_CARET_EQ] = ACTIONS(6802),
    [anon_sym_PIPE_EQ] = ACTIONS(6802),
    [anon_sym_and_eq] = ACTIONS(6800),
    [anon_sym_or_eq] = ACTIONS(6800),
    [anon_sym_xor_eq] = ACTIONS(6800),
    [anon_sym_LT_EQ_GT] = ACTIONS(6802),
    [anon_sym_or] = ACTIONS(6800),
    [anon_sym_and] = ACTIONS(6800),
    [anon_sym_bitor] = ACTIONS(6800),
    [anon_sym_xor] = ACTIONS(6800),
    [anon_sym_bitand] = ACTIONS(6800),
    [anon_sym_not_eq] = ACTIONS(6800),
    [anon_sym_DASH_DASH] = ACTIONS(6802),
    [anon_sym_PLUS_PLUS] = ACTIONS(6802),
    [anon_sym_DOT] = ACTIONS(6800),
    [anon_sym_DOT_STAR] = ACTIONS(6802),
    [anon_sym_DASH_GT] = ACTIONS(6802),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6802),
  },
  [STATE(2694)] = {
    [sym_identifier] = ACTIONS(6804),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6806),
    [anon_sym_COMMA] = ACTIONS(6806),
    [anon_sym_RPAREN] = ACTIONS(6806),
    [aux_sym_preproc_if_token2] = ACTIONS(6806),
    [aux_sym_preproc_else_token1] = ACTIONS(6806),
    [aux_sym_preproc_elif_token1] = ACTIONS(6804),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6806),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6806),
    [anon_sym_LPAREN2] = ACTIONS(6806),
    [anon_sym_DASH] = ACTIONS(6804),
    [anon_sym_PLUS] = ACTIONS(6804),
    [anon_sym_STAR] = ACTIONS(6804),
    [anon_sym_SLASH] = ACTIONS(6804),
    [anon_sym_PERCENT] = ACTIONS(6804),
    [anon_sym_PIPE_PIPE] = ACTIONS(6806),
    [anon_sym_AMP_AMP] = ACTIONS(6806),
    [anon_sym_PIPE] = ACTIONS(6804),
    [anon_sym_CARET] = ACTIONS(6804),
    [anon_sym_AMP] = ACTIONS(6804),
    [anon_sym_EQ_EQ] = ACTIONS(6806),
    [anon_sym_BANG_EQ] = ACTIONS(6806),
    [anon_sym_GT] = ACTIONS(6804),
    [anon_sym_GT_EQ] = ACTIONS(6806),
    [anon_sym_LT_EQ] = ACTIONS(6804),
    [anon_sym_LT] = ACTIONS(6804),
    [anon_sym_LT_LT] = ACTIONS(6804),
    [anon_sym_GT_GT] = ACTIONS(6804),
    [anon_sym_SEMI] = ACTIONS(6806),
    [anon_sym___attribute__] = ACTIONS(6804),
    [anon_sym___attribute] = ACTIONS(6804),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6806),
    [anon_sym_RBRACE] = ACTIONS(6806),
    [anon_sym_LBRACK] = ACTIONS(6804),
    [anon_sym_RBRACK] = ACTIONS(6806),
    [anon_sym_EQ] = ACTIONS(6804),
    [anon_sym_COLON] = ACTIONS(6806),
    [anon_sym_QMARK] = ACTIONS(6806),
    [anon_sym_STAR_EQ] = ACTIONS(6806),
    [anon_sym_SLASH_EQ] = ACTIONS(6806),
    [anon_sym_PERCENT_EQ] = ACTIONS(6806),
    [anon_sym_PLUS_EQ] = ACTIONS(6806),
    [anon_sym_DASH_EQ] = ACTIONS(6806),
    [anon_sym_LT_LT_EQ] = ACTIONS(6806),
    [anon_sym_GT_GT_EQ] = ACTIONS(6806),
    [anon_sym_AMP_EQ] = ACTIONS(6806),
    [anon_sym_CARET_EQ] = ACTIONS(6806),
    [anon_sym_PIPE_EQ] = ACTIONS(6806),
    [anon_sym_and_eq] = ACTIONS(6804),
    [anon_sym_or_eq] = ACTIONS(6804),
    [anon_sym_xor_eq] = ACTIONS(6804),
    [anon_sym_LT_EQ_GT] = ACTIONS(6806),
    [anon_sym_or] = ACTIONS(6804),
    [anon_sym_and] = ACTIONS(6804),
    [anon_sym_bitor] = ACTIONS(6804),
    [anon_sym_xor] = ACTIONS(6804),
    [anon_sym_bitand] = ACTIONS(6804),
    [anon_sym_not_eq] = ACTIONS(6804),
    [anon_sym_DASH_DASH] = ACTIONS(6806),
    [anon_sym_PLUS_PLUS] = ACTIONS(6806),
    [anon_sym_DOT] = ACTIONS(6804),
    [anon_sym_DOT_STAR] = ACTIONS(6806),
    [anon_sym_DASH_GT] = ACTIONS(6806),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6806),
  },
  [STATE(2695)] = {
    [sym_identifier] = ACTIONS(3830),
    [anon_sym_LPAREN2] = ACTIONS(3832),
    [anon_sym_TILDE] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_AMP_AMP] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3830),
    [anon_sym___extension__] = ACTIONS(3830),
    [anon_sym___device__] = ACTIONS(3830),
    [anon_sym___host__] = ACTIONS(3830),
    [anon_sym___global__] = ACTIONS(3830),
    [anon_sym___forceinline__] = ACTIONS(3830),
    [anon_sym___noinline__] = ACTIONS(3830),
    [anon_sym_virtual] = ACTIONS(3830),
    [anon_sym_extern] = ACTIONS(3830),
    [anon_sym___attribute__] = ACTIONS(3830),
    [anon_sym___attribute] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(3832),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3832),
    [anon_sym___declspec] = ACTIONS(3830),
    [anon_sym___based] = ACTIONS(3830),
    [anon_sym_signed] = ACTIONS(3830),
    [anon_sym_unsigned] = ACTIONS(3830),
    [anon_sym_long] = ACTIONS(3830),
    [anon_sym_short] = ACTIONS(3830),
    [anon_sym_LBRACK] = ACTIONS(3830),
    [anon_sym_static] = ACTIONS(3830),
    [anon_sym_register] = ACTIONS(3830),
    [anon_sym_inline] = ACTIONS(3830),
    [anon_sym___inline] = ACTIONS(3830),
    [anon_sym___inline__] = ACTIONS(3830),
    [anon_sym___forceinline] = ACTIONS(3830),
    [anon_sym_thread_local] = ACTIONS(3830),
    [anon_sym___thread] = ACTIONS(3830),
    [anon_sym_const] = ACTIONS(3830),
    [anon_sym_constexpr] = ACTIONS(3830),
    [anon_sym_volatile] = ACTIONS(3830),
    [anon_sym_restrict] = ACTIONS(3830),
    [anon_sym___restrict__] = ACTIONS(3830),
    [anon_sym__Atomic] = ACTIONS(3830),
    [anon_sym__Noreturn] = ACTIONS(3830),
    [anon_sym_noreturn] = ACTIONS(3830),
    [anon_sym__Nonnull] = ACTIONS(3830),
    [anon_sym_mutable] = ACTIONS(3830),
    [anon_sym_constinit] = ACTIONS(3830),
    [anon_sym_consteval] = ACTIONS(3830),
    [anon_sym___shared__] = ACTIONS(3830),
    [anon_sym___local__] = ACTIONS(3830),
    [anon_sym___constant__] = ACTIONS(3830),
    [anon_sym___managed__] = ACTIONS(3830),
    [anon_sym___grid_constant__] = ACTIONS(3830),
    [anon_sym_alignas] = ACTIONS(3830),
    [anon_sym__Alignas] = ACTIONS(3830),
    [sym_primitive_type] = ACTIONS(3830),
    [anon_sym_enum] = ACTIONS(3830),
    [anon_sym_class] = ACTIONS(3830),
    [anon_sym_struct] = ACTIONS(3830),
    [anon_sym_union] = ACTIONS(3830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3830),
    [anon_sym_decltype] = ACTIONS(3830),
    [anon_sym_explicit] = ACTIONS(3830),
    [anon_sym_typename] = ACTIONS(3830),
    [anon_sym_template] = ACTIONS(3830),
    [anon_sym_operator] = ACTIONS(3830),
    [anon_sym___launch_bounds__] = ACTIONS(3830),
  },
  [STATE(2696)] = {
    [sym_string_literal] = STATE(2696),
    [sym_raw_string_literal] = STATE(2696),
    [aux_sym_concatenated_string_repeat1] = STATE(2696),
    [sym_identifier] = ACTIONS(6808),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5882),
    [anon_sym_COMMA] = ACTIONS(5882),
    [anon_sym_RPAREN] = ACTIONS(5882),
    [anon_sym_LPAREN2] = ACTIONS(5882),
    [anon_sym_DASH] = ACTIONS(5884),
    [anon_sym_PLUS] = ACTIONS(5884),
    [anon_sym_STAR] = ACTIONS(5884),
    [anon_sym_SLASH] = ACTIONS(5884),
    [anon_sym_PERCENT] = ACTIONS(5884),
    [anon_sym_PIPE_PIPE] = ACTIONS(5882),
    [anon_sym_AMP_AMP] = ACTIONS(5882),
    [anon_sym_PIPE] = ACTIONS(5884),
    [anon_sym_CARET] = ACTIONS(5884),
    [anon_sym_AMP] = ACTIONS(5884),
    [anon_sym_EQ_EQ] = ACTIONS(5882),
    [anon_sym_BANG_EQ] = ACTIONS(5882),
    [anon_sym_GT] = ACTIONS(5884),
    [anon_sym_GT_EQ] = ACTIONS(5882),
    [anon_sym_LT_EQ] = ACTIONS(5884),
    [anon_sym_LT] = ACTIONS(5884),
    [anon_sym_LT_LT] = ACTIONS(5884),
    [anon_sym_GT_GT] = ACTIONS(5884),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_EQ] = ACTIONS(5884),
    [anon_sym_QMARK] = ACTIONS(5882),
    [anon_sym_STAR_EQ] = ACTIONS(5882),
    [anon_sym_SLASH_EQ] = ACTIONS(5882),
    [anon_sym_PERCENT_EQ] = ACTIONS(5882),
    [anon_sym_PLUS_EQ] = ACTIONS(5882),
    [anon_sym_DASH_EQ] = ACTIONS(5882),
    [anon_sym_LT_LT_EQ] = ACTIONS(5882),
    [anon_sym_GT_GT_EQ] = ACTIONS(5882),
    [anon_sym_AMP_EQ] = ACTIONS(5882),
    [anon_sym_CARET_EQ] = ACTIONS(5882),
    [anon_sym_PIPE_EQ] = ACTIONS(5882),
    [anon_sym_LT_EQ_GT] = ACTIONS(5882),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_bitor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_bitand] = ACTIONS(5884),
    [anon_sym_not_eq] = ACTIONS(5884),
    [anon_sym_DASH_DASH] = ACTIONS(5882),
    [anon_sym_PLUS_PLUS] = ACTIONS(5882),
    [anon_sym_DOT] = ACTIONS(5884),
    [anon_sym_DOT_STAR] = ACTIONS(5882),
    [anon_sym_DASH_GT] = ACTIONS(5884),
    [anon_sym_L_DQUOTE] = ACTIONS(6811),
    [anon_sym_u_DQUOTE] = ACTIONS(6811),
    [anon_sym_U_DQUOTE] = ACTIONS(6811),
    [anon_sym_u8_DQUOTE] = ACTIONS(6811),
    [anon_sym_DQUOTE] = ACTIONS(6811),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6814),
    [anon_sym_LR_DQUOTE] = ACTIONS(6814),
    [anon_sym_uR_DQUOTE] = ACTIONS(6814),
    [anon_sym_UR_DQUOTE] = ACTIONS(6814),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6814),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5882),
    [sym_literal_suffix] = ACTIONS(5884),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5882),
  },
  [STATE(2697)] = {
    [sym_identifier] = ACTIONS(6817),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6819),
    [anon_sym_COMMA] = ACTIONS(6819),
    [anon_sym_RPAREN] = ACTIONS(6819),
    [aux_sym_preproc_if_token2] = ACTIONS(6819),
    [aux_sym_preproc_else_token1] = ACTIONS(6819),
    [aux_sym_preproc_elif_token1] = ACTIONS(6817),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6819),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6819),
    [anon_sym_LPAREN2] = ACTIONS(6819),
    [anon_sym_DASH] = ACTIONS(6817),
    [anon_sym_PLUS] = ACTIONS(6817),
    [anon_sym_STAR] = ACTIONS(6817),
    [anon_sym_SLASH] = ACTIONS(6817),
    [anon_sym_PERCENT] = ACTIONS(6817),
    [anon_sym_PIPE_PIPE] = ACTIONS(6819),
    [anon_sym_AMP_AMP] = ACTIONS(6819),
    [anon_sym_PIPE] = ACTIONS(6817),
    [anon_sym_CARET] = ACTIONS(6817),
    [anon_sym_AMP] = ACTIONS(6817),
    [anon_sym_EQ_EQ] = ACTIONS(6819),
    [anon_sym_BANG_EQ] = ACTIONS(6819),
    [anon_sym_GT] = ACTIONS(6817),
    [anon_sym_GT_EQ] = ACTIONS(6819),
    [anon_sym_LT_EQ] = ACTIONS(6817),
    [anon_sym_LT] = ACTIONS(6817),
    [anon_sym_LT_LT] = ACTIONS(6817),
    [anon_sym_GT_GT] = ACTIONS(6817),
    [anon_sym_SEMI] = ACTIONS(6819),
    [anon_sym___attribute__] = ACTIONS(6817),
    [anon_sym___attribute] = ACTIONS(6817),
    [anon_sym_RBRACE] = ACTIONS(6819),
    [anon_sym_LBRACK] = ACTIONS(6817),
    [anon_sym_RBRACK] = ACTIONS(6819),
    [anon_sym_EQ] = ACTIONS(6817),
    [anon_sym_COLON] = ACTIONS(6819),
    [anon_sym_QMARK] = ACTIONS(6819),
    [anon_sym_STAR_EQ] = ACTIONS(6819),
    [anon_sym_SLASH_EQ] = ACTIONS(6819),
    [anon_sym_PERCENT_EQ] = ACTIONS(6819),
    [anon_sym_PLUS_EQ] = ACTIONS(6819),
    [anon_sym_DASH_EQ] = ACTIONS(6819),
    [anon_sym_LT_LT_EQ] = ACTIONS(6819),
    [anon_sym_GT_GT_EQ] = ACTIONS(6819),
    [anon_sym_AMP_EQ] = ACTIONS(6819),
    [anon_sym_CARET_EQ] = ACTIONS(6819),
    [anon_sym_PIPE_EQ] = ACTIONS(6819),
    [anon_sym_and_eq] = ACTIONS(6817),
    [anon_sym_or_eq] = ACTIONS(6817),
    [anon_sym_xor_eq] = ACTIONS(6817),
    [anon_sym_LT_EQ_GT] = ACTIONS(6819),
    [anon_sym_or] = ACTIONS(6817),
    [anon_sym_and] = ACTIONS(6817),
    [anon_sym_bitor] = ACTIONS(6817),
    [anon_sym_xor] = ACTIONS(6817),
    [anon_sym_bitand] = ACTIONS(6817),
    [anon_sym_not_eq] = ACTIONS(6817),
    [anon_sym_DASH_DASH] = ACTIONS(6819),
    [anon_sym_PLUS_PLUS] = ACTIONS(6819),
    [anon_sym_DOT] = ACTIONS(6817),
    [anon_sym_DOT_STAR] = ACTIONS(6819),
    [anon_sym_DASH_GT] = ACTIONS(6819),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LBRACK_RBRACK] = ACTIONS(6821),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6819),
  },
  [STATE(2698)] = {
    [sym_template_argument_list] = STATE(2360),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4010),
    [anon_sym_COMMA] = ACTIONS(6823),
    [anon_sym_LPAREN2] = ACTIONS(4010),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_STAR] = ACTIONS(4010),
    [anon_sym_AMP_AMP] = ACTIONS(4010),
    [anon_sym_AMP] = ACTIONS(4002),
    [anon_sym_LT] = ACTIONS(6782),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4010),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(4002),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(6825),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_GT2] = ACTIONS(6823),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(2699)] = {
    [sym_string_literal] = STATE(2582),
    [sym_raw_string_literal] = STATE(2582),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6354),
    [anon_sym_COMMA] = ACTIONS(6354),
    [anon_sym_LPAREN2] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6352),
    [anon_sym_STAR] = ACTIONS(6352),
    [anon_sym_SLASH] = ACTIONS(6352),
    [anon_sym_PERCENT] = ACTIONS(6352),
    [anon_sym_PIPE_PIPE] = ACTIONS(6354),
    [anon_sym_AMP_AMP] = ACTIONS(6354),
    [anon_sym_PIPE] = ACTIONS(6352),
    [anon_sym_CARET] = ACTIONS(6352),
    [anon_sym_AMP] = ACTIONS(6352),
    [anon_sym_EQ_EQ] = ACTIONS(6354),
    [anon_sym_BANG_EQ] = ACTIONS(6354),
    [anon_sym_GT] = ACTIONS(6352),
    [anon_sym_GT_EQ] = ACTIONS(6352),
    [anon_sym_LT_EQ] = ACTIONS(6352),
    [anon_sym_LT] = ACTIONS(6352),
    [anon_sym_LT_LT] = ACTIONS(6352),
    [anon_sym_GT_GT] = ACTIONS(6352),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [anon_sym_EQ] = ACTIONS(6352),
    [anon_sym_QMARK] = ACTIONS(6354),
    [anon_sym_STAR_EQ] = ACTIONS(6354),
    [anon_sym_SLASH_EQ] = ACTIONS(6354),
    [anon_sym_PERCENT_EQ] = ACTIONS(6354),
    [anon_sym_PLUS_EQ] = ACTIONS(6354),
    [anon_sym_DASH_EQ] = ACTIONS(6354),
    [anon_sym_LT_LT_EQ] = ACTIONS(6354),
    [anon_sym_GT_GT_EQ] = ACTIONS(6352),
    [anon_sym_AMP_EQ] = ACTIONS(6354),
    [anon_sym_CARET_EQ] = ACTIONS(6354),
    [anon_sym_PIPE_EQ] = ACTIONS(6354),
    [anon_sym_and_eq] = ACTIONS(6352),
    [anon_sym_or_eq] = ACTIONS(6352),
    [anon_sym_xor_eq] = ACTIONS(6352),
    [anon_sym_LT_EQ_GT] = ACTIONS(6354),
    [anon_sym_or] = ACTIONS(6352),
    [anon_sym_and] = ACTIONS(6352),
    [anon_sym_bitor] = ACTIONS(6352),
    [anon_sym_xor] = ACTIONS(6352),
    [anon_sym_bitand] = ACTIONS(6352),
    [anon_sym_not_eq] = ACTIONS(6352),
    [anon_sym_DASH_DASH] = ACTIONS(6354),
    [anon_sym_PLUS_PLUS] = ACTIONS(6354),
    [anon_sym_DOT] = ACTIONS(6352),
    [anon_sym_DOT_STAR] = ACTIONS(6354),
    [anon_sym_DASH_GT] = ACTIONS(6354),
    [anon_sym_L_DQUOTE] = ACTIONS(6581),
    [anon_sym_u_DQUOTE] = ACTIONS(6581),
    [anon_sym_U_DQUOTE] = ACTIONS(6581),
    [anon_sym_u8_DQUOTE] = ACTIONS(6581),
    [anon_sym_DQUOTE] = ACTIONS(6581),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(6354),
    [anon_sym_R_DQUOTE] = ACTIONS(6583),
    [anon_sym_LR_DQUOTE] = ACTIONS(6583),
    [anon_sym_uR_DQUOTE] = ACTIONS(6583),
    [anon_sym_UR_DQUOTE] = ACTIONS(6583),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6583),
    [sym_literal_suffix] = ACTIONS(6352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6354),
  },
  [STATE(2700)] = {
    [sym_template_argument_list] = STATE(3076),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2323),
    [sym_identifier] = ACTIONS(4002),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4010),
    [anon_sym_COMMA] = ACTIONS(4010),
    [anon_sym_RPAREN] = ACTIONS(4025),
    [anon_sym_LPAREN2] = ACTIONS(4025),
    [anon_sym_TILDE] = ACTIONS(4010),
    [anon_sym_STAR] = ACTIONS(4010),
    [anon_sym_AMP_AMP] = ACTIONS(4010),
    [anon_sym_AMP] = ACTIONS(4002),
    [anon_sym_LT] = ACTIONS(6782),
    [anon_sym___extension__] = ACTIONS(4002),
    [anon_sym___device__] = ACTIONS(4002),
    [anon_sym___host__] = ACTIONS(4002),
    [anon_sym___global__] = ACTIONS(4002),
    [anon_sym___forceinline__] = ACTIONS(4002),
    [anon_sym___noinline__] = ACTIONS(4002),
    [anon_sym_virtual] = ACTIONS(4002),
    [anon_sym_extern] = ACTIONS(4002),
    [anon_sym___attribute__] = ACTIONS(4002),
    [anon_sym___attribute] = ACTIONS(4002),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4025),
    [anon_sym___declspec] = ACTIONS(4002),
    [anon_sym___based] = ACTIONS(4002),
    [anon_sym_signed] = ACTIONS(4030),
    [anon_sym_unsigned] = ACTIONS(4030),
    [anon_sym_long] = ACTIONS(4030),
    [anon_sym_short] = ACTIONS(4030),
    [anon_sym_LBRACK] = ACTIONS(6477),
    [anon_sym_static] = ACTIONS(4002),
    [anon_sym_EQ] = ACTIONS(4010),
    [anon_sym_register] = ACTIONS(4002),
    [anon_sym_inline] = ACTIONS(4002),
    [anon_sym___inline] = ACTIONS(4002),
    [anon_sym___inline__] = ACTIONS(4002),
    [anon_sym___forceinline] = ACTIONS(4002),
    [anon_sym_thread_local] = ACTIONS(4002),
    [anon_sym___thread] = ACTIONS(4002),
    [anon_sym_const] = ACTIONS(4002),
    [anon_sym_constexpr] = ACTIONS(4002),
    [anon_sym_volatile] = ACTIONS(4002),
    [anon_sym_restrict] = ACTIONS(4002),
    [anon_sym___restrict__] = ACTIONS(4002),
    [anon_sym__Atomic] = ACTIONS(4002),
    [anon_sym__Noreturn] = ACTIONS(4002),
    [anon_sym_noreturn] = ACTIONS(4002),
    [anon_sym__Nonnull] = ACTIONS(4002),
    [anon_sym_mutable] = ACTIONS(4002),
    [anon_sym_constinit] = ACTIONS(4002),
    [anon_sym_consteval] = ACTIONS(4002),
    [anon_sym___shared__] = ACTIONS(4002),
    [anon_sym___local__] = ACTIONS(4002),
    [anon_sym___constant__] = ACTIONS(4002),
    [anon_sym___managed__] = ACTIONS(4002),
    [anon_sym___grid_constant__] = ACTIONS(4002),
    [anon_sym_alignas] = ACTIONS(4002),
    [anon_sym__Alignas] = ACTIONS(4002),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4002),
    [anon_sym_decltype] = ACTIONS(4002),
    [anon_sym_template] = ACTIONS(4002),
    [anon_sym_operator] = ACTIONS(4002),
    [anon_sym___launch_bounds__] = ACTIONS(4002),
  },
  [STATE(2701)] = {
    [sym__declaration_modifiers] = STATE(2701),
    [sym_attribute_specifier] = STATE(2701),
    [sym_attribute_declaration] = STATE(2701),
    [sym_ms_declspec_modifier] = STATE(2701),
    [sym_storage_class_specifier] = STATE(2701),
    [sym_type_qualifier] = STATE(2701),
    [sym_alignas_qualifier] = STATE(2630),
    [sym_explicit_function_specifier] = STATE(2701),
    [sym__constructor_specifiers] = STATE(2701),
    [sym_launch_bounds] = STATE(2701),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2701),
    [sym_identifier] = ACTIONS(6827),
    [anon_sym_LPAREN2] = ACTIONS(6829),
    [anon_sym_TILDE] = ACTIONS(6829),
    [anon_sym_STAR] = ACTIONS(6829),
    [anon_sym_AMP_AMP] = ACTIONS(6829),
    [anon_sym_AMP] = ACTIONS(6827),
    [anon_sym___extension__] = ACTIONS(6831),
    [anon_sym___device__] = ACTIONS(6834),
    [anon_sym___host__] = ACTIONS(6834),
    [anon_sym___global__] = ACTIONS(6834),
    [anon_sym___forceinline__] = ACTIONS(6834),
    [anon_sym___noinline__] = ACTIONS(6834),
    [anon_sym_virtual] = ACTIONS(6834),
    [anon_sym_extern] = ACTIONS(6837),
    [anon_sym___attribute__] = ACTIONS(6840),
    [anon_sym___attribute] = ACTIONS(6840),
    [anon_sym_COLON_COLON] = ACTIONS(6829),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6843),
    [anon_sym___declspec] = ACTIONS(6846),
    [anon_sym___based] = ACTIONS(6827),
    [anon_sym_LBRACK] = ACTIONS(6827),
    [anon_sym_static] = ACTIONS(6837),
    [anon_sym_register] = ACTIONS(6837),
    [anon_sym_inline] = ACTIONS(6837),
    [anon_sym___inline] = ACTIONS(6837),
    [anon_sym___inline__] = ACTIONS(6837),
    [anon_sym___forceinline] = ACTIONS(6837),
    [anon_sym_thread_local] = ACTIONS(6837),
    [anon_sym___thread] = ACTIONS(6837),
    [anon_sym_const] = ACTIONS(6831),
    [anon_sym_constexpr] = ACTIONS(6831),
    [anon_sym_volatile] = ACTIONS(6831),
    [anon_sym_restrict] = ACTIONS(6831),
    [anon_sym___restrict__] = ACTIONS(6831),
    [anon_sym__Atomic] = ACTIONS(6831),
    [anon_sym__Noreturn] = ACTIONS(6831),
    [anon_sym_noreturn] = ACTIONS(6831),
    [anon_sym__Nonnull] = ACTIONS(6831),
    [anon_sym_mutable] = ACTIONS(6831),
    [anon_sym_constinit] = ACTIONS(6831),
    [anon_sym_consteval] = ACTIONS(6831),
    [anon_sym___shared__] = ACTIONS(6831),
    [anon_sym___local__] = ACTIONS(6831),
    [anon_sym___constant__] = ACTIONS(6831),
    [anon_sym___managed__] = ACTIONS(6831),
    [anon_sym___grid_constant__] = ACTIONS(6831),
    [anon_sym_alignas] = ACTIONS(6849),
    [anon_sym__Alignas] = ACTIONS(6849),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(6827),
    [anon_sym_explicit] = ACTIONS(6852),
    [anon_sym_template] = ACTIONS(6827),
    [anon_sym_operator] = ACTIONS(6827),
    [anon_sym___launch_bounds__] = ACTIONS(6855),
  },
  [STATE(2702)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6194),
    [anon_sym_COMMA] = ACTIONS(6194),
    [anon_sym_RPAREN] = ACTIONS(6194),
    [anon_sym_LPAREN2] = ACTIONS(6194),
    [anon_sym_DASH] = ACTIONS(6192),
    [anon_sym_PLUS] = ACTIONS(6192),
    [anon_sym_STAR] = ACTIONS(6192),
    [anon_sym_SLASH] = ACTIONS(6192),
    [anon_sym_PERCENT] = ACTIONS(6192),
    [anon_sym_PIPE_PIPE] = ACTIONS(6194),
    [anon_sym_AMP_AMP] = ACTIONS(6194),
    [anon_sym_PIPE] = ACTIONS(6192),
    [anon_sym_CARET] = ACTIONS(6192),
    [anon_sym_AMP] = ACTIONS(6192),
    [anon_sym_EQ_EQ] = ACTIONS(6194),
    [anon_sym_BANG_EQ] = ACTIONS(6194),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_GT_EQ] = ACTIONS(6194),
    [anon_sym_LT_EQ] = ACTIONS(6192),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_LT_LT] = ACTIONS(6192),
    [anon_sym_GT_GT] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [anon_sym_EQ] = ACTIONS(6192),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_STAR_EQ] = ACTIONS(6194),
    [anon_sym_SLASH_EQ] = ACTIONS(6194),
    [anon_sym_PERCENT_EQ] = ACTIONS(6194),
    [anon_sym_PLUS_EQ] = ACTIONS(6194),
    [anon_sym_DASH_EQ] = ACTIONS(6194),
    [anon_sym_LT_LT_EQ] = ACTIONS(6194),
    [anon_sym_GT_GT_EQ] = ACTIONS(6194),
    [anon_sym_AMP_EQ] = ACTIONS(6194),
    [anon_sym_CARET_EQ] = ACTIONS(6194),
    [anon_sym_PIPE_EQ] = ACTIONS(6194),
    [anon_sym_and_eq] = ACTIONS(6192),
    [anon_sym_or_eq] = ACTIONS(6192),
    [anon_sym_xor_eq] = ACTIONS(6192),
    [anon_sym_LT_EQ_GT] = ACTIONS(6194),
    [anon_sym_or] = ACTIONS(6192),
    [anon_sym_and] = ACTIONS(6192),
    [anon_sym_bitor] = ACTIONS(6192),
    [anon_sym_xor] = ACTIONS(6192),
    [anon_sym_bitand] = ACTIONS(6192),
    [anon_sym_not_eq] = ACTIONS(6192),
    [anon_sym_DASH_DASH] = ACTIONS(6194),
    [anon_sym_PLUS_PLUS] = ACTIONS(6194),
    [anon_sym_DOT] = ACTIONS(6192),
    [anon_sym_DOT_STAR] = ACTIONS(6194),
    [anon_sym_DASH_GT] = ACTIONS(6192),
    [anon_sym_L_DQUOTE] = ACTIONS(6194),
    [anon_sym_u_DQUOTE] = ACTIONS(6194),
    [anon_sym_U_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8_DQUOTE] = ACTIONS(6194),
    [anon_sym_DQUOTE] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6194),
    [anon_sym_LR_DQUOTE] = ACTIONS(6194),
    [anon_sym_uR_DQUOTE] = ACTIONS(6194),
    [anon_sym_UR_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6194),
    [sym_literal_suffix] = ACTIONS(6192),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6194),
  },
  [STATE(2703)] = {
    [sym_identifier] = ACTIONS(6159),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6161),
    [anon_sym_COMMA] = ACTIONS(6161),
    [anon_sym_RPAREN] = ACTIONS(6161),
    [anon_sym_LPAREN2] = ACTIONS(6161),
    [anon_sym_DASH] = ACTIONS(6159),
    [anon_sym_PLUS] = ACTIONS(6159),
    [anon_sym_STAR] = ACTIONS(6159),
    [anon_sym_SLASH] = ACTIONS(6159),
    [anon_sym_PERCENT] = ACTIONS(6159),
    [anon_sym_PIPE_PIPE] = ACTIONS(6161),
    [anon_sym_AMP_AMP] = ACTIONS(6161),
    [anon_sym_PIPE] = ACTIONS(6159),
    [anon_sym_CARET] = ACTIONS(6159),
    [anon_sym_AMP] = ACTIONS(6159),
    [anon_sym_EQ_EQ] = ACTIONS(6161),
    [anon_sym_BANG_EQ] = ACTIONS(6161),
    [anon_sym_GT] = ACTIONS(6159),
    [anon_sym_GT_EQ] = ACTIONS(6161),
    [anon_sym_LT_EQ] = ACTIONS(6159),
    [anon_sym_LT] = ACTIONS(6159),
    [anon_sym_LT_LT] = ACTIONS(6159),
    [anon_sym_GT_GT] = ACTIONS(6159),
    [anon_sym_LBRACK] = ACTIONS(6161),
    [anon_sym_EQ] = ACTIONS(6159),
    [anon_sym_QMARK] = ACTIONS(6161),
    [anon_sym_STAR_EQ] = ACTIONS(6161),
    [anon_sym_SLASH_EQ] = ACTIONS(6161),
    [anon_sym_PERCENT_EQ] = ACTIONS(6161),
    [anon_sym_PLUS_EQ] = ACTIONS(6161),
    [anon_sym_DASH_EQ] = ACTIONS(6161),
    [anon_sym_LT_LT_EQ] = ACTIONS(6161),
    [anon_sym_GT_GT_EQ] = ACTIONS(6161),
    [anon_sym_AMP_EQ] = ACTIONS(6161),
    [anon_sym_CARET_EQ] = ACTIONS(6161),
    [anon_sym_PIPE_EQ] = ACTIONS(6161),
    [anon_sym_and_eq] = ACTIONS(6159),
    [anon_sym_or_eq] = ACTIONS(6159),
    [anon_sym_xor_eq] = ACTIONS(6159),
    [anon_sym_LT_EQ_GT] = ACTIONS(6161),
    [anon_sym_or] = ACTIONS(6159),
    [anon_sym_and] = ACTIONS(6159),
    [anon_sym_bitor] = ACTIONS(6159),
    [anon_sym_xor] = ACTIONS(6159),
    [anon_sym_bitand] = ACTIONS(6159),
    [anon_sym_not_eq] = ACTIONS(6159),
    [anon_sym_DASH_DASH] = ACTIONS(6161),
    [anon_sym_PLUS_PLUS] = ACTIONS(6161),
    [anon_sym_DOT] = ACTIONS(6159),
    [anon_sym_DOT_STAR] = ACTIONS(6161),
    [anon_sym_DASH_GT] = ACTIONS(6159),
    [anon_sym_L_DQUOTE] = ACTIONS(6161),
    [anon_sym_u_DQUOTE] = ACTIONS(6161),
    [anon_sym_U_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8_DQUOTE] = ACTIONS(6161),
    [anon_sym_DQUOTE] = ACTIONS(6161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6161),
    [anon_sym_LR_DQUOTE] = ACTIONS(6161),
    [anon_sym_uR_DQUOTE] = ACTIONS(6161),
    [anon_sym_UR_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6161),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6161),
    [sym_literal_suffix] = ACTIONS(6159),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6161),
  },
  [STATE(2704)] = {
    [sym_identifier] = ACTIONS(6858),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6860),
    [anon_sym_COMMA] = ACTIONS(6860),
    [anon_sym_RPAREN] = ACTIONS(6860),
    [aux_sym_preproc_if_token2] = ACTIONS(6860),
    [aux_sym_preproc_else_token1] = ACTIONS(6860),
    [aux_sym_preproc_elif_token1] = ACTIONS(6858),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6860),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6860),
    [anon_sym_LPAREN2] = ACTIONS(6860),
    [anon_sym_DASH] = ACTIONS(6858),
    [anon_sym_PLUS] = ACTIONS(6858),
    [anon_sym_STAR] = ACTIONS(6858),
    [anon_sym_SLASH] = ACTIONS(6858),
    [anon_sym_PERCENT] = ACTIONS(6858),
    [anon_sym_PIPE_PIPE] = ACTIONS(6860),
    [anon_sym_AMP_AMP] = ACTIONS(6860),
    [anon_sym_PIPE] = ACTIONS(6858),
    [anon_sym_CARET] = ACTIONS(6858),
    [anon_sym_AMP] = ACTIONS(6858),
    [anon_sym_EQ_EQ] = ACTIONS(6860),
    [anon_sym_BANG_EQ] = ACTIONS(6860),
    [anon_sym_GT] = ACTIONS(6858),
    [anon_sym_GT_EQ] = ACTIONS(6860),
    [anon_sym_LT_EQ] = ACTIONS(6858),
    [anon_sym_LT] = ACTIONS(6858),
    [anon_sym_LT_LT] = ACTIONS(6858),
    [anon_sym_GT_GT] = ACTIONS(6858),
    [anon_sym_SEMI] = ACTIONS(6860),
    [anon_sym___attribute__] = ACTIONS(6858),
    [anon_sym___attribute] = ACTIONS(6858),
    [anon_sym_LBRACE] = ACTIONS(6860),
    [anon_sym_RBRACE] = ACTIONS(6860),
    [anon_sym_LBRACK] = ACTIONS(6860),
    [anon_sym_RBRACK] = ACTIONS(6860),
    [anon_sym_EQ] = ACTIONS(6858),
    [anon_sym_COLON] = ACTIONS(6860),
    [anon_sym_QMARK] = ACTIONS(6860),
    [anon_sym_STAR_EQ] = ACTIONS(6860),
    [anon_sym_SLASH_EQ] = ACTIONS(6860),
    [anon_sym_PERCENT_EQ] = ACTIONS(6860),
    [anon_sym_PLUS_EQ] = ACTIONS(6860),
    [anon_sym_DASH_EQ] = ACTIONS(6860),
    [anon_sym_LT_LT_EQ] = ACTIONS(6860),
    [anon_sym_GT_GT_EQ] = ACTIONS(6860),
    [anon_sym_AMP_EQ] = ACTIONS(6860),
    [anon_sym_CARET_EQ] = ACTIONS(6860),
    [anon_sym_PIPE_EQ] = ACTIONS(6860),
    [anon_sym_and_eq] = ACTIONS(6858),
    [anon_sym_or_eq] = ACTIONS(6858),
    [anon_sym_xor_eq] = ACTIONS(6858),
    [anon_sym_LT_EQ_GT] = ACTIONS(6860),
    [anon_sym_or] = ACTIONS(6858),
    [anon_sym_and] = ACTIONS(6858),
    [anon_sym_bitor] = ACTIONS(6858),
    [anon_sym_xor] = ACTIONS(6858),
    [anon_sym_bitand] = ACTIONS(6858),
    [anon_sym_not_eq] = ACTIONS(6858),
    [anon_sym_DASH_DASH] = ACTIONS(6860),
    [anon_sym_PLUS_PLUS] = ACTIONS(6860),
    [anon_sym_DOT] = ACTIONS(6858),
    [anon_sym_DOT_STAR] = ACTIONS(6860),
    [anon_sym_DASH_GT] = ACTIONS(6860),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6860),
  },
  [STATE(2705)] = {
    [sym_identifier] = ACTIONS(6732),
    [anon_sym_LPAREN2] = ACTIONS(6734),
    [anon_sym_TILDE] = ACTIONS(6734),
    [anon_sym_STAR] = ACTIONS(6734),
    [anon_sym_AMP_AMP] = ACTIONS(6734),
    [anon_sym_AMP] = ACTIONS(6732),
    [anon_sym___extension__] = ACTIONS(6732),
    [anon_sym___device__] = ACTIONS(6732),
    [anon_sym___host__] = ACTIONS(6732),
    [anon_sym___global__] = ACTIONS(6732),
    [anon_sym___forceinline__] = ACTIONS(6732),
    [anon_sym___noinline__] = ACTIONS(6732),
    [anon_sym_virtual] = ACTIONS(6732),
    [anon_sym_extern] = ACTIONS(6732),
    [anon_sym___attribute__] = ACTIONS(6732),
    [anon_sym___attribute] = ACTIONS(6732),
    [anon_sym_COLON_COLON] = ACTIONS(6734),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6734),
    [anon_sym___declspec] = ACTIONS(6732),
    [anon_sym___based] = ACTIONS(6732),
    [anon_sym_signed] = ACTIONS(6732),
    [anon_sym_unsigned] = ACTIONS(6732),
    [anon_sym_long] = ACTIONS(6732),
    [anon_sym_short] = ACTIONS(6732),
    [anon_sym_LBRACK] = ACTIONS(6732),
    [anon_sym_static] = ACTIONS(6732),
    [anon_sym_register] = ACTIONS(6732),
    [anon_sym_inline] = ACTIONS(6732),
    [anon_sym___inline] = ACTIONS(6732),
    [anon_sym___inline__] = ACTIONS(6732),
    [anon_sym___forceinline] = ACTIONS(6732),
    [anon_sym_thread_local] = ACTIONS(6732),
    [anon_sym___thread] = ACTIONS(6732),
    [anon_sym_const] = ACTIONS(6732),
    [anon_sym_constexpr] = ACTIONS(6732),
    [anon_sym_volatile] = ACTIONS(6732),
    [anon_sym_restrict] = ACTIONS(6732),
    [anon_sym___restrict__] = ACTIONS(6732),
    [anon_sym__Atomic] = ACTIONS(6732),
    [anon_sym__Noreturn] = ACTIONS(6732),
    [anon_sym_noreturn] = ACTIONS(6732),
    [anon_sym__Nonnull] = ACTIONS(6732),
    [anon_sym_mutable] = ACTIONS(6732),
    [anon_sym_constinit] = ACTIONS(6732),
    [anon_sym_consteval] = ACTIONS(6732),
    [anon_sym___shared__] = ACTIONS(6732),
    [anon_sym___local__] = ACTIONS(6732),
    [anon_sym___constant__] = ACTIONS(6732),
    [anon_sym___managed__] = ACTIONS(6732),
    [anon_sym___grid_constant__] = ACTIONS(6732),
    [anon_sym_alignas] = ACTIONS(6732),
    [anon_sym__Alignas] = ACTIONS(6732),
    [sym_primitive_type] = ACTIONS(6732),
    [anon_sym_enum] = ACTIONS(6732),
    [anon_sym_class] = ACTIONS(6732),
    [anon_sym_struct] = ACTIONS(6732),
    [anon_sym_union] = ACTIONS(6732),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6732),
    [anon_sym_decltype] = ACTIONS(6732),
    [anon_sym_explicit] = ACTIONS(6732),
    [anon_sym_typename] = ACTIONS(6732),
    [anon_sym_template] = ACTIONS(6732),
    [anon_sym_operator] = ACTIONS(6732),
    [anon_sym___launch_bounds__] = ACTIONS(6732),
  },
  [STATE(2706)] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2568),
    [sym_identifier] = ACTIONS(5684),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [aux_sym_preproc_if_token2] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5684),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5686),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5686),
    [anon_sym_LPAREN2] = ACTIONS(5686),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5684),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5684),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_CARET] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5684),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5684),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_LBRACE] = ACTIONS(5686),
    [anon_sym_signed] = ACTIONS(6518),
    [anon_sym_unsigned] = ACTIONS(6518),
    [anon_sym_long] = ACTIONS(6518),
    [anon_sym_short] = ACTIONS(6518),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_EQ] = ACTIONS(5684),
    [anon_sym_QMARK] = ACTIONS(5686),
    [anon_sym_STAR_EQ] = ACTIONS(5686),
    [anon_sym_SLASH_EQ] = ACTIONS(5686),
    [anon_sym_PERCENT_EQ] = ACTIONS(5686),
    [anon_sym_PLUS_EQ] = ACTIONS(5686),
    [anon_sym_DASH_EQ] = ACTIONS(5686),
    [anon_sym_LT_LT_EQ] = ACTIONS(5686),
    [anon_sym_GT_GT_EQ] = ACTIONS(5686),
    [anon_sym_AMP_EQ] = ACTIONS(5686),
    [anon_sym_CARET_EQ] = ACTIONS(5686),
    [anon_sym_PIPE_EQ] = ACTIONS(5686),
    [anon_sym_and_eq] = ACTIONS(5684),
    [anon_sym_or_eq] = ACTIONS(5684),
    [anon_sym_xor_eq] = ACTIONS(5684),
    [anon_sym_LT_EQ_GT] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_and] = ACTIONS(5684),
    [anon_sym_bitor] = ACTIONS(5684),
    [anon_sym_xor] = ACTIONS(5684),
    [anon_sym_bitand] = ACTIONS(5684),
    [anon_sym_not_eq] = ACTIONS(5684),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_DOT_STAR] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5684),
    [anon_sym_decltype] = ACTIONS(5684),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(5686),
  },
  [STATE(2707)] = {
    [sym_identifier] = ACTIONS(6167),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6169),
    [anon_sym_COMMA] = ACTIONS(6169),
    [anon_sym_RPAREN] = ACTIONS(6169),
    [anon_sym_LPAREN2] = ACTIONS(6169),
    [anon_sym_DASH] = ACTIONS(6167),
    [anon_sym_PLUS] = ACTIONS(6167),
    [anon_sym_STAR] = ACTIONS(6167),
    [anon_sym_SLASH] = ACTIONS(6167),
    [anon_sym_PERCENT] = ACTIONS(6167),
    [anon_sym_PIPE_PIPE] = ACTIONS(6169),
    [anon_sym_AMP_AMP] = ACTIONS(6169),
    [anon_sym_PIPE] = ACTIONS(6167),
    [anon_sym_CARET] = ACTIONS(6167),
    [anon_sym_AMP] = ACTIONS(6167),
    [anon_sym_EQ_EQ] = ACTIONS(6169),
    [anon_sym_BANG_EQ] = ACTIONS(6169),
    [anon_sym_GT] = ACTIONS(6167),
    [anon_sym_GT_EQ] = ACTIONS(6169),
    [anon_sym_LT_EQ] = ACTIONS(6167),
    [anon_sym_LT] = ACTIONS(6167),
    [anon_sym_LT_LT] = ACTIONS(6167),
    [anon_sym_GT_GT] = ACTIONS(6167),
    [anon_sym_LBRACK] = ACTIONS(6169),
    [anon_sym_EQ] = ACTIONS(6167),
    [anon_sym_QMARK] = ACTIONS(6169),
    [anon_sym_STAR_EQ] = ACTIONS(6169),
    [anon_sym_SLASH_EQ] = ACTIONS(6169),
    [anon_sym_PERCENT_EQ] = ACTIONS(6169),
    [anon_sym_PLUS_EQ] = ACTIONS(6169),
    [anon_sym_DASH_EQ] = ACTIONS(6169),
    [anon_sym_LT_LT_EQ] = ACTIONS(6169),
    [anon_sym_GT_GT_EQ] = ACTIONS(6169),
    [anon_sym_AMP_EQ] = ACTIONS(6169),
    [anon_sym_CARET_EQ] = ACTIONS(6169),
    [anon_sym_PIPE_EQ] = ACTIONS(6169),
    [anon_sym_and_eq] = ACTIONS(6167),
    [anon_sym_or_eq] = ACTIONS(6167),
    [anon_sym_xor_eq] = ACTIONS(6167),
    [anon_sym_LT_EQ_GT] = ACTIONS(6169),
    [anon_sym_or] = ACTIONS(6167),
    [anon_sym_and] = ACTIONS(6167),
    [anon_sym_bitor] = ACTIONS(6167),
    [anon_sym_xor] = ACTIONS(6167),
    [anon_sym_bitand] = ACTIONS(6167),
    [anon_sym_not_eq] = ACTIONS(6167),
    [anon_sym_DASH_DASH] = ACTIONS(6169),
    [anon_sym_PLUS_PLUS] = ACTIONS(6169),
    [anon_sym_DOT] = ACTIONS(6167),
    [anon_sym_DOT_STAR] = ACTIONS(6169),
    [anon_sym_DASH_GT] = ACTIONS(6167),
    [anon_sym_L_DQUOTE] = ACTIONS(6169),
    [anon_sym_u_DQUOTE] = ACTIONS(6169),
    [anon_sym_U_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8_DQUOTE] = ACTIONS(6169),
    [anon_sym_DQUOTE] = ACTIONS(6169),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6169),
    [anon_sym_LR_DQUOTE] = ACTIONS(6169),
    [anon_sym_uR_DQUOTE] = ACTIONS(6169),
    [anon_sym_UR_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6169),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6169),
    [sym_literal_suffix] = ACTIONS(6167),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6169),
  },
  [STATE(2708)] = {
    [sym_identifier] = ACTIONS(6862),
    [anon_sym_LPAREN2] = ACTIONS(6865),
    [anon_sym_TILDE] = ACTIONS(6865),
    [anon_sym_STAR] = ACTIONS(6865),
    [anon_sym_AMP_AMP] = ACTIONS(6865),
    [anon_sym_AMP] = ACTIONS(6867),
    [anon_sym___extension__] = ACTIONS(6862),
    [anon_sym___device__] = ACTIONS(6862),
    [anon_sym___host__] = ACTIONS(6862),
    [anon_sym___global__] = ACTIONS(6862),
    [anon_sym___forceinline__] = ACTIONS(6862),
    [anon_sym___noinline__] = ACTIONS(6862),
    [anon_sym_virtual] = ACTIONS(6862),
    [anon_sym_extern] = ACTIONS(6862),
    [anon_sym___attribute__] = ACTIONS(6862),
    [anon_sym___attribute] = ACTIONS(6862),
    [anon_sym_COLON_COLON] = ACTIONS(6869),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6869),
    [anon_sym___declspec] = ACTIONS(6862),
    [anon_sym___based] = ACTIONS(6867),
    [anon_sym_signed] = ACTIONS(6872),
    [anon_sym_unsigned] = ACTIONS(6872),
    [anon_sym_long] = ACTIONS(6872),
    [anon_sym_short] = ACTIONS(6872),
    [anon_sym_LBRACK] = ACTIONS(6867),
    [anon_sym_static] = ACTIONS(6862),
    [anon_sym_register] = ACTIONS(6862),
    [anon_sym_inline] = ACTIONS(6862),
    [anon_sym___inline] = ACTIONS(6862),
    [anon_sym___inline__] = ACTIONS(6862),
    [anon_sym___forceinline] = ACTIONS(6862),
    [anon_sym_thread_local] = ACTIONS(6862),
    [anon_sym___thread] = ACTIONS(6862),
    [anon_sym_const] = ACTIONS(6862),
    [anon_sym_constexpr] = ACTIONS(6862),
    [anon_sym_volatile] = ACTIONS(6862),
    [anon_sym_restrict] = ACTIONS(6862),
    [anon_sym___restrict__] = ACTIONS(6862),
    [anon_sym__Atomic] = ACTIONS(6862),
    [anon_sym__Noreturn] = ACTIONS(6862),
    [anon_sym_noreturn] = ACTIONS(6862),
    [anon_sym__Nonnull] = ACTIONS(6862),
    [anon_sym_mutable] = ACTIONS(6862),
    [anon_sym_constinit] = ACTIONS(6862),
    [anon_sym_consteval] = ACTIONS(6862),
    [anon_sym___shared__] = ACTIONS(6862),
    [anon_sym___local__] = ACTIONS(6862),
    [anon_sym___constant__] = ACTIONS(6862),
    [anon_sym___managed__] = ACTIONS(6862),
    [anon_sym___grid_constant__] = ACTIONS(6862),
    [anon_sym_alignas] = ACTIONS(6862),
    [anon_sym__Alignas] = ACTIONS(6862),
    [sym_primitive_type] = ACTIONS(6872),
    [anon_sym_enum] = ACTIONS(6872),
    [anon_sym_class] = ACTIONS(6872),
    [anon_sym_struct] = ACTIONS(6872),
    [anon_sym_union] = ACTIONS(6872),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6872),
    [anon_sym_decltype] = ACTIONS(6862),
    [anon_sym_explicit] = ACTIONS(6867),
    [anon_sym_typename] = ACTIONS(6872),
    [anon_sym_template] = ACTIONS(6862),
    [anon_sym_operator] = ACTIONS(6867),
    [anon_sym___launch_bounds__] = ACTIONS(6862),
  },
  [STATE(2709)] = {
    [sym_identifier] = ACTIONS(6163),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6165),
    [anon_sym_COMMA] = ACTIONS(6165),
    [anon_sym_RPAREN] = ACTIONS(6165),
    [anon_sym_LPAREN2] = ACTIONS(6165),
    [anon_sym_DASH] = ACTIONS(6163),
    [anon_sym_PLUS] = ACTIONS(6163),
    [anon_sym_STAR] = ACTIONS(6163),
    [anon_sym_SLASH] = ACTIONS(6163),
    [anon_sym_PERCENT] = ACTIONS(6163),
    [anon_sym_PIPE_PIPE] = ACTIONS(6165),
    [anon_sym_AMP_AMP] = ACTIONS(6165),
    [anon_sym_PIPE] = ACTIONS(6163),
    [anon_sym_CARET] = ACTIONS(6163),
    [anon_sym_AMP] = ACTIONS(6163),
    [anon_sym_EQ_EQ] = ACTIONS(6165),
    [anon_sym_BANG_EQ] = ACTIONS(6165),
    [anon_sym_GT] = ACTIONS(6163),
    [anon_sym_GT_EQ] = ACTIONS(6165),
    [anon_sym_LT_EQ] = ACTIONS(6163),
    [anon_sym_LT] = ACTIONS(6163),
    [anon_sym_LT_LT] = ACTIONS(6163),
    [anon_sym_GT_GT] = ACTIONS(6163),
    [anon_sym_LBRACK] = ACTIONS(6165),
    [anon_sym_EQ] = ACTIONS(6163),
    [anon_sym_QMARK] = ACTIONS(6165),
    [anon_sym_STAR_EQ] = ACTIONS(6165),
    [anon_sym_SLASH_EQ] = ACTIONS(6165),
    [anon_sym_PERCENT_EQ] = ACTIONS(6165),
    [anon_sym_PLUS_EQ] = ACTIONS(6165),
    [anon_sym_DASH_EQ] = ACTIONS(6165),
    [anon_sym_LT_LT_EQ] = ACTIONS(6165),
    [anon_sym_GT_GT_EQ] = ACTIONS(6165),
    [anon_sym_AMP_EQ] = ACTIONS(6165),
    [anon_sym_CARET_EQ] = ACTIONS(6165),
    [anon_sym_PIPE_EQ] = ACTIONS(6165),
    [anon_sym_and_eq] = ACTIONS(6163),
    [anon_sym_or_eq] = ACTIONS(6163),
    [anon_sym_xor_eq] = ACTIONS(6163),
    [anon_sym_LT_EQ_GT] = ACTIONS(6165),
    [anon_sym_or] = ACTIONS(6163),
    [anon_sym_and] = ACTIONS(6163),
    [anon_sym_bitor] = ACTIONS(6163),
    [anon_sym_xor] = ACTIONS(6163),
    [anon_sym_bitand] = ACTIONS(6163),
    [anon_sym_not_eq] = ACTIONS(6163),
    [anon_sym_DASH_DASH] = ACTIONS(6165),
    [anon_sym_PLUS_PLUS] = ACTIONS(6165),
    [anon_sym_DOT] = ACTIONS(6163),
    [anon_sym_DOT_STAR] = ACTIONS(6165),
    [anon_sym_DASH_GT] = ACTIONS(6163),
    [anon_sym_L_DQUOTE] = ACTIONS(6165),
    [anon_sym_u_DQUOTE] = ACTIONS(6165),
    [anon_sym_U_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8_DQUOTE] = ACTIONS(6165),
    [anon_sym_DQUOTE] = ACTIONS(6165),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6165),
    [anon_sym_LR_DQUOTE] = ACTIONS(6165),
    [anon_sym_uR_DQUOTE] = ACTIONS(6165),
    [anon_sym_UR_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6165),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6165),
    [sym_literal_suffix] = ACTIONS(6163),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6165),
  },
  [STATE(2710)] = {
    [sym_identifier] = ACTIONS(6874),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6876),
    [anon_sym_COMMA] = ACTIONS(6876),
    [anon_sym_RPAREN] = ACTIONS(6876),
    [aux_sym_preproc_if_token2] = ACTIONS(6876),
    [aux_sym_preproc_else_token1] = ACTIONS(6876),
    [aux_sym_preproc_elif_token1] = ACTIONS(6874),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6876),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6876),
    [anon_sym_LPAREN2] = ACTIONS(6876),
    [anon_sym_DASH] = ACTIONS(6874),
    [anon_sym_PLUS] = ACTIONS(6874),
    [anon_sym_STAR] = ACTIONS(6874),
    [anon_sym_SLASH] = ACTIONS(6874),
    [anon_sym_PERCENT] = ACTIONS(6874),
    [anon_sym_PIPE_PIPE] = ACTIONS(6876),
    [anon_sym_AMP_AMP] = ACTIONS(6876),
    [anon_sym_PIPE] = ACTIONS(6874),
    [anon_sym_CARET] = ACTIONS(6874),
    [anon_sym_AMP] = ACTIONS(6874),
    [anon_sym_EQ_EQ] = ACTIONS(6876),
    [anon_sym_BANG_EQ] = ACTIONS(6876),
    [anon_sym_GT] = ACTIONS(6874),
    [anon_sym_GT_EQ] = ACTIONS(6876),
    [anon_sym_LT_EQ] = ACTIONS(6874),
    [anon_sym_LT] = ACTIONS(6874),
    [anon_sym_LT_LT] = ACTIONS(6874),
    [anon_sym_GT_GT] = ACTIONS(6874),
    [anon_sym_SEMI] = ACTIONS(6876),
    [anon_sym___attribute__] = ACTIONS(6874),
    [anon_sym___attribute] = ACTIONS(6874),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6876),
    [anon_sym_RBRACE] = ACTIONS(6876),
    [anon_sym_LBRACK] = ACTIONS(6874),
    [anon_sym_RBRACK] = ACTIONS(6876),
    [anon_sym_EQ] = ACTIONS(6874),
    [anon_sym_COLON] = ACTIONS(6876),
    [anon_sym_QMARK] = ACTIONS(6876),
    [anon_sym_STAR_EQ] = ACTIONS(6876),
    [anon_sym_SLASH_EQ] = ACTIONS(6876),
    [anon_sym_PERCENT_EQ] = ACTIONS(6876),
    [anon_sym_PLUS_EQ] = ACTIONS(6876),
    [anon_sym_DASH_EQ] = ACTIONS(6876),
    [anon_sym_LT_LT_EQ] = ACTIONS(6876),
    [anon_sym_GT_GT_EQ] = ACTIONS(6876),
    [anon_sym_AMP_EQ] = ACTIONS(6876),
    [anon_sym_CARET_EQ] = ACTIONS(6876),
    [anon_sym_PIPE_EQ] = ACTIONS(6876),
    [anon_sym_and_eq] = ACTIONS(6874),
    [anon_sym_or_eq] = ACTIONS(6874),
    [anon_sym_xor_eq] = ACTIONS(6874),
    [anon_sym_LT_EQ_GT] = ACTIONS(6876),
    [anon_sym_or] = ACTIONS(6874),
    [anon_sym_and] = ACTIONS(6874),
    [anon_sym_bitor] = ACTIONS(6874),
    [anon_sym_xor] = ACTIONS(6874),
    [anon_sym_bitand] = ACTIONS(6874),
    [anon_sym_not_eq] = ACTIONS(6874),
    [anon_sym_DASH_DASH] = ACTIONS(6876),
    [anon_sym_PLUS_PLUS] = ACTIONS(6876),
    [anon_sym_DOT] = ACTIONS(6874),
    [anon_sym_DOT_STAR] = ACTIONS(6876),
    [anon_sym_DASH_GT] = ACTIONS(6876),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6876),
  },
  [STATE(2711)] = {
    [sym_attribute_specifier] = STATE(3316),
    [sym_field_declaration_list] = STATE(3062),
    [sym_virtual_specifier] = STATE(7705),
    [sym_base_class_clause] = STATE(8291),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6036),
    [anon_sym_COMMA] = ACTIONS(6036),
    [anon_sym_RPAREN] = ACTIONS(6036),
    [anon_sym_LPAREN2] = ACTIONS(6036),
    [anon_sym_DASH] = ACTIONS(6038),
    [anon_sym_PLUS] = ACTIONS(6038),
    [anon_sym_STAR] = ACTIONS(6038),
    [anon_sym_SLASH] = ACTIONS(6038),
    [anon_sym_PERCENT] = ACTIONS(6038),
    [anon_sym_PIPE_PIPE] = ACTIONS(6036),
    [anon_sym_AMP_AMP] = ACTIONS(6036),
    [anon_sym_PIPE] = ACTIONS(6038),
    [anon_sym_CARET] = ACTIONS(6038),
    [anon_sym_AMP] = ACTIONS(6038),
    [anon_sym_EQ_EQ] = ACTIONS(6036),
    [anon_sym_BANG_EQ] = ACTIONS(6036),
    [anon_sym_GT] = ACTIONS(6038),
    [anon_sym_GT_EQ] = ACTIONS(6036),
    [anon_sym_LT_EQ] = ACTIONS(6038),
    [anon_sym_LT] = ACTIONS(6038),
    [anon_sym_LT_LT] = ACTIONS(6038),
    [anon_sym_GT_GT] = ACTIONS(6038),
    [anon_sym___attribute__] = ACTIONS(6878),
    [anon_sym___attribute] = ACTIONS(6880),
    [anon_sym_LBRACE] = ACTIONS(6882),
    [anon_sym_LBRACK] = ACTIONS(6036),
    [anon_sym_EQ] = ACTIONS(6038),
    [anon_sym_COLON] = ACTIONS(6046),
    [anon_sym_QMARK] = ACTIONS(6036),
    [anon_sym_STAR_EQ] = ACTIONS(6036),
    [anon_sym_SLASH_EQ] = ACTIONS(6036),
    [anon_sym_PERCENT_EQ] = ACTIONS(6036),
    [anon_sym_PLUS_EQ] = ACTIONS(6036),
    [anon_sym_DASH_EQ] = ACTIONS(6036),
    [anon_sym_LT_LT_EQ] = ACTIONS(6036),
    [anon_sym_GT_GT_EQ] = ACTIONS(6036),
    [anon_sym_AMP_EQ] = ACTIONS(6036),
    [anon_sym_CARET_EQ] = ACTIONS(6036),
    [anon_sym_PIPE_EQ] = ACTIONS(6036),
    [anon_sym_and_eq] = ACTIONS(6036),
    [anon_sym_or_eq] = ACTIONS(6036),
    [anon_sym_xor_eq] = ACTIONS(6036),
    [anon_sym_LT_EQ_GT] = ACTIONS(6036),
    [anon_sym_or] = ACTIONS(6038),
    [anon_sym_and] = ACTIONS(6038),
    [anon_sym_bitor] = ACTIONS(6036),
    [anon_sym_xor] = ACTIONS(6038),
    [anon_sym_bitand] = ACTIONS(6036),
    [anon_sym_not_eq] = ACTIONS(6036),
    [anon_sym_DASH_DASH] = ACTIONS(6036),
    [anon_sym_PLUS_PLUS] = ACTIONS(6036),
    [anon_sym_DOT] = ACTIONS(6038),
    [anon_sym_DOT_STAR] = ACTIONS(6036),
    [anon_sym_DASH_GT] = ACTIONS(6038),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6036),
    [anon_sym_decltype] = ACTIONS(6036),
    [anon_sym_final] = ACTIONS(6048),
    [anon_sym_override] = ACTIONS(6048),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6036),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6036),
  },
  [STATE(2712)] = {
    [sym_string_literal] = STATE(2727),
    [sym_raw_string_literal] = STATE(2727),
    [aux_sym_concatenated_string_repeat1] = STATE(2727),
    [sym_identifier] = ACTIONS(6884),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6002),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_RPAREN] = ACTIONS(6002),
    [anon_sym_LPAREN2] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_STAR] = ACTIONS(6004),
    [anon_sym_SLASH] = ACTIONS(6004),
    [anon_sym_PERCENT] = ACTIONS(6004),
    [anon_sym_PIPE_PIPE] = ACTIONS(6002),
    [anon_sym_AMP_AMP] = ACTIONS(6002),
    [anon_sym_PIPE] = ACTIONS(6004),
    [anon_sym_CARET] = ACTIONS(6004),
    [anon_sym_AMP] = ACTIONS(6004),
    [anon_sym_EQ_EQ] = ACTIONS(6002),
    [anon_sym_BANG_EQ] = ACTIONS(6002),
    [anon_sym_GT] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(6002),
    [anon_sym_LT_EQ] = ACTIONS(6004),
    [anon_sym_LT] = ACTIONS(6004),
    [anon_sym_LT_LT] = ACTIONS(6004),
    [anon_sym_GT_GT] = ACTIONS(6004),
    [anon_sym_LBRACK] = ACTIONS(6002),
    [anon_sym_EQ] = ACTIONS(6004),
    [anon_sym_QMARK] = ACTIONS(6002),
    [anon_sym_STAR_EQ] = ACTIONS(6002),
    [anon_sym_SLASH_EQ] = ACTIONS(6002),
    [anon_sym_PERCENT_EQ] = ACTIONS(6002),
    [anon_sym_PLUS_EQ] = ACTIONS(6002),
    [anon_sym_DASH_EQ] = ACTIONS(6002),
    [anon_sym_LT_LT_EQ] = ACTIONS(6002),
    [anon_sym_GT_GT_EQ] = ACTIONS(6002),
    [anon_sym_AMP_EQ] = ACTIONS(6002),
    [anon_sym_CARET_EQ] = ACTIONS(6002),
    [anon_sym_PIPE_EQ] = ACTIONS(6002),
    [anon_sym_LT_EQ_GT] = ACTIONS(6002),
    [anon_sym_or] = ACTIONS(6004),
    [anon_sym_and] = ACTIONS(6004),
    [anon_sym_bitor] = ACTIONS(6004),
    [anon_sym_xor] = ACTIONS(6004),
    [anon_sym_bitand] = ACTIONS(6004),
    [anon_sym_not_eq] = ACTIONS(6004),
    [anon_sym_DASH_DASH] = ACTIONS(6002),
    [anon_sym_PLUS_PLUS] = ACTIONS(6002),
    [anon_sym_DOT] = ACTIONS(6004),
    [anon_sym_DOT_STAR] = ACTIONS(6002),
    [anon_sym_DASH_GT] = ACTIONS(6004),
    [anon_sym_L_DQUOTE] = ACTIONS(4314),
    [anon_sym_u_DQUOTE] = ACTIONS(4314),
    [anon_sym_U_DQUOTE] = ACTIONS(4314),
    [anon_sym_u8_DQUOTE] = ACTIONS(4314),
    [anon_sym_DQUOTE] = ACTIONS(4314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(4316),
    [anon_sym_LR_DQUOTE] = ACTIONS(4316),
    [anon_sym_uR_DQUOTE] = ACTIONS(4316),
    [anon_sym_UR_DQUOTE] = ACTIONS(4316),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4316),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6002),
    [sym_literal_suffix] = ACTIONS(6004),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6002),
  },
  [STATE(2713)] = {
    [sym_template_argument_list] = STATE(2360),
    [sym_identifier] = ACTIONS(4512),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4519),
    [anon_sym_COMMA] = ACTIONS(4519),
    [anon_sym_RPAREN] = ACTIONS(4519),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_TILDE] = ACTIONS(4519),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4512),
    [anon_sym_LT] = ACTIONS(6782),
    [anon_sym___extension__] = ACTIONS(4512),
    [anon_sym___device__] = ACTIONS(4512),
    [anon_sym___host__] = ACTIONS(4512),
    [anon_sym___global__] = ACTIONS(4512),
    [anon_sym___forceinline__] = ACTIONS(4512),
    [anon_sym___noinline__] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym___attribute__] = ACTIONS(4512),
    [anon_sym___attribute] = ACTIONS(4512),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4519),
    [anon_sym___declspec] = ACTIONS(4512),
    [anon_sym___based] = ACTIONS(4512),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_EQ] = ACTIONS(4519),
    [anon_sym_register] = ACTIONS(4512),
    [anon_sym_inline] = ACTIONS(4512),
    [anon_sym___inline] = ACTIONS(4512),
    [anon_sym___inline__] = ACTIONS(4512),
    [anon_sym___forceinline] = ACTIONS(4512),
    [anon_sym_thread_local] = ACTIONS(4512),
    [anon_sym___thread] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_constexpr] = ACTIONS(4512),
    [anon_sym_volatile] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym___restrict__] = ACTIONS(4512),
    [anon_sym__Atomic] = ACTIONS(4512),
    [anon_sym__Noreturn] = ACTIONS(4512),
    [anon_sym_noreturn] = ACTIONS(4512),
    [anon_sym__Nonnull] = ACTIONS(4512),
    [anon_sym_mutable] = ACTIONS(4512),
    [anon_sym_constinit] = ACTIONS(4512),
    [anon_sym_consteval] = ACTIONS(4512),
    [anon_sym___shared__] = ACTIONS(4512),
    [anon_sym___local__] = ACTIONS(4512),
    [anon_sym___constant__] = ACTIONS(4512),
    [anon_sym___managed__] = ACTIONS(4512),
    [anon_sym___grid_constant__] = ACTIONS(4512),
    [anon_sym_alignas] = ACTIONS(4512),
    [anon_sym__Alignas] = ACTIONS(4512),
    [anon_sym_COLON] = ACTIONS(4512),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4512),
    [anon_sym_decltype] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_override] = ACTIONS(4512),
    [anon_sym_template] = ACTIONS(4512),
    [anon_sym_GT2] = ACTIONS(4519),
    [anon_sym_operator] = ACTIONS(4512),
    [anon_sym___launch_bounds__] = ACTIONS(4512),
  },
  [STATE(2714)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6165),
    [anon_sym_COMMA] = ACTIONS(6165),
    [anon_sym_LPAREN2] = ACTIONS(6165),
    [anon_sym_DASH] = ACTIONS(6163),
    [anon_sym_PLUS] = ACTIONS(6163),
    [anon_sym_STAR] = ACTIONS(6163),
    [anon_sym_SLASH] = ACTIONS(6163),
    [anon_sym_PERCENT] = ACTIONS(6163),
    [anon_sym_PIPE_PIPE] = ACTIONS(6165),
    [anon_sym_AMP_AMP] = ACTIONS(6165),
    [anon_sym_PIPE] = ACTIONS(6163),
    [anon_sym_CARET] = ACTIONS(6163),
    [anon_sym_AMP] = ACTIONS(6163),
    [anon_sym_EQ_EQ] = ACTIONS(6165),
    [anon_sym_BANG_EQ] = ACTIONS(6165),
    [anon_sym_GT] = ACTIONS(6163),
    [anon_sym_GT_EQ] = ACTIONS(6165),
    [anon_sym_LT_EQ] = ACTIONS(6163),
    [anon_sym_LT] = ACTIONS(6163),
    [anon_sym_LT_LT] = ACTIONS(6163),
    [anon_sym_GT_GT] = ACTIONS(6163),
    [anon_sym_SEMI] = ACTIONS(6165),
    [anon_sym___attribute__] = ACTIONS(6163),
    [anon_sym___attribute] = ACTIONS(6163),
    [anon_sym_LBRACK] = ACTIONS(6165),
    [anon_sym_EQ] = ACTIONS(6163),
    [anon_sym_QMARK] = ACTIONS(6165),
    [anon_sym_STAR_EQ] = ACTIONS(6165),
    [anon_sym_SLASH_EQ] = ACTIONS(6165),
    [anon_sym_PERCENT_EQ] = ACTIONS(6165),
    [anon_sym_PLUS_EQ] = ACTIONS(6165),
    [anon_sym_DASH_EQ] = ACTIONS(6165),
    [anon_sym_LT_LT_EQ] = ACTIONS(6165),
    [anon_sym_GT_GT_EQ] = ACTIONS(6165),
    [anon_sym_AMP_EQ] = ACTIONS(6165),
    [anon_sym_CARET_EQ] = ACTIONS(6165),
    [anon_sym_PIPE_EQ] = ACTIONS(6165),
    [anon_sym_and_eq] = ACTIONS(6163),
    [anon_sym_or_eq] = ACTIONS(6163),
    [anon_sym_xor_eq] = ACTIONS(6163),
    [anon_sym_LT_EQ_GT] = ACTIONS(6165),
    [anon_sym_or] = ACTIONS(6163),
    [anon_sym_and] = ACTIONS(6163),
    [anon_sym_bitor] = ACTIONS(6163),
    [anon_sym_xor] = ACTIONS(6163),
    [anon_sym_bitand] = ACTIONS(6163),
    [anon_sym_not_eq] = ACTIONS(6163),
    [anon_sym_DASH_DASH] = ACTIONS(6165),
    [anon_sym_PLUS_PLUS] = ACTIONS(6165),
    [anon_sym_DOT] = ACTIONS(6163),
    [anon_sym_DOT_STAR] = ACTIONS(6165),
    [anon_sym_DASH_GT] = ACTIONS(6165),
    [anon_sym_L_DQUOTE] = ACTIONS(6165),
    [anon_sym_u_DQUOTE] = ACTIONS(6165),
    [anon_sym_U_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8_DQUOTE] = ACTIONS(6165),
    [anon_sym_DQUOTE] = ACTIONS(6165),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6165),
    [anon_sym_LR_DQUOTE] = ACTIONS(6165),
    [anon_sym_uR_DQUOTE] = ACTIONS(6165),
    [anon_sym_UR_DQUOTE] = ACTIONS(6165),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6165),
    [sym_literal_suffix] = ACTIONS(6163),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6165),
  },
  [STATE(2715)] = {
    [sym_identifier] = ACTIONS(6886),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6888),
    [anon_sym_COMMA] = ACTIONS(6888),
    [anon_sym_RPAREN] = ACTIONS(6888),
    [aux_sym_preproc_if_token2] = ACTIONS(6888),
    [aux_sym_preproc_else_token1] = ACTIONS(6888),
    [aux_sym_preproc_elif_token1] = ACTIONS(6886),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6888),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6888),
    [anon_sym_LPAREN2] = ACTIONS(6888),
    [anon_sym_DASH] = ACTIONS(6886),
    [anon_sym_PLUS] = ACTIONS(6886),
    [anon_sym_STAR] = ACTIONS(6886),
    [anon_sym_SLASH] = ACTIONS(6886),
    [anon_sym_PERCENT] = ACTIONS(6886),
    [anon_sym_PIPE_PIPE] = ACTIONS(6888),
    [anon_sym_AMP_AMP] = ACTIONS(6888),
    [anon_sym_PIPE] = ACTIONS(6886),
    [anon_sym_CARET] = ACTIONS(6886),
    [anon_sym_AMP] = ACTIONS(6886),
    [anon_sym_EQ_EQ] = ACTIONS(6888),
    [anon_sym_BANG_EQ] = ACTIONS(6888),
    [anon_sym_GT] = ACTIONS(6886),
    [anon_sym_GT_EQ] = ACTIONS(6888),
    [anon_sym_LT_EQ] = ACTIONS(6886),
    [anon_sym_LT] = ACTIONS(6886),
    [anon_sym_LT_LT] = ACTIONS(6886),
    [anon_sym_GT_GT] = ACTIONS(6886),
    [anon_sym_SEMI] = ACTIONS(6888),
    [anon_sym___attribute__] = ACTIONS(6886),
    [anon_sym___attribute] = ACTIONS(6886),
    [anon_sym_LBRACE] = ACTIONS(6888),
    [anon_sym_RBRACE] = ACTIONS(6888),
    [anon_sym_LBRACK] = ACTIONS(6888),
    [anon_sym_RBRACK] = ACTIONS(6888),
    [anon_sym_EQ] = ACTIONS(6886),
    [anon_sym_COLON] = ACTIONS(6888),
    [anon_sym_QMARK] = ACTIONS(6888),
    [anon_sym_STAR_EQ] = ACTIONS(6888),
    [anon_sym_SLASH_EQ] = ACTIONS(6888),
    [anon_sym_PERCENT_EQ] = ACTIONS(6888),
    [anon_sym_PLUS_EQ] = ACTIONS(6888),
    [anon_sym_DASH_EQ] = ACTIONS(6888),
    [anon_sym_LT_LT_EQ] = ACTIONS(6888),
    [anon_sym_GT_GT_EQ] = ACTIONS(6888),
    [anon_sym_AMP_EQ] = ACTIONS(6888),
    [anon_sym_CARET_EQ] = ACTIONS(6888),
    [anon_sym_PIPE_EQ] = ACTIONS(6888),
    [anon_sym_and_eq] = ACTIONS(6886),
    [anon_sym_or_eq] = ACTIONS(6886),
    [anon_sym_xor_eq] = ACTIONS(6886),
    [anon_sym_LT_EQ_GT] = ACTIONS(6888),
    [anon_sym_or] = ACTIONS(6886),
    [anon_sym_and] = ACTIONS(6886),
    [anon_sym_bitor] = ACTIONS(6886),
    [anon_sym_xor] = ACTIONS(6886),
    [anon_sym_bitand] = ACTIONS(6886),
    [anon_sym_not_eq] = ACTIONS(6886),
    [anon_sym_DASH_DASH] = ACTIONS(6888),
    [anon_sym_PLUS_PLUS] = ACTIONS(6888),
    [anon_sym_DOT] = ACTIONS(6886),
    [anon_sym_DOT_STAR] = ACTIONS(6888),
    [anon_sym_DASH_GT] = ACTIONS(6888),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6888),
  },
  [STATE(2716)] = {
    [sym_identifier] = ACTIONS(6886),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6888),
    [anon_sym_COMMA] = ACTIONS(6888),
    [anon_sym_RPAREN] = ACTIONS(6888),
    [aux_sym_preproc_if_token2] = ACTIONS(6888),
    [aux_sym_preproc_else_token1] = ACTIONS(6888),
    [aux_sym_preproc_elif_token1] = ACTIONS(6886),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6888),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6888),
    [anon_sym_LPAREN2] = ACTIONS(6888),
    [anon_sym_DASH] = ACTIONS(6886),
    [anon_sym_PLUS] = ACTIONS(6886),
    [anon_sym_STAR] = ACTIONS(6886),
    [anon_sym_SLASH] = ACTIONS(6886),
    [anon_sym_PERCENT] = ACTIONS(6886),
    [anon_sym_PIPE_PIPE] = ACTIONS(6888),
    [anon_sym_AMP_AMP] = ACTIONS(6888),
    [anon_sym_PIPE] = ACTIONS(6886),
    [anon_sym_CARET] = ACTIONS(6886),
    [anon_sym_AMP] = ACTIONS(6886),
    [anon_sym_EQ_EQ] = ACTIONS(6888),
    [anon_sym_BANG_EQ] = ACTIONS(6888),
    [anon_sym_GT] = ACTIONS(6886),
    [anon_sym_GT_EQ] = ACTIONS(6888),
    [anon_sym_LT_EQ] = ACTIONS(6886),
    [anon_sym_LT] = ACTIONS(6886),
    [anon_sym_LT_LT] = ACTIONS(6886),
    [anon_sym_GT_GT] = ACTIONS(6886),
    [anon_sym_SEMI] = ACTIONS(6888),
    [anon_sym___attribute__] = ACTIONS(6886),
    [anon_sym___attribute] = ACTIONS(6886),
    [anon_sym_LBRACE] = ACTIONS(6888),
    [anon_sym_RBRACE] = ACTIONS(6888),
    [anon_sym_LBRACK] = ACTIONS(6888),
    [anon_sym_RBRACK] = ACTIONS(6888),
    [anon_sym_EQ] = ACTIONS(6886),
    [anon_sym_COLON] = ACTIONS(6888),
    [anon_sym_QMARK] = ACTIONS(6888),
    [anon_sym_STAR_EQ] = ACTIONS(6888),
    [anon_sym_SLASH_EQ] = ACTIONS(6888),
    [anon_sym_PERCENT_EQ] = ACTIONS(6888),
    [anon_sym_PLUS_EQ] = ACTIONS(6888),
    [anon_sym_DASH_EQ] = ACTIONS(6888),
    [anon_sym_LT_LT_EQ] = ACTIONS(6888),
    [anon_sym_GT_GT_EQ] = ACTIONS(6888),
    [anon_sym_AMP_EQ] = ACTIONS(6888),
    [anon_sym_CARET_EQ] = ACTIONS(6888),
    [anon_sym_PIPE_EQ] = ACTIONS(6888),
    [anon_sym_and_eq] = ACTIONS(6886),
    [anon_sym_or_eq] = ACTIONS(6886),
    [anon_sym_xor_eq] = ACTIONS(6886),
    [anon_sym_LT_EQ_GT] = ACTIONS(6888),
    [anon_sym_or] = ACTIONS(6886),
    [anon_sym_and] = ACTIONS(6886),
    [anon_sym_bitor] = ACTIONS(6886),
    [anon_sym_xor] = ACTIONS(6886),
    [anon_sym_bitand] = ACTIONS(6886),
    [anon_sym_not_eq] = ACTIONS(6886),
    [anon_sym_DASH_DASH] = ACTIONS(6888),
    [anon_sym_PLUS_PLUS] = ACTIONS(6888),
    [anon_sym_DOT] = ACTIONS(6886),
    [anon_sym_DOT_STAR] = ACTIONS(6888),
    [anon_sym_DASH_GT] = ACTIONS(6888),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6888),
  },
  [STATE(2717)] = {
    [sym_identifier] = ACTIONS(6890),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6892),
    [anon_sym_COMMA] = ACTIONS(6892),
    [anon_sym_RPAREN] = ACTIONS(6892),
    [aux_sym_preproc_if_token2] = ACTIONS(6892),
    [aux_sym_preproc_else_token1] = ACTIONS(6892),
    [aux_sym_preproc_elif_token1] = ACTIONS(6890),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6892),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6892),
    [anon_sym_LPAREN2] = ACTIONS(6892),
    [anon_sym_DASH] = ACTIONS(6890),
    [anon_sym_PLUS] = ACTIONS(6890),
    [anon_sym_STAR] = ACTIONS(6890),
    [anon_sym_SLASH] = ACTIONS(6890),
    [anon_sym_PERCENT] = ACTIONS(6890),
    [anon_sym_PIPE_PIPE] = ACTIONS(6892),
    [anon_sym_AMP_AMP] = ACTIONS(6892),
    [anon_sym_PIPE] = ACTIONS(6890),
    [anon_sym_CARET] = ACTIONS(6890),
    [anon_sym_AMP] = ACTIONS(6890),
    [anon_sym_EQ_EQ] = ACTIONS(6892),
    [anon_sym_BANG_EQ] = ACTIONS(6892),
    [anon_sym_GT] = ACTIONS(6890),
    [anon_sym_GT_EQ] = ACTIONS(6892),
    [anon_sym_LT_EQ] = ACTIONS(6890),
    [anon_sym_LT] = ACTIONS(6890),
    [anon_sym_LT_LT] = ACTIONS(6890),
    [anon_sym_GT_GT] = ACTIONS(6890),
    [anon_sym_SEMI] = ACTIONS(6892),
    [anon_sym___attribute__] = ACTIONS(6890),
    [anon_sym___attribute] = ACTIONS(6890),
    [anon_sym_LBRACE] = ACTIONS(6892),
    [anon_sym_RBRACE] = ACTIONS(6892),
    [anon_sym_LBRACK] = ACTIONS(6892),
    [anon_sym_RBRACK] = ACTIONS(6892),
    [anon_sym_EQ] = ACTIONS(6890),
    [anon_sym_COLON] = ACTIONS(6892),
    [anon_sym_QMARK] = ACTIONS(6892),
    [anon_sym_STAR_EQ] = ACTIONS(6892),
    [anon_sym_SLASH_EQ] = ACTIONS(6892),
    [anon_sym_PERCENT_EQ] = ACTIONS(6892),
    [anon_sym_PLUS_EQ] = ACTIONS(6892),
    [anon_sym_DASH_EQ] = ACTIONS(6892),
    [anon_sym_LT_LT_EQ] = ACTIONS(6892),
    [anon_sym_GT_GT_EQ] = ACTIONS(6892),
    [anon_sym_AMP_EQ] = ACTIONS(6892),
    [anon_sym_CARET_EQ] = ACTIONS(6892),
    [anon_sym_PIPE_EQ] = ACTIONS(6892),
    [anon_sym_and_eq] = ACTIONS(6890),
    [anon_sym_or_eq] = ACTIONS(6890),
    [anon_sym_xor_eq] = ACTIONS(6890),
    [anon_sym_LT_EQ_GT] = ACTIONS(6892),
    [anon_sym_or] = ACTIONS(6890),
    [anon_sym_and] = ACTIONS(6890),
    [anon_sym_bitor] = ACTIONS(6890),
    [anon_sym_xor] = ACTIONS(6890),
    [anon_sym_bitand] = ACTIONS(6890),
    [anon_sym_not_eq] = ACTIONS(6890),
    [anon_sym_DASH_DASH] = ACTIONS(6892),
    [anon_sym_PLUS_PLUS] = ACTIONS(6892),
    [anon_sym_DOT] = ACTIONS(6890),
    [anon_sym_DOT_STAR] = ACTIONS(6892),
    [anon_sym_DASH_GT] = ACTIONS(6892),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6892),
  },
  [STATE(2718)] = {
    [sym_template_argument_list] = STATE(2360),
    [sym_identifier] = ACTIONS(5669),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4028),
    [anon_sym_COMMA] = ACTIONS(4028),
    [anon_sym_RPAREN] = ACTIONS(4028),
    [anon_sym_LPAREN2] = ACTIONS(4028),
    [anon_sym_TILDE] = ACTIONS(4028),
    [anon_sym_STAR] = ACTIONS(4028),
    [anon_sym_AMP_AMP] = ACTIONS(4028),
    [anon_sym_AMP] = ACTIONS(5669),
    [anon_sym_LT] = ACTIONS(6782),
    [anon_sym___extension__] = ACTIONS(5669),
    [anon_sym___device__] = ACTIONS(5669),
    [anon_sym___host__] = ACTIONS(5669),
    [anon_sym___global__] = ACTIONS(5669),
    [anon_sym___forceinline__] = ACTIONS(5669),
    [anon_sym___noinline__] = ACTIONS(5669),
    [anon_sym_virtual] = ACTIONS(5669),
    [anon_sym_extern] = ACTIONS(5669),
    [anon_sym___attribute__] = ACTIONS(5669),
    [anon_sym___attribute] = ACTIONS(5669),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4028),
    [anon_sym___declspec] = ACTIONS(5669),
    [anon_sym___based] = ACTIONS(5669),
    [anon_sym_LBRACE] = ACTIONS(4028),
    [anon_sym_LBRACK] = ACTIONS(5669),
    [anon_sym_static] = ACTIONS(5669),
    [anon_sym_EQ] = ACTIONS(4028),
    [anon_sym_register] = ACTIONS(5669),
    [anon_sym_inline] = ACTIONS(5669),
    [anon_sym___inline] = ACTIONS(5669),
    [anon_sym___inline__] = ACTIONS(5669),
    [anon_sym___forceinline] = ACTIONS(5669),
    [anon_sym_thread_local] = ACTIONS(5669),
    [anon_sym___thread] = ACTIONS(5669),
    [anon_sym_const] = ACTIONS(5669),
    [anon_sym_constexpr] = ACTIONS(5669),
    [anon_sym_volatile] = ACTIONS(5669),
    [anon_sym_restrict] = ACTIONS(5669),
    [anon_sym___restrict__] = ACTIONS(5669),
    [anon_sym__Atomic] = ACTIONS(5669),
    [anon_sym__Noreturn] = ACTIONS(5669),
    [anon_sym_noreturn] = ACTIONS(5669),
    [anon_sym__Nonnull] = ACTIONS(5669),
    [anon_sym_mutable] = ACTIONS(5669),
    [anon_sym_constinit] = ACTIONS(5669),
    [anon_sym_consteval] = ACTIONS(5669),
    [anon_sym___shared__] = ACTIONS(5669),
    [anon_sym___local__] = ACTIONS(5669),
    [anon_sym___constant__] = ACTIONS(5669),
    [anon_sym___managed__] = ACTIONS(5669),
    [anon_sym___grid_constant__] = ACTIONS(5669),
    [anon_sym_alignas] = ACTIONS(5669),
    [anon_sym__Alignas] = ACTIONS(5669),
    [anon_sym_COLON] = ACTIONS(5669),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5669),
    [anon_sym_decltype] = ACTIONS(5669),
    [anon_sym_final] = ACTIONS(5669),
    [anon_sym_override] = ACTIONS(5669),
    [anon_sym_template] = ACTIONS(5669),
    [anon_sym_GT2] = ACTIONS(4028),
    [anon_sym_operator] = ACTIONS(5669),
    [anon_sym___launch_bounds__] = ACTIONS(5669),
  },
  [STATE(2719)] = {
    [sym_template_argument_list] = STATE(1659),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2860),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6074),
    [anon_sym_COMMA] = ACTIONS(6074),
    [anon_sym_RPAREN] = ACTIONS(6074),
    [anon_sym_LPAREN2] = ACTIONS(6074),
    [anon_sym_DASH] = ACTIONS(6072),
    [anon_sym_PLUS] = ACTIONS(6072),
    [anon_sym_STAR] = ACTIONS(6072),
    [anon_sym_SLASH] = ACTIONS(6072),
    [anon_sym_PERCENT] = ACTIONS(6072),
    [anon_sym_PIPE_PIPE] = ACTIONS(6074),
    [anon_sym_AMP_AMP] = ACTIONS(6074),
    [anon_sym_PIPE] = ACTIONS(6072),
    [anon_sym_CARET] = ACTIONS(6072),
    [anon_sym_AMP] = ACTIONS(6072),
    [anon_sym_EQ_EQ] = ACTIONS(6074),
    [anon_sym_BANG_EQ] = ACTIONS(6074),
    [anon_sym_GT] = ACTIONS(6072),
    [anon_sym_GT_EQ] = ACTIONS(6074),
    [anon_sym_LT_EQ] = ACTIONS(6072),
    [anon_sym_LT] = ACTIONS(6072),
    [anon_sym_LT_LT] = ACTIONS(6072),
    [anon_sym_GT_GT] = ACTIONS(6072),
    [anon_sym___attribute__] = ACTIONS(6074),
    [anon_sym___attribute] = ACTIONS(6072),
    [anon_sym_COLON_COLON] = ACTIONS(4023),
    [anon_sym_LBRACE] = ACTIONS(6074),
    [anon_sym_signed] = ACTIONS(6894),
    [anon_sym_unsigned] = ACTIONS(6894),
    [anon_sym_long] = ACTIONS(6894),
    [anon_sym_short] = ACTIONS(6894),
    [anon_sym_LBRACK] = ACTIONS(6074),
    [anon_sym_EQ] = ACTIONS(6072),
    [anon_sym_QMARK] = ACTIONS(6074),
    [anon_sym_STAR_EQ] = ACTIONS(6074),
    [anon_sym_SLASH_EQ] = ACTIONS(6074),
    [anon_sym_PERCENT_EQ] = ACTIONS(6074),
    [anon_sym_PLUS_EQ] = ACTIONS(6074),
    [anon_sym_DASH_EQ] = ACTIONS(6074),
    [anon_sym_LT_LT_EQ] = ACTIONS(6074),
    [anon_sym_GT_GT_EQ] = ACTIONS(6074),
    [anon_sym_AMP_EQ] = ACTIONS(6074),
    [anon_sym_CARET_EQ] = ACTIONS(6074),
    [anon_sym_PIPE_EQ] = ACTIONS(6074),
    [anon_sym_and_eq] = ACTIONS(6074),
    [anon_sym_or_eq] = ACTIONS(6074),
    [anon_sym_xor_eq] = ACTIONS(6074),
    [anon_sym_LT_EQ_GT] = ACTIONS(6074),
    [anon_sym_or] = ACTIONS(6072),
    [anon_sym_and] = ACTIONS(6072),
    [anon_sym_bitor] = ACTIONS(6074),
    [anon_sym_xor] = ACTIONS(6072),
    [anon_sym_bitand] = ACTIONS(6074),
    [anon_sym_not_eq] = ACTIONS(6074),
    [anon_sym_DASH_DASH] = ACTIONS(6074),
    [anon_sym_PLUS_PLUS] = ACTIONS(6074),
    [anon_sym_DOT] = ACTIONS(6072),
    [anon_sym_DOT_STAR] = ACTIONS(6074),
    [anon_sym_DASH_GT] = ACTIONS(6072),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6074),
    [anon_sym_decltype] = ACTIONS(6074),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6074),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6074),
  },
  [STATE(2720)] = {
    [sym_identifier] = ACTIONS(6728),
    [anon_sym_LPAREN2] = ACTIONS(6730),
    [anon_sym_TILDE] = ACTIONS(6730),
    [anon_sym_STAR] = ACTIONS(6730),
    [anon_sym_AMP_AMP] = ACTIONS(6730),
    [anon_sym_AMP] = ACTIONS(6728),
    [anon_sym___extension__] = ACTIONS(6728),
    [anon_sym___device__] = ACTIONS(6728),
    [anon_sym___host__] = ACTIONS(6728),
    [anon_sym___global__] = ACTIONS(6728),
    [anon_sym___forceinline__] = ACTIONS(6728),
    [anon_sym___noinline__] = ACTIONS(6728),
    [anon_sym_virtual] = ACTIONS(6728),
    [anon_sym_extern] = ACTIONS(6728),
    [anon_sym___attribute__] = ACTIONS(6728),
    [anon_sym___attribute] = ACTIONS(6728),
    [anon_sym_COLON_COLON] = ACTIONS(6730),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6730),
    [anon_sym___declspec] = ACTIONS(6728),
    [anon_sym___based] = ACTIONS(6728),
    [anon_sym_signed] = ACTIONS(6728),
    [anon_sym_unsigned] = ACTIONS(6728),
    [anon_sym_long] = ACTIONS(6728),
    [anon_sym_short] = ACTIONS(6728),
    [anon_sym_LBRACK] = ACTIONS(6728),
    [anon_sym_static] = ACTIONS(6728),
    [anon_sym_register] = ACTIONS(6728),
    [anon_sym_inline] = ACTIONS(6728),
    [anon_sym___inline] = ACTIONS(6728),
    [anon_sym___inline__] = ACTIONS(6728),
    [anon_sym___forceinline] = ACTIONS(6728),
    [anon_sym_thread_local] = ACTIONS(6728),
    [anon_sym___thread] = ACTIONS(6728),
    [anon_sym_const] = ACTIONS(6728),
    [anon_sym_constexpr] = ACTIONS(6728),
    [anon_sym_volatile] = ACTIONS(6728),
    [anon_sym_restrict] = ACTIONS(6728),
    [anon_sym___restrict__] = ACTIONS(6728),
    [anon_sym__Atomic] = ACTIONS(6728),
    [anon_sym__Noreturn] = ACTIONS(6728),
    [anon_sym_noreturn] = ACTIONS(6728),
    [anon_sym__Nonnull] = ACTIONS(6728),
    [anon_sym_mutable] = ACTIONS(6728),
    [anon_sym_constinit] = ACTIONS(6728),
    [anon_sym_consteval] = ACTIONS(6728),
    [anon_sym___shared__] = ACTIONS(6728),
    [anon_sym___local__] = ACTIONS(6728),
    [anon_sym___constant__] = ACTIONS(6728),
    [anon_sym___managed__] = ACTIONS(6728),
    [anon_sym___grid_constant__] = ACTIONS(6728),
    [anon_sym_alignas] = ACTIONS(6728),
    [anon_sym__Alignas] = ACTIONS(6728),
    [sym_primitive_type] = ACTIONS(6728),
    [anon_sym_enum] = ACTIONS(6728),
    [anon_sym_class] = ACTIONS(6728),
    [anon_sym_struct] = ACTIONS(6728),
    [anon_sym_union] = ACTIONS(6728),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6728),
    [anon_sym_decltype] = ACTIONS(6728),
    [anon_sym_explicit] = ACTIONS(6728),
    [anon_sym_typename] = ACTIONS(6728),
    [anon_sym_template] = ACTIONS(6728),
    [anon_sym_operator] = ACTIONS(6728),
    [anon_sym___launch_bounds__] = ACTIONS(6728),
  },
  [STATE(2721)] = {
    [sym_identifier] = ACTIONS(6286),
    [anon_sym_LPAREN2] = ACTIONS(6288),
    [anon_sym_TILDE] = ACTIONS(6288),
    [anon_sym_STAR] = ACTIONS(6288),
    [anon_sym_AMP_AMP] = ACTIONS(6288),
    [anon_sym_AMP] = ACTIONS(6286),
    [anon_sym___extension__] = ACTIONS(6286),
    [anon_sym___device__] = ACTIONS(6286),
    [anon_sym___host__] = ACTIONS(6286),
    [anon_sym___global__] = ACTIONS(6286),
    [anon_sym___forceinline__] = ACTIONS(6286),
    [anon_sym___noinline__] = ACTIONS(6286),
    [anon_sym_virtual] = ACTIONS(6286),
    [anon_sym_extern] = ACTIONS(6286),
    [anon_sym___attribute__] = ACTIONS(6286),
    [anon_sym___attribute] = ACTIONS(6286),
    [anon_sym_COLON_COLON] = ACTIONS(6288),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6288),
    [anon_sym___declspec] = ACTIONS(6286),
    [anon_sym___based] = ACTIONS(6286),
    [anon_sym_signed] = ACTIONS(6286),
    [anon_sym_unsigned] = ACTIONS(6286),
    [anon_sym_long] = ACTIONS(6286),
    [anon_sym_short] = ACTIONS(6286),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [anon_sym_static] = ACTIONS(6286),
    [anon_sym_register] = ACTIONS(6286),
    [anon_sym_inline] = ACTIONS(6286),
    [anon_sym___inline] = ACTIONS(6286),
    [anon_sym___inline__] = ACTIONS(6286),
    [anon_sym___forceinline] = ACTIONS(6286),
    [anon_sym_thread_local] = ACTIONS(6286),
    [anon_sym___thread] = ACTIONS(6286),
    [anon_sym_const] = ACTIONS(6286),
    [anon_sym_constexpr] = ACTIONS(6286),
    [anon_sym_volatile] = ACTIONS(6286),
    [anon_sym_restrict] = ACTIONS(6286),
    [anon_sym___restrict__] = ACTIONS(6286),
    [anon_sym__Atomic] = ACTIONS(6286),
    [anon_sym__Noreturn] = ACTIONS(6286),
    [anon_sym_noreturn] = ACTIONS(6286),
    [anon_sym__Nonnull] = ACTIONS(6286),
    [anon_sym_mutable] = ACTIONS(6286),
    [anon_sym_constinit] = ACTIONS(6286),
    [anon_sym_consteval] = ACTIONS(6286),
    [anon_sym___shared__] = ACTIONS(6286),
    [anon_sym___local__] = ACTIONS(6286),
    [anon_sym___constant__] = ACTIONS(6286),
    [anon_sym___managed__] = ACTIONS(6286),
    [anon_sym___grid_constant__] = ACTIONS(6286),
    [anon_sym_alignas] = ACTIONS(6286),
    [anon_sym__Alignas] = ACTIONS(6286),
    [sym_primitive_type] = ACTIONS(6286),
    [anon_sym_enum] = ACTIONS(6286),
    [anon_sym_class] = ACTIONS(6286),
    [anon_sym_struct] = ACTIONS(6286),
    [anon_sym_union] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6286),
    [anon_sym_decltype] = ACTIONS(6286),
    [anon_sym_explicit] = ACTIONS(6286),
    [anon_sym_typename] = ACTIONS(6286),
    [anon_sym_template] = ACTIONS(6286),
    [anon_sym_operator] = ACTIONS(6286),
    [anon_sym___launch_bounds__] = ACTIONS(6286),
  },
  [STATE(2722)] = {
    [sym_template_argument_list] = STATE(2672),
    [sym_identifier] = ACTIONS(6896),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6898),
    [anon_sym_COMMA] = ACTIONS(6898),
    [anon_sym_RPAREN] = ACTIONS(6898),
    [aux_sym_preproc_if_token2] = ACTIONS(6898),
    [aux_sym_preproc_else_token1] = ACTIONS(6898),
    [aux_sym_preproc_elif_token1] = ACTIONS(6896),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6898),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6898),
    [anon_sym_LPAREN2] = ACTIONS(6898),
    [anon_sym_DASH] = ACTIONS(6896),
    [anon_sym_PLUS] = ACTIONS(6896),
    [anon_sym_STAR] = ACTIONS(6896),
    [anon_sym_SLASH] = ACTIONS(6896),
    [anon_sym_PERCENT] = ACTIONS(6896),
    [anon_sym_PIPE_PIPE] = ACTIONS(6898),
    [anon_sym_AMP_AMP] = ACTIONS(6898),
    [anon_sym_PIPE] = ACTIONS(6896),
    [anon_sym_CARET] = ACTIONS(6896),
    [anon_sym_AMP] = ACTIONS(6896),
    [anon_sym_EQ_EQ] = ACTIONS(6898),
    [anon_sym_BANG_EQ] = ACTIONS(6898),
    [anon_sym_GT] = ACTIONS(6896),
    [anon_sym_GT_EQ] = ACTIONS(6898),
    [anon_sym_LT_EQ] = ACTIONS(6896),
    [anon_sym_LT] = ACTIONS(6900),
    [anon_sym_LT_LT] = ACTIONS(6896),
    [anon_sym_GT_GT] = ACTIONS(6896),
    [anon_sym_SEMI] = ACTIONS(6898),
    [anon_sym___attribute__] = ACTIONS(6896),
    [anon_sym___attribute] = ACTIONS(6896),
    [anon_sym_RBRACE] = ACTIONS(6898),
    [anon_sym_LBRACK] = ACTIONS(6898),
    [anon_sym_RBRACK] = ACTIONS(6898),
    [anon_sym_EQ] = ACTIONS(6896),
    [anon_sym_COLON] = ACTIONS(6898),
    [anon_sym_QMARK] = ACTIONS(6898),
    [anon_sym_STAR_EQ] = ACTIONS(6898),
    [anon_sym_SLASH_EQ] = ACTIONS(6898),
    [anon_sym_PERCENT_EQ] = ACTIONS(6898),
    [anon_sym_PLUS_EQ] = ACTIONS(6898),
    [anon_sym_DASH_EQ] = ACTIONS(6898),
    [anon_sym_LT_LT_EQ] = ACTIONS(6898),
    [anon_sym_GT_GT_EQ] = ACTIONS(6898),
    [anon_sym_AMP_EQ] = ACTIONS(6898),
    [anon_sym_CARET_EQ] = ACTIONS(6898),
    [anon_sym_PIPE_EQ] = ACTIONS(6898),
    [anon_sym_and_eq] = ACTIONS(6896),
    [anon_sym_or_eq] = ACTIONS(6896),
    [anon_sym_xor_eq] = ACTIONS(6896),
    [anon_sym_LT_EQ_GT] = ACTIONS(6898),
    [anon_sym_or] = ACTIONS(6896),
    [anon_sym_and] = ACTIONS(6896),
    [anon_sym_bitor] = ACTIONS(6896),
    [anon_sym_xor] = ACTIONS(6896),
    [anon_sym_bitand] = ACTIONS(6896),
    [anon_sym_not_eq] = ACTIONS(6896),
    [anon_sym_DASH_DASH] = ACTIONS(6898),
    [anon_sym_PLUS_PLUS] = ACTIONS(6898),
    [anon_sym_DOT] = ACTIONS(6896),
    [anon_sym_DOT_STAR] = ACTIONS(6898),
    [anon_sym_DASH_GT] = ACTIONS(6898),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6898),
  },
  [STATE(2723)] = {
    [sym_identifier] = ACTIONS(6903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6905),
    [anon_sym_COMMA] = ACTIONS(6905),
    [anon_sym_RPAREN] = ACTIONS(6905),
    [aux_sym_preproc_if_token2] = ACTIONS(6905),
    [aux_sym_preproc_else_token1] = ACTIONS(6905),
    [aux_sym_preproc_elif_token1] = ACTIONS(6903),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6905),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6905),
    [anon_sym_LPAREN2] = ACTIONS(6905),
    [anon_sym_DASH] = ACTIONS(6903),
    [anon_sym_PLUS] = ACTIONS(6903),
    [anon_sym_STAR] = ACTIONS(6903),
    [anon_sym_SLASH] = ACTIONS(6903),
    [anon_sym_PERCENT] = ACTIONS(6903),
    [anon_sym_PIPE_PIPE] = ACTIONS(6905),
    [anon_sym_AMP_AMP] = ACTIONS(6905),
    [anon_sym_PIPE] = ACTIONS(6903),
    [anon_sym_CARET] = ACTIONS(6903),
    [anon_sym_AMP] = ACTIONS(6903),
    [anon_sym_EQ_EQ] = ACTIONS(6905),
    [anon_sym_BANG_EQ] = ACTIONS(6905),
    [anon_sym_GT] = ACTIONS(6903),
    [anon_sym_GT_EQ] = ACTIONS(6905),
    [anon_sym_LT_EQ] = ACTIONS(6903),
    [anon_sym_LT] = ACTIONS(6903),
    [anon_sym_LT_LT] = ACTIONS(6903),
    [anon_sym_GT_GT] = ACTIONS(6903),
    [anon_sym_SEMI] = ACTIONS(6905),
    [anon_sym___attribute__] = ACTIONS(6903),
    [anon_sym___attribute] = ACTIONS(6903),
    [anon_sym_LBRACE] = ACTIONS(6905),
    [anon_sym_RBRACE] = ACTIONS(6905),
    [anon_sym_LBRACK] = ACTIONS(6905),
    [anon_sym_RBRACK] = ACTIONS(6905),
    [anon_sym_EQ] = ACTIONS(6903),
    [anon_sym_COLON] = ACTIONS(6905),
    [anon_sym_QMARK] = ACTIONS(6905),
    [anon_sym_STAR_EQ] = ACTIONS(6905),
    [anon_sym_SLASH_EQ] = ACTIONS(6905),
    [anon_sym_PERCENT_EQ] = ACTIONS(6905),
    [anon_sym_PLUS_EQ] = ACTIONS(6905),
    [anon_sym_DASH_EQ] = ACTIONS(6905),
    [anon_sym_LT_LT_EQ] = ACTIONS(6905),
    [anon_sym_GT_GT_EQ] = ACTIONS(6905),
    [anon_sym_AMP_EQ] = ACTIONS(6905),
    [anon_sym_CARET_EQ] = ACTIONS(6905),
    [anon_sym_PIPE_EQ] = ACTIONS(6905),
    [anon_sym_and_eq] = ACTIONS(6903),
    [anon_sym_or_eq] = ACTIONS(6903),
    [anon_sym_xor_eq] = ACTIONS(6903),
    [anon_sym_LT_EQ_GT] = ACTIONS(6905),
    [anon_sym_or] = ACTIONS(6903),
    [anon_sym_and] = ACTIONS(6903),
    [anon_sym_bitor] = ACTIONS(6903),
    [anon_sym_xor] = ACTIONS(6903),
    [anon_sym_bitand] = ACTIONS(6903),
    [anon_sym_not_eq] = ACTIONS(6903),
    [anon_sym_DASH_DASH] = ACTIONS(6905),
    [anon_sym_PLUS_PLUS] = ACTIONS(6905),
    [anon_sym_DOT] = ACTIONS(6903),
    [anon_sym_DOT_STAR] = ACTIONS(6905),
    [anon_sym_DASH_GT] = ACTIONS(6905),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6905),
  },
  [STATE(2724)] = {
    [sym_identifier] = ACTIONS(6907),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6909),
    [anon_sym_COMMA] = ACTIONS(6909),
    [anon_sym_RPAREN] = ACTIONS(6909),
    [aux_sym_preproc_if_token2] = ACTIONS(6909),
    [aux_sym_preproc_else_token1] = ACTIONS(6909),
    [aux_sym_preproc_elif_token1] = ACTIONS(6907),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6909),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6909),
    [anon_sym_LPAREN2] = ACTIONS(6909),
    [anon_sym_DASH] = ACTIONS(6907),
    [anon_sym_PLUS] = ACTIONS(6907),
    [anon_sym_STAR] = ACTIONS(6907),
    [anon_sym_SLASH] = ACTIONS(6907),
    [anon_sym_PERCENT] = ACTIONS(6907),
    [anon_sym_PIPE_PIPE] = ACTIONS(6909),
    [anon_sym_AMP_AMP] = ACTIONS(6909),
    [anon_sym_PIPE] = ACTIONS(6907),
    [anon_sym_CARET] = ACTIONS(6907),
    [anon_sym_AMP] = ACTIONS(6907),
    [anon_sym_EQ_EQ] = ACTIONS(6909),
    [anon_sym_BANG_EQ] = ACTIONS(6909),
    [anon_sym_GT] = ACTIONS(6907),
    [anon_sym_GT_EQ] = ACTIONS(6909),
    [anon_sym_LT_EQ] = ACTIONS(6907),
    [anon_sym_LT] = ACTIONS(6907),
    [anon_sym_LT_LT] = ACTIONS(6907),
    [anon_sym_GT_GT] = ACTIONS(6907),
    [anon_sym_SEMI] = ACTIONS(6909),
    [anon_sym___attribute__] = ACTIONS(6907),
    [anon_sym___attribute] = ACTIONS(6907),
    [anon_sym_LBRACE] = ACTIONS(6909),
    [anon_sym_RBRACE] = ACTIONS(6909),
    [anon_sym_LBRACK] = ACTIONS(6909),
    [anon_sym_RBRACK] = ACTIONS(6909),
    [anon_sym_EQ] = ACTIONS(6907),
    [anon_sym_COLON] = ACTIONS(6909),
    [anon_sym_QMARK] = ACTIONS(6909),
    [anon_sym_STAR_EQ] = ACTIONS(6909),
    [anon_sym_SLASH_EQ] = ACTIONS(6909),
    [anon_sym_PERCENT_EQ] = ACTIONS(6909),
    [anon_sym_PLUS_EQ] = ACTIONS(6909),
    [anon_sym_DASH_EQ] = ACTIONS(6909),
    [anon_sym_LT_LT_EQ] = ACTIONS(6909),
    [anon_sym_GT_GT_EQ] = ACTIONS(6909),
    [anon_sym_AMP_EQ] = ACTIONS(6909),
    [anon_sym_CARET_EQ] = ACTIONS(6909),
    [anon_sym_PIPE_EQ] = ACTIONS(6909),
    [anon_sym_and_eq] = ACTIONS(6907),
    [anon_sym_or_eq] = ACTIONS(6907),
    [anon_sym_xor_eq] = ACTIONS(6907),
    [anon_sym_LT_EQ_GT] = ACTIONS(6909),
    [anon_sym_or] = ACTIONS(6907),
    [anon_sym_and] = ACTIONS(6907),
    [anon_sym_bitor] = ACTIONS(6907),
    [anon_sym_xor] = ACTIONS(6907),
    [anon_sym_bitand] = ACTIONS(6907),
    [anon_sym_not_eq] = ACTIONS(6907),
    [anon_sym_DASH_DASH] = ACTIONS(6909),
    [anon_sym_PLUS_PLUS] = ACTIONS(6909),
    [anon_sym_DOT] = ACTIONS(6907),
    [anon_sym_DOT_STAR] = ACTIONS(6909),
    [anon_sym_DASH_GT] = ACTIONS(6909),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6909),
  },
  [STATE(2725)] = {
    [sym_string_literal] = STATE(2536),
    [sym_raw_string_literal] = STATE(2536),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6354),
    [anon_sym_COMMA] = ACTIONS(6354),
    [anon_sym_LPAREN2] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6352),
    [anon_sym_STAR] = ACTIONS(6352),
    [anon_sym_SLASH] = ACTIONS(6352),
    [anon_sym_PERCENT] = ACTIONS(6352),
    [anon_sym_PIPE_PIPE] = ACTIONS(6354),
    [anon_sym_AMP_AMP] = ACTIONS(6354),
    [anon_sym_PIPE] = ACTIONS(6352),
    [anon_sym_CARET] = ACTIONS(6352),
    [anon_sym_AMP] = ACTIONS(6352),
    [anon_sym_EQ_EQ] = ACTIONS(6354),
    [anon_sym_BANG_EQ] = ACTIONS(6354),
    [anon_sym_GT] = ACTIONS(6352),
    [anon_sym_GT_EQ] = ACTIONS(6354),
    [anon_sym_LT_EQ] = ACTIONS(6352),
    [anon_sym_LT] = ACTIONS(6352),
    [anon_sym_LT_LT] = ACTIONS(6352),
    [anon_sym_GT_GT] = ACTIONS(6352),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [anon_sym_EQ] = ACTIONS(6352),
    [anon_sym_QMARK] = ACTIONS(6354),
    [anon_sym_STAR_EQ] = ACTIONS(6354),
    [anon_sym_SLASH_EQ] = ACTIONS(6354),
    [anon_sym_PERCENT_EQ] = ACTIONS(6354),
    [anon_sym_PLUS_EQ] = ACTIONS(6354),
    [anon_sym_DASH_EQ] = ACTIONS(6354),
    [anon_sym_LT_LT_EQ] = ACTIONS(6354),
    [anon_sym_GT_GT_EQ] = ACTIONS(6354),
    [anon_sym_AMP_EQ] = ACTIONS(6354),
    [anon_sym_CARET_EQ] = ACTIONS(6354),
    [anon_sym_PIPE_EQ] = ACTIONS(6354),
    [anon_sym_and_eq] = ACTIONS(6352),
    [anon_sym_or_eq] = ACTIONS(6352),
    [anon_sym_xor_eq] = ACTIONS(6352),
    [anon_sym_LT_EQ_GT] = ACTIONS(6354),
    [anon_sym_or] = ACTIONS(6352),
    [anon_sym_and] = ACTIONS(6352),
    [anon_sym_bitor] = ACTIONS(6352),
    [anon_sym_xor] = ACTIONS(6352),
    [anon_sym_bitand] = ACTIONS(6352),
    [anon_sym_not_eq] = ACTIONS(6352),
    [anon_sym_DASH_DASH] = ACTIONS(6354),
    [anon_sym_PLUS_PLUS] = ACTIONS(6354),
    [anon_sym_DOT] = ACTIONS(6352),
    [anon_sym_DOT_STAR] = ACTIONS(6354),
    [anon_sym_DASH_GT] = ACTIONS(6354),
    [anon_sym_L_DQUOTE] = ACTIONS(6522),
    [anon_sym_u_DQUOTE] = ACTIONS(6522),
    [anon_sym_U_DQUOTE] = ACTIONS(6522),
    [anon_sym_u8_DQUOTE] = ACTIONS(6522),
    [anon_sym_DQUOTE] = ACTIONS(6522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6524),
    [anon_sym_LR_DQUOTE] = ACTIONS(6524),
    [anon_sym_uR_DQUOTE] = ACTIONS(6524),
    [anon_sym_UR_DQUOTE] = ACTIONS(6524),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6524),
    [sym_literal_suffix] = ACTIONS(6352),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6354),
    [aux_sym_kernel_call_syntax_token2] = ACTIONS(6354),
  },
  [STATE(2726)] = {
    [sym_identifier] = ACTIONS(3830),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3832),
    [anon_sym_COMMA] = ACTIONS(3832),
    [anon_sym_RPAREN] = ACTIONS(3832),
    [aux_sym_preproc_if_token2] = ACTIONS(3832),
    [aux_sym_preproc_else_token1] = ACTIONS(3832),
    [aux_sym_preproc_elif_token1] = ACTIONS(3830),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(3832),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(3832),
    [anon_sym_LPAREN2] = ACTIONS(3832),
    [anon_sym_DASH] = ACTIONS(3830),
    [anon_sym_PLUS] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_SLASH] = ACTIONS(3830),
    [anon_sym_PERCENT] = ACTIONS(3830),
    [anon_sym_PIPE_PIPE] = ACTIONS(3832),
    [anon_sym_AMP_AMP] = ACTIONS(3832),
    [anon_sym_PIPE] = ACTIONS(3830),
    [anon_sym_CARET] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3830),
    [anon_sym_EQ_EQ] = ACTIONS(3832),
    [anon_sym_BANG_EQ] = ACTIONS(3832),
    [anon_sym_GT] = ACTIONS(3830),
    [anon_sym_GT_EQ] = ACTIONS(3832),
    [anon_sym_LT_EQ] = ACTIONS(3830),
    [anon_sym_LT] = ACTIONS(3830),
    [anon_sym_LT_LT] = ACTIONS(3830),
    [anon_sym_GT_GT] = ACTIONS(3830),
    [anon_sym_SEMI] = ACTIONS(3832),
    [anon_sym___attribute__] = ACTIONS(3830),
    [anon_sym___attribute] = ACTIONS(3830),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3832),
    [anon_sym_RBRACE] = ACTIONS(3832),
    [anon_sym_LBRACK] = ACTIONS(3830),
    [anon_sym_RBRACK] = ACTIONS(3832),
    [anon_sym_EQ] = ACTIONS(3830),
    [anon_sym_COLON] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3832),
    [anon_sym_STAR_EQ] = ACTIONS(3832),
    [anon_sym_SLASH_EQ] = ACTIONS(3832),
    [anon_sym_PERCENT_EQ] = ACTIONS(3832),
    [anon_sym_PLUS_EQ] = ACTIONS(3832),
    [anon_sym_DASH_EQ] = ACTIONS(3832),
    [anon_sym_LT_LT_EQ] = ACTIONS(3832),
    [anon_sym_GT_GT_EQ] = ACTIONS(3832),
    [anon_sym_AMP_EQ] = ACTIONS(3832),
    [anon_sym_CARET_EQ] = ACTIONS(3832),
    [anon_sym_PIPE_EQ] = ACTIONS(3832),
    [anon_sym_and_eq] = ACTIONS(3830),
    [anon_sym_or_eq] = ACTIONS(3830),
    [anon_sym_xor_eq] = ACTIONS(3830),
    [anon_sym_LT_EQ_GT] = ACTIONS(3832),
    [anon_sym_or] = ACTIONS(3830),
    [anon_sym_and] = ACTIONS(3830),
    [anon_sym_bitor] = ACTIONS(3830),
    [anon_sym_xor] = ACTIONS(3830),
    [anon_sym_bitand] = ACTIONS(3830),
    [anon_sym_not_eq] = ACTIONS(3830),
    [anon_sym_DASH_DASH] = ACTIONS(3832),
    [anon_sym_PLUS_PLUS] = ACTIONS(3832),
    [anon_sym_DOT] = ACTIONS(3830),
    [anon_sym_DOT_STAR] = ACTIONS(3832),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(3832),
  },
  [STATE(2727)] = {
    [sym_string_literal] = STATE(2696),
    [sym_raw_string_literal] = STATE(2696),
    [aux_sym_concatenated_string_repeat1] = STATE(2696),
    [sym_identifier] = ACTIONS(6911),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6016),
    [anon_sym_COMMA] = ACTIONS(6016),
    [anon_sym_RPAREN] = ACTIONS(6016),
    [anon_sym_LPAREN2] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6018),
    [anon_sym_STAR] = ACTIONS(6018),
    [anon_sym_SLASH] = ACTIONS(6018),
    [anon_sym_PERCENT] = ACTIONS(6018),
    [anon_sym_PIPE_PIPE] = ACTIONS(6016),
    [anon_sym_AMP_AMP] = ACTIONS(6016),
    [anon_sym_PIPE] = ACTIONS(6018),
    [anon_sym_CARET] = ACTIONS(6018),
    [anon_sym_AMP] = ACTIONS(6018),
    [anon_sym_EQ_EQ] = ACTIONS(6016),
    [anon_sym_BANG_EQ] = ACTIONS(6016),
    [anon_sym_GT] = ACTIONS(6018),
    [anon_sym_GT_EQ] = ACTIONS(6016),
    [anon_sym_LT_EQ] = ACTIONS(6018),
    [anon_sym_LT] = ACTIONS(6018),
    [anon_sym_LT_LT] = ACTIONS(6018),
    [anon_sym_GT_GT] = ACTIONS(6018),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [anon_sym_EQ] = ACTIONS(6018),
    [anon_sym_QMARK] = ACTIONS(6016),
    [anon_sym_STAR_EQ] = ACTIONS(6016),
    [anon_sym_SLASH_EQ] = ACTIONS(6016),
    [anon_sym_PERCENT_EQ] = ACTIONS(6016),
    [anon_sym_PLUS_EQ] = ACTIONS(6016),
    [anon_sym_DASH_EQ] = ACTIONS(6016),
    [anon_sym_LT_LT_EQ] = ACTIONS(6016),
    [anon_sym_GT_GT_EQ] = ACTIONS(6016),
    [anon_sym_AMP_EQ] = ACTIONS(6016),
    [anon_sym_CARET_EQ] = ACTIONS(6016),
    [anon_sym_PIPE_EQ] = ACTIONS(6016),
    [anon_sym_LT_EQ_GT] = ACTIONS(6016),
    [anon_sym_or] = ACTIONS(6018),
    [anon_sym_and] = ACTIONS(6018),
    [anon_sym_bitor] = ACTIONS(6018),
    [anon_sym_xor] = ACTIONS(6018),
    [anon_sym_bitand] = ACTIONS(6018),
    [anon_sym_not_eq] = ACTIONS(6018),
    [anon_sym_DASH_DASH] = ACTIONS(6016),
    [anon_sym_PLUS_PLUS] = ACTIONS(6016),
    [anon_sym_DOT] = ACTIONS(6018),
    [anon_sym_DOT_STAR] = ACTIONS(6016),
    [anon_sym_DASH_GT] = ACTIONS(6018),
    [anon_sym_L_DQUOTE] = ACTIONS(4314),
    [anon_sym_u_DQUOTE] = ACTIONS(4314),
    [anon_sym_U_DQUOTE] = ACTIONS(4314),
    [anon_sym_u8_DQUOTE] = ACTIONS(4314),
    [anon_sym_DQUOTE] = ACTIONS(4314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(4316),
    [anon_sym_LR_DQUOTE] = ACTIONS(4316),
    [anon_sym_uR_DQUOTE] = ACTIONS(4316),
    [anon_sym_UR_DQUOTE] = ACTIONS(4316),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4316),
    [anon_sym_DASH_GT_STAR] = ACTIONS(6016),
    [sym_literal_suffix] = ACTIONS(6018),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6016),
  },
  [STATE(2728)] = {
    [sym_identifier] = ACTIONS(6913),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6915),
    [anon_sym_COMMA] = ACTIONS(6915),
    [anon_sym_RPAREN] = ACTIONS(6915),
    [aux_sym_preproc_if_token2] = ACTIONS(6915),
    [aux_sym_preproc_else_token1] = ACTIONS(6915),
    [aux_sym_preproc_elif_token1] = ACTIONS(6913),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6915),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6915),
    [anon_sym_LPAREN2] = ACTIONS(6915),
    [anon_sym_DASH] = ACTIONS(6913),
    [anon_sym_PLUS] = ACTIONS(6913),
    [anon_sym_STAR] = ACTIONS(6913),
    [anon_sym_SLASH] = ACTIONS(6913),
    [anon_sym_PERCENT] = ACTIONS(6913),
    [anon_sym_PIPE_PIPE] = ACTIONS(6915),
    [anon_sym_AMP_AMP] = ACTIONS(6915),
    [anon_sym_PIPE] = ACTIONS(6913),
    [anon_sym_CARET] = ACTIONS(6913),
    [anon_sym_AMP] = ACTIONS(6913),
    [anon_sym_EQ_EQ] = ACTIONS(6915),
    [anon_sym_BANG_EQ] = ACTIONS(6915),
    [anon_sym_GT] = ACTIONS(6913),
    [anon_sym_GT_EQ] = ACTIONS(6915),
    [anon_sym_LT_EQ] = ACTIONS(6913),
    [anon_sym_LT] = ACTIONS(6913),
    [anon_sym_LT_LT] = ACTIONS(6913),
    [anon_sym_GT_GT] = ACTIONS(6913),
    [anon_sym_SEMI] = ACTIONS(6915),
    [anon_sym___attribute__] = ACTIONS(6913),
    [anon_sym___attribute] = ACTIONS(6913),
    [anon_sym_LBRACE] = ACTIONS(6915),
    [anon_sym_RBRACE] = ACTIONS(6915),
    [anon_sym_LBRACK] = ACTIONS(6915),
    [anon_sym_RBRACK] = ACTIONS(6915),
    [anon_sym_EQ] = ACTIONS(6913),
    [anon_sym_COLON] = ACTIONS(6915),
    [anon_sym_QMARK] = ACTIONS(6915),
    [anon_sym_STAR_EQ] = ACTIONS(6915),
    [anon_sym_SLASH_EQ] = ACTIONS(6915),
    [anon_sym_PERCENT_EQ] = ACTIONS(6915),
    [anon_sym_PLUS_EQ] = ACTIONS(6915),
    [anon_sym_DASH_EQ] = ACTIONS(6915),
    [anon_sym_LT_LT_EQ] = ACTIONS(6915),
    [anon_sym_GT_GT_EQ] = ACTIONS(6915),
    [anon_sym_AMP_EQ] = ACTIONS(6915),
    [anon_sym_CARET_EQ] = ACTIONS(6915),
    [anon_sym_PIPE_EQ] = ACTIONS(6915),
    [anon_sym_and_eq] = ACTIONS(6913),
    [anon_sym_or_eq] = ACTIONS(6913),
    [anon_sym_xor_eq] = ACTIONS(6913),
    [anon_sym_LT_EQ_GT] = ACTIONS(6915),
    [anon_sym_or] = ACTIONS(6913),
    [anon_sym_and] = ACTIONS(6913),
    [anon_sym_bitor] = ACTIONS(6913),
    [anon_sym_xor] = ACTIONS(6913),
    [anon_sym_bitand] = ACTIONS(6913),
    [anon_sym_not_eq] = ACTIONS(6913),
    [anon_sym_DASH_DASH] = ACTIONS(6915),
    [anon_sym_PLUS_PLUS] = ACTIONS(6915),
    [anon_sym_DOT] = ACTIONS(6913),
    [anon_sym_DOT_STAR] = ACTIONS(6915),
    [anon_sym_DASH_GT] = ACTIONS(6915),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6915),
  },
  [STATE(2729)] = {
    [sym_identifier] = ACTIONS(3826),
    [anon_sym_LPAREN2] = ACTIONS(3828),
    [anon_sym_TILDE] = ACTIONS(3828),
    [anon_sym_STAR] = ACTIONS(3828),
    [anon_sym_AMP_AMP] = ACTIONS(3828),
    [anon_sym_AMP] = ACTIONS(3826),
    [anon_sym___extension__] = ACTIONS(3826),
    [anon_sym___device__] = ACTIONS(3826),
    [anon_sym___host__] = ACTIONS(3826),
    [anon_sym___global__] = ACTIONS(3826),
    [anon_sym___forceinline__] = ACTIONS(3826),
    [anon_sym___noinline__] = ACTIONS(3826),
    [anon_sym_virtual] = ACTIONS(3826),
    [anon_sym_extern] = ACTIONS(3826),
    [anon_sym___attribute__] = ACTIONS(3826),
    [anon_sym___attribute] = ACTIONS(3826),
    [anon_sym_COLON_COLON] = ACTIONS(3828),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3828),
    [anon_sym___declspec] = ACTIONS(3826),
    [anon_sym___based] = ACTIONS(3826),
    [anon_sym_signed] = ACTIONS(3826),
    [anon_sym_unsigned] = ACTIONS(3826),
    [anon_sym_long] = ACTIONS(3826),
    [anon_sym_short] = ACTIONS(3826),
    [anon_sym_LBRACK] = ACTIONS(3826),
    [anon_sym_static] = ACTIONS(3826),
    [anon_sym_register] = ACTIONS(3826),
    [anon_sym_inline] = ACTIONS(3826),
    [anon_sym___inline] = ACTIONS(3826),
    [anon_sym___inline__] = ACTIONS(3826),
    [anon_sym___forceinline] = ACTIONS(3826),
    [anon_sym_thread_local] = ACTIONS(3826),
    [anon_sym___thread] = ACTIONS(3826),
    [anon_sym_const] = ACTIONS(3826),
    [anon_sym_constexpr] = ACTIONS(3826),
    [anon_sym_volatile] = ACTIONS(3826),
    [anon_sym_restrict] = ACTIONS(3826),
    [anon_sym___restrict__] = ACTIONS(3826),
    [anon_sym__Atomic] = ACTIONS(3826),
    [anon_sym__Noreturn] = ACTIONS(3826),
    [anon_sym_noreturn] = ACTIONS(3826),
    [anon_sym__Nonnull] = ACTIONS(3826),
    [anon_sym_mutable] = ACTIONS(3826),
    [anon_sym_constinit] = ACTIONS(3826),
    [anon_sym_consteval] = ACTIONS(3826),
    [anon_sym___shared__] = ACTIONS(3826),
    [anon_sym___local__] = ACTIONS(3826),
    [anon_sym___constant__] = ACTIONS(3826),
    [anon_sym___managed__] = ACTIONS(3826),
    [anon_sym___grid_constant__] = ACTIONS(3826),
    [anon_sym_alignas] = ACTIONS(3826),
    [anon_sym__Alignas] = ACTIONS(3826),
    [sym_primitive_type] = ACTIONS(3826),
    [anon_sym_enum] = ACTIONS(3826),
    [anon_sym_class] = ACTIONS(3826),
    [anon_sym_struct] = ACTIONS(3826),
    [anon_sym_union] = ACTIONS(3826),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3826),
    [anon_sym_decltype] = ACTIONS(3826),
    [anon_sym_explicit] = ACTIONS(3826),
    [anon_sym_typename] = ACTIONS(3826),
    [anon_sym_template] = ACTIONS(3826),
    [anon_sym_operator] = ACTIONS(3826),
    [anon_sym___launch_bounds__] = ACTIONS(3826),
  },
  [STATE(2730)] = {
    [sym__declaration_modifiers] = STATE(2730),
    [sym_attribute_specifier] = STATE(2730),
    [sym_attribute_declaration] = STATE(2730),
    [sym_ms_declspec_modifier] = STATE(2730),
    [sym_storage_class_specifier] = STATE(2730),
    [sym_type_qualifier] = STATE(2730),
    [sym_alignas_qualifier] = STATE(1719),
    [sym_launch_bounds] = STATE(2730),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2730),
    [sym_identifier] = ACTIONS(6119),
    [anon_sym___extension__] = ACTIONS(6917),
    [anon_sym___device__] = ACTIONS(6920),
    [anon_sym___host__] = ACTIONS(6920),
    [anon_sym___global__] = ACTIONS(6920),
    [anon_sym___forceinline__] = ACTIONS(6920),
    [anon_sym___noinline__] = ACTIONS(6920),
    [anon_sym_virtual] = ACTIONS(6920),
    [anon_sym_extern] = ACTIONS(6923),
    [anon_sym___attribute__] = ACTIONS(6926),
    [anon_sym___attribute] = ACTIONS(6926),
    [anon_sym_COLON_COLON] = ACTIONS(6121),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6929),
    [anon_sym___declspec] = ACTIONS(6932),
    [anon_sym_signed] = ACTIONS(6119),
    [anon_sym_unsigned] = ACTIONS(6119),
    [anon_sym_long] = ACTIONS(6119),
    [anon_sym_short] = ACTIONS(6119),
    [anon_sym_static] = ACTIONS(6923),
    [anon_sym_register] = ACTIONS(6923),
    [anon_sym_inline] = ACTIONS(6923),
    [anon_sym___inline] = ACTIONS(6923),
    [anon_sym___inline__] = ACTIONS(6923),
    [anon_sym___forceinline] = ACTIONS(6923),
    [anon_sym_thread_local] = ACTIONS(6923),
    [anon_sym___thread] = ACTIONS(6923),
    [anon_sym_const] = ACTIONS(6917),
    [anon_sym_constexpr] = ACTIONS(6917),
    [anon_sym_volatile] = ACTIONS(6917),
    [anon_sym_restrict] = ACTIONS(6917),
    [anon_sym___restrict__] = ACTIONS(6917),
    [anon_sym__Atomic] = ACTIONS(6917),
    [anon_sym__Noreturn] = ACTIONS(6917),
    [anon_sym_noreturn] = ACTIONS(6917),
    [anon_sym__Nonnull] = ACTIONS(6917),
    [anon_sym_mutable] = ACTIONS(6917),
    [anon_sym_constinit] = ACTIONS(6917),
    [anon_sym_consteval] = ACTIONS(6917),
    [anon_sym___shared__] = ACTIONS(6917),
    [anon_sym___local__] = ACTIONS(6917),
    [anon_sym___constant__] = ACTIONS(6917),
    [anon_sym___managed__] = ACTIONS(6917),
    [anon_sym___grid_constant__] = ACTIONS(6917),
    [anon_sym_alignas] = ACTIONS(6935),
    [anon_sym__Alignas] = ACTIONS(6935),
    [sym_primitive_type] = ACTIONS(6119),
    [anon_sym_enum] = ACTIONS(6119),
    [anon_sym_class] = ACTIONS(6119),
    [anon_sym_struct] = ACTIONS(6119),
    [anon_sym_union] = ACTIONS(6119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6119),
    [anon_sym_decltype] = ACTIONS(6119),
    [anon_sym_typename] = ACTIONS(6119),
    [anon_sym_template] = ACTIONS(6119),
    [anon_sym___launch_bounds__] = ACTIONS(6938),
  },
  [STATE(2731)] = {
    [sym_identifier] = ACTIONS(6356),
    [anon_sym_LPAREN2] = ACTIONS(6358),
    [anon_sym_TILDE] = ACTIONS(6358),
    [anon_sym_STAR] = ACTIONS(6358),
    [anon_sym_AMP_AMP] = ACTIONS(6358),
    [anon_sym_AMP] = ACTIONS(6356),
    [anon_sym___extension__] = ACTIONS(6356),
    [anon_sym___device__] = ACTIONS(6356),
    [anon_sym___host__] = ACTIONS(6356),
    [anon_sym___global__] = ACTIONS(6356),
    [anon_sym___forceinline__] = ACTIONS(6356),
    [anon_sym___noinline__] = ACTIONS(6356),
    [anon_sym_virtual] = ACTIONS(6356),
    [anon_sym_extern] = ACTIONS(6356),
    [anon_sym___attribute__] = ACTIONS(6356),
    [anon_sym___attribute] = ACTIONS(6356),
    [anon_sym_COLON_COLON] = ACTIONS(6358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6358),
    [anon_sym___declspec] = ACTIONS(6356),
    [anon_sym___based] = ACTIONS(6356),
    [anon_sym_signed] = ACTIONS(6356),
    [anon_sym_unsigned] = ACTIONS(6356),
    [anon_sym_long] = ACTIONS(6356),
    [anon_sym_short] = ACTIONS(6356),
    [anon_sym_LBRACK] = ACTIONS(6356),
    [anon_sym_static] = ACTIONS(6356),
    [anon_sym_register] = ACTIONS(6356),
    [anon_sym_inline] = ACTIONS(6356),
    [anon_sym___inline] = ACTIONS(6356),
    [anon_sym___inline__] = ACTIONS(6356),
    [anon_sym___forceinline] = ACTIONS(6356),
    [anon_sym_thread_local] = ACTIONS(6356),
    [anon_sym___thread] = ACTIONS(6356),
    [anon_sym_const] = ACTIONS(6356),
    [anon_sym_constexpr] = ACTIONS(6356),
    [anon_sym_volatile] = ACTIONS(6356),
    [anon_sym_restrict] = ACTIONS(6356),
    [anon_sym___restrict__] = ACTIONS(6356),
    [anon_sym__Atomic] = ACTIONS(6356),
    [anon_sym__Noreturn] = ACTIONS(6356),
    [anon_sym_noreturn] = ACTIONS(6356),
    [anon_sym__Nonnull] = ACTIONS(6356),
    [anon_sym_mutable] = ACTIONS(6356),
    [anon_sym_constinit] = ACTIONS(6356),
    [anon_sym_consteval] = ACTIONS(6356),
    [anon_sym___shared__] = ACTIONS(6356),
    [anon_sym___local__] = ACTIONS(6356),
    [anon_sym___constant__] = ACTIONS(6356),
    [anon_sym___managed__] = ACTIONS(6356),
    [anon_sym___grid_constant__] = ACTIONS(6356),
    [anon_sym_alignas] = ACTIONS(6356),
    [anon_sym__Alignas] = ACTIONS(6356),
    [sym_primitive_type] = ACTIONS(6356),
    [anon_sym_enum] = ACTIONS(6356),
    [anon_sym_class] = ACTIONS(6356),
    [anon_sym_struct] = ACTIONS(6356),
    [anon_sym_union] = ACTIONS(6356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(6356),
    [anon_sym_decltype] = ACTIONS(6356),
    [anon_sym_explicit] = ACTIONS(6356),
    [anon_sym_typename] = ACTIONS(6356),
    [anon_sym_template] = ACTIONS(6356),
    [anon_sym_operator] = ACTIONS(6356),
    [anon_sym___launch_bounds__] = ACTIONS(6356),
  },
  [STATE(2732)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6161),
    [anon_sym_COMMA] = ACTIONS(6161),
    [anon_sym_LPAREN2] = ACTIONS(6161),
    [anon_sym_DASH] = ACTIONS(6159),
    [anon_sym_PLUS] = ACTIONS(6159),
    [anon_sym_STAR] = ACTIONS(6159),
    [anon_sym_SLASH] = ACTIONS(6159),
    [anon_sym_PERCENT] = ACTIONS(6159),
    [anon_sym_PIPE_PIPE] = ACTIONS(6161),
    [anon_sym_AMP_AMP] = ACTIONS(6161),
    [anon_sym_PIPE] = ACTIONS(6159),
    [anon_sym_CARET] = ACTIONS(6159),
    [anon_sym_AMP] = ACTIONS(6159),
    [anon_sym_EQ_EQ] = ACTIONS(6161),
    [anon_sym_BANG_EQ] = ACTIONS(6161),
    [anon_sym_GT] = ACTIONS(6159),
    [anon_sym_GT_EQ] = ACTIONS(6161),
    [anon_sym_LT_EQ] = ACTIONS(6159),
    [anon_sym_LT] = ACTIONS(6159),
    [anon_sym_LT_LT] = ACTIONS(6159),
    [anon_sym_GT_GT] = ACTIONS(6159),
    [anon_sym_SEMI] = ACTIONS(6161),
    [anon_sym___attribute__] = ACTIONS(6159),
    [anon_sym___attribute] = ACTIONS(6159),
    [anon_sym_LBRACK] = ACTIONS(6161),
    [anon_sym_EQ] = ACTIONS(6159),
    [anon_sym_QMARK] = ACTIONS(6161),
    [anon_sym_STAR_EQ] = ACTIONS(6161),
    [anon_sym_SLASH_EQ] = ACTIONS(6161),
    [anon_sym_PERCENT_EQ] = ACTIONS(6161),
    [anon_sym_PLUS_EQ] = ACTIONS(6161),
    [anon_sym_DASH_EQ] = ACTIONS(6161),
    [anon_sym_LT_LT_EQ] = ACTIONS(6161),
    [anon_sym_GT_GT_EQ] = ACTIONS(6161),
    [anon_sym_AMP_EQ] = ACTIONS(6161),
    [anon_sym_CARET_EQ] = ACTIONS(6161),
    [anon_sym_PIPE_EQ] = ACTIONS(6161),
    [anon_sym_and_eq] = ACTIONS(6159),
    [anon_sym_or_eq] = ACTIONS(6159),
    [anon_sym_xor_eq] = ACTIONS(6159),
    [anon_sym_LT_EQ_GT] = ACTIONS(6161),
    [anon_sym_or] = ACTIONS(6159),
    [anon_sym_and] = ACTIONS(6159),
    [anon_sym_bitor] = ACTIONS(6159),
    [anon_sym_xor] = ACTIONS(6159),
    [anon_sym_bitand] = ACTIONS(6159),
    [anon_sym_not_eq] = ACTIONS(6159),
    [anon_sym_DASH_DASH] = ACTIONS(6161),
    [anon_sym_PLUS_PLUS] = ACTIONS(6161),
    [anon_sym_DOT] = ACTIONS(6159),
    [anon_sym_DOT_STAR] = ACTIONS(6161),
    [anon_sym_DASH_GT] = ACTIONS(6161),
    [anon_sym_L_DQUOTE] = ACTIONS(6161),
    [anon_sym_u_DQUOTE] = ACTIONS(6161),
    [anon_sym_U_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8_DQUOTE] = ACTIONS(6161),
    [anon_sym_DQUOTE] = ACTIONS(6161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6161),
    [anon_sym_LR_DQUOTE] = ACTIONS(6161),
    [anon_sym_uR_DQUOTE] = ACTIONS(6161),
    [anon_sym_UR_DQUOTE] = ACTIONS(6161),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6161),
    [sym_literal_suffix] = ACTIONS(6159),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6161),
  },
  [STATE(2733)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6169),
    [anon_sym_COMMA] = ACTIONS(6169),
    [anon_sym_LPAREN2] = ACTIONS(6169),
    [anon_sym_DASH] = ACTIONS(6167),
    [anon_sym_PLUS] = ACTIONS(6167),
    [anon_sym_STAR] = ACTIONS(6167),
    [anon_sym_SLASH] = ACTIONS(6167),
    [anon_sym_PERCENT] = ACTIONS(6167),
    [anon_sym_PIPE_PIPE] = ACTIONS(6169),
    [anon_sym_AMP_AMP] = ACTIONS(6169),
    [anon_sym_PIPE] = ACTIONS(6167),
    [anon_sym_CARET] = ACTIONS(6167),
    [anon_sym_AMP] = ACTIONS(6167),
    [anon_sym_EQ_EQ] = ACTIONS(6169),
    [anon_sym_BANG_EQ] = ACTIONS(6169),
    [anon_sym_GT] = ACTIONS(6167),
    [anon_sym_GT_EQ] = ACTIONS(6169),
    [anon_sym_LT_EQ] = ACTIONS(6167),
    [anon_sym_LT] = ACTIONS(6167),
    [anon_sym_LT_LT] = ACTIONS(6167),
    [anon_sym_GT_GT] = ACTIONS(6167),
    [anon_sym_SEMI] = ACTIONS(6169),
    [anon_sym___attribute__] = ACTIONS(6167),
    [anon_sym___attribute] = ACTIONS(6167),
    [anon_sym_LBRACK] = ACTIONS(6169),
    [anon_sym_EQ] = ACTIONS(6167),
    [anon_sym_QMARK] = ACTIONS(6169),
    [anon_sym_STAR_EQ] = ACTIONS(6169),
    [anon_sym_SLASH_EQ] = ACTIONS(6169),
    [anon_sym_PERCENT_EQ] = ACTIONS(6169),
    [anon_sym_PLUS_EQ] = ACTIONS(6169),
    [anon_sym_DASH_EQ] = ACTIONS(6169),
    [anon_sym_LT_LT_EQ] = ACTIONS(6169),
    [anon_sym_GT_GT_EQ] = ACTIONS(6169),
    [anon_sym_AMP_EQ] = ACTIONS(6169),
    [anon_sym_CARET_EQ] = ACTIONS(6169),
    [anon_sym_PIPE_EQ] = ACTIONS(6169),
    [anon_sym_and_eq] = ACTIONS(6167),
    [anon_sym_or_eq] = ACTIONS(6167),
    [anon_sym_xor_eq] = ACTIONS(6167),
    [anon_sym_LT_EQ_GT] = ACTIONS(6169),
    [anon_sym_or] = ACTIONS(6167),
    [anon_sym_and] = ACTIONS(6167),
    [anon_sym_bitor] = ACTIONS(6167),
    [anon_sym_xor] = ACTIONS(6167),
    [anon_sym_bitand] = ACTIONS(6167),
    [anon_sym_not_eq] = ACTIONS(6167),
    [anon_sym_DASH_DASH] = ACTIONS(6169),
    [anon_sym_PLUS_PLUS] = ACTIONS(6169),
    [anon_sym_DOT] = ACTIONS(6167),
    [anon_sym_DOT_STAR] = ACTIONS(6169),
    [anon_sym_DASH_GT] = ACTIONS(6169),
    [anon_sym_L_DQUOTE] = ACTIONS(6169),
    [anon_sym_u_DQUOTE] = ACTIONS(6169),
    [anon_sym_U_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8_DQUOTE] = ACTIONS(6169),
    [anon_sym_DQUOTE] = ACTIONS(6169),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6169),
    [anon_sym_LR_DQUOTE] = ACTIONS(6169),
    [anon_sym_uR_DQUOTE] = ACTIONS(6169),
    [anon_sym_UR_DQUOTE] = ACTIONS(6169),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6169),
    [sym_literal_suffix] = ACTIONS(6167),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6169),
  },
  [STATE(2734)] = {
    [sym_identifier] = ACTIONS(3826),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3828),
    [anon_sym_COMMA] = ACTIONS(3828),
    [anon_sym_RPAREN] = ACTIONS(3828),
    [aux_sym_preproc_if_token2] = ACTIONS(3828),
    [aux_sym_preproc_else_token1] = ACTIONS(3828),
    [aux_sym_preproc_elif_token1] = ACTIONS(3826),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(3828),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(3828),
    [anon_sym_LPAREN2] = ACTIONS(3828),
    [anon_sym_DASH] = ACTIONS(3826),
    [anon_sym_PLUS] = ACTIONS(3826),
    [anon_sym_STAR] = ACTIONS(3826),
    [anon_sym_SLASH] = ACTIONS(3826),
    [anon_sym_PERCENT] = ACTIONS(3826),
    [anon_sym_PIPE_PIPE] = ACTIONS(3828),
    [anon_sym_AMP_AMP] = ACTIONS(3828),
    [anon_sym_PIPE] = ACTIONS(3826),
    [anon_sym_CARET] = ACTIONS(3826),
    [anon_sym_AMP] = ACTIONS(3826),
    [anon_sym_EQ_EQ] = ACTIONS(3828),
    [anon_sym_BANG_EQ] = ACTIONS(3828),
    [anon_sym_GT] = ACTIONS(3826),
    [anon_sym_GT_EQ] = ACTIONS(3828),
    [anon_sym_LT_EQ] = ACTIONS(3826),
    [anon_sym_LT] = ACTIONS(3826),
    [anon_sym_LT_LT] = ACTIONS(3826),
    [anon_sym_GT_GT] = ACTIONS(3826),
    [anon_sym_SEMI] = ACTIONS(3828),
    [anon_sym___attribute__] = ACTIONS(3826),
    [anon_sym___attribute] = ACTIONS(3826),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3828),
    [anon_sym_RBRACE] = ACTIONS(3828),
    [anon_sym_LBRACK] = ACTIONS(3826),
    [anon_sym_RBRACK] = ACTIONS(3828),
    [anon_sym_EQ] = ACTIONS(3826),
    [anon_sym_COLON] = ACTIONS(3828),
    [anon_sym_QMARK] = ACTIONS(3828),
    [anon_sym_STAR_EQ] = ACTIONS(3828),
    [anon_sym_SLASH_EQ] = ACTIONS(3828),
    [anon_sym_PERCENT_EQ] = ACTIONS(3828),
    [anon_sym_PLUS_EQ] = ACTIONS(3828),
    [anon_sym_DASH_EQ] = ACTIONS(3828),
    [anon_sym_LT_LT_EQ] = ACTIONS(3828),
    [anon_sym_GT_GT_EQ] = ACTIONS(3828),
    [anon_sym_AMP_EQ] = ACTIONS(3828),
    [anon_sym_CARET_EQ] = ACTIONS(3828),
    [anon_sym_PIPE_EQ] = ACTIONS(3828),
    [anon_sym_and_eq] = ACTIONS(3826),
    [anon_sym_or_eq] = ACTIONS(3826),
    [anon_sym_xor_eq] = ACTIONS(3826),
    [anon_sym_LT_EQ_GT] = ACTIONS(3828),
    [anon_sym_or] = ACTIONS(3826),
    [anon_sym_and] = ACTIONS(3826),
    [anon_sym_bitor] = ACTIONS(3826),
    [anon_sym_xor] = ACTIONS(3826),
    [anon_sym_bitand] = ACTIONS(3826),
    [anon_sym_not_eq] = ACTIONS(3826),
    [anon_sym_DASH_DASH] = ACTIONS(3828),
    [anon_sym_PLUS_PLUS] = ACTIONS(3828),
    [anon_sym_DOT] = ACTIONS(3826),
    [anon_sym_DOT_STAR] = ACTIONS(3828),
    [anon_sym_DASH_GT] = ACTIONS(3828),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(3828),
  },
  [STATE(2735)] = {
    [sym_identifier] = ACTIONS(6941),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6943),
    [anon_sym_COMMA] = ACTIONS(6943),
    [anon_sym_RPAREN] = ACTIONS(6943),
    [aux_sym_preproc_if_token2] = ACTIONS(6943),
    [aux_sym_preproc_else_token1] = ACTIONS(6943),
    [aux_sym_preproc_elif_token1] = ACTIONS(6941),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6943),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6943),
    [anon_sym_LPAREN2] = ACTIONS(6943),
    [anon_sym_DASH] = ACTIONS(6941),
    [anon_sym_PLUS] = ACTIONS(6941),
    [anon_sym_STAR] = ACTIONS(6941),
    [anon_sym_SLASH] = ACTIONS(6941),
    [anon_sym_PERCENT] = ACTIONS(6941),
    [anon_sym_PIPE_PIPE] = ACTIONS(6943),
    [anon_sym_AMP_AMP] = ACTIONS(6943),
    [anon_sym_PIPE] = ACTIONS(6941),
    [anon_sym_CARET] = ACTIONS(6941),
    [anon_sym_AMP] = ACTIONS(6941),
    [anon_sym_EQ_EQ] = ACTIONS(6943),
    [anon_sym_BANG_EQ] = ACTIONS(6943),
    [anon_sym_GT] = ACTIONS(6941),
    [anon_sym_GT_EQ] = ACTIONS(6943),
    [anon_sym_LT_EQ] = ACTIONS(6941),
    [anon_sym_LT] = ACTIONS(6941),
    [anon_sym_LT_LT] = ACTIONS(6941),
    [anon_sym_GT_GT] = ACTIONS(6941),
    [anon_sym_SEMI] = ACTIONS(6943),
    [anon_sym___attribute__] = ACTIONS(6941),
    [anon_sym___attribute] = ACTIONS(6941),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6943),
    [anon_sym_RBRACE] = ACTIONS(6943),
    [anon_sym_LBRACK] = ACTIONS(6941),
    [anon_sym_RBRACK] = ACTIONS(6943),
    [anon_sym_EQ] = ACTIONS(6941),
    [anon_sym_COLON] = ACTIONS(6943),
    [anon_sym_QMARK] = ACTIONS(6943),
    [anon_sym_STAR_EQ] = ACTIONS(6943),
    [anon_sym_SLASH_EQ] = ACTIONS(6943),
    [anon_sym_PERCENT_EQ] = ACTIONS(6943),
    [anon_sym_PLUS_EQ] = ACTIONS(6943),
    [anon_sym_DASH_EQ] = ACTIONS(6943),
    [anon_sym_LT_LT_EQ] = ACTIONS(6943),
    [anon_sym_GT_GT_EQ] = ACTIONS(6943),
    [anon_sym_AMP_EQ] = ACTIONS(6943),
    [anon_sym_CARET_EQ] = ACTIONS(6943),
    [anon_sym_PIPE_EQ] = ACTIONS(6943),
    [anon_sym_and_eq] = ACTIONS(6941),
    [anon_sym_or_eq] = ACTIONS(6941),
    [anon_sym_xor_eq] = ACTIONS(6941),
    [anon_sym_LT_EQ_GT] = ACTIONS(6943),
    [anon_sym_or] = ACTIONS(6941),
    [anon_sym_and] = ACTIONS(6941),
    [anon_sym_bitor] = ACTIONS(6941),
    [anon_sym_xor] = ACTIONS(6941),
    [anon_sym_bitand] = ACTIONS(6941),
    [anon_sym_not_eq] = ACTIONS(6941),
    [anon_sym_DASH_DASH] = ACTIONS(6943),
    [anon_sym_PLUS_PLUS] = ACTIONS(6943),
    [anon_sym_DOT] = ACTIONS(6941),
    [anon_sym_DOT_STAR] = ACTIONS(6943),
    [anon_sym_DASH_GT] = ACTIONS(6943),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6943),
  },
  [STATE(2736)] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6194),
    [anon_sym_COMMA] = ACTIONS(6194),
    [anon_sym_LPAREN2] = ACTIONS(6194),
    [anon_sym_DASH] = ACTIONS(6192),
    [anon_sym_PLUS] = ACTIONS(6192),
    [anon_sym_STAR] = ACTIONS(6192),
    [anon_sym_SLASH] = ACTIONS(6192),
    [anon_sym_PERCENT] = ACTIONS(6192),
    [anon_sym_PIPE_PIPE] = ACTIONS(6194),
    [anon_sym_AMP_AMP] = ACTIONS(6194),
    [anon_sym_PIPE] = ACTIONS(6192),
    [anon_sym_CARET] = ACTIONS(6192),
    [anon_sym_AMP] = ACTIONS(6192),
    [anon_sym_EQ_EQ] = ACTIONS(6194),
    [anon_sym_BANG_EQ] = ACTIONS(6194),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_GT_EQ] = ACTIONS(6194),
    [anon_sym_LT_EQ] = ACTIONS(6192),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_LT_LT] = ACTIONS(6192),
    [anon_sym_GT_GT] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [anon_sym___attribute__] = ACTIONS(6192),
    [anon_sym___attribute] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [anon_sym_EQ] = ACTIONS(6192),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_STAR_EQ] = ACTIONS(6194),
    [anon_sym_SLASH_EQ] = ACTIONS(6194),
    [anon_sym_PERCENT_EQ] = ACTIONS(6194),
    [anon_sym_PLUS_EQ] = ACTIONS(6194),
    [anon_sym_DASH_EQ] = ACTIONS(6194),
    [anon_sym_LT_LT_EQ] = ACTIONS(6194),
    [anon_sym_GT_GT_EQ] = ACTIONS(6194),
    [anon_sym_AMP_EQ] = ACTIONS(6194),
    [anon_sym_CARET_EQ] = ACTIONS(6194),
    [anon_sym_PIPE_EQ] = ACTIONS(6194),
    [anon_sym_and_eq] = ACTIONS(6192),
    [anon_sym_or_eq] = ACTIONS(6192),
    [anon_sym_xor_eq] = ACTIONS(6192),
    [anon_sym_LT_EQ_GT] = ACTIONS(6194),
    [anon_sym_or] = ACTIONS(6192),
    [anon_sym_and] = ACTIONS(6192),
    [anon_sym_bitor] = ACTIONS(6192),
    [anon_sym_xor] = ACTIONS(6192),
    [anon_sym_bitand] = ACTIONS(6192),
    [anon_sym_not_eq] = ACTIONS(6192),
    [anon_sym_DASH_DASH] = ACTIONS(6194),
    [anon_sym_PLUS_PLUS] = ACTIONS(6194),
    [anon_sym_DOT] = ACTIONS(6192),
    [anon_sym_DOT_STAR] = ACTIONS(6194),
    [anon_sym_DASH_GT] = ACTIONS(6194),
    [anon_sym_L_DQUOTE] = ACTIONS(6194),
    [anon_sym_u_DQUOTE] = ACTIONS(6194),
    [anon_sym_U_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8_DQUOTE] = ACTIONS(6194),
    [anon_sym_DQUOTE] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(6194),
    [anon_sym_LR_DQUOTE] = ACTIONS(6194),
    [anon_sym_uR_DQUOTE] = ACTIONS(6194),
    [anon_sym_UR_DQUOTE] = ACTIONS(6194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6194),
    [sym_literal_suffix] = ACTIONS(6192),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6194),
  },
  [STATE(2737)] = {
    [sym_identifier] = ACTIONS(6886),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6888),
    [anon_sym_COMMA] = ACTIONS(6888),
    [anon_sym_RPAREN] = ACTIONS(6888),
    [aux_sym_preproc_if_token2] = ACTIONS(6888),
    [aux_sym_preproc_else_token1] = ACTIONS(6888),
    [aux_sym_preproc_elif_token1] = ACTIONS(6886),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6888),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6888),
    [anon_sym_LPAREN2] = ACTIONS(6888),
    [anon_sym_DASH] = ACTIONS(6886),
    [anon_sym_PLUS] = ACTIONS(6886),
    [anon_sym_STAR] = ACTIONS(6886),
    [anon_sym_SLASH] = ACTIONS(6886),
    [anon_sym_PERCENT] = ACTIONS(6886),
    [anon_sym_PIPE_PIPE] = ACTIONS(6888),
    [anon_sym_AMP_AMP] = ACTIONS(6888),
    [anon_sym_PIPE] = ACTIONS(6886),
    [anon_sym_CARET] = ACTIONS(6886),
    [anon_sym_AMP] = ACTIONS(6886),
    [anon_sym_EQ_EQ] = ACTIONS(6888),
    [anon_sym_BANG_EQ] = ACTIONS(6888),
    [anon_sym_GT] = ACTIONS(6886),
    [anon_sym_GT_EQ] = ACTIONS(6888),
    [anon_sym_LT_EQ] = ACTIONS(6886),
    [anon_sym_LT] = ACTIONS(6886),
    [anon_sym_LT_LT] = ACTIONS(6886),
    [anon_sym_GT_GT] = ACTIONS(6886),
    [anon_sym_SEMI] = ACTIONS(6888),
    [anon_sym___attribute__] = ACTIONS(6886),
    [anon_sym___attribute] = ACTIONS(6886),
    [anon_sym_LBRACE] = ACTIONS(6888),
    [anon_sym_RBRACE] = ACTIONS(6888),
    [anon_sym_LBRACK] = ACTIONS(6888),
    [anon_sym_RBRACK] = ACTIONS(6888),
    [anon_sym_EQ] = ACTIONS(6886),
    [anon_sym_COLON] = ACTIONS(6888),
    [anon_sym_QMARK] = ACTIONS(6888),
    [anon_sym_STAR_EQ] = ACTIONS(6888),
    [anon_sym_SLASH_EQ] = ACTIONS(6888),
    [anon_sym_PERCENT_EQ] = ACTIONS(6888),
    [anon_sym_PLUS_EQ] = ACTIONS(6888),
    [anon_sym_DASH_EQ] = ACTIONS(6888),
    [anon_sym_LT_LT_EQ] = ACTIONS(6888),
    [anon_sym_GT_GT_EQ] = ACTIONS(6888),
    [anon_sym_AMP_EQ] = ACTIONS(6888),
    [anon_sym_CARET_EQ] = ACTIONS(6888),
    [anon_sym_PIPE_EQ] = ACTIONS(6888),
    [anon_sym_and_eq] = ACTIONS(6886),
    [anon_sym_or_eq] = ACTIONS(6886),
    [anon_sym_xor_eq] = ACTIONS(6886),
    [anon_sym_LT_EQ_GT] = ACTIONS(6888),
    [anon_sym_or] = ACTIONS(6886),
    [anon_sym_and] = ACTIONS(6886),
    [anon_sym_bitor] = ACTIONS(6886),
    [anon_sym_xor] = ACTIONS(6886),
    [anon_sym_bitand] = ACTIONS(6886),
    [anon_sym_not_eq] = ACTIONS(6886),
    [anon_sym_DASH_DASH] = ACTIONS(6888),
    [anon_sym_PLUS_PLUS] = ACTIONS(6888),
    [anon_sym_DOT] = ACTIONS(6886),
    [anon_sym_DOT_STAR] = ACTIONS(6888),
    [anon_sym_DASH_GT] = ACTIONS(6888),
    [sym_comment] = ACTIONS(3),
    [aux_sym_kernel_call_syntax_token1] = ACTIONS(6888),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6947), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [71] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4004), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [142] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(2897), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6949), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6074), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [221] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6951), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6953), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6955), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6957), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [363] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6959), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6961), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [434] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    STATE(3151), 1,
      sym_field_declaration_list,
    STATE(3542), 1,
      sym_attribute_specifier,
    STATE(7568), 1,
      sym_virtual_specifier,
    STATE(8508), 1,
      sym_base_class_clause,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6038), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6036), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6969), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6971), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [594] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(2947), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6973), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6074), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [673] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    ACTIONS(4512), 7,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4519), 53,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6977), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6194), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6385), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6383), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [963] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6979), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6981), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1034] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5331), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1105] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6983), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6985), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6987), 1,
      anon_sym_or,
    ACTIONS(6989), 1,
      anon_sym_and,
    ACTIONS(5871), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5873), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1184] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6782), 1,
      anon_sym_LT,
    ACTIONS(6825), 1,
      anon_sym_EQ,
    STATE(2360), 1,
      sym_template_argument_list,
    ACTIONS(6823), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(4028), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
    ACTIONS(5669), 50,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [1265] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6196), 1,
      anon_sym___attribute,
    ACTIONS(6399), 1,
      anon_sym_LBRACE,
    ACTIONS(6991), 1,
      anon_sym___attribute__,
    ACTIONS(6993), 1,
      anon_sym_COLON,
    STATE(2388), 1,
      sym__enum_base_clause,
    STATE(2428), 1,
      sym_enumerator_list,
    STATE(2479), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6679), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
  [1350] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6995), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6997), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3994), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7001), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7003), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7005), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5305), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7009), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4514), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1847] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4514), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1918] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4514), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [1989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4514), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4514), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4514), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5289), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5289), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5289), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2415] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(1930), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7011), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7013), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(2060), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6165), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [2699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7017), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2770] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7019), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7021), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7023), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7025), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7027), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7029), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [2983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7031), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7033), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3054] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5297), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5301), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6169), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [3267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7037), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7039), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7041), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3409] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7045), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3480] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7047), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7049), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7053), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5309), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5285), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3764] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    ACTIONS(5669), 7,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4028), 53,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [3841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5327), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7055), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7057), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [3983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6817), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6819), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4054] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7019), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7021), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7059), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7061), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7063), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7065), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7069), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7071), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7073), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4409] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7077), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4480] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7079), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7081), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(1926), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7085), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4693] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    STATE(3168), 1,
      sym_field_declaration_list,
    STATE(3644), 1,
      sym_attribute_specifier,
    STATE(7668), 1,
      sym_virtual_specifier,
    STATE(8334), 1,
      sym_base_class_clause,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6038), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6036), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [4782] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7093), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7095), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4853] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7097), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7099), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5313), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [4995] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7101), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7103), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [5066] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6196), 1,
      anon_sym___attribute,
    ACTIONS(6399), 1,
      anon_sym_LBRACE,
    ACTIONS(6991), 1,
      anon_sym___attribute__,
    ACTIONS(6993), 1,
      anon_sym_COLON,
    STATE(2407), 1,
      sym__enum_base_clause,
    STATE(2439), 1,
      sym_enumerator_list,
    STATE(2504), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6673), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
  [5151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7107), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [5222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5293), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [5293] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7109), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7111), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [5364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7113), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7115), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [5435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6161), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [5506] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7117), 1,
      anon_sym_COLON,
    STATE(2241), 1,
      sym_attribute_specifier,
    STATE(2369), 1,
      sym__enum_base_clause,
    STATE(2563), 1,
      sym_enumerator_list,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6673), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(6671), 45,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [5589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6169), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [5660] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7117), 1,
      anon_sym_COLON,
    STATE(2246), 1,
      sym_attribute_specifier,
    STATE(2416), 1,
      sym__enum_base_clause,
    STATE(2553), 1,
      sym_enumerator_list,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6679), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(6677), 45,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [5743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4004), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [5814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6161), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [5885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7119), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7121), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [5956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7125), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [6027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6169), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [6098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6194), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [6169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6165), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [6240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6194), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [6311] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6161), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [6382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6165), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [6453] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7129), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [6524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7131), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7133), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [6595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7135), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7137), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [6666] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7139), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7141), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [6737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7143), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7145), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [6808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5339), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [6879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4004), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [6950] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5335), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [7021] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6985), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6989), 1,
      anon_sym_and,
    ACTIONS(5860), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5862), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [7096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5317), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [7167] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7147), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7149), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [7238] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1734), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7151), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6012), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6010), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [7312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6169), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [7382] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1734), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7151), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5982), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5980), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [7456] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(4199), 1,
      anon_sym_STAR,
    ACTIONS(4201), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4203), 1,
      anon_sym_AMP,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6512), 1,
      anon_sym_RPAREN,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7111), 1,
      sym__declarator,
    STATE(7313), 1,
      sym__abstract_declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [7574] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6165), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [7644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6194), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [7714] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7153), 1,
      anon_sym_LT,
    STATE(2929), 1,
      sym_template_argument_list,
    ACTIONS(4512), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4519), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [7790] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2712), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(4314), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(4316), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6352), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6354), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [7866] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2871), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7156), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5968), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5966), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [7940] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7158), 1,
      anon_sym_LT,
    STATE(2860), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2929), 1,
      sym_template_argument_list,
    ACTIONS(6894), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4010), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [8020] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(2654), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6401), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 6,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
    ACTIONS(4010), 48,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [8100] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7158), 1,
      anon_sym_LT,
    STATE(2929), 1,
      sym_template_argument_list,
    ACTIONS(5669), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4028), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [8176] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6165), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [8246] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1734), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7151), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5900), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5898), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [8320] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7168), 1,
      anon_sym___attribute__,
    ACTIONS(7171), 1,
      anon_sym___attribute,
    ACTIONS(7174), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5524), 1,
      sym__function_attributes_start,
    STATE(5581), 1,
      sym_ref_qualifier,
    STATE(6147), 1,
      sym_trailing_return_type,
    STATE(6297), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5874), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [8444] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2864), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7195), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5996), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5994), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [8518] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6161), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [8588] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1734), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7151), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6008), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6006), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [8662] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2228), 1,
      sym_attribute_specifier,
    STATE(2913), 1,
      sym_enumerator_list,
    ACTIONS(6185), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6183), 51,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [8742] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2251), 1,
      sym_attribute_specifier,
    STATE(2917), 1,
      sym_enumerator_list,
    ACTIONS(6179), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6177), 51,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [8822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6161), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [8892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6194), 3,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
    ACTIONS(6192), 59,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [8962] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1734), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7151), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5986), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5984), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [9036] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2851), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7197), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5770), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5772), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [9110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6169), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [9180] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6194), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [9250] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1734), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7151), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5964), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5962), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [9324] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7168), 1,
      anon_sym___attribute__,
    ACTIONS(7171), 1,
      anon_sym___attribute,
    ACTIONS(7174), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7202), 1,
      anon_sym_requires,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5438), 1,
      sym__function_attributes_start,
    STATE(5579), 1,
      sym_ref_qualifier,
    STATE(6131), 1,
      sym_trailing_return_type,
    STATE(6307), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7199), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5842), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [9448] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4553), 1,
      anon_sym_const,
    ACTIONS(4564), 1,
      anon_sym_AMP,
    ACTIONS(4557), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK,
      anon_sym_GT2,
    ACTIONS(4562), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4555), 18,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(4560), 24,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
  [9526] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2840), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7205), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5990), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5988), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [9600] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2838), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7207), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5919), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5917), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [9674] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4523), 1,
      anon_sym_LBRACK,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(2970), 1,
      sym_template_argument_list,
    ACTIONS(4516), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4519), 4,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
    ACTIONS(4512), 52,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [9754] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(4199), 1,
      anon_sym_STAR,
    ACTIONS(4201), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4203), 1,
      anon_sym_AMP,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(5925), 1,
      anon_sym_RPAREN,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7064), 1,
      sym__declarator,
    STATE(7362), 1,
      sym__abstract_declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [9872] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1734), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7151), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6026), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6024), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [9946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6165), 3,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
    ACTIONS(6163), 59,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [10016] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7202), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7216), 1,
      anon_sym___asm,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5553), 1,
      sym__function_attributes_start,
    STATE(5588), 1,
      sym_ref_qualifier,
    STATE(6131), 1,
      sym_trailing_return_type,
    STATE(6327), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7199), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7213), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5885), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [10139] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5661), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [10210] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6786), 1,
      sym__declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2877), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3743), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [10325] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7267), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2891), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3750), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [10440] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6734), 1,
      sym__declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3693), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [10555] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    ACTIONS(7239), 1,
      anon_sym_LBRACE,
    ACTIONS(7241), 1,
      anon_sym_COLON,
    STATE(3035), 1,
      sym__enum_base_clause,
    STATE(3136), 1,
      sym_enumerator_list,
    STATE(3310), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6673), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [10638] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7243), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5900), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5898), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [10711] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7245), 1,
      anon_sym_LT,
    STATE(2897), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2982), 1,
      sym_template_argument_list,
    ACTIONS(6949), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4010), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [10790] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7247), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5900), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5898), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [10863] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7245), 1,
      anon_sym_LT,
    STATE(2982), 1,
      sym_template_argument_list,
    ACTIONS(5669), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4028), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [10938] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6169), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [11007] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7205), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3703), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [11122] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7255), 1,
      sym_identifier,
    STATE(2885), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(7258), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(7261), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5884), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5882), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [11199] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7243), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6026), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6024), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [11272] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7188), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3706), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [11387] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7264), 1,
      anon_sym_LT,
    STATE(2947), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2989), 1,
      sym_template_argument_list,
    ACTIONS(6973), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4010), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [11466] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6727), 1,
      sym__declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3697), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [11581] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7243), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5964), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5962), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [11654] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7271), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3710), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [11769] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5661), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [11840] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7247), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5964), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5962), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [11913] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7266), 1,
      anon_sym_STAR,
    ACTIONS(7268), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6947), 1,
      sym__declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3699), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [12028] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7271), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2940), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3710), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [12143] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6733), 1,
      sym__declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2902), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3777), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [12258] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7247), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5986), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5984), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [12331] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7064), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2938), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3682), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [12446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5665), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5667), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [12515] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7266), 1,
      anon_sym_STAR,
    ACTIONS(7268), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6926), 1,
      sym__declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2894), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3752), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [12630] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2240), 1,
      sym_attribute_specifier,
    ACTIONS(6240), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6238), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [12705] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6702), 1,
      sym__declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3772), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [12820] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2272), 1,
      sym_attribute_specifier,
    ACTIONS(6244), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6242), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [12895] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5688), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5690), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [12966] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2263), 1,
      sym_attribute_specifier,
    ACTIONS(6236), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6234), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [13041] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7064), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2958), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3757), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [13156] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2227), 1,
      sym_attribute_specifier,
    ACTIONS(6254), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6252), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [13231] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(3023), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7288), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6074), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [13308] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2231), 1,
      sym_attribute_specifier,
    ACTIONS(6212), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6210), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [13383] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2232), 1,
      sym_attribute_specifier,
    ACTIONS(6228), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6226), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [13458] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2250), 1,
      sym_attribute_specifier,
    ACTIONS(6218), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6216), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [13533] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7042), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2928), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3737), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [13648] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2252), 1,
      sym_attribute_specifier,
    ACTIONS(6279), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6277), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [13723] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2257), 1,
      sym_attribute_specifier,
    ACTIONS(6250), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6248), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [13798] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2258), 1,
      sym_attribute_specifier,
    ACTIONS(6264), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6262), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [13873] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2946), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7290), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5990), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5988), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [13946] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2268), 1,
      sym_attribute_specifier,
    ACTIONS(6260), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6258), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [14021] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(2248), 1,
      sym_attribute_specifier,
    ACTIONS(6268), 6,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6266), 52,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_LBRACE,
      anon_sym_static,
      anon_sym_EQ,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [14096] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7292), 1,
      sym_identifier,
    STATE(2885), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3788), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3792), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6018), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6016), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [14173] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5556), 1,
      sym__function_attributes_start,
    STATE(5587), 1,
      sym_ref_qualifier,
    STATE(6147), 1,
      sym_trailing_return_type,
    STATE(6534), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5900), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [14296] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7266), 1,
      anon_sym_STAR,
    ACTIONS(7268), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6954), 1,
      sym__declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3701), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [14411] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7243), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5982), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5980), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [14484] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7064), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3757), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [14599] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2948), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7296), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5919), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5917), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [14672] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2926), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7298), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5919), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5917), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [14745] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7243), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6012), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6010), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [14818] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7216), 1,
      anon_sym___asm,
    ACTIONS(7302), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5547), 1,
      sym__function_attributes_start,
    STATE(5591), 1,
      sym_ref_qualifier,
    STATE(6032), 1,
      sym_trailing_return_type,
    STATE(6303), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7213), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5884), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [14941] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7064), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3682), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [15056] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4553), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4560), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [15125] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7216), 1,
      anon_sym___asm,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5544), 1,
      sym__function_attributes_start,
    STATE(5598), 1,
      sym_ref_qualifier,
    STATE(6147), 1,
      sym_trailing_return_type,
    STATE(6322), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7213), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5897), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [15248] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7186), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2884), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3746), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [15363] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7266), 1,
      anon_sym_STAR,
    ACTIONS(7268), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6947), 1,
      sym__declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2921), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3699), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [15478] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    STATE(3330), 1,
      sym_field_declaration_list,
    STATE(3874), 1,
      sym_attribute_specifier,
    STATE(7692), 1,
      sym_virtual_specifier,
    STATE(8505), 1,
      sym_base_class_clause,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6038), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6036), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [15565] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7317), 1,
      anon_sym_LT,
    STATE(2982), 1,
      sym_template_argument_list,
    ACTIONS(4512), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4519), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [15640] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7243), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6008), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6006), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [15713] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    ACTIONS(7239), 1,
      anon_sym_LBRACE,
    ACTIONS(7241), 1,
      anon_sym_COLON,
    STATE(3043), 1,
      sym__enum_base_clause,
    STATE(3099), 1,
      sym_enumerator_list,
    STATE(3278), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6679), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [15796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6194), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [15865] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7111), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3687), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [15980] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7264), 1,
      anon_sym_LT,
    STATE(2989), 1,
      sym_template_argument_list,
    ACTIONS(5669), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4028), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [16055] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7278), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3711), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [16170] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7247), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6026), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6024), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [16243] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7320), 1,
      anon_sym_LT,
    STATE(2989), 1,
      sym_template_argument_list,
    ACTIONS(4512), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4519), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [16318] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7323), 1,
      sym_identifier,
    STATE(2919), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3788), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3792), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6004), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6002), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [16395] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7216), 1,
      anon_sym___asm,
    ACTIONS(7302), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7325), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5552), 1,
      sym__function_attributes_start,
    STATE(5600), 1,
      sym_ref_qualifier,
    STATE(6051), 1,
      sym_trailing_return_type,
    STATE(6311), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7199), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7213), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5901), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [16518] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4553), 1,
      anon_sym_const,
    ACTIONS(4564), 1,
      anon_sym_AMP,
    ACTIONS(4557), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK,
    ACTIONS(4562), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(4555), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(4560), 24,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
  [16595] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7247), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5982), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5980), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [16668] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7243), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5986), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5984), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [16741] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7247), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6012), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6010), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [16814] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2941), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7328), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5968), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5966), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [16887] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7042), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2923), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3776), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [17002] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2922), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7330), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5990), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5988), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [17075] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6712), 1,
      sym__declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3774), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [17190] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2893), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7332), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5996), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5994), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [17263] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7205), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2887), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3703), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [17378] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6165), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [17447] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7202), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5558), 1,
      sym__function_attributes_start,
    STATE(5595), 1,
      sym_ref_qualifier,
    STATE(6131), 1,
      sym_trailing_return_type,
    STATE(6536), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7199), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5898), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [17570] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6702), 1,
      sym__declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2952), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3772), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [17685] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7111), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3692), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [17800] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2886), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7334), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5968), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5966), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [17873] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2881), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7336), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5770), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5772), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [17946] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2890), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7338), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5996), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5994), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [18019] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7247), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6008), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6006), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [18092] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5099), 1,
      anon_sym_SEMI,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(6477), 1,
      anon_sym_LBRACK,
    STATE(2323), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3076), 1,
      sym_template_argument_list,
    ACTIONS(4025), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4010), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(4030), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 46,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [18177] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2879), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7340), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5770), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5772), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [18250] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6161), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [18319] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6734), 1,
      sym__declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2889), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3693), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [18434] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7342), 1,
      anon_sym_LT,
    STATE(3077), 1,
      sym_template_argument_list,
    ACTIONS(4028), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5669), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [18508] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6165), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [18576] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5690), 1,
      anon_sym_SEMI,
    ACTIONS(5686), 5,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5684), 53,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [18648] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4564), 1,
      anon_sym_LBRACK,
    ACTIONS(4557), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4560), 5,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
    ACTIONS(4553), 52,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [18720] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    ACTIONS(7344), 1,
      anon_sym_LBRACE,
    ACTIONS(7346), 1,
      anon_sym_COLON,
    STATE(3113), 1,
      sym__enum_base_clause,
    STATE(3170), 1,
      sym_enumerator_list,
    STATE(3565), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6679), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [18802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5659), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5661), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [18870] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5690), 1,
      anon_sym_SEMI,
    ACTIONS(5686), 6,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5684), 53,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [18940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5665), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5667), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [19008] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2851), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7197), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5684), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [19080] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7353), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5561), 1,
      sym__function_attributes_start,
    STATE(5631), 1,
      sym_ref_qualifier,
    STATE(6638), 1,
      sym_trailing_return_type,
    STATE(6780), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7350), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5908), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [19202] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    ACTIONS(7344), 1,
      anon_sym_LBRACE,
    ACTIONS(7346), 1,
      anon_sym_COLON,
    STATE(3120), 1,
      sym__enum_base_clause,
    STATE(3150), 1,
      sym_enumerator_list,
    STATE(3538), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6673), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [19284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7358), 5,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7356), 55,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [19352] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    ACTIONS(7360), 1,
      anon_sym_LBRACE,
    ACTIONS(7362), 1,
      anon_sym_COLON,
    STATE(3117), 1,
      sym__enum_base_clause,
    STATE(3166), 1,
      sym_enumerator_list,
    STATE(3640), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6673), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [19434] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7302), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7364), 1,
      anon_sym___attribute__,
    ACTIONS(7367), 1,
      anon_sym___attribute,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5570), 1,
      sym__function_attributes_start,
    STATE(5605), 1,
      sym_ref_qualifier,
    STATE(6032), 1,
      sym_trailing_return_type,
    STATE(6487), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5905), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [19556] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4330), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4332), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [19624] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4553), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4560), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [19692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4396), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4398), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [19760] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5661), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [19830] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5661), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [19900] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5665), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5667), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [19968] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7374), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5567), 1,
      sym__function_attributes_start,
    STATE(5648), 1,
      sym_ref_qualifier,
    STATE(6516), 1,
      sym_trailing_return_type,
    STATE(6782), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7350), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5911), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [20090] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4402), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4404), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [20158] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4553), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4560), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [20226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4408), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4410), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [20294] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7342), 1,
      anon_sym_LT,
    STATE(3077), 1,
      sym_template_argument_list,
    ACTIONS(4519), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4512), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [20368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4350), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4352), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [20436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4356), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4358), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [20504] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4366), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4368), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [20572] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5661), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [20642] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5559), 1,
      sym__function_attributes_start,
    STATE(5630), 1,
      sym_ref_qualifier,
    STATE(6651), 1,
      sym_trailing_return_type,
    STATE(6716), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5907), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [20764] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    ACTIONS(7360), 1,
      anon_sym_LBRACE,
    ACTIONS(7362), 1,
      anon_sym_COLON,
    STATE(3091), 1,
      sym__enum_base_clause,
    STATE(3184), 1,
      sym_enumerator_list,
    STATE(3665), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6679), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [20846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4553), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4560), 42,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [20914] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7302), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7383), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5573), 1,
      sym__function_attributes_start,
    STATE(5618), 1,
      sym_ref_qualifier,
    STATE(6589), 1,
      sym__function_attributes_end,
    STATE(6882), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7199), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5906), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [21036] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5568), 1,
      sym__function_attributes_start,
    STATE(5640), 1,
      sym_ref_qualifier,
    STATE(6514), 1,
      sym_trailing_return_type,
    STATE(6740), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5922), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [21158] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5688), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5690), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [21228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6194), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [21296] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5661), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [21366] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5688), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5690), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [21436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6161), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [21504] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7302), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7325), 1,
      anon_sym_requires,
    ACTIONS(7364), 1,
      anon_sym___attribute__,
    ACTIONS(7367), 1,
      anon_sym___attribute,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5575), 1,
      sym__function_attributes_start,
    STATE(5637), 1,
      sym_ref_qualifier,
    STATE(6051), 1,
      sym_trailing_return_type,
    STATE(6491), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7199), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5915), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [21626] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7364), 1,
      anon_sym___attribute__,
    ACTIONS(7367), 1,
      anon_sym___attribute,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5564), 1,
      sym__function_attributes_start,
    STATE(5635), 1,
      sym_ref_qualifier,
    STATE(6514), 1,
      sym_trailing_return_type,
    STATE(6549), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5929), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [21748] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7364), 1,
      anon_sym___attribute__,
    ACTIONS(7367), 1,
      anon_sym___attribute,
    ACTIONS(7374), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5562), 1,
      sym__function_attributes_start,
    STATE(5606), 1,
      sym_ref_qualifier,
    STATE(6516), 1,
      sym_trailing_return_type,
    STATE(6553), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7350), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5925), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [21870] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6169), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [21938] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7302), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5571), 1,
      sym__function_attributes_start,
    STATE(5614), 1,
      sym_ref_qualifier,
    STATE(6685), 1,
      sym__function_attributes_end,
    STATE(6846), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5920), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [22060] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 14,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      sym_identifier,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_kernel_call_syntax_token1,
  [22159] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7408), 1,
      anon_sym_LT,
    STATE(2998), 1,
      sym_template_argument_list,
    ACTIONS(4512), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4519), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [22232] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4523), 1,
      anon_sym_LBRACK,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(3076), 1,
      sym_template_argument_list,
    ACTIONS(4516), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4519), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
    ACTIONS(4512), 46,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [22309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5659), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5661), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [22376] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7415), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7425), 1,
      anon_sym_or,
    ACTIONS(7427), 1,
      anon_sym_and,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7411), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(7413), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [22491] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7415), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7425), 1,
      anon_sym_or,
    ACTIONS(7427), 1,
      anon_sym_and,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7431), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(7433), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [22606] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7437), 1,
      anon_sym_LBRACK,
    ACTIONS(7439), 1,
      sym_auto,
    ACTIONS(7441), 1,
      anon_sym_decltype,
    STATE(3282), 1,
      sym_new_declarator,
    STATE(3355), 1,
      sym_decltype_auto,
    STATE(3795), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6334), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [22689] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7415), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7425), 1,
      anon_sym_or,
    ACTIONS(7427), 1,
      anon_sym_and,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7445), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7015), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(7017), 15,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [22808] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7415), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7425), 1,
      anon_sym_or,
    ACTIONS(7427), 1,
      anon_sym_and,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7447), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(7449), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [22923] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7427), 1,
      anon_sym_and,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      sym_identifier,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_kernel_call_syntax_token1,
  [23032] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 8,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_kernel_call_syntax_token1,
  [23137] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 10,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      sym_identifier,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_kernel_call_syntax_token1,
  [23240] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1846), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7451), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5986), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5984), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [23311] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 12,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      sym_identifier,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_kernel_call_syntax_token1,
  [23412] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1846), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7451), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5982), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5980), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [23483] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1846), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7451), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6010), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [23554] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3040), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7453), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5968), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5966), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [23625] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3041), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7455), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5996), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5994), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [23696] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1846), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7451), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6008), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6006), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [23767] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2879), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7340), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5684), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [23838] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7437), 1,
      anon_sym_LBRACK,
    ACTIONS(7439), 1,
      sym_auto,
    ACTIONS(7441), 1,
      anon_sym_decltype,
    STATE(3355), 1,
      sym_decltype_auto,
    STATE(3394), 1,
      sym_new_declarator,
    STATE(4005), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6325), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [23921] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7437), 1,
      anon_sym_LBRACK,
    ACTIONS(7439), 1,
      sym_auto,
    ACTIONS(7441), 1,
      anon_sym_decltype,
    STATE(3271), 1,
      sym_new_declarator,
    STATE(3355), 1,
      sym_decltype_auto,
    STATE(3934), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6350), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [24004] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_kernel_call_syntax_token1,
  [24095] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3046), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7457), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5770), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5772), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [24166] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    ACTIONS(7239), 1,
      anon_sym_LBRACE,
    STATE(3104), 1,
      sym_enumerator_list,
    STATE(3285), 1,
      sym_attribute_specifier,
    ACTIONS(6185), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6183), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [24243] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7415), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7425), 1,
      anon_sym_or,
    ACTIONS(7427), 1,
      anon_sym_and,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7459), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(7461), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [24358] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7415), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7425), 1,
      anon_sym_or,
    ACTIONS(7427), 1,
      anon_sym_and,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7445), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7463), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(7465), 15,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [24477] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7415), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7425), 1,
      anon_sym_or,
    ACTIONS(7427), 1,
      anon_sym_and,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7467), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(7469), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [24592] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7406), 1,
      anon_sym_not_eq,
    ACTIONS(7415), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7425), 1,
      anon_sym_or,
    ACTIONS(7427), 1,
      anon_sym_and,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7445), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7396), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7419), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7421), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7423), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7471), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(7473), 15,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [24711] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1846), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7451), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6026), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6024), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [24782] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1846), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7451), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5964), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5962), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [24853] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5659), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5661), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [24920] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    ACTIONS(7239), 1,
      anon_sym_LBRACE,
    STATE(3092), 1,
      sym_enumerator_list,
    STATE(3280), 1,
      sym_attribute_specifier,
    ACTIONS(6179), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6177), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [24997] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    STATE(2323), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3819), 1,
      sym_template_argument_list,
    ACTIONS(4025), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4010), 3,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
    ACTIONS(4030), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 45,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [25078] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2881), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7336), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5684), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5686), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [25149] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1846), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7451), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5900), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5898), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [25220] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5580), 1,
      sym__function_attributes_start,
    STATE(5672), 1,
      sym_ref_qualifier,
    STATE(6799), 1,
      sym_trailing_return_type,
    STATE(6804), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5942), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [25341] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7481), 1,
      anon_sym_LT,
    STATE(2998), 1,
      sym_template_argument_list,
    ACTIONS(5669), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4028), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [25414] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7483), 1,
      anon_sym_requires,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5583), 1,
      sym__function_attributes_start,
    STATE(5699), 1,
      sym_ref_qualifier,
    STATE(6808), 1,
      sym_trailing_return_type,
    STATE(6815), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7350), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5936), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7160), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [25535] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7437), 1,
      anon_sym_LBRACK,
    ACTIONS(7439), 1,
      sym_auto,
    ACTIONS(7441), 1,
      anon_sym_decltype,
    STATE(3355), 1,
      sym_decltype_auto,
    STATE(3359), 1,
      sym_new_declarator,
    STATE(3823), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6307), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [25618] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3025), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7486), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5990), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5988), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [25689] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [25774] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [25861] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [25950] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7481), 1,
      anon_sym_LT,
    STATE(2998), 1,
      sym_template_argument_list,
    STATE(3023), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7288), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4010), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [26027] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3026), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7488), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5919), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5917), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [26098] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7400), 1,
      anon_sym_GT_EQ,
    ACTIONS(7404), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7392), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7402), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7394), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7398), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 15,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_kernel_call_syntax_token1,
  [26193] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7302), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5589), 1,
      sym__function_attributes_start,
    STATE(5774), 1,
      sym_ref_qualifier,
    STATE(6032), 1,
      sym_trailing_return_type,
    STATE(6841), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(7160), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(5972), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [26313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7494), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(7492), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [26379] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7033), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_RBRACK_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7031), 32,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
  [26445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4356), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4358), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [26511] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3305), 1,
      sym_attribute_specifier,
    ACTIONS(6212), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6210), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [26583] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3326), 1,
      sym_attribute_specifier,
    ACTIONS(6228), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6226), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [26655] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4366), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4368), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [26721] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7147), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7149), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
      aux_sym_kernel_call_syntax_token1,
  [26787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2083), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(2078), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [26853] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5661), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5659), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [26921] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2247), 1,
      sym_attribute_specifier,
    STATE(2510), 1,
      sym_field_declaration_list,
    STATE(7605), 1,
      sym_virtual_specifier,
    STATE(8243), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6036), 5,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6038), 43,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [27003] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3360), 1,
      sym_attribute_specifier,
    ACTIONS(6264), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6262), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [27075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5661), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5659), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [27141] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5661), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5659), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [27209] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
      aux_sym_kernel_call_syntax_token1,
  [27275] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7498), 1,
      anon_sym_LBRACK,
    ACTIONS(7500), 1,
      sym_auto,
    ACTIONS(7502), 1,
      anon_sym_decltype,
    STATE(3613), 1,
      sym_decltype_auto,
    STATE(3674), 1,
      sym_new_declarator,
    STATE(4261), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6325), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [27357] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
      aux_sym_kernel_call_syntax_token1,
  [27423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7506), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(7504), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [27489] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4555), 1,
      anon_sym_SEMI,
    ACTIONS(4564), 1,
      anon_sym_LBRACK,
    ACTIONS(4557), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4560), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_EQ,
    ACTIONS(4553), 46,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [27561] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4553), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [27627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2168), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(2166), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [27693] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7364), 1,
      anon_sym___attribute__,
    ACTIONS(7367), 1,
      anon_sym___attribute,
    ACTIONS(7483), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5585), 1,
      sym__function_attributes_start,
    STATE(5827), 1,
      sym_ref_qualifier,
    STATE(6785), 1,
      sym__function_attributes_end,
    STATE(6808), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7350), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(7160), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    STATE(5965), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [27813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5665), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5667), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [27879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
      aux_sym_kernel_call_syntax_token1,
  [27945] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(7512), 1,
      anon_sym_LBRACK,
    ACTIONS(7514), 1,
      sym_auto,
    ACTIONS(7516), 1,
      anon_sym_decltype,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3562), 1,
      sym_new_declarator,
    STATE(4130), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6350), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [28027] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7364), 1,
      anon_sym___attribute__,
    ACTIONS(7367), 1,
      anon_sym___attribute,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5586), 1,
      sym__function_attributes_start,
    STATE(5770), 1,
      sym_ref_qualifier,
    STATE(6751), 1,
      sym__function_attributes_end,
    STATE(6799), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(7160), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    STATE(5960), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [28147] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4402), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4404), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [28213] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    ACTIONS(7525), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(7522), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7520), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT2,
    ACTIONS(7518), 39,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [28287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4350), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4352), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [28353] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7498), 1,
      anon_sym_LBRACK,
    ACTIONS(7500), 1,
      sym_auto,
    ACTIONS(7502), 1,
      anon_sym_decltype,
    STATE(3448), 1,
      sym_new_declarator,
    STATE(3613), 1,
      sym_decltype_auto,
    STATE(4256), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6334), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [28435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6161), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [28501] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(7512), 1,
      anon_sym_LBRACK,
    ACTIONS(7514), 1,
      sym_auto,
    ACTIONS(7516), 1,
      anon_sym_decltype,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3546), 1,
      sym_new_declarator,
    STATE(4101), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6307), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [28583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7530), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(7528), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [28649] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    ACTIONS(7360), 1,
      anon_sym_LBRACE,
    STATE(3192), 1,
      sym_enumerator_list,
    STATE(3450), 1,
      sym_attribute_specifier,
    ACTIONS(6179), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6177), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [28725] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3288), 1,
      sym_attribute_specifier,
    ACTIONS(6260), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6258), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [28797] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5667), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5665), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [28863] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7364), 1,
      anon_sym___attribute__,
    ACTIONS(7367), 1,
      anon_sym___attribute,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5599), 1,
      sym__function_attributes_start,
    STATE(5761), 1,
      sym_ref_qualifier,
    STATE(6651), 1,
      sym_trailing_return_type,
    STATE(6709), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(7160), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5956), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [28983] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(7512), 1,
      anon_sym_LBRACK,
    ACTIONS(7514), 1,
      sym_auto,
    ACTIONS(7516), 1,
      anon_sym_decltype,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3589), 1,
      sym_new_declarator,
    STATE(4176), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6334), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [29065] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7353), 1,
      anon_sym_requires,
    ACTIONS(7364), 1,
      anon_sym___attribute__,
    ACTIONS(7367), 1,
      anon_sym___attribute,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5590), 1,
      sym__function_attributes_start,
    STATE(5805), 1,
      sym_ref_qualifier,
    STATE(6638), 1,
      sym_trailing_return_type,
    STATE(6736), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7350), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(7160), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5971), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [29185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7111), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_RBRACK_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7109), 32,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
  [29251] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7498), 1,
      anon_sym_LBRACK,
    ACTIONS(7500), 1,
      sym_auto,
    ACTIONS(7502), 1,
      anon_sym_decltype,
    STATE(3613), 1,
      sym_decltype_auto,
    STATE(3663), 1,
      sym_new_declarator,
    STATE(4248), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6350), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [29333] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3287), 1,
      sym_attribute_specifier,
    ACTIONS(6218), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6216), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [29405] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(7512), 1,
      anon_sym_LBRACK,
    ACTIONS(7514), 1,
      sym_auto,
    ACTIONS(7516), 1,
      anon_sym_decltype,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3581), 1,
      sym_new_declarator,
    STATE(4159), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6325), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [29487] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6957), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_RBRACK_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(6955), 32,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
  [29553] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3315), 1,
      sym_attribute_specifier,
    ACTIONS(6244), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6242), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [29625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7536), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(7534), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [29691] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3344), 1,
      sym_attribute_specifier,
    ACTIONS(6279), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6277), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [29763] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5661), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [29831] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3425), 1,
      sym_attribute_specifier,
    ACTIONS(6268), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6266), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [29903] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5661), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [29971] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
      aux_sym_kernel_call_syntax_token1,
  [30037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4408), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4410), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [30103] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4404), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4402), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [30169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4410), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4408), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [30235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4352), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4350), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [30301] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    ACTIONS(7344), 1,
      anon_sym_LBRACE,
    STATE(3202), 1,
      sym_enumerator_list,
    STATE(3591), 1,
      sym_attribute_specifier,
    ACTIONS(6179), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6177), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [30377] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5688), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5690), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [30445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4330), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4332), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [30511] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
      aux_sym_kernel_call_syntax_token1,
  [30577] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    ACTIONS(7360), 1,
      anon_sym_LBRACE,
    STATE(3187), 1,
      sym_enumerator_list,
    STATE(3667), 1,
      sym_attribute_specifier,
    ACTIONS(6185), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6183), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [30653] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    ACTIONS(7538), 1,
      anon_sym_LBRACE,
    ACTIONS(7540), 1,
      anon_sym_COLON,
    STATE(3242), 1,
      sym__enum_base_clause,
    STATE(3382), 1,
      sym_enumerator_list,
    STATE(3944), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6679), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [30733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6169), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [30799] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    ACTIONS(7344), 1,
      anon_sym_LBRACE,
    STATE(3208), 1,
      sym_enumerator_list,
    STATE(3568), 1,
      sym_attribute_specifier,
    ACTIONS(6185), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6183), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [30875] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3309), 1,
      sym_attribute_specifier,
    ACTIONS(6240), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6238), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [30947] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5690), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5688), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [31015] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4396), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4398), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [31081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4358), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4356), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [31147] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4368), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4366), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [31213] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7498), 1,
      anon_sym_LBRACK,
    ACTIONS(7500), 1,
      sym_auto,
    ACTIONS(7502), 1,
      anon_sym_decltype,
    STATE(3613), 1,
      sym_decltype_auto,
    STATE(3648), 1,
      sym_new_declarator,
    STATE(4237), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6307), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [31295] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7302), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7325), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5602), 1,
      sym__function_attributes_start,
    STATE(5832), 1,
      sym_ref_qualifier,
    STATE(6051), 1,
      sym_trailing_return_type,
    STATE(6845), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7199), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3788), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4437), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(7160), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(5945), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [31415] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3424), 1,
      sym_attribute_specifier,
    ACTIONS(6250), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6248), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [31487] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4332), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4330), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [31553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7544), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(7542), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [31619] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    ACTIONS(7538), 1,
      anon_sym_LBRACE,
    ACTIONS(7540), 1,
      anon_sym_COLON,
    STATE(3218), 1,
      sym__enum_base_clause,
    STATE(3356), 1,
      sym_enumerator_list,
    STATE(3866), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6673), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [31699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6194), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [31765] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3277), 1,
      sym_attribute_specifier,
    ACTIONS(6236), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6234), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [31837] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7546), 1,
      anon_sym_COLON,
    STATE(2241), 1,
      sym_attribute_specifier,
    STATE(2856), 1,
      sym__enum_base_clause,
    STATE(2907), 1,
      sym_enumerator_list,
    ACTIONS(6671), 5,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
    ACTIONS(6673), 46,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [31917] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7546), 1,
      anon_sym_COLON,
    STATE(2246), 1,
      sym_attribute_specifier,
    STATE(2857), 1,
      sym__enum_base_clause,
    STATE(2911), 1,
      sym_enumerator_list,
    ACTIONS(6677), 5,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym___forceinline,
      anon_sym_const,
    ACTIONS(6679), 46,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
      anon_sym___launch_bounds__,
  [31997] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6878), 1,
      anon_sym___attribute__,
    ACTIONS(6880), 1,
      anon_sym___attribute,
    STATE(3284), 1,
      sym_attribute_specifier,
    ACTIONS(6254), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6252), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [32069] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4398), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(4396), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [32135] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
      aux_sym_kernel_call_syntax_token1,
  [32201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6165), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [32267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5659), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5661), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [32332] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6022), 1,
      anon_sym___asm,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6624), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3142), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4383), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [32435] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      anon_sym___asm,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6648), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4385), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [32538] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [32625] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7572), 1,
      anon_sym_requires,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5641), 1,
      sym__function_attributes_start,
    STATE(5860), 1,
      sym_ref_qualifier,
    STATE(6934), 1,
      sym__function_attributes_end,
    STATE(7066), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7160), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7199), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5983), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [32744] = 54,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7575), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7577), 1,
      anon_sym_COMMA,
    ACTIONS(7579), 1,
      anon_sym_RPAREN,
    ACTIONS(7581), 1,
      anon_sym_DASH,
    ACTIONS(7583), 1,
      anon_sym_PLUS,
    ACTIONS(7585), 1,
      anon_sym_STAR,
    ACTIONS(7587), 1,
      anon_sym_SLASH,
    ACTIONS(7589), 1,
      anon_sym_PERCENT,
    ACTIONS(7591), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7595), 1,
      anon_sym_PIPE,
    ACTIONS(7597), 1,
      anon_sym_CARET,
    ACTIONS(7599), 1,
      anon_sym_AMP,
    ACTIONS(7601), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7603), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7605), 1,
      anon_sym_GT,
    ACTIONS(7607), 1,
      anon_sym_GT_EQ,
    ACTIONS(7609), 1,
      anon_sym_LT_EQ,
    ACTIONS(7611), 1,
      anon_sym_LT,
    ACTIONS(7613), 1,
      anon_sym_LT_LT,
    ACTIONS(7615), 1,
      anon_sym_GT_GT,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7619), 1,
      anon_sym_EQ,
    ACTIONS(7621), 1,
      anon_sym_QMARK,
    ACTIONS(7623), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7625), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7627), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7629), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7631), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7633), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7635), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7637), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7639), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7641), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7647), 1,
      anon_sym_or,
    ACTIONS(7649), 1,
      anon_sym_and,
    ACTIONS(7651), 1,
      anon_sym_bitor,
    ACTIONS(7653), 1,
      anon_sym_xor,
    ACTIONS(7655), 1,
      anon_sym_bitand,
    ACTIONS(7657), 1,
      anon_sym_not_eq,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7643), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [32911] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7667), 1,
      sym_literal_suffix,
    ACTIONS(4012), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4004), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [32978] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7353), 1,
      anon_sym_requires,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5616), 1,
      sym__function_attributes_start,
    STATE(5852), 1,
      sym_ref_qualifier,
    STATE(6638), 1,
      sym_trailing_return_type,
    STATE(6978), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7160), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7350), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5987), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [33097] = 54,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7575), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7577), 1,
      anon_sym_COMMA,
    ACTIONS(7581), 1,
      anon_sym_DASH,
    ACTIONS(7583), 1,
      anon_sym_PLUS,
    ACTIONS(7585), 1,
      anon_sym_STAR,
    ACTIONS(7587), 1,
      anon_sym_SLASH,
    ACTIONS(7589), 1,
      anon_sym_PERCENT,
    ACTIONS(7591), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7595), 1,
      anon_sym_PIPE,
    ACTIONS(7597), 1,
      anon_sym_CARET,
    ACTIONS(7599), 1,
      anon_sym_AMP,
    ACTIONS(7601), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7603), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7605), 1,
      anon_sym_GT,
    ACTIONS(7607), 1,
      anon_sym_GT_EQ,
    ACTIONS(7609), 1,
      anon_sym_LT_EQ,
    ACTIONS(7611), 1,
      anon_sym_LT,
    ACTIONS(7613), 1,
      anon_sym_LT_LT,
    ACTIONS(7615), 1,
      anon_sym_GT_GT,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7619), 1,
      anon_sym_EQ,
    ACTIONS(7621), 1,
      anon_sym_QMARK,
    ACTIONS(7623), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7625), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7627), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7629), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7631), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7633), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7635), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7637), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7639), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7641), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7647), 1,
      anon_sym_or,
    ACTIONS(7649), 1,
      anon_sym_and,
    ACTIONS(7651), 1,
      anon_sym_bitor,
    ACTIONS(7653), 1,
      anon_sym_xor,
    ACTIONS(7655), 1,
      anon_sym_bitand,
    ACTIONS(7657), 1,
      anon_sym_not_eq,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7673), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7643), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [33264] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3564), 1,
      sym_attribute_specifier,
    ACTIONS(6236), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6234), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [33335] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3567), 1,
      sym_attribute_specifier,
    ACTIONS(6254), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6252), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [33406] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3675), 1,
      sym_attribute_specifier,
    ACTIONS(6212), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6210), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [33477] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3572), 1,
      sym_attribute_specifier,
    ACTIONS(6228), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6226), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [33548] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3046), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7457), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5684), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [33617] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3639), 1,
      sym_attribute_specifier,
    ACTIONS(6240), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6238), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [33688] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3643), 1,
      sym_attribute_specifier,
    ACTIONS(6244), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6242), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [33759] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7471), 1,
      anon_sym_EQ,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7691), 1,
      anon_sym_QMARK,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [33878] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7707), 1,
      anon_sym___declspec,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(7713), 1,
      anon_sym___launch_bounds__,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    ACTIONS(61), 2,
      anon_sym___inline,
      anon_sym___forceinline,
    ACTIONS(5952), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(5954), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(7703), 6,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
    ACTIONS(7705), 7,
      anon_sym_extern,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
    STATE(3566), 8,
      sym__declaration_modifiers,
      sym_attribute_specifier,
      sym_attribute_declaration,
      sym_ms_declspec_modifier,
      sym_storage_class_specifier,
      sym_type_qualifier,
      sym_launch_bounds,
      aux_sym__declaration_specifiers_repeat1,
    ACTIONS(7300), 17,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [33975] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7463), 1,
      anon_sym_EQ,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7691), 1,
      anon_sym_QMARK,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [34094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5710), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5712), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [34159] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6022), 1,
      anon_sym___attribute,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6661), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3161), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4387), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [34262] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6590), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4411), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [34365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5714), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5716), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [34430] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7411), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [34545] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5770), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5772), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [34610] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3664), 1,
      sym_attribute_specifier,
    ACTIONS(6236), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6234), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [34681] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3666), 1,
      sym_attribute_specifier,
    ACTIONS(6254), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6252), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [34752] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5821), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5823), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [34817] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3669), 1,
      sym_attribute_specifier,
    ACTIONS(6212), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6210), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [34888] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3670), 1,
      sym_attribute_specifier,
    ACTIONS(6228), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6226), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [34959] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3590), 1,
      sym_attribute_specifier,
    ACTIONS(6218), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6216), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [35030] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5782), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5784), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [35095] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5638), 1,
      sym__function_attributes_start,
    STATE(5873), 1,
      sym_ref_qualifier,
    STATE(6927), 1,
      sym__function_attributes_end,
    STATE(7050), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7160), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6432), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5974), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [35214] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6022), 1,
      anon_sym___asm,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6609), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3177), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4336), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [35317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5748), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [35382] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7431), 1,
      anon_sym_EQ,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [35497] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [35582] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5933), 1,
      anon_sym___asm,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6623), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4356), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [35685] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3593), 1,
      sym_attribute_specifier,
    ACTIONS(6250), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6248), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [35756] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7015), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7691), 1,
      anon_sym_QMARK,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [35875] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3537), 1,
      sym_attribute_specifier,
    ACTIONS(6240), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6238), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [35946] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3594), 1,
      sym_attribute_specifier,
    ACTIONS(6264), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6262), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [36017] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4555), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [36084] = 54,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7575), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7577), 1,
      anon_sym_COMMA,
    ACTIONS(7581), 1,
      anon_sym_DASH,
    ACTIONS(7583), 1,
      anon_sym_PLUS,
    ACTIONS(7585), 1,
      anon_sym_STAR,
    ACTIONS(7587), 1,
      anon_sym_SLASH,
    ACTIONS(7589), 1,
      anon_sym_PERCENT,
    ACTIONS(7591), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7595), 1,
      anon_sym_PIPE,
    ACTIONS(7597), 1,
      anon_sym_CARET,
    ACTIONS(7599), 1,
      anon_sym_AMP,
    ACTIONS(7601), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7603), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7605), 1,
      anon_sym_GT,
    ACTIONS(7607), 1,
      anon_sym_GT_EQ,
    ACTIONS(7609), 1,
      anon_sym_LT_EQ,
    ACTIONS(7611), 1,
      anon_sym_LT,
    ACTIONS(7613), 1,
      anon_sym_LT_LT,
    ACTIONS(7615), 1,
      anon_sym_GT_GT,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7619), 1,
      anon_sym_EQ,
    ACTIONS(7621), 1,
      anon_sym_QMARK,
    ACTIONS(7623), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7625), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7627), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7629), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7631), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7633), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7635), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7637), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7639), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7641), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7647), 1,
      anon_sym_or,
    ACTIONS(7649), 1,
      anon_sym_and,
    ACTIONS(7651), 1,
      anon_sym_bitor,
    ACTIONS(7653), 1,
      anon_sym_xor,
    ACTIONS(7655), 1,
      anon_sym_bitand,
    ACTIONS(7657), 1,
      anon_sym_not_eq,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7729), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7643), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [36251] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3449), 1,
      sym_attribute_specifier,
    ACTIONS(6218), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6216), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [36322] = 54,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7575), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7577), 1,
      anon_sym_COMMA,
    ACTIONS(7581), 1,
      anon_sym_DASH,
    ACTIONS(7583), 1,
      anon_sym_PLUS,
    ACTIONS(7585), 1,
      anon_sym_STAR,
    ACTIONS(7587), 1,
      anon_sym_SLASH,
    ACTIONS(7589), 1,
      anon_sym_PERCENT,
    ACTIONS(7591), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7595), 1,
      anon_sym_PIPE,
    ACTIONS(7597), 1,
      anon_sym_CARET,
    ACTIONS(7599), 1,
      anon_sym_AMP,
    ACTIONS(7601), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7603), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7605), 1,
      anon_sym_GT,
    ACTIONS(7607), 1,
      anon_sym_GT_EQ,
    ACTIONS(7609), 1,
      anon_sym_LT_EQ,
    ACTIONS(7611), 1,
      anon_sym_LT,
    ACTIONS(7613), 1,
      anon_sym_LT_LT,
    ACTIONS(7615), 1,
      anon_sym_GT_GT,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7619), 1,
      anon_sym_EQ,
    ACTIONS(7621), 1,
      anon_sym_QMARK,
    ACTIONS(7623), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7625), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7627), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7629), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7631), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7633), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7635), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7637), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7639), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7641), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7647), 1,
      anon_sym_or,
    ACTIONS(7649), 1,
      anon_sym_and,
    ACTIONS(7651), 1,
      anon_sym_bitor,
    ACTIONS(7653), 1,
      anon_sym_xor,
    ACTIONS(7655), 1,
      anon_sym_bitand,
    ACTIONS(7657), 1,
      anon_sym_not_eq,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7731), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7643), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [36489] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3541), 1,
      sym_attribute_specifier,
    ACTIONS(6244), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6242), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [36560] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3451), 1,
      sym_attribute_specifier,
    ACTIONS(6279), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6277), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [36631] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3452), 1,
      sym_attribute_specifier,
    ACTIONS(6250), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6248), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [36702] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3453), 1,
      sym_attribute_specifier,
    ACTIONS(6264), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6262), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [36773] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7177), 1,
      anon_sym_LBRACK,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(5642), 1,
      sym__function_attributes_start,
    STATE(5870), 1,
      sym_ref_qualifier,
    STATE(6651), 1,
      sym_trailing_return_type,
    STATE(6974), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7160), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4277), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6636), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5988), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [36892] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7707), 1,
      anon_sym___declspec,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(7713), 1,
      anon_sym___launch_bounds__,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    ACTIONS(61), 2,
      anon_sym___inline,
      anon_sym___forceinline,
    ACTIONS(5972), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(5974), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(7733), 6,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
    ACTIONS(7705), 7,
      anon_sym_extern,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
    STATE(3475), 8,
      sym__declaration_modifiers,
      sym_attribute_specifier,
      sym_attribute_declaration,
      sym_ms_declspec_modifier,
      sym_storage_class_specifier,
      sym_type_qualifier,
      sym_launch_bounds,
      aux_sym__declaration_specifiers_repeat1,
    ACTIONS(7300), 17,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [36989] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3455), 1,
      sym_attribute_specifier,
    ACTIONS(6260), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6258), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [37060] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7087), 1,
      anon_sym___attribute__,
    ACTIONS(7089), 1,
      anon_sym___attribute,
    STATE(3456), 1,
      sym_attribute_specifier,
    ACTIONS(6268), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6266), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [37131] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [37214] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [37303] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7459), 1,
      anon_sym_EQ,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [37418] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 2,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token1,
  [37527] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6767), 3,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token1,
  [37632] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6769), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [37733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(7737), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [37798] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7467), 1,
      anon_sym_EQ,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [37913] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3598), 1,
      sym_attribute_specifier,
    ACTIONS(6260), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6258), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [37984] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [38083] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7447), 1,
      anon_sym_EQ,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [38198] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
  [38293] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [38386] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3599), 1,
      sym_attribute_specifier,
    ACTIONS(6268), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6266), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [38457] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6963), 1,
      anon_sym___attribute__,
    ACTIONS(6965), 1,
      anon_sym___attribute,
    STATE(3592), 1,
      sym_attribute_specifier,
    ACTIONS(6279), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6277), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [38528] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 11,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [38616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5821), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5823), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [38680] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 4,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token1,
  [38784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(7737), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [38848] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    ACTIONS(7765), 1,
      anon_sym_LBRACK,
    ACTIONS(7767), 1,
      sym_auto,
    ACTIONS(7769), 1,
      anon_sym_decltype,
    STATE(3796), 1,
      sym_decltype_auto,
    STATE(3962), 1,
      sym_new_declarator,
    STATE(4414), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6325), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [38928] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7771), 1,
      anon_sym_LPAREN2,
    ACTIONS(7773), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    STATE(3754), 1,
      sym_parameter_list,
    STATE(3301), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6480), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6482), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [39002] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    ACTIONS(7765), 1,
      anon_sym_LBRACK,
    ACTIONS(7767), 1,
      sym_auto,
    ACTIONS(7769), 1,
      anon_sym_decltype,
    STATE(3796), 1,
      sym_decltype_auto,
    STATE(3896), 1,
      sym_new_declarator,
    STATE(4369), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6307), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [39082] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7771), 1,
      anon_sym_LPAREN2,
    ACTIONS(7773), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    STATE(3754), 1,
      sym_parameter_list,
    STATE(3301), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6508), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6510), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [39156] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [39254] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    ACTIONS(7538), 1,
      anon_sym_LBRACE,
    STATE(3261), 1,
      sym_enumerator_list,
    STATE(3949), 1,
      sym_attribute_specifier,
    ACTIONS(6185), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6183), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [39328] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7771), 1,
      anon_sym_LPAREN2,
    ACTIONS(7773), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    STATE(3754), 1,
      sym_parameter_list,
    STATE(3301), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6438), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6440), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [39402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5714), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5716), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [39466] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7777), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_or,
    ACTIONS(7783), 1,
      anon_sym_and,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7467), 2,
      anon_sym___attribute,
      anon_sym_EQ,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [39580] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7667), 1,
      sym_literal_suffix,
    ACTIONS(4012), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(4004), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [39646] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5782), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5784), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [39710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5770), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5772), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [39774] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7771), 1,
      anon_sym_LPAREN2,
    ACTIONS(7773), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    STATE(3754), 1,
      sym_parameter_list,
    STATE(3301), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6452), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6454), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [39848] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5821), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5823), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [39912] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7777), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_or,
    ACTIONS(7783), 1,
      anon_sym_and,
    ACTIONS(7785), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7015), 2,
      anon_sym___attribute,
      anon_sym_EQ,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [40030] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7777), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_or,
    ACTIONS(7783), 1,
      anon_sym_and,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7411), 2,
      anon_sym___attribute,
      anon_sym_EQ,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [40144] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4519), 1,
      anon_sym_LBRACE,
    ACTIONS(4526), 1,
      anon_sym_LT,
    STATE(3182), 1,
      sym_template_argument_list,
    ACTIONS(4521), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [40216] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 8,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
  [40310] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 8,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [40402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5655), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5657), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [40466] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7783), 1,
      anon_sym_and,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6767), 3,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token1,
  [40574] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4514), 1,
      anon_sym_SEMI,
    ACTIONS(4523), 1,
      anon_sym_LBRACK,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(3076), 1,
      sym_template_argument_list,
    ACTIONS(4516), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4519), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(4512), 46,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [40650] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5748), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [40714] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7777), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_or,
    ACTIONS(7783), 1,
      anon_sym_and,
    ACTIONS(7785), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7471), 2,
      anon_sym___attribute,
      anon_sym_EQ,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [40832] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6273), 4,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(6275), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(4004), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(4012), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
  [40900] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5710), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5712), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [40964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5748), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [41028] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    ACTIONS(7765), 1,
      anon_sym_LBRACK,
    ACTIONS(7767), 1,
      sym_auto,
    ACTIONS(7769), 1,
      anon_sym_decltype,
    STATE(3796), 1,
      sym_decltype_auto,
    STATE(3939), 1,
      sym_new_declarator,
    STATE(4413), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6350), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [41108] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [41208] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    ACTIONS(7538), 1,
      anon_sym_LBRACE,
    STATE(3325), 1,
      sym_enumerator_list,
    STATE(3988), 1,
      sym_attribute_specifier,
    ACTIONS(6179), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6177), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [41282] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7777), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_or,
    ACTIONS(7783), 1,
      anon_sym_and,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7431), 2,
      anon_sym___attribute,
      anon_sym_EQ,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [41396] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7777), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_or,
    ACTIONS(7783), 1,
      anon_sym_and,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7459), 2,
      anon_sym___attribute,
      anon_sym_EQ,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [41510] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5684), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [41576] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7777), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_or,
    ACTIONS(7783), 1,
      anon_sym_and,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7447), 2,
      anon_sym___attribute,
      anon_sym_EQ,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [41690] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7745), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7747), 1,
      anon_sym_PIPE,
    ACTIONS(7751), 1,
      anon_sym_AMP,
    ACTIONS(7757), 1,
      anon_sym_GT_EQ,
    ACTIONS(7759), 1,
      anon_sym_bitor,
    ACTIONS(7761), 1,
      anon_sym_bitand,
    ACTIONS(7777), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_or,
    ACTIONS(7783), 1,
      anon_sym_and,
    ACTIONS(7785), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7463), 2,
      anon_sym___attribute,
      anon_sym_EQ,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7749), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7753), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7755), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [41808] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7771), 1,
      anon_sym_LPAREN2,
    ACTIONS(7773), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    STATE(3754), 1,
      sym_parameter_list,
    STATE(3301), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6504), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6506), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [41882] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    ACTIONS(7765), 1,
      anon_sym_LBRACK,
    ACTIONS(7767), 1,
      sym_auto,
    ACTIONS(7769), 1,
      anon_sym_decltype,
    STATE(3796), 1,
      sym_decltype_auto,
    STATE(3984), 1,
      sym_new_declarator,
    STATE(4377), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6334), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [41962] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4519), 1,
      anon_sym_LBRACE,
    ACTIONS(4675), 1,
      anon_sym_LT,
    STATE(3338), 1,
      sym_template_argument_list,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [42034] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      sym_auto,
    ACTIONS(7441), 1,
      anon_sym_decltype,
    STATE(3355), 1,
      sym_decltype_auto,
    ACTIONS(5673), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5675), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [42104] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5710), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5712), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [42168] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5770), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5772), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [42232] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7789), 1,
      anon_sym_RPAREN,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7774), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [42344] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [42426] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 13,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [42510] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7739), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7743), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7741), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 11,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [42596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5782), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5784), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [42660] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5714), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5716), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [42724] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [42811] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3990), 1,
      sym_attribute_specifier,
    ACTIONS(6279), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6277), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [42880] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9066), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [42989] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7463), 1,
      anon_sym_EQ,
    ACTIONS(7575), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7621), 1,
      anon_sym_QMARK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7819), 1,
      anon_sym_or,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [43106] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5630), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [43169] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7447), 1,
      anon_sym_EQ,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7819), 1,
      anon_sym_or,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [43282] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3943), 1,
      sym_attribute_specifier,
    ACTIONS(6236), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6234), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [43351] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9237), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [43460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7829), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT2,
    ACTIONS(7827), 44,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [43523] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5684), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [43588] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8607), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [43697] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    STATE(3793), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6585), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6587), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [43766] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8784), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [43875] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7467), 1,
      anon_sym_EQ,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7819), 1,
      anon_sym_or,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [43988] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9104), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [44097] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8833), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [44206] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [44297] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5797), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5799), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [44360] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5809), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5811), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [44423] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9388), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [44532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5734), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5736), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [44595] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9426), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [44704] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    STATE(3967), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6601), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6603), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [44773] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [44858] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5774), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5776), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [44921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5853), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5855), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [44984] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7831), 1,
      anon_sym_LPAREN2,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7835), 1,
      anon_sym_LBRACK,
    STATE(3972), 1,
      sym_parameter_list,
    STATE(3641), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6452), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6454), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [45057] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5726), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5728), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [45120] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5754), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5756), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [45183] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8698), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [45292] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7837), 1,
      anon_sym_LPAREN2,
    ACTIONS(7839), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7841), 1,
      anon_sym_LBRACK,
    STATE(3936), 1,
      sym_parameter_list,
    STATE(3479), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6438), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6440), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [45365] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5684), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5686), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [45430] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6290), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [45539] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7865), 1,
      anon_sym_enum,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(7873), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3963), 1,
      sym_type_specifier,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    STATE(3569), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [45648] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7875), 1,
      anon_sym_COLON,
    STATE(2246), 1,
      sym_attribute_specifier,
    STATE(2416), 1,
      sym__enum_base_clause,
    STATE(2553), 1,
      sym_enumerator_list,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6679), 5,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6677), 43,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [45723] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6022), 1,
      anon_sym___attribute,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6836), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3297), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4494), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [45824] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8672), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [45933] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6851), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4497), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [46034] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6706), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6708), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [46113] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7883), 1,
      sym_identifier,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7891), 1,
      anon_sym_enum,
    ACTIONS(7893), 1,
      anon_sym_class,
    ACTIONS(7895), 1,
      anon_sym_struct,
    ACTIONS(7897), 1,
      anon_sym_union,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7903), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3800), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    STATE(3515), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [46222] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6294), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [46331] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7773), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3335), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6593), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6595), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [46398] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4700), 1,
      sym_type_specifier,
    STATE(6630), 1,
      sym_type_descriptor,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3532), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [46507] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8973), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [46616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5698), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [46679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5803), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [46742] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9121), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [46851] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7907), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT2,
    ACTIONS(7905), 44,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [46914] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6767), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [46993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5692), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5694), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [47056] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5738), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5740), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [47119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2220), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(2218), 53,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [47182] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7865), 1,
      anon_sym_enum,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(7873), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4284), 1,
      sym_type_specifier,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    STATE(3586), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [47291] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2046), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(2044), 53,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [47354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [47417] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5786), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5788), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [47480] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5805), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5807), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [47543] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7837), 1,
      anon_sym_LPAREN2,
    ACTIONS(7839), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7841), 1,
      anon_sym_LBRACK,
    STATE(3936), 1,
      sym_parameter_list,
    STATE(3479), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6508), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6510), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [47616] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7909), 1,
      sym_identifier,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7915), 1,
      sym_primitive_type,
    ACTIONS(7917), 1,
      anon_sym_enum,
    ACTIONS(7919), 1,
      anon_sym_class,
    ACTIONS(7921), 1,
      anon_sym_struct,
    ACTIONS(7923), 1,
      anon_sym_union,
    ACTIONS(7925), 1,
      sym_auto,
    ACTIONS(7927), 1,
      anon_sym_decltype,
    ACTIONS(7929), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(4276), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4511), 1,
      sym_type_specifier,
    STATE(5194), 1,
      sym_qualified_type_identifier,
    STATE(5228), 1,
      sym_decltype_auto,
    STATE(6630), 1,
      sym_type_descriptor,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3505), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4959), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7913), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5232), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [47725] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [47832] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2034), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(2032), 53,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [47895] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [47958] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6767), 3,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48061] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48124] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7883), 1,
      sym_identifier,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7891), 1,
      anon_sym_enum,
    ACTIONS(7893), 1,
      anon_sym_class,
    ACTIONS(7895), 1,
      anon_sym_struct,
    ACTIONS(7897), 1,
      anon_sym_union,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7903), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3998), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    STATE(3510), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [48233] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3864), 1,
      sym_attribute_specifier,
    ACTIONS(6260), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6258), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48302] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5819), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48428] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6336), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [48537] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5698), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48600] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3952), 1,
      sym_attribute_specifier,
    ACTIONS(6212), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6210), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48669] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3956), 1,
      sym_attribute_specifier,
    ACTIONS(6228), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6226), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48738] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3991), 1,
      sym_attribute_specifier,
    ACTIONS(6250), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6248), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48807] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9099), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [48916] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6748), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6750), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [48995] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7931), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3335), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6561), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6563), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [49062] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9428), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [49171] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3802), 1,
      sym_attribute_specifier,
    ACTIONS(6268), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6266), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [49240] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4555), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [49305] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [49404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2597), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(2595), 53,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [49467] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8578), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [49576] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7471), 1,
      anon_sym_EQ,
    ACTIONS(7575), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7621), 1,
      anon_sym_QMARK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7819), 1,
      anon_sym_or,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [49693] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8934), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [49802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5742), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5744), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [49865] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6317), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [49974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5655), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5657), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [50037] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2943), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3788), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3792), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6352), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6354), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [50106] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6687), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6689), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [50183] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7934), 1,
      sym_identifier,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7938), 1,
      anon_sym_enum,
    ACTIONS(7940), 1,
      anon_sym_class,
    ACTIONS(7942), 1,
      anon_sym_struct,
    ACTIONS(7944), 1,
      anon_sym_union,
    ACTIONS(7946), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4646), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    STATE(3575), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [50292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5825), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5827), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [50355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5829), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5831), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [50418] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6318), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [50527] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3992), 1,
      sym_attribute_specifier,
    ACTIONS(6264), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6262), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [50596] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [50705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5844), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [50768] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3948), 1,
      sym_attribute_specifier,
    ACTIONS(6254), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6252), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [50837] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9273), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [50946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5778), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5780), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [51009] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    STATE(4001), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6568), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6570), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [51078] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5758), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5760), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [51141] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5815), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [51204] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7865), 1,
      anon_sym_enum,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(7873), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4570), 1,
      sym_type_specifier,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    STATE(3596), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [51313] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7575), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7621), 1,
      anon_sym_QMARK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7819), 1,
      anon_sym_or,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [51430] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4505), 1,
      sym_type_specifier,
    STATE(6630), 1,
      sym_type_descriptor,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3582), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [51539] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6333), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [51648] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6784), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6786), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [51727] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6335), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [51836] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7831), 1,
      anon_sym_LPAREN2,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7835), 1,
      anon_sym_LBRACK,
    STATE(3972), 1,
      sym_parameter_list,
    STATE(3641), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6480), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6482), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [51909] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5766), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5768), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [51972] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9170), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [52081] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6337), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [52190] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4521), 1,
      sym_type_specifier,
    STATE(6630), 1,
      sym_type_descriptor,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3550), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [52299] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6338), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [52408] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2115), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(2110), 53,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [52471] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6340), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [52580] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7837), 1,
      anon_sym_LPAREN2,
    ACTIONS(7839), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7841), 1,
      anon_sym_LBRACK,
    STATE(3936), 1,
      sym_parameter_list,
    STATE(3479), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6480), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6482), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [52653] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6341), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [52762] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7459), 1,
      anon_sym_EQ,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7819), 1,
      anon_sym_or,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [52875] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6342), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [52984] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8781), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [53093] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6343), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [53202] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3987), 1,
      sym_attribute_specifier,
    ACTIONS(6218), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6216), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [53271] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6344), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [53380] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6345), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [53489] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6346), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [53598] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6347), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [53707] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7831), 1,
      anon_sym_LPAREN2,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7835), 1,
      anon_sym_LBRACK,
    STATE(3972), 1,
      sym_parameter_list,
    STATE(3641), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6504), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6506), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [53780] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7500), 1,
      sym_auto,
    ACTIONS(7502), 1,
      anon_sym_decltype,
    STATE(3613), 1,
      sym_decltype_auto,
    ACTIONS(5673), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5675), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [53849] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8666), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [53958] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9029), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [54067] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [54150] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9049), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [54259] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7883), 1,
      sym_identifier,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7891), 1,
      anon_sym_enum,
    ACTIONS(7893), 1,
      anon_sym_class,
    ACTIONS(7895), 1,
      anon_sym_struct,
    ACTIONS(7897), 1,
      anon_sym_union,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7903), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4412), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    STATE(3495), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [54368] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    STATE(3918), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6659), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6661), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [54437] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7514), 1,
      sym_auto,
    ACTIONS(7516), 1,
      anon_sym_decltype,
    STATE(3530), 1,
      sym_decltype_auto,
    ACTIONS(5673), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5675), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [54506] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7831), 1,
      anon_sym_LPAREN2,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7835), 1,
      anon_sym_LBRACK,
    STATE(3972), 1,
      sym_parameter_list,
    STATE(3641), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6438), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6440), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [54579] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7837), 1,
      anon_sym_LPAREN2,
    ACTIONS(7839), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7841), 1,
      anon_sym_LBRACK,
    STATE(3936), 1,
      sym_parameter_list,
    STATE(3479), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6504), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6506), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [54652] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6697), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6699), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [54729] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2880), 1,
      anon_sym_enum,
    ACTIONS(2882), 1,
      anon_sym_class,
    ACTIONS(2884), 1,
      anon_sym_struct,
    ACTIONS(2886), 1,
      anon_sym_union,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(2914), 1,
      anon_sym_typename,
    ACTIONS(7948), 1,
      sym_identifier,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7952), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4569), 1,
      sym_type_specifier,
    STATE(6630), 1,
      sym_type_descriptor,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    STATE(3574), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2876), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [54838] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4519), 1,
      anon_sym_LBRACE,
    ACTIONS(5681), 1,
      anon_sym_LT,
    STATE(3610), 1,
      sym_template_argument_list,
    ACTIONS(4521), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [54909] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5730), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5732), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [54972] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7875), 1,
      anon_sym_COLON,
    STATE(2241), 1,
      sym_attribute_specifier,
    STATE(2369), 1,
      sym__enum_base_clause,
    STATE(2563), 1,
      sym_enumerator_list,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6673), 5,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6671), 43,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [55047] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8734), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [55156] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2030), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(2028), 53,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [55219] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3736), 1,
      sym_identifier,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(3750), 1,
      anon_sym_enum,
    ACTIONS(3752), 1,
      anon_sym_class,
    ACTIONS(3754), 1,
      anon_sym_struct,
    ACTIONS(3756), 1,
      anon_sym_union,
    ACTIONS(3758), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4461), 1,
      sym_type_specifier,
    STATE(6373), 1,
      sym_type_descriptor,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    STATE(3503), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [55328] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [55425] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3865), 1,
      sym_attribute_specifier,
    ACTIONS(6240), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6238), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [55494] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [55575] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6771), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6773), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [55654] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9174), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [55763] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [55826] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9062), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [55935] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7819), 1,
      anon_sym_or,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [56048] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8799), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [56157] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7909), 1,
      sym_identifier,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7915), 1,
      sym_primitive_type,
    ACTIONS(7917), 1,
      anon_sym_enum,
    ACTIONS(7919), 1,
      anon_sym_class,
    ACTIONS(7921), 1,
      anon_sym_struct,
    ACTIONS(7923), 1,
      anon_sym_union,
    ACTIONS(7925), 1,
      sym_auto,
    ACTIONS(7927), 1,
      anon_sym_decltype,
    ACTIONS(7929), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(4276), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4337), 1,
      sym_type_specifier,
    STATE(5194), 1,
      sym_qualified_type_identifier,
    STATE(5228), 1,
      sym_decltype_auto,
    STATE(6630), 1,
      sym_type_descriptor,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3528), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4959), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7913), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5232), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [56266] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4003), 1,
      sym_alignas_qualifier,
    ACTIONS(7957), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5112), 10,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DASH_GT,
    ACTIONS(7954), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
    ACTIONS(5110), 21,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      sym_primitive_type,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [56337] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2880), 1,
      anon_sym_enum,
    ACTIONS(2882), 1,
      anon_sym_class,
    ACTIONS(2884), 1,
      anon_sym_struct,
    ACTIONS(2886), 1,
      anon_sym_union,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(2914), 1,
      anon_sym_typename,
    ACTIONS(7948), 1,
      sym_identifier,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7952), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4523), 1,
      sym_type_specifier,
    STATE(6630), 1,
      sym_type_descriptor,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    STATE(3587), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2876), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [56446] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9462), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [56555] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7431), 1,
      anon_sym_EQ,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7807), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7819), 1,
      anon_sym_or,
    ACTIONS(7821), 1,
      anon_sym_and,
    ACTIONS(7823), 1,
      anon_sym_bitor,
    ACTIONS(7825), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7809), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [56668] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9232), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [56777] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8820), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [56886] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9239), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [56995] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7831), 1,
      anon_sym_LPAREN2,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7835), 1,
      anon_sym_LBRACK,
    STATE(3972), 1,
      sym_parameter_list,
    STATE(3641), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6508), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6510), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [57068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5724), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [57131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5718), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5720), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [57194] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9257), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [57303] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9262), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [57412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5655), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5657), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [57475] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8902), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [57584] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9277), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [57693] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9282), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [57802] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9420), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [57911] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9296), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [58020] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9301), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [58129] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9315), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [58238] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9320), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [58347] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9331), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [58456] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4930), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(9335), 1,
      sym_type_descriptor,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3501), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [58565] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5762), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5764), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [58628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2385), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(2383), 53,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym___launch_bounds__,
  [58691] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7837), 1,
      anon_sym_LPAREN2,
    ACTIONS(7839), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7841), 1,
      anon_sym_LBRACK,
    STATE(3936), 1,
      sym_parameter_list,
    STATE(3479), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6452), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6454), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [58764] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7645), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8263), 1,
      sym_kernel_call_syntax,
    ACTIONS(7659), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7795), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7797), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7813), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [58857] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8591), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [58966] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4837), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(8776), 1,
      sym_type_descriptor,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3563), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [59075] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7311), 1,
      anon_sym___attribute__,
    ACTIONS(7313), 1,
      anon_sym___attribute,
    STATE(3871), 1,
      sym_attribute_specifier,
    ACTIONS(6244), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6242), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [59144] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5397), 1,
      sym_type_specifier,
    STATE(6320), 1,
      sym__type_definition_type,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    STATE(3460), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [59253] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7471), 1,
      anon_sym_EQ,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7960), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7966), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7986), 1,
      anon_sym_QMARK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7990), 1,
      anon_sym_or,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 15,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token2,
  [59369] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    STATE(4217), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6601), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6603), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59437] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5726), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5728), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5734), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5736), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59561] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5742), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5744), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59623] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5724), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5758), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5760), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59747] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5762), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5764), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5754), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5756), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5718), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5720), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [59933] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    STATE(4466), 1,
      sym_field_declaration_list,
    STATE(4584), 1,
      sym_attribute_specifier,
    STATE(7710), 1,
      sym_virtual_specifier,
    STATE(8378), 1,
      sym_base_class_clause,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6038), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6036), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [60011] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7691), 1,
      anon_sym_QMARK,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    ACTIONS(7729), 1,
      anon_sym_RPAREN,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8008), 1,
      anon_sym_EQ,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7643), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [60131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5630), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [60193] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5398), 1,
      sym_type_specifier,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [60299] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7463), 1,
      anon_sym_EQ,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7960), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7966), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7986), 1,
      anon_sym_QMARK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7990), 1,
      anon_sym_or,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 15,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token2,
  [60415] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8010), 1,
      sym_identifier,
    STATE(3464), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(6407), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(6409), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6004), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6002), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [60485] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4521), 1,
      anon_sym_LBRACK,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(3819), 1,
      sym_template_argument_list,
    ACTIONS(4516), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4519), 3,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
    ACTIONS(4512), 45,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [60557] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8012), 1,
      sym_identifier,
    STATE(3465), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(6407), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(6409), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6018), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6016), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [60627] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8014), 1,
      sym_identifier,
    STATE(3465), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(8017), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(8020), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5884), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5882), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [60697] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7667), 1,
      sym_literal_suffix,
    ACTIONS(4012), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(4004), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [60761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(7737), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [60823] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8023), 1,
      anon_sym_LT,
    STATE(3678), 1,
      sym_template_argument_list,
    ACTIONS(6775), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6777), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [60891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5782), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5784), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [60953] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6919), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4553), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [61051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5748), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [61113] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8032), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3472), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6561), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6563), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [61179] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(3820), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8035), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6074), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [61249] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_LT,
    STATE(1905), 1,
      sym_template_argument_list,
    ACTIONS(6896), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6898), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [61315] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7707), 1,
      anon_sym___declspec,
    ACTIONS(7713), 1,
      anon_sym___launch_bounds__,
    STATE(1719), 1,
      sym_alignas_qualifier,
    ACTIONS(61), 2,
      anon_sym___inline,
      anon_sym___forceinline,
    ACTIONS(6099), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6101), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(8040), 6,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
    ACTIONS(7705), 7,
      anon_sym_extern,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
    STATE(3561), 8,
      sym__declaration_modifiers,
      sym_attribute_specifier,
      sym_attribute_declaration,
      sym_ms_declspec_modifier,
      sym_storage_class_specifier,
      sym_type_qualifier,
      sym_launch_bounds,
      aux_sym__declaration_specifiers_repeat1,
    ACTIONS(7300), 17,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [61403] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4519), 1,
      anon_sym_LBRACE,
    ACTIONS(8042), 1,
      anon_sym_LT,
    STATE(3760), 1,
      sym_template_argument_list,
    ACTIONS(4521), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [61473] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4519), 1,
      anon_sym_LBRACE,
    ACTIONS(5833), 1,
      anon_sym_LT,
    STATE(3759), 1,
      sym_template_argument_list,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [61543] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    ACTIONS(8048), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(8045), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7520), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7518), 33,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [61613] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7839), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3498), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6593), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6595), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [61679] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8055), 1,
      anon_sym_RPAREN,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [61841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5714), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5716), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [61903] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5770), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5772), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [61965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5821), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5823), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [62027] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8139), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(8137), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(8135), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(8133), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [62093] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2880), 1,
      anon_sym_enum,
    ACTIONS(2882), 1,
      anon_sym_class,
    ACTIONS(2884), 1,
      anon_sym_struct,
    ACTIONS(2886), 1,
      anon_sym_union,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(2914), 1,
      anon_sym_typename,
    ACTIONS(7948), 1,
      sym_identifier,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7952), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4833), 1,
      sym_type_specifier,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2876), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [62199] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7015), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7675), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7677), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7679), 1,
      anon_sym_PIPE,
    ACTIONS(7683), 1,
      anon_sym_AMP,
    ACTIONS(7689), 1,
      anon_sym_GT_EQ,
    ACTIONS(7691), 1,
      anon_sym_QMARK,
    ACTIONS(7693), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7695), 1,
      anon_sym_or,
    ACTIONS(7697), 1,
      anon_sym_and,
    ACTIONS(7699), 1,
      anon_sym_bitor,
    ACTIONS(7701), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7564), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7568), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7681), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8141), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7566), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7685), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7687), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [62317] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8143), 1,
      anon_sym_LT,
    STATE(3678), 1,
      sym_template_argument_list,
    ACTIONS(6752), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6754), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [62385] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3770), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(8146), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(3766), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(3764), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [62451] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8148), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [62613] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8150), 1,
      anon_sym_LT,
    STATE(3182), 1,
      sym_template_argument_list,
    ACTIONS(6896), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6898), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [62679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5710), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5712), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [62741] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_LT,
    STATE(3338), 1,
      sym_template_argument_list,
    ACTIONS(6896), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6898), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [62807] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5686), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [62869] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8159), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(8157), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(8155), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(8153), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [62935] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7883), 1,
      sym_identifier,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7891), 1,
      anon_sym_enum,
    ACTIONS(7893), 1,
      anon_sym_class,
    ACTIONS(7895), 1,
      anon_sym_struct,
    ACTIONS(7897), 1,
      anon_sym_union,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7903), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4368), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [63041] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8161), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6817), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6819), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [63105] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8163), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [63267] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8165), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3498), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6561), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6563), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [63333] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8150), 1,
      anon_sym_LT,
    STATE(991), 1,
      sym_template_argument_list,
    ACTIONS(6896), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6898), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [63399] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3762), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(8168), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(3740), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(3738), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [63465] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4976), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [63571] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8170), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [63733] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3736), 1,
      sym_identifier,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(3750), 1,
      anon_sym_enum,
    ACTIONS(3752), 1,
      anon_sym_class,
    ACTIONS(3754), 1,
      anon_sym_struct,
    ACTIONS(3756), 1,
      anon_sym_union,
    ACTIONS(3758), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4456), 1,
      sym_type_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [63839] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8178), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(8176), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(8174), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(8172), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [63905] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7909), 1,
      sym_identifier,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7915), 1,
      sym_primitive_type,
    ACTIONS(7917), 1,
      anon_sym_enum,
    ACTIONS(7919), 1,
      anon_sym_class,
    ACTIONS(7921), 1,
      anon_sym_struct,
    ACTIONS(7923), 1,
      anon_sym_union,
    ACTIONS(7925), 1,
      sym_auto,
    ACTIONS(7927), 1,
      anon_sym_decltype,
    ACTIONS(7929), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(4276), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4506), 1,
      sym_type_specifier,
    STATE(5194), 1,
      sym_qualified_type_identifier,
    STATE(5228), 1,
      sym_decltype_auto,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4959), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7913), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5232), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [64011] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7437), 1,
      anon_sym_LBRACK,
    STATE(3717), 1,
      sym_new_declarator,
    ACTIONS(6738), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6740), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [64077] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8180), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [64239] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6748), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6750), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [64317] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8188), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(8186), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(8184), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(8182), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [64383] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7883), 1,
      sym_identifier,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7891), 1,
      anon_sym_enum,
    ACTIONS(7893), 1,
      anon_sym_class,
    ACTIONS(7895), 1,
      anon_sym_struct,
    ACTIONS(7897), 1,
      anon_sym_union,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7903), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3906), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [64489] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8190), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [64651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5730), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5732), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [64713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5686), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [64775] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8198), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(8196), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(8194), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(8192), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [64841] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7883), 1,
      sym_identifier,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7891), 1,
      anon_sym_enum,
    ACTIONS(7893), 1,
      anon_sym_class,
    ACTIONS(7895), 1,
      anon_sym_struct,
    ACTIONS(7897), 1,
      anon_sym_union,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7903), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3808), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [64947] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6687), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6689), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [65023] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8210), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8228), 1,
      anon_sym_or,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(7431), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [65133] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [65195] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8238), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [65357] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5825), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5827), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [65419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5829), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5831), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [65481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5778), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5780), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [65543] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5815), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [65605] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6771), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6773), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [65683] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6784), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6786), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [65761] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8240), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6817), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6819), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [65825] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8210), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8228), 1,
      anon_sym_or,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(7447), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [65935] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7909), 1,
      sym_identifier,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7915), 1,
      sym_primitive_type,
    ACTIONS(7917), 1,
      anon_sym_enum,
    ACTIONS(7919), 1,
      anon_sym_class,
    ACTIONS(7921), 1,
      anon_sym_struct,
    ACTIONS(7923), 1,
      anon_sym_union,
    ACTIONS(7925), 1,
      sym_auto,
    ACTIONS(7927), 1,
      anon_sym_decltype,
    ACTIONS(7929), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(4276), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4313), 1,
      sym_type_specifier,
    STATE(5194), 1,
      sym_qualified_type_identifier,
    STATE(5228), 1,
      sym_decltype_auto,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4959), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7913), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5232), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [66041] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6697), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6699), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [66117] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5844), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [66179] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8242), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [66341] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4726), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [66447] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8244), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [66609] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8210), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8228), 1,
      anon_sym_or,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(7411), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [66719] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8246), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [66881] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8150), 1,
      anon_sym_LT,
    STATE(967), 1,
      sym_template_argument_list,
    ACTIONS(6896), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6898), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [66947] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5692), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5694), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5738), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5740), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67071] = 53,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7663), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7665), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8053), 1,
      anon_sym_COMMA,
    ACTIONS(8057), 1,
      anon_sym_DASH,
    ACTIONS(8059), 1,
      anon_sym_PLUS,
    ACTIONS(8061), 1,
      anon_sym_STAR,
    ACTIONS(8063), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_PERCENT,
    ACTIONS(8067), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8069), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8071), 1,
      anon_sym_PIPE,
    ACTIONS(8073), 1,
      anon_sym_CARET,
    ACTIONS(8075), 1,
      anon_sym_AMP,
    ACTIONS(8077), 1,
      anon_sym_EQ_EQ,
    ACTIONS(8079), 1,
      anon_sym_BANG_EQ,
    ACTIONS(8081), 1,
      anon_sym_GT,
    ACTIONS(8083), 1,
      anon_sym_GT_EQ,
    ACTIONS(8085), 1,
      anon_sym_LT_EQ,
    ACTIONS(8087), 1,
      anon_sym_LT,
    ACTIONS(8089), 1,
      anon_sym_LT_LT,
    ACTIONS(8091), 1,
      anon_sym_GT_GT,
    ACTIONS(8093), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8097), 1,
      anon_sym_STAR_EQ,
    ACTIONS(8099), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(8101), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(8103), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(8105), 1,
      anon_sym_DASH_EQ,
    ACTIONS(8107), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(8109), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(8111), 1,
      anon_sym_AMP_EQ,
    ACTIONS(8113), 1,
      anon_sym_CARET_EQ,
    ACTIONS(8115), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8119), 1,
      anon_sym_or,
    ACTIONS(8121), 1,
      anon_sym_and,
    ACTIONS(8123), 1,
      anon_sym_bitor,
    ACTIONS(8125), 1,
      anon_sym_xor,
    ACTIONS(8127), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_not_eq,
    ACTIONS(8248), 1,
      anon_sym_RPAREN,
    STATE(1368), 1,
      sym__binary_fold_operator,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    STATE(8642), 1,
      sym__fold_operator,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [67233] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5752), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5786), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5788), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67357] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5805), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5807), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5752), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5752), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67543] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8210), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8228), 1,
      anon_sym_or,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    ACTIONS(8250), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8252), 1,
      anon_sym_QMARK,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(7015), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 14,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [67657] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    STATE(4158), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6568), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6570), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67725] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67805] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67883] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 3,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [67987] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4529), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [68093] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6767), 4,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68193] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68289] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68383] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 8,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68473] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 8,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68561] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68647] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 14,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68729] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68813] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6706), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6708), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [68891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8256), 25,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(8254), 29,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym___extension__,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [68953] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6917), 1,
      anon_sym_const,
    ACTIONS(6926), 1,
      anon_sym___attribute,
    ACTIONS(8267), 1,
      anon_sym___attribute__,
    ACTIONS(8270), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8273), 1,
      anon_sym___declspec,
    ACTIONS(8279), 1,
      anon_sym___launch_bounds__,
    STATE(1719), 1,
      sym_alignas_qualifier,
    ACTIONS(6119), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    ACTIONS(6923), 2,
      anon_sym___inline,
      anon_sym___forceinline,
    ACTIONS(8276), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6121), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 6,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
    ACTIONS(8264), 7,
      anon_sym_extern,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
    STATE(3561), 8,
      sym__declaration_modifiers,
      sym_attribute_specifier,
      sym_attribute_declaration,
      sym_ms_declspec_modifier,
      sym_storage_class_specifier,
      sym_type_qualifier,
      sym_launch_bounds,
      aux_sym__declaration_specifiers_repeat1,
    ACTIONS(8258), 17,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [69041] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    STATE(4175), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6585), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6587), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [69109] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4769), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [69215] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5797), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5799), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [69277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5809), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5811), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [69339] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7707), 1,
      anon_sym___declspec,
    ACTIONS(7713), 1,
      anon_sym___launch_bounds__,
    STATE(1719), 1,
      sym_alignas_qualifier,
    ACTIONS(61), 2,
      anon_sym___inline,
      anon_sym___forceinline,
    ACTIONS(6115), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6117), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(8040), 6,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
    ACTIONS(7705), 7,
      anon_sym_extern,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym_thread_local,
      anon_sym___thread,
    STATE(3561), 8,
      sym__declaration_modifiers,
      sym_attribute_specifier,
      sym_attribute_declaration,
      sym_ms_declspec_modifier,
      sym_storage_class_specifier,
      sym_type_qualifier,
      sym_launch_bounds,
      aux_sym__declaration_specifiers_repeat1,
    ACTIONS(7300), 17,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [69427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5774), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5776), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [69489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5853), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5855), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [69551] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7865), 1,
      anon_sym_enum,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(7873), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3965), 1,
      sym_type_specifier,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [69657] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5698), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [69719] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7467), 1,
      anon_sym_EQ,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7966), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7990), 1,
      anon_sym_or,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token2,
  [69831] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5819), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [69893] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5698), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [69955] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2880), 1,
      anon_sym_enum,
    ACTIONS(2882), 1,
      anon_sym_class,
    ACTIONS(2884), 1,
      anon_sym_struct,
    ACTIONS(2886), 1,
      anon_sym_union,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(2914), 1,
      anon_sym_typename,
    ACTIONS(7948), 1,
      sym_identifier,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7952), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4554), 1,
      sym_type_specifier,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2876), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [70061] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7934), 1,
      sym_identifier,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7938), 1,
      anon_sym_enum,
    ACTIONS(7940), 1,
      anon_sym_class,
    ACTIONS(7942), 1,
      anon_sym_struct,
    ACTIONS(7944), 1,
      anon_sym_union,
    ACTIONS(7946), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4647), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [70167] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5766), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5768), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [70229] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6022), 1,
      anon_sym___attribute,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6902), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3578), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4549), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [70329] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6904), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4551), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [70429] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2943), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3788), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3792), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6352), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6354), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [70497] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8210), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8228), 1,
      anon_sym_or,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(7459), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [70607] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    STATE(4180), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6659), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6661), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [70675] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4527), 1,
      sym_type_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [70781] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6748), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6750), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [70859] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6918), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3470), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4540), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [70957] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8210), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8228), 1,
      anon_sym_or,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    ACTIONS(8250), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8252), 1,
      anon_sym_QMARK,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(7463), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 14,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [71071] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7865), 1,
      anon_sym_enum,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(7873), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4285), 1,
      sym_type_specifier,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [71177] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2880), 1,
      anon_sym_enum,
    ACTIONS(2882), 1,
      anon_sym_class,
    ACTIONS(2884), 1,
      anon_sym_struct,
    ACTIONS(2886), 1,
      anon_sym_union,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(2914), 1,
      anon_sym_typename,
    ACTIONS(7948), 1,
      sym_identifier,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7952), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4519), 1,
      sym_type_specifier,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2876), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [71283] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8210), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8228), 1,
      anon_sym_or,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(7467), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [71393] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    STATE(4185), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6601), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6603), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [71461] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5726), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5728), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [71523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5734), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5736), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [71585] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5742), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5744), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [71647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5724), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [71709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5758), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5760), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [71771] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5762), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5764), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [71833] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7865), 1,
      anon_sym_enum,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(7873), 1,
      anon_sym_typename,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4571), 1,
      sym_type_specifier,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [71939] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(8210), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8212), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8214), 1,
      anon_sym_PIPE,
    ACTIONS(8218), 1,
      anon_sym_AMP,
    ACTIONS(8226), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8228), 1,
      anon_sym_or,
    ACTIONS(8230), 1,
      anon_sym_and,
    ACTIONS(8232), 1,
      anon_sym_bitor,
    ACTIONS(8234), 1,
      anon_sym_bitand,
    ACTIONS(8250), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8252), 1,
      anon_sym_QMARK,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8308), 1,
      sym_kernel_call_syntax,
    ACTIONS(7471), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8206), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8216), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8224), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8236), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8208), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8220), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8222), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 14,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [72053] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5754), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5756), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [72115] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5718), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5720), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [72177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5730), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5732), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72239] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72301] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6687), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6689), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72377] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7431), 1,
      anon_sym_EQ,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7966), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7990), 1,
      anon_sym_or,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token2,
  [72489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5825), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5827), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5829), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5831), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72613] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5778), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5780), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72675] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5815), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72737] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6771), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6773), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72815] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6784), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6786), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [72893] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4555), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [72957] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7447), 1,
      anon_sym_EQ,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7966), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7990), 1,
      anon_sym_or,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token2,
  [73069] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6697), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6699), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [73145] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5844), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [73207] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6687), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6689), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
  [73283] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7431), 1,
      anon_sym_EQ,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8306), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8326), 1,
      anon_sym_or,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [73395] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6771), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6773), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [73473] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6784), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6786), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [73551] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7447), 1,
      anon_sym_EQ,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8306), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8326), 1,
      anon_sym_or,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [73663] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6697), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6699), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
  [73739] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7411), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8306), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8326), 1,
      anon_sym_or,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [73851] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7015), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8306), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8326), 1,
      anon_sym_or,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    ACTIONS(8334), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 15,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [73967] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [74047] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [74125] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 2,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token1,
  [74231] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6767), 3,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token1,
  [74333] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [74431] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [74527] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
  [74619] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [74709] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [74795] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [74877] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [74961] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6706), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6708), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [75039] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7459), 1,
      anon_sym_EQ,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8306), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8326), 1,
      anon_sym_or,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [75151] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7463), 1,
      anon_sym_EQ,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8306), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8326), 1,
      anon_sym_or,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    ACTIONS(8334), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 15,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [75267] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7467), 1,
      anon_sym_EQ,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8306), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8326), 1,
      anon_sym_or,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [75379] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7443), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7471), 1,
      anon_sym_EQ,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8306), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8308), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    ACTIONS(8314), 1,
      anon_sym_AMP,
    ACTIONS(8320), 1,
      anon_sym_GT_EQ,
    ACTIONS(8324), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8326), 1,
      anon_sym_or,
    ACTIONS(8328), 1,
      anon_sym_and,
    ACTIONS(8330), 1,
      anon_sym_bitor,
    ACTIONS(8332), 1,
      anon_sym_bitand,
    ACTIONS(8334), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8302), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8312), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8322), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8304), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8316), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8318), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 15,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [75495] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7966), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7990), 1,
      anon_sym_or,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token2,
  [75607] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5692), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5694), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [75669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5738), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5740), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [75731] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3472), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6593), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6595), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [75797] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [75859] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5786), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5788), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [75921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5805), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5807), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [75983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76107] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7960), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7966), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7986), 1,
      anon_sym_QMARK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7990), 1,
      anon_sym_or,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 15,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token2,
  [76223] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    STATE(4260), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6568), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6570), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76291] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76371] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76449] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76555] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 3,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76657] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76755] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76851] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [76943] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77033] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77119] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77201] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77285] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8417), 1,
      sym_kernel_call_syntax,
    ACTIONS(6710), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6748), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6750), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [77363] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6706), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6708), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77441] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5630), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [77503] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    STATE(4079), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6585), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6587), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77571] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5797), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5799), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77633] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5809), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5811), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5774), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5776), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77757] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5853), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5855), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77819] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5698), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77881] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5803), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [77943] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5819), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [78005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5698), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [78067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5766), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5768), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [78129] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7459), 1,
      anon_sym_EQ,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7966), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7968), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7970), 1,
      anon_sym_PIPE,
    ACTIONS(7974), 1,
      anon_sym_AMP,
    ACTIONS(7980), 1,
      anon_sym_GT_EQ,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7990), 1,
      anon_sym_or,
    ACTIONS(7992), 1,
      anon_sym_and,
    ACTIONS(7994), 1,
      anon_sym_bitor,
    ACTIONS(7996), 1,
      anon_sym_bitand,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8478), 1,
      sym_kernel_call_syntax,
    ACTIONS(7962), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7972), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7998), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7964), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7976), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7978), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      aux_sym_kernel_call_syntax_token2,
  [78241] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    STATE(4120), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6659), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6661), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [78309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5803), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [78371] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(7737), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [78432] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8336), 1,
      anon_sym_LT,
    STATE(2147), 1,
      sym_template_argument_list,
    ACTIONS(6896), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6898), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [78497] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6800), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6802), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [78560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6817), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6819), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [78621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5339), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [78682] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6804), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6806), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [78743] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7111), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [78842] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5335), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [78903] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6385), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6383), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [78964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6575), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6577), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [79025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6621), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6623), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [79086] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7128), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [79185] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5684), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [79248] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5317), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [79309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6969), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6971), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [79370] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_LT,
    STATE(1070), 1,
      sym_template_argument_list,
    ACTIONS(6896), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6898), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [79435] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7128), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [79534] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6727), 1,
      sym__declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [79633] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4036), 1,
      anon_sym_EQ,
    ACTIONS(4040), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [79698] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5099), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6364), 1,
      anon_sym_LPAREN2,
    ACTIONS(6367), 1,
      anon_sym_LBRACK,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [79765] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5099), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6364), 1,
      anon_sym_LPAREN2,
    ACTIONS(6367), 1,
      anon_sym_LBRACK,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [79832] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6747), 1,
      sym__declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [79931] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8339), 1,
      sym_identifier,
    ACTIONS(8349), 1,
      sym_primitive_type,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4263), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8346), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3708), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8344), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5158), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(5160), 13,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8341), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [80008] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7266), 1,
      anon_sym_STAR,
    ACTIONS(7268), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6954), 1,
      sym__declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [80107] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8351), 1,
      anon_sym_LT,
    STATE(3971), 1,
      sym_template_argument_list,
    ACTIONS(6752), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6754), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [80174] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7266), 1,
      anon_sym_STAR,
    ACTIONS(7268), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6901), 1,
      sym__declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [80273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6941), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6943), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [80334] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7188), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [80433] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6605), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6607), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [80494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6609), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6611), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [80555] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7214), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [80654] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6631), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6633), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [80715] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8354), 1,
      sym_identifier,
    ACTIONS(8364), 1,
      sym_primitive_type,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4479), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8361), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8359), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5173), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(5175), 13,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8356), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [80792] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5327), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [80853] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7278), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [80952] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7281), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [81051] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7767), 1,
      sym_auto,
    ACTIONS(7769), 1,
      anon_sym_decltype,
    STATE(3796), 1,
      sym_decltype_auto,
    ACTIONS(5673), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5675), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [81118] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8366), 1,
      anon_sym_LT,
    STATE(3971), 1,
      sym_template_argument_list,
    ACTIONS(6775), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6777), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [81185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6817), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6819), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [81246] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6989), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4674), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [81343] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5305), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [81404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6903), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6905), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [81465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6655), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6657), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [81526] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5309), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [81587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5285), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [81648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5313), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [81709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5293), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [81770] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6385), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6383), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [81831] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3830), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3832), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [81892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6627), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6629), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [81953] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5099), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6367), 1,
      anon_sym_LBRACK,
    ACTIONS(6364), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(4012), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [82020] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6969), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6971), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [82081] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6982), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3715), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4606), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [82178] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5099), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6367), 1,
      anon_sym_LBRACK,
    ACTIONS(6364), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(4012), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [82245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3826), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3828), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [82306] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5331), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [82367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6635), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6637), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [82428] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4036), 1,
      anon_sym_EQ,
    ACTIONS(5099), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6364), 1,
      anon_sym_LPAREN2,
    ACTIONS(6367), 1,
      anon_sym_LBRACK,
    ACTIONS(4040), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [82499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7147), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7149), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [82560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6639), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6641), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [82621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5289), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [82682] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7064), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [82781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5289), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [82842] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8375), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    STATE(2201), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5101), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4010), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
  [82913] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5289), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [82974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(1930), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [83035] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [83096] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6734), 1,
      sym__declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [83195] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [83256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [83317] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7205), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [83416] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7512), 1,
      anon_sym_LBRACK,
    STATE(3923), 1,
      sym_new_declarator,
    ACTIONS(6738), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6740), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [83481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [83542] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [83603] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7271), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [83702] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8377), 1,
      sym_literal_suffix,
    ACTIONS(4012), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [83765] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7266), 1,
      anon_sym_STAR,
    ACTIONS(7268), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6947), 1,
      sym__declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [83864] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8336), 1,
      anon_sym_LT,
    STATE(3610), 1,
      sym_template_argument_list,
    ACTIONS(6896), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6898), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [83929] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6597), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6599), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [83990] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [84051] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8379), 1,
      anon_sym_LT,
    STATE(3811), 1,
      sym_template_argument_list,
    ACTIONS(6775), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6777), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [84118] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7111), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [84217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(1926), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [84278] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4555), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [84341] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4555), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [84404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6617), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6619), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [84465] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(2201), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5101), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(6074), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
  [84534] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7498), 1,
      anon_sym_LBRACK,
    STATE(3950), 1,
      sym_new_declarator,
    ACTIONS(6738), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6740), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [84599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5297), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [84660] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8384), 1,
      anon_sym_LPAREN2,
    ACTIONS(8386), 5,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8382), 47,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_explicit,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [84723] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5655), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5657), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [84784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5301), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [84845] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6874), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6876), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [84906] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8388), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6817), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6819), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [84969] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8392), 6,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8390), 47,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_explicit,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [85030] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8394), 1,
      anon_sym_LT,
    STATE(3811), 1,
      sym_template_argument_list,
    ACTIONS(6752), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6754), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [85097] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6712), 1,
      sym__declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [85196] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5686), 5,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5684), 47,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [85259] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6773), 1,
      sym__declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [85358] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6403), 1,
      anon_sym_EQ,
    ACTIONS(6405), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [85423] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7064), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [85522] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6702), 1,
      sym__declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [85621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5309), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [85681] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6771), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6773), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [85757] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8397), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8399), 1,
      anon_sym_and,
    ACTIONS(5860), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5862), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [85821] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6784), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6786), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [85897] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8401), 1,
      sym_identifier,
    STATE(3889), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(5129), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5131), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6002), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(6004), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
  [85965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7039), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7041), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [86025] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8403), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6817), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6819), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [86087] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7110), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4707), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [86183] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7045), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [86243] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7053), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [86303] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    STATE(1719), 1,
      sym_alignas_qualifier,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4442), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6000), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(8413), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
    ACTIONS(8411), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [86377] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8415), 1,
      anon_sym_LT,
    STATE(3759), 1,
      sym_template_argument_list,
    ACTIONS(6896), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6898), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [86441] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8418), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6817), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6819), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [86503] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7447), 1,
      anon_sym_EQ,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8424), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [86611] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6697), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6699), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [86685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7055), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7057), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [86745] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8448), 1,
      sym_identifier,
    STATE(3830), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(6533), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(6535), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6004), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6002), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [86813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7071), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7073), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [86873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5844), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [86933] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6169), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [86993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(7737), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [87053] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87113] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8452), 1,
      anon_sym___asm,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4778), 1,
      sym_decltype_auto,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6613), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4381), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [87207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5718), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5720), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6888), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87447] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3805), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8458), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5133), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5135), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [87511] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7129), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87571] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7143), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7145), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87631] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    ACTIONS(8463), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4778), 1,
      sym_decltype_auto,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6639), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4384), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [87725] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7079), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7081), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87785] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87845] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6800), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6802), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [87907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7001), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [87967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6888), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88147] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7009), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88207] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8465), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    STATE(3820), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8035), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(4010), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [88277] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3805), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8467), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5900), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5898), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [88341] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4562), 1,
      anon_sym_LBRACK,
    ACTIONS(4557), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4560), 4,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
    ACTIONS(4553), 45,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___device__,
      anon_sym___host__,
      anon_sym___global__,
      anon_sym___forceinline__,
      anon_sym___noinline__,
      anon_sym_virtual,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_operator,
      anon_sym___launch_bounds__,
  [88405] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3805), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8467), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5986), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5984), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [88469] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3826), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8469), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5990), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5988), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [88533] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3829), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8471), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5919), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5917), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [88597] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7027), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7029), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88657] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6475), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7131), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7133), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88779] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3805), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8467), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5982), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5980), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [88843] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7023), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7025), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88903] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6947), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [88963] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3805), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8467), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6012), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6010), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [89027] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8473), 1,
      sym_identifier,
    STATE(3881), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(6533), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(6535), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6018), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6016), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [89095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7069), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [89155] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8415), 1,
      anon_sym_LT,
    STATE(2177), 1,
      sym_template_argument_list,
    ACTIONS(6896), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6898), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [89219] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3843), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8475), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5968), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5966), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [89283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5331), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [89343] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3844), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8477), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5996), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5994), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [89407] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3805), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8467), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6008), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6006), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [89471] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3818), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8479), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5770), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5772), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [89535] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6617), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6619), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [89595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6627), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6629), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [89655] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6635), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6637), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [89715] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6639), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6641), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [89775] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [89835] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3805), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8467), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6026), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6024), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [89899] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3805), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8467), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5964), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5962), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [89963] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8424), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [90071] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3830), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3832), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [90131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7101), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7103), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6979), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6981), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90251] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym_LT,
    STATE(3760), 1,
      sym_template_argument_list,
    ACTIONS(6896), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6898), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [90315] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7107), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90375] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8397), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8399), 1,
      anon_sym_and,
    ACTIONS(8484), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8486), 1,
      anon_sym_or,
    ACTIONS(5871), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5873), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6617), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6619), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [90503] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6627), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6629), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [90563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6635), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6637), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [90623] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6639), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6641), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [90683] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7047), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7049), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1926), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90863] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5630), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90923] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6385), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6383), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [90983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7737), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7735), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
  [91043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6888), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91103] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7101), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3890), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4728), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [91199] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5754), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5756), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91259] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5692), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5694), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91319] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5738), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5740), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91379] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5285), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91439] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3994), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6655), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6657), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [91559] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91619] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5786), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5788), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91679] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8465), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    ACTIONS(5669), 24,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4028), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [91745] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8494), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    ACTIONS(4512), 24,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4519), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [91811] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5805), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5807), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [91931] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6575), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6577), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [91991] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6621), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6623), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [92051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5752), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [92111] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3462), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(6407), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(6409), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6352), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6354), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [92177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7109), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7111), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [92237] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8497), 1,
      sym_identifier,
    STATE(3881), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(8500), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(8503), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5884), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5882), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [92305] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6687), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6689), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [92379] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6955), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6957), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [92439] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6892), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [92499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 10,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DASH_GT,
    ACTIONS(5143), 42,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [92559] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 1,
      anon_sym_EQ,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8424), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [92671] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7003), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7005), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [92731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2060), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [92791] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8506), 1,
      sym_identifier,
    STATE(3958), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(5129), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5131), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6016), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(6018), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
  [92859] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7024), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4735), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [92955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7019), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7021), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93015] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(2654), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6401), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(4010), 39,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [93085] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7059), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7061), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93145] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7063), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7065), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93205] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6951), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6953), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93265] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    STATE(4394), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6568), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6570), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7037), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93391] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5305), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93451] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3826), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3828), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [93511] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6941), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6943), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [93571] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6977), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93631] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5297), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93769] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93845] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6767), 1,
      anon_sym_EQ,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [93949] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    ACTIONS(8463), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4778), 1,
      sym_decltype_auto,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6684), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4392), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [94043] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [94141] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8150), 1,
      anon_sym_LT,
    STATE(1113), 1,
      sym_template_argument_list,
    ACTIONS(6896), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6898), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [94205] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6767), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [94299] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7431), 1,
      anon_sym_EQ,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8424), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [94407] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 4,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
    ACTIONS(6769), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [94497] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 4,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
    ACTIONS(6769), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [94585] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
    ACTIONS(6769), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [94669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [94729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6969), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6971), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [94789] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6022), 1,
      anon_sym___attribute,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7069), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3924), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4680), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [94887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5730), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5732), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [94947] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7097), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7099), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95007] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 9,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6941), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6943), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [95147] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5317), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95207] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
    ACTIONS(6769), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95289] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6903), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6905), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [95349] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7115), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4683), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [95447] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7077), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95507] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6913), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6915), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95567] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8514), 1,
      sym_literal_suffix,
    ACTIONS(4012), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(4004), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [95629] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7147), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7149), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95689] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1930), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95749] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5301), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5313), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95869] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7085), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95929] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5327), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [95989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7093), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7095), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96049] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6706), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6708), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6597), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6599), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [96185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6165), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [96245] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6022), 1,
      anon_sym___attribute,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7103), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3960), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4690), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [96343] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    STATE(4375), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6585), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6587), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96409] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6194), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [96469] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5293), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7019), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7021), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5797), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5799), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96649] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5809), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5811), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7113), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7115), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96769] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6959), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6961), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96829] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5825), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5827), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96889] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5774), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5776), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [96949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5853), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5855), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [97009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6903), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6905), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [97069] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5698), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [97129] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5803), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [97189] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6804), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6806), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [97249] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7080), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3785), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4701), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [97345] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6655), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6657), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [97405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5819), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [97465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5698), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [97525] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8522), 1,
      sym_identifier,
    STATE(3958), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(8525), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(8528), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5882), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(5884), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
  [97593] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5766), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5768), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [97653] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7112), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4678), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [97751] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7459), 1,
      anon_sym_EQ,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8424), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [97859] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    STATE(4306), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6659), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6661), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [97925] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    ACTIONS(8452), 1,
      anon_sym___asm,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6637), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4309), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [98019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6874), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6876), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [98079] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    ACTIONS(8463), 1,
      anon_sym___asm,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6620), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4352), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [98173] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6817), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6819), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [98233] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6995), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6997), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [98293] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [98353] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3830), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3832), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [98413] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6874), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6876), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [98473] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6800), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6802), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [98535] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6597), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6599), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [98595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7017), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [98655] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7011), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7013), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [98715] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7463), 1,
      anon_sym_EQ,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8424), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [98827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5829), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5831), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [98887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6907), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6909), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [98947] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6605), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6607), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [99007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5778), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5780), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6575), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6577), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [99127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6609), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6611), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [99187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6621), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6623), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [99247] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7467), 1,
      anon_sym_EQ,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8424), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [99355] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    STATE(4340), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6601), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6603), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6631), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6633), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [99481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6161), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [99541] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5726), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5728), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99601] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5734), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5736), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99661] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7119), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7121), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99721] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5742), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5744), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5724), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5758), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5760), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99901] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5762), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5764), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [99961] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7125), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [100021] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5815), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [100081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7031), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7033), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [100141] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3826), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3828), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [100201] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    ACTIONS(8452), 1,
      anon_sym___attribute,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4778), 1,
      sym_decltype_auto,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6678), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4364), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [100295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5686), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [100355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6804), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6806), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [100415] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7135), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7137), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [100475] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8531), 1,
      sym_literal_suffix,
    ACTIONS(4004), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(4012), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
  [100537] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 10,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_DASH_GT,
    ACTIONS(1969), 42,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [100597] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7471), 1,
      anon_sym_EQ,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8051), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8095), 1,
      anon_sym_QMARK,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8424), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8426), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [100709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7139), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7141), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [100769] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5339), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [100829] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6605), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6607), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [100889] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [100949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [101009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [101069] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6609), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6611), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [101129] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6631), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6633), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [101189] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5335), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [101249] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6858), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6860), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [101309] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6767), 1,
      anon_sym_EQ,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    ACTIONS(7617), 1,
      anon_sym_LBRACK,
    ACTIONS(7801), 1,
      anon_sym_DOT_STAR,
    ACTIONS(8117), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8428), 1,
      anon_sym_PIPE,
    ACTIONS(8430), 1,
      anon_sym_CARET,
    ACTIONS(8432), 1,
      anon_sym_AMP,
    ACTIONS(8438), 1,
      anon_sym_GT_EQ,
    ACTIONS(8442), 1,
      anon_sym_bitor,
    ACTIONS(8444), 1,
      anon_sym_xor,
    ACTIONS(8446), 1,
      anon_sym_bitand,
    STATE(3891), 1,
      sym_argument_list,
    STATE(3893), 1,
      sym_subscript_argument_list,
    STATE(8487), 1,
      sym_kernel_call_syntax,
    ACTIONS(7661), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(8131), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8420), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8440), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8422), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8434), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8436), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [101411] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6491), 1,
      anon_sym_EQ,
    ACTIONS(6468), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [101474] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4396), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4398), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [101533] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4402), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4404), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [101592] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4408), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4410), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [101651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4350), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4352), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [101710] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8533), 1,
      sym_identifier,
    ACTIONS(8535), 1,
      anon_sym_LPAREN2,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(8539), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP,
    ACTIONS(8547), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3290), 1,
      sym__type_declarator,
    STATE(3841), 1,
      sym_pointer_type_declarator,
    STATE(8863), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4024), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4795), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8545), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3839), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [101805] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4356), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4358), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [101864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4366), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4368), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [101923] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8533), 1,
      sym_identifier,
    ACTIONS(8535), 1,
      anon_sym_LPAREN2,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(8539), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP,
    ACTIONS(8547), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3441), 1,
      sym__type_declarator,
    STATE(3841), 1,
      sym_pointer_type_declarator,
    STATE(8863), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4834), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8545), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3839), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [102018] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5125), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(5127), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [102081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7009), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [102140] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8533), 1,
      sym_identifier,
    ACTIONS(8535), 1,
      anon_sym_LPAREN2,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(8539), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP,
    ACTIONS(8547), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3441), 1,
      sym__type_declarator,
    STATE(3841), 1,
      sym_pointer_type_declarator,
    STATE(8863), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4102), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4834), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8545), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3839), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [102235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7125), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [102294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7019), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7021), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [102353] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4330), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4332), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [102412] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(8555), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8557), 1,
      anon_sym_AMP,
    ACTIONS(8561), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(6874), 1,
      sym__type_declarator,
    STATE(8992), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4143), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4781), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [102507] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5339), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [102566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5317), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [102625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6161), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [102684] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6169), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [102743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6817), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6819), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [102802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6194), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [102861] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7079), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7081), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [102920] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6165), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [102979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [103038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7037), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [103097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [103156] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7143), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7145), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [103215] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4555), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [103276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [103335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5339), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [103394] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5317), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [103453] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6955), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6957), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [103512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6977), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [103571] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6959), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6961), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [103630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6817), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6819), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [103689] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7131), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7133), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [103748] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5688), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5690), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [103809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6979), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6981), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [103868] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7045), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [103927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7053), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [103986] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7001), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7009), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104104] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(8569), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8571), 1,
      anon_sym_AMP,
    ACTIONS(8575), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2421), 1,
      sym__type_declarator,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8622), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4084), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4750), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [104199] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6947), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5331), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [104317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3994), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [104376] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7003), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7005), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [104435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5305), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [104494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104671] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7069), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104730] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104789] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104848] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7107), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [104966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4330), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4332), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [105025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7019), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7021), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [105084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7059), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7061), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [105143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5289), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [105202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5289), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [105261] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5289), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [105320] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7055), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7057), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [105379] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7023), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7025), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [105438] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8561), 1,
      sym_primitive_type,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(8579), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8581), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6458), 1,
      sym__type_declarator,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(9172), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4806), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [105533] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(2060), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [105592] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(8569), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8571), 1,
      anon_sym_AMP,
    ACTIONS(8575), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2467), 1,
      sym__type_declarator,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8622), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4804), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [105687] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(8569), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8571), 1,
      anon_sym_AMP,
    ACTIONS(8575), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2423), 1,
      sym__type_declarator,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8622), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4752), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [105782] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8561), 1,
      sym_primitive_type,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(8579), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8581), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6458), 1,
      sym__type_declarator,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(9172), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4122), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4806), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [105877] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4396), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4398), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [105936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4402), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4404), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [105995] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4408), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4410), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [106054] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(8569), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8571), 1,
      anon_sym_AMP,
    ACTIONS(8575), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2423), 1,
      sym__type_declarator,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8622), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4083), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4752), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [106149] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8583), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8585), 1,
      anon_sym_and,
    ACTIONS(5860), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5862), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [106212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6892), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [106271] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6888), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [106330] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8587), 1,
      sym_identifier,
    ACTIONS(8589), 1,
      anon_sym_LPAREN2,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(8593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8595), 1,
      anon_sym_AMP,
    ACTIONS(8599), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3219), 1,
      sym__type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3735), 1,
      sym_pointer_type_declarator,
    STATE(8652), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4205), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4755), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8597), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3725), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [106425] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4350), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4352), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [106484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6888), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [106543] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6888), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [106602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7017), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [106661] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4356), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4358), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [106720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4366), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4368), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [106779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6907), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6909), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [106838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7027), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7029), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [106897] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8533), 1,
      sym_identifier,
    ACTIONS(8535), 1,
      anon_sym_LPAREN2,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(8539), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP,
    ACTIONS(8547), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3317), 1,
      sym__type_declarator,
    STATE(3841), 1,
      sym_pointer_type_declarator,
    STATE(8863), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4763), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8545), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3839), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [106992] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7063), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7065), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5297), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5301), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6858), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6860), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [107228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6913), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6915), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6947), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1930), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7069), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7031), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7033), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [107523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7101), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7103), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [107582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7107), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7047), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7049), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107700] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5309), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5285), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107818] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7147), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7149), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [107877] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5331), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [107936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6385), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6383), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [107995] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7097), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7099), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [108054] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(4454), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8601), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 6,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_COLON,
      anon_sym___asm,
    ACTIONS(6074), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [108123] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8561), 1,
      sym_primitive_type,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(8579), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8581), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6503), 1,
      sym__type_declarator,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(9172), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4748), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [108218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1926), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [108277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7085), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [108336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7077), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [108395] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5305), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [108454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6385), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6383), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [108513] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6830), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4133), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4772), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [108608] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7109), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7111), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [108667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7093), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7095), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [108726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7113), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7115), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [108785] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7129), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [108844] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6857), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4774), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [108939] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6857), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4136), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4774), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [109034] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7765), 1,
      anon_sym_LBRACK,
    STATE(4287), 1,
      sym_new_declarator,
    ACTIONS(6738), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6740), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [109097] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6862), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4777), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [109192] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5661), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [109253] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5661), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [109314] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6613), 1,
      anon_sym_EQ,
    ACTIONS(6615), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [109377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6951), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6953), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [109436] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8609), 1,
      anon_sym_LBRACE,
    ACTIONS(8611), 1,
      anon_sym_COLON,
    STATE(4345), 1,
      sym__enum_base_clause,
    STATE(4460), 1,
      sym_enumerator_list,
    STATE(4671), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6671), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6673), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [109507] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5665), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5667), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [109566] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(8555), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8557), 1,
      anon_sym_AMP,
    ACTIONS(8561), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(6878), 1,
      sym__type_declarator,
    STATE(8992), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4782), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [109661] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(8555), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8557), 1,
      anon_sym_AMP,
    ACTIONS(8561), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(6878), 1,
      sym__type_declarator,
    STATE(8992), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4145), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4782), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [109756] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(8555), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8557), 1,
      anon_sym_AMP,
    ACTIONS(8561), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(6879), 1,
      sym__type_declarator,
    STATE(8992), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4783), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [109851] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [109910] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [109969] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [110028] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7119), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7121), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [110087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6888), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [110146] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6888), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [110205] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7037), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [110264] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7174), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4154), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4790), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [110359] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7145), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4792), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [110454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6886), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6888), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [110513] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6892), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [110572] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    STATE(4286), 1,
      sym_new_declarator,
    ACTIONS(6738), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6740), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [110635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7135), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7137), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [110694] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7139), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7141), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [110753] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8609), 1,
      anon_sym_LBRACE,
    ACTIONS(8611), 1,
      anon_sym_COLON,
    STATE(4421), 1,
      sym__enum_base_clause,
    STATE(4430), 1,
      sym_enumerator_list,
    STATE(4594), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6677), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6679), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [110824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7109), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7111), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [110883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5335), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [110942] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8621), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8623), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8625), 1,
      anon_sym_or,
    ACTIONS(8627), 1,
      anon_sym_and,
    ACTIONS(5871), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5873), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111009] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(8631), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8633), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(7307), 1,
      sym__type_declarator,
    STATE(9229), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4167), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4796), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [111104] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    ACTIONS(4512), 6,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_COLON,
      anon_sym___asm,
    ACTIONS(4519), 42,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [111169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7063), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7065), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [111228] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(8631), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8633), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(7305), 1,
      sym__type_declarator,
    STATE(9229), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4797), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [111323] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(8631), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8633), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(7305), 1,
      sym__type_declarator,
    STATE(9229), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4170), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4797), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [111418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5313), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111477] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(8631), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8633), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(7323), 1,
      sym__type_declarator,
    STATE(9229), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4798), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [111572] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5293), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111631] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6858), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6860), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6969), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6971), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111749] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7019), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7021), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7055), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7057), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111867] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7071), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7073), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7129), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [111985] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6951), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6953), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [112044] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6900), 1,
      anon_sym_LT,
    STATE(2196), 1,
      sym_template_argument_list,
    ACTIONS(6896), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6898), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [112107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7097), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7099), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [112166] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5297), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [112225] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5301), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [112284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5327), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [112343] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5309), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [112402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6995), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6997), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [112461] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7011), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7013), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [112520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5285), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [112579] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7039), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7041), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [112638] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6529), 1,
      anon_sym_EQ,
    ACTIONS(6531), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [112701] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7023), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7025), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [112760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7101), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7103), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [112819] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7079), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7081), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [112878] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [112937] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [112996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6913), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6915), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7131), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7133), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113173] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6959), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6961), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113232] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8635), 1,
      sym_identifier,
    ACTIONS(8637), 1,
      anon_sym_LPAREN2,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(8641), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8643), 1,
      anon_sym_AMP,
    ACTIONS(8647), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3423), 1,
      sym__type_declarator,
    STATE(3855), 1,
      sym_pointer_type_declarator,
    STATE(8621), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4766), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8645), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3853), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [113327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6979), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6981), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6907), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6909), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [113445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5335), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113504] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8623), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8627), 1,
      anon_sym_and,
    ACTIONS(5860), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5862), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [113567] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    ACTIONS(5669), 6,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_COLON,
      anon_sym___asm,
    ACTIONS(4028), 42,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [113632] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8587), 1,
      sym_identifier,
    ACTIONS(8589), 1,
      anon_sym_LPAREN2,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(8593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8595), 1,
      anon_sym_AMP,
    ACTIONS(8599), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3225), 1,
      sym__type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3735), 1,
      sym_pointer_type_declarator,
    STATE(8652), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4799), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8597), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3725), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [113727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5313), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113786] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8635), 1,
      sym_identifier,
    ACTIONS(8637), 1,
      anon_sym_LPAREN2,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(8641), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8643), 1,
      anon_sym_AMP,
    ACTIONS(8647), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3286), 1,
      sym__type_declarator,
    STATE(3855), 1,
      sym_pointer_type_declarator,
    STATE(8621), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4759), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8645), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3853), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [113881] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5293), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3994), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [113999] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8635), 1,
      sym_identifier,
    ACTIONS(8637), 1,
      anon_sym_LPAREN2,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(8641), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8643), 1,
      anon_sym_AMP,
    ACTIONS(8647), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3286), 1,
      sym__type_declarator,
    STATE(3855), 1,
      sym_pointer_type_declarator,
    STATE(8621), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4199), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4759), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8645), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3853), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [114094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7003), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7005), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [114153] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8649), 1,
      anon_sym_COMMA,
    ACTIONS(8651), 1,
      anon_sym_RBRACK,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [114216] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6537), 1,
      anon_sym_COMMA,
    ACTIONS(6539), 1,
      anon_sym_RBRACK,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [114279] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7143), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7145), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [114338] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4555), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [114399] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8587), 1,
      sym_identifier,
    ACTIONS(8589), 1,
      anon_sym_LPAREN2,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(8593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8595), 1,
      anon_sym_AMP,
    ACTIONS(8599), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3225), 1,
      sym__type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3735), 1,
      sym_pointer_type_declarator,
    STATE(8652), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4219), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4799), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8597), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3725), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [114494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6995), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6997), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [114553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [114612] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8587), 1,
      sym_identifier,
    ACTIONS(8589), 1,
      anon_sym_LPAREN2,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(8593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8595), 1,
      anon_sym_AMP,
    ACTIONS(8599), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3216), 1,
      sym__type_declarator,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3735), 1,
      sym_pointer_type_declarator,
    STATE(8652), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4776), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8597), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3725), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [114707] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7155), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4228), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4818), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6020), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [114802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [114861] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [114920] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [114979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [115038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4514), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [115097] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8561), 1,
      sym_primitive_type,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(8579), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8581), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6517), 1,
      sym__type_declarator,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(9172), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4081), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4786), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [115192] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7085), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [115251] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7168), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4821), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [115346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7011), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7013), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [115405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(2060), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [115464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6969), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6971), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [115523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5327), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [115582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6977), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [115641] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(4454), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8601), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 6,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_COLON,
      anon_sym___asm,
    ACTIONS(4010), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [115710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7017), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [115769] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6955), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6957), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [115828] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7027), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7029), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [115887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1930), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [115946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7829), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7827), 38,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [116005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7039), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7041), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [116064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1926), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [116123] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7031), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7033), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [116182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7047), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7049), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [116241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7045), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [116300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7907), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7905), 38,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [116359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7077), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [116418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7147), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7149), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [116477] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7093), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7095), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [116536] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7113), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7115), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [116595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7053), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [116654] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7019), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7021), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [116713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7059), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7061), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [116772] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4036), 1,
      anon_sym_EQ,
    ACTIONS(4067), 1,
      anon_sym_SEMI,
    ACTIONS(5099), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6364), 1,
      anon_sym_LPAREN2,
    ACTIONS(6367), 1,
      anon_sym_LBRACK,
    ACTIONS(4040), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4004), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
  [116843] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8635), 1,
      sym_identifier,
    ACTIONS(8637), 1,
      anon_sym_LPAREN2,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(8641), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8643), 1,
      anon_sym_AMP,
    ACTIONS(8647), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(3396), 1,
      sym__type_declarator,
    STATE(3855), 1,
      sym_pointer_type_declarator,
    STATE(8621), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8543), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4207), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4809), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7556), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8645), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3853), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [116938] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8583), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8585), 1,
      anon_sym_and,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_or,
    ACTIONS(5871), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5873), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [117005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7071), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7073), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [117064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7001), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [117123] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7119), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7121), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [117182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7125), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [117241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7135), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7137), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [117300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7139), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(7141), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [117359] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6491), 1,
      anon_sym_EQ,
    ACTIONS(6556), 1,
      anon_sym_COMMA,
    ACTIONS(6558), 1,
      anon_sym_RBRACK,
    ACTIONS(6468), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [117426] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5133), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(8664), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5354), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(5351), 34,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [117490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6169), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [117548] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3794), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(6533), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(6535), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6352), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6354), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [117612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(2060), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [117670] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7113), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7115), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [117728] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(7737), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [117786] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4036), 1,
      anon_sym_EQ,
    ACTIONS(4067), 1,
      anon_sym_SEMI,
    ACTIONS(4040), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4004), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [117850] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7177), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4271), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4887), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6020), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [117944] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7556), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(3268), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7206), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7558), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7560), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3085), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4889), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [118038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6194), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [118096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6165), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [118154] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3782), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(5129), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5131), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(6352), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6354), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [118218] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8377), 1,
      sym_literal_suffix,
    ACTIONS(4012), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [118278] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8673), 1,
      sym_identifier,
    ACTIONS(8683), 1,
      sym_primitive_type,
    STATE(4488), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4539), 1,
      sym_alignas_qualifier,
    ACTIONS(8680), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4280), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8678), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5160), 9,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(5158), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(8675), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [118352] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    STATE(4003), 1,
      sym_alignas_qualifier,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4562), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4633), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6225), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(8413), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
    ACTIONS(8411), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [118424] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8685), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    ACTIONS(4512), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4519), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
  [118488] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7129), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [118546] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8688), 1,
      sym_identifier,
    ACTIONS(8698), 1,
      sym_primitive_type,
    STATE(4539), 1,
      sym_alignas_qualifier,
    STATE(4657), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8695), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8693), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5175), 9,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(5173), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(8690), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [118620] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8664), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5135), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(5133), 36,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [118682] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7011), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7013), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [118740] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3818), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8479), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5684), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5686), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [118802] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    ACTIONS(8452), 1,
      anon_sym___attribute,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6833), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4489), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [118894] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    ACTIONS(8463), 1,
      anon_sym___attribute,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6849), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4495), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [118986] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6903), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6905), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [119044] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6903), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6905), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [119102] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8375), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    ACTIONS(5669), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4028), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
  [119166] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6161), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [119224] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5659), 24,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5661), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [119282] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6743), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4402), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4996), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [119373] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7097), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7099), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [119430] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6977), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [119487] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(7288), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4934), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [119578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7119), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7121), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [119635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7135), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7137), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [119692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7079), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7081), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [119749] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(7288), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4308), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4934), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [119840] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3994), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [119897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7139), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7141), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [119954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5339), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [120011] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7045), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [120068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6165), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [120125] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8718), 1,
      anon_sym_STAR,
    ACTIONS(8720), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8722), 1,
      anon_sym_AMP,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7276), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4376), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4981), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6020), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [120218] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(7284), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4938), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [120309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7097), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7099), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [120366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [120423] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(7289), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4958), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [120514] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    ACTIONS(8726), 1,
      anon_sym___asm,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6617), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [120599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4004), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [120656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7053), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [120713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7031), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7033), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [120770] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8463), 1,
      anon_sym___attribute,
    ACTIONS(8728), 1,
      sym_auto,
    ACTIONS(8730), 1,
      anon_sym_decltype,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(5090), 1,
      sym_decltype_auto,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6899), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4550), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [120861] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6194), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [120918] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6959), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6961), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [120975] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8732), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8734), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5871), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5873), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7119), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7121), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121093] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6040), 1,
      anon_sym___attribute__,
    ACTIONS(6042), 1,
      anon_sym___attribute,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(8736), 1,
      anon_sym_COLON,
    STATE(2125), 1,
      sym_attribute_specifier,
    STATE(2281), 1,
      sym__enum_base_clause,
    STATE(2307), 1,
      sym_enumerator_list,
    ACTIONS(6671), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(6673), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
  [121164] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6040), 1,
      anon_sym___attribute__,
    ACTIONS(6042), 1,
      anon_sym___attribute,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(8736), 1,
      anon_sym_COLON,
    STATE(2145), 1,
      sym_attribute_specifier,
    STATE(2278), 1,
      sym__enum_base_clause,
    STATE(2291), 1,
      sym_enumerator_list,
    ACTIONS(6677), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(6679), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
  [121235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7023), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7025), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5313), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7125), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7027), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7029), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [121463] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5293), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6995), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6997), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [121577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5327), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6947), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121691] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7069), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [121748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7023), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7025), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [121805] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    ACTIONS(8740), 1,
      sym_auto,
    ACTIONS(8742), 1,
      anon_sym_decltype,
    STATE(4532), 1,
      sym_new_declarator,
    STATE(4616), 1,
      sym_decltype_auto,
    STATE(4323), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6307), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [121878] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7055), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7057), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [121935] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7125), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [121992] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7071), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7073), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [122049] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7101), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7103), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [122106] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6951), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6953), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [122163] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5933), 1,
      anon_sym___asm,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6623), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [122248] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8452), 1,
      anon_sym___attribute,
    ACTIONS(8728), 1,
      sym_auto,
    ACTIONS(8730), 1,
      anon_sym_decltype,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(5090), 1,
      sym_decltype_auto,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6897), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4548), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [122339] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7107), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [122396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6947), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [122453] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6995), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6997), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [122510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7069), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [122567] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7113), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7115), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [122624] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7003), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7005), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [122681] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4539), 1,
      sym_alignas_qualifier,
    ACTIONS(8747), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5112), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5110), 15,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8744), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [122746] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8609), 1,
      anon_sym_LBRACE,
    STATE(4436), 1,
      sym_enumerator_list,
    STATE(4676), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6185), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6183), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [122811] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [122868] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    ACTIONS(8740), 1,
      sym_auto,
    ACTIONS(8742), 1,
      anon_sym_decltype,
    STATE(4504), 1,
      sym_new_declarator,
    STATE(4616), 1,
      sym_decltype_auto,
    STATE(4397), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6350), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [122941] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6161), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [122998] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7011), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7013), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [123055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5335), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [123112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7101), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7103), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [123169] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    ACTIONS(8752), 1,
      anon_sym___asm,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6662), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [123254] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    ACTIONS(8740), 1,
      sym_auto,
    ACTIONS(8742), 1,
      anon_sym_decltype,
    STATE(4526), 1,
      sym_new_declarator,
    STATE(4616), 1,
      sym_decltype_auto,
    STATE(4300), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6325), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [123327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7017), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [123384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7107), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [123441] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6514), 1,
      anon_sym___asm,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6687), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [123526] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7017), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [123583] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    ACTIONS(8762), 1,
      sym_ms_restrict_modifier,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(5563), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7251), 1,
      sym__abstract_declarator,
    ACTIONS(8764), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8766), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4361), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4924), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6020), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [123676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7003), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7005), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [123733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4004), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [123790] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    ACTIONS(8762), 1,
      sym_ms_restrict_modifier,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(5563), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7253), 1,
      sym__abstract_declarator,
    ACTIONS(8764), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8766), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4926), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5391), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(5925), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [123883] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    ACTIONS(8740), 1,
      sym_auto,
    ACTIONS(8742), 1,
      anon_sym_decltype,
    STATE(4498), 1,
      sym_new_declarator,
    STATE(4616), 1,
      sym_decltype_auto,
    STATE(4333), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6334), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [123956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7109), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7111), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [124013] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    ACTIONS(8726), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6681), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [124098] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(4486), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8770), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6074), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [124163] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6169), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [124220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [124277] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4778), 1,
      sym_decltype_auto,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6957), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4552), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [124366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7027), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7029), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [124423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6161), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [124480] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6169), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [124537] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1926), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [124594] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4004), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [124651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7077), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [124708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7055), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7057), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [124765] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8718), 1,
      anon_sym_STAR,
    ACTIONS(8720), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8722), 1,
      anon_sym_AMP,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7283), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4939), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [124858] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7071), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7073), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [124915] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7077), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [124972] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7039), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7041), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [125029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3994), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [125086] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8726), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6632), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [125171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5297), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [125228] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      anon_sym___asm,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6648), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [125313] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8752), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6652), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [125398] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6514), 1,
      anon_sym___asm,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6658), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [125483] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7047), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7049), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [125540] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6590), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [125625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7009), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [125682] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5301), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [125739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7045), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [125796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5317), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [125853] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    ACTIONS(8752), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6607), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [125938] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8734), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5860), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5862), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [125997] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7135), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7137), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [126054] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6959), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6961), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [126111] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7079), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7081), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [126168] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7093), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7095), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [126225] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7053), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [126282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7129), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [126339] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1930), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [126396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6194), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [126453] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6748), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4955), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [126544] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5331), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [126601] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6748), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4409), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4955), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [126692] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    STATE(4765), 1,
      sym_field_declaration_list,
    STATE(5010), 1,
      sym_attribute_specifier,
    STATE(7513), 1,
      sym_virtual_specifier,
    STATE(8346), 1,
      sym_base_class_clause,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6038), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6036), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [126767] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7037), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [126824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6951), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6953), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [126881] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6977), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [126938] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6761), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(3131), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4998), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3129), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [127029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5289), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [127086] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6514), 1,
      anon_sym___attribute,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6622), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [127171] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4778), 1,
      sym_decltype_auto,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6960), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4580), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [127260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7093), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7095), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [127317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7139), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7141), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [127374] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4537), 1,
      sym_alignas_qualifier,
    ACTIONS(8781), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5110), 12,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(5112), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(8778), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [127439] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6955), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6957), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [127496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6165), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [127553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2060), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [127610] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7009), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [127667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7039), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7041), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [127724] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8609), 1,
      anon_sym_LBRACE,
    STATE(4449), 1,
      sym_enumerator_list,
    STATE(4613), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6179), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6177), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [127789] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(2287), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5123), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6074), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [127854] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7047), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7049), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [127911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5309), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [127968] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7001), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [128025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7001), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [128082] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5285), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [128139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7037), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [128196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5305), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
      aux_sym_kernel_call_syntax_token1,
  [128253] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4608), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6218), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6216), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [128313] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(4716), 1,
      sym_new_declarator,
    STATE(4333), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6334), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [128385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6165), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [128441] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(4743), 1,
      sym_new_declarator,
    STATE(4397), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6350), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [128513] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4443), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8790), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5684), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5686), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [128573] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4443), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8790), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5770), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5772), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [128633] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4629), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6279), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6277), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [128693] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    STATE(1719), 1,
      sym_alignas_qualifier,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8413), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
    ACTIONS(8411), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [128759] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4677), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6250), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6248), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [128819] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8792), 1,
      anon_sym_LT,
    STATE(4641), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4670), 1,
      sym_template_argument_list,
    ACTIONS(4002), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8794), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4010), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [128885] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(4641), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6072), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8794), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6074), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [128951] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4636), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6264), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6262), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [129011] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    STATE(1719), 1,
      sym_alignas_qualifier,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8798), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
    ACTIONS(8796), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [129077] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8800), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5900), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5898), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [129137] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4665), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6240), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6238), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [129197] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8800), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6026), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6024), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [129257] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8800), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5964), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5962), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [129317] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4602), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6244), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6242), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [129377] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_identifier,
    ACTIONS(5840), 1,
      sym_primitive_type,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(4651), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8807), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4473), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8805), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5160), 8,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5158), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
    ACTIONS(8802), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [129449] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4610), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6260), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6258), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [129509] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4632), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6268), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6266), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [129569] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6161), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [129625] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7362), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(5221), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [129717] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6194), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [129773] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8800), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5986), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5984), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [129833] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(4722), 1,
      sym_new_declarator,
    STATE(4323), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6307), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [129905] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6987), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4604), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [129993] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4474), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8810), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5990), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5988), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [130053] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4475), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8812), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5919), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5917), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [130113] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4603), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6236), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6234), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [130173] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4593), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6254), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6252), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [130233] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6979), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4623), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [130321] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7317), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4463), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(5076), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6020), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [130413] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7319), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3478), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(5077), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [130505] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(8820), 1,
      anon_sym_COLON,
    STATE(2241), 1,
      sym_attribute_specifier,
    STATE(2856), 1,
      sym__enum_base_clause,
    STATE(2907), 1,
      sym_enumerator_list,
    ACTIONS(6671), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6673), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [130575] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(8820), 1,
      anon_sym_COLON,
    STATE(2246), 1,
      sym_attribute_specifier,
    STATE(2857), 1,
      sym__enum_base_clause,
    STATE(2911), 1,
      sym_enumerator_list,
    ACTIONS(6677), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6679), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [130645] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4619), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6212), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6210), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [130705] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4627), 1,
      sym_attribute_specifier,
    ACTIONS(6042), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6228), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6226), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [130765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6161), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [130821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6165), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [130877] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(4681), 1,
      sym_new_declarator,
    STATE(4300), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6325), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [130949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6169), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
  [131005] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(3129), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4239), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7352), 1,
      sym__abstract_declarator,
    ACTIONS(8290), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8292), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4452), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(5143), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6020), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [131097] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5700), 1,
      sym_identifier,
    ACTIONS(5708), 1,
      sym_primitive_type,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(2205), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8825), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5704), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5175), 8,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5173), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
    ACTIONS(8822), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [131169] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8800), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5982), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5980), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [131229] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8800), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6012), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6010), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [131289] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4445), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8828), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5968), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5966), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [131349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6194), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [131405] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4446), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8830), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5996), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5994), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [131465] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4281), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8800), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6008), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6006), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [131525] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6169), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [131581] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2337), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8832), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6008), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6006), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [131640] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2337), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8832), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5900), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5898), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [131699] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8834), 1,
      anon_sym_LT,
    STATE(4544), 1,
      sym_template_argument_list,
    ACTIONS(5669), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4028), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [131760] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8836), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5135), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5133), 32,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [131819] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8839), 1,
      anon_sym_LT,
    STATE(2406), 1,
      sym_template_argument_list,
    ACTIONS(4512), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4519), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [131880] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2337), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8832), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5986), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5984), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [131939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5770), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5772), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [131994] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5133), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(8836), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5354), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5351), 30,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [132055] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    ACTIONS(8726), 1,
      anon_sym___attribute,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6839), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [132138] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4500), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8842), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5990), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5988), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [132197] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4501), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8844), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5919), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5917), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [132256] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8846), 1,
      anon_sym_LT,
    STATE(4544), 1,
      sym_template_argument_list,
    ACTIONS(4512), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4519), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [132317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5782), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5784), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [132372] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6851), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [132455] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    ACTIONS(8752), 1,
      anon_sym___attribute,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6852), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [132538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5748), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [132593] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(6514), 1,
      anon_sym___attribute,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6853), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [132676] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    STATE(4325), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6601), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6603), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [132737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6941), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6943), 42,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [132792] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2337), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8832), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5982), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5980), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [132851] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2337), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8832), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6012), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6010), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [132910] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4517), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8849), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5968), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5966), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [132969] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4518), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8851), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5996), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5994), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [133028] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    STATE(4331), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6585), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6587), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [133089] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8452), 1,
      anon_sym___attribute,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7082), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4689), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [133178] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    ACTIONS(8728), 1,
      sym_auto,
    ACTIONS(8730), 1,
      anon_sym_decltype,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(5090), 1,
      sym_decltype_auto,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7085), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4729), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [133265] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5710), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5712), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [133320] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8792), 1,
      anon_sym_LT,
    STATE(4670), 1,
      sym_template_argument_list,
    ACTIONS(4512), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4519), 40,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [133381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6874), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6876), 42,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [133436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6804), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6806), 42,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [133491] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    ACTIONS(8728), 1,
      sym_auto,
    ACTIONS(8730), 1,
      anon_sym_decltype,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(5090), 1,
      sym_decltype_auto,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7026), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4719), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [133578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5821), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5823), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [133633] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8853), 1,
      anon_sym_LT,
    STATE(2406), 1,
      sym_template_argument_list,
    ACTIONS(5669), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4028), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [133694] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8792), 1,
      anon_sym_LT,
    STATE(4670), 1,
      sym_template_argument_list,
    ACTIONS(5669), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4028), 40,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [133755] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6153), 1,
      sym_identifier,
    ACTIONS(6157), 1,
      sym_primitive_type,
    STATE(2279), 1,
      sym_alignas_qualifier,
    STATE(4731), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8860), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4522), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8858), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5158), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_GT2,
    ACTIONS(5160), 8,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8855), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [133826] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8853), 1,
      anon_sym_LT,
    STATE(2287), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2406), 1,
      sym_template_argument_list,
    ACTIONS(5123), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4010), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [133891] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2337), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8832), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6026), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6024), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [133950] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2337), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8832), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5964), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5962), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [134009] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8463), 1,
      anon_sym___attribute,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7037), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4682), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [134098] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8867), 1,
      anon_sym___attribute__,
    ACTIONS(8870), 1,
      anon_sym___attribute,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    ACTIONS(8865), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(8863), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [134159] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7067), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4695), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [134246] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6105), 1,
      sym_identifier,
    ACTIONS(6113), 1,
      sym_primitive_type,
    STATE(2279), 1,
      sym_alignas_qualifier,
    STATE(2285), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8876), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2188), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6109), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5173), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_GT2,
    ACTIONS(5175), 8,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8873), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [134317] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8452), 1,
      anon_sym___attribute,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7049), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4714), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [134406] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    STATE(4711), 1,
      sym_field_declaration_list,
    STATE(4775), 1,
      sym_attribute_specifier,
    STATE(7606), 1,
      sym_virtual_specifier,
    STATE(8332), 1,
      sym_base_class_clause,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6038), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6036), 33,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_try,
      anon_sym_requires,
  [134479] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(6078), 1,
      anon_sym_STAR,
    ACTIONS(8881), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8885), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8887), 1,
      anon_sym_AMP,
    ACTIONS(8889), 1,
      anon_sym_EQ,
    STATE(3083), 1,
      sym_parameter_list,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6791), 1,
      sym__declarator,
    STATE(7131), 1,
      sym__abstract_declarator,
    STATE(7300), 1,
      sym_abstract_reference_declarator,
    STATE(8135), 1,
      sym_variadic_declarator,
    STATE(8142), 1,
      sym_variadic_reference_declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(8883), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(7301), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [134588] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    STATE(4292), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6659), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6661), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [134649] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8463), 1,
      anon_sym___attribute,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7107), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4691), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [134738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5714), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5716), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [134793] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7061), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4702), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [134880] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(6084), 1,
      anon_sym_STAR,
    ACTIONS(8881), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8885), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8887), 1,
      anon_sym_AMP,
    ACTIONS(8891), 1,
      anon_sym_EQ,
    STATE(3094), 1,
      sym_parameter_list,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6850), 1,
      sym__declarator,
    STATE(7144), 1,
      sym__abstract_declarator,
    STATE(7378), 1,
      sym_abstract_reference_declarator,
    STATE(8135), 1,
      sym_variadic_declarator,
    STATE(8142), 1,
      sym_variadic_reference_declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(8883), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(7301), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [134989] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8834), 1,
      anon_sym_LT,
    STATE(4486), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4544), 1,
      sym_template_argument_list,
    ACTIONS(8770), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4010), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [135054] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    STATE(4296), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6568), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6570), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [135115] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4482), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8893), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5770), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5772), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [135174] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(6020), 1,
      anon_sym_COLON,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8762), 1,
      sym_ms_restrict_modifier,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(5563), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7502), 1,
      sym__abstract_declarator,
    ACTIONS(8764), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8766), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4564), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(5408), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [135264] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    ACTIONS(8901), 1,
      anon_sym_LBRACE,
    ACTIONS(8903), 1,
      anon_sym_COLON,
    STATE(4692), 1,
      sym__enum_base_clause,
    STATE(4802), 1,
      sym_enumerator_list,
    STATE(5220), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6679), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [135332] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    STATE(4003), 1,
      sym_alignas_qualifier,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8413), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
    ACTIONS(8411), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [135396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(1969), 33,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [135450] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8740), 1,
      sym_auto,
    ACTIONS(8742), 1,
      anon_sym_decltype,
    STATE(4616), 1,
      sym_decltype_auto,
    ACTIONS(5673), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5675), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [135510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(1969), 36,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [135564] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6919), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [135644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5630), 41,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [135698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5143), 36,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [135752] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    ACTIONS(8901), 1,
      anon_sym_LBRACE,
    ACTIONS(8903), 1,
      anon_sym_COLON,
    STATE(4727), 1,
      sym__enum_base_clause,
    STATE(4745), 1,
      sym_enumerator_list,
    STATE(5037), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6673), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [135820] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4553), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4560), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [135874] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4330), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4332), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [135928] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6202), 1,
      anon_sym___attribute__,
    ACTIONS(6204), 1,
      anon_sym___attribute,
    ACTIONS(6362), 1,
      anon_sym_LBRACE,
    ACTIONS(8905), 1,
      anon_sym_COLON,
    STATE(2408), 1,
      sym__enum_base_clause,
    STATE(2434), 1,
      sym_enumerator_list,
    STATE(2494), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6673), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [135996] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6202), 1,
      anon_sym___attribute__,
    ACTIONS(6204), 1,
      anon_sym___attribute,
    ACTIONS(6362), 1,
      anon_sym_LBRACE,
    ACTIONS(8905), 1,
      anon_sym_COLON,
    STATE(2370), 1,
      sym__enum_base_clause,
    STATE(2475), 1,
      sym_enumerator_list,
    STATE(2524), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6679), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [136064] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8726), 1,
      anon_sym___attribute,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6898), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [136146] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6904), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [136228] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8752), 1,
      anon_sym___attribute,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6900), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [136310] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6514), 1,
      anon_sym___attribute,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6905), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [136392] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6928), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [136472] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6956), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [136552] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7159), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4791), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [136638] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4396), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4398), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [136692] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(5661), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [136748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4402), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4404), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [136802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5655), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5657), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [136856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5143), 33,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [136910] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5684), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5686), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [136966] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(5661), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [137022] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    STATE(4003), 1,
      sym_alignas_qualifier,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8798), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
    ACTIONS(8796), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [137086] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    ACTIONS(8909), 1,
      anon_sym_COLON,
    STATE(4601), 1,
      sym__enum_base_clause,
    STATE(4708), 1,
      sym_enumerator_list,
    STATE(4764), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6673), 35,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [137154] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(5925), 1,
      anon_sym_COLON,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8762), 1,
      sym_ms_restrict_modifier,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(5563), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7507), 1,
      sym__abstract_declarator,
    ACTIONS(8764), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8766), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5391), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(5413), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [137244] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(2201), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5101), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6072), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(6074), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [137308] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4350), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4352), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [137362] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4356), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4358), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [137416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4366), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4368), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [137470] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7161), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4789), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [137556] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7154), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4817), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8450), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [137642] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2255), 1,
      sym_decltype_auto,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7163), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4819), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8461), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [137728] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [137798] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6706), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6708), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [137868] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6687), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6689), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
  [137936] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6771), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6773), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [138006] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6784), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6786), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [138076] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6697), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6699), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
  [138144] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    STATE(2201), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(4002), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(5101), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4010), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [138208] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    ACTIONS(8909), 1,
      anon_sym_COLON,
    STATE(4607), 1,
      sym__enum_base_clause,
    STATE(4730), 1,
      sym_enumerator_list,
    STATE(4813), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6679), 35,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [138276] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6955), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [138356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5665), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(5667), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [138410] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5688), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(5690), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [138466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4408), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(4410), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [138520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5805), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5807), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [138573] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 7,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      sym_identifier,
    ACTIONS(6769), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token1,
  [138664] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4330), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4332), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [138717] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4396), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4398), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [138770] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4402), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4404), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [138823] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4408), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4410), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [138876] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4350), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4352), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [138929] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4356), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4358), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [138982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4366), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4368), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [139035] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5774), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5776), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [139088] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5809), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5811), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [139141] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 9,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      sym_identifier,
    ACTIONS(6769), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token1,
  [139230] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 10,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token1,
  [139315] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 13,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token1,
  [139396] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 14,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [139471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5752), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [139524] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5927), 1,
      anon_sym_STAR,
    ACTIONS(5929), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5931), 1,
      anon_sym_AMP,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(8881), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(3007), 1,
      sym_parameter_list,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6940), 1,
      sym__declarator,
    STATE(7149), 1,
      sym__abstract_declarator,
    STATE(8071), 1,
      sym_variadic_declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(8939), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(8937), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [139623] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    STATE(4737), 1,
      sym_enumerator_list,
    STATE(4823), 1,
      sym_attribute_specifier,
    ACTIONS(6185), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6183), 36,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [139686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5786), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5788), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [139739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5797), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5799), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [139792] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6990), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [139871] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 13,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [139950] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6989), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [140029] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    STATE(4684), 1,
      sym_enumerator_list,
    STATE(4832), 1,
      sym_attribute_specifier,
    ACTIONS(6179), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6177), 36,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [140092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5726), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5728), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [140145] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7459), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [140252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5754), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5756), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [140305] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5698), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [140358] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8957), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7463), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 5,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [140469] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5734), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5736), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [140522] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7467), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [140629] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8957), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7471), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 5,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [140740] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5844), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [140793] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7431), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [140900] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7447), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [141007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5803), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5752), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141113] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5752), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141166] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5766), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5768), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141219] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6986), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [141298] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5698), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5815), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141404] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8957), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8959), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(8961), 5,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [141515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5819), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5778), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5780), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5742), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5744), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141674] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5730), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5732), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141727] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    STATE(5002), 1,
      sym_field_declaration_list,
    STATE(5018), 1,
      sym_attribute_specifier,
    STATE(7623), 1,
      sym_virtual_specifier,
    STATE(8270), 1,
      sym_base_class_clause,
    ACTIONS(6038), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6036), 33,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [141798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5718), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5720), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [141851] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8969), 1,
      anon_sym___attribute__,
    ACTIONS(8972), 1,
      anon_sym___attribute,
    STATE(4633), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    ACTIONS(8865), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(8863), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [141910] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4482), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8893), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5684), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5686), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [141967] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7411), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [142074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5758), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5760), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [142127] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8941), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8949), 1,
      anon_sym_or,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8957), 1,
      anon_sym_QMARK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7015), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 5,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [142238] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 16,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6769), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      aux_sym_kernel_call_syntax_token1,
  [142311] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4640), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5684), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8975), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5686), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [142368] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5900), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8977), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5898), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [142425] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5986), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8977), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5984), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [142482] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(4498), 1,
      sym_new_declarator,
    STATE(4333), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(6334), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [142551] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4650), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5990), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5988), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [142608] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4654), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5919), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8981), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5917), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [142665] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5688), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(5690), 40,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [142720] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4778), 1,
      sym_decltype_auto,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7180), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4885), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8450), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [142805] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(4778), 1,
      sym_decltype_auto,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7193), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4888), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8461), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [142890] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5686), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [142943] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8943), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8951), 1,
      anon_sym_and,
    ACTIONS(8953), 1,
      anon_sym_xor,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6767), 3,
      aux_sym_preproc_elif_token1,
      anon_sym_or,
      sym_identifier,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token1,
  [143044] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5982), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8977), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5980), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [143101] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1845), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5133), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(5600), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5354), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
    ACTIONS(5351), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [143160] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5762), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5764), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [143213] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(4532), 1,
      sym_new_declarator,
    STATE(4323), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(6307), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [143282] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6012), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8977), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6010), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [143339] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4659), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5968), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8983), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5966), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [143396] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4660), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5996), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8985), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5994), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [143453] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6008), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8977), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6006), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [143510] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4640), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5770), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8975), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5772), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [143567] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6026), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8977), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6024), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [143624] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4484), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5964), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(8977), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5962), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [143681] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5825), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5827), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [143734] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8953), 1,
      anon_sym_xor,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8945), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 4,
      aux_sym_preproc_elif_token1,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
    ACTIONS(6769), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token1,
  [143831] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5829), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5831), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [143884] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(8919), 1,
      anon_sym_SLASH,
    ACTIONS(8927), 1,
      anon_sym_GT_EQ,
    ACTIONS(8929), 1,
      anon_sym_LT_LT,
    ACTIONS(8931), 1,
      anon_sym_GT_GT,
    ACTIONS(8933), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8935), 1,
      anon_sym_not_eq,
    ACTIONS(8947), 1,
      anon_sym_CARET,
    ACTIONS(8953), 1,
      anon_sym_xor,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8915), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8917), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8921), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(8923), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8925), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6767), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      sym_identifier,
    ACTIONS(6769), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token1,
  [143979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5692), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5694), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [144032] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(5661), 40,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [144087] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5659), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(5661), 40,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [144142] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(4504), 1,
      sym_new_declarator,
    STATE(4397), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(6350), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [144211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5659), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5661), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [144264] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4553), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4560), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [144317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5738), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5740), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [144370] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5665), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(5667), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [144423] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8619), 1,
      anon_sym_LBRACK,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(4526), 1,
      sym_new_declarator,
    STATE(4300), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(6325), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [144492] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6991), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [144571] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(2287), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6072), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5123), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6074), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [144634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5853), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5855), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [144687] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5724), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [144740] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6514), 1,
      anon_sym___attribute,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7121), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [144820] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6771), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
    ACTIONS(6773), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [144888] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7115), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [144968] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(4292), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6659), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6661), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [145026] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    ACTIONS(8752), 1,
      anon_sym___attribute,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7052), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [145106] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6514), 1,
      anon_sym___attribute,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7029), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [145186] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4805), 1,
      sym_attribute_specifier,
    ACTIONS(6260), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6258), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [145244] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8454), 1,
      sym_auto,
    ACTIONS(8456), 1,
      anon_sym_decltype,
    STATE(4778), 1,
      sym_decltype_auto,
    ACTIONS(5673), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5675), 36,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [145302] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4807), 1,
      sym_attribute_specifier,
    ACTIONS(6268), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6266), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [145360] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    ACTIONS(8989), 1,
      anon_sym_LBRACK,
    ACTIONS(8991), 1,
      sym_auto,
    ACTIONS(8993), 1,
      anon_sym_decltype,
    STATE(5082), 1,
      sym_new_declarator,
    STATE(5226), 1,
      sym_decltype_auto,
    STATE(5459), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6307), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [145428] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    ACTIONS(8995), 1,
      anon_sym_LBRACE,
    ACTIONS(8997), 1,
      anon_sym_COLON,
    STATE(4892), 1,
      sym__enum_base_clause,
    STATE(4941), 1,
      sym_enumerator_list,
    STATE(5206), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6673), 35,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [145494] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    ACTIONS(8726), 1,
      anon_sym___attribute,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7105), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [145574] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5933), 1,
      anon_sym___attribute,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7112), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [145654] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    ACTIONS(8752), 1,
      anon_sym___attribute,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7116), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [145734] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    ACTIONS(8901), 1,
      anon_sym_LBRACE,
    STATE(4800), 1,
      sym_enumerator_list,
    STATE(5106), 1,
      sym_attribute_specifier,
    ACTIONS(6179), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6177), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [145796] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    ACTIONS(8995), 1,
      anon_sym_LBRACE,
    ACTIONS(8997), 1,
      anon_sym_COLON,
    STATE(4862), 1,
      sym__enum_base_clause,
    STATE(4929), 1,
      sym_enumerator_list,
    STATE(5094), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6679), 35,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [145862] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    ACTIONS(4512), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4519), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [145920] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7094), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [145998] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8999), 1,
      anon_sym_LT,
    STATE(2287), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2406), 1,
      sym_template_argument_list,
    ACTIONS(4002), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5123), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4010), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [146060] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    ACTIONS(9003), 1,
      anon_sym_LBRACK,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(5117), 1,
      sym_new_declarator,
    STATE(5462), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6305), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6307), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [146128] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6697), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
    ACTIONS(6699), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
  [146194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5659), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5661), 41,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [146246] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7243), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4919), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8450), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [146330] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7110), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [146408] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7075), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [146486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7109), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7111), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [146538] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6784), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
    ACTIONS(6786), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [146606] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    ACTIONS(8989), 1,
      anon_sym_LBRACK,
    ACTIONS(8991), 1,
      sym_auto,
    ACTIONS(8993), 1,
      anon_sym_decltype,
    STATE(5171), 1,
      sym_new_declarator,
    STATE(5226), 1,
      sym_decltype_auto,
    STATE(5423), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6350), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [146674] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4812), 1,
      sym_attribute_specifier,
    ACTIONS(6236), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6234), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [146732] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7122), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [146810] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4822), 1,
      sym_attribute_specifier,
    ACTIONS(6254), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6252), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [146868] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    ACTIONS(9003), 1,
      anon_sym_LBRACK,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(5209), 1,
      sym_new_declarator,
    STATE(5519), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6348), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6350), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [146936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6955), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6957), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [146988] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4827), 1,
      sym_attribute_specifier,
    ACTIONS(6212), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6210), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [147046] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4830), 1,
      sym_attribute_specifier,
    ACTIONS(6228), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6226), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [147104] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9033), 1,
      anon_sym_SEMI,
    ACTIONS(9035), 1,
      anon_sym_QMARK,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7412), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    STATE(8686), 1,
      sym_attribute_specifier,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147218] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    ACTIONS(8726), 1,
      anon_sym___attribute,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7036), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [147298] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8999), 1,
      anon_sym_LT,
    STATE(2406), 1,
      sym_template_argument_list,
    ACTIONS(5669), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4028), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [147356] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(4325), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6601), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6603), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [147414] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
    ACTIONS(6769), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [147482] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9035), 1,
      anon_sym_QMARK,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    ACTIONS(9043), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7416), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    STATE(9248), 1,
      sym_attribute_specifier,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147596] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7084), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [147674] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7031), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(7033), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [147726] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
    ACTIONS(5669), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4028), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [147784] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(4296), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6568), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6570), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [147842] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    ACTIONS(9003), 1,
      anon_sym_LBRACK,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(5014), 1,
      sym_new_declarator,
    STATE(5431), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6325), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [147910] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    ACTIONS(8989), 1,
      anon_sym_LBRACK,
    ACTIONS(8991), 1,
      sym_auto,
    ACTIONS(8993), 1,
      anon_sym_decltype,
    STATE(5080), 1,
      sym_new_declarator,
    STATE(5226), 1,
      sym_decltype_auto,
    STATE(5536), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6334), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [147978] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6687), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
    ACTIONS(6689), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
  [148044] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7245), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4925), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8461), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [148128] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    ACTIONS(8901), 1,
      anon_sym_LBRACE,
    STATE(4815), 1,
      sym_enumerator_list,
    STATE(5017), 1,
      sym_attribute_specifier,
    ACTIONS(6185), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6183), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [148190] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7024), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [148268] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7117), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [148346] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4824), 1,
      sym_attribute_specifier,
    ACTIONS(6218), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6216), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [148404] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2237), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5133), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(6096), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5354), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_GT2,
    ACTIONS(5351), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [148462] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9035), 1,
      anon_sym_QMARK,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    ACTIONS(9045), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7394), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    STATE(9007), 1,
      sym_attribute_specifier,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [148576] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    STATE(2143), 1,
      sym_attribute_specifier,
    STATE(5496), 1,
      sym_field_declaration_list,
    STATE(7690), 1,
      sym_virtual_specifier,
    STATE(8498), 1,
      sym_base_class_clause,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6036), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6038), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [148644] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8999), 1,
      anon_sym_LT,
    STATE(2406), 1,
      sym_template_argument_list,
    ACTIONS(4512), 4,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(4519), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [148702] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7118), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [148780] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4762), 1,
      sym_attribute_specifier,
    ACTIONS(6240), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6238), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [148838] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4749), 1,
      sym_attribute_specifier,
    ACTIONS(6279), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6277), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [148896] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4754), 1,
      sym_attribute_specifier,
    ACTIONS(6250), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6248), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [148954] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    ACTIONS(9003), 1,
      anon_sym_LBRACK,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(5169), 1,
      sym_new_declarator,
    STATE(5508), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6332), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6334), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [149022] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4756), 1,
      sym_attribute_specifier,
    ACTIONS(6264), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6262), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [149080] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6706), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
    ACTIONS(6708), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [149148] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    STATE(4773), 1,
      sym_attribute_specifier,
    ACTIONS(6244), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6242), 37,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [149206] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(4331), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6585), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(6587), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [149264] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    ACTIONS(8989), 1,
      anon_sym_LBRACK,
    ACTIONS(8991), 1,
      sym_auto,
    ACTIONS(8993), 1,
      anon_sym_decltype,
    STATE(5039), 1,
      sym_new_declarator,
    STATE(5226), 1,
      sym_decltype_auto,
    STATE(5489), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6323), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6325), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [149332] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5015), 1,
      sym_attribute_specifier,
    ACTIONS(6254), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6252), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [149389] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5127), 1,
      sym_attribute_specifier,
    ACTIONS(6250), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6248), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [149446] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7667), 1,
      sym_literal_suffix,
    ACTIONS(4012), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4004), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [149499] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8561), 1,
      sym_primitive_type,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(8579), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8581), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(6474), 1,
      sym__type_declarator,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(9172), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [149578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5742), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5744), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [149629] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(8569), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8571), 1,
      anon_sym_AMP,
    ACTIONS(8575), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2423), 1,
      sym__type_declarator,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(8622), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [149708] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5217), 1,
      sym_attribute_specifier,
    ACTIONS(6236), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6234), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [149765] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(8569), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8571), 1,
      anon_sym_AMP,
    ACTIONS(8575), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2467), 1,
      sym__type_declarator,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(8622), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [149844] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5149), 1,
      sym_attribute_specifier,
    ACTIONS(6264), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6262), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [149901] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5724), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [149952] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8587), 1,
      sym_identifier,
    ACTIONS(8589), 1,
      anon_sym_LPAREN2,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(8593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8595), 1,
      anon_sym_AMP,
    ACTIONS(8599), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3225), 1,
      sym__type_declarator,
    STATE(3735), 1,
      sym_pointer_type_declarator,
    STATE(8652), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8597), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3725), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [150031] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5758), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5760), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [150082] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5762), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5764), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [150133] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9047), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5860), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5862), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [150186] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8635), 1,
      sym_identifier,
    ACTIONS(8637), 1,
      anon_sym_LPAREN2,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(8641), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8643), 1,
      anon_sym_AMP,
    ACTIONS(8647), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3423), 1,
      sym__type_declarator,
    STATE(3855), 1,
      sym_pointer_type_declarator,
    STATE(8621), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8645), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3853), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [150265] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5782), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5784), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [150316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(7737), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [150367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5692), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5694), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [150418] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8533), 1,
      sym_identifier,
    ACTIONS(8535), 1,
      anon_sym_LPAREN2,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(8539), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP,
    ACTIONS(8547), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3376), 1,
      sym__type_declarator,
    STATE(3841), 1,
      sym_pointer_type_declarator,
    STATE(8863), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8545), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3839), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [150497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5738), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5740), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [150548] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5027), 1,
      sym_attribute_specifier,
    ACTIONS(6212), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6210), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [150605] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8635), 1,
      sym_identifier,
    ACTIONS(8637), 1,
      anon_sym_LPAREN2,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(8641), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8643), 1,
      anon_sym_AMP,
    ACTIONS(8647), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3368), 1,
      sym__type_declarator,
    STATE(3855), 1,
      sym_pointer_type_declarator,
    STATE(8621), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8645), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3853), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [150684] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5029), 1,
      sym_attribute_specifier,
    ACTIONS(6228), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6226), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [150741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5748), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [150792] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7364), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5218), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8461), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [150875] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9047), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5871), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5873), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [150930] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5752), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [150981] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6857), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [151060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5786), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5788), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [151111] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6862), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [151190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5805), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5807), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [151241] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8587), 1,
      sym_identifier,
    ACTIONS(8589), 1,
      anon_sym_LPAREN2,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(8593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8595), 1,
      anon_sym_AMP,
    ACTIONS(8599), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3214), 1,
      sym__type_declarator,
    STATE(3735), 1,
      sym_pointer_type_declarator,
    STATE(8652), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8597), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3725), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [151320] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6864), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [151399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5844), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [151450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5752), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [151501] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5752), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [151552] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(8555), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8557), 1,
      anon_sym_AMP,
    ACTIONS(8561), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(6878), 1,
      sym__type_declarator,
    STATE(8992), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [151631] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(8555), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8557), 1,
      anon_sym_AMP,
    ACTIONS(8561), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(6879), 1,
      sym__type_declarator,
    STATE(8992), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [151710] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(8555), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8557), 1,
      anon_sym_AMP,
    ACTIONS(8561), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(6880), 1,
      sym__type_declarator,
    STATE(8992), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [151789] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    ACTIONS(4519), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(4512), 36,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_COLON,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
  [151846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5778), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5780), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [151897] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8561), 1,
      sym_primitive_type,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(8579), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8581), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(6458), 1,
      sym__type_declarator,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(9172), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [151976] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    ACTIONS(4028), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(5669), 36,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_COLON,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
  [152033] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5927), 1,
      anon_sym_STAR,
    ACTIONS(5929), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5931), 1,
      anon_sym_AMP,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    STATE(3007), 1,
      sym_parameter_list,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6940), 1,
      sym__declarator,
    STATE(7149), 1,
      sym__abstract_declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(8939), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(8937), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [152126] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7173), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152203] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7145), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152280] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7136), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152357] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7146), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152434] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5829), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5831), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [152485] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9051), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(6941), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(6943), 36,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [152538] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8533), 1,
      sym_identifier,
    ACTIONS(8535), 1,
      anon_sym_LPAREN2,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(8539), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP,
    ACTIONS(8547), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3441), 1,
      sym__type_declarator,
    STATE(3841), 1,
      sym_pointer_type_declarator,
    STATE(8863), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8545), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3839), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152617] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(8631), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8633), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7305), 1,
      sym__type_declarator,
    STATE(9229), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152696] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(8631), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8633), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7323), 1,
      sym__type_declarator,
    STATE(9229), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152775] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(8631), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8633), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7335), 1,
      sym__type_declarator,
    STATE(9229), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152854] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8587), 1,
      sym_identifier,
    ACTIONS(8589), 1,
      anon_sym_LPAREN2,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(8593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8595), 1,
      anon_sym_AMP,
    ACTIONS(8599), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3216), 1,
      sym__type_declarator,
    STATE(3735), 1,
      sym_pointer_type_declarator,
    STATE(8652), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8597), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3725), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [152933] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5174), 1,
      sym_attribute_specifier,
    ACTIONS(6260), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6258), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [152990] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5178), 1,
      sym_attribute_specifier,
    ACTIONS(6268), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6266), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [153047] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5105), 1,
      sym_attribute_specifier,
    ACTIONS(6218), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6216), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [153104] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5815), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153155] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(8569), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8571), 1,
      anon_sym_AMP,
    ACTIONS(8575), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2449), 1,
      sym__type_declarator,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(8622), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [153234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5754), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5756), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153285] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8561), 1,
      sym_primitive_type,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(8579), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8581), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(6503), 1,
      sym__type_declarator,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(9172), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [153364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5718), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5720), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153415] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5730), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5732), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153466] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8635), 1,
      sym_identifier,
    ACTIONS(8637), 1,
      anon_sym_LPAREN2,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(8641), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8643), 1,
      anon_sym_AMP,
    ACTIONS(8647), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3286), 1,
      sym__type_declarator,
    STATE(3855), 1,
      sym_pointer_type_declarator,
    STATE(8621), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8645), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3853), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [153545] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7312), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5219), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8450), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [153628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5714), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5716), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5797), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5799), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153730] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5809), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5811), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5686), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153832] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5124), 1,
      sym_attribute_specifier,
    ACTIONS(6279), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6277), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [153889] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5710), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5712), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [153940] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7160), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8724), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [154017] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7168), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5925), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [154094] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7170), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8750), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [154171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5770), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5772), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154222] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(65), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7171), 1,
      sym__abstract_declarator,
    ACTIONS(7305), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6512), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7300), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [154299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5774), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5776), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154350] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5853), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5855), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154401] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5726), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5728), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154452] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5821), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5823), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154503] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5698), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154554] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5803), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154605] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5035), 1,
      sym_attribute_specifier,
    ACTIONS(6240), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6238), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [154662] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8772), 1,
      anon_sym___attribute__,
    ACTIONS(8774), 1,
      anon_sym___attribute,
    STATE(5249), 1,
      sym_attribute_specifier,
    ACTIONS(6244), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6242), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [154719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5819), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154770] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5698), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5734), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5736), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [154872] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(6448), 1,
      sym_auto,
    ACTIONS(6450), 1,
      anon_sym_decltype,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(2527), 1,
      sym_decltype_auto,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7333), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5109), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8461), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [154955] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8533), 1,
      sym_identifier,
    ACTIONS(8535), 1,
      anon_sym_LPAREN2,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(8539), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP,
    ACTIONS(8547), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(3317), 1,
      sym__type_declarator,
    STATE(3841), 1,
      sym_pointer_type_declarator,
    STATE(8863), 1,
      sym_ms_based_modifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8545), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3839), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [155034] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5825), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5827), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [155085] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5766), 5,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym___asm,
    ACTIONS(5768), 38,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [155136] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7299), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5064), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8450), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [155219] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7465), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [155321] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7017), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [155423] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [155521] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6767), 1,
      anon_sym___attribute,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      aux_sym_kernel_call_syntax_token1,
  [155615] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym___attribute,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [155705] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym___attribute,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      aux_sym_kernel_call_syntax_token1,
  [155793] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym___attribute,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
  [155877] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7471), 1,
      anon_sym___attribute,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9035), 1,
      anon_sym_QMARK,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7473), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [155981] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym___attribute,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [156063] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5317), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [156113] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [156191] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [156289] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [156361] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [156459] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5782), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5784), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [156509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5714), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5716), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [156559] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(7737), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [156609] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [156707] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [156783] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5339), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [156833] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5335), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [156883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5305), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [156933] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [157031] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [157101] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    ACTIONS(8995), 1,
      anon_sym_LBRACE,
    STATE(5003), 1,
      sym_enumerator_list,
    STATE(5040), 1,
      sym_attribute_specifier,
    ACTIONS(6179), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6177), 35,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [157161] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      aux_sym_kernel_call_syntax_token1,
  [157255] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7431), 1,
      anon_sym___attribute,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [157355] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7447), 1,
      anon_sym___attribute,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [157455] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      aux_sym_kernel_call_syntax_token1,
  [157547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5710), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5712), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [157597] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5313), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [157647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5293), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [157697] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [157787] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9035), 1,
      anon_sym_QMARK,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    ACTIONS(9090), 1,
      anon_sym___attribute,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(9088), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [157891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5331), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [157941] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7667), 1,
      sym_literal_suffix,
    ACTIONS(4012), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(4004), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [157993] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9092), 1,
      anon_sym_COMMA,
    ACTIONS(9094), 1,
      anon_sym_SEMI,
    ACTIONS(9096), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7834), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [158101] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5297), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [158151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5301), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [158201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5327), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [158251] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7015), 1,
      anon_sym___attribute,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9035), 1,
      anon_sym_QMARK,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7017), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [158355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5748), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [158405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5309), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [158455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5285), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [158505] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7459), 1,
      anon_sym___attribute,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [158605] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9035), 1,
      anon_sym_QMARK,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    ACTIONS(9100), 1,
      anon_sym___attribute,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(9098), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [158709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5770), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5772), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [158759] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7192), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8724), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [158835] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9102), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9104), 1,
      anon_sym_and,
    ACTIONS(5860), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5862), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [158889] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7206), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [158965] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7208), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8750), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [159041] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7179), 1,
      anon_sym_const,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(4003), 1,
      sym_alignas_qualifier,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7217), 1,
      sym__abstract_declarator,
    ACTIONS(7181), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6512), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7166), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [159117] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7463), 1,
      anon_sym___attribute,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9035), 1,
      anon_sym_QMARK,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7465), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [159221] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(1930), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [159271] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    ACTIONS(8995), 1,
      anon_sym_LBRACE,
    STATE(4967), 1,
      sym_enumerator_list,
    STATE(5150), 1,
      sym_attribute_specifier,
    ACTIONS(6185), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6183), 35,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [159331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5289), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [159381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5289), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [159431] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5821), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5823), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [159481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(5289), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [159531] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [159601] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7411), 1,
      anon_sym___attribute,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [159701] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7473), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [159803] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7467), 1,
      anon_sym___attribute,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9013), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [159903] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6767), 1,
      anon_sym___attribute,
    ACTIONS(9011), 1,
      anon_sym_SLASH,
    ACTIONS(9017), 1,
      anon_sym_PIPE,
    ACTIONS(9021), 1,
      anon_sym_AMP,
    ACTIONS(9027), 1,
      anon_sym_GT_EQ,
    ACTIONS(9029), 1,
      anon_sym_LT_LT,
    ACTIONS(9031), 1,
      anon_sym_GT_GT,
    ACTIONS(9037), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9039), 1,
      anon_sym_bitor,
    ACTIONS(9041), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9007), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9009), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9015), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9019), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9023), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9025), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      aux_sym_kernel_call_syntax_token1,
  [159999] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      aux_sym_kernel_call_syntax_token1,
  [160087] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
  [160171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute,
      anon_sym_DOT,
    ACTIONS(1926), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
      aux_sym_kernel_call_syntax_token1,
  [160221] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [160303] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [160381] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [160453] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [160529] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9102), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9104), 1,
      anon_sym_and,
    ACTIONS(9106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9108), 1,
      anon_sym_or,
    ACTIONS(5871), 16,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5873), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [160587] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9146), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7960), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [160688] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9176), 1,
      anon_sym_RBRACK,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8111), 1,
      aux_sym_subscript_argument_list_repeat1,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [160793] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5655), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5657), 38,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160842] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5081), 1,
      sym_attribute_specifier,
    ACTIONS(6268), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6266), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160897] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5195), 1,
      sym_attribute_specifier,
    ACTIONS(6228), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6226), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160952] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9186), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7984), 1,
      aux_sym_subscript_argument_list_repeat1,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [161057] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9190), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8103), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [161162] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5055), 1,
      sym_attribute_specifier,
    ACTIONS(6250), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6248), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161217] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5059), 1,
      sym_attribute_specifier,
    ACTIONS(6264), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6262), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161272] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7244), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8724), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [161347] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6202), 1,
      anon_sym___attribute__,
    ACTIONS(6204), 1,
      anon_sym___attribute,
    ACTIONS(6362), 1,
      anon_sym_LBRACE,
    ACTIONS(9192), 1,
      anon_sym_COLON,
    STATE(2370), 1,
      sym__enum_base_clause,
    STATE(2475), 1,
      sym_enumerator_list,
    STATE(2524), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6679), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [161410] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9194), 1,
      sym_identifier,
    ACTIONS(9200), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5396), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5947), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5173), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9197), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5175), 6,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5942), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [161475] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9205), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9203), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [161578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5655), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5657), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [161627] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7253), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [161702] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7246), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8750), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [161777] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7254), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6512), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [161852] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9207), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8160), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [161953] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(6078), 1,
      anon_sym_STAR,
    ACTIONS(6080), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6082), 1,
      anon_sym_AMP,
    STATE(3083), 1,
      sym_parameter_list,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6940), 1,
      sym__declarator,
    STATE(7273), 1,
      sym__abstract_declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(8937), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(8939), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [162044] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5038), 1,
      sym_attribute_specifier,
    ACTIONS(6218), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6216), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162099] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8450), 1,
      anon_sym_COLON,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7457), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5388), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [162180] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9209), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8060), 1,
      aux_sym_subscript_argument_list_repeat1,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [162285] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9211), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7906), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [162386] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(9215), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7831), 1,
      aux_sym_generic_expression_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [162491] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(7289), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [162566] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9217), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8110), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [162667] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9219), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7783), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [162768] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6040), 1,
      anon_sym___attribute__,
    ACTIONS(6042), 1,
      anon_sym___attribute,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(9221), 1,
      anon_sym_COLON,
    STATE(2145), 1,
      sym_attribute_specifier,
    STATE(2278), 1,
      sym__enum_base_clause,
    STATE(2291), 1,
      sym_enumerator_list,
    ACTIONS(6677), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6679), 32,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [162831] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(7288), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [162906] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8718), 1,
      anon_sym_STAR,
    ACTIONS(8720), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8722), 1,
      anon_sym_AMP,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7287), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6512), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [162981] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9223), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7932), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [163082] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5148), 1,
      sym_attribute_specifier,
    ACTIONS(6254), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6252), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163137] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9225), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [163240] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9227), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7970), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [163341] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9229), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9231), 1,
      anon_sym_COMMA,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9257), 1,
      anon_sym_QMARK,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    ACTIONS(9267), 1,
      aux_sym_kernel_call_syntax_token2,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8124), 1,
      aux_sym_kernel_call_syntax_repeat1,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [163444] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9096), 1,
      anon_sym_RBRACE,
    ACTIONS(9269), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7834), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [163549] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9271), 1,
      anon_sym_COMMA,
    ACTIONS(9273), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8175), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [163654] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5684), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5686), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [163705] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6040), 1,
      anon_sym___attribute__,
    ACTIONS(6042), 1,
      anon_sym___attribute,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(9221), 1,
      anon_sym_COLON,
    STATE(2125), 1,
      sym_attribute_specifier,
    STATE(2281), 1,
      sym__enum_base_clause,
    STATE(2307), 1,
      sym_enumerator_list,
    ACTIONS(6671), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6673), 32,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [163768] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(9275), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7967), 1,
      aux_sym_generic_expression_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [163873] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(9277), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8043), 1,
      aux_sym_generic_expression_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [163978] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9279), 1,
      anon_sym_COMMA,
    ACTIONS(9281), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7911), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [164083] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(9283), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7894), 1,
      aux_sym_generic_expression_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [164188] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9285), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8004), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [164289] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9287), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8185), 1,
      aux_sym_subscript_argument_list_repeat1,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [164394] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6761), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [164469] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9289), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8019), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [164570] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5088), 1,
      sym_attribute_specifier,
    ACTIONS(6236), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6234), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164625] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(7290), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [164700] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5684), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5686), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164751] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(9291), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8052), 1,
      aux_sym_generic_expression_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [164856] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9293), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8168), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [164961] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9295), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7861), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [165062] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(9297), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8058), 1,
      aux_sym_generic_expression_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [165167] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9299), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7897), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [165268] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9301), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8065), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [165369] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(9303), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7973), 1,
      aux_sym_generic_expression_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [165474] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5043), 1,
      sym_attribute_specifier,
    ACTIONS(6279), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6277), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [165529] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9094), 1,
      anon_sym_SEMI,
    ACTIONS(9305), 1,
      anon_sym_COMMA,
    ACTIONS(9308), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [165634] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(9310), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8152), 1,
      aux_sym_generic_expression_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [165739] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(4454), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(4002), 4,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_COLON,
    ACTIONS(8601), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4010), 29,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [165798] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9312), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8191), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [165899] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9314), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8095), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [166000] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9316), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7919), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [166101] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5204), 1,
      sym_attribute_specifier,
    ACTIONS(6240), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6238), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [166156] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9318), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7909), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [166261] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8461), 1,
      anon_sym_COLON,
    ACTIONS(8786), 1,
      sym_auto,
    ACTIONS(8788), 1,
      anon_sym_decltype,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(2160), 1,
      sym_decltype_auto,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7497), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5412), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [166342] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6202), 1,
      anon_sym___attribute__,
    ACTIONS(6204), 1,
      anon_sym___attribute,
    ACTIONS(6362), 1,
      anon_sym_LBRACE,
    ACTIONS(9192), 1,
      anon_sym_COLON,
    STATE(2408), 1,
      sym__enum_base_clause,
    STATE(2434), 1,
      sym_enumerator_list,
    STATE(2494), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6673), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [166405] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9320), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7855), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [166506] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(9322), 1,
      anon_sym_COLON,
    STATE(2145), 1,
      sym_attribute_specifier,
    STATE(5256), 1,
      sym__enum_base_clause,
    STATE(5498), 1,
      sym_enumerator_list,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6679), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6677), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [166567] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5012), 1,
      sym_attribute_specifier,
    ACTIONS(6244), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6242), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [166622] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8718), 1,
      anon_sym_STAR,
    ACTIONS(8720), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8722), 1,
      anon_sym_AMP,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7283), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [166697] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9324), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7864), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [166802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9326), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7847), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [166907] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9328), 1,
      sym_identifier,
    ACTIONS(9334), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5411), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5912), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4921), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5158), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9331), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5160), 6,
      anon_sym_AMP,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5907), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [166972] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9337), 1,
      anon_sym_COMMA,
    ACTIONS(9339), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7850), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [167077] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9341), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8165), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [167178] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8991), 1,
      sym_auto,
    ACTIONS(8993), 1,
      anon_sym_decltype,
    STATE(5226), 1,
      sym_decltype_auto,
    ACTIONS(5673), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5675), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [167233] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9343), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7845), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [167338] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(6084), 1,
      anon_sym_STAR,
    ACTIONS(6086), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6088), 1,
      anon_sym_AMP,
    STATE(3094), 1,
      sym_parameter_list,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6940), 1,
      sym__declarator,
    STATE(7256), 1,
      sym__abstract_declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    ACTIONS(8937), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(8939), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [167429] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9345), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7930), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [167534] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9347), 1,
      anon_sym_COMMA,
    ACTIONS(9349), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7938), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [167639] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9225), 1,
      anon_sym_SEMI,
    ACTIONS(9351), 1,
      anon_sym_COMMA,
    ACTIONS(9354), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [167744] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9356), 1,
      anon_sym_COMMA,
    ACTIONS(9358), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7905), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [167849] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9360), 1,
      anon_sym_COMMA,
    ACTIONS(9362), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7880), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [167954] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(5410), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6074), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(6072), 33,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [168011] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6748), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [168086] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8728), 1,
      sym_auto,
    ACTIONS(8730), 1,
      anon_sym_decltype,
    STATE(5090), 1,
      sym_decltype_auto,
    ACTIONS(5673), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5675), 35,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168141] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6731), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(3133), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3127), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [168216] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(9322), 1,
      anon_sym_COLON,
    STATE(2125), 1,
      sym_attribute_specifier,
    STATE(5383), 1,
      sym__enum_base_clause,
    STATE(5495), 1,
      sym_enumerator_list,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6673), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6671), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [168277] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9364), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7886), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [168382] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9366), 1,
      anon_sym_COMMA,
    ACTIONS(9368), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(7895), 1,
      aux_sym_initializer_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [168487] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5170), 1,
      sym_attribute_specifier,
    ACTIONS(6212), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6210), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168542] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8963), 1,
      anon_sym___attribute__,
    ACTIONS(8965), 1,
      anon_sym___attribute,
    STATE(5074), 1,
      sym_attribute_specifier,
    ACTIONS(6260), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6258), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168597] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9370), 1,
      anon_sym_RPAREN,
    ACTIONS(9372), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [168702] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9374), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(7987), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [168803] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9376), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8189), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [168908] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    ACTIONS(9378), 1,
      anon_sym_GT2,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8048), 1,
      aux_sym_template_argument_list_repeat1,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [169009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5778), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5780), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [169057] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9408), 1,
      anon_sym_COLON,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [169159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5805), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5807), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [169207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5766), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5768), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5786), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5788), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169303] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token2,
  [169397] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    STATE(5505), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6659), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6661), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [169451] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5774), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5776), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [169499] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9418), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [169601] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5853), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5855), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [169649] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5805), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5807), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169697] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9420), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [169799] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [169895] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(7473), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [169991] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9422), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [170091] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5752), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5698), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [170187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5752), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170235] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9424), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [170335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5803), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [170383] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(7737), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [170431] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5819), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [170479] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6771), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6773), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [170543] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9426), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [170643] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6784), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6786), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [170707] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5698), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [170755] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token2,
  [170849] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5692), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5694), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [170897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5710), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5712), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170945] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5738), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5740), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [170993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5726), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5728), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [171041] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    STATE(5534), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6659), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6661), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [171095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5734), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5736), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [171143] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9428), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [171245] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9430), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [171347] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5742), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5744), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [171395] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6687), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6689), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
  [171457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5766), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5768), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [171505] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9432), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [171607] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [171703] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6771), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6773), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [171767] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6784), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6786), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [171831] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7461), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [171923] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [172019] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6697), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6699), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
  [172081] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9434), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [172183] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7413), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [172275] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5724), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [172323] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9436), 1,
      anon_sym_COMMA,
    ACTIONS(9438), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [172425] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5825), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5827), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [172473] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9440), 1,
      anon_sym_COMMA,
    ACTIONS(9442), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [172575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5758), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5760), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [172623] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5829), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5831), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [172671] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9444), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [172773] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5762), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5764), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [172821] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token2,
  [172915] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7337), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8724), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [172989] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6697), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6699), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [173051] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9446), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [173153] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9229), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9257), 1,
      anon_sym_QMARK,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(7465), 2,
      anon_sym_COMMA,
      aux_sym_kernel_call_syntax_token2,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [173251] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9448), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [173353] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9450), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [173455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5778), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5780), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [173503] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9452), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [173603] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9229), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9257), 1,
      anon_sym_QMARK,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(7017), 2,
      anon_sym_COMMA,
      aux_sym_kernel_call_syntax_token2,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [173701] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5815), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [173749] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5754), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5756), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [173797] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6687), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6689), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [173859] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7319), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [173933] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7320), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6512), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [174007] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token2,
  [174101] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(7473), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [174201] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    STATE(5430), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6601), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6603), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [174255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5718), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5720), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [174303] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    STATE(5488), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6568), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6570), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [174357] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9454), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [174459] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5630), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [174507] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(7465), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [174607] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5714), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5716), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [174655] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6706), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6708), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [174719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5797), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5799), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [174767] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7433), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [174859] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5844), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [174907] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9372), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [175009] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9456), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [175109] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9458), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [175211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5809), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5811), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [175259] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9460), 1,
      anon_sym_COMMA,
    ACTIONS(9462), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [175361] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(7017), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [175457] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9464), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [175559] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9466), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [175661] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [175729] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6769), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [175793] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_or,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [175883] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [175971] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [176057] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9468), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [176153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5726), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5728), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [176201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5734), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5736), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [176249] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [176333] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9229), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9257), 1,
      anon_sym_QMARK,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(7473), 2,
      anon_sym_COMMA,
      aux_sym_kernel_call_syntax_token2,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [176431] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7341), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8750), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [176505] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8141), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [176605] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9470), 1,
      anon_sym_COMMA,
    ACTIONS(9472), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [176707] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9474), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [176809] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [176889] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9476), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [176991] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [177069] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [177143] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    STATE(5531), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6568), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6570), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [177197] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 7,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [177267] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9478), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [177369] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9480), 1,
      anon_sym_COMMA,
    ACTIONS(9482), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [177471] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9484), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [177573] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9486), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [177675] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [177747] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5742), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5744), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [177795] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9488), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [177897] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9203), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [177997] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5722), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5724), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [178045] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(9492), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [178147] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9094), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [178249] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5770), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5772), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [178297] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6769), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [178365] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9494), 1,
      anon_sym_COMMA,
    ACTIONS(9496), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [178467] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [178531] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [178619] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [178705] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [178789] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9498), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [178891] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [178973] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [179051] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [179127] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [179201] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 8,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6769), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [179271] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7362), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5925), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [179345] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [179417] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6771), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6773), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [179481] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6784), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6786), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [179545] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9500), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [179647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5774), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5776), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [179695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5758), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5760), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [179743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5853), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5855), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [179791] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9502), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [179891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5762), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5764), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [179939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5821), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5823), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [179987] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9504), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [180089] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9506), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [180191] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6706), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6708), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [180255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5698), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [180303] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5782), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5784), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [180351] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9508), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [180453] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7449), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [180545] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7469), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [180637] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9510), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [180739] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9512), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [180835] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9512), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [180931] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9512), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [181031] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5730), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5732), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [181079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5686), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [181127] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9514), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [181229] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    STATE(5480), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6601), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6603), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [181283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5801), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5803), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [181331] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    STATE(5532), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6585), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6587), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [181385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5630), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [181433] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6697), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6699), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [181495] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5754), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5756), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [181543] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [181639] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7017), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [181739] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [181807] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5718), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5720), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [181855] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      aux_sym_kernel_call_syntax_token1,
  [181947] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      aux_sym_kernel_call_syntax_token1,
  [182037] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [182125] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      aux_sym_kernel_call_syntax_token1,
  [182211] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
  [182293] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [182373] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [182449] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [182519] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [182593] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5752), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [182641] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9308), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [182741] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7461), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [182837] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7465), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [182937] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [183033] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7473), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [183133] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5686), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [183181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5819), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [183229] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [183325] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6706), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6708), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [183389] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5686), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [183437] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9516), 1,
      anon_sym_COMMA,
    ACTIONS(9518), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [183539] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7449), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [183635] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9512), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [183735] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5696), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5698), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [183783] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9354), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [183883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5692), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5694), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [183931] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9520), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [184031] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5738), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5740), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [184079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5825), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5827), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [184127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5829), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5831), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [184175] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    STATE(5507), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6585), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6587), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [184229] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9426), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [184325] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5752), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [184373] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5746), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5748), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [184421] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8961), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [184521] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5815), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [184569] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5752), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [184617] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9522), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [184719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5797), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5799), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [184767] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7303), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8750), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [184841] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7332), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8724), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [184915] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5809), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5811), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [184963] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3127), 1,
      anon_sym_const,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4537), 1,
      sym_alignas_qualifier,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7313), 1,
      sym__abstract_declarator,
    ACTIONS(8296), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4415), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6512), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8288), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [185037] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9524), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [185139] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7413), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [185235] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7469), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [185331] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9526), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [185433] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5844), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [185481] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9424), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [185581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5730), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5732), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [185629] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(7017), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [185729] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9225), 1,
      anon_sym_COLON,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [185831] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7667), 1,
      sym_literal_suffix,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(4004), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [185881] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5684), 3,
      anon_sym_AMP,
      anon_sym___attribute,
      anon_sym_const,
    ACTIONS(5686), 37,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [185929] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    ACTIONS(8200), 1,
      anon_sym_LBRACK,
    ACTIONS(8202), 1,
      anon_sym_DOT,
    ACTIONS(9110), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9118), 1,
      anon_sym_SLASH,
    ACTIONS(9124), 1,
      anon_sym_PIPE,
    ACTIONS(9128), 1,
      anon_sym_AMP,
    ACTIONS(9136), 1,
      anon_sym_QMARK,
    ACTIONS(9138), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9140), 1,
      anon_sym_bitor,
    ACTIONS(9142), 1,
      anon_sym_bitand,
    STATE(4251), 1,
      sym_argument_list,
    STATE(4252), 1,
      sym_subscript_argument_list,
    STATE(8279), 1,
      sym_kernel_call_syntax,
    ACTIONS(7465), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(8204), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9114), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9120), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9122), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9126), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9134), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9144), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9130), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9132), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [186025] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6687), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6689), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [186087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5750), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5752), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [186135] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7433), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      aux_sym_kernel_call_syntax_token2,
  [186229] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9528), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [186331] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9530), 1,
      anon_sym_COMMA,
    ACTIONS(9532), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [186433] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    ACTIONS(7984), 1,
      anon_sym_LBRACK,
    ACTIONS(8000), 1,
      anon_sym_DOT,
    ACTIONS(9229), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9237), 1,
      anon_sym_SLASH,
    ACTIONS(9243), 1,
      anon_sym_PIPE,
    ACTIONS(9247), 1,
      anon_sym_AMP,
    ACTIONS(9253), 1,
      anon_sym_GT_EQ,
    ACTIONS(9257), 1,
      anon_sym_QMARK,
    ACTIONS(9259), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9261), 1,
      anon_sym_bitor,
    ACTIONS(9263), 1,
      anon_sym_bitand,
    STATE(4074), 1,
      sym_argument_list,
    STATE(4075), 1,
      sym_subscript_argument_list,
    STATE(8218), 1,
      sym_kernel_call_syntax,
    ACTIONS(8002), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(9233), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9235), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9239), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9241), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9245), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9255), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9265), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9534), 2,
      anon_sym_COMMA,
      aux_sym_kernel_call_syntax_token2,
    ACTIONS(9249), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9251), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [186531] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [186599] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6767), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6769), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [186663] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      aux_sym_kernel_call_syntax_token1,
  [186755] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      aux_sym_kernel_call_syntax_token1,
  [186845] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      aux_sym_kernel_call_syntax_token1,
  [186933] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6767), 1,
      anon_sym_PIPE,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      aux_sym_kernel_call_syntax_token1,
  [187019] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      aux_sym_kernel_call_syntax_token1,
  [187101] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6767), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [187181] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [187257] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5786), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5788), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [187305] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
    ACTIONS(6769), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [187375] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9536), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [187477] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9380), 1,
      anon_sym_COMMA,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9538), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [187579] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6767), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6769), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      aux_sym_kernel_call_syntax_token1,
  [187653] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8006), 1,
      anon_sym_COMMA,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9540), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [187755] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9542), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [187854] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    STATE(2124), 1,
      sym_attribute_specifier,
    STATE(5503), 1,
      sym_enumerator_list,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6177), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6179), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [187909] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9544), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188008] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9546), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188107] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8989), 1,
      anon_sym_LBRACK,
    STATE(5399), 1,
      sym_new_declarator,
    ACTIONS(6738), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6740), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [188158] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9548), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188257] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4956), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188356] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9550), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188455] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9552), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188554] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5012), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188653] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9554), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188752] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9556), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188851] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9558), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [188950] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9560), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189049] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9562), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189148] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9564), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189247] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9566), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189346] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9568), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189445] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9570), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9572), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189544] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9574), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189643] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5005), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189742] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9576), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189841] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9578), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [189940] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9580), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190039] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9582), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190138] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9584), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190237] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9586), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190336] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9588), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190435] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9590), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190534] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9592), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190633] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4555), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [190682] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9594), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190781] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9596), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190880] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9598), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [190979] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9600), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191078] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9602), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191177] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9604), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191276] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9606), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191375] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    ACTIONS(9608), 1,
      anon_sym_COLON,
    STATE(4601), 1,
      sym__enum_base_clause,
    STATE(4708), 1,
      sym_enumerator_list,
    STATE(4764), 1,
      sym_attribute_specifier,
    ACTIONS(6671), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(6673), 29,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [191436] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9610), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191535] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    ACTIONS(9608), 1,
      anon_sym_COLON,
    STATE(4607), 1,
      sym__enum_base_clause,
    STATE(4730), 1,
      sym_enumerator_list,
    STATE(4813), 1,
      sym_attribute_specifier,
    ACTIONS(6677), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(6679), 29,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [191596] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9612), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191695] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9614), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191794] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4934), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191893] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9616), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [191992] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9618), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192091] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9620), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192190] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9622), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192289] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9624), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192388] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4562), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4555), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [192437] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9626), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192536] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4832), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192635] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4879), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192734] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9628), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192833] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4838), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [192932] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9630), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193031] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9632), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193130] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9634), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193229] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9636), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193328] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9638), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193427] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9640), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193526] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9642), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193625] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193724] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5099), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6364), 1,
      anon_sym_LPAREN2,
    ACTIONS(6367), 1,
      anon_sym_LBRACK,
    ACTIONS(4012), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(4004), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [193777] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9644), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193876] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4981), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [193975] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9646), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194074] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9205), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194173] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9648), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194272] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9650), 1,
      anon_sym_RBRACE,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194371] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9652), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194470] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9654), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194569] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9656), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194668] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4836), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194767] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9658), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194866] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9660), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [194965] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9662), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195064] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9664), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195163] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9666), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195262] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9668), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195361] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9670), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195460] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9672), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195559] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(9674), 1,
      anon_sym_LPAREN2,
    STATE(2319), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4174), 1,
      sym_argument_list,
    STATE(5419), 1,
      sym_initializer_list,
    ACTIONS(5684), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6246), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5686), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [195618] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9677), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195717] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9679), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195816] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9003), 1,
      anon_sym_LBRACK,
    STATE(5395), 1,
      sym_new_declarator,
    ACTIONS(6738), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6740), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [195867] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4907), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [195966] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9681), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196065] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8298), 1,
      anon_sym_DOT,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_SLASH,
    ACTIONS(9392), 1,
      anon_sym_PIPE,
    ACTIONS(9396), 1,
      anon_sym_AMP,
    ACTIONS(9402), 1,
      anon_sym_GT_EQ,
    ACTIONS(9404), 1,
      anon_sym_LT_LT,
    ACTIONS(9406), 1,
      anon_sym_GT_GT,
    ACTIONS(9410), 1,
      anon_sym_QMARK,
    ACTIONS(9412), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9414), 1,
      anon_sym_bitor,
    ACTIONS(9416), 1,
      anon_sym_bitand,
    ACTIONS(9683), 1,
      anon_sym_COLON,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(8300), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9382), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9384), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9388), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9390), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9394), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9398), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9400), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196164] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9685), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196263] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9687), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196362] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1298), 1,
      sym__fold_operator,
    ACTIONS(9691), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(9689), 25,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [196411] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4844), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196510] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9693), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196609] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9695), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196708] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4989), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196807] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    ACTIONS(9697), 1,
      anon_sym_RBRACK,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [196906] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9699), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197005] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4903), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197104] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4890), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197203] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9701), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197302] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9703), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197401] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9705), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197500] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5003), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197599] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9707), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197698] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9709), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197797] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9711), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197896] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4883), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [197995] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4999), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198094] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9713), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198193] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5010), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198292] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9715), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198391] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9717), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198490] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9719), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198589] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9721), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198688] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5001), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198787] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9723), 1,
      anon_sym_RPAREN,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198886] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4892), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [198985] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9725), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199084] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9727), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199183] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9729), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199282] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9731), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199381] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9733), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199480] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9735), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199579] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9737), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199678] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9739), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199777] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9741), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199876] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9743), 1,
      anon_sym_COMMA,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [199975] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    STATE(2163), 1,
      sym_attribute_specifier,
    STATE(5500), 1,
      sym_enumerator_list,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6183), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6185), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [200030] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9745), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [200129] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    ACTIONS(9747), 1,
      anon_sym_SEMI,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [200228] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4894), 1,
      anon_sym_RBRACK,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9154), 1,
      anon_sym_SLASH,
    ACTIONS(9160), 1,
      anon_sym_PIPE,
    ACTIONS(9164), 1,
      anon_sym_AMP,
    ACTIONS(9170), 1,
      anon_sym_GT_EQ,
    ACTIONS(9172), 1,
      anon_sym_LT_LT,
    ACTIONS(9174), 1,
      anon_sym_GT_GT,
    ACTIONS(9178), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9182), 1,
      anon_sym_bitor,
    ACTIONS(9184), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8301), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9150), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9152), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9156), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9158), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9162), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9166), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9168), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [200327] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5405), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5988), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9749), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5990), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [200377] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8724), 1,
      anon_sym_COLON,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7496), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [200449] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5392), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5966), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9752), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5968), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [200499] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5416), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5994), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9755), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5996), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [200549] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9758), 1,
      sym_ms_restrict_modifier,
    STATE(5563), 1,
      sym_ms_unaligned_ptr_modifier,
    ACTIONS(7518), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(9761), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(9764), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(5391), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(7520), 28,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [200605] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6024), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9767), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6026), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [200655] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5402), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5772), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(5770), 33,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [200703] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    ACTIONS(6691), 1,
      anon_sym_LBRACK,
    ACTIONS(6693), 1,
      anon_sym_DOT,
    ACTIONS(7429), 1,
      aux_sym_kernel_call_syntax_token1,
    ACTIONS(8955), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9058), 1,
      anon_sym_SLASH,
    ACTIONS(9064), 1,
      anon_sym_PIPE,
    ACTIONS(9068), 1,
      anon_sym_AMP,
    ACTIONS(9074), 1,
      anon_sym_GT_EQ,
    ACTIONS(9076), 1,
      anon_sym_LT_LT,
    ACTIONS(9078), 1,
      anon_sym_GT_GT,
    ACTIONS(9080), 1,
      anon_sym_QMARK,
    ACTIONS(9082), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(9084), 1,
      anon_sym_bitor,
    ACTIONS(9086), 1,
      anon_sym_bitand,
    STATE(2794), 1,
      sym_argument_list,
    STATE(2795), 1,
      sym_subscript_argument_list,
    STATE(8514), 1,
      sym_kernel_call_syntax,
    ACTIONS(6695), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8911), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(9054), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9056), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9060), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9062), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9066), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(9070), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(9072), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [200799] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6903), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6905), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [200845] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6006), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9770), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6008), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [200895] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5677), 1,
      sym_auto,
    ACTIONS(5679), 1,
      anon_sym_decltype,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2160), 1,
      sym_decltype_auto,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5574), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(9775), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9773), 8,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [200955] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5677), 1,
      sym_auto,
    ACTIONS(5679), 1,
      anon_sym_decltype,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2160), 1,
      sym_decltype_auto,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5572), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(9779), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9777), 8,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [201015] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6903), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6905), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [201061] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8514), 1,
      sym_literal_suffix,
    ACTIONS(4012), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(4004), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [201109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(7737), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [201155] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5898), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9781), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5900), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [201205] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(4199), 1,
      anon_sym_STAR,
    ACTIONS(4201), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4203), 1,
      anon_sym_AMP,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8937), 1,
      anon_sym_RPAREN,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7109), 1,
      sym__declarator,
    STATE(7354), 1,
      sym__abstract_declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [201291] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(5410), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(4010), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9784), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(4002), 27,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [201347] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5980), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9786), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5982), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [201397] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6010), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9789), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(6012), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [201447] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6340), 1,
      sym_identifier,
    ACTIONS(6344), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(5565), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5409), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5158), 3,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_GT2,
    ACTIONS(5160), 4,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(9792), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [201509] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(5925), 1,
      anon_sym_COLON,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7507), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [201581] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6292), 1,
      sym_identifier,
    ACTIONS(6296), 1,
      sym_primitive_type,
    STATE(1719), 1,
      sym_alignas_qualifier,
    STATE(2638), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5173), 3,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_GT2,
    ACTIONS(5175), 4,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(6294), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [201643] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5984), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9794), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5986), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [201693] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5354), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9797), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5351), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [201743] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8750), 1,
      anon_sym_COLON,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7443), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [201815] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(5702), 1,
      anon_sym_const,
    ACTIONS(6512), 1,
      anon_sym_COLON,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    STATE(1873), 1,
      sym_alignas_qualifier,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7459), 1,
      sym__abstract_declarator,
    ACTIONS(8768), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1738), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8760), 18,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [201887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(7737), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [201933] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8531), 1,
      sym_literal_suffix,
    ACTIONS(4012), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(4004), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [201981] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5962), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9801), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5964), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [202031] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5406), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5917), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(9804), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5919), 29,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [202081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7119), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7121), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [202126] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6959), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6961), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [202171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7045), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [202216] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7053), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [202261] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2060), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [202306] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7093), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7095), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5331), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7079), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7081), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202441] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6951), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6953), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5327), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202531] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7031), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7033), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202576] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4004), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6995), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6997), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202666] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7139), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7141), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [202711] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7011), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7013), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4004), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7125), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3994), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7003), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7005), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7039), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7041), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [202981] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(9809), 1,
      anon_sym___attribute__,
    ACTIONS(9812), 1,
      anon_sym___attribute,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(5578), 1,
      sym_ref_qualifier,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6308), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5846), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [203068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6951), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6953), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203113] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7037), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203158] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5305), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [203203] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7023), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7025), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [203248] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7101), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7103), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [203293] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(5861), 1,
      sym_ms_call_modifier,
    STATE(6065), 1,
      sym__declarator,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7790), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [203374] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7001), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7113), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7115), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [203464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7009), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7023), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7025), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203554] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7109), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7111), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [203599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7017), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6947), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203689] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7069), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203734] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7101), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7103), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7107), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203824] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(5848), 1,
      sym_ms_call_modifier,
    STATE(6088), 1,
      sym__declarator,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7804), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [203905] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6977), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203950] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7031), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7033), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [203995] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7015), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7017), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204040] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7027), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7029), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204085] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7037), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204130] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6977), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204175] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7027), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7029), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [204220] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(5849), 1,
      sym_ms_call_modifier,
    STATE(6103), 1,
      sym__declarator,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(8093), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [204301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1926), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7077), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204391] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(5857), 1,
      sym_ms_call_modifier,
    STATE(6119), 1,
      sym__declarator,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7996), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [204472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5297), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204517] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4197), 1,
      anon_sym_LPAREN2,
    ACTIONS(4199), 1,
      anon_sym_STAR,
    ACTIONS(4201), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4203), 1,
      anon_sym_AMP,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(5937), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7247), 1,
      sym__declarator,
    STATE(7501), 1,
      sym__abstract_declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [204600] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(5882), 1,
      sym_ms_call_modifier,
    STATE(6179), 1,
      sym__declarator,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7776), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [204681] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7045), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7053), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204771] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(5858), 1,
      sym_ms_call_modifier,
    STATE(6132), 1,
      sym__declarator,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7778), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [204852] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7001), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7009), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204942] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5301), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [204987] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6947), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [205032] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7039), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7041), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [205077] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7069), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [205122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7107), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [205167] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6995), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6997), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [205212] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9826), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9828), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5871), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5873), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [205261] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(6701), 1,
      anon_sym_LPAREN2,
    STATE(2189), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3942), 1,
      sym_argument_list,
    STATE(3946), 1,
      sym_initializer_list,
    ACTIONS(5684), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5978), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5686), 26,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
  [205318] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(5859), 1,
      sym_ms_call_modifier,
    STATE(6074), 1,
      sym__declarator,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(8132), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [205399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7047), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7049), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [205444] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4067), 1,
      anon_sym_SEMI,
    ACTIONS(5099), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6364), 1,
      anon_sym_LPAREN2,
    ACTIONS(6367), 1,
      anon_sym_LBRACK,
    ACTIONS(4012), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(4004), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [205497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3994), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [205542] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9830), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9832), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5871), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5873), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [205591] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7135), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7137), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [205636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7139), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7141), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [205681] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5289), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [205726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5335), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [205771] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2115), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6238), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6240), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [205820] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2139), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6242), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6244), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [205869] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2141), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6234), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6236), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [205918] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2136), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6252), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6254), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [205967] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2142), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6210), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6212), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [206016] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2149), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6226), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6228), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [206065] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2122), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6216), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6218), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [206114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7011), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7013), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206159] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2128), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6277), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6279), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [206208] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2121), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6248), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6250), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [206257] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2132), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6262), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6264), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [206306] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2131), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6258), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6260), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [206355] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2120), 1,
      sym_attribute_specifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(6266), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(6268), 31,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [206404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7097), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7099), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7079), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7081), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7055), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7057), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206539] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7071), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7073), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206584] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9828), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5860), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5862), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206631] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7003), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7005), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6959), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6961), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [206721] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4004), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5289), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [206811] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5289), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [206856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7077), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206901] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7109), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7111), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [206946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2060), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [206991] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4004), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [207036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7093), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7095), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [207081] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(6187), 1,
      anon_sym_LPAREN2,
    STATE(2189), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2776), 1,
      sym_argument_list,
    STATE(4315), 1,
      sym_initializer_list,
    ACTIONS(5684), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5978), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5686), 26,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
  [207138] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5313), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207183] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5293), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7047), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7049), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207273] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(9809), 1,
      anon_sym___attribute__,
    ACTIONS(9812), 1,
      anon_sym___attribute,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(5582), 1,
      sym_ref_qualifier,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6299), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5856), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [207360] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5309), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5285), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207450] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4067), 1,
      anon_sym_SEMI,
    ACTIONS(7667), 1,
      sym_literal_suffix,
    ACTIONS(4012), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(4004), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [207499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7113), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7115), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [207544] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1930), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6955), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6957), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [207634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7135), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7137), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [207679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7055), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7057), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207724] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9834), 1,
      anon_sym_COMMA,
    ACTIONS(9836), 1,
      anon_sym_RBRACK,
    ACTIONS(4012), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(4004), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [207773] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7097), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7099), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207818] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6955), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6957), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207863] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7071), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7073), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207908] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7125), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [207953] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7129), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [207998] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7127), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7129), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
      aux_sym_kernel_call_syntax_token1,
  [208043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5339), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [208088] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9832), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5860), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5862), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [208135] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5317), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [208180] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7119), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(7121), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
      aux_sym_kernel_call_syntax_token2,
  [208225] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    STATE(5596), 1,
      sym_ref_qualifier,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6323), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5887), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [208311] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(5867), 1,
      sym_ms_call_modifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7032), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [208389] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4067), 1,
      anon_sym_SEMI,
    ACTIONS(4012), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_DOT,
    ACTIONS(4004), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      aux_sym_kernel_call_syntax_token1,
  [208435] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5593), 1,
      sym_ref_qualifier,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6304), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5893), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [208521] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(5847), 1,
      sym_ms_call_modifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7060), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [208599] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(5854), 1,
      sym_ms_call_modifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7070), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [208677] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(5876), 1,
      sym_ms_call_modifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7025), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [208755] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(5877), 1,
      sym_ms_call_modifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7291), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [208833] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(5592), 1,
      sym_ref_qualifier,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6312), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5886), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [208919] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    ACTIONS(9842), 1,
      anon_sym___asm,
    STATE(5584), 1,
      sym_ref_qualifier,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6328), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5892), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [209005] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(5863), 1,
      sym_ms_call_modifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7123), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [209083] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(5883), 1,
      sym_ms_call_modifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7095), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [209161] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(5594), 1,
      sym_ref_qualifier,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6568), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5888), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [209247] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(5845), 1,
      sym_ms_call_modifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7068), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [209325] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(5597), 1,
      sym_ref_qualifier,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6566), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5899), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [209411] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(5615), 1,
      sym_ref_qualifier,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(6763), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5931), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [209496] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9851), 1,
      sym_identifier,
    ACTIONS(9853), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9857), 1,
      anon_sym_EQ,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6169), 1,
      sym_ms_declspec_modifier,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9855), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6170), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5756), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [209587] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(5619), 1,
      sym_ref_qualifier,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6789), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5923), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [209672] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    ACTIONS(9871), 1,
      anon_sym_requires,
    STATE(5624), 1,
      sym_ref_qualifier,
    STATE(6465), 1,
      sym_trailing_return_type,
    STATE(6554), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5926), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [209757] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7827), 3,
      anon_sym_AMP,
      sym_ms_restrict_modifier,
      anon_sym_const,
    ACTIONS(7829), 32,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [209800] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(5644), 1,
      sym_ref_qualifier,
    STATE(6477), 1,
      sym_trailing_return_type,
    STATE(6550), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5930), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [209885] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1902), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5354), 3,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_GT2,
    ACTIONS(5351), 4,
      anon_sym___attribute__,
      anon_sym___attribute,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5650), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5133), 23,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
  [209934] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7905), 3,
      anon_sym_AMP,
      sym_ms_restrict_modifier,
      anon_sym_const,
    ACTIONS(7907), 32,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [209977] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9871), 1,
      anon_sym_requires,
    STATE(5634), 1,
      sym_ref_qualifier,
    STATE(6465), 1,
      sym_trailing_return_type,
    STATE(6759), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5909), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [210062] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(5603), 1,
      sym_ref_qualifier,
    STATE(6477), 1,
      sym_trailing_return_type,
    STATE(6749), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5916), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [210147] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5402), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5686), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9874), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5684), 27,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [210194] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(5612), 1,
      sym_ref_qualifier,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6518), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5913), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [210279] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5639), 1,
      sym_ref_qualifier,
    STATE(6663), 1,
      sym__function_attributes_end,
    STATE(6792), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5910), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [210364] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1719), 1,
      sym_alignas_qualifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(9879), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9877), 8,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [210415] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9881), 1,
      anon_sym_requires,
    STATE(5604), 1,
      sym_ref_qualifier,
    STATE(6671), 1,
      sym__function_attributes_end,
    STATE(6883), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5912), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [210500] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1719), 1,
      sym_alignas_qualifier,
    ACTIONS(67), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(1698), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(9886), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9884), 8,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(65), 19,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
  [210551] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(5647), 1,
      sym_ref_qualifier,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6492), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5918), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [210636] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5690), 1,
      anon_sym_LBRACE,
    ACTIONS(5684), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5686), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [210682] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1802), 1,
      anon_sym_enum,
    ACTIONS(1804), 1,
      anon_sym_class,
    ACTIONS(1806), 1,
      anon_sym_struct,
    ACTIONS(1808), 1,
      anon_sym_union,
    ACTIONS(1832), 1,
      anon_sym_typename,
    ACTIONS(2276), 1,
      sym_primitive_type,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9853), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9857), 1,
      anon_sym_EQ,
    ACTIONS(9888), 1,
      sym_identifier,
    STATE(2190), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2218), 1,
      sym_type_specifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2625), 1,
      sym_qualified_type_identifier,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    ACTIONS(9855), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(57), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [210766] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(9892), 1,
      anon_sym___attribute__,
    ACTIONS(9895), 1,
      anon_sym___attribute,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9906), 1,
      anon_sym_requires,
    STATE(6167), 1,
      sym_trailing_return_type,
    STATE(6309), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5855), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [210844] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(9809), 1,
      anon_sym___attribute__,
    ACTIONS(9812), 1,
      anon_sym___attribute,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6308), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5846), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [210922] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(5673), 1,
      sym_ref_qualifier,
    STATE(6800), 1,
      sym_trailing_return_type,
    STATE(6805), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5933), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [211006] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(9809), 1,
      anon_sym___attribute__,
    ACTIONS(9812), 1,
      anon_sym___attribute,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6299), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5856), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [211084] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(9892), 1,
      anon_sym___attribute__,
    ACTIONS(9895), 1,
      anon_sym___attribute,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6180), 1,
      sym_trailing_return_type,
    STATE(6300), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5853), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [211162] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9909), 1,
      anon_sym_requires,
    STATE(5700), 1,
      sym_ref_qualifier,
    STATE(6809), 1,
      sym_trailing_return_type,
    STATE(6816), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5938), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [211246] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9906), 1,
      anon_sym_requires,
    ACTIONS(9915), 1,
      anon_sym___asm,
    STATE(6167), 1,
      sym_trailing_return_type,
    STATE(6329), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9912), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5891), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [211323] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    ACTIONS(9909), 1,
      anon_sym_requires,
    STATE(5769), 1,
      sym_ref_qualifier,
    STATE(6788), 1,
      sym__function_attributes_end,
    STATE(6809), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    STATE(5968), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [211406] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(5785), 1,
      sym_ref_qualifier,
    STATE(6752), 1,
      sym__function_attributes_end,
    STATE(6800), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    STATE(5964), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [211489] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6568), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5888), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [211566] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    ACTIONS(9842), 1,
      anon_sym___asm,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6328), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5892), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [211643] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5819), 1,
      sym_ref_qualifier,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6842), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(5951), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [211726] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(5815), 1,
      sym_ref_qualifier,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6737), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5970), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [211809] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6304), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5893), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [211886] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9915), 1,
      anon_sym___asm,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9921), 1,
      anon_sym_requires,
    STATE(6056), 1,
      sym_trailing_return_type,
    STATE(6313), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9912), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5894), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [211963] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9915), 1,
      anon_sym___asm,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6027), 1,
      sym_trailing_return_type,
    STATE(6372), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9912), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5896), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [212040] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6180), 1,
      sym_trailing_return_type,
    STATE(6520), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5895), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [212117] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6566), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5899), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [212194] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9915), 1,
      anon_sym___asm,
    STATE(6180), 1,
      sym_trailing_return_type,
    STATE(6325), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9912), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5890), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [212271] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9906), 1,
      anon_sym_requires,
    STATE(6167), 1,
      sym_trailing_return_type,
    STATE(6575), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5889), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [212348] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6323), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5887), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [212425] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(5823), 1,
      sym_ref_qualifier,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(6714), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5958), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [212508] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6312), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5886), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [212585] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5690), 1,
      anon_sym_LBRACE,
    ACTIONS(5684), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5686), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___global__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym__Nonnull,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym___shared__,
      anon_sym___local__,
      anon_sym___constant__,
      anon_sym___managed__,
      anon_sym___grid_constant__,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [212628] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(5836), 1,
      sym_ref_qualifier,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6894), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(5946), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [212711] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6501), 1,
      sym_trailing_return_type,
    STATE(6726), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5904), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [212787] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9924), 1,
      anon_sym_requires,
    STATE(6596), 1,
      sym__function_attributes_end,
    STATE(6884), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5903), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [212863] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6518), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5913), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [212939] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    ACTIONS(9871), 1,
      anon_sym_requires,
    STATE(6465), 1,
      sym_trailing_return_type,
    STATE(6554), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5926), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [213015] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9927), 1,
      sym_identifier,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9933), 1,
      sym_primitive_type,
    ACTIONS(9935), 1,
      anon_sym_enum,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9947), 1,
      anon_sym_typename,
    STATE(1661), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2339), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(5789), 1,
      sym_argument_list,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9931), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [213095] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9949), 1,
      sym_identifier,
    ACTIONS(9953), 1,
      sym_primitive_type,
    ACTIONS(9955), 1,
      anon_sym_enum,
    ACTIONS(9957), 1,
      anon_sym_typename,
    STATE(1665), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2339), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(5768), 1,
      sym_argument_list,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9951), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [213175] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(7952), 1,
      sym_primitive_type,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9959), 1,
      sym_identifier,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9965), 1,
      anon_sym_enum,
    ACTIONS(9967), 1,
      anon_sym_class,
    ACTIONS(9969), 1,
      anon_sym_struct,
    ACTIONS(9971), 1,
      anon_sym_union,
    ACTIONS(9973), 1,
      anon_sym_typename,
    STATE(2271), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4709), 1,
      sym_type_specifier,
    STATE(5835), 1,
      sym_argument_list,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9963), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [213255] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4455), 1,
      sym_type_specifier,
    STATE(5810), 1,
      sym_argument_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [213335] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9991), 1,
      sym_identifier,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9997), 1,
      sym_primitive_type,
    ACTIONS(9999), 1,
      anon_sym_enum,
    ACTIONS(10001), 1,
      anon_sym_class,
    ACTIONS(10003), 1,
      anon_sym_struct,
    ACTIONS(10005), 1,
      anon_sym_union,
    ACTIONS(10007), 1,
      sym_auto,
    ACTIONS(10009), 1,
      anon_sym_decltype,
    ACTIONS(10011), 1,
      anon_sym_typename,
    STATE(2162), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4330), 1,
      sym_type_specifier,
    STATE(4630), 1,
      sym_decltype_auto,
    STATE(5773), 1,
      sym_argument_list,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4560), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9995), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4648), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [213415] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6027), 1,
      sym_trailing_return_type,
    STATE(6488), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5924), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [213491] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10019), 1,
      sym_identifier,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10025), 1,
      sym_primitive_type,
    ACTIONS(10027), 1,
      anon_sym_enum,
    ACTIONS(10029), 1,
      anon_sym_class,
    ACTIONS(10031), 1,
      anon_sym_struct,
    ACTIONS(10033), 1,
      anon_sym_union,
    ACTIONS(10035), 1,
      sym_auto,
    ACTIONS(10037), 1,
      anon_sym_decltype,
    ACTIONS(10039), 1,
      anon_sym_typename,
    STATE(1709), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3032), 1,
      sym_type_specifier,
    STATE(3327), 1,
      sym_qualified_type_identifier,
    STATE(3401), 1,
      sym_decltype_auto,
    STATE(5811), 1,
      sym_argument_list,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3245), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10023), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3411), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [213571] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6663), 1,
      sym__function_attributes_end,
    STATE(6792), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5910), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [213647] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6650), 1,
      sym_trailing_return_type,
    STATE(6705), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5921), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [213723] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(5850), 1,
      sym_ref_qualifier,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6985), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5973), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [213805] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9991), 1,
      sym_identifier,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9997), 1,
      sym_primitive_type,
    ACTIONS(9999), 1,
      anon_sym_enum,
    ACTIONS(10001), 1,
      anon_sym_class,
    ACTIONS(10003), 1,
      anon_sym_struct,
    ACTIONS(10005), 1,
      anon_sym_union,
    ACTIONS(10007), 1,
      sym_auto,
    ACTIONS(10009), 1,
      anon_sym_decltype,
    ACTIONS(10011), 1,
      anon_sym_typename,
    STATE(2162), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4347), 1,
      sym_type_specifier,
    STATE(4630), 1,
      sym_decltype_auto,
    STATE(5778), 1,
      sym_argument_list,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4560), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9995), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4648), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [213885] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9881), 1,
      anon_sym_requires,
    STATE(6671), 1,
      sym__function_attributes_end,
    STATE(6883), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5912), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [213961] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    STATE(6706), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5917), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [214037] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4668), 1,
      sym_type_specifier,
    STATE(5771), 1,
      sym_argument_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214117] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4433), 1,
      sym_type_specifier,
    STATE(5814), 1,
      sym_argument_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214197] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10047), 1,
      sym_identifier,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10053), 1,
      sym_primitive_type,
    ACTIONS(10055), 1,
      anon_sym_enum,
    ACTIONS(10057), 1,
      anon_sym_class,
    ACTIONS(10059), 1,
      anon_sym_struct,
    ACTIONS(10061), 1,
      anon_sym_union,
    ACTIONS(10063), 1,
      sym_auto,
    ACTIONS(10065), 1,
      anon_sym_decltype,
    ACTIONS(10067), 1,
      anon_sym_typename,
    STATE(1711), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3126), 1,
      sym_type_specifier,
    STATE(3518), 1,
      sym_qualified_type_identifier,
    STATE(3600), 1,
      sym_decltype_auto,
    STATE(5833), 1,
      sym_argument_list,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3269), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10051), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3601), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214277] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(7952), 1,
      sym_primitive_type,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9959), 1,
      sym_identifier,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9965), 1,
      anon_sym_enum,
    ACTIONS(9967), 1,
      anon_sym_class,
    ACTIONS(9969), 1,
      anon_sym_struct,
    ACTIONS(9971), 1,
      anon_sym_union,
    ACTIONS(9973), 1,
      anon_sym_typename,
    STATE(2271), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4697), 1,
      sym_type_specifier,
    STATE(5838), 1,
      sym_argument_list,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9963), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214357] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    ACTIONS(10069), 1,
      anon_sym_requires,
    STATE(6480), 1,
      sym_trailing_return_type,
    STATE(6555), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5927), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [214433] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10072), 1,
      sym_identifier,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10078), 1,
      sym_primitive_type,
    ACTIONS(10080), 1,
      anon_sym_enum,
    ACTIONS(10082), 1,
      anon_sym_class,
    ACTIONS(10084), 1,
      anon_sym_struct,
    ACTIONS(10086), 1,
      anon_sym_union,
    ACTIONS(10088), 1,
      sym_auto,
    ACTIONS(10090), 1,
      anon_sym_decltype,
    ACTIONS(10092), 1,
      anon_sym_typename,
    STATE(2236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4705), 1,
      sym_type_specifier,
    STATE(5166), 1,
      sym_decltype_auto,
    STATE(5198), 1,
      sym_qualified_type_identifier,
    STATE(5764), 1,
      sym_argument_list,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4947), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10076), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5167), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214513] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10047), 1,
      sym_identifier,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10053), 1,
      sym_primitive_type,
    ACTIONS(10055), 1,
      anon_sym_enum,
    ACTIONS(10057), 1,
      anon_sym_class,
    ACTIONS(10059), 1,
      anon_sym_struct,
    ACTIONS(10061), 1,
      anon_sym_union,
    ACTIONS(10063), 1,
      sym_auto,
    ACTIONS(10065), 1,
      anon_sym_decltype,
    ACTIONS(10067), 1,
      anon_sym_typename,
    STATE(1711), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3098), 1,
      sym_type_specifier,
    STATE(3518), 1,
      sym_qualified_type_identifier,
    STATE(3600), 1,
      sym_decltype_auto,
    STATE(5840), 1,
      sym_argument_list,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3269), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10051), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3601), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214593] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9949), 1,
      sym_identifier,
    ACTIONS(9953), 1,
      sym_primitive_type,
    ACTIONS(9955), 1,
      anon_sym_enum,
    ACTIONS(9957), 1,
      anon_sym_typename,
    STATE(1665), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2357), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(5807), 1,
      sym_argument_list,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9951), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214673] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4653), 1,
      sym_type_specifier,
    STATE(5784), 1,
      sym_argument_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214753] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10019), 1,
      sym_identifier,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10025), 1,
      sym_primitive_type,
    ACTIONS(10027), 1,
      anon_sym_enum,
    ACTIONS(10029), 1,
      anon_sym_class,
    ACTIONS(10031), 1,
      anon_sym_struct,
    ACTIONS(10033), 1,
      anon_sym_union,
    ACTIONS(10035), 1,
      sym_auto,
    ACTIONS(10037), 1,
      anon_sym_decltype,
    ACTIONS(10039), 1,
      anon_sym_typename,
    STATE(1709), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3050), 1,
      sym_type_specifier,
    STATE(3327), 1,
      sym_qualified_type_identifier,
    STATE(3401), 1,
      sym_decltype_auto,
    STATE(5791), 1,
      sym_argument_list,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3245), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10023), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3411), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [214833] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(6763), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5931), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [214909] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6789), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5923), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [214985] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10072), 1,
      sym_identifier,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10078), 1,
      sym_primitive_type,
    ACTIONS(10080), 1,
      anon_sym_enum,
    ACTIONS(10082), 1,
      anon_sym_class,
    ACTIONS(10084), 1,
      anon_sym_struct,
    ACTIONS(10086), 1,
      anon_sym_union,
    ACTIONS(10088), 1,
      sym_auto,
    ACTIONS(10090), 1,
      anon_sym_decltype,
    ACTIONS(10092), 1,
      anon_sym_typename,
    STATE(2236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4687), 1,
      sym_type_specifier,
    STATE(5166), 1,
      sym_decltype_auto,
    STATE(5198), 1,
      sym_qualified_type_identifier,
    STATE(5787), 1,
      sym_argument_list,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4947), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10076), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5167), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [215065] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10094), 1,
      sym_identifier,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10100), 1,
      sym_primitive_type,
    ACTIONS(10102), 1,
      anon_sym_enum,
    ACTIONS(10104), 1,
      anon_sym_class,
    ACTIONS(10106), 1,
      anon_sym_struct,
    ACTIONS(10108), 1,
      anon_sym_union,
    ACTIONS(10110), 1,
      sym_auto,
    ACTIONS(10112), 1,
      anon_sym_decltype,
    ACTIONS(10114), 1,
      anon_sym_typename,
    STATE(1712), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3082), 1,
      sym_type_specifier,
    STATE(3493), 1,
      sym_qualified_type_identifier,
    STATE(3512), 1,
      sym_decltype_auto,
    STATE(5834), 1,
      sym_argument_list,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3291), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10098), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3513), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [215145] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10069), 1,
      anon_sym_requires,
    STATE(6480), 1,
      sym_trailing_return_type,
    STATE(6695), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5914), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [215221] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6477), 1,
      sym_trailing_return_type,
    STATE(6550), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5930), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [215297] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10116), 1,
      sym_identifier,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10122), 1,
      sym_primitive_type,
    ACTIONS(10124), 1,
      anon_sym_enum,
    ACTIONS(10126), 1,
      anon_sym_class,
    ACTIONS(10128), 1,
      anon_sym_struct,
    ACTIONS(10130), 1,
      anon_sym_union,
    ACTIONS(10132), 1,
      sym_auto,
    ACTIONS(10134), 1,
      anon_sym_decltype,
    ACTIONS(10136), 1,
      anon_sym_typename,
    STATE(1725), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3215), 1,
      sym_type_specifier,
    STATE(3914), 1,
      sym_qualified_type_identifier,
    STATE(3917), 1,
      sym_decltype_auto,
    STATE(5780), 1,
      sym_argument_list,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3688), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10120), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3999), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [215377] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6492), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5918), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [215453] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(5866), 1,
      sym_ref_qualifier,
    STATE(6930), 1,
      sym__function_attributes_end,
    STATE(7051), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5977), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [215535] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6641), 1,
      sym__function_attributes_end,
    STATE(6794), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5919), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [215611] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6477), 1,
      sym_trailing_return_type,
    STATE(6749), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5916), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [215687] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_requires,
    STATE(5869), 1,
      sym_ref_qualifier,
    STATE(6935), 1,
      sym__function_attributes_end,
    STATE(7130), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5984), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [215769] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7164), 1,
      anon_sym_AMP,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(5871), 1,
      sym_ref_qualifier,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(7001), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5990), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [215851] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(9927), 1,
      sym_identifier,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9933), 1,
      sym_primitive_type,
    ACTIONS(9935), 1,
      anon_sym_enum,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9947), 1,
      anon_sym_typename,
    STATE(1661), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2357), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(5792), 1,
      sym_argument_list,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9931), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [215931] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6501), 1,
      sym_trailing_return_type,
    STATE(6551), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5902), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [216007] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10094), 1,
      sym_identifier,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10100), 1,
      sym_primitive_type,
    ACTIONS(10102), 1,
      anon_sym_enum,
    ACTIONS(10104), 1,
      anon_sym_class,
    ACTIONS(10106), 1,
      anon_sym_struct,
    ACTIONS(10108), 1,
      anon_sym_union,
    ACTIONS(10110), 1,
      sym_auto,
    ACTIONS(10112), 1,
      anon_sym_decltype,
    ACTIONS(10114), 1,
      anon_sym_typename,
    STATE(1712), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3089), 1,
      sym_type_specifier,
    STATE(3493), 1,
      sym_qualified_type_identifier,
    STATE(3512), 1,
      sym_decltype_auto,
    STATE(5797), 1,
      sym_argument_list,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3291), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10098), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3513), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [216087] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(10116), 1,
      sym_identifier,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10122), 1,
      sym_primitive_type,
    ACTIONS(10124), 1,
      anon_sym_enum,
    ACTIONS(10126), 1,
      anon_sym_class,
    ACTIONS(10128), 1,
      anon_sym_struct,
    ACTIONS(10130), 1,
      anon_sym_union,
    ACTIONS(10132), 1,
      sym_auto,
    ACTIONS(10134), 1,
      anon_sym_decltype,
    ACTIONS(10136), 1,
      anon_sym_typename,
    STATE(1725), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3240), 1,
      sym_type_specifier,
    STATE(3914), 1,
      sym_qualified_type_identifier,
    STATE(3917), 1,
      sym_decltype_auto,
    STATE(5790), 1,
      sym_argument_list,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3688), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10120), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3999), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [216167] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9921), 1,
      anon_sym_requires,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6056), 1,
      sym_trailing_return_type,
    STATE(6493), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5928), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [216243] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9871), 1,
      anon_sym_requires,
    STATE(6465), 1,
      sym_trailing_return_type,
    STATE(6759), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5909), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [216319] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4661), 1,
      sym__class_declaration,
    STATE(4663), 1,
      sym__class_declaration_item,
    STATE(6199), 1,
      sym_ms_declspec_modifier,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6201), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5830), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [216400] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2384), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [216481] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2384), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [216562] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2384), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [216643] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2414), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [216724] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2414), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [216805] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2414), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [216886] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2401), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [216967] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3351), 1,
      sym__class_declaration_item,
    STATE(3361), 1,
      sym__class_declaration,
    STATE(6077), 1,
      sym_ms_declspec_modifier,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6078), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5826), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217048] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2401), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217129] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2399), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217210] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2399), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217291] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2399), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217372] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2400), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217453] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2400), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217534] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2400), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217615] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217696] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2380), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217777] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2380), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217858] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2380), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [217939] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2382), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218020] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2382), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218101] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2382), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218182] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6800), 1,
      sym_trailing_return_type,
    STATE(6805), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5933), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [218257] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6801), 1,
      sym_trailing_return_type,
    STATE(6806), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5934), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [218332] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2375), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218413] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2375), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218494] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2375), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218575] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2376), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218656] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2376), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218737] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2376), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218818] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218899] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2383), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [218980] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2383), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219061] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2383), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219142] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2386), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219223] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2386), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219304] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2386), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219385] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2153), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(6082), 1,
      sym_ms_declspec_modifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6083), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5820), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219466] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2137), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(6082), 1,
      sym_ms_declspec_modifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6083), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5820), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219547] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2146), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(6082), 1,
      sym_ms_declspec_modifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6083), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5820), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219628] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6145), 1,
      sym_ms_declspec_modifier,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6062), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5825), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219709] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6145), 1,
      sym_ms_declspec_modifier,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6062), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5825), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219790] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6145), 1,
      sym_ms_declspec_modifier,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6062), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5825), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219871] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2153), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(6186), 1,
      sym_ms_declspec_modifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6188), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5831), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [219952] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2137), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(6186), 1,
      sym_ms_declspec_modifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6188), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5831), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220033] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2146), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(6186), 1,
      sym_ms_declspec_modifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6188), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5831), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220114] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2153), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(6191), 1,
      sym_ms_declspec_modifier,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6192), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5767), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220195] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2137), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(6191), 1,
      sym_ms_declspec_modifier,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6192), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5767), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220276] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2146), 1,
      sym__class_declaration,
    STATE(2156), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(6191), 1,
      sym_ms_declspec_modifier,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6192), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5767), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220357] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9909), 1,
      anon_sym_requires,
    STATE(6809), 1,
      sym_trailing_return_type,
    STATE(6816), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5938), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9807), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [220432] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10155), 1,
      anon_sym_requires,
    STATE(6810), 1,
      sym_trailing_return_type,
    STATE(6817), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5941), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(9890), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [220507] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2528), 1,
      sym__class_declaration_item,
    STATE(2613), 1,
      sym__class_declaration,
    STATE(6109), 1,
      sym_ms_declspec_modifier,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6110), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5828), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220588] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2498), 1,
      sym__class_declaration,
    STATE(2528), 1,
      sym__class_declaration_item,
    STATE(6109), 1,
      sym_ms_declspec_modifier,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6110), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5828), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220669] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(6172), 1,
      sym_ms_declspec_modifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6175), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5772), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220750] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(6172), 1,
      sym_ms_declspec_modifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6175), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5772), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220831] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6169), 1,
      sym_ms_declspec_modifier,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6170), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5756), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220912] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4785), 1,
      sym__class_declaration,
    STATE(4793), 1,
      sym__class_declaration_item,
    STATE(6117), 1,
      sym_ms_declspec_modifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6118), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5757), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [220993] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(6172), 1,
      sym_ms_declspec_modifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6175), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5772), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221074] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6169), 1,
      sym_ms_declspec_modifier,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6170), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5756), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221155] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2528), 1,
      sym__class_declaration_item,
    STATE(2613), 1,
      sym__class_declaration,
    STATE(6124), 1,
      sym_ms_declspec_modifier,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6125), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5779), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221236] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2491), 1,
      sym__class_declaration,
    STATE(2528), 1,
      sym__class_declaration_item,
    STATE(6124), 1,
      sym_ms_declspec_modifier,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6125), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5779), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221317] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2498), 1,
      sym__class_declaration,
    STATE(2528), 1,
      sym__class_declaration_item,
    STATE(6124), 1,
      sym_ms_declspec_modifier,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6125), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5779), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221398] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6169), 1,
      sym_ms_declspec_modifier,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6170), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5756), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221479] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3947), 1,
      sym__class_declaration,
    STATE(3976), 1,
      sym__class_declaration_item,
    STATE(6133), 1,
      sym_ms_declspec_modifier,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6134), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5776), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221560] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3976), 1,
      sym__class_declaration_item,
    STATE(3979), 1,
      sym__class_declaration,
    STATE(6133), 1,
      sym_ms_declspec_modifier,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6134), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5776), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221641] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3976), 1,
      sym__class_declaration_item,
    STATE(3995), 1,
      sym__class_declaration,
    STATE(6133), 1,
      sym_ms_declspec_modifier,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6134), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5776), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221722] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2529), 1,
      sym__class_declaration,
    STATE(2530), 1,
      sym__class_declaration_item,
    STATE(6095), 1,
      sym_ms_declspec_modifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6096), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5763), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221803] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2530), 1,
      sym__class_declaration_item,
    STATE(2531), 1,
      sym__class_declaration,
    STATE(6095), 1,
      sym_ms_declspec_modifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6096), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5763), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221884] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2530), 1,
      sym__class_declaration_item,
    STATE(2538), 1,
      sym__class_declaration,
    STATE(6095), 1,
      sym_ms_declspec_modifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6096), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5763), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [221965] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4793), 1,
      sym__class_declaration_item,
    STATE(4835), 1,
      sym__class_declaration,
    STATE(6085), 1,
      sym_ms_declspec_modifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6086), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5809), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222046] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4785), 1,
      sym__class_declaration,
    STATE(4793), 1,
      sym__class_declaration_item,
    STATE(6085), 1,
      sym_ms_declspec_modifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6086), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5809), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222127] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4793), 1,
      sym__class_declaration_item,
    STATE(4803), 1,
      sym__class_declaration,
    STATE(6085), 1,
      sym_ms_declspec_modifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6086), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5809), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222208] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3350), 1,
      sym__class_declaration,
    STATE(3351), 1,
      sym__class_declaration_item,
    STATE(6077), 1,
      sym_ms_declspec_modifier,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6078), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5826), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222289] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2395), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222370] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2395), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222451] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2395), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222532] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222613] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5207), 1,
      sym__class_declaration,
    STATE(5208), 1,
      sym__class_declaration_item,
    STATE(6141), 1,
      sym_ms_declspec_modifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6142), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5759), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222694] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5008), 1,
      sym__class_declaration,
    STATE(5208), 1,
      sym__class_declaration_item,
    STATE(6141), 1,
      sym_ms_declspec_modifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6142), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5759), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222775] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5208), 1,
      sym__class_declaration_item,
    STATE(5214), 1,
      sym__class_declaration,
    STATE(6141), 1,
      sym_ms_declspec_modifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6142), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5759), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222856] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2415), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [222937] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2415), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223018] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2415), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223099] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2401), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223180] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3520), 1,
      sym__class_declaration,
    STATE(3521), 1,
      sym__class_declaration_item,
    STATE(6151), 1,
      sym_ms_declspec_modifier,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6152), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5782), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223261] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3521), 1,
      sym__class_declaration_item,
    STATE(3522), 1,
      sym__class_declaration,
    STATE(6151), 1,
      sym_ms_declspec_modifier,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6152), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5782), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223342] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3521), 1,
      sym__class_declaration_item,
    STATE(3523), 1,
      sym__class_declaration,
    STATE(6151), 1,
      sym_ms_declspec_modifier,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6152), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5782), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223423] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4793), 1,
      sym__class_declaration_item,
    STATE(4803), 1,
      sym__class_declaration,
    STATE(6117), 1,
      sym_ms_declspec_modifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6118), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5757), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223504] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10176), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6563), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(6561), 18,
      anon_sym_virtual,
      anon_sym___attribute__,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym___asm,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_try,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_requires,
  [223547] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(6101), 1,
      sym_ms_declspec_modifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6102), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5762), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223628] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(6101), 1,
      sym_ms_declspec_modifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6102), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5762), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223709] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(6101), 1,
      sym_ms_declspec_modifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6102), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5762), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223790] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5057), 1,
      sym__class_declaration,
    STATE(5060), 1,
      sym__class_declaration_item,
    STATE(6157), 1,
      sym_ms_declspec_modifier,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6158), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5795), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223871] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5060), 1,
      sym__class_declaration_item,
    STATE(5070), 1,
      sym__class_declaration,
    STATE(6157), 1,
      sym_ms_declspec_modifier,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6158), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5795), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [223952] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5060), 1,
      sym__class_declaration_item,
    STATE(5073), 1,
      sym__class_declaration,
    STATE(6157), 1,
      sym_ms_declspec_modifier,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6158), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5795), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224033] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3604), 1,
      sym__class_declaration,
    STATE(3605), 1,
      sym__class_declaration_item,
    STATE(6162), 1,
      sym_ms_declspec_modifier,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6163), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5803), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224114] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3605), 1,
      sym__class_declaration_item,
    STATE(3606), 1,
      sym__class_declaration,
    STATE(6162), 1,
      sym_ms_declspec_modifier,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6163), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5803), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224195] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3605), 1,
      sym__class_declaration_item,
    STATE(3607), 1,
      sym__class_declaration,
    STATE(6162), 1,
      sym_ms_declspec_modifier,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6163), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5803), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224276] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3351), 1,
      sym__class_declaration_item,
    STATE(3358), 1,
      sym__class_declaration,
    STATE(6077), 1,
      sym_ms_declspec_modifier,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6078), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5826), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224357] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4793), 1,
      sym__class_declaration_item,
    STATE(4835), 1,
      sym__class_declaration,
    STATE(6117), 1,
      sym_ms_declspec_modifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6118), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5757), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224438] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4628), 1,
      sym__class_declaration,
    STATE(4663), 1,
      sym__class_declaration_item,
    STATE(6199), 1,
      sym_ms_declspec_modifier,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6201), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5830), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224519] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4625), 1,
      sym__class_declaration,
    STATE(4663), 1,
      sym__class_declaration_item,
    STATE(6199), 1,
      sym_ms_declspec_modifier,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6201), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5830), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224600] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2265), 1,
      sym__class_declaration,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2381), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224681] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2269), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2381), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224762] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2266), 1,
      sym__class_declaration_item,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6100), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2381), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6114), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5783), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224843] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2491), 1,
      sym__class_declaration,
    STATE(2528), 1,
      sym__class_declaration_item,
    STATE(6109), 1,
      sym_ms_declspec_modifier,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6110), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5828), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [224924] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2254), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6174), 1,
      sym_ms_declspec_modifier,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6173), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [225002] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4780), 1,
      sym__class_declaration_item,
    STATE(6121), 1,
      sym_ms_declspec_modifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6120), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [225080] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10072), 1,
      sym_identifier,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10078), 1,
      sym_primitive_type,
    ACTIONS(10080), 1,
      anon_sym_enum,
    ACTIONS(10082), 1,
      anon_sym_class,
    ACTIONS(10084), 1,
      anon_sym_struct,
    ACTIONS(10086), 1,
      anon_sym_union,
    ACTIONS(10088), 1,
      sym_auto,
    ACTIONS(10090), 1,
      anon_sym_decltype,
    ACTIONS(10092), 1,
      anon_sym_typename,
    STATE(2236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4987), 1,
      sym_type_specifier,
    STATE(5166), 1,
      sym_decltype_auto,
    STATE(5198), 1,
      sym_qualified_type_identifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4947), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10076), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5167), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [225154] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5211), 1,
      sym__class_declaration_item,
    STATE(6144), 1,
      sym_ms_declspec_modifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6143), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [225232] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1878), 1,
      anon_sym_enum,
    ACTIONS(1880), 1,
      anon_sym_class,
    ACTIONS(1882), 1,
      anon_sym_struct,
    ACTIONS(1884), 1,
      anon_sym_union,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(1912), 1,
      anon_sym_typename,
    ACTIONS(7787), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7793), 1,
      sym_primitive_type,
    STATE(2048), 1,
      sym_type_specifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [225306] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(6714), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5958), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [225380] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2254), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(6105), 1,
      sym_ms_declspec_modifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6104), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [225458] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2526), 1,
      sym__class_declaration_item,
    STATE(6098), 1,
      sym_ms_declspec_modifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6097), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [225536] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10072), 1,
      sym_identifier,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10078), 1,
      sym_primitive_type,
    ACTIONS(10080), 1,
      anon_sym_enum,
    ACTIONS(10082), 1,
      anon_sym_class,
    ACTIONS(10084), 1,
      anon_sym_struct,
    ACTIONS(10086), 1,
      anon_sym_union,
    ACTIONS(10088), 1,
      sym_auto,
    ACTIONS(10090), 1,
      anon_sym_decltype,
    ACTIONS(10092), 1,
      anon_sym_typename,
    STATE(2236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4724), 1,
      sym_type_specifier,
    STATE(5166), 1,
      sym_decltype_auto,
    STATE(5198), 1,
      sym_qualified_type_identifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4947), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10076), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5167), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [225610] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2880), 1,
      anon_sym_enum,
    ACTIONS(2882), 1,
      anon_sym_class,
    ACTIONS(2884), 1,
      anon_sym_struct,
    ACTIONS(2886), 1,
      anon_sym_union,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(2914), 1,
      anon_sym_typename,
    ACTIONS(7948), 1,
      sym_identifier,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7952), 1,
      sym_primitive_type,
    STATE(2422), 1,
      sym_type_specifier,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2876), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [225684] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7865), 1,
      anon_sym_enum,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(7873), 1,
      anon_sym_typename,
    STATE(2218), 1,
      sym_type_specifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [225758] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2151), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(6194), 1,
      sym_ms_declspec_modifier,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6193), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [225836] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9949), 1,
      sym_identifier,
    ACTIONS(9953), 1,
      sym_primitive_type,
    ACTIONS(9955), 1,
      anon_sym_enum,
    ACTIONS(9957), 1,
      anon_sym_typename,
    STATE(1665), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2343), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9951), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [225910] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    ACTIONS(10155), 1,
      anon_sym_requires,
    STATE(6698), 1,
      sym__function_attributes_end,
    STATE(6810), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    STATE(5948), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [225984] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6752), 1,
      sym__function_attributes_end,
    STATE(6800), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    STATE(5964), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [226058] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4642), 1,
      sym_type_specifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [226132] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2254), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(6185), 1,
      sym_ms_declspec_modifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6184), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [226210] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9991), 1,
      sym_identifier,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9997), 1,
      sym_primitive_type,
    ACTIONS(9999), 1,
      anon_sym_enum,
    ACTIONS(10001), 1,
      anon_sym_class,
    ACTIONS(10003), 1,
      anon_sym_struct,
    ACTIONS(10005), 1,
      anon_sym_union,
    ACTIONS(10007), 1,
      sym_auto,
    ACTIONS(10009), 1,
      anon_sym_decltype,
    ACTIONS(10011), 1,
      anon_sym_typename,
    STATE(2162), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4353), 1,
      sym_type_specifier,
    STATE(4630), 1,
      sym_decltype_auto,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4560), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9995), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4648), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [226284] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6842), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(5951), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [226358] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      sym_identifier,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7849), 1,
      sym_primitive_type,
    ACTIONS(7851), 1,
      anon_sym_enum,
    ACTIONS(7853), 1,
      anon_sym_class,
    ACTIONS(7855), 1,
      anon_sym_struct,
    ACTIONS(7857), 1,
      anon_sym_union,
    ACTIONS(7859), 1,
      anon_sym_typename,
    STATE(2048), 1,
      sym_type_specifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [226432] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3878), 1,
      sym__class_declaration_item,
    STATE(6137), 1,
      sym_ms_declspec_modifier,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6136), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [226510] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10019), 1,
      sym_identifier,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10025), 1,
      sym_primitive_type,
    ACTIONS(10027), 1,
      anon_sym_enum,
    ACTIONS(10029), 1,
      anon_sym_class,
    ACTIONS(10031), 1,
      anon_sym_struct,
    ACTIONS(10033), 1,
      anon_sym_union,
    ACTIONS(10035), 1,
      sym_auto,
    ACTIONS(10037), 1,
      anon_sym_decltype,
    ACTIONS(10039), 1,
      anon_sym_typename,
    STATE(1709), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3251), 1,
      sym_type_specifier,
    STATE(3327), 1,
      sym_qualified_type_identifier,
    STATE(3401), 1,
      sym_decltype_auto,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3245), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10023), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3411), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [226584] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9991), 1,
      sym_identifier,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9997), 1,
      sym_primitive_type,
    ACTIONS(9999), 1,
      anon_sym_enum,
    ACTIONS(10001), 1,
      anon_sym_class,
    ACTIONS(10003), 1,
      anon_sym_struct,
    ACTIONS(10005), 1,
      anon_sym_union,
    ACTIONS(10007), 1,
      sym_auto,
    ACTIONS(10009), 1,
      anon_sym_decltype,
    ACTIONS(10011), 1,
      anon_sym_typename,
    STATE(2162), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4362), 1,
      sym_type_specifier,
    STATE(4630), 1,
      sym_decltype_auto,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4560), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9995), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4648), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [226658] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2516), 1,
      sym__class_declaration_item,
    STATE(6129), 1,
      sym_ms_declspec_modifier,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6128), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [226736] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10116), 1,
      sym_identifier,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10122), 1,
      sym_primitive_type,
    ACTIONS(10124), 1,
      anon_sym_enum,
    ACTIONS(10126), 1,
      anon_sym_class,
    ACTIONS(10128), 1,
      anon_sym_struct,
    ACTIONS(10130), 1,
      anon_sym_union,
    ACTIONS(10132), 1,
      sym_auto,
    ACTIONS(10134), 1,
      anon_sym_decltype,
    ACTIONS(10136), 1,
      anon_sym_typename,
    STATE(1725), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3213), 1,
      sym_type_specifier,
    STATE(3914), 1,
      sym_qualified_type_identifier,
    STATE(3917), 1,
      sym_decltype_auto,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3688), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10120), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3999), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [226810] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6515), 1,
      sym__declarator,
    STATE(8171), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [226880] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3544), 1,
      sym__class_declaration_item,
    STATE(6154), 1,
      sym_ms_declspec_modifier,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6153), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [226958] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2254), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6093), 1,
      sym_ms_declspec_modifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6089), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [227036] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4673), 1,
      sym_type_specifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227110] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6753), 1,
      sym__function_attributes_end,
    STATE(6801), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    STATE(5955), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [227184] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(10185), 1,
      anon_sym_enum,
    ACTIONS(10187), 1,
      anon_sym_typename,
    STATE(2218), 1,
      sym_type_specifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(5407), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10183), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227258] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10072), 1,
      sym_identifier,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10078), 1,
      sym_primitive_type,
    ACTIONS(10080), 1,
      anon_sym_enum,
    ACTIONS(10082), 1,
      anon_sym_class,
    ACTIONS(10084), 1,
      anon_sym_struct,
    ACTIONS(10086), 1,
      anon_sym_union,
    ACTIONS(10088), 1,
      sym_auto,
    ACTIONS(10090), 1,
      anon_sym_decltype,
    ACTIONS(10092), 1,
      anon_sym_typename,
    STATE(2236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4744), 1,
      sym_type_specifier,
    STATE(5166), 1,
      sym_decltype_auto,
    STATE(5198), 1,
      sym_qualified_type_identifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4947), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10076), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5167), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227332] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(7952), 1,
      sym_primitive_type,
    ACTIONS(9959), 1,
      sym_identifier,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9965), 1,
      anon_sym_enum,
    ACTIONS(9967), 1,
      anon_sym_class,
    ACTIONS(9969), 1,
      anon_sym_struct,
    ACTIONS(9971), 1,
      anon_sym_union,
    ACTIONS(9973), 1,
      anon_sym_typename,
    STATE(2271), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2422), 1,
      sym_type_specifier,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9963), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227406] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9927), 1,
      sym_identifier,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9933), 1,
      sym_primitive_type,
    ACTIONS(9935), 1,
      anon_sym_enum,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9947), 1,
      anon_sym_typename,
    STATE(1661), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2343), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9931), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227480] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10116), 1,
      sym_identifier,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10122), 1,
      sym_primitive_type,
    ACTIONS(10124), 1,
      anon_sym_enum,
    ACTIONS(10126), 1,
      anon_sym_class,
    ACTIONS(10128), 1,
      anon_sym_struct,
    ACTIONS(10130), 1,
      anon_sym_union,
    ACTIONS(10132), 1,
      sym_auto,
    ACTIONS(10134), 1,
      anon_sym_decltype,
    ACTIONS(10136), 1,
      anon_sym_typename,
    STATE(1725), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3249), 1,
      sym_type_specifier,
    STATE(3914), 1,
      sym_qualified_type_identifier,
    STATE(3917), 1,
      sym_decltype_auto,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3688), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10120), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3999), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227554] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10019), 1,
      sym_identifier,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10025), 1,
      sym_primitive_type,
    ACTIONS(10027), 1,
      anon_sym_enum,
    ACTIONS(10029), 1,
      anon_sym_class,
    ACTIONS(10031), 1,
      anon_sym_struct,
    ACTIONS(10033), 1,
      anon_sym_union,
    ACTIONS(10035), 1,
      sym_auto,
    ACTIONS(10037), 1,
      anon_sym_decltype,
    ACTIONS(10039), 1,
      anon_sym_typename,
    STATE(1709), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3031), 1,
      sym_type_specifier,
    STATE(3327), 1,
      sym_qualified_type_identifier,
    STATE(3401), 1,
      sym_decltype_auto,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3245), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10023), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3411), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227628] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9927), 1,
      sym_identifier,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9933), 1,
      sym_primitive_type,
    ACTIONS(9935), 1,
      anon_sym_enum,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9947), 1,
      anon_sym_typename,
    STATE(1661), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2351), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9931), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227702] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2276), 1,
      sym_primitive_type,
    ACTIONS(2278), 1,
      anon_sym_enum,
    ACTIONS(2280), 1,
      anon_sym_class,
    ACTIONS(2282), 1,
      anon_sym_struct,
    ACTIONS(2284), 1,
      anon_sym_union,
    ACTIONS(2286), 1,
      anon_sym_typename,
    ACTIONS(5147), 1,
      sym_identifier,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    STATE(2190), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2218), 1,
      sym_type_specifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2625), 1,
      sym_qualified_type_identifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(57), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227776] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6510), 1,
      sym__declarator,
    STATE(7804), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [227846] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5025), 1,
      sym__class_declaration_item,
    STATE(6160), 1,
      sym_ms_declspec_modifier,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6159), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [227924] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1802), 1,
      anon_sym_enum,
    ACTIONS(1804), 1,
      anon_sym_class,
    ACTIONS(1806), 1,
      anon_sym_struct,
    ACTIONS(1808), 1,
      anon_sym_union,
    ACTIONS(1832), 1,
      anon_sym_typename,
    ACTIONS(2276), 1,
      sym_primitive_type,
    ACTIONS(4601), 1,
      sym_identifier,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    STATE(2190), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2218), 1,
      sym_type_specifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2625), 1,
      sym_qualified_type_identifier,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(57), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [227998] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10094), 1,
      sym_identifier,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10100), 1,
      sym_primitive_type,
    ACTIONS(10102), 1,
      anon_sym_enum,
    ACTIONS(10104), 1,
      anon_sym_class,
    ACTIONS(10106), 1,
      anon_sym_struct,
    ACTIONS(10108), 1,
      anon_sym_union,
    ACTIONS(10110), 1,
      sym_auto,
    ACTIONS(10112), 1,
      anon_sym_decltype,
    ACTIONS(10114), 1,
      anon_sym_typename,
    STATE(1712), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3100), 1,
      sym_type_specifier,
    STATE(3493), 1,
      sym_qualified_type_identifier,
    STATE(3512), 1,
      sym_decltype_auto,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3291), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10098), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3513), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [228072] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6495), 1,
      sym__declarator,
    STATE(7790), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [228142] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6530), 1,
      sym__declarator,
    STATE(8320), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [228212] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9927), 1,
      sym_identifier,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9933), 1,
      sym_primitive_type,
    ACTIONS(9935), 1,
      anon_sym_enum,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9947), 1,
      anon_sym_typename,
    STATE(1661), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2457), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9931), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [228286] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(10185), 1,
      anon_sym_enum,
    ACTIONS(10187), 1,
      anon_sym_typename,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(5407), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(7438), 1,
      sym_type_specifier,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10183), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [228360] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10116), 1,
      sym_identifier,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10122), 1,
      sym_primitive_type,
    ACTIONS(10124), 1,
      anon_sym_enum,
    ACTIONS(10126), 1,
      anon_sym_class,
    ACTIONS(10128), 1,
      anon_sym_struct,
    ACTIONS(10130), 1,
      anon_sym_union,
    ACTIONS(10132), 1,
      sym_auto,
    ACTIONS(10134), 1,
      anon_sym_decltype,
    ACTIONS(10136), 1,
      anon_sym_typename,
    STATE(1725), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3712), 1,
      sym_type_specifier,
    STATE(3914), 1,
      sym_qualified_type_identifier,
    STATE(3917), 1,
      sym_decltype_auto,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3688), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10120), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3999), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [228434] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3646), 1,
      sym__class_declaration_item,
    STATE(6165), 1,
      sym_ms_declspec_modifier,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6164), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [228512] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7934), 1,
      sym_identifier,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7938), 1,
      anon_sym_enum,
    ACTIONS(7940), 1,
      anon_sym_class,
    ACTIONS(7942), 1,
      anon_sym_struct,
    ACTIONS(7944), 1,
      anon_sym_union,
    ACTIONS(7946), 1,
      anon_sym_typename,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4685), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [228586] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6737), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5970), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [228660] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9949), 1,
      sym_identifier,
    ACTIONS(9953), 1,
      sym_primitive_type,
    ACTIONS(9955), 1,
      anon_sym_enum,
    ACTIONS(9957), 1,
      anon_sym_typename,
    STATE(1665), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2457), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9951), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [228734] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9937), 1,
      anon_sym_class,
    ACTIONS(9939), 1,
      anon_sym_struct,
    ACTIONS(9941), 1,
      anon_sym_union,
    ACTIONS(9943), 1,
      sym_auto,
    ACTIONS(9945), 1,
      anon_sym_decltype,
    ACTIONS(9949), 1,
      sym_identifier,
    ACTIONS(9953), 1,
      sym_primitive_type,
    ACTIONS(9955), 1,
      anon_sym_enum,
    ACTIONS(9957), 1,
      anon_sym_typename,
    STATE(1665), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2351), 1,
      sym_type_specifier,
    STATE(2500), 1,
      sym_decltype_auto,
    STATE(2522), 1,
      sym_qualified_type_identifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2427), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9951), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2506), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [228808] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(6421), 1,
      sym__declarator,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(8171), 1,
      sym_init_declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [228878] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4780), 1,
      sym__class_declaration_item,
    STATE(6091), 1,
      sym_ms_declspec_modifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6090), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [228956] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4470), 1,
      sym_type_specifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229030] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10019), 1,
      sym_identifier,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10025), 1,
      sym_primitive_type,
    ACTIONS(10027), 1,
      anon_sym_enum,
    ACTIONS(10029), 1,
      anon_sym_class,
    ACTIONS(10031), 1,
      anon_sym_struct,
    ACTIONS(10033), 1,
      anon_sym_union,
    ACTIONS(10035), 1,
      sym_auto,
    ACTIONS(10037), 1,
      anon_sym_decltype,
    ACTIONS(10039), 1,
      anon_sym_typename,
    STATE(1709), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3017), 1,
      sym_type_specifier,
    STATE(3327), 1,
      sym_qualified_type_identifier,
    STATE(3401), 1,
      sym_decltype_auto,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3245), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10023), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3411), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229104] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2048), 1,
      sym_type_specifier,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229178] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_enum,
    ACTIONS(73), 1,
      anon_sym_class,
    ACTIONS(75), 1,
      anon_sym_struct,
    ACTIONS(77), 1,
      anon_sym_union,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(129), 1,
      anon_sym_typename,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2276), 1,
      sym_primitive_type,
    ACTIONS(5147), 1,
      sym_identifier,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    STATE(2190), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2218), 1,
      sym_type_specifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2625), 1,
      sym_qualified_type_identifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(57), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229252] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1908), 1,
      sym_auto,
    ACTIONS(1910), 1,
      anon_sym_decltype,
    ACTIONS(7793), 1,
      sym_primitive_type,
    ACTIONS(9975), 1,
      sym_identifier,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9981), 1,
      anon_sym_enum,
    ACTIONS(9983), 1,
      anon_sym_class,
    ACTIONS(9985), 1,
      anon_sym_struct,
    ACTIONS(9987), 1,
      anon_sym_union,
    ACTIONS(9989), 1,
      anon_sym_typename,
    STATE(2123), 1,
      sym_decltype_auto,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4431), 1,
      sym_type_specifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2072), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2127), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229326] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    STATE(6738), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5959), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [229400] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7883), 1,
      sym_identifier,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7889), 1,
      sym_primitive_type,
    ACTIONS(7891), 1,
      anon_sym_enum,
    ACTIONS(7893), 1,
      anon_sym_class,
    ACTIONS(7895), 1,
      anon_sym_struct,
    ACTIONS(7897), 1,
      anon_sym_union,
    ACTIONS(7899), 1,
      sym_auto,
    ACTIONS(7901), 1,
      anon_sym_decltype,
    ACTIONS(7903), 1,
      anon_sym_typename,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4685), 1,
      sym_type_specifier,
    STATE(4808), 1,
      sym_decltype_auto,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4814), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229474] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(7909), 1,
      sym_identifier,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7915), 1,
      sym_primitive_type,
    ACTIONS(7917), 1,
      anon_sym_enum,
    ACTIONS(7919), 1,
      anon_sym_class,
    ACTIONS(7921), 1,
      anon_sym_struct,
    ACTIONS(7923), 1,
      anon_sym_union,
    ACTIONS(7925), 1,
      sym_auto,
    ACTIONS(7927), 1,
      anon_sym_decltype,
    ACTIONS(7929), 1,
      anon_sym_typename,
    STATE(4276), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4997), 1,
      sym_type_specifier,
    STATE(5194), 1,
      sym_qualified_type_identifier,
    STATE(5228), 1,
      sym_decltype_auto,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4959), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7913), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(5232), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229548] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10094), 1,
      sym_identifier,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10100), 1,
      sym_primitive_type,
    ACTIONS(10102), 1,
      anon_sym_enum,
    ACTIONS(10104), 1,
      anon_sym_class,
    ACTIONS(10106), 1,
      anon_sym_struct,
    ACTIONS(10108), 1,
      anon_sym_union,
    ACTIONS(10110), 1,
      sym_auto,
    ACTIONS(10112), 1,
      anon_sym_decltype,
    ACTIONS(10114), 1,
      anon_sym_typename,
    STATE(1712), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3395), 1,
      sym_type_specifier,
    STATE(3493), 1,
      sym_qualified_type_identifier,
    STATE(3512), 1,
      sym_decltype_auto,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3291), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10098), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3513), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229622] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6027), 1,
      sym_trailing_return_type,
    STATE(6843), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(5966), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [229696] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2151), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(6107), 1,
      sym_ms_declspec_modifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6106), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [229774] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6485), 1,
      sym__declarator,
    STATE(7776), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [229844] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(7861), 1,
      sym_identifier,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7867), 1,
      anon_sym_class,
    ACTIONS(7869), 1,
      anon_sym_struct,
    ACTIONS(7871), 1,
      anon_sym_union,
    ACTIONS(10185), 1,
      anon_sym_enum,
    ACTIONS(10187), 1,
      anon_sym_typename,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(5407), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(7494), 1,
      sym_type_specifier,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10183), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [229918] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6650), 1,
      sym_trailing_return_type,
    STATE(6718), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5967), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [229992] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(123), 1,
      sym_auto,
    ACTIONS(125), 1,
      anon_sym_decltype,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(3736), 1,
      sym_identifier,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3748), 1,
      sym_primitive_type,
    ACTIONS(3750), 1,
      anon_sym_enum,
    ACTIONS(3752), 1,
      anon_sym_class,
    ACTIONS(3754), 1,
      anon_sym_struct,
    ACTIONS(3756), 1,
      anon_sym_union,
    ACTIONS(3758), 1,
      anon_sym_typename,
    STATE(2218), 1,
      sym_type_specifier,
    STATE(2243), 1,
      sym_decltype_auto,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2374), 1,
      sym_qualified_type_identifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2212), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2264), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [230066] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2254), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(6072), 1,
      sym_ms_declspec_modifier,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6071), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [230144] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3323), 1,
      sym__class_declaration_item,
    STATE(6080), 1,
      sym_ms_declspec_modifier,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6079), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [230222] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    ACTIONS(9909), 1,
      anon_sym_requires,
    STATE(6788), 1,
      sym__function_attributes_end,
    STATE(6809), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    STATE(5968), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [230296] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2516), 1,
      sym__class_declaration_item,
    STATE(6112), 1,
      sym_ms_declspec_modifier,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6111), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [230374] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6498), 1,
      sym__declarator,
    STATE(8171), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [230444] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4621), 1,
      sym__class_declaration_item,
    STATE(6204), 1,
      sym_ms_declspec_modifier,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6203), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [230522] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5497), 1,
      anon_sym___declspec,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2151), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(6205), 1,
      sym_ms_declspec_modifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(5491), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(5499), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6200), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [230600] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6894), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(5946), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [230674] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10047), 1,
      sym_identifier,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10053), 1,
      sym_primitive_type,
    ACTIONS(10055), 1,
      anon_sym_enum,
    ACTIONS(10057), 1,
      anon_sym_class,
    ACTIONS(10059), 1,
      anon_sym_struct,
    ACTIONS(10061), 1,
      anon_sym_union,
    ACTIONS(10063), 1,
      sym_auto,
    ACTIONS(10065), 1,
      anon_sym_decltype,
    ACTIONS(10067), 1,
      anon_sym_typename,
    STATE(1711), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3073), 1,
      sym_type_specifier,
    STATE(3518), 1,
      sym_qualified_type_identifier,
    STATE(3600), 1,
      sym_decltype_auto,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3269), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10051), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3601), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [230748] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10094), 1,
      sym_identifier,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10100), 1,
      sym_primitive_type,
    ACTIONS(10102), 1,
      anon_sym_enum,
    ACTIONS(10104), 1,
      anon_sym_class,
    ACTIONS(10106), 1,
      anon_sym_struct,
    ACTIONS(10108), 1,
      anon_sym_union,
    ACTIONS(10110), 1,
      sym_auto,
    ACTIONS(10112), 1,
      anon_sym_decltype,
    ACTIONS(10114), 1,
      anon_sym_typename,
    STATE(1712), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3095), 1,
      sym_type_specifier,
    STATE(3493), 1,
      sym_qualified_type_identifier,
    STATE(3512), 1,
      sym_decltype_auto,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3291), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10098), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3513), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [230822] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(7952), 1,
      sym_primitive_type,
    ACTIONS(9959), 1,
      sym_identifier,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9965), 1,
      anon_sym_enum,
    ACTIONS(9967), 1,
      anon_sym_class,
    ACTIONS(9969), 1,
      anon_sym_struct,
    ACTIONS(9971), 1,
      anon_sym_union,
    ACTIONS(9973), 1,
      anon_sym_typename,
    STATE(2271), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4739), 1,
      sym_type_specifier,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9963), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [230896] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9921), 1,
      anon_sym_requires,
    STATE(6056), 1,
      sym_trailing_return_type,
    STATE(6847), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(5954), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [230970] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6504), 1,
      sym__declarator,
    STATE(8132), 1,
      sym_init_declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [231040] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2910), 1,
      sym_auto,
    ACTIONS(2912), 1,
      anon_sym_decltype,
    ACTIONS(7952), 1,
      sym_primitive_type,
    ACTIONS(9959), 1,
      sym_identifier,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9965), 1,
      anon_sym_enum,
    ACTIONS(9967), 1,
      anon_sym_class,
    ACTIONS(9969), 1,
      anon_sym_struct,
    ACTIONS(9971), 1,
      anon_sym_union,
    ACTIONS(9973), 1,
      anon_sym_typename,
    STATE(2271), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2552), 1,
      sym_qualified_type_identifier,
    STATE(2610), 1,
      sym_decltype_auto,
    STATE(4723), 1,
      sym_type_specifier,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(2446), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9963), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2611), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [231114] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(9991), 1,
      sym_identifier,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9997), 1,
      sym_primitive_type,
    ACTIONS(9999), 1,
      anon_sym_enum,
    ACTIONS(10001), 1,
      anon_sym_class,
    ACTIONS(10003), 1,
      anon_sym_struct,
    ACTIONS(10005), 1,
      anon_sym_union,
    ACTIONS(10007), 1,
      sym_auto,
    ACTIONS(10009), 1,
      anon_sym_decltype,
    ACTIONS(10011), 1,
      anon_sym_typename,
    STATE(2162), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2169), 1,
      sym_qualified_type_identifier,
    STATE(4538), 1,
      sym_type_specifier,
    STATE(4630), 1,
      sym_decltype_auto,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(4560), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(9995), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4648), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [231188] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10047), 1,
      sym_identifier,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10053), 1,
      sym_primitive_type,
    ACTIONS(10055), 1,
      anon_sym_enum,
    ACTIONS(10057), 1,
      anon_sym_class,
    ACTIONS(10059), 1,
      anon_sym_struct,
    ACTIONS(10061), 1,
      anon_sym_union,
    ACTIONS(10063), 1,
      sym_auto,
    ACTIONS(10065), 1,
      anon_sym_decltype,
    ACTIONS(10067), 1,
      anon_sym_typename,
    STATE(1711), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3087), 1,
      sym_type_specifier,
    STATE(3518), 1,
      sym_qualified_type_identifier,
    STATE(3600), 1,
      sym_decltype_auto,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3269), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10051), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3601), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [231262] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(10047), 1,
      sym_identifier,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10053), 1,
      sym_primitive_type,
    ACTIONS(10055), 1,
      anon_sym_enum,
    ACTIONS(10057), 1,
      anon_sym_class,
    ACTIONS(10059), 1,
      anon_sym_struct,
    ACTIONS(10061), 1,
      anon_sym_union,
    ACTIONS(10063), 1,
      sym_auto,
    ACTIONS(10065), 1,
      anon_sym_decltype,
    ACTIONS(10067), 1,
      anon_sym_typename,
    STATE(1711), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3388), 1,
      sym_type_specifier,
    STATE(3518), 1,
      sym_qualified_type_identifier,
    STATE(3600), 1,
      sym_decltype_auto,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_dependent_type_identifier,
    STATE(3269), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(10051), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3601), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [231336] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(9809), 1,
      anon_sym___attribute__,
    ACTIONS(9812), 1,
      anon_sym___attribute,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6308), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [231403] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7190), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [231470] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7109), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [231537] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7033), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [231604] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(9892), 1,
      anon_sym___attribute__,
    ACTIONS(9895), 1,
      anon_sym___attribute,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9906), 1,
      anon_sym_requires,
    STATE(6167), 1,
      sym_trailing_return_type,
    STATE(6309), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [231671] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7071), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [231738] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7053), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [231805] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7058), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [231872] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    STATE(6994), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9890), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5985), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [231945] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7109), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232012] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6985), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5973), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [232085] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(10191), 1,
      anon_sym___attribute__,
    ACTIONS(10194), 1,
      anon_sym___attribute,
    ACTIONS(10197), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6198), 1,
      sym_trailing_return_type,
    STATE(6301), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [232152] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7108), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232219] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(10191), 1,
      anon_sym___attribute__,
    ACTIONS(10194), 1,
      anon_sym___attribute,
    ACTIONS(10197), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10205), 1,
      anon_sym_requires,
    STATE(6168), 1,
      sym_trailing_return_type,
    STATE(6310), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [232286] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(9892), 1,
      anon_sym___attribute__,
    ACTIONS(9895), 1,
      anon_sym___attribute,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6180), 1,
      sym_trailing_return_type,
    STATE(6300), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [232353] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7031), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232420] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7088), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232487] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7126), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232554] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_requires,
    STATE(6935), 1,
      sym__function_attributes_end,
    STATE(7130), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5984), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [232627] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7120), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232694] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7266), 1,
      anon_sym_STAR,
    ACTIONS(7268), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6940), 1,
      sym__declarator,
    STATE(8750), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232761] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7072), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232828] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7274), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232895] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(7221), 1,
      anon_sym_STAR,
    ACTIONS(7223), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7225), 1,
      anon_sym_AMP,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6787), 1,
      sym__declarator,
    STATE(8660), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [232962] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6931), 1,
      sym__function_attributes_end,
    STATE(7054), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9890), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5986), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [233035] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7047), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233102] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7250), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233169] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10208), 1,
      anon_sym_requires,
    STATE(6936), 1,
      sym__function_attributes_end,
    STATE(7078), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9890), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5978), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [233242] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(7001), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5990), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [233315] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6650), 1,
      sym_trailing_return_type,
    STATE(7005), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9890), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5981), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [233388] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7258), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233455] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7189), 1,
      anon_sym_noexcept,
    ACTIONS(7191), 1,
      anon_sym_throw,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6930), 1,
      sym__function_attributes_end,
    STATE(7051), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5977), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [233528] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(9809), 1,
      anon_sym___attribute__,
    ACTIONS(9812), 1,
      anon_sym___attribute,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6299), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [233595] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 1,
      anon_sym_STAR,
    ACTIONS(7251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7253), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(7140), 1,
      sym__declarator,
    STATE(8805), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233662] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7099), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233729] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7247), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233796] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5923), 1,
      sym_identifier,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7272), 1,
      anon_sym_STAR,
    ACTIONS(7274), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7276), 1,
      anon_sym_AMP,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6750), 1,
      sym__declarator,
    STATE(9278), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233863] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7231), 1,
      anon_sym_STAR,
    ACTIONS(7233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(7268), 1,
      sym__declarator,
    STATE(8856), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233930] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7238), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [233997] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2260), 1,
      anon_sym_STAR,
    ACTIONS(2262), 1,
      anon_sym_AMP,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5483), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(7294), 1,
      sym__declarator,
    STATE(9004), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [234064] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7063), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [234131] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2256), 1,
      anon_sym_LPAREN2,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7229), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      sym_identifier,
    ACTIONS(7280), 1,
      anon_sym_STAR,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_AMP,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(7113), 1,
      sym__declarator,
    STATE(9252), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6660), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [234198] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6304), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234264] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    ACTIONS(9842), 1,
      anon_sym___asm,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6328), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [234330] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9915), 1,
      anon_sym___asm,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9921), 1,
      anon_sym_requires,
    STATE(6056), 1,
      sym_trailing_return_type,
    STATE(6313), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9912), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234396] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9915), 1,
      anon_sym___asm,
    STATE(6180), 1,
      sym_trailing_return_type,
    STATE(6325), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9912), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [234462] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6180), 1,
      sym_trailing_return_type,
    STATE(6520), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [234528] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(10197), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10205), 1,
      anon_sym_requires,
    STATE(6168), 1,
      sym_trailing_return_type,
    STATE(6521), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [234594] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(10197), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10214), 1,
      anon_sym___asm,
    STATE(6198), 1,
      sym_trailing_return_type,
    STATE(6326), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10211), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [234660] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(10197), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10205), 1,
      anon_sym_requires,
    ACTIONS(10214), 1,
      anon_sym___asm,
    STATE(6168), 1,
      sym_trailing_return_type,
    STATE(6330), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10211), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [234726] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9906), 1,
      anon_sym_requires,
    ACTIONS(9915), 1,
      anon_sym___asm,
    STATE(6167), 1,
      sym_trailing_return_type,
    STATE(6329), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9912), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [234792] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9915), 1,
      anon_sym___asm,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6027), 1,
      sym_trailing_return_type,
    STATE(6372), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9912), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234858] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10214), 1,
      anon_sym___asm,
    ACTIONS(10217), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10220), 1,
      anon_sym_requires,
    STATE(5995), 1,
      sym_trailing_return_type,
    STATE(6314), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10211), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234924] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(10197), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6198), 1,
      sym_trailing_return_type,
    STATE(6576), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [234990] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10214), 1,
      anon_sym___asm,
    ACTIONS(10217), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6044), 1,
      sym_trailing_return_type,
    STATE(6306), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10211), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [235056] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6323), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [235122] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(6156), 1,
      sym_trailing_return_type,
    STATE(6566), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [235188] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9906), 1,
      anon_sym_requires,
    STATE(6167), 1,
      sym_trailing_return_type,
    STATE(6575), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [235254] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6115), 1,
      sym_trailing_return_type,
    STATE(6568), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [235320] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9842), 1,
      anon_sym___asm,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6312), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9839), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [235386] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10223), 1,
      anon_sym___attribute__,
    ACTIONS(10226), 1,
      anon_sym___attribute,
    STATE(6470), 1,
      sym_trailing_return_type,
    STATE(6552), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [235451] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10217), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10229), 1,
      anon_sym_requires,
    STATE(6606), 1,
      sym__function_attributes_end,
    STATE(6885), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [235516] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6470), 1,
      sym_trailing_return_type,
    STATE(6723), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [235581] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6518), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [235646] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9881), 1,
      anon_sym_requires,
    STATE(6671), 1,
      sym__function_attributes_end,
    STATE(6883), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [235711] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(6763), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [235776] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6789), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [235841] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10069), 1,
      anon_sym_requires,
    STATE(6480), 1,
      sym_trailing_return_type,
    STATE(6695), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [235906] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6641), 1,
      sym__function_attributes_end,
    STATE(6794), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [235971] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9871), 1,
      anon_sym_requires,
    STATE(6465), 1,
      sym_trailing_return_type,
    STATE(6759), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [236036] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9924), 1,
      anon_sym_requires,
    STATE(6596), 1,
      sym__function_attributes_end,
    STATE(6884), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [236101] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6027), 1,
      sym_trailing_return_type,
    STATE(6488), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [236166] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10235), 1,
      anon_sym_requires,
    STATE(6481), 1,
      sym_trailing_return_type,
    STATE(6708), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [236231] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6492), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [236296] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6501), 1,
      sym_trailing_return_type,
    STATE(6726), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [236361] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10238), 1,
      anon_sym_requires,
    STATE(6654), 1,
      sym_trailing_return_type,
    STATE(6768), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [236426] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9921), 1,
      anon_sym_requires,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6056), 1,
      sym_trailing_return_type,
    STATE(6493), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [236491] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10217), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6694), 1,
      sym__function_attributes_end,
    STATE(6797), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [236556] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6663), 1,
      sym__function_attributes_end,
    STATE(6792), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [236621] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6642), 1,
      sym_trailing_return_type,
    STATE(6707), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [236686] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6477), 1,
      sym_trailing_return_type,
    STATE(6749), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [236751] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    STATE(6706), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [236816] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10217), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10223), 1,
      anon_sym___attribute__,
    ACTIONS(10226), 1,
      anon_sym___attribute,
    STATE(6044), 1,
      sym_trailing_return_type,
    STATE(6489), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [236881] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    ACTIONS(9871), 1,
      anon_sym_requires,
    STATE(6465), 1,
      sym_trailing_return_type,
    STATE(6554), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [236946] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    ACTIONS(10069), 1,
      anon_sym_requires,
    STATE(6480), 1,
      sym_trailing_return_type,
    STATE(6555), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [237011] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10223), 1,
      anon_sym___attribute__,
    ACTIONS(10226), 1,
      anon_sym___attribute,
    ACTIONS(10235), 1,
      anon_sym_requires,
    STATE(6481), 1,
      sym_trailing_return_type,
    STATE(6556), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [237076] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10217), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10220), 1,
      anon_sym_requires,
    ACTIONS(10223), 1,
      anon_sym___attribute__,
    ACTIONS(10226), 1,
      anon_sym___attribute,
    STATE(5995), 1,
      sym_trailing_return_type,
    STATE(6494), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [237141] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6477), 1,
      sym_trailing_return_type,
    STATE(6550), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [237206] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6501), 1,
      sym_trailing_return_type,
    STATE(6551), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ,
      anon_sym_GT2,
  [237271] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6650), 1,
      sym_trailing_return_type,
    STATE(6705), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [237336] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6409), 1,
      sym_ms_call_modifier,
    STATE(7334), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(53), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [237394] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6801), 1,
      sym_trailing_return_type,
    STATE(6806), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [237458] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6802), 1,
      sym_trailing_return_type,
    STATE(6807), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [237522] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6406), 1,
      sym_ms_call_modifier,
    STATE(7345), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(53), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [237580] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9909), 1,
      anon_sym_requires,
    STATE(6809), 1,
      sym_trailing_return_type,
    STATE(6816), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [237644] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6453), 1,
      sym_ms_call_modifier,
    STATE(7372), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(53), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [237702] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10155), 1,
      anon_sym_requires,
    STATE(6810), 1,
      sym_trailing_return_type,
    STATE(6817), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [237766] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6411), 1,
      sym_ms_call_modifier,
    STATE(7330), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(53), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [237824] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6385), 1,
      sym_ms_call_modifier,
    STATE(7329), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(53), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [237882] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10241), 1,
      anon_sym_requires,
    STATE(6811), 1,
      sym_trailing_return_type,
    STATE(6818), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [237946] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6800), 1,
      sym_trailing_return_type,
    STATE(6805), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [238010] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    ACTIONS(10244), 1,
      anon_sym_LPAREN2,
    ACTIONS(10246), 1,
      anon_sym_LBRACE,
    ACTIONS(10250), 1,
      anon_sym_requires,
    STATE(2904), 1,
      sym_template_type,
    STATE(3834), 1,
      sym_requirement_seq,
    STATE(6574), 1,
      sym_lambda_capture_specifier,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(8244), 1,
      sym_requires_parameter_list,
    ACTIONS(10248), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3851), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [238071] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    ACTIONS(10252), 1,
      anon_sym_LPAREN2,
    ACTIONS(10254), 1,
      anon_sym_LBRACE,
    ACTIONS(10258), 1,
      anon_sym_requires,
    STATE(4582), 1,
      sym_template_type,
    STATE(5424), 1,
      sym_requirement_seq,
    STATE(6569), 1,
      sym_lambda_capture_specifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(8483), 1,
      sym_requires_parameter_list,
    ACTIONS(10256), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5487), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [238132] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(6054), 1,
      sym_trailing_return_type,
    STATE(6894), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [238195] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9921), 1,
      anon_sym_requires,
    STATE(6056), 1,
      sym_trailing_return_type,
    STATE(6847), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [238258] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    ACTIONS(10260), 1,
      anon_sym_LPAREN2,
    ACTIONS(10262), 1,
      anon_sym_LBRACE,
    ACTIONS(10266), 1,
      anon_sym_requires,
    STATE(3004), 1,
      sym_template_type,
    STATE(4118), 1,
      sym_requirement_seq,
    STATE(6561), 1,
      sym_lambda_capture_specifier,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(8250), 1,
      sym_requires_parameter_list,
    ACTIONS(10264), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4255), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [238319] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10223), 1,
      anon_sym___attribute__,
    ACTIONS(10226), 1,
      anon_sym___attribute,
    ACTIONS(10241), 1,
      anon_sym_requires,
    STATE(6704), 1,
      sym__function_attributes_end,
    STATE(6811), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [238382] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7715), 1,
      anon_sym_STAR,
    ACTIONS(7717), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7719), 1,
      anon_sym_AMP,
    ACTIONS(8939), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6675), 1,
      sym__abstract_declarator,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [238433] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    ACTIONS(10268), 1,
      anon_sym_LPAREN2,
    ACTIONS(10270), 1,
      anon_sym_LBRACE,
    ACTIONS(10274), 1,
      anon_sym_requires,
    STATE(3114), 1,
      sym_template_type,
    STATE(4403), 1,
      sym_requirement_seq,
    STATE(6545), 1,
      sym_lambda_capture_specifier,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(8274), 1,
      sym_requires_parameter_list,
    ACTIONS(10272), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4316), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [238494] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9918), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6027), 1,
      sym_trailing_return_type,
    STATE(6843), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [238557] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7723), 1,
      anon_sym_STAR,
    ACTIONS(7725), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7727), 1,
      anon_sym_AMP,
    ACTIONS(8939), 1,
      anon_sym___asm,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6612), 1,
      sym__abstract_declarator,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [238608] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    ACTIONS(10276), 1,
      anon_sym_LPAREN2,
    ACTIONS(10278), 1,
      anon_sym_LBRACE,
    ACTIONS(10282), 1,
      anon_sym_requires,
    STATE(3001), 1,
      sym_template_type,
    STATE(4061), 1,
      sym_requirement_seq,
    STATE(6573), 1,
      sym_lambda_capture_specifier,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(8549), 1,
      sym_requires_parameter_list,
    ACTIONS(10280), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4163), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [238669] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10217), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10220), 1,
      anon_sym_requires,
    STATE(5995), 1,
      sym_trailing_return_type,
    STATE(6848), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [238732] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10223), 1,
      anon_sym___attribute__,
    ACTIONS(10226), 1,
      anon_sym___attribute,
    STATE(6755), 1,
      sym__function_attributes_end,
    STATE(6802), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [238795] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(6714), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
  [238858] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    ACTIONS(10284), 1,
      anon_sym_LPAREN2,
    ACTIONS(10286), 1,
      anon_sym_LBRACE,
    ACTIONS(10290), 1,
      anon_sym_requires,
    STATE(2359), 1,
      sym_template_type,
    STATE(2752), 1,
      sym_requirement_seq,
    STATE(6572), 1,
      sym_lambda_capture_specifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(8480), 1,
      sym_requires_parameter_list,
    ACTIONS(10288), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2753), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [238919] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6650), 1,
      sym_trailing_return_type,
    STATE(6718), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
  [238982] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10223), 1,
      anon_sym___attribute__,
    ACTIONS(10226), 1,
      anon_sym___attribute,
    ACTIONS(10238), 1,
      anon_sym_requires,
    STATE(6654), 1,
      sym_trailing_return_type,
    STATE(6739), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
  [239045] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6752), 1,
      sym__function_attributes_end,
    STATE(6800), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [239108] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    ACTIONS(10292), 1,
      anon_sym_LPAREN2,
    ACTIONS(10294), 1,
      anon_sym_LBRACE,
    ACTIONS(10298), 1,
      anon_sym_requires,
    STATE(2080), 1,
      sym_template_type,
    STATE(3731), 1,
      sym_requirement_seq,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(8256), 1,
      sym_requires_parameter_list,
    ACTIONS(10296), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4770), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [239169] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    ACTIONS(10300), 1,
      anon_sym_LPAREN2,
    ACTIONS(10302), 1,
      anon_sym_LBRACE,
    ACTIONS(10306), 1,
      anon_sym_requires,
    STATE(2385), 1,
      sym_template_type,
    STATE(4872), 1,
      sym_requirement_seq,
    STATE(6526), 1,
      sym_lambda_capture_specifier,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(8248), 1,
      sym_requires_parameter_list,
    ACTIONS(10304), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5481), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [239230] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7550), 1,
      anon_sym_STAR,
    ACTIONS(7552), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7554), 1,
      anon_sym_AMP,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6629), 1,
      sym__abstract_declarator,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [239281] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    STATE(6753), 1,
      sym__function_attributes_end,
    STATE(6801), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [239344] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    ACTIONS(9909), 1,
      anon_sym_requires,
    STATE(6788), 1,
      sym__function_attributes_end,
    STATE(6809), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [239407] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10217), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6044), 1,
      sym_trailing_return_type,
    STATE(6844), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [239470] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10223), 1,
      anon_sym___attribute__,
    ACTIONS(10226), 1,
      anon_sym___attribute,
    STATE(6642), 1,
      sym_trailing_return_type,
    STATE(6719), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
  [239533] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    ACTIONS(10155), 1,
      anon_sym_requires,
    STATE(6698), 1,
      sym__function_attributes_end,
    STATE(6810), 1,
      sym_trailing_return_type,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [239596] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    ACTIONS(10292), 1,
      anon_sym_LPAREN2,
    ACTIONS(10294), 1,
      anon_sym_LBRACE,
    ACTIONS(10298), 1,
      anon_sym_requires,
    STATE(3731), 1,
      sym_requirement_seq,
    STATE(4053), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(8256), 1,
      sym_requires_parameter_list,
    ACTIONS(10308), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4909), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [239657] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10013), 1,
      anon_sym___attribute__,
    ACTIONS(10016), 1,
      anon_sym___attribute,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    STATE(6738), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
  [239720] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    ACTIONS(9865), 1,
      anon_sym___attribute__,
    ACTIONS(9868), 1,
      anon_sym___attribute,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6737), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
  [239783] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6059), 1,
      sym_trailing_return_type,
    STATE(6842), 1,
      sym__function_attributes_end,
    STATE(7326), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5982), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6028), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [239846] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    STATE(6994), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9890), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
  [239908] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6930), 1,
      sym__function_attributes_end,
    STATE(7051), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
  [239970] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_SEMI,
    ACTIONS(10314), 1,
      anon_sym_LBRACE,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(10318), 1,
      anon_sym_EQ,
    ACTIONS(10320), 1,
      anon_sym_COLON,
    ACTIONS(10322), 1,
      anon_sym_try,
    STATE(1984), 1,
      sym_compound_statement,
    STATE(1985), 1,
      sym_default_method_clause,
    STATE(1986), 1,
      sym_delete_method_clause,
    STATE(1987), 1,
      sym_pure_virtual_clause,
    STATE(1988), 1,
      sym_try_statement,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7399), 1,
      sym_bitfield_clause,
    STATE(7401), 1,
      sym_initializer_list,
    STATE(7402), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8636), 1,
      sym_attribute_specifier,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [240044] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(10326), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6004), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10324), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [240086] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6931), 1,
      sym__function_attributes_end,
    STATE(7054), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9890), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240148] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(10197), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10328), 1,
      anon_sym_requires,
    STATE(6937), 1,
      sym__function_attributes_end,
    STATE(7083), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10189), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240210] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(10320), 1,
      anon_sym_COLON,
    ACTIONS(10331), 1,
      anon_sym_SEMI,
    ACTIONS(10333), 1,
      anon_sym_LBRACE,
    ACTIONS(10335), 1,
      anon_sym_EQ,
    ACTIONS(10337), 1,
      anon_sym_try,
    STATE(2021), 1,
      sym_compound_statement,
    STATE(2038), 1,
      sym_default_method_clause,
    STATE(2045), 1,
      sym_delete_method_clause,
    STATE(2046), 1,
      sym_pure_virtual_clause,
    STATE(2047), 1,
      sym_try_statement,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7398), 1,
      sym_bitfield_clause,
    STATE(7417), 1,
      sym_initializer_list,
    STATE(7425), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8691), 1,
      sym_attribute_specifier,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [240284] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(6535), 1,
      sym_ms_call_modifier,
    STATE(7248), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    ACTIONS(1870), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [240338] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6642), 1,
      sym_trailing_return_type,
    STATE(7017), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10189), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240400] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(10341), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6000), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10339), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [240442] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(9815), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_requires,
    STATE(6935), 1,
      sym__function_attributes_end,
    STATE(7130), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240504] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(9898), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10208), 1,
      anon_sym_requires,
    STATE(6936), 1,
      sym__function_attributes_end,
    STATE(7078), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9890), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240566] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10238), 1,
      anon_sym_requires,
    STATE(6654), 1,
      sym_trailing_return_type,
    STATE(6999), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10189), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240628] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(10197), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6932), 1,
      sym__function_attributes_end,
    STATE(7055), 1,
      sym_trailing_return_type,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(10189), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240690] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(6682), 1,
      sym_trailing_return_type,
    STATE(6985), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240752] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6635), 1,
      sym_trailing_return_type,
    STATE(7001), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9807), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240814] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(10320), 1,
      anon_sym_COLON,
    ACTIONS(10343), 1,
      anon_sym_SEMI,
    ACTIONS(10345), 1,
      anon_sym_LBRACE,
    ACTIONS(10347), 1,
      anon_sym_EQ,
    ACTIONS(10349), 1,
      anon_sym_try,
    STATE(1855), 1,
      sym_compound_statement,
    STATE(1857), 1,
      sym_default_method_clause,
    STATE(1858), 1,
      sym_delete_method_clause,
    STATE(1860), 1,
      sym_pure_virtual_clause,
    STATE(1861), 1,
      sym_try_statement,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7380), 1,
      sym_bitfield_clause,
    STATE(7381), 1,
      sym_initializer_list,
    STATE(7383), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8882), 1,
      sym_attribute_specifier,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [240888] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7185), 1,
      anon_sym___asm,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6650), 1,
      sym_trailing_return_type,
    STATE(7005), 1,
      sym__function_attributes_end,
    STATE(7353), 1,
      sym_gnu_asm_expression,
    ACTIONS(7183), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9890), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6012), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6272), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
  [240950] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(7877), 1,
      anon_sym_STAR,
    ACTIONS(7879), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7881), 1,
      anon_sym_AMP,
    ACTIONS(8939), 1,
      anon_sym___attribute,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6838), 1,
      sym__abstract_declarator,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [240999] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10353), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10351), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [241030] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8026), 1,
      anon_sym_STAR,
    ACTIONS(8028), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8030), 1,
      anon_sym_AMP,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6920), 1,
      sym__abstract_declarator,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [241076] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6427), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10357), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10355), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [241114] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_requires,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10361), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10359), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [241152] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(133), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2270), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(10369), 1,
      sym_identifier,
    ACTIONS(10371), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(5996), 1,
      sym__scope_resolution,
    STATE(7616), 1,
      sym_operator_cast,
    STATE(7666), 1,
      sym_qualified_operator_cast_identifier,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [241222] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    STATE(2080), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    ACTIONS(10375), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3689), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [241274] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(10377), 1,
      sym_identifier,
    ACTIONS(10379), 1,
      anon_sym_TILDE,
    ACTIONS(10381), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10383), 1,
      anon_sym_template,
    ACTIONS(10385), 1,
      anon_sym_operator,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(5998), 1,
      sym__scope_resolution,
    STATE(7616), 1,
      sym_operator_cast,
    STATE(7666), 1,
      sym_qualified_operator_cast_identifier,
    STATE(8622), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [241344] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10390), 1,
      anon_sym_requires,
    ACTIONS(10387), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6427), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10357), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10355), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [241382] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10326), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10324), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [241416] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(10393), 1,
      anon_sym_LPAREN2,
    ACTIONS(10397), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6532), 1,
      sym_lambda_capture_specifier,
    STATE(7225), 1,
      sym__scope_resolution,
    ACTIONS(10395), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6150), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [241468] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10399), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5860), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5862), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [241500] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10179), 1,
      sym_identifier,
    ACTIONS(10401), 1,
      anon_sym_LPAREN2,
    ACTIONS(10405), 1,
      anon_sym_requires,
    STATE(4645), 1,
      sym_template_type,
    STATE(6541), 1,
      sym_lambda_capture_specifier,
    STATE(7230), 1,
      sym__scope_resolution,
    ACTIONS(10403), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6484), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [241552] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10409), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10407), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [241586] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6528), 1,
      sym_lambda_capture_specifier,
    STATE(7229), 1,
      sym__scope_resolution,
    ACTIONS(10413), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6033), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [241638] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(133), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3836), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(10417), 1,
      sym_identifier,
    ACTIONS(10419), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6006), 1,
      sym__scope_resolution,
    STATE(7616), 1,
      sym_operator_cast,
    STATE(7666), 1,
      sym_qualified_operator_cast_identifier,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [241708] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    ACTIONS(10250), 1,
      anon_sym_requires,
    ACTIONS(10421), 1,
      anon_sym_LPAREN2,
    STATE(2904), 1,
      sym_template_type,
    STATE(6574), 1,
      sym_lambda_capture_specifier,
    STATE(7202), 1,
      sym__scope_resolution,
    ACTIONS(10423), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3921), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [241760] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    ACTIONS(10266), 1,
      anon_sym_requires,
    ACTIONS(10425), 1,
      anon_sym_LPAREN2,
    STATE(3004), 1,
      sym_template_type,
    STATE(6561), 1,
      sym_lambda_capture_specifier,
    STATE(7234), 1,
      sym__scope_resolution,
    ACTIONS(10427), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4047), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [241812] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(10393), 1,
      anon_sym_LPAREN2,
    ACTIONS(10397), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6532), 1,
      sym_lambda_capture_specifier,
    STATE(7225), 1,
      sym__scope_resolution,
    ACTIONS(10429), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(7079), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [241864] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10179), 1,
      sym_identifier,
    ACTIONS(10401), 1,
      anon_sym_LPAREN2,
    ACTIONS(10405), 1,
      anon_sym_requires,
    STATE(4645), 1,
      sym_template_type,
    STATE(6541), 1,
      sym_lambda_capture_specifier,
    STATE(7230), 1,
      sym__scope_resolution,
    ACTIONS(10431), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6473), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [241916] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10435), 1,
      anon_sym_LPAREN2,
    STATE(6352), 1,
      sym_preproc_argument_list,
    ACTIONS(10437), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10433), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [241950] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10341), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(4633), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6225), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10339), 13,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [241990] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10179), 1,
      sym_identifier,
    ACTIONS(10401), 1,
      anon_sym_LPAREN2,
    ACTIONS(10405), 1,
      anon_sym_requires,
    STATE(4645), 1,
      sym_template_type,
    STATE(6541), 1,
      sym_lambda_capture_specifier,
    STATE(7230), 1,
      sym__scope_resolution,
    ACTIONS(10439), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6459), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242042] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    STATE(2080), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7197), 1,
      sym__scope_resolution,
    ACTIONS(10441), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4758), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242094] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    ACTIONS(10258), 1,
      anon_sym_requires,
    ACTIONS(10443), 1,
      anon_sym_LPAREN2,
    STATE(4582), 1,
      sym_template_type,
    STATE(6569), 1,
      sym_lambda_capture_specifier,
    STATE(7195), 1,
      sym__scope_resolution,
    ACTIONS(10445), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5541), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242146] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    ACTIONS(10447), 1,
      sym_identifier,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    STATE(2181), 1,
      sym_template_type,
    STATE(6558), 1,
      sym_lambda_capture_specifier,
    STATE(7179), 1,
      sym__scope_resolution,
    ACTIONS(10451), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2184), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242198] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    ACTIONS(10282), 1,
      anon_sym_requires,
    ACTIONS(10453), 1,
      anon_sym_LPAREN2,
    STATE(3001), 1,
      sym_template_type,
    STATE(6573), 1,
      sym_lambda_capture_specifier,
    STATE(7218), 1,
      sym__scope_resolution,
    ACTIONS(10455), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4203), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242250] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    ACTIONS(10258), 1,
      anon_sym_requires,
    ACTIONS(10443), 1,
      anon_sym_LPAREN2,
    STATE(4582), 1,
      sym_template_type,
    STATE(6569), 1,
      sym_lambda_capture_specifier,
    STATE(7195), 1,
      sym__scope_resolution,
    ACTIONS(10457), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5542), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242302] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    ACTIONS(10274), 1,
      anon_sym_requires,
    ACTIONS(10459), 1,
      anon_sym_LPAREN2,
    STATE(3114), 1,
      sym_template_type,
    STATE(6545), 1,
      sym_lambda_capture_specifier,
    STATE(7183), 1,
      sym__scope_resolution,
    ACTIONS(10461), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4393), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242354] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    ACTIONS(10306), 1,
      anon_sym_requires,
    ACTIONS(10463), 1,
      anon_sym_LPAREN2,
    STATE(2385), 1,
      sym_template_type,
    STATE(6526), 1,
      sym_lambda_capture_specifier,
    STATE(7187), 1,
      sym__scope_resolution,
    ACTIONS(10465), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6855), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242406] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    STATE(4053), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7189), 1,
      sym__scope_resolution,
    ACTIONS(10467), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4886), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242458] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    ACTIONS(10469), 1,
      sym_identifier,
    ACTIONS(10471), 1,
      anon_sym_COLON_COLON,
    STATE(2080), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7204), 1,
      sym__scope_resolution,
    ACTIONS(10473), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6626), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242510] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6528), 1,
      sym_lambda_capture_specifier,
    STATE(7229), 1,
      sym__scope_resolution,
    ACTIONS(10475), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6002), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242562] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    ACTIONS(10469), 1,
      sym_identifier,
    ACTIONS(10471), 1,
      anon_sym_COLON_COLON,
    STATE(2080), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7204), 1,
      sym__scope_resolution,
    ACTIONS(10375), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3689), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242614] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    ACTIONS(10306), 1,
      anon_sym_requires,
    ACTIONS(10463), 1,
      anon_sym_LPAREN2,
    STATE(2385), 1,
      sym_template_type,
    STATE(6526), 1,
      sym_lambda_capture_specifier,
    STATE(7213), 1,
      sym__scope_resolution,
    ACTIONS(10477), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5509), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242666] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6528), 1,
      sym_lambda_capture_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    ACTIONS(10479), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(1697), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242718] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10200), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10189), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [242756] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10341), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10339), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [242790] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(10393), 1,
      anon_sym_LPAREN2,
    ACTIONS(10397), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6532), 1,
      sym_lambda_capture_specifier,
    STATE(7225), 1,
      sym__scope_resolution,
    ACTIONS(10481), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(7041), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242842] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6528), 1,
      sym_lambda_capture_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    ACTIONS(10483), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6796), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [242894] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10326), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(4633), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6302), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10324), 13,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [242934] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9818), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9807), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [242972] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10399), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(10485), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5871), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5873), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [243006] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    ACTIONS(10282), 1,
      anon_sym_requires,
    ACTIONS(10453), 1,
      anon_sym_LPAREN2,
    STATE(3001), 1,
      sym_template_type,
    STATE(6573), 1,
      sym_lambda_capture_specifier,
    STATE(7218), 1,
      sym__scope_resolution,
    ACTIONS(10487), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4033), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243058] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    STATE(2080), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7197), 1,
      sym__scope_resolution,
    ACTIONS(10375), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3689), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243110] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    ACTIONS(10447), 1,
      sym_identifier,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    STATE(2181), 1,
      sym_template_type,
    STATE(6558), 1,
      sym_lambda_capture_specifier,
    STATE(7179), 1,
      sym__scope_resolution,
    ACTIONS(10489), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2168), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243162] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    STATE(4053), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7189), 1,
      sym__scope_resolution,
    ACTIONS(10375), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3689), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243214] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6528), 1,
      sym_lambda_capture_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    ACTIONS(10491), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6887), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243266] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    ACTIONS(10393), 1,
      anon_sym_LPAREN2,
    ACTIONS(10397), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6532), 1,
      sym_lambda_capture_specifier,
    STATE(7210), 1,
      sym__scope_resolution,
    ACTIONS(10493), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6122), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243318] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6528), 1,
      sym_lambda_capture_specifier,
    STATE(7229), 1,
      sym__scope_resolution,
    ACTIONS(10479), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(1697), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243370] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    ACTIONS(10306), 1,
      anon_sym_requires,
    ACTIONS(10463), 1,
      anon_sym_LPAREN2,
    STATE(2385), 1,
      sym_template_type,
    STATE(6526), 1,
      sym_lambda_capture_specifier,
    STATE(7187), 1,
      sym__scope_resolution,
    ACTIONS(10495), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6881), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243422] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    ACTIONS(10469), 1,
      sym_identifier,
    ACTIONS(10471), 1,
      anon_sym_COLON_COLON,
    STATE(2080), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7204), 1,
      sym__scope_resolution,
    ACTIONS(10497), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6604), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243474] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    ACTIONS(10290), 1,
      anon_sym_requires,
    ACTIONS(10499), 1,
      anon_sym_LPAREN2,
    STATE(2359), 1,
      sym_template_type,
    STATE(6572), 1,
      sym_lambda_capture_specifier,
    STATE(7178), 1,
      sym__scope_resolution,
    ACTIONS(10501), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2835), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243526] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10361), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10359), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [243564] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    ACTIONS(10290), 1,
      anon_sym_requires,
    ACTIONS(10499), 1,
      anon_sym_LPAREN2,
    STATE(2359), 1,
      sym_template_type,
    STATE(6572), 1,
      sym_lambda_capture_specifier,
    STATE(7178), 1,
      sym__scope_resolution,
    ACTIONS(10503), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2836), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243616] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    ACTIONS(10306), 1,
      anon_sym_requires,
    ACTIONS(10463), 1,
      anon_sym_LPAREN2,
    STATE(2385), 1,
      sym_template_type,
    STATE(6526), 1,
      sym_lambda_capture_specifier,
    STATE(7187), 1,
      sym__scope_resolution,
    ACTIONS(10505), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4847), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243668] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8282), 1,
      anon_sym_STAR,
    ACTIONS(8284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8286), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym___attribute,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6903), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [243716] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    ACTIONS(10393), 1,
      anon_sym_LPAREN2,
    ACTIONS(10397), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6532), 1,
      sym_lambda_capture_specifier,
    STATE(7210), 1,
      sym__scope_resolution,
    ACTIONS(10507), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6149), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243768] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    ACTIONS(10306), 1,
      anon_sym_requires,
    ACTIONS(10463), 1,
      anon_sym_LPAREN2,
    STATE(2385), 1,
      sym_template_type,
    STATE(6526), 1,
      sym_lambda_capture_specifier,
    STATE(7213), 1,
      sym__scope_resolution,
    ACTIONS(10505), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4847), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243820] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    STATE(2080), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    ACTIONS(10509), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(7211), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243872] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9848), 1,
      anon_sym_requires,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9818), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9807), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [243910] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    ACTIONS(10393), 1,
      anon_sym_LPAREN2,
    ACTIONS(10397), 1,
      anon_sym_requires,
    STATE(2161), 1,
      sym_template_type,
    STATE(6532), 1,
      sym_lambda_capture_specifier,
    STATE(7210), 1,
      sym__scope_resolution,
    ACTIONS(10395), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6150), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [243962] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    ACTIONS(10250), 1,
      anon_sym_requires,
    ACTIONS(10421), 1,
      anon_sym_LPAREN2,
    STATE(2904), 1,
      sym_template_type,
    STATE(6574), 1,
      sym_lambda_capture_specifier,
    STATE(7202), 1,
      sym__scope_resolution,
    ACTIONS(10511), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3780), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [244014] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9921), 1,
      anon_sym_requires,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9901), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9890), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [244052] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10411), 1,
      anon_sym_LPAREN2,
    ACTIONS(10415), 1,
      anon_sym_requires,
    ACTIONS(10447), 1,
      sym_identifier,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    STATE(2181), 1,
      sym_template_type,
    STATE(6558), 1,
      sym_lambda_capture_specifier,
    STATE(7179), 1,
      sym__scope_resolution,
    ACTIONS(10479), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(1697), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [244104] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10220), 1,
      anon_sym_requires,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10200), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10189), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [244142] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    ACTIONS(10298), 1,
      anon_sym_requires,
    ACTIONS(10373), 1,
      anon_sym_LPAREN2,
    STATE(2080), 1,
      sym_template_type,
    STATE(6533), 1,
      sym_lambda_capture_specifier,
    STATE(7203), 1,
      sym__scope_resolution,
    ACTIONS(10513), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(7216), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [244194] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    ACTIONS(10266), 1,
      anon_sym_requires,
    ACTIONS(10425), 1,
      anon_sym_LPAREN2,
    STATE(3004), 1,
      sym_template_type,
    STATE(6561), 1,
      sym_lambda_capture_specifier,
    STATE(7234), 1,
      sym__scope_resolution,
    ACTIONS(10515), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4090), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [244246] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9901), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9890), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [244284] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2004), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    ACTIONS(10274), 1,
      anon_sym_requires,
    ACTIONS(10459), 1,
      anon_sym_LPAREN2,
    STATE(3114), 1,
      sym_template_type,
    STATE(6545), 1,
      sym_lambda_capture_specifier,
    STATE(7183), 1,
      sym__scope_resolution,
    ACTIONS(10517), 2,
      sym_true,
      sym_false,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4391), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [244336] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6116), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    ACTIONS(10521), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10519), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [244369] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2253), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [244428] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6427), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10357), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10355), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [244465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5335), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [244494] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10527), 1,
      anon_sym_SEMI,
    ACTIONS(10529), 1,
      anon_sym_LBRACE,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10537), 1,
      anon_sym_try,
    STATE(233), 1,
      sym_compound_statement,
    STATE(234), 1,
      sym_try_statement,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7927), 1,
      sym_gnu_asm_expression,
    STATE(8011), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [244555] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5313), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [244584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5293), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [244613] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10541), 1,
      anon_sym_RPAREN,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10551), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6075), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [244656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5327), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [244685] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    ACTIONS(10555), 1,
      anon_sym_SEMI,
    STATE(5979), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(8904), 1,
      sym_attribute_specifier,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [244738] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2230), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [244797] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2235), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6076), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [244856] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2133), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [244915] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(1850), 1,
      anon_sym_LBRACE,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10557), 1,
      anon_sym_SEMI,
    ACTIONS(10559), 1,
      anon_sym_try,
    STATE(724), 1,
      sym_compound_statement,
    STATE(726), 1,
      sym_try_statement,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(8144), 1,
      sym_gnu_asm_expression,
    STATE(8150), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [244976] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10561), 1,
      anon_sym_COMMA,
    ACTIONS(10563), 1,
      anon_sym_RPAREN,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10571), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10573), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10575), 1,
      anon_sym_PIPE,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    STATE(7770), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [245031] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2259), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245090] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3314), 1,
      sym__class_declaration_item,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6079), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245149] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3321), 1,
      sym__class_declaration_item,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245208] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3304), 1,
      sym__class_declaration_item,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245267] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3329), 1,
      sym__class_declaration_item,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6081), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245326] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_field_declaration_list,
    STATE(3439), 1,
      sym__class_declaration_item,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(7691), 1,
      sym_virtual_specifier,
    STATE(8214), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2711), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245385] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2130), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6106), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245444] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2148), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245503] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2259), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245562] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4771), 1,
      sym__class_declaration_item,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6090), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245621] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4779), 1,
      sym__class_declaration_item,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245680] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    ACTIONS(10589), 1,
      anon_sym_SEMI,
    STATE(5975), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9138), 1,
      sym_attribute_specifier,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [245733] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10591), 1,
      anon_sym_SEMI,
    ACTIONS(10593), 1,
      anon_sym_LBRACE,
    ACTIONS(10595), 1,
      anon_sym_try,
    STATE(531), 1,
      sym_compound_statement,
    STATE(532), 1,
      sym_try_statement,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7870), 1,
      sym_gnu_asm_expression,
    STATE(7871), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [245794] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2230), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245853] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4826), 1,
      sym__class_declaration_item,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245912] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4831), 1,
      sym__class_declaration_item,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6094), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [245971] = 5,
    ACTIONS(10433), 1,
      anon_sym_LF,
    ACTIONS(10597), 1,
      anon_sym_LPAREN2,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(6429), 1,
      sym_preproc_argument_list,
    ACTIONS(10437), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [246004] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2235), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6084), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246063] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4757), 1,
      sym__class_declaration_item,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246122] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2513), 1,
      sym__class_declaration_item,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6097), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246181] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2519), 1,
      sym__class_declaration_item,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246240] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2488), 1,
      sym__class_declaration_item,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246299] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2492), 1,
      sym__class_declaration_item,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6099), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246358] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2448), 1,
      sym_field_declaration_list,
    STATE(2556), 1,
      sym__class_declaration_item,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(7636), 1,
      sym_virtual_specifier,
    STATE(8420), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2284), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246417] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2245), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6089), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246476] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2245), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6104), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246535] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2253), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246594] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(10322), 1,
      anon_sym_try,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10601), 1,
      anon_sym_SEMI,
    ACTIONS(10603), 1,
      anon_sym_LBRACE,
    STATE(2030), 1,
      sym_compound_statement,
    STATE(2036), 1,
      sym_try_statement,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(8121), 1,
      sym_gnu_asm_expression,
    STATE(8122), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [246655] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2230), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246714] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2235), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6108), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246773] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2116), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246832] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2154), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6140), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246891] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2259), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [246950] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2503), 1,
      sym__class_declaration_item,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6111), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247009] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2515), 1,
      sym__class_declaration_item,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247068] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2545), 1,
      sym__class_declaration_item,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247127] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2559), 1,
      sym__class_declaration_item,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6113), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247186] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2592), 1,
      sym__class_declaration_item,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247245] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2253), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247304] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9901), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9890), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [247341] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10609), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6116), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    ACTIONS(10607), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10605), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [247374] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4771), 1,
      sym__class_declaration_item,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6120), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247433] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4779), 1,
      sym__class_declaration_item,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247492] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(10349), 1,
      anon_sym_try,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10612), 1,
      anon_sym_SEMI,
    ACTIONS(10614), 1,
      anon_sym_LBRACE,
    STATE(1812), 1,
      sym_compound_statement,
    STATE(1813), 1,
      sym_try_statement,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7798), 1,
      sym_gnu_asm_expression,
    STATE(7807), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [247553] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4826), 1,
      sym__class_declaration_item,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247612] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4831), 1,
      sym__class_declaration_item,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6123), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247671] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10616), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(10618), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5871), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5873), 14,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [247704] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4742), 1,
      sym_field_declaration_list,
    STATE(4757), 1,
      sym__class_declaration_item,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7529), 1,
      sym_virtual_specifier,
    STATE(8482), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4524), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247763] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2503), 1,
      sym__class_declaration_item,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6128), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247822] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2515), 1,
      sym__class_declaration_item,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [247881] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(133), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(10620), 1,
      sym_identifier,
    ACTIONS(10622), 1,
      anon_sym_template,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6126), 1,
      sym__scope_resolution,
    STATE(7616), 1,
      sym_operator_cast,
    STATE(7666), 1,
      sym_qualified_operator_cast_identifier,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [247944] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10624), 1,
      anon_sym_RPAREN,
    ACTIONS(10626), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6182), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [247987] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2545), 1,
      sym__class_declaration_item,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248046] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2559), 1,
      sym__class_declaration_item,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6130), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248105] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2474), 1,
      sym_field_declaration_list,
    STATE(2592), 1,
      sym__class_declaration_item,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(7520), 1,
      sym_virtual_specifier,
    STATE(8266), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2286), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248164] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9823), 1,
      anon_sym_requires,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9818), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9807), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [248201] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(10337), 1,
      anon_sym_try,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10628), 1,
      anon_sym_SEMI,
    ACTIONS(10630), 1,
      anon_sym_LBRACE,
    STATE(2008), 1,
      sym_compound_statement,
    STATE(2009), 1,
      sym_try_statement,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7820), 1,
      sym_gnu_asm_expression,
    STATE(7824), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [248262] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3870), 1,
      sym__class_declaration_item,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6136), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248321] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3875), 1,
      sym__class_declaration_item,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248380] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(1930), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [248409] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3951), 1,
      sym__class_declaration_item,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248468] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3957), 1,
      sym__class_declaration_item,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6138), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248527] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3445), 1,
      sym_field_declaration_list,
    STATE(3993), 1,
      sym__class_declaration_item,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(7674), 1,
      sym_virtual_specifier,
    STATE(8476), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2933), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248586] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(1926), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [248615] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2133), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248674] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5235), 1,
      sym__class_declaration_item,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6143), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248733] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5188), 1,
      sym__class_declaration_item,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248792] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5024), 1,
      sym__class_declaration_item,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248851] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5033), 1,
      sym__class_declaration_item,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6216), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248910] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2245), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3068), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6071), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [248969] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10634), 1,
      anon_sym_LPAREN2,
    ACTIONS(10636), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10632), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [249000] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9818), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9807), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [249037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5339), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [249066] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10618), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5860), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5862), 16,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [249097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5317), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [249126] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3540), 1,
      sym__class_declaration_item,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6153), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249185] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3543), 1,
      sym__class_declaration_item,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249244] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3570), 1,
      sym__class_declaration_item,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249303] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3573), 1,
      sym__class_declaration_item,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6155), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249362] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3186), 1,
      sym_field_declaration_list,
    STATE(3595), 1,
      sym__class_declaration_item,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(7548), 1,
      sym_virtual_specifier,
    STATE(8474), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2744), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249421] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9906), 1,
      anon_sym_requires,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9901), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9890), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [249458] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5215), 1,
      sym__class_declaration_item,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6159), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249517] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5023), 1,
      sym__class_declaration_item,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249576] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5157), 1,
      sym__class_declaration_item,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249635] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5202), 1,
      sym__class_declaration_item,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249694] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4980), 1,
      sym_field_declaration_list,
    STATE(5062), 1,
      sym__class_declaration_item,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(7611), 1,
      sym_virtual_specifier,
    STATE(8240), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4631), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249753] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3642), 1,
      sym__class_declaration_item,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6164), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249812] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3645), 1,
      sym__class_declaration_item,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249871] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3668), 1,
      sym__class_declaration_item,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249930] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3671), 1,
      sym__class_declaration_item,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6166), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [249989] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3155), 1,
      sym_field_declaration_list,
    STATE(3454), 1,
      sym__class_declaration_item,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(7654), 1,
      sym_virtual_specifier,
    STATE(8312), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2803), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250048] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10205), 1,
      anon_sym_requires,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10200), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10189), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [250085] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10638), 1,
      anon_sym_requires,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10361), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10359), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [250122] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2245), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6173), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250181] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2253), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250240] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10641), 1,
      anon_sym_requires,
    ACTIONS(10387), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6427), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10357), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10355), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [250277] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2245), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6184), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250336] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2230), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250395] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2235), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6176), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250454] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2253), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250513] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2259), 1,
      sym__class_declaration_item,
    STATE(2588), 1,
      sym_field_declaration_list,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(7643), 1,
      sym_virtual_specifier,
    STATE(8453), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2267), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250572] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10646), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10644), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [250601] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10650), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10648), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [250630] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10652), 1,
      anon_sym_SEMI,
    ACTIONS(10654), 1,
      anon_sym_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_try,
    STATE(533), 1,
      sym_compound_statement,
    STATE(534), 1,
      sym_try_statement,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7865), 1,
      sym_gnu_asm_expression,
    STATE(7866), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [250691] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10200), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10189), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [250728] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10658), 1,
      anon_sym_RPAREN,
    ACTIONS(10660), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6187), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [250771] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10561), 1,
      anon_sym_COMMA,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10571), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10573), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10575), 1,
      anon_sym_PIPE,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(10662), 1,
      anon_sym_RPAREN,
    STATE(7924), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [250826] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    ACTIONS(10664), 1,
      anon_sym_SEMI,
    STATE(5989), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(8712), 1,
      sym_attribute_specifier,
    STATE(9140), 1,
      sym_ms_based_modifier,
    ACTIONS(43), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [250879] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2230), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250938] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2235), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6189), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [250997] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2130), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6200), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251056] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10561), 1,
      anon_sym_COMMA,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10571), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10573), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10575), 1,
      anon_sym_PIPE,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(10666), 1,
      anon_sym_RPAREN,
    STATE(7997), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [251111] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2148), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251170] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2259), 1,
      sym__class_declaration_item,
    STATE(2903), 1,
      sym_field_declaration_list,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(7743), 1,
      sym_virtual_specifier,
    STATE(8538), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2652), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251229] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8369), 1,
      anon_sym_STAR,
    ACTIONS(8371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(6984), 1,
      sym__abstract_declarator,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [251274] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2130), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6193), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251333] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2148), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251392] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2116), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251451] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2154), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6196), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10670), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10668), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [251539] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2133), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_field_declaration_list,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(7688), 1,
      sym_virtual_specifier,
    STATE(8497), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4733), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10674), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10672), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [251627] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10361), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10359), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [251664] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4599), 1,
      sym__class_declaration_item,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6203), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251723] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2116), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251782] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4620), 1,
      sym__class_declaration_item,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5331), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [251870] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4624), 1,
      sym__class_declaration_item,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251929] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4611), 1,
      sym__class_declaration_item,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6207), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [251988] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2154), 1,
      sym__class_declaration_item,
    STATE(2303), 1,
      sym_field_declaration_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(7651), 1,
      sym_virtual_specifier,
    STATE(8219), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2217), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(6073), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [252047] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5305), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252076] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4447), 1,
      sym_field_declaration_list,
    STATE(4652), 1,
      sym__class_declaration_item,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(7702), 1,
      sym_virtual_specifier,
    STATE(8365), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3457), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [252135] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5289), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252164] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5289), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252193] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5289), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5297), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5301), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5309), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5285), 18,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_and,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10678), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10676), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [252367] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6149), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_field_declaration_list,
    STATE(5152), 1,
      sym__class_declaration_item,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(7595), 1,
      sym_virtual_specifier,
    STATE(8293), 1,
      sym_base_class_clause,
    ACTIONS(6151), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4405), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [252426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10682), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10680), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [252454] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10692), 1,
      anon_sym_RBRACK,
    ACTIONS(10694), 1,
      sym_this,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [252506] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(10696), 1,
      sym_identifier,
    ACTIONS(10698), 1,
      anon_sym_TILDE,
    ACTIONS(10700), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10702), 1,
      anon_sym_template,
    ACTIONS(10704), 1,
      anon_sym_operator,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3799), 1,
      sym_pointer_type_declarator,
    STATE(3801), 1,
      sym_template_function,
    STATE(3803), 1,
      sym_destructor_name,
    STATE(3810), 1,
      sym_dependent_identifier,
    STATE(3813), 1,
      sym_qualified_identifier,
    STATE(3814), 1,
      sym_operator_name,
    STATE(6219), 1,
      sym__scope_resolution,
    STATE(8652), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [252570] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10706), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [252622] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8508), 1,
      anon_sym_STAR,
    ACTIONS(8510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8512), 1,
      anon_sym_AMP,
    ACTIONS(8939), 1,
      anon_sym___attribute,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7096), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [252668] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10708), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [252720] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10710), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6223), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6561), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6563), 14,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252752] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10715), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10713), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [252780] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6223), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10326), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10324), 14,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [252812] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8405), 1,
      anon_sym_STAR,
    ACTIONS(8407), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8409), 1,
      anon_sym_AMP,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7081), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [252856] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(10717), 1,
      sym_identifier,
    ACTIONS(10719), 1,
      anon_sym_TILDE,
    ACTIONS(10721), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10723), 1,
      anon_sym_template,
    ACTIONS(10725), 1,
      anon_sym_operator,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3742), 1,
      sym_pointer_type_declarator,
    STATE(3744), 1,
      sym_template_function,
    STATE(3745), 1,
      sym_destructor_name,
    STATE(3748), 1,
      sym_dependent_identifier,
    STATE(3749), 1,
      sym_qualified_identifier,
    STATE(3755), 1,
      sym_operator_name,
    STATE(6227), 1,
      sym__scope_resolution,
    STATE(8652), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [252920] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10727), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [252972] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8516), 1,
      anon_sym_STAR,
    ACTIONS(8518), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8520), 1,
      anon_sym_AMP,
    ACTIONS(8939), 1,
      anon_sym___attribute,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7106), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [253018] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10729), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [253070] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10731), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6316), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [253110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10735), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10733), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [253138] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10739), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10737), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [253170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10739), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10737), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [253198] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(10698), 1,
      anon_sym_TILDE,
    ACTIONS(10704), 1,
      anon_sym_operator,
    ACTIONS(10741), 1,
      sym_identifier,
    ACTIONS(10743), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10745), 1,
      anon_sym_template,
    STATE(1949), 1,
      sym_template_type,
    STATE(1950), 1,
      sym_dependent_type_identifier,
    STATE(2159), 1,
      sym_qualified_type_identifier,
    STATE(3799), 1,
      sym_pointer_type_declarator,
    STATE(3801), 1,
      sym_template_function,
    STATE(3803), 1,
      sym_destructor_name,
    STATE(3810), 1,
      sym_dependent_identifier,
    STATE(3813), 1,
      sym_qualified_identifier,
    STATE(3814), 1,
      sym_operator_name,
    STATE(6235), 1,
      sym__scope_resolution,
    STATE(8652), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [253262] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10573), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10575), 1,
      anon_sym_PIPE,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10737), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
  [253310] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10575), 1,
      anon_sym_PIPE,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10737), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [253356] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(10739), 1,
      anon_sym_PIPE,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10737), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [253402] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(10739), 1,
      anon_sym_PIPE,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10737), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
  [253446] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10739), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(10737), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
  [253488] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10739), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(10737), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [253528] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10739), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10737), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [253564] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10739), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10737), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [253598] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10747), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [253650] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10749), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [253702] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(10719), 1,
      anon_sym_TILDE,
    ACTIONS(10725), 1,
      anon_sym_operator,
    ACTIONS(10751), 1,
      sym_identifier,
    ACTIONS(10753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10755), 1,
      anon_sym_template,
    STATE(1949), 1,
      sym_template_type,
    STATE(1950), 1,
      sym_dependent_type_identifier,
    STATE(2159), 1,
      sym_qualified_type_identifier,
    STATE(3742), 1,
      sym_pointer_type_declarator,
    STATE(3744), 1,
      sym_template_function,
    STATE(3745), 1,
      sym_destructor_name,
    STATE(3748), 1,
      sym_dependent_identifier,
    STATE(3749), 1,
      sym_qualified_identifier,
    STATE(3755), 1,
      sym_operator_name,
    STATE(6246), 1,
      sym__scope_resolution,
    STATE(8652), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [253766] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10767), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6451), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [253806] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10771), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6452), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [253846] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10773), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6455), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [253886] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10775), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6456), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [253926] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10777), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6376), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [253966] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10779), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6377), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254006] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10781), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6381), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254046] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10783), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6382), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254086] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10785), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6403), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254126] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10787), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6404), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254166] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10789), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6380), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254206] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10791), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [254258] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10793), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6405), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254298] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(10795), 1,
      sym_identifier,
    ACTIONS(10797), 1,
      anon_sym_TILDE,
    ACTIONS(10799), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10801), 1,
      anon_sym_template,
    ACTIONS(10803), 1,
      anon_sym_operator,
    STATE(1949), 1,
      sym_template_type,
    STATE(1950), 1,
      sym_dependent_type_identifier,
    STATE(2159), 1,
      sym_qualified_type_identifier,
    STATE(2762), 1,
      sym_pointer_type_declarator,
    STATE(2763), 1,
      sym_template_function,
    STATE(2764), 1,
      sym_destructor_name,
    STATE(2765), 1,
      sym_dependent_identifier,
    STATE(2766), 1,
      sym_qualified_identifier,
    STATE(2767), 1,
      sym_operator_name,
    STATE(6260), 1,
      sym__scope_resolution,
    STATE(8622), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [254362] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10805), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [254414] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10807), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6384), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254454] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10809), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [254506] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10811), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6401), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254546] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10813), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6407), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254586] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(10797), 1,
      anon_sym_TILDE,
    ACTIONS(10803), 1,
      anon_sym_operator,
    ACTIONS(10815), 1,
      sym_identifier,
    ACTIONS(10817), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10819), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(2762), 1,
      sym_pointer_type_declarator,
    STATE(2763), 1,
      sym_template_function,
    STATE(2764), 1,
      sym_destructor_name,
    STATE(2765), 1,
      sym_dependent_identifier,
    STATE(2766), 1,
      sym_qualified_identifier,
    STATE(2767), 1,
      sym_operator_name,
    STATE(6266), 1,
      sym__scope_resolution,
    STATE(8622), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [254650] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4593), 1,
      anon_sym_RBRACK,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [254702] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10821), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [254754] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10823), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [254806] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4619), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(10825), 1,
      sym_identifier,
    ACTIONS(10827), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6270), 1,
      sym__scope_resolution,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [254870] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10829), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6424), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [254910] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6223), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10341), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10339), 14,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [254942] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10833), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10831), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [254970] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(10835), 1,
      sym_identifier,
    ACTIONS(10837), 1,
      anon_sym_TILDE,
    ACTIONS(10839), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10841), 1,
      anon_sym_template,
    ACTIONS(10843), 1,
      anon_sym_operator,
    STATE(2378), 1,
      sym_template_type,
    STATE(2394), 1,
      sym_dependent_type_identifier,
    STATE(2419), 1,
      sym_qualified_type_identifier,
    STATE(4218), 1,
      sym_pointer_type_declarator,
    STATE(4221), 1,
      sym_template_function,
    STATE(4222), 1,
      sym_destructor_name,
    STATE(4223), 1,
      sym_dependent_identifier,
    STATE(4224), 1,
      sym_qualified_identifier,
    STATE(4225), 1,
      sym_operator_name,
    STATE(6274), 1,
      sym__scope_resolution,
    STATE(8621), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [255034] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10845), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [255086] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10847), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [255138] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10849), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [255190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10853), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10851), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [255218] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(10698), 1,
      anon_sym_TILDE,
    ACTIONS(10704), 1,
      anon_sym_operator,
    ACTIONS(10855), 1,
      sym_identifier,
    ACTIONS(10857), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10859), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3799), 1,
      sym_pointer_type_declarator,
    STATE(3801), 1,
      sym_template_function,
    STATE(3803), 1,
      sym_destructor_name,
    STATE(3810), 1,
      sym_dependent_identifier,
    STATE(3813), 1,
      sym_qualified_identifier,
    STATE(3814), 1,
      sym_operator_name,
    STATE(6279), 1,
      sym__scope_resolution,
    STATE(8652), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [255282] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4593), 1,
      anon_sym_RBRACK,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10861), 1,
      sym_identifier,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [255334] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10863), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [255386] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(10865), 1,
      sym_identifier,
    ACTIONS(10867), 1,
      anon_sym_TILDE,
    ACTIONS(10869), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10871), 1,
      anon_sym_template,
    ACTIONS(10873), 1,
      anon_sym_operator,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(4065), 1,
      sym_pointer_type_declarator,
    STATE(4066), 1,
      sym_template_function,
    STATE(4067), 1,
      sym_destructor_name,
    STATE(4069), 1,
      sym_dependent_identifier,
    STATE(4070), 1,
      sym_qualified_identifier,
    STATE(4071), 1,
      sym_operator_name,
    STATE(6282), 1,
      sym__scope_resolution,
    STATE(8863), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [255450] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10875), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6430), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [255490] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(10837), 1,
      anon_sym_TILDE,
    ACTIONS(10843), 1,
      anon_sym_operator,
    ACTIONS(10877), 1,
      sym_identifier,
    ACTIONS(10879), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10881), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(4218), 1,
      sym_pointer_type_declarator,
    STATE(4221), 1,
      sym_template_function,
    STATE(4222), 1,
      sym_destructor_name,
    STATE(4223), 1,
      sym_dependent_identifier,
    STATE(4224), 1,
      sym_qualified_identifier,
    STATE(4225), 1,
      sym_operator_name,
    STATE(6284), 1,
      sym__scope_resolution,
    STATE(8621), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [255554] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(10797), 1,
      anon_sym_TILDE,
    ACTIONS(10803), 1,
      anon_sym_operator,
    ACTIONS(10883), 1,
      sym_identifier,
    ACTIONS(10885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10887), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(2762), 1,
      sym_pointer_type_declarator,
    STATE(2763), 1,
      sym_template_function,
    STATE(2764), 1,
      sym_destructor_name,
    STATE(2765), 1,
      sym_dependent_identifier,
    STATE(2766), 1,
      sym_qualified_identifier,
    STATE(2767), 1,
      sym_operator_name,
    STATE(6285), 1,
      sym__scope_resolution,
    STATE(8622), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [255618] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4205), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(10889), 1,
      sym_identifier,
    ACTIONS(10891), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6286), 1,
      sym__scope_resolution,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [255682] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8488), 1,
      anon_sym_STAR,
    ACTIONS(8490), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8492), 1,
      anon_sym_AMP,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7102), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [255726] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10893), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6435), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [255766] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10895), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6354), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [255806] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7456), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [255856] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(10797), 1,
      anon_sym_TILDE,
    ACTIONS(10803), 1,
      anon_sym_operator,
    ACTIONS(10897), 1,
      sym_identifier,
    ACTIONS(10899), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10901), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(2762), 1,
      sym_pointer_type_declarator,
    STATE(2763), 1,
      sym_template_function,
    STATE(2764), 1,
      sym_destructor_name,
    STATE(2765), 1,
      sym_dependent_identifier,
    STATE(2766), 1,
      sym_qualified_identifier,
    STATE(2767), 1,
      sym_operator_name,
    STATE(6291), 1,
      sym__scope_resolution,
    STATE(8622), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [255920] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10903), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [255972] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10905), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [256024] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7511), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [256074] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10907), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [256126] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10909), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [256178] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7193), 1,
      anon_sym_requires,
    STATE(6115), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9818), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [256218] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10911), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [256270] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7193), 1,
      anon_sym_requires,
    STATE(6180), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9901), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [256310] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7193), 1,
      anon_sym_requires,
    STATE(6198), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10200), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [256350] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(7193), 1,
      anon_sym_requires,
    STATE(6063), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10361), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [256390] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6223), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10409), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10407), 14,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [256422] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    STATE(6059), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9818), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [256462] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    STATE(6027), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9901), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [256502] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(10379), 1,
      anon_sym_TILDE,
    ACTIONS(10913), 1,
      sym_identifier,
    ACTIONS(10915), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10917), 1,
      anon_sym_template,
    ACTIONS(10919), 1,
      anon_sym_operator,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6305), 1,
      sym__scope_resolution,
    STATE(8622), 1,
      sym_ms_based_modifier,
    STATE(9247), 1,
      sym_decltype,
  [256566] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    STATE(5994), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10361), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [256606] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(6156), 1,
      sym_trailing_return_type,
    ACTIONS(9818), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [256646] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(9906), 1,
      anon_sym_requires,
    STATE(6167), 1,
      sym_trailing_return_type,
    ACTIONS(9901), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [256686] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(10205), 1,
      anon_sym_requires,
    STATE(6168), 1,
      sym_trailing_return_type,
    ACTIONS(10200), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [256726] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7187), 1,
      anon_sym_DASH_GT,
    ACTIONS(10638), 1,
      anon_sym_requires,
    STATE(6171), 1,
      sym_trailing_return_type,
    ACTIONS(10361), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [256766] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(6054), 1,
      sym_trailing_return_type,
    ACTIONS(9818), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [256806] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(9921), 1,
      anon_sym_requires,
    STATE(6056), 1,
      sym_trailing_return_type,
    ACTIONS(9901), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [256846] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(10220), 1,
      anon_sym_requires,
    STATE(5995), 1,
      sym_trailing_return_type,
    ACTIONS(10200), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [256886] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(10366), 1,
      anon_sym_requires,
    STATE(5999), 1,
      sym_trailing_return_type,
    ACTIONS(10361), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [256926] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10921), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [256978] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10571), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10573), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10575), 1,
      anon_sym_PIPE,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10923), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [257028] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7504), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [257078] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7487), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [257128] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10925), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [257180] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7486), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [257230] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10927), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [257282] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    STATE(6115), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9818), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [257322] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    STATE(6180), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9901), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [257362] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10929), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6440), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [257402] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    STATE(6198), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10200), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [257442] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    STATE(6063), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10361), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [257482] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(6156), 1,
      sym_trailing_return_type,
    ACTIONS(9818), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [257522] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(9906), 1,
      anon_sym_requires,
    STATE(6167), 1,
      sym_trailing_return_type,
    ACTIONS(9901), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [257562] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(10205), 1,
      anon_sym_requires,
    STATE(6168), 1,
      sym_trailing_return_type,
    ACTIONS(10200), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [257602] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7219), 1,
      anon_sym_DASH_GT,
    ACTIONS(10638), 1,
      anon_sym_requires,
    STATE(6171), 1,
      sym_trailing_return_type,
    ACTIONS(10361), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [257642] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10931), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6388), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [257682] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10933), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6402), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [257722] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7458), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [257772] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10935), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6442), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [257812] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7499), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [257862] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7505), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [257912] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7461), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [257962] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7474), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258012] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7735), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7737), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [258040] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7498), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258090] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7437), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258140] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7468), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258190] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7490), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258240] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7450), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258290] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7452), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258340] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7463), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258390] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7119), 1,
      sym__type_declarator,
    STATE(7471), 1,
      sym__type_definition_declarators,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [258440] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10937), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6449), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [258480] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10939), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [258532] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10941), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [258584] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10943), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6410), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [258624] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10947), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10945), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [258652] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10951), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10949), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [258680] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10955), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10953), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [258708] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10957), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6233), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [258748] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10959), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6234), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [258788] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10961), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6236), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [258828] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10963), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6237), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [258868] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10965), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6238), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [258908] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10967), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [258960] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10969), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6239), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [259000] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10971), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6240), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [259040] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10973), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6241), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [259080] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10975), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6450), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [259120] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10977), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [259172] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10979), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [259224] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10981), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6386), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [259264] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10757), 1,
      sym_identifier,
    ACTIONS(10759), 1,
      anon_sym_LPAREN2,
    ACTIONS(10761), 1,
      anon_sym_defined,
    ACTIONS(10983), 1,
      sym_number_literal,
    ACTIONS(10763), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10769), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6397), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [259304] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10985), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6242), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [259344] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10539), 1,
      sym_identifier,
    ACTIONS(10543), 1,
      anon_sym_LPAREN2,
    ACTIONS(10545), 1,
      anon_sym_defined,
    ACTIONS(10987), 1,
      sym_number_literal,
    ACTIONS(10547), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(10549), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10553), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(6243), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [259384] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4595), 1,
      anon_sym_EQ,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10688), 1,
      anon_sym_AMP,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10694), 1,
      sym_this,
    ACTIONS(10989), 1,
      anon_sym_RBRACK,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8280), 1,
      sym_lambda_default_capture,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7899), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [259436] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7307), 1,
      anon_sym_DASH_GT,
    ACTIONS(7309), 1,
      anon_sym_requires,
    STATE(6044), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10200), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [259476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10993), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10991), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [259503] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10851), 1,
      anon_sym_LF,
    ACTIONS(10853), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [259530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10997), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10995), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [259557] = 10,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(10739), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [259598] = 9,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(10739), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [259637] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11013), 1,
      sym_identifier,
    ACTIONS(11015), 1,
      anon_sym_template,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [259694] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(8631), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8633), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7331), 1,
      sym__type_declarator,
    STATE(9229), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [259741] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11017), 1,
      anon_sym_LF,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [259786] = 8,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(10739), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
  [259823] = 7,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(10739), 7,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [259858] = 3,
    ACTIONS(7737), 1,
      anon_sym_LF,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(7735), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [259885] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11025), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [259930] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7309), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [259977] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11027), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [260022] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10831), 1,
      anon_sym_LF,
    ACTIONS(10833), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [260049] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10571), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10573), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10575), 1,
      anon_sym_PIPE,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(11029), 1,
      anon_sym_RPAREN,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [260098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11033), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11031), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [260125] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(6540), 1,
      sym_template_argument_list,
    ACTIONS(7475), 4,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym___asm,
    ACTIONS(5099), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [260158] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5935), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(11035), 1,
      sym_identifier,
    ACTIONS(11037), 1,
      anon_sym_template,
    STATE(6391), 1,
      sym__scope_resolution,
    STATE(6591), 1,
      sym_pointer_type_declarator,
    STATE(6593), 1,
      sym_template_function,
    STATE(6594), 1,
      sym_destructor_name,
    STATE(6595), 1,
      sym_dependent_identifier,
    STATE(6597), 1,
      sym_qualified_identifier,
    STATE(6603), 1,
      sym_operator_name,
    STATE(9172), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [260215] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11041), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11039), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [260242] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(10620), 1,
      sym_identifier,
    ACTIONS(10622), 1,
      anon_sym_template,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6393), 1,
      sym__scope_resolution,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [260299] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10949), 1,
      anon_sym_LF,
    ACTIONS(10951), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [260326] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8567), 1,
      anon_sym_STAR,
    ACTIONS(8569), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8571), 1,
      anon_sym_AMP,
    ACTIONS(8575), 1,
      sym_primitive_type,
    STATE(2466), 1,
      sym__type_declarator,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(8622), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [260373] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11045), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11043), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [260400] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11047), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [260445] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7286), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(11049), 1,
      sym_identifier,
    ACTIONS(11051), 1,
      anon_sym_template,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6398), 1,
      sym__scope_resolution,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [260502] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(6540), 1,
      sym_template_argument_list,
    ACTIONS(4521), 4,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym___asm,
    ACTIONS(4514), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [260535] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8635), 1,
      sym_identifier,
    ACTIONS(8637), 1,
      anon_sym_LPAREN2,
    ACTIONS(8639), 1,
      anon_sym_STAR,
    ACTIONS(8641), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8643), 1,
      anon_sym_AMP,
    ACTIONS(8647), 1,
      sym_primitive_type,
    STATE(3387), 1,
      sym__type_declarator,
    STATE(3855), 1,
      sym_pointer_type_declarator,
    STATE(8621), 1,
      sym_ms_based_modifier,
    ACTIONS(8645), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3853), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [260582] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11053), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [260627] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10953), 1,
      anon_sym_LF,
    ACTIONS(10955), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [260654] = 6,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(10739), 11,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [260687] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(10739), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [260718] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11055), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [260763] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7355), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [260810] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11057), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [260855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11061), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11059), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [260882] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7342), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [260929] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11063), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [260974] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7336), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [261021] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11067), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11065), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261048] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11071), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11069), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11075), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11073), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261102] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10713), 1,
      anon_sym_LF,
    ACTIONS(10715), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [261129] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(2998), 1,
      sym_template_argument_list,
    ACTIONS(5669), 2,
      anon_sym___attribute,
      anon_sym_COLON,
    ACTIONS(4028), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [261162] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(11077), 1,
      sym_identifier,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11081), 1,
      anon_sym_template,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(9018), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [261219] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(8555), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8557), 1,
      anon_sym_AMP,
    ACTIONS(8561), 1,
      sym_primitive_type,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(6875), 1,
      sym__type_declarator,
    STATE(8992), 1,
      sym_ms_based_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [261266] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10200), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10189), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261293] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8533), 1,
      sym_identifier,
    ACTIONS(8535), 1,
      anon_sym_LPAREN2,
    ACTIONS(8537), 1,
      anon_sym_STAR,
    ACTIONS(8539), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP,
    ACTIONS(8547), 1,
      sym_primitive_type,
    STATE(3397), 1,
      sym__type_declarator,
    STATE(3841), 1,
      sym_pointer_type_declarator,
    STATE(8863), 1,
      sym_ms_based_modifier,
    ACTIONS(8545), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3839), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [261340] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(11083), 1,
      anon_sym_SEMI,
    ACTIONS(11085), 1,
      anon_sym_COLON,
    STATE(2930), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(8196), 1,
      sym_gnu_asm_expression,
    STATE(8199), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [261395] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7237), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8629), 1,
      anon_sym_STAR,
    ACTIONS(10620), 1,
      sym_identifier,
    ACTIONS(10622), 1,
      anon_sym_template,
    STATE(3072), 1,
      sym_operator_name,
    STATE(3074), 1,
      sym_template_function,
    STATE(3081), 1,
      sym_pointer_type_declarator,
    STATE(3108), 1,
      sym_dependent_identifier,
    STATE(3116), 1,
      sym_destructor_name,
    STATE(3138), 1,
      sym_qualified_identifier,
    STATE(6422), 1,
      sym__scope_resolution,
    STATE(9229), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [261452] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(2998), 1,
      sym_template_argument_list,
    ACTIONS(4512), 2,
      anon_sym___attribute,
      anon_sym_COLON,
    ACTIONS(4519), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [261485] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11087), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [261530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11091), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11089), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11095), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11093), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11099), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11097), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261611] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(6891), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [261658] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10945), 1,
      anon_sym_LF,
    ACTIONS(10947), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [261685] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11101), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [261730] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8654), 1,
      anon_sym_STAR,
    ACTIONS(8656), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8658), 1,
      anon_sym_AMP,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7156), 1,
      sym__abstract_declarator,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [261773] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9818), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9807), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261800] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9901), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(9890), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10361), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10359), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [261854] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10569), 1,
      anon_sym_SLASH,
    ACTIONS(10571), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10573), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10575), 1,
      anon_sym_PIPE,
    ACTIONS(10577), 1,
      anon_sym_CARET,
    ACTIONS(10579), 1,
      anon_sym_AMP,
    ACTIONS(11103), 1,
      anon_sym_RPAREN,
    ACTIONS(10565), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(10567), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(10581), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10583), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(10585), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(10587), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [261903] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8549), 1,
      sym_identifier,
    ACTIONS(8551), 1,
      anon_sym_LPAREN2,
    ACTIONS(8561), 1,
      sym_primitive_type,
    ACTIONS(8577), 1,
      anon_sym_STAR,
    ACTIONS(8579), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8581), 1,
      anon_sym_AMP,
    STATE(6475), 1,
      sym__type_declarator,
    STATE(6646), 1,
      sym_pointer_type_declarator,
    STATE(9172), 1,
      sym_ms_based_modifier,
    ACTIONS(8559), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6644), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [261950] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11105), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6817), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6819), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [261979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11109), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11107), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11113), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11111), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262033] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11115), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [262078] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8587), 1,
      sym_identifier,
    ACTIONS(8589), 1,
      anon_sym_LPAREN2,
    ACTIONS(8591), 1,
      anon_sym_STAR,
    ACTIONS(8593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8595), 1,
      anon_sym_AMP,
    ACTIONS(8599), 1,
      sym_primitive_type,
    STATE(3248), 1,
      sym__type_declarator,
    STATE(3735), 1,
      sym_pointer_type_declarator,
    STATE(8652), 1,
      sym_ms_based_modifier,
    ACTIONS(8597), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3725), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [262125] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11117), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [262170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11121), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11119), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262197] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10680), 1,
      anon_sym_LF,
    ACTIONS(10682), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [262224] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2258), 1,
      anon_sym_TILDE,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7227), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8553), 1,
      anon_sym_STAR,
    ACTIONS(11035), 1,
      sym_identifier,
    ACTIONS(11037), 1,
      anon_sym_template,
    STATE(6445), 1,
      sym__scope_resolution,
    STATE(6591), 1,
      sym_pointer_type_declarator,
    STATE(6593), 1,
      sym_template_function,
    STATE(6594), 1,
      sym_destructor_name,
    STATE(6595), 1,
      sym_dependent_identifier,
    STATE(6597), 1,
      sym_qualified_identifier,
    STATE(6603), 1,
      sym_operator_name,
    STATE(8992), 1,
      sym_ms_based_modifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [262281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10357), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(10355), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262308] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8613), 1,
      anon_sym_STAR,
    ACTIONS(8615), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_AMP,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7141), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(8937), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [262351] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10733), 1,
      anon_sym_LF,
    ACTIONS(10735), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [262378] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11123), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [262423] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11019), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(11125), 1,
      anon_sym_LF,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [262468] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(10739), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [262497] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(10739), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [262524] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7304), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [262571] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(8563), 1,
      sym_identifier,
    ACTIONS(8565), 1,
      anon_sym_LPAREN2,
    ACTIONS(8575), 1,
      sym_primitive_type,
    ACTIONS(8603), 1,
      anon_sym_STAR,
    ACTIONS(8605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8607), 1,
      anon_sym_AMP,
    STATE(2602), 1,
      sym_pointer_type_declarator,
    STATE(7142), 1,
      sym__type_declarator,
    STATE(9018), 1,
      sym_ms_based_modifier,
    ACTIONS(8573), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2599), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [262618] = 12,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(10739), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [262663] = 11,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10737), 1,
      anon_sym_LF,
    ACTIONS(11003), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_AMP,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(10739), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(10999), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(11007), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(11011), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(11001), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(11009), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [262706] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11129), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11127), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262733] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    ACTIONS(6452), 2,
      anon_sym___attribute,
      anon_sym___asm,
    STATE(6525), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6454), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [262769] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5860), 1,
      anon_sym___attribute,
    ACTIONS(11133), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5862), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262797] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5311), 1,
      anon_sym___attribute,
    ACTIONS(5313), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262823] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5291), 1,
      anon_sym___attribute,
    ACTIONS(5293), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262849] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(11135), 1,
      anon_sym_virtual,
    STATE(2161), 1,
      sym_template_type,
    STATE(7040), 1,
      sym_access_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8014), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(11137), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [262897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5329), 1,
      anon_sym___attribute,
    ACTIONS(5331), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [262923] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6817), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6819), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [262949] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(10069), 1,
      anon_sym_requires,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [262983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6969), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6971), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [263009] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10521), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6500), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    ACTIONS(10519), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263039] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(11139), 1,
      anon_sym_virtual,
    STATE(2161), 1,
      sym_template_type,
    STATE(7044), 1,
      sym_access_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(5738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7728), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(11137), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [263087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5303), 1,
      anon_sym___attribute,
    ACTIONS(5305), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263113] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [263147] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11141), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6561), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6563), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [263177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5325), 1,
      anon_sym___attribute,
    ACTIONS(5327), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263203] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5871), 1,
      anon_sym___attribute,
    ACTIONS(11133), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(11144), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5873), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263233] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    ACTIONS(6480), 2,
      anon_sym___attribute,
      anon_sym___asm,
    STATE(6525), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6482), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [263269] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    ACTIONS(6504), 2,
      anon_sym___attribute,
      anon_sym___asm,
    STATE(6525), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6506), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [263305] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 1,
      anon_sym___attribute,
    ACTIONS(5289), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263331] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [263365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 1,
      anon_sym___attribute,
    ACTIONS(5289), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263391] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5287), 1,
      anon_sym___attribute,
    ACTIONS(5289), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263417] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(10235), 1,
      anon_sym_requires,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [263451] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(11149), 1,
      anon_sym_requires,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [263485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5337), 1,
      anon_sym___attribute,
    ACTIONS(5339), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263511] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(11152), 1,
      anon_sym_virtual,
    STATE(2161), 1,
      sym_template_type,
    STATE(7104), 1,
      sym_access_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(6468), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7594), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(11137), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [263559] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5315), 1,
      anon_sym___attribute,
    ACTIONS(5317), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [263585] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10652), 1,
      anon_sym_SEMI,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7865), 1,
      sym_gnu_asm_expression,
    STATE(7866), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [263637] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3830), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(3832), 15,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [263663] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(6059), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9818), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [263701] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(6044), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10200), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [263739] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(5994), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(10361), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [263777] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym___attribute,
    ACTIONS(11157), 1,
      anon_sym_requires,
    ACTIONS(11154), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6578), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [263811] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(6054), 1,
      sym_trailing_return_type,
    ACTIONS(9818), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [263849] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9921), 1,
      anon_sym_requires,
    STATE(6056), 1,
      sym_trailing_return_type,
    ACTIONS(9901), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [263887] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(10220), 1,
      anon_sym_requires,
    STATE(5995), 1,
      sym_trailing_return_type,
    ACTIONS(10200), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [263925] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(10366), 1,
      anon_sym_requires,
    STATE(5999), 1,
      sym_trailing_return_type,
    ACTIONS(10361), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [263963] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10527), 1,
      anon_sym_SEMI,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7927), 1,
      sym_gnu_asm_expression,
    STATE(8011), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [264015] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(11160), 1,
      anon_sym_virtual,
    STATE(2161), 1,
      sym_template_type,
    STATE(7129), 1,
      sym_access_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(6462), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7808), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(11137), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [264063] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5333), 1,
      anon_sym___attribute,
    ACTIONS(5335), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [264089] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11083), 1,
      anon_sym_SEMI,
    ACTIONS(11162), 1,
      anon_sym_EQ,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7853), 1,
      sym_initializer_list,
    STATE(8196), 1,
      sym_gnu_asm_expression,
    STATE(8199), 1,
      aux_sym_declaration_repeat1,
    STATE(8235), 1,
      sym_argument_list,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [264143] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(10357), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6578), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [264177] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10607), 1,
      anon_sym___attribute,
    ACTIONS(11164), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6500), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    ACTIONS(10605), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [264207] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [264241] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7548), 1,
      anon_sym_LPAREN2,
    ACTIONS(7562), 1,
      anon_sym_LBRACK,
    ACTIONS(8667), 1,
      anon_sym_STAR,
    ACTIONS(8669), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8671), 1,
      anon_sym_AMP,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6457), 1,
      sym__function_declarator_seq,
    STATE(7191), 1,
      sym__abstract_declarator,
    ACTIONS(8937), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6392), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [264283] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    ACTIONS(6508), 2,
      anon_sym___attribute,
      anon_sym___asm,
    STATE(6525), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6510), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [264319] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10557), 1,
      anon_sym_SEMI,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(8144), 1,
      sym_gnu_asm_expression,
    STATE(8150), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [264371] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3826), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(3828), 15,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [264397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5295), 1,
      anon_sym___attribute,
    ACTIONS(5297), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [264423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5299), 1,
      anon_sym___attribute,
    ACTIONS(5301), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [264449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5307), 1,
      anon_sym___attribute,
    ACTIONS(5309), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [264475] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5283), 1,
      anon_sym___attribute,
    ACTIONS(5285), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [264501] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(10591), 1,
      anon_sym_SEMI,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(7870), 1,
      sym_gnu_asm_expression,
    STATE(7871), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [264553] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(6540), 1,
      sym_template_argument_list,
    ACTIONS(6896), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6898), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [264583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 1,
      anon_sym___attribute,
    ACTIONS(1930), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [264609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 1,
      anon_sym___attribute,
    ACTIONS(1926), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [264635] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [264669] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    ACTIONS(11083), 1,
      anon_sym_SEMI,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(8196), 1,
      sym_gnu_asm_expression,
    STATE(8199), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [264721] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(9871), 1,
      anon_sym_requires,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [264755] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    ACTIONS(6438), 2,
      anon_sym___attribute,
      anon_sym___asm,
    STATE(6525), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6440), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [264791] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(6027), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(9901), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [264829] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(6701), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [264872] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6198), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 7,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [264909] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    ACTIONS(10638), 1,
      anon_sym_requires,
    STATE(6171), 1,
      sym_trailing_return_type,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 7,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [264946] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8718), 1,
      anon_sym_STAR,
    ACTIONS(8720), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8722), 1,
      anon_sym_AMP,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7277), 1,
      sym__abstract_declarator,
    ACTIONS(8937), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [264987] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11167), 1,
      anon_sym_LBRACE,
    ACTIONS(11169), 1,
      anon_sym_requires,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(3867), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6732), 1,
      sym_requires_clause,
    STATE(7585), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265036] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11171), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4427), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6730), 1,
      sym_requires_clause,
    STATE(7584), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265085] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6593), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6595), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [265114] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11175), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4859), 1,
      sym_compound_statement,
    STATE(6538), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7714), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265163] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6385), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6383), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [265188] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    STATE(1694), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6564), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7660), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265237] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11177), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4116), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6783), 1,
      sym_requires_clause,
    STATE(7641), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265286] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(111), 1,
      anon_sym___asm,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(10525), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10533), 1,
      anon_sym_EQ,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(8226), 1,
      sym_gnu_asm_expression,
    ACTIONS(10535), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(11179), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8235), 2,
      sym_argument_list,
      sym_initializer_list,
  [265333] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11181), 1,
      sym_identifier,
    ACTIONS(5882), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    STATE(6531), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(11184), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(11187), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [265364] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11190), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6206), 1,
      sym_compound_statement,
    STATE(6537), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7558), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265413] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11192), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(3716), 1,
      sym_compound_statement,
    STATE(6571), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7514), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265462] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6115), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 7,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [265499] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(7282), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [265542] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 1,
      anon_sym_requires,
    STATE(6156), 1,
      sym_trailing_return_type,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 7,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [265579] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11190), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6214), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6717), 1,
      sym_requires_clause,
    STATE(7579), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265628] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11175), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4881), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6744), 1,
      sym_requires_clause,
    STATE(7661), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265677] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11194), 1,
      anon_sym_AMP,
    ACTIONS(11196), 1,
      sym_this,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(7920), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [265720] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4560), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4562), 4,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym___asm,
    ACTIONS(4555), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [265747] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11198), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6469), 1,
      sym_compound_statement,
    STATE(6559), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7709), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265796] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    ACTIONS(11202), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7754), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [265829] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11206), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11204), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [265858] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11208), 1,
      anon_sym_LBRACE,
    STATE(2789), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6778), 1,
      sym_requires_clause,
    STATE(7577), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265907] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11171), 1,
      anon_sym_LBRACE,
    ACTIONS(11173), 1,
      anon_sym_LT,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4429), 1,
      sym_compound_statement,
    STATE(6524), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7537), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [265956] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11210), 1,
      anon_sym_LBRACE,
    STATE(1688), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6710), 1,
      sym_requires_clause,
    STATE(7517), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266005] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11212), 1,
      sym_identifier,
    ACTIONS(6002), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    STATE(6548), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(11214), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(11216), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [266036] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11218), 1,
      sym_identifier,
    ACTIONS(6016), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    STATE(6531), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(11214), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(11216), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [266067] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    STATE(6477), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [266104] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    STATE(6501), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [266141] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    STATE(6470), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [266178] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7386), 1,
      anon_sym_requires,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    STATE(6499), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [266215] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(9871), 1,
      anon_sym_requires,
    STATE(6465), 1,
      sym_trailing_return_type,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [266252] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(10069), 1,
      anon_sym_requires,
    STATE(6480), 1,
      sym_trailing_return_type,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [266289] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(10235), 1,
      anon_sym_requires,
    STATE(6481), 1,
      sym_trailing_return_type,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [266326] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7388), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(11149), 1,
      anon_sym_requires,
    STATE(6490), 1,
      sym_trailing_return_type,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [266363] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8700), 1,
      sym_identifier,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8704), 1,
      anon_sym_STAR,
    ACTIONS(8706), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8708), 1,
      anon_sym_AMP,
    STATE(6627), 1,
      sym__field_declarator,
    STATE(6933), 1,
      sym_operator_name,
    STATE(9140), 1,
      sym_ms_based_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [266406] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11210), 1,
      anon_sym_LBRACE,
    STATE(1694), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6546), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7685), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266455] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11198), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6509), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6742), 1,
      sym_requires_clause,
    STATE(7715), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266504] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11220), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(5526), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6715), 1,
      sym_requires_clause,
    STATE(7717), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266553] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11222), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4126), 1,
      sym_compound_statement,
    STATE(6565), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7618), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266602] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8754), 1,
      anon_sym_STAR,
    ACTIONS(8756), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8758), 1,
      anon_sym_AMP,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7252), 1,
      sym__abstract_declarator,
    ACTIONS(8937), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266643] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym___based,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(8702), 1,
      anon_sym_LPAREN2,
    ACTIONS(8710), 1,
      sym_identifier,
    ACTIONS(8712), 1,
      anon_sym_STAR,
    ACTIONS(8714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8716), 1,
      anon_sym_AMP,
    STATE(7285), 1,
      sym__field_declarator,
    STATE(7415), 1,
      sym_operator_name,
    STATE(8767), 1,
      sym_ms_based_modifier,
    STATE(6997), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [266686] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    STATE(1688), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6760), 1,
      sym_requires_clause,
    STATE(7680), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266735] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11222), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4187), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6774), 1,
      sym_requires_clause,
    STATE(7630), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266784] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9906), 1,
      anon_sym_requires,
    STATE(6167), 1,
      sym_trailing_return_type,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 7,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [266821] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(10684), 1,
      sym_identifier,
    ACTIONS(10686), 1,
      anon_sym_STAR,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11194), 1,
      anon_sym_AMP,
    ACTIONS(11224), 1,
      sym_this,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(8461), 5,
      sym__lambda_capture_identifier,
      sym_lambda_capture_initializer,
      sym__lambda_capture,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
  [266864] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6180), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 7,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [266901] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11220), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(5441), 1,
      sym_compound_statement,
    STATE(6560), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7684), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [266950] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11228), 2,
      anon_sym___attribute__,
      anon_sym___attribute,
    ACTIONS(11233), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(11231), 3,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
    STATE(6570), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
    ACTIONS(11226), 7,
      anon_sym___declspec,
      anon_sym_COLON,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
  [266981] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11169), 1,
      anon_sym_requires,
    ACTIONS(11192), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(3720), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(6776), 1,
      sym_requires_clause,
    STATE(7632), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [267030] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11208), 1,
      anon_sym_LBRACE,
    STATE(2760), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6544), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7639), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [267079] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11173), 1,
      anon_sym_LT,
    ACTIONS(11177), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4064), 1,
      sym_compound_statement,
    STATE(6529), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7556), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [267128] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11167), 1,
      anon_sym_LBRACE,
    ACTIONS(11173), 1,
      anon_sym_LT,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(3898), 1,
      sym_compound_statement,
    STATE(6523), 1,
      sym_template_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7519), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [267177] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10205), 1,
      anon_sym_requires,
    STATE(6168), 1,
      sym_trailing_return_type,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 7,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [267214] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7193), 1,
      anon_sym_requires,
    ACTIONS(7294), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    STATE(6063), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 7,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [267251] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11236), 1,
      sym_identifier,
    ACTIONS(11238), 1,
      sym_primitive_type,
    STATE(4276), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(5130), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7913), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [267291] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11099), 1,
      anon_sym___attribute,
    ACTIONS(11097), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [267315] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11240), 1,
      sym_identifier,
    ACTIONS(11242), 1,
      sym_primitive_type,
    STATE(2162), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(4487), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(9995), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [267355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10997), 1,
      anon_sym___attribute,
    ACTIONS(10995), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [267379] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11244), 1,
      sym_identifier,
    ACTIONS(11246), 1,
      sym_primitive_type,
    STATE(5407), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(2225), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(10183), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [267419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7147), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(7149), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [267443] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11248), 1,
      sym_identifier,
    ACTIONS(11250), 1,
      sym_primitive_type,
    STATE(4984), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(2135), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7847), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [267483] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11033), 1,
      anon_sym___attribute,
    ACTIONS(11031), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [267507] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8814), 1,
      anon_sym_STAR,
    ACTIONS(8816), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8818), 1,
      anon_sym_AMP,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7318), 1,
      sym__abstract_declarator,
    ACTIONS(8937), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [267547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6621), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6623), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [267571] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(10238), 1,
      anon_sym_requires,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [267603] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11254), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11252), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [267627] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9881), 1,
      anon_sym_requires,
    STATE(6883), 1,
      sym_trailing_return_type,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [267663] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___attribute,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [267695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(4514), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [267719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11071), 1,
      anon_sym___attribute,
    ACTIONS(11069), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [267743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(4514), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [267767] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(4514), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [267791] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(4514), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [267815] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10229), 1,
      anon_sym_requires,
    STATE(6885), 1,
      sym_trailing_return_type,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [267851] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(4514), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [267875] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11262), 1,
      sym_identifier,
    ACTIONS(11264), 1,
      sym_primitive_type,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(2534), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2876), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [267915] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11266), 1,
      sym_identifier,
    ACTIONS(11268), 1,
      sym_primitive_type,
    STATE(1712), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(3253), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(10098), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [267955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11045), 1,
      anon_sym___attribute,
    ACTIONS(11043), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [267979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11061), 1,
      anon_sym___attribute,
    ACTIONS(11059), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [268003] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11095), 1,
      anon_sym___attribute,
    ACTIONS(11093), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [268027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(4514), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [268051] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5871), 1,
      anon_sym___attribute,
    ACTIONS(11270), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(11272), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5873), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [268079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11067), 1,
      anon_sym___attribute,
    ACTIONS(11065), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [268103] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    ACTIONS(11274), 1,
      anon_sym_requires,
    STATE(6886), 1,
      sym_trailing_return_type,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [268139] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11279), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [268171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6597), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6599), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [268195] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11283), 1,
      anon_sym___asm,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [268227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11287), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11285), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [268251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11291), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11289), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [268275] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11295), 1,
      anon_sym___asm,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [268307] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11299), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [268339] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11303), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11301), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [268363] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11305), 1,
      sym_identifier,
    ACTIONS(11307), 1,
      sym_primitive_type,
    STATE(2190), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(2225), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(57), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [268403] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11305), 1,
      sym_identifier,
    ACTIONS(11307), 1,
      sym_primitive_type,
    STATE(2190), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(2225), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(57), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [268443] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11311), 1,
      anon_sym___asm,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [268475] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11041), 1,
      anon_sym___attribute,
    ACTIONS(11039), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [268499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11315), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11313), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [268523] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym___asm,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [268555] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10698), 1,
      anon_sym_TILDE,
    ACTIONS(11321), 1,
      sym_identifier,
    ACTIONS(11323), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11326), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11328), 1,
      anon_sym_template,
    STATE(6970), 1,
      sym__scope_resolution,
    STATE(8333), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(3848), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [268597] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11332), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [268629] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___asm,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [268661] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11283), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [268693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11336), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11334), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [268717] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5860), 1,
      anon_sym___attribute,
    ACTIONS(11272), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5862), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [268743] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(10320), 1,
      anon_sym_COLON,
    ACTIONS(11340), 1,
      anon_sym___attribute,
    ACTIONS(11342), 1,
      anon_sym_EQ,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7700), 1,
      sym_bitfield_clause,
    STATE(7701), 1,
      sym_initializer_list,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11338), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [268789] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11344), 1,
      sym_identifier,
    ACTIONS(11346), 1,
      sym_primitive_type,
    STATE(2236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(4884), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(10076), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [268829] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11295), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [268861] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10993), 1,
      anon_sym___attribute,
    ACTIONS(10991), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [268885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11350), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11348), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [268909] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11311), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [268941] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym___attribute,
    ACTIONS(11352), 1,
      anon_sym_requires,
    ACTIONS(11154), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6578), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [268973] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(9890), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [268997] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [269029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(9807), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [269053] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11299), 1,
      anon_sym___asm,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [269085] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(9862), 1,
      anon_sym_requires,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [269117] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [269149] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(10359), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [269173] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6797), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [269209] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [269241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6617), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6619), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [269265] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6627), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6629), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [269289] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6635), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6637), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [269313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6639), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6641), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [269337] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11355), 1,
      sym_identifier,
    ACTIONS(11357), 1,
      sym_primitive_type,
    STATE(2158), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(2135), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(9979), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [269377] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___asm,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [269409] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(10189), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [269433] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [269465] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [269497] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11279), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [269529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6655), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6657), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [269553] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(11359), 1,
      anon_sym_requires,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [269585] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11244), 1,
      sym_identifier,
    ACTIONS(11246), 1,
      sym_primitive_type,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(2225), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [269625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11075), 1,
      anon_sym___attribute,
    ACTIONS(11073), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [269649] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11362), 1,
      sym_identifier,
    ACTIONS(11364), 1,
      sym_primitive_type,
    STATE(1709), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(3164), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(10023), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [269689] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11332), 1,
      anon_sym___asm,
    STATE(2873), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [269721] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11091), 1,
      anon_sym___attribute,
    ACTIONS(11089), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [269745] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7475), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(5099), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [269769] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11283), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [269801] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11279), 1,
      anon_sym___asm,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [269833] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6794), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [269869] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym___attribute,
    ACTIONS(10355), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [269893] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11366), 1,
      sym_identifier,
    ACTIONS(11368), 1,
      sym_primitive_type,
    STATE(1711), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(3224), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(10051), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [269933] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11370), 1,
      sym_identifier,
    ACTIONS(11372), 1,
      sym_primitive_type,
    STATE(1665), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(2482), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(9951), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [269973] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11129), 1,
      anon_sym___attribute,
    ACTIONS(11127), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [269997] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(10357), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6578), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [270029] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11374), 1,
      sym_identifier,
    ACTIONS(11376), 1,
      sym_primitive_type,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(4820), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [270069] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6605), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6607), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [270093] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9924), 1,
      anon_sym_requires,
    STATE(6884), 1,
      sym_trailing_return_type,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [270129] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11378), 1,
      sym_identifier,
    ACTIONS(11380), 1,
      sym_primitive_type,
    STATE(1661), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(2482), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(9931), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [270169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11384), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11382), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [270193] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11386), 1,
      sym_identifier,
    ACTIONS(11388), 1,
      sym_primitive_type,
    STATE(1725), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(3482), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(10120), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [270233] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11295), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [270265] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11374), 1,
      sym_identifier,
    ACTIONS(11376), 1,
      sym_primitive_type,
    STATE(3698), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(4820), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [270305] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11392), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(11390), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [270329] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11299), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [270361] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11357), 1,
      sym_primitive_type,
    ACTIONS(11394), 1,
      sym_identifier,
    STATE(4448), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(2135), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(1872), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [270401] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11264), 1,
      sym_primitive_type,
    ACTIONS(11396), 1,
      sym_identifier,
    STATE(2271), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(2534), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(9963), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [270441] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11311), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [270473] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(10044), 1,
      anon_sym_requires,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [270505] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7354), 1,
      sym__abstract_declarator,
    ACTIONS(8937), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [270545] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym___attribute,
    STATE(2865), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [270577] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6792), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [270613] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11244), 1,
      sym_identifier,
    ACTIONS(11246), 1,
      sym_primitive_type,
    STATE(2354), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(2225), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(3746), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [270653] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11332), 1,
      anon_sym___asm,
    STATE(2944), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [270685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6575), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6577), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [270709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11109), 1,
      anon_sym___attribute,
    ACTIONS(11107), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [270733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6609), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6611), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [270757] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6631), 3,
      anon_sym___attribute,
      anon_sym_LBRACK,
      anon_sym___asm,
    ACTIONS(6633), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_GT2,
      anon_sym_try,
  [270781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11113), 1,
      anon_sym___attribute,
    ACTIONS(11111), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [270805] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11121), 1,
      anon_sym___attribute,
    ACTIONS(11119), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [270829] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7381), 1,
      anon_sym_DASH_GT,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    STATE(6798), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [270865] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(10235), 1,
      anon_sym_requires,
    STATE(6481), 1,
      sym_trailing_return_type,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [270898] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10867), 1,
      anon_sym_TILDE,
    ACTIONS(11398), 1,
      sym_identifier,
    ACTIONS(11400), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11402), 1,
      anon_sym_template,
    STATE(6951), 1,
      sym__scope_resolution,
    STATE(8340), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(4200), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [270937] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10797), 1,
      anon_sym_TILDE,
    ACTIONS(11404), 1,
      sym_identifier,
    ACTIONS(11406), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11408), 1,
      anon_sym_template,
    STATE(6958), 1,
      sym__scope_resolution,
    STATE(8290), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(2751), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [270976] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(10241), 1,
      anon_sym_requires,
    STATE(6811), 1,
      sym_trailing_return_type,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [271011] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7863), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [271040] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8901), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [271069] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11412), 1,
      anon_sym___attribute,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11410), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [271104] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11416), 1,
      anon_sym___asm,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11414), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [271139] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10797), 1,
      anon_sym_TILDE,
    ACTIONS(11404), 1,
      sym_identifier,
    ACTIONS(11418), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11420), 1,
      anon_sym_template,
    STATE(6911), 1,
      sym__scope_resolution,
    STATE(8336), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(2751), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [271178] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(11422), 1,
      anon_sym_requires,
    STATE(6812), 1,
      sym_trailing_return_type,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [271213] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    STATE(6642), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [271246] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(10238), 1,
      anon_sym_requires,
    STATE(6654), 1,
      sym_trailing_return_type,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [271279] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    STATE(6668), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [271312] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(11149), 1,
      anon_sym_requires,
    STATE(6490), 1,
      sym_trailing_return_type,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [271345] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    STATE(6635), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [271380] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11210), 1,
      anon_sym_LBRACE,
    STATE(1690), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7528), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [271423] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11427), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11429), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11431), 1,
      aux_sym_preproc_elif_token1,
    STATE(7035), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(7076), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(7322), 1,
      sym_enumerator,
    ACTIONS(11433), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9216), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
    STATE(9263), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [271462] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11437), 1,
      anon_sym___asm,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11435), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [271497] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11429), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11431), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11439), 1,
      aux_sym_preproc_if_token2,
    STATE(7086), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(7087), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(7322), 1,
      sym_enumerator,
    ACTIONS(11433), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9160), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
    STATE(9163), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [271536] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    STATE(6650), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [271571] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11220), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(5522), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7617), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [271614] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    STATE(6635), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [271647] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11190), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6067), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7583), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [271690] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    STATE(6642), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [271725] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    STATE(6668), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [271760] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8141), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [271789] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7841), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [271818] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7771), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [271847] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    STATE(6499), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [271880] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7985), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [271909] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8143), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [271938] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    STATE(6470), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [271971] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11437), 1,
      anon_sym___asm,
    STATE(2930), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11435), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [272006] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7921), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [272035] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7959), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [272064] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11171), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4324), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7604), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [272107] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11443), 1,
      anon_sym___attribute,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11441), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [272142] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11167), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(3941), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7625), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [272185] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11447), 1,
      anon_sym___asm,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11445), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [272220] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11416), 1,
      anon_sym___asm,
    STATE(2930), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11414), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [272255] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(6547), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(6354), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(11214), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(11216), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [272282] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(6682), 1,
      sym_trailing_return_type,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [272317] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [272352] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(10238), 1,
      anon_sym_requires,
    STATE(6654), 1,
      sym_trailing_return_type,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [272387] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7532), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(11359), 1,
      anon_sym_requires,
    STATE(6633), 1,
      sym_trailing_return_type,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [272422] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    STATE(6477), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [272455] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7860), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [272484] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11198), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6461), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7716), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [272527] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11451), 1,
      anon_sym___attribute,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11449), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [272562] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11175), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4869), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7541), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [272605] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7914), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [272634] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11429), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11431), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11453), 1,
      aux_sym_preproc_if_token2,
    STATE(7043), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(7057), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(7322), 1,
      sym_enumerator,
    ACTIONS(11433), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9020), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
    STATE(9134), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [272673] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11457), 1,
      anon_sym___asm,
    STATE(2930), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11455), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [272708] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11461), 1,
      anon_sym___attribute,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11459), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [272743] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(7386), 1,
      anon_sym_requires,
    STATE(6501), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [272776] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11465), 1,
      anon_sym___asm,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11463), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [272811] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    STATE(6800), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [272846] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    STATE(6801), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [272881] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    STATE(6802), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [272916] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10698), 1,
      anon_sym_TILDE,
    ACTIONS(11321), 1,
      sym_identifier,
    ACTIONS(11326), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11328), 1,
      anon_sym_template,
    STATE(6970), 1,
      sym__scope_resolution,
    STATE(8333), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(3848), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [272955] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    STATE(6803), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [272990] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8114), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273019] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11429), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11431), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11467), 1,
      aux_sym_preproc_if_token2,
    STATE(7114), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(7125), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(7322), 1,
      sym_enumerator,
    ACTIONS(11433), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9506), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
    STATE(9522), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [273058] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8190), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273087] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(10069), 1,
      anon_sym_requires,
    STATE(6480), 1,
      sym_trailing_return_type,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [273120] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(1690), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7682), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [273163] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11471), 1,
      anon_sym___attribute,
    STATE(2852), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(6923), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11469), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [273198] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8205), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273227] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(7379), 1,
      anon_sym_requires,
    STATE(6650), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [273260] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10837), 1,
      anon_sym_TILDE,
    ACTIONS(11473), 1,
      sym_identifier,
    ACTIONS(11475), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11477), 1,
      anon_sym_template,
    STATE(6925), 1,
      sym__scope_resolution,
    STATE(8269), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(4054), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [273299] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8605), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273328] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7891), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273357] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8720), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273386] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(11359), 1,
      anon_sym_requires,
    STATE(6633), 1,
      sym_trailing_return_type,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [273419] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8159), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273448] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8795), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273477] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7812), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273506] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8846), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273535] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11457), 1,
      anon_sym___asm,
    STATE(2927), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11455), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_try,
  [273570] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11222), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4208), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7635), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [273613] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8894), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273642] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11192), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(3722), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7565), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [273685] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(7854), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273714] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11208), 1,
      anon_sym_LBRACE,
    STATE(2810), 1,
      sym_compound_statement,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7689), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [273757] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8055), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273786] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(6682), 1,
      sym_trailing_return_type,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [273819] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(9132), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273848] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7372), 1,
      anon_sym_DASH_GT,
    ACTIONS(9871), 1,
      anon_sym_requires,
    STATE(6465), 1,
      sym_trailing_return_type,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [273881] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(11177), 1,
      anon_sym_LBRACE,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(4171), 1,
      sym_compound_statement,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7697), 1,
      sym_abstract_function_declarator,
    STATE(7725), 1,
      sym__abstract_declarator,
    STATE(6618), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [273924] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11200), 1,
      sym_identifier,
    STATE(6735), 2,
      sym_string_literal,
      sym_raw_string_literal,
    STATE(8109), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(153), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [273953] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(9909), 1,
      anon_sym_requires,
    STATE(6809), 1,
      sym_trailing_return_type,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [273988] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11447), 1,
      anon_sym___asm,
    STATE(2930), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11445), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [274023] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11465), 1,
      anon_sym___asm,
    STATE(2930), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11463), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [274058] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7508), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(10155), 1,
      anon_sym_requires,
    STATE(6810), 1,
      sym_trailing_return_type,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274093] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7348), 1,
      anon_sym_DASH_GT,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [274126] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7538), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3407), 1,
      sym_enumerator_list,
    STATE(7183), 1,
      sym__scope_resolution,
    ACTIONS(11479), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(3131), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [274166] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11483), 1,
      anon_sym_EQ,
    STATE(2980), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    ACTIONS(11481), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7359), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [274206] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [274236] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2569), 1,
      sym_enumerator_list,
    STATE(7227), 1,
      sym__scope_resolution,
    ACTIONS(11485), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(3402), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [274276] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [274306] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(7162), 1,
      sym_access_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(7728), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(11137), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [274344] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5860), 1,
      anon_sym_LBRACK,
    ACTIONS(11487), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5862), 11,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [274368] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [274398] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(10357), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6427), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [274428] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274458] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274488] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274518] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274548] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7479), 1,
      anon_sym_requires,
    ACTIONS(10357), 1,
      anon_sym___attribute,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6578), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274578] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    STATE(6800), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274610] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    STATE(6801), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274642] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    STATE(6802), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274674] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(7479), 1,
      anon_sym_requires,
    STATE(6803), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274706] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9818), 1,
      anon_sym___attribute,
    ACTIONS(9909), 1,
      anon_sym_requires,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274736] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9901), 1,
      anon_sym___attribute,
    ACTIONS(10155), 1,
      anon_sym_requires,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274766] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10200), 1,
      anon_sym___attribute,
    ACTIONS(10241), 1,
      anon_sym_requires,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274796] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10361), 1,
      anon_sym___attribute,
    ACTIONS(11422), 1,
      anon_sym_requires,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274826] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym___attribute,
    ACTIONS(11489), 1,
      anon_sym_requires,
    ACTIONS(11154), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6578), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274856] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7239), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3121), 1,
      sym_enumerator_list,
    STATE(7202), 1,
      sym__scope_resolution,
    ACTIONS(11492), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2878), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [274896] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11494), 1,
      anon_sym_SEMI,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    ACTIONS(11498), 1,
      anon_sym_EQ,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11502), 1,
      anon_sym_try,
    STATE(2107), 1,
      sym_compound_statement,
    STATE(8331), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(2108), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [274934] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(9909), 1,
      anon_sym_requires,
    STATE(6809), 1,
      sym_trailing_return_type,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274966] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(10155), 1,
      anon_sym_requires,
    STATE(6810), 1,
      sym_trailing_return_type,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [274998] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(10241), 1,
      anon_sym_requires,
    STATE(6811), 1,
      sym_trailing_return_type,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [275030] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DASH_GT,
    ACTIONS(11422), 1,
      anon_sym_requires,
    STATE(6812), 1,
      sym_trailing_return_type,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [275062] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6362), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2473), 1,
      sym_enumerator_list,
    STATE(7187), 1,
      sym__scope_resolution,
    ACTIONS(11504), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4977), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [275102] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2901), 1,
      sym_enumerator_list,
    STATE(7225), 1,
      sym__scope_resolution,
    ACTIONS(11506), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(3134), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [275142] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(7176), 1,
      sym_access_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(7642), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(11137), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [275180] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11508), 1,
      anon_sym_SEMI,
    ACTIONS(11510), 1,
      anon_sym_EQ,
    ACTIONS(11512), 1,
      anon_sym_try,
    STATE(751), 1,
      sym_compound_statement,
    STATE(8469), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(753), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [275218] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6399), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2447), 1,
      sym_enumerator_list,
    STATE(7178), 1,
      sym__scope_resolution,
    ACTIONS(11514), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2621), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [275258] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2302), 1,
      sym_enumerator_list,
    STATE(7197), 1,
      sym__scope_resolution,
    ACTIONS(11516), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4318), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [275298] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11518), 1,
      anon_sym_SEMI,
    ACTIONS(11520), 1,
      anon_sym_EQ,
    ACTIONS(11522), 1,
      anon_sym_try,
    STATE(494), 1,
      sym_compound_statement,
    STATE(8249), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(496), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [275336] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11524), 1,
      anon_sym_SEMI,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    ACTIONS(11528), 1,
      anon_sym_try,
    STATE(291), 1,
      sym_compound_statement,
    STATE(8402), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(292), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [275374] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11530), 1,
      anon_sym_SEMI,
    ACTIONS(11532), 1,
      anon_sym_EQ,
    ACTIONS(11534), 1,
      anon_sym_try,
    STATE(472), 1,
      sym_compound_statement,
    STATE(8278), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(473), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [275412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6159), 1,
      sym_identifier,
    ACTIONS(6161), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [275434] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6362), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2473), 1,
      sym_enumerator_list,
    STATE(7213), 1,
      sym__scope_resolution,
    ACTIONS(11536), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4546), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [275474] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6438), 1,
      anon_sym___attribute,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6440), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_try,
  [275506] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11532), 1,
      anon_sym_EQ,
    ACTIONS(11534), 1,
      anon_sym_try,
    ACTIONS(11538), 1,
      anon_sym_SEMI,
    STATE(484), 1,
      sym_compound_statement,
    STATE(8350), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(485), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [275544] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11520), 1,
      anon_sym_EQ,
    ACTIONS(11522), 1,
      anon_sym_try,
    ACTIONS(11540), 1,
      anon_sym_SEMI,
    STATE(537), 1,
      sym_compound_statement,
    STATE(8359), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(538), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [275582] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11299), 1,
      anon_sym___attribute,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [275612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6167), 1,
      sym_identifier,
    ACTIONS(6169), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [275634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6192), 1,
      sym_identifier,
    ACTIONS(6194), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [275656] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11283), 1,
      anon_sym___attribute,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [275686] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(7148), 1,
      sym_access_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(8014), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(11137), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [275724] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11295), 1,
      anon_sym___attribute,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [275754] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11311), 1,
      anon_sym___attribute,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [275784] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11510), 1,
      anon_sym_EQ,
    ACTIONS(11512), 1,
      anon_sym_try,
    ACTIONS(11542), 1,
      anon_sym_SEMI,
    STATE(731), 1,
      sym_compound_statement,
    STATE(8264), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(732), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [275822] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(6059), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [275856] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(6027), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [275890] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(6044), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [275924] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7309), 1,
      anon_sym_requires,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    STATE(5994), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [275958] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9848), 1,
      anon_sym_requires,
    STATE(6054), 1,
      sym_trailing_return_type,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [275992] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7390), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [276022] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10220), 1,
      anon_sym_requires,
    STATE(5995), 1,
      sym_trailing_return_type,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [276056] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    ACTIONS(10366), 1,
      anon_sym_requires,
    STATE(5999), 1,
      sym_trailing_return_type,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [276090] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym___attribute,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [276120] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11544), 1,
      anon_sym_EQ,
    STATE(2980), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    ACTIONS(11481), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7359), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [276160] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___attribute,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [276190] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11279), 1,
      anon_sym___attribute,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [276220] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    ACTIONS(11332), 1,
      anon_sym___attribute,
    STATE(3006), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [276250] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6399), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2447), 1,
      sym_enumerator_list,
    STATE(7178), 1,
      sym__scope_resolution,
    ACTIONS(11546), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2808), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276290] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5860), 1,
      anon_sym___attribute,
    ACTIONS(11548), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5862), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [276314] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4736), 1,
      sym_enumerator_list,
    STATE(7210), 1,
      sym__scope_resolution,
    ACTIONS(11550), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4563), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276354] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6452), 1,
      anon_sym___attribute,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6454), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_try,
  [276386] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    ACTIONS(11498), 1,
      anon_sym_EQ,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11502), 1,
      anon_sym_try,
    ACTIONS(11552), 1,
      anon_sym_SEMI,
    STATE(2022), 1,
      sym_compound_statement,
    STATE(8286), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(2023), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [276424] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(7169), 1,
      sym_access_specifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(8177), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(11137), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [276462] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11554), 1,
      anon_sym_SEMI,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    ACTIONS(11558), 1,
      anon_sym_EQ,
    ACTIONS(11560), 1,
      anon_sym_try,
    STATE(1801), 1,
      sym_compound_statement,
    STATE(8485), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(1802), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [276500] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8901), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4828), 1,
      sym_enumerator_list,
    STATE(7195), 1,
      sym__scope_resolution,
    ACTIONS(11562), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4543), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276540] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6508), 1,
      anon_sym___attribute,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6510), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_try,
  [276572] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7344), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3180), 1,
      sym_enumerator_list,
    STATE(7218), 1,
      sym__scope_resolution,
    ACTIONS(11564), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2977), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276612] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6480), 1,
      anon_sym___attribute,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6482), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_try,
  [276644] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2901), 1,
      sym_enumerator_list,
    STATE(7210), 1,
      sym__scope_resolution,
    ACTIONS(11566), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7124), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276684] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8995), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4974), 1,
      sym_enumerator_list,
    STATE(7230), 1,
      sym__scope_resolution,
    ACTIONS(11568), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4688), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276724] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7360), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3154), 1,
      sym_enumerator_list,
    STATE(7234), 1,
      sym__scope_resolution,
    ACTIONS(11570), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2979), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276764] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2302), 1,
      sym_enumerator_list,
    STATE(7203), 1,
      sym__scope_resolution,
    ACTIONS(11572), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4948), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276804] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8609), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4444), 1,
      sym_enumerator_list,
    STATE(7189), 1,
      sym__scope_resolution,
    ACTIONS(11574), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4141), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276844] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4736), 1,
      sym_enumerator_list,
    STATE(7225), 1,
      sym__scope_resolution,
    ACTIONS(11576), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(5293), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276884] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2569), 1,
      sym_enumerator_list,
    STATE(7199), 1,
      sym__scope_resolution,
    ACTIONS(11578), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2814), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [276924] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11580), 1,
      anon_sym_SEMI,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    ACTIONS(11584), 1,
      anon_sym_EQ,
    ACTIONS(11586), 1,
      anon_sym_try,
    STATE(1993), 1,
      sym_compound_statement,
    STATE(8215), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(1994), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [276962] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8895), 1,
      anon_sym_STAR,
    ACTIONS(8897), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8899), 1,
      anon_sym_AMP,
    ACTIONS(8937), 1,
      anon_sym_COLON,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7503), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [277000] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6438), 1,
      anon_sym___asm,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    STATE(6961), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6440), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [277032] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6504), 1,
      anon_sym___asm,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    STATE(6961), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6506), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [277064] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2901), 1,
      sym_enumerator_list,
    STATE(7210), 1,
      sym__scope_resolution,
    ACTIONS(11588), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4464), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [277104] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    ACTIONS(11558), 1,
      anon_sym_EQ,
    ACTIONS(11560), 1,
      anon_sym_try,
    ACTIONS(11590), 1,
      anon_sym_SEMI,
    STATE(1815), 1,
      sym_compound_statement,
    STATE(8523), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(1816), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [277142] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6452), 1,
      anon_sym___asm,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    STATE(6961), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6454), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [277174] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6508), 1,
      anon_sym___asm,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    STATE(6961), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6510), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [277206] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6480), 1,
      anon_sym___asm,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11131), 1,
      anon_sym_LBRACK,
    STATE(6608), 1,
      sym_parameter_list,
    STATE(6961), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6482), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [277238] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5871), 1,
      anon_sym___attribute,
    ACTIONS(11548), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(11592), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5873), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [277264] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(9881), 1,
      anon_sym_requires,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [277294] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9924), 1,
      anon_sym_requires,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [277324] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10229), 1,
      anon_sym_requires,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [277354] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    ACTIONS(11274), 1,
      anon_sym_requires,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [277384] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym_LBRACK,
    ACTIONS(11594), 1,
      anon_sym_requires,
    ACTIONS(10387), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6427), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [277414] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5871), 1,
      anon_sym_LBRACK,
    ACTIONS(11487), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(11597), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5873), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [277440] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    ACTIONS(11584), 1,
      anon_sym_EQ,
    ACTIONS(11586), 1,
      anon_sym_try,
    ACTIONS(11599), 1,
      anon_sym_SEMI,
    STATE(2011), 1,
      sym_compound_statement,
    STATE(8427), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(2012), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [277478] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    ACTIONS(11528), 1,
      anon_sym_try,
    ACTIONS(11601), 1,
      anon_sym_SEMI,
    STATE(241), 1,
      sym_compound_statement,
    STATE(8236), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(242), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [277516] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(5492), 1,
      sym_enumerator_list,
    STATE(7222), 1,
      sym__scope_resolution,
    ACTIONS(11603), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4999), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [277556] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6504), 1,
      anon_sym___attribute,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6506), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_try,
  [277588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6163), 1,
      sym_identifier,
    ACTIONS(6165), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [277610] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2569), 1,
      sym_enumerator_list,
    STATE(7200), 1,
      sym__scope_resolution,
    ACTIONS(11605), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2686), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [277650] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7490), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(9921), 1,
      anon_sym_requires,
    STATE(6056), 1,
      sym_trailing_return_type,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [277684] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11613), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8355), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8628), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [277717] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11615), 1,
      sym_identifier,
    ACTIONS(11617), 1,
      anon_sym_COLON_COLON,
    STATE(6922), 1,
      sym__scope_resolution,
    STATE(8253), 1,
      sym_field_initializer,
    STATE(8276), 1,
      sym_operator_name,
    STATE(7621), 2,
      sym_template_method,
      sym_qualified_field_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [277754] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11299), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [277783] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11311), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [277812] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11319), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [277841] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11279), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [277870] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11457), 1,
      anon_sym___attribute,
    STATE(2980), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11455), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [277903] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11283), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [277932] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11295), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [277961] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [277990] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11332), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3008), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [278019] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11621), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8392), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8790), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278052] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11623), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8375), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8683), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278085] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11532), 1,
      anon_sym_EQ,
    ACTIONS(11534), 1,
      anon_sym_try,
    STATE(472), 1,
      sym_compound_statement,
    STATE(8278), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(473), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [278120] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11625), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8512), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9231), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6906), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278153] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11627), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8524), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9289), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278186] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11418), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11420), 1,
      anon_sym_template,
    ACTIONS(11629), 1,
      sym_identifier,
    STATE(2715), 1,
      sym_dependent_field_identifier,
    STATE(2716), 1,
      sym_qualified_field_identifier,
    STATE(2737), 1,
      sym_template_method,
    STATE(6911), 1,
      sym__scope_resolution,
    STATE(8336), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [278225] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11631), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8544), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9404), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278258] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11633), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8391), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8743), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278291] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11637), 1,
      anon_sym_LT,
    STATE(6996), 1,
      sym_template_argument_list,
    ACTIONS(11639), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11635), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [278316] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11641), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8310), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9119), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6895), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278349] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11643), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8265), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8632), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6921), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278382] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11510), 1,
      anon_sym_EQ,
    ACTIONS(11512), 1,
      anon_sym_try,
    STATE(731), 1,
      sym_compound_statement,
    STATE(8264), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(732), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [278417] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [278444] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [278471] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [278498] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11645), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8282), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8809), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278531] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11647), 1,
      sym_identifier,
    ACTIONS(11649), 1,
      anon_sym_template,
    STATE(2715), 1,
      sym_dependent_field_identifier,
    STATE(2716), 1,
      sym_qualified_field_identifier,
    STATE(2737), 1,
      sym_template_method,
    STATE(6922), 1,
      sym__scope_resolution,
    STATE(8276), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [278570] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11653), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6223), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11651), 8,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [278595] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11615), 1,
      sym_identifier,
    ACTIONS(11617), 1,
      anon_sym_COLON_COLON,
    STATE(6922), 1,
      sym__scope_resolution,
    STATE(7764), 1,
      sym_field_initializer,
    STATE(8276), 1,
      sym_operator_name,
    STATE(7621), 2,
      sym_template_method,
      sym_qualified_field_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [278632] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11475), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11477), 1,
      anon_sym_template,
    ACTIONS(11655), 1,
      sym_identifier,
    STATE(4092), 1,
      sym_template_method,
    STATE(4095), 1,
      sym_dependent_field_identifier,
    STATE(4096), 1,
      sym_qualified_field_identifier,
    STATE(6925), 1,
      sym__scope_resolution,
    STATE(8269), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [278671] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11447), 1,
      anon_sym___attribute,
    STATE(2980), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11445), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [278704] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    STATE(7051), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [278737] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [278764] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11657), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8329), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9390), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6939), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [278797] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    STATE(7054), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [278830] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    STATE(7055), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [278863] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    STATE(7056), 1,
      sym_trailing_return_type,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [278896] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11637), 1,
      anon_sym_LT,
    STATE(7009), 1,
      sym_template_argument_list,
    ACTIONS(11661), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11659), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [278921] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_requires,
    STATE(7130), 1,
      sym_trailing_return_type,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [278954] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10208), 1,
      anon_sym_requires,
    STATE(7078), 1,
      sym_trailing_return_type,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [278987] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10328), 1,
      anon_sym_requires,
    STATE(7083), 1,
      sym_trailing_return_type,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [279020] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7570), 1,
      anon_sym_DASH_GT,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    ACTIONS(11663), 1,
      anon_sym_requires,
    STATE(7092), 1,
      sym_trailing_return_type,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [279053] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11520), 1,
      anon_sym_EQ,
    ACTIONS(11522), 1,
      anon_sym_try,
    STATE(537), 1,
      sym_compound_statement,
    STATE(8359), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(538), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [279088] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11666), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8343), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8586), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279121] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11465), 1,
      anon_sym___attribute,
    STATE(2980), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11463), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [279154] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11668), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8341), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8588), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6913), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279187] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4671), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11670), 1,
      sym_identifier,
    STATE(6378), 1,
      sym__scope_resolution,
    ACTIONS(4673), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8267), 2,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [279222] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11672), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8374), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8681), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6944), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279255] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11674), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8387), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8716), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279288] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11532), 1,
      anon_sym_EQ,
    ACTIONS(11534), 1,
      anon_sym_try,
    STATE(484), 1,
      sym_compound_statement,
    STATE(8350), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(485), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [279323] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11676), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8488), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9118), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6907), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279356] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11416), 1,
      anon_sym___attribute,
    STATE(2980), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11414), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [279389] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11206), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6223), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11204), 8,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [279414] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7501), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [279449] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11678), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8309), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9126), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6959), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279482] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11400), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11402), 1,
      anon_sym_template,
    ACTIONS(11680), 1,
      sym_identifier,
    STATE(4150), 1,
      sym_template_method,
    STATE(4151), 1,
      sym_dependent_field_identifier,
    STATE(4155), 1,
      sym_qualified_field_identifier,
    STATE(6951), 1,
      sym__scope_resolution,
    STATE(8340), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [279521] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    ACTIONS(11528), 1,
      anon_sym_try,
    STATE(241), 1,
      sym_compound_statement,
    STATE(8236), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(242), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [279556] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11520), 1,
      anon_sym_EQ,
    ACTIONS(11522), 1,
      anon_sym_try,
    STATE(494), 1,
      sym_compound_statement,
    STATE(8249), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(496), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [279591] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11437), 1,
      anon_sym___attribute,
    STATE(2980), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11435), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [279624] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [279651] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [279678] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [279705] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11406), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11408), 1,
      anon_sym_template,
    ACTIONS(11629), 1,
      sym_identifier,
    STATE(2715), 1,
      sym_dependent_field_identifier,
    STATE(2716), 1,
      sym_qualified_field_identifier,
    STATE(2737), 1,
      sym_template_method,
    STATE(6958), 1,
      sym__scope_resolution,
    STATE(8290), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [279744] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11682), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8456), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8957), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279777] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2956), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 9,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [279804] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6593), 2,
      anon_sym_LBRACK,
      anon_sym___asm,
    STATE(6223), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6595), 8,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_asm,
      anon_sym___asm__,
  [279829] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11684), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8502), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9159), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6912), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279862] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    ACTIONS(8718), 1,
      anon_sym_STAR,
    ACTIONS(8720), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8722), 1,
      anon_sym_AMP,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7295), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [279897] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11686), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8384), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8702), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279930] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11688), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8496), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9144), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6910), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279963] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11690), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8209), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8835), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6964), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [279996] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11692), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8393), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8756), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [280029] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11609), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11694), 1,
      anon_sym_RBRACE,
    ACTIONS(11611), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8500), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(9165), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6967), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [280062] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    ACTIONS(11528), 1,
      anon_sym_try,
    STATE(291), 1,
      sym_compound_statement,
    STATE(8402), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(292), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [280097] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11326), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11328), 1,
      anon_sym_template,
    ACTIONS(11696), 1,
      sym_identifier,
    STATE(3804), 1,
      sym_template_method,
    STATE(3815), 1,
      sym_dependent_field_identifier,
    STATE(3862), 1,
      sym_qualified_field_identifier,
    STATE(6970), 1,
      sym__scope_resolution,
    STATE(8333), 1,
      sym_operator_name,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [280136] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6593), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6595), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_try,
  [280161] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_LPAREN2,
    ACTIONS(4605), 1,
      anon_sym_STAR,
    ACTIONS(4607), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4609), 1,
      anon_sym_AMP,
    ACTIONS(8294), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6667), 1,
      sym__function_declarator_seq,
    STATE(7482), 1,
      sym__abstract_declarator,
    STATE(6618), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [280196] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    ACTIONS(11510), 1,
      anon_sym_EQ,
    ACTIONS(11512), 1,
      anon_sym_try,
    STATE(751), 1,
      sym_compound_statement,
    STATE(8469), 1,
      sym_field_initializer_list,
    ACTIONS(5099), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(753), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [280231] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    STATE(6635), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [280261] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2905), 1,
      sym_enumerator_list,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(7127), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [280297] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(10143), 1,
      sym_identifier,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    STATE(2161), 1,
      sym_template_type,
    STATE(2558), 1,
      sym_enumerator_list,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(3294), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [280333] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8995), 1,
      anon_sym_LBRACE,
    ACTIONS(10179), 1,
      sym_identifier,
    STATE(4645), 1,
      sym_template_type,
    STATE(4957), 1,
      sym_enumerator_list,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(4693), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [280369] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(9862), 1,
      anon_sym_requires,
    STATE(6682), 1,
      sym_trailing_return_type,
    ACTIONS(9859), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6634), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [280399] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [280425] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7360), 1,
      anon_sym_LBRACE,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10181), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_template_type,
    STATE(3165), 1,
      sym_enumerator_list,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(2997), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [280461] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8609), 1,
      anon_sym_LBRACE,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10141), 1,
      sym_identifier,
    STATE(4053), 1,
      sym_template_type,
    STATE(4459), 1,
      sym_enumerator_list,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(4160), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [280497] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [280523] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4706), 1,
      sym_enumerator_list,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(5295), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [280559] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [280585] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(10044), 1,
      anon_sym_requires,
    STATE(6587), 1,
      sym_trailing_return_type,
    ACTIONS(10041), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [280615] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [280641] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [280667] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6399), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2437), 1,
      sym_enumerator_list,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(2755), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [280703] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [280729] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [280755] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(2999), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 8,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [280781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11700), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11698), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [280801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11704), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11702), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [280821] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(10238), 1,
      anon_sym_requires,
    STATE(6654), 1,
      sym_trailing_return_type,
    ACTIONS(10232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [280851] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7538), 1,
      anon_sym_LBRACE,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10166), 1,
      sym_identifier,
    STATE(3114), 1,
      sym_template_type,
    STATE(3266), 1,
      sym_enumerator_list,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(3118), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [280887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6800), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(6802), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [280907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11661), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11659), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [280927] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(6547), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(11214), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(11216), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [280949] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    ACTIONS(11359), 1,
      anon_sym_requires,
    STATE(6633), 1,
      sym_trailing_return_type,
    ACTIONS(11146), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [280979] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6362), 1,
      anon_sym_LBRACE,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2425), 1,
      sym_enumerator_list,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(4920), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281015] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    STATE(6650), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6649), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [281045] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(10162), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2558), 1,
      sym_enumerator_list,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(2816), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281081] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(10143), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2558), 1,
      sym_enumerator_list,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(2656), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281117] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2905), 1,
      sym_enumerator_list,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(4465), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281153] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    STATE(6642), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6640), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [281183] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10151), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2301), 1,
      sym_enumerator_list,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(4319), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281219] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8907), 1,
      anon_sym_LBRACE,
    ACTIONS(10170), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(4706), 1,
      sym_enumerator_list,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281255] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7239), 1,
      anon_sym_LBRACE,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10145), 1,
      sym_identifier,
    STATE(2904), 1,
      sym_template_type,
    STATE(3133), 1,
      sym_enumerator_list,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(2936), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281291] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(6892), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [281311] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6399), 1,
      anon_sym_LBRACE,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10168), 1,
      sym_identifier,
    STATE(2359), 1,
      sym_template_type,
    STATE(2437), 1,
      sym_enumerator_list,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(2622), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281347] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11708), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11706), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [281367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11712), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11710), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [281387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11716), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11714), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [281407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11720), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11718), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [281427] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10153), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(5494), 1,
      sym_enumerator_list,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(4979), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281463] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6181), 1,
      anon_sym_LBRACE,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10147), 1,
      sym_identifier,
    STATE(2080), 1,
      sym_template_type,
    STATE(2301), 1,
      sym_enumerator_list,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(4937), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281499] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7379), 1,
      anon_sym_requires,
    ACTIONS(7671), 1,
      anon_sym_DASH_GT,
    STATE(6668), 1,
      sym_trailing_return_type,
    ACTIONS(7377), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6467), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6664), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_COLON,
  [281529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7356), 6,
      anon_sym_AMP,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
    ACTIONS(7358), 6,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
  [281549] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(8901), 1,
      anon_sym_LBRACE,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10172), 1,
      sym_identifier,
    STATE(4582), 1,
      sym_template_type,
    STATE(4751), 1,
      sym_enumerator_list,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(4535), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281585] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(2905), 1,
      sym_enumerator_list,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(3135), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281621] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7344), 1,
      anon_sym_LBRACE,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10174), 1,
      sym_identifier,
    STATE(3001), 1,
      sym_template_type,
    STATE(3149), 1,
      sym_enumerator_list,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(2971), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281657] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(6362), 1,
      anon_sym_LBRACE,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10164), 1,
      sym_identifier,
    STATE(2385), 1,
      sym_template_type,
    STATE(2425), 1,
      sym_enumerator_list,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(4547), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [281693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11724), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(11722), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [281713] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [281738] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10559), 1,
      anon_sym_try,
    STATE(687), 1,
      sym_try_statement,
    STATE(759), 1,
      sym_compound_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [281773] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [281798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4356), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(4358), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [281817] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4671), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(10690), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11670), 1,
      sym_identifier,
    STATE(6378), 1,
      sym__scope_resolution,
    STATE(8267), 2,
      sym_identifier_parameter_pack_expansion,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [281848] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11332), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [281875] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4366), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(4368), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [281894] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10349), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    STATE(1826), 1,
      sym_compound_statement,
    STATE(1827), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [281929] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10349), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    STATE(1828), 1,
      sym_compound_statement,
    STATE(1829), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [281964] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10656), 1,
      anon_sym_try,
    STATE(601), 1,
      sym_compound_statement,
    STATE(602), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [281999] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11726), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(9092), 1,
      sym_qualified_identifier,
    ACTIONS(11728), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [282030] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11730), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11732), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11734), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11736), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(7280), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8676), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [282059] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11311), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [282086] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11319), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [282113] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11738), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(9259), 1,
      sym_qualified_identifier,
    ACTIONS(11740), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [282144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4330), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(4332), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [282163] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(11742), 1,
      anon_sym_virtual,
    STATE(2161), 1,
      sym_template_type,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(8177), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [282196] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5860), 1,
      anon_sym_LBRACK,
    ACTIONS(11744), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5862), 8,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [282217] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11445), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [282246] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11746), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11748), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11750), 1,
      aux_sym_preproc_elif_token1,
    STATE(7279), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(11752), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8823), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [282277] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(11754), 1,
      anon_sym_virtual,
    STATE(2161), 1,
      sym_template_type,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(7642), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [282310] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11732), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11734), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11756), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11736), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(7057), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(9134), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [282339] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11758), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(8929), 1,
      sym_qualified_identifier,
    ACTIONS(11760), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [282370] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10349), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    STATE(1840), 1,
      sym_compound_statement,
    STATE(1841), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [282405] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11762), 1,
      sym_identifier,
    ACTIONS(11765), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(11771), 1,
      sym_preproc_directive,
    ACTIONS(11774), 1,
      anon_sym_RBRACE,
    ACTIONS(11768), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8658), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(7048), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [282434] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11299), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [282461] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [282488] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [282515] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11279), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [282542] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10595), 1,
      anon_sym_try,
    STATE(589), 1,
      sym_compound_statement,
    STATE(590), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [282577] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [282604] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [282631] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7721), 1,
      anon_sym_requires,
    ACTIONS(10357), 1,
      anon_sym_LBRACK,
    ACTIONS(6048), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6427), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [282658] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11732), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11734), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11776), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11736), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(7280), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8829), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [282687] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10322), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    STATE(2091), 1,
      sym_compound_statement,
    STATE(2092), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [282722] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4396), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(4398), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [282741] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10595), 1,
      anon_sym_try,
    STATE(592), 1,
      sym_compound_statement,
    STATE(593), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [282776] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [282801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4402), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(4404), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [282820] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10656), 1,
      anon_sym_try,
    STATE(563), 1,
      sym_compound_statement,
    STATE(564), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [282855] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11414), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [282884] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11778), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(8810), 1,
      sym_qualified_identifier,
    ACTIONS(11780), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [282915] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9818), 1,
      anon_sym_LBRACK,
    ACTIONS(10138), 1,
      anon_sym_requires,
    ACTIONS(9820), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6433), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9807), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [282942] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [282967] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10656), 1,
      anon_sym_try,
    STATE(568), 1,
      sym_compound_statement,
    STATE(569), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [283002] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11283), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [283029] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10322), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    STATE(2093), 1,
      sym_compound_statement,
    STATE(2096), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [283064] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10595), 1,
      anon_sym_try,
    STATE(467), 1,
      sym_compound_statement,
    STATE(468), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [283099] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10537), 1,
      anon_sym_try,
    STATE(226), 1,
      sym_compound_statement,
    STATE(227), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [283134] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11782), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(8699), 1,
      sym_qualified_identifier,
    ACTIONS(11784), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [283165] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11748), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11750), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11786), 1,
      aux_sym_preproc_if_token2,
    STATE(7076), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(11752), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9216), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [283196] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [283221] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11748), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11750), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11788), 1,
      aux_sym_preproc_if_token2,
    STATE(7279), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(11752), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8608), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [283252] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11790), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(8881), 1,
      sym_qualified_identifier,
    ACTIONS(11792), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [283283] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10200), 1,
      anon_sym_LBRACK,
    ACTIONS(10328), 1,
      anon_sym_requires,
    ACTIONS(10202), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6434), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10189), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [283310] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5871), 1,
      anon_sym_LBRACK,
    ACTIONS(11744), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(11794), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5873), 6,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [283333] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [283358] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [283383] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11299), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [283410] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10361), 1,
      anon_sym_LBRACK,
    ACTIONS(11663), 1,
      anon_sym_requires,
    ACTIONS(10363), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6446), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10359), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [283437] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [283462] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [283487] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11748), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11750), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11796), 1,
      aux_sym_preproc_if_token2,
    STATE(7279), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(11752), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9116), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [283518] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11732), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11734), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11798), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11736), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(7280), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8885), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [283547] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10337), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    STATE(2026), 1,
      sym_compound_statement,
    STATE(2027), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [283582] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11439), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11748), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11750), 1,
      aux_sym_preproc_elif_token1,
    STATE(7086), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(11752), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9160), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [283613] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(4410), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [283632] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11453), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11748), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11750), 1,
      aux_sym_preproc_elif_token1,
    STATE(7043), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(11752), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9020), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [283663] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym_LBRACK,
    ACTIONS(11800), 1,
      anon_sym_requires,
    ACTIONS(10387), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6427), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(10355), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [283690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4350), 2,
      anon_sym___attribute,
      anon_sym_LBRACK,
    ACTIONS(4352), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_try,
  [283709] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [283734] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10337), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    STATE(2031), 1,
      sym_compound_statement,
    STATE(2032), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [283769] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11295), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [283796] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11732), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11734), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11803), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11736), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(7087), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(9163), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [283825] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11748), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11750), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11805), 1,
      aux_sym_preproc_if_token2,
    STATE(7114), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(11752), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9506), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [283856] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10559), 1,
      anon_sym_try,
    STATE(700), 1,
      sym_compound_statement,
    STATE(701), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [283891] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11807), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(8777), 1,
      sym_qualified_identifier,
    ACTIONS(11809), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [283922] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [283947] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [283972] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11283), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [283999] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(11811), 1,
      anon_sym_virtual,
    STATE(2161), 1,
      sym_template_type,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(7728), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [284032] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11311), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [284059] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11295), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [284086] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11319), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [284113] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10322), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    STATE(1934), 1,
      sym_compound_statement,
    STATE(1935), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [284148] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11463), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [284177] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [284202] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11435), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [284231] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [284258] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10337), 1,
      anon_sym_try,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    STATE(2051), 1,
      sym_compound_statement,
    STATE(2052), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [284293] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(11748), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11750), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11813), 1,
      aux_sym_preproc_if_token2,
    STATE(7279), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(11752), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(9151), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [284324] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3079), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 6,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [284351] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11279), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [284378] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [284403] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2987), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [284428] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11815), 1,
      anon_sym_COMMA,
    ACTIONS(11819), 1,
      anon_sym___attribute,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(7477), 1,
      aux_sym__type_definition_declarators_repeat1,
    ACTIONS(11817), 2,
      anon_sym_SEMI,
      anon_sym___attribute__,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [284461] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10537), 1,
      anon_sym_try,
    STATE(309), 1,
      sym_compound_statement,
    STATE(311), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [284496] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11332), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3096), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [284523] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2976), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [284548] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10537), 1,
      anon_sym_try,
    STATE(306), 1,
      sym_try_statement,
    STATE(321), 1,
      sym_compound_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [284583] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(11821), 1,
      anon_sym_COLON,
    STATE(2241), 1,
      sym_attribute_specifier,
    STATE(2856), 1,
      sym__enum_base_clause,
    STATE(2907), 1,
      sym_enumerator_list,
    ACTIONS(6673), 4,
      anon_sym_COMMA,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [284614] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(11732), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(11734), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(11823), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11736), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(7280), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(9154), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [284643] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(10559), 1,
      anon_sym_try,
    STATE(714), 1,
      sym_compound_statement,
    STATE(716), 1,
      sym_try_statement,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [284678] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6360), 1,
      anon_sym_LBRACE,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(11821), 1,
      anon_sym_COLON,
    STATE(2246), 1,
      sym_attribute_specifier,
    STATE(2857), 1,
      sym__enum_base_clause,
    STATE(2911), 1,
      sym_enumerator_list,
    ACTIONS(6679), 4,
      anon_sym_COMMA,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [284709] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11455), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [284738] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    ACTIONS(11825), 1,
      anon_sym_virtual,
    STATE(2161), 1,
      sym_template_type,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(8014), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [284771] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9901), 1,
      anon_sym_LBRACK,
    ACTIONS(10208), 1,
      anon_sym_requires,
    ACTIONS(9903), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6061), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6419), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9890), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [284798] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3083), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11481), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(7377), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [284828] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11831), 1,
      anon_sym_delete,
    ACTIONS(11833), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [284850] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11835), 1,
      anon_sym_delete,
    ACTIONS(11837), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [284872] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11283), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3007), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [284898] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11841), 1,
      anon_sym_LBRACK,
    STATE(7670), 1,
      sym_gnu_asm_input_operand,
    STATE(9061), 1,
      sym_string_literal,
    ACTIONS(11839), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [284922] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [284946] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3007), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [284972] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11833), 1,
      anon_sym_new,
    ACTIONS(11843), 1,
      anon_sym_delete,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [284994] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11845), 1,
      anon_sym_delete,
    ACTIONS(11847), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285016] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11849), 1,
      anon_sym_EQ,
    STATE(3058), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(8932), 1,
      sym_initializer_list,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [285048] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [285072] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11853), 1,
      anon_sym___attribute,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(11851), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [285100] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11855), 1,
      anon_sym_delete,
    ACTIONS(11857), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285122] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3094), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11481), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(7377), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [285152] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [285176] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [285200] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11859), 1,
      anon_sym_delete,
    ACTIONS(11861), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285222] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(8177), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [285252] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11295), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3007), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [285278] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11863), 1,
      anon_sym_delete,
    ACTIONS(11865), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285300] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11867), 1,
      anon_sym_delete,
    ACTIONS(11869), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285322] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11332), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3007), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT2,
  [285348] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11871), 1,
      anon_sym_delete,
    ACTIONS(11873), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285370] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285394] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285418] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285442] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11837), 1,
      anon_sym_new,
    ACTIONS(11875), 1,
      anon_sym_delete,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285464] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11877), 1,
      sym_identifier,
    ACTIONS(11879), 1,
      anon_sym_COLON_COLON,
    STATE(3122), 1,
      sym_template_type,
    STATE(7198), 1,
      sym__scope_resolution,
    STATE(3130), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [285494] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [285518] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285542] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [285566] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(7642), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [285596] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285620] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11883), 1,
      anon_sym_LBRACK,
    STATE(7735), 1,
      sym_gnu_asm_output_operand,
    STATE(8807), 1,
      sym_string_literal,
    ACTIONS(11881), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [285644] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11885), 1,
      anon_sym_delete,
    ACTIONS(11887), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285666] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11887), 1,
      anon_sym_new,
    ACTIONS(11889), 1,
      anon_sym_delete,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285688] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11891), 1,
      anon_sym_delete,
    ACTIONS(11893), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285710] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285734] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(7986), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [285764] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285788] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3127), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 6,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285812] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11887), 1,
      anon_sym_new,
    ACTIONS(11895), 1,
      anon_sym_delete,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285834] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [285858] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3049), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [285882] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11897), 1,
      anon_sym_delete,
    ACTIONS(11899), 1,
      anon_sym_new,
    ACTIONS(11829), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(11827), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [285904] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10160), 1,
      sym_identifier,
    STATE(2161), 1,
      sym_template_type,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(7645), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(9247), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [285934] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [285957] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11901), 1,
      sym_identifier,
    ACTIONS(11903), 1,
      anon_sym_template,
    STATE(2365), 1,
      sym_template_type,
    STATE(2366), 1,
      sym_dependent_type_identifier,
    STATE(2409), 1,
      sym_qualified_type_identifier,
    STATE(7178), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [285988] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10449), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11905), 1,
      sym_identifier,
    ACTIONS(11907), 1,
      anon_sym_template,
    STATE(2164), 1,
      sym_template_type,
    STATE(2172), 1,
      sym_dependent_type_identifier,
    STATE(2186), 1,
      sym_qualified_type_identifier,
    STATE(7179), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286019] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [286042] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11909), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(9106), 1,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [286069] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11911), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(9220), 1,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [286096] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10118), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11913), 1,
      sym_identifier,
    ACTIONS(11915), 1,
      anon_sym_template,
    STATE(3105), 1,
      sym_template_type,
    STATE(3107), 1,
      sym_dependent_type_identifier,
    STATE(3140), 1,
      sym_qualified_type_identifier,
    STATE(7183), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286127] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11917), 1,
      sym_identifier,
    ACTIONS(11921), 1,
      sym_system_lib_string,
    STATE(9298), 2,
      sym_preproc_call_expression,
      sym_string_literal,
    ACTIONS(11919), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [286148] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11923), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(8616), 1,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [286175] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3058), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    ACTIONS(11445), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [286202] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7950), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11925), 1,
      sym_identifier,
    ACTIONS(11927), 1,
      anon_sym_template,
    STATE(2378), 1,
      sym_template_type,
    STATE(2394), 1,
      sym_dependent_type_identifier,
    STATE(2419), 1,
      sym_qualified_type_identifier,
    STATE(7187), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286233] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3058), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    ACTIONS(11435), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [286260] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9993), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11929), 1,
      sym_identifier,
    ACTIONS(11931), 1,
      anon_sym_template,
    STATE(4137), 1,
      sym_template_type,
    STATE(4138), 1,
      sym_dependent_type_identifier,
    STATE(4290), 1,
      sym_qualified_type_identifier,
    STATE(7189), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286291] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3058), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    ACTIONS(11463), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [286318] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [286341] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [286364] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [286387] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11933), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(9325), 1,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [286414] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10074), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11935), 1,
      sym_identifier,
    ACTIONS(11937), 1,
      anon_sym_template,
    STATE(4556), 1,
      sym_template_type,
    STATE(4561), 1,
      sym_dependent_type_identifier,
    STATE(4669), 1,
      sym_qualified_type_identifier,
    STATE(7195), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286445] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11939), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(8723), 1,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [286472] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11941), 1,
      sym_identifier,
    ACTIONS(11943), 1,
      anon_sym_template,
    STATE(1949), 1,
      sym_template_type,
    STATE(1950), 1,
      sym_dependent_type_identifier,
    STATE(2159), 1,
      sym_qualified_type_identifier,
    STATE(7197), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286503] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11879), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11945), 1,
      sym_identifier,
    ACTIONS(11947), 1,
      anon_sym_template,
    STATE(3067), 1,
      sym_template_type,
    STATE(3070), 1,
      sym_qualified_type_identifier,
    STATE(3071), 1,
      sym_dependent_type_identifier,
    STATE(7198), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286534] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(4611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11949), 1,
      sym_identifier,
    ACTIONS(11951), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(7199), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286565] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(5149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11953), 1,
      sym_identifier,
    ACTIONS(11955), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(7200), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286596] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11957), 1,
      sym_identifier,
    ACTIONS(11959), 1,
      sym_system_lib_string,
    STATE(9424), 2,
      sym_preproc_call_expression,
      sym_string_literal,
    ACTIONS(11919), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [286617] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10021), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11961), 1,
      sym_identifier,
    ACTIONS(11963), 1,
      anon_sym_template,
    STATE(2874), 1,
      sym_template_type,
    STATE(2892), 1,
      sym_dependent_type_identifier,
    STATE(2972), 1,
      sym_qualified_type_identifier,
    STATE(7202), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286648] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7791), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11943), 1,
      anon_sym_template,
    ACTIONS(11965), 1,
      sym_identifier,
    STATE(1949), 1,
      sym_template_type,
    STATE(1950), 1,
      sym_dependent_type_identifier,
    STATE(2159), 1,
      sym_qualified_type_identifier,
    STATE(7203), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286679] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10471), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11967), 1,
      sym_identifier,
    ACTIONS(11969), 1,
      anon_sym_template,
    STATE(1949), 1,
      sym_template_type,
    STATE(1950), 1,
      sym_dependent_type_identifier,
    STATE(2159), 1,
      sym_qualified_type_identifier,
    STATE(7204), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286710] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3058), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    ACTIONS(11414), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [286737] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [286760] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11971), 1,
      sym_identifier,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    STATE(626), 1,
      sym_declaration_list,
    STATE(7344), 1,
      sym_attribute_declaration,
    STATE(8213), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [286791] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [286814] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(3182), 1,
      sym_template_argument_list,
    ACTIONS(7475), 2,
      anon_sym_LBRACK,
      anon_sym_COLON,
    ACTIONS(5099), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
  [286837] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7885), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11977), 1,
      sym_identifier,
    ACTIONS(11979), 1,
      anon_sym_template,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(2471), 1,
      sym_qualified_type_identifier,
    STATE(7210), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286868] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5871), 1,
      anon_sym_AMP,
    ACTIONS(11981), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(11983), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5873), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [286889] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11985), 1,
      sym_identifier,
    ACTIONS(11987), 1,
      sym_system_lib_string,
    STATE(8646), 2,
      sym_preproc_call_expression,
      sym_string_literal,
    ACTIONS(11919), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [286910] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(9961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11927), 1,
      anon_sym_template,
    ACTIONS(11989), 1,
      sym_identifier,
    STATE(2378), 1,
      sym_template_type,
    STATE(2394), 1,
      sym_dependent_type_identifier,
    STATE(2419), 1,
      sym_qualified_type_identifier,
    STATE(7213), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [286941] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(3058), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    ACTIONS(11455), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [286968] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11991), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(8687), 1,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [286995] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5860), 1,
      anon_sym_AMP,
    ACTIONS(11983), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5862), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_or,
  [287014] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11260), 1,
      anon_sym_LBRACK,
    STATE(3144), 1,
      sym_parameter_list,
    STATE(6426), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 5,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [287037] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10096), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11993), 1,
      sym_identifier,
    ACTIONS(11995), 1,
      anon_sym_template,
    STATE(2984), 1,
      sym_template_type,
    STATE(2985), 1,
      sym_dependent_type_identifier,
    STATE(3042), 1,
      sym_qualified_type_identifier,
    STATE(7218), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [287068] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(11997), 1,
      sym_identifier,
    STATE(289), 1,
      sym_declaration_list,
    STATE(7338), 1,
      sym_attribute_declaration,
    STATE(8429), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [287099] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(11999), 1,
      sym_identifier,
    STATE(721), 1,
      sym_declaration_list,
    STATE(7308), 1,
      sym_attribute_declaration,
    STATE(8259), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [287130] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12001), 1,
      sym_identifier,
    ACTIONS(12003), 1,
      sym_system_lib_string,
    STATE(8998), 2,
      sym_preproc_call_expression,
      sym_string_literal,
    ACTIONS(11919), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [287151] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7845), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12005), 1,
      sym_identifier,
    ACTIONS(12007), 1,
      anon_sym_template,
    STATE(1949), 1,
      sym_template_type,
    STATE(1950), 1,
      sym_dependent_type_identifier,
    STATE(2159), 1,
      sym_qualified_type_identifier,
    STATE(7222), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [287182] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12009), 1,
      sym_identifier,
    STATE(609), 1,
      sym_declaration_list,
    STATE(7306), 1,
      sym_attribute_declaration,
    STATE(8237), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [287213] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12011), 1,
      sym_identifier,
    STATE(495), 1,
      sym_declaration_list,
    STATE(7302), 1,
      sym_attribute_declaration,
    STATE(8472), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [287244] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7936), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12013), 1,
      sym_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(2471), 1,
      sym_qualified_type_identifier,
    STATE(7225), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [287275] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(11079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12015), 1,
      sym_identifier,
    STATE(6417), 1,
      sym__scope_resolution,
    STATE(9185), 1,
      sym_qualified_identifier,
    STATE(9247), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [287302] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10149), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11953), 1,
      sym_identifier,
    ACTIONS(11955), 1,
      anon_sym_template,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(2471), 1,
      sym_qualified_type_identifier,
    STATE(7227), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [287333] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12017), 1,
      sym_identifier,
    STATE(766), 1,
      sym_declaration_list,
    STATE(7343), 1,
      sym_attribute_declaration,
    STATE(8437), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [287364] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7863), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11977), 1,
      sym_identifier,
    ACTIONS(11979), 1,
      anon_sym_template,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(7229), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [287395] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(7911), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12019), 1,
      sym_identifier,
    ACTIONS(12021), 1,
      anon_sym_template,
    STATE(4666), 1,
      sym_template_type,
    STATE(4667), 1,
      sym_dependent_type_identifier,
    STATE(4699), 1,
      sym_qualified_type_identifier,
    STATE(7230), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [287426] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(3182), 1,
      sym_template_argument_list,
    ACTIONS(4521), 2,
      anon_sym_LBRACK,
      anon_sym_COLON,
    ACTIONS(4514), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
  [287449] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_template,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(3744), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12013), 1,
      sym_identifier,
    STATE(2114), 1,
      sym_qualified_type_identifier,
    STATE(2126), 1,
      sym_template_type,
    STATE(2144), 1,
      sym_dependent_type_identifier,
    STATE(7232), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [287480] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12023), 1,
      sym_identifier,
    STATE(303), 1,
      sym_declaration_list,
    STATE(7357), 1,
      sym_attribute_declaration,
    STATE(8489), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [287511] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      anon_sym_decltype,
    ACTIONS(10049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12025), 1,
      sym_identifier,
    ACTIONS(12027), 1,
      anon_sym_template,
    STATE(2995), 1,
      sym_template_type,
    STATE(3003), 1,
      sym_dependent_type_identifier,
    STATE(3014), 1,
      sym_qualified_type_identifier,
    STATE(7234), 1,
      sym__scope_resolution,
    STATE(9247), 1,
      sym_decltype,
  [287542] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12029), 1,
      sym_identifier,
    STATE(471), 1,
      sym_declaration_list,
    STATE(7316), 1,
      sym_attribute_declaration,
    STATE(8283), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [287573] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12031), 1,
      anon_sym_SEMI,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [287599] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12033), 1,
      anon_sym_SEMI,
    ACTIONS(12035), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(7742), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [287625] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12037), 1,
      anon_sym_SEMI,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [287651] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(6896), 1,
      anon_sym_LBRACK,
    STATE(3182), 1,
      sym_template_argument_list,
    ACTIONS(6898), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_COLON,
  [287671] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12039), 1,
      anon_sym_SEMI,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [287697] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12041), 1,
      anon_sym_SEMI,
    ACTIONS(12043), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(7712), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [287723] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(6459), 1,
      anon_sym_COMMA,
    ACTIONS(12045), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12047), 1,
      anon_sym_RBRACK,
    ACTIONS(12050), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(7910), 1,
      aux_sym_structured_binding_declarator_repeat1,
  [287751] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [287773] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [287795] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [287817] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [287839] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12052), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [287865] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(12054), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7382), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [287891] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11283), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3083), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 3,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_GT2,
  [287915] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12056), 1,
      anon_sym_SEMI,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [287941] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [287963] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [287985] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [288007] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3147), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 4,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [288029] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11283), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3094), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
  [288053] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11295), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3094), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
  [288077] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12060), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(12058), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [288093] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12062), 1,
      anon_sym_COLON,
    STATE(3172), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288119] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12064), 1,
      anon_sym_SEMI,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288145] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3094), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
  [288169] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11332), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3094), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym___attribute__,
  [288193] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12068), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(12066), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [288209] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12072), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(12074), 1,
      anon_sym_EQ,
    ACTIONS(12070), 6,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      sym_identifier,
  [288227] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(7475), 1,
      anon_sym_LBRACK,
    STATE(6540), 1,
      sym_template_argument_list,
    ACTIONS(5099), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [288249] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11258), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3083), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 3,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_GT2,
  [288273] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12076), 1,
      anon_sym_SEMI,
    ACTIONS(12078), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(7662), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288299] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11445), 1,
      anon_sym_COLON,
    STATE(3172), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288325] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11463), 1,
      anon_sym_COLON,
    STATE(3172), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288351] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12080), 1,
      anon_sym_SEMI,
    ACTIONS(12082), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(7732), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288377] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12084), 1,
      anon_sym_SEMI,
    ACTIONS(12086), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(7609), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288403] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11414), 1,
      anon_sym_COLON,
    STATE(3172), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288429] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4521), 1,
      anon_sym_LBRACK,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(6540), 1,
      sym_template_argument_list,
    ACTIONS(4514), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [288451] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11295), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3083), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 3,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_GT2,
  [288475] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12088), 1,
      anon_sym_SEMI,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288501] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11332), 1,
      anon_sym___attribute,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3083), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 3,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_GT2,
  [288525] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [288547] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [288569] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11435), 1,
      anon_sym_COLON,
    STATE(3172), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288595] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12090), 1,
      sym_identifier,
    ACTIONS(12095), 1,
      aux_sym_preproc_elif_token1,
    STATE(7279), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
    ACTIONS(12093), 4,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [288617] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12097), 1,
      sym_identifier,
    ACTIONS(12102), 1,
      aux_sym_preproc_elif_token1,
    STATE(7280), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    ACTIONS(12100), 4,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [288637] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(11455), 1,
      anon_sym_COLON,
    STATE(3172), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6948), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288663] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(12104), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7382), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288689] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [288711] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11449), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7382), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288737] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11410), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7382), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288763] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12106), 1,
      anon_sym_SEMI,
    ACTIONS(12108), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(7704), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288789] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [288811] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11459), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7382), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288837] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11469), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7382), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288863] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10316), 1,
      anon_sym_LBRACK,
    ACTIONS(11441), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6992), 1,
      sym__function_declarator_seq,
    STATE(7382), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288889] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12110), 1,
      anon_sym_RPAREN,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288915] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11883), 1,
      anon_sym_LBRACK,
    STATE(8188), 1,
      sym_gnu_asm_output_operand,
    STATE(8807), 1,
      sym_string_literal,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [288935] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12112), 1,
      anon_sym_SEMI,
    ACTIONS(12114), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    STATE(7738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288961] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12116), 1,
      anon_sym_SEMI,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [288987] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3000), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(12118), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [289009] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11841), 1,
      anon_sym_LBRACK,
    STATE(8102), 1,
      sym_gnu_asm_input_operand,
    STATE(9061), 1,
      sym_string_literal,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [289029] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    ACTIONS(12120), 1,
      anon_sym_SEMI,
    STATE(3010), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12124), 1,
      anon_sym_AMP,
    ACTIONS(12122), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [289070] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [289091] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11041), 1,
      anon_sym___attribute,
    ACTIONS(12126), 1,
      anon_sym_EQ,
    ACTIONS(11039), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [289108] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    ACTIONS(12128), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [289127] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12130), 1,
      sym_identifier,
    STATE(555), 1,
      sym_declaration_list,
    STATE(8361), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [289152] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [289173] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12132), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289196] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6454), 1,
      anon_sym_COLON,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(7418), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289219] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12029), 1,
      sym_identifier,
    STATE(471), 1,
      sym_declaration_list,
    STATE(8283), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [289244] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(7418), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289267] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12017), 1,
      sym_identifier,
    STATE(766), 1,
      sym_declaration_list,
    STATE(8437), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [289292] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12134), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289315] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12045), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12136), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    ACTIONS(6537), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [289338] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12138), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [289355] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11297), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [289376] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [289397] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(2693), 1,
      sym_template_argument_list,
    STATE(8076), 2,
      sym_argument_list,
      sym_initializer_list,
  [289420] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12045), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12050), 1,
      anon_sym_EQ,
    STATE(1659), 1,
      sym_template_argument_list,
    ACTIONS(6556), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [289443] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12142), 1,
      sym_identifier,
    STATE(551), 1,
      sym_declaration_list,
    STATE(8377), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [289468] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [289489] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [289510] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [289531] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11330), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [289552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4686), 1,
      anon_sym_AMP,
    ACTIONS(4684), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [289567] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12146), 1,
      anon_sym_COMMA,
    ACTIONS(12148), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(12144), 5,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      sym_identifier,
  [289584] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6510), 1,
      anon_sym_COLON,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(7418), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289607] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12150), 1,
      anon_sym_LBRACK,
    ACTIONS(12153), 1,
      anon_sym_EQ,
    ACTIONS(12155), 1,
      anon_sym_DOT,
    STATE(7324), 4,
      sym_subscript_designator,
      sym_subscript_range_designator,
      sym_field_designator,
      aux_sym_initializer_pair_repeat1,
  [289626] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12160), 1,
      anon_sym_AMP,
    ACTIONS(12158), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [289641] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(5495), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(5976), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6000), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289662] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6028), 1,
      anon_sym_AMP,
    ACTIONS(6030), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_requires,
  [289677] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12162), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12164), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [289694] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12167), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289717] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12169), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289740] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(7418), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289763] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [289784] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [289805] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12171), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289828] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6482), 1,
      anon_sym_COLON,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(7418), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289851] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12173), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289874] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11309), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [289895] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12023), 1,
      sym_identifier,
    STATE(303), 1,
      sym_declaration_list,
    STATE(8489), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [289920] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(10531), 1,
      anon_sym_LBRACK,
    STATE(2920), 1,
      sym_parameter_list,
    STATE(6619), 1,
      sym__function_declarator_seq,
    STATE(6543), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [289943] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12177), 1,
      anon_sym_AMP,
    ACTIONS(12175), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [289958] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3047), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11277), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [289979] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12179), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [290002] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12181), 1,
      sym_identifier,
    STATE(761), 1,
      sym_declaration_list,
    STATE(8210), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [290027] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12011), 1,
      sym_identifier,
    STATE(495), 1,
      sym_declaration_list,
    STATE(8472), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [290052] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12183), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [290075] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12185), 1,
      anon_sym_LPAREN2,
    STATE(7311), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6058), 1,
      anon_sym_AMP,
    ACTIONS(6060), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_requires,
  [290107] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(6896), 1,
      anon_sym_LBRACK,
    STATE(6540), 1,
      sym_template_argument_list,
    ACTIONS(6898), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [290126] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12187), 1,
      anon_sym_LPAREN2,
    STATE(7351), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6054), 1,
      anon_sym_AMP,
    ACTIONS(6056), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_requires,
  [290158] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12189), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290175] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11281), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [290196] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym___attribute__,
    ACTIONS(7211), 1,
      anon_sym___attribute,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6031), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(6225), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [290217] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11293), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [290238] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12191), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [290261] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12195), 1,
      anon_sym_AMP,
    ACTIONS(12193), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [290276] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12197), 1,
      sym_identifier,
    STATE(270), 1,
      sym_declaration_list,
    STATE(8352), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [290301] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12199), 1,
      anon_sym_LBRACK,
    ACTIONS(12201), 1,
      anon_sym_EQ,
    ACTIONS(12203), 1,
      anon_sym_DOT,
    STATE(7324), 4,
      sym_subscript_designator,
      sym_subscript_range_designator,
      sym_field_designator,
      aux_sym_initializer_pair_repeat1,
  [290320] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    ACTIONS(12205), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [290339] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12207), 1,
      anon_sym_LPAREN2,
    STATE(7361), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290356] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12209), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290373] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11256), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [290394] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12211), 1,
      anon_sym_LPAREN2,
    STATE(7365), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290411] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
    ACTIONS(11317), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [290432] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12213), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290449] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12215), 1,
      anon_sym_LPAREN2,
    STATE(7367), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290466] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12217), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290483] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12219), 1,
      anon_sym_LPAREN2,
    STATE(7369), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290500] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12221), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290517] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12223), 1,
      anon_sym_LPAREN2,
    STATE(7371), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290534] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12225), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290551] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(12227), 1,
      anon_sym_RPAREN,
    STATE(2589), 1,
      sym_parameter_list,
    STATE(6971), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [290574] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12229), 1,
      anon_sym_LPAREN2,
    STATE(7374), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290591] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12231), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290608] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12233), 1,
      anon_sym_LPAREN2,
    STATE(7376), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290625] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12235), 1,
      anon_sym_LPAREN2,
    STATE(7328), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(12140), 4,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [290642] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    ACTIONS(12205), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [290661] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11041), 1,
      anon_sym___attribute,
    ACTIONS(12237), 1,
      anon_sym_EQ,
    ACTIONS(11039), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym___attribute__,
      anon_sym_LBRACK,
  [290678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12239), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12241), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [290692] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12243), 1,
      anon_sym_SEMI,
    STATE(7389), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8961), 1,
      sym_attribute_specifier,
  [290714] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12245), 1,
      anon_sym_SEMI,
    STATE(7390), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8980), 1,
      sym_attribute_specifier,
  [290736] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11653), 1,
      anon_sym_LBRACK,
    ACTIONS(11651), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [290754] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12247), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8987), 1,
      sym_attribute_specifier,
  [290776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12095), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(12093), 5,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      sym_identifier,
  [290790] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(10559), 1,
      anon_sym_try,
    ACTIONS(12249), 1,
      anon_sym_SEMI,
    ACTIONS(12251), 1,
      anon_sym_EQ,
    STATE(735), 2,
      sym_compound_statement,
      sym_try_statement,
  [290810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12253), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12255), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [290824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12257), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12259), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [290838] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12261), 1,
      anon_sym_SEMI,
    STATE(7396), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9012), 1,
      sym_attribute_specifier,
  [290860] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12263), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9016), 1,
      sym_attribute_specifier,
  [290882] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12265), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9021), 1,
      sym_attribute_specifier,
  [290904] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(10559), 1,
      anon_sym_try,
    ACTIONS(12267), 1,
      anon_sym_SEMI,
    ACTIONS(12269), 1,
      anon_sym_EQ,
    STATE(730), 2,
      sym_compound_statement,
      sym_try_statement,
  [290924] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10349), 1,
      anon_sym_try,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    ACTIONS(12271), 1,
      anon_sym_SEMI,
    ACTIONS(12273), 1,
      anon_sym_EQ,
    STATE(1805), 2,
      sym_compound_statement,
      sym_try_statement,
  [290944] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10322), 1,
      anon_sym_try,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    ACTIONS(12275), 1,
      anon_sym_SEMI,
    ACTIONS(12277), 1,
      anon_sym_EQ,
    STATE(2112), 2,
      sym_compound_statement,
      sym_try_statement,
  [290964] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12279), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9027), 1,
      sym_attribute_specifier,
  [290986] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12281), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8724), 1,
      sym_attribute_specifier,
  [291008] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12283), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9032), 1,
      sym_attribute_specifier,
  [291030] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6782), 1,
      anon_sym_LT,
    ACTIONS(6896), 1,
      anon_sym_LBRACK,
    STATE(3076), 1,
      sym_template_argument_list,
    ACTIONS(6898), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [291048] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12285), 1,
      anon_sym_SEMI,
    STATE(7406), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9547), 1,
      sym_attribute_specifier,
  [291070] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12287), 1,
      anon_sym_SEMI,
    STATE(7430), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8845), 1,
      sym_attribute_specifier,
  [291092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(8890), 1,
      sym_string_literal,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [291106] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12289), 1,
      anon_sym_SEMI,
    STATE(7431), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8855), 1,
      sym_attribute_specifier,
  [291128] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12291), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8862), 1,
      sym_attribute_specifier,
  [291150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12293), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12295), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [291164] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(10537), 1,
      anon_sym_try,
    ACTIONS(12297), 1,
      anon_sym_SEMI,
    ACTIONS(12299), 1,
      anon_sym_EQ,
    STATE(244), 2,
      sym_compound_statement,
      sym_try_statement,
  [291184] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10349), 1,
      anon_sym_try,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    ACTIONS(12301), 1,
      anon_sym_SEMI,
    ACTIONS(12303), 1,
      anon_sym_EQ,
    STATE(1818), 2,
      sym_compound_statement,
      sym_try_statement,
  [291204] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12305), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8714), 1,
      sym_attribute_specifier,
  [291226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12307), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12309), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [291240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12311), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12313), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [291254] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12315), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12317), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [291268] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(6896), 1,
      anon_sym_LBRACK,
    STATE(3076), 1,
      sym_template_argument_list,
    ACTIONS(6898), 3,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
  [291286] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12293), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12295), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [291300] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12319), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8738), 1,
      sym_attribute_specifier,
  [291322] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12321), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8740), 1,
      sym_attribute_specifier,
  [291344] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(11639), 1,
      anon_sym_LBRACK,
    STATE(6996), 1,
      sym_template_argument_list,
    ACTIONS(11635), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [291362] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(11661), 1,
      anon_sym_LBRACK,
    STATE(7009), 1,
      sym_template_argument_list,
    ACTIONS(11659), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [291380] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12323), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8899), 1,
      sym_attribute_specifier,
  [291402] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12325), 1,
      anon_sym_SEMI,
    STATE(7395), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8590), 1,
      sym_attribute_specifier,
  [291424] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6593), 1,
      anon_sym_LBRACK,
    ACTIONS(7669), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6595), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(6223), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [291442] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12327), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9342), 1,
      sym_attribute_specifier,
  [291464] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10322), 1,
      anon_sym_try,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    ACTIONS(12329), 1,
      anon_sym_SEMI,
    ACTIONS(12331), 1,
      anon_sym_EQ,
    STATE(2069), 2,
      sym_compound_statement,
      sym_try_statement,
  [291484] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10337), 1,
      anon_sym_try,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    ACTIONS(12333), 1,
      anon_sym_SEMI,
    ACTIONS(12335), 1,
      anon_sym_EQ,
    STATE(2014), 2,
      sym_compound_statement,
      sym_try_statement,
  [291504] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(10595), 1,
      anon_sym_try,
    ACTIONS(12337), 1,
      anon_sym_SEMI,
    ACTIONS(12339), 1,
      anon_sym_EQ,
    STATE(475), 2,
      sym_compound_statement,
      sym_try_statement,
  [291524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12341), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12343), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [291538] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_try,
    ACTIONS(12345), 1,
      anon_sym_SEMI,
    ACTIONS(12347), 1,
      anon_sym_EQ,
    STATE(540), 2,
      sym_compound_statement,
      sym_try_statement,
  [291558] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12349), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8612), 1,
      sym_attribute_specifier,
  [291580] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(10595), 1,
      anon_sym_try,
    ACTIONS(12351), 1,
      anon_sym_SEMI,
    ACTIONS(12353), 1,
      anon_sym_EQ,
    STATE(487), 2,
      sym_compound_statement,
      sym_try_statement,
  [291600] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12355), 1,
      anon_sym_SEMI,
    STATE(7419), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9254), 1,
      sym_attribute_specifier,
  [291622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11774), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12357), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [291636] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12359), 1,
      anon_sym_SEMI,
    STATE(7413), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8705), 1,
      sym_attribute_specifier,
  [291658] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12361), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9290), 1,
      sym_attribute_specifier,
  [291680] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(9005), 1,
      anon_sym_COMMA,
    ACTIONS(12363), 1,
      anon_sym_SEMI,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    STATE(9309), 1,
      sym_attribute_specifier,
  [291702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(9000), 1,
      sym_string_literal,
    ACTIONS(117), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [291716] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    ACTIONS(10537), 1,
      anon_sym_try,
    ACTIONS(12365), 1,
      anon_sym_SEMI,
    ACTIONS(12367), 1,
      anon_sym_EQ,
    STATE(295), 2,
      sym_compound_statement,
      sym_try_statement,
  [291736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12341), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(12343), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [291750] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    ACTIONS(10656), 1,
      anon_sym_try,
    ACTIONS(12369), 1,
      anon_sym_SEMI,
    ACTIONS(12371), 1,
      anon_sym_EQ,
    STATE(518), 2,
      sym_compound_statement,
      sym_try_statement,
  [291770] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10337), 1,
      anon_sym_try,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    ACTIONS(12373), 1,
      anon_sym_SEMI,
    ACTIONS(12375), 1,
      anon_sym_EQ,
    STATE(1998), 2,
      sym_compound_statement,
      sym_try_statement,
  [291790] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12377), 1,
      anon_sym_SEMI,
    STATE(7449), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [291807] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    STATE(2255), 1,
      sym_decltype_auto,
    ACTIONS(12379), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [291824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12381), 2,
      anon_sym_class,
      anon_sym_typename,
    STATE(8464), 3,
      sym_type_parameter_declaration,
      sym_variadic_type_parameter_declaration,
      sym_optional_type_parameter_declaration,
  [291837] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9853), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9857), 1,
      anon_sym_EQ,
    ACTIONS(12383), 1,
      sym_identifier,
    ACTIONS(9855), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [291854] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    ACTIONS(12385), 1,
      anon_sym_RPAREN,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [291873] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(6896), 1,
      anon_sym_LBRACK,
    STATE(3819), 1,
      sym_template_argument_list,
    ACTIONS(6898), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [291890] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11277), 1,
      anon_sym_COLON,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [291909] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12387), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [291926] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(6896), 1,
      anon_sym_LBRACK,
    STATE(2970), 1,
      sym_template_argument_list,
    ACTIONS(6898), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [291943] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12389), 1,
      sym_identifier,
    STATE(8138), 1,
      sym__namespace_specifier,
    STATE(8533), 1,
      sym_nested_namespace_specifier,
  [291962] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12391), 1,
      sym_identifier,
    STATE(8780), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [291981] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(12393), 1,
      aux_sym_preproc_if_token2,
    STATE(7322), 1,
      sym_enumerator,
    STATE(7570), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(7571), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
  [292000] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12395), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292017] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12397), 1,
      anon_sym_SEMI,
    STATE(7453), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292034] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12399), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292051] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12401), 1,
      anon_sym_SEMI,
    STATE(7455), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292068] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12403), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292085] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1653), 1,
      sym_template_argument_list,
    ACTIONS(4514), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [292102] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12405), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292119] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12407), 1,
      anon_sym_SEMI,
    STATE(7479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292136] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11297), 1,
      anon_sym_COLON,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292155] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12409), 1,
      anon_sym_SEMI,
    STATE(7500), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292172] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11330), 1,
      anon_sym_COLON,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292191] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12411), 1,
      sym_identifier,
    STATE(9386), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [292210] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12413), 1,
      anon_sym_SEMI,
    STATE(7475), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12417), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12415), 4,
      anon_sym_virtual,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
  [292240] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12419), 1,
      anon_sym_SEMI,
    STATE(7472), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292257] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(12421), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(2728), 1,
      sym_template_method,
    STATE(8276), 1,
      sym_operator_name,
  [292276] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12423), 1,
      sym_identifier,
    STATE(9395), 1,
      sym__namespace_specifier,
    STATE(9413), 1,
      sym_nested_namespace_specifier,
  [292295] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(12425), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(4196), 1,
      sym_template_method,
    STATE(8340), 1,
      sym_operator_name,
  [292314] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12427), 5,
      anon_sym_LPAREN2,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
      anon_sym___volatile__,
  [292325] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12429), 1,
      anon_sym_SEMI,
    STATE(7491), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292342] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(12431), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3926), 1,
      sym_template_method,
    STATE(8333), 1,
      sym_operator_name,
  [292361] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    ACTIONS(12433), 1,
      anon_sym_RPAREN,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292380] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12435), 1,
      anon_sym_SEMI,
    STATE(7473), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292397] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12437), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292414] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12439), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292431] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12441), 1,
      anon_sym_SEMI,
    STATE(7481), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292448] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12443), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292465] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12389), 1,
      sym_identifier,
    STATE(8198), 1,
      sym__namespace_specifier,
    STATE(8229), 1,
      sym_nested_namespace_specifier,
  [292484] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11815), 1,
      anon_sym_COMMA,
    ACTIONS(12447), 1,
      anon_sym___attribute,
    STATE(7492), 1,
      aux_sym__type_definition_declarators_repeat1,
    ACTIONS(12445), 2,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [292501] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12449), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292518] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12451), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292535] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11975), 1,
      anon_sym_inline,
    ACTIONS(12453), 1,
      sym_identifier,
    STATE(8925), 1,
      sym_nested_namespace_specifier,
    STATE(9395), 1,
      sym__namespace_specifier,
  [292554] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12455), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292571] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    ACTIONS(12457), 1,
      anon_sym_RPAREN,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292590] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12459), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292607] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12461), 1,
      anon_sym_COMMA,
    ACTIONS(12466), 1,
      anon_sym___attribute,
    STATE(7484), 1,
      aux_sym_field_declaration_repeat1,
    ACTIONS(12464), 2,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [292624] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    ACTIONS(12470), 1,
      anon_sym_COLON_COLON,
    STATE(8424), 1,
      sym_argument_list,
    ACTIONS(12468), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [292641] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12472), 1,
      anon_sym_SEMI,
    STATE(7451), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292658] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12474), 1,
      anon_sym_SEMI,
    STATE(7488), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292675] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12476), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292692] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(12478), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(4107), 1,
      sym_template_method,
    STATE(8269), 1,
      sym_operator_name,
  [292711] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12480), 1,
      anon_sym_SEMI,
    STATE(7506), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292728] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12482), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292745] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12484), 1,
      anon_sym_COMMA,
    ACTIONS(12489), 1,
      anon_sym___attribute,
    STATE(7492), 1,
      aux_sym__type_definition_declarators_repeat1,
    ACTIONS(12487), 2,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [292762] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(12491), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(2728), 1,
      sym_template_method,
    STATE(8290), 1,
      sym_operator_name,
  [292781] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7709), 1,
      sym_auto,
    ACTIONS(7711), 1,
      anon_sym_decltype,
    STATE(2255), 1,
      sym_decltype_auto,
    ACTIONS(12493), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [292798] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(2693), 1,
      sym_template_argument_list,
    ACTIONS(6754), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
  [292815] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11309), 1,
      anon_sym_COLON,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292834] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11317), 1,
      anon_sym_COLON,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292853] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12495), 1,
      anon_sym_SEMI,
    STATE(7508), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292870] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12497), 1,
      anon_sym_SEMI,
    STATE(7444), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292887] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12499), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292904] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    ACTIONS(12501), 1,
      anon_sym_RPAREN,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292923] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11281), 1,
      anon_sym_COLON,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292942] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11293), 1,
      anon_sym_COLON,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [292961] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12503), 1,
      anon_sym_SEMI,
    STATE(7510), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292978] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12505), 1,
      anon_sym_SEMI,
    STATE(7478), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [292995] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12507), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [293012] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11256), 1,
      anon_sym_COLON,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(3190), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [293031] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12509), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [293048] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_operator,
    ACTIONS(12491), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(2728), 1,
      sym_template_method,
    STATE(8336), 1,
      sym_operator_name,
  [293067] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12511), 1,
      anon_sym_SEMI,
    STATE(4520), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [293084] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      anon_sym___attribute,
    ACTIONS(6736), 1,
      anon_sym___attribute__,
    ACTIONS(12513), 1,
      anon_sym_SEMI,
    STATE(7483), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [293101] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    ACTIONS(12517), 1,
      anon_sym_LBRACE,
    STATE(6463), 1,
      sym_requirement_seq,
    STATE(8317), 1,
      sym_requires_parameter_list,
  [293117] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    STATE(4746), 1,
      sym_field_declaration_list,
    STATE(8397), 1,
      sym_base_class_clause,
  [293133] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11192), 1,
      anon_sym_LBRACE,
    STATE(3719), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293147] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    STATE(4174), 1,
      sym_argument_list,
    STATE(5419), 1,
      sym_initializer_list,
  [293163] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12521), 1,
      anon_sym_GT2,
    STATE(7868), 1,
      aux_sym_template_argument_list_repeat1,
  [293179] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11210), 1,
      anon_sym_LBRACE,
    STATE(1696), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293193] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    STATE(3942), 1,
      sym_argument_list,
    STATE(4395), 1,
      sym_initializer_list,
  [293209] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11167), 1,
      anon_sym_LBRACE,
    STATE(3778), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293223] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    STATE(2442), 1,
      sym_field_declaration_list,
    STATE(8314), 1,
      sym_base_class_clause,
  [293239] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12523), 1,
      anon_sym_GT2,
    STATE(8161), 1,
      aux_sym_template_argument_list_repeat1,
  [293255] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12525), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [293269] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12529), 1,
      anon_sym_DQUOTE,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [293285] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    STATE(4029), 1,
      sym_argument_list,
    STATE(5511), 1,
      sym_initializer_list,
  [293301] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    ACTIONS(12535), 1,
      anon_sym_LBRACE,
    STATE(1700), 1,
      sym_requirement_seq,
    STATE(8306), 1,
      sym_requires_parameter_list,
  [293317] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12537), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [293333] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12539), 1,
      anon_sym_GT2,
    STATE(8066), 1,
      aux_sym_template_argument_list_repeat1,
  [293349] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11210), 1,
      anon_sym_LBRACE,
    STATE(1699), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293363] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    STATE(4712), 1,
      sym_field_declaration_list,
    STATE(8339), 1,
      sym_base_class_clause,
  [293379] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12541), 1,
      anon_sym_DQUOTE,
    ACTIONS(12543), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12545), 1,
      sym_escape_sequence,
    STATE(7679), 1,
      aux_sym_string_literal_repeat1,
  [293395] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12547), 1,
      anon_sym_DQUOTE,
    ACTIONS(12549), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12551), 1,
      sym_escape_sequence,
    STATE(7539), 1,
      aux_sym_string_literal_repeat1,
  [293411] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12553), 1,
      anon_sym_EQ,
    STATE(7720), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [293425] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12555), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [293439] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12557), 1,
      anon_sym___except,
    ACTIONS(12559), 1,
      anon_sym___finally,
    STATE(432), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [293453] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12563), 1,
      anon_sym_EQ,
    STATE(522), 1,
      sym_declaration_list,
  [293469] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12565), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [293485] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11171), 1,
      anon_sym_LBRACE,
    STATE(4424), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293499] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4617), 1,
      anon_sym_LT,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(811), 1,
      sym_template_parameter_list,
    STATE(2150), 1,
      sym_template_type,
  [293515] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12569), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [293531] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12571), 1,
      anon_sym_DQUOTE,
    ACTIONS(12573), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12575), 1,
      sym_escape_sequence,
    STATE(7552), 1,
      aux_sym_string_literal_repeat1,
  [293547] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11175), 1,
      anon_sym_LBRACE,
    STATE(4877), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293561] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12577), 1,
      anon_sym_GT2,
    STATE(8096), 1,
      aux_sym_template_argument_list_repeat1,
  [293577] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    STATE(2306), 1,
      sym_field_declaration_list,
    STATE(8389), 1,
      sym_base_class_clause,
  [293593] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12579), 1,
      anon_sym_COMMA,
    STATE(7544), 1,
      aux_sym_gnu_asm_clobber_list_repeat1,
    ACTIONS(12582), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [293607] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12584), 1,
      anon_sym___except,
    ACTIONS(12586), 1,
      anon_sym___finally,
    STATE(392), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [293621] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    ACTIONS(12588), 1,
      anon_sym_LBRACE,
    STATE(6202), 1,
      sym_requirement_seq,
    STATE(8477), 1,
      sym_requires_parameter_list,
  [293637] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12590), 1,
      anon_sym_DQUOTE,
    ACTIONS(12592), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12594), 1,
      sym_escape_sequence,
    STATE(7553), 1,
      aux_sym_string_literal_repeat1,
  [293653] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    STATE(3152), 1,
      sym_field_declaration_list,
    STATE(8509), 1,
      sym_base_class_clause,
  [293669] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12596), 1,
      anon_sym_GT2,
    STATE(7961), 1,
      aux_sym_template_argument_list_repeat1,
  [293685] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12598), 1,
      anon_sym___except,
    ACTIONS(12600), 1,
      anon_sym___finally,
    STATE(903), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [293699] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12602), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [293713] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12604), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [293729] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12606), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [293745] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12608), 1,
      anon_sym_EQ,
    STATE(315), 1,
      sym_declaration_list,
  [293761] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10278), 1,
      anon_sym_LBRACE,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    STATE(4061), 1,
      sym_requirement_seq,
    STATE(8549), 1,
      sym_requires_parameter_list,
  [293777] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11177), 1,
      anon_sym_LBRACE,
    STATE(4115), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293791] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    STATE(2454), 1,
      sym_field_declaration_list,
    STATE(8357), 1,
      sym_base_class_clause,
  [293807] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11190), 1,
      anon_sym_LBRACE,
    STATE(6213), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293821] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12610), 1,
      anon_sym_SEMI,
    STATE(1659), 1,
      sym_template_argument_list,
  [293837] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12612), 1,
      anon_sym_GT2,
    STATE(7922), 1,
      aux_sym_template_argument_list_repeat1,
  [293853] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12614), 1,
      anon_sym_SEMI,
    STATE(1659), 1,
      sym_template_argument_list,
  [293869] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12616), 1,
      anon_sym_DQUOTE,
    ACTIONS(12618), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12620), 1,
      sym_escape_sequence,
    STATE(7567), 1,
      aux_sym_string_literal_repeat1,
  [293885] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12622), 1,
      anon_sym_DQUOTE,
    ACTIONS(12624), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12626), 1,
      sym_escape_sequence,
    STATE(7574), 1,
      aux_sym_string_literal_repeat1,
  [293901] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    STATE(7801), 1,
      sym_compound_statement,
    STATE(8342), 1,
      sym_field_initializer_list,
  [293917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11192), 1,
      anon_sym_LBRACE,
    STATE(3709), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [293931] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4617), 1,
      anon_sym_LT,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(808), 1,
      sym_template_parameter_list,
    STATE(2150), 1,
      sym_template_type,
  [293947] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12628), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [293963] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    STATE(3178), 1,
      sym_field_declaration_list,
    STATE(8525), 1,
      sym_base_class_clause,
  [293979] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12630), 1,
      anon_sym_GT2,
    STATE(8115), 1,
      aux_sym_template_argument_list_repeat1,
  [293995] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(12632), 1,
      aux_sym_preproc_if_token2,
    STATE(7279), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
  [294011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(12634), 1,
      aux_sym_preproc_if_token2,
    STATE(7280), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
  [294025] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12636), 1,
      anon_sym_DQUOTE,
    ACTIONS(12638), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12640), 1,
      sym_escape_sequence,
    STATE(7575), 1,
      aux_sym_string_literal_repeat1,
  [294041] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    STATE(2430), 1,
      sym_field_declaration_list,
    STATE(8399), 1,
      sym_base_class_clause,
  [294057] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12642), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [294073] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12644), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [294089] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12646), 1,
      anon_sym_DQUOTE,
    ACTIONS(12648), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12650), 1,
      sym_escape_sequence,
    STATE(7581), 1,
      aux_sym_string_literal_repeat1,
  [294105] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11208), 1,
      anon_sym_LBRACE,
    STATE(2806), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294119] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12652), 1,
      anon_sym_DQUOTE,
    ACTIONS(12654), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12656), 1,
      sym_escape_sequence,
    STATE(7653), 1,
      aux_sym_string_literal_repeat1,
  [294135] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11190), 1,
      anon_sym_LBRACE,
    STATE(6066), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294149] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11607), 1,
      sym_identifier,
    ACTIONS(12393), 1,
      aux_sym_preproc_if_token2,
    STATE(7570), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8610), 1,
      sym_enumerator,
  [294165] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12658), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [294181] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12660), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12662), 1,
      anon_sym_LPAREN,
    ACTIONS(12664), 1,
      sym_preproc_arg,
    STATE(8415), 1,
      sym_preproc_params,
  [294197] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11190), 1,
      anon_sym_LBRACE,
    STATE(6069), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294211] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11171), 1,
      anon_sym_LBRACE,
    STATE(4321), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294225] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11167), 1,
      anon_sym_LBRACE,
    STATE(3931), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294239] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12666), 1,
      anon_sym_DQUOTE,
    ACTIONS(12668), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12670), 1,
      sym_escape_sequence,
    STATE(7602), 1,
      aux_sym_string_literal_repeat1,
  [294255] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10302), 1,
      anon_sym_LBRACE,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    STATE(4872), 1,
      sym_requirement_seq,
    STATE(8248), 1,
      sym_requires_parameter_list,
  [294271] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12672), 1,
      anon_sym_GT2,
    STATE(7993), 1,
      aux_sym_template_argument_list_repeat1,
  [294287] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    STATE(4029), 1,
      sym_argument_list,
    STATE(4198), 1,
      sym_initializer_list,
  [294303] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12674), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12676), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [294317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9100), 1,
      anon_sym___attribute,
    ACTIONS(9098), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [294329] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12679), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [294343] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11425), 1,
      sym_identifier,
    ACTIONS(12681), 1,
      aux_sym_preproc_if_token2,
    STATE(7571), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
  [294357] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12683), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12687), 1,
      anon_sym_LBRACE,
    STATE(8081), 1,
      aux_sym_base_class_clause_repeat1,
  [294373] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    STATE(4767), 1,
      sym_field_declaration_list,
    STATE(8347), 1,
      sym_base_class_clause,
  [294389] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12689), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [294403] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12691), 1,
      anon_sym_SEMI,
    STATE(1659), 1,
      sym_template_argument_list,
  [294419] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12662), 1,
      anon_sym_LPAREN,
    ACTIONS(12693), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12695), 1,
      sym_preproc_arg,
    STATE(8272), 1,
      sym_preproc_params,
  [294435] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12697), 1,
      anon_sym_SEMI,
    STATE(1659), 1,
      sym_template_argument_list,
  [294451] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    STATE(7772), 1,
      sym_compound_statement,
    STATE(8385), 1,
      sym_field_initializer_list,
  [294467] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4617), 1,
      anon_sym_LT,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(810), 1,
      sym_template_parameter_list,
    STATE(2150), 1,
      sym_template_type,
  [294483] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12699), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [294499] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12701), 1,
      anon_sym_DQUOTE,
    ACTIONS(12703), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12705), 1,
      sym_escape_sequence,
    STATE(7615), 1,
      aux_sym_string_literal_repeat1,
  [294515] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11171), 1,
      anon_sym_LBRACE,
    STATE(4326), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294529] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2581), 1,
      sym_field_declaration_list,
    STATE(8468), 1,
      sym_base_class_clause,
  [294545] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    STATE(4738), 1,
      sym_field_declaration_list,
    STATE(8467), 1,
      sym_base_class_clause,
  [294561] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12707), 1,
      anon_sym_GT2,
    STATE(7912), 1,
      aux_sym_template_argument_list_repeat1,
  [294577] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2645), 1,
      anon_sym_LBRACE,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    STATE(2743), 1,
      sym_initializer_list,
    STATE(2776), 1,
      sym_argument_list,
  [294593] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12709), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [294607] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12711), 1,
      anon_sym_DQUOTE,
    ACTIONS(12713), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12716), 1,
      sym_escape_sequence,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [294623] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    STATE(4914), 1,
      sym_field_declaration_list,
    STATE(8271), 1,
      sym_base_class_clause,
  [294639] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    STATE(7883), 1,
      sym_compound_statement,
    STATE(8409), 1,
      sym_field_initializer_list,
  [294655] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12719), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [294669] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4617), 1,
      anon_sym_LT,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(809), 1,
      sym_template_parameter_list,
    STATE(2150), 1,
      sym_template_type,
  [294685] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12721), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [294701] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12723), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [294711] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11220), 1,
      anon_sym_LBRACE,
    STATE(5427), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294725] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11222), 1,
      anon_sym_LBRACE,
    STATE(4184), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294739] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    STATE(7878), 1,
      sym_compound_statement,
    STATE(8228), 1,
      sym_field_initializer_list,
  [294755] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    STATE(8129), 1,
      sym_compound_statement,
    STATE(8423), 1,
      sym_field_initializer_list,
  [294771] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8084), 2,
      sym_argument_list,
      sym_initializer_list,
  [294785] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4617), 1,
      anon_sym_LT,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(812), 1,
      sym_template_parameter_list,
    STATE(2150), 1,
      sym_template_type,
  [294801] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    STATE(4917), 1,
      sym_field_declaration_list,
    STATE(8284), 1,
      sym_base_class_clause,
  [294817] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12725), 1,
      anon_sym_GT2,
    STATE(7784), 1,
      aux_sym_template_argument_list_repeat1,
  [294833] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11167), 1,
      anon_sym_LBRACE,
    STATE(3933), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294847] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12727), 1,
      anon_sym_SEMI,
    STATE(1659), 1,
      sym_template_argument_list,
  [294863] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12729), 1,
      anon_sym___except,
    ACTIONS(12731), 1,
      anon_sym___finally,
    STATE(460), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [294877] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12733), 1,
      anon_sym_DQUOTE,
    ACTIONS(12735), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12737), 1,
      sym_escape_sequence,
    STATE(7718), 1,
      aux_sym_string_literal_repeat1,
  [294893] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12739), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [294909] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11222), 1,
      anon_sym_LBRACE,
    STATE(4206), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294923] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12741), 1,
      anon_sym_SEMI,
    STATE(1659), 1,
      sym_template_argument_list,
  [294939] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11192), 1,
      anon_sym_LBRACE,
    STATE(3721), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294953] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    STATE(7814), 1,
      sym_compound_statement,
    STATE(8441), 1,
      sym_field_initializer_list,
  [294969] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4514), 1,
      anon_sym_SEMI,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1905), 1,
      sym_template_argument_list,
  [294985] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11222), 1,
      anon_sym_LBRACE,
    STATE(4232), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [294999] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    STATE(2445), 1,
      sym_field_declaration_list,
    STATE(8518), 1,
      sym_base_class_clause,
  [295015] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12743), 1,
      anon_sym_GT2,
    STATE(8172), 1,
      aux_sym_template_argument_list_repeat1,
  [295031] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8492), 1,
      sym_argument_list,
    ACTIONS(12745), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [295045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11208), 1,
      anon_sym_LBRACE,
    STATE(2788), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12747), 1,
      sym_identifier,
    ACTIONS(12749), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [295071] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11177), 1,
      anon_sym_LBRACE,
    STATE(4169), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295085] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12751), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12753), 1,
      anon_sym_LBRACE,
    STATE(8010), 1,
      aux_sym_base_class_clause_repeat1,
  [295101] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2511), 1,
      sym_field_declaration_list,
    STATE(8281), 1,
      sym_base_class_clause,
  [295117] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12755), 1,
      anon_sym___except,
    ACTIONS(12757), 1,
      anon_sym___finally,
    STATE(460), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [295131] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12759), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12761), 1,
      anon_sym_LBRACE,
    STATE(8176), 1,
      aux_sym_base_class_clause_repeat1,
  [295147] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4617), 1,
      anon_sym_LT,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(807), 1,
      sym_template_parameter_list,
    STATE(2150), 1,
      sym_template_type,
  [295163] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12763), 1,
      anon_sym_DQUOTE,
    ACTIONS(12765), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12767), 1,
      sym_escape_sequence,
    STATE(7656), 1,
      aux_sym_string_literal_repeat1,
  [295179] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12769), 1,
      anon_sym_DQUOTE,
    ACTIONS(12771), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12773), 1,
      sym_escape_sequence,
    STATE(7686), 1,
      aux_sym_string_literal_repeat1,
  [295195] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12775), 1,
      anon_sym_DQUOTE,
    ACTIONS(12777), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12779), 1,
      sym_escape_sequence,
    STATE(7677), 1,
      aux_sym_string_literal_repeat1,
  [295211] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12781), 1,
      anon_sym_DQUOTE,
    ACTIONS(12783), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12785), 1,
      sym_escape_sequence,
    STATE(7536), 1,
      aux_sym_string_literal_repeat1,
  [295227] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    STATE(2296), 1,
      sym_field_declaration_list,
    STATE(8303), 1,
      sym_base_class_clause,
  [295243] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4617), 1,
      anon_sym_LT,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(813), 1,
      sym_template_parameter_list,
    STATE(2150), 1,
      sym_template_type,
  [295259] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12787), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [295275] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    STATE(3169), 1,
      sym_field_declaration_list,
    STATE(8335), 1,
      sym_base_class_clause,
  [295291] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12789), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [295305] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12791), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [295321] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12793), 1,
      anon_sym_SEMI,
    ACTIONS(12795), 1,
      anon_sym_DASH_GT,
    ACTIONS(12797), 1,
      anon_sym_noexcept,
    STATE(9101), 1,
      sym_trailing_return_type,
  [295337] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10262), 1,
      anon_sym_LBRACE,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    STATE(4118), 1,
      sym_requirement_seq,
    STATE(8250), 1,
      sym_requires_parameter_list,
  [295353] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12662), 1,
      anon_sym_LPAREN,
    ACTIONS(12799), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12801), 1,
      sym_preproc_arg,
    STATE(8493), 1,
      sym_preproc_params,
  [295369] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(1695), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295383] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11175), 1,
      anon_sym_LBRACE,
    STATE(4868), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295397] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12803), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [295411] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12805), 1,
      anon_sym_GT2,
    STATE(8049), 1,
      aux_sym_template_argument_list_repeat1,
  [295427] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12807), 1,
      anon_sym_EQ,
    STATE(7726), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [295441] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    STATE(2776), 1,
      sym_argument_list,
    STATE(4315), 1,
      sym_initializer_list,
  [295457] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12723), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [295467] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    STATE(4050), 1,
      sym_initializer_list,
    STATE(4174), 1,
      sym_argument_list,
  [295483] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    STATE(3188), 1,
      sym_field_declaration_list,
    STATE(8344), 1,
      sym_base_class_clause,
  [295499] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12809), 1,
      anon_sym_COMMA,
    STATE(7750), 1,
      aux_sym_gnu_asm_output_operand_list_repeat1,
    ACTIONS(12811), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [295513] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12813), 1,
      anon_sym_COMMA,
    STATE(7753), 1,
      aux_sym_gnu_asm_input_operand_list_repeat1,
    ACTIONS(12815), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [295527] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4617), 1,
      anon_sym_LT,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(7439), 1,
      sym_template_parameter_list,
  [295543] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12817), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [295557] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12819), 1,
      anon_sym_GT2,
    STATE(7856), 1,
      aux_sym_template_argument_list_repeat1,
  [295573] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    STATE(3331), 1,
      sym_field_declaration_list,
    STATE(8506), 1,
      sym_base_class_clause,
  [295589] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12821), 1,
      anon_sym___except,
    ACTIONS(12823), 1,
      anon_sym___finally,
    STATE(188), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [295603] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12825), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [295617] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12827), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [295633] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12829), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [295647] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12831), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [295663] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(1696), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295677] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10270), 1,
      anon_sym_LBRACE,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    STATE(4403), 1,
      sym_requirement_seq,
    STATE(8274), 1,
      sym_requires_parameter_list,
  [295693] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(1699), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295707] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10254), 1,
      anon_sym_LBRACE,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    STATE(5424), 1,
      sym_requirement_seq,
    STATE(8483), 1,
      sym_requires_parameter_list,
  [295723] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11220), 1,
      anon_sym_LBRACE,
    STATE(5525), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295737] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11210), 1,
      anon_sym_LBRACE,
    STATE(1695), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295751] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12833), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [295767] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12086), 1,
      anon_sym_EQ,
    STATE(7609), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [295781] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    STATE(5497), 1,
      sym_field_declaration_list,
    STATE(8499), 1,
      sym_base_class_clause,
  [295797] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11208), 1,
      anon_sym_LBRACE,
    STATE(2791), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295811] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    STATE(5501), 1,
      sym_field_declaration_list,
    STATE(8503), 1,
      sym_base_class_clause,
  [295827] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    STATE(3063), 1,
      sym_field_declaration_list,
    STATE(8298), 1,
      sym_base_class_clause,
  [295843] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    STATE(3332), 1,
      sym_field_declaration_list,
    STATE(8545), 1,
      sym_base_class_clause,
  [295859] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12835), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [295873] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12837), 1,
      anon_sym_GT2,
    STATE(8193), 1,
      aux_sym_template_argument_list_repeat1,
  [295889] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4023), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(12839), 1,
      anon_sym_SEMI,
    STATE(1659), 1,
      sym_template_argument_list,
  [295905] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1653), 1,
      sym_template_argument_list,
    ACTIONS(6898), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [295919] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11177), 1,
      anon_sym_LBRACE,
    STATE(4183), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [295933] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12841), 1,
      anon_sym_GT2,
    STATE(8020), 1,
      aux_sym_template_argument_list_repeat1,
  [295949] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12843), 1,
      anon_sym_DQUOTE,
    ACTIONS(12845), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12847), 1,
      sym_escape_sequence,
    STATE(7708), 1,
      aux_sym_string_literal_repeat1,
  [295965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12851), 1,
      anon_sym___attribute,
    ACTIONS(12849), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [295977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12855), 1,
      anon_sym___attribute,
    ACTIONS(12853), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [295989] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    STATE(4467), 1,
      sym_field_declaration_list,
    STATE(8379), 1,
      sym_base_class_clause,
  [296005] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12857), 1,
      anon_sym_EQ,
    STATE(526), 1,
      sym_declaration_list,
  [296021] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12859), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296035] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    STATE(3128), 1,
      sym_field_declaration_list,
    STATE(8471), 1,
      sym_base_class_clause,
  [296051] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12078), 1,
      anon_sym_EQ,
    STATE(7662), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296065] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12861), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [296079] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12863), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [296095] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11198), 1,
      anon_sym_LBRACE,
    STATE(6508), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [296109] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    STATE(4438), 1,
      sym_field_declaration_list,
    STATE(8388), 1,
      sym_base_class_clause,
  [296125] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12865), 1,
      anon_sym_GT2,
    STATE(7907), 1,
      aux_sym_template_argument_list_repeat1,
  [296141] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12867), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296155] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_EQ,
    STATE(7704), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296169] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11175), 1,
      anon_sym_LBRACE,
    STATE(4880), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [296183] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11198), 1,
      anon_sym_LBRACE,
    STATE(6460), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [296197] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11198), 1,
      anon_sym_LBRACE,
    STATE(6472), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [296211] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11220), 1,
      anon_sym_LBRACE,
    STATE(5521), 1,
      sym_compound_statement,
    ACTIONS(11039), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [296225] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12869), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [296241] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12871), 1,
      anon_sym_DQUOTE,
    ACTIONS(12873), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12875), 1,
      sym_escape_sequence,
    STATE(7523), 1,
      aux_sym_string_literal_repeat1,
  [296257] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12877), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296271] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12043), 1,
      anon_sym_EQ,
    STATE(7712), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296285] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12879), 1,
      anon_sym_DQUOTE,
    ACTIONS(12881), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12883), 1,
      sym_escape_sequence,
    STATE(7724), 1,
      aux_sym_string_literal_repeat1,
  [296301] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12885), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [296315] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12887), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [296331] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    ACTIONS(11619), 1,
      anon_sym_LBRACK,
    STATE(2996), 1,
      sym_parameter_list,
    STATE(6602), 1,
      sym__function_declarator_seq,
  [296347] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12889), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296361] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12082), 1,
      anon_sym_EQ,
    STATE(7732), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296375] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12891), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12893), 1,
      anon_sym_LBRACE,
    STATE(7803), 1,
      aux_sym_base_class_clause_repeat1,
  [296391] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12895), 1,
      anon_sym_EQ,
    STATE(712), 1,
      sym_declaration_list,
  [296407] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12662), 1,
      anon_sym_LPAREN,
    ACTIONS(12897), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12899), 1,
      sym_preproc_arg,
    STATE(8288), 1,
      sym_preproc_params,
  [296423] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12901), 1,
      anon_sym_GT2,
    STATE(7934), 1,
      aux_sym_template_argument_list_repeat1,
  [296439] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12903), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296453] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12114), 1,
      anon_sym_EQ,
    STATE(7738), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296467] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10246), 1,
      anon_sym_LBRACE,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    STATE(3834), 1,
      sym_requirement_seq,
    STATE(8244), 1,
      sym_requires_parameter_list,
  [296483] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12809), 1,
      anon_sym_COMMA,
    STATE(7669), 1,
      aux_sym_gnu_asm_output_operand_list_repeat1,
    ACTIONS(12905), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [296497] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12907), 1,
      anon_sym_DQUOTE,
    ACTIONS(12909), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12911), 1,
      sym_escape_sequence,
    STATE(7740), 1,
      aux_sym_string_literal_repeat1,
  [296513] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12913), 1,
      anon_sym_SQUOTE,
    STATE(7590), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [296527] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12915), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296541] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12035), 1,
      anon_sym_EQ,
    STATE(7742), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296555] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12917), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [296571] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12662), 1,
      anon_sym_LPAREN,
    ACTIONS(12919), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12921), 1,
      sym_preproc_arg,
    STATE(8296), 1,
      sym_preproc_params,
  [296587] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(12923), 1,
      anon_sym_EQ,
    STATE(6471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [296601] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2910), 1,
      sym_field_declaration_list,
    STATE(8541), 1,
      sym_base_class_clause,
  [296617] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6046), 1,
      anon_sym_COLON,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2914), 1,
      sym_field_declaration_list,
    STATE(8542), 1,
      sym_base_class_clause,
  [296633] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12925), 1,
      anon_sym_DQUOTE,
    ACTIONS(12927), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12929), 1,
      sym_escape_sequence,
    STATE(7629), 1,
      aux_sym_string_literal_repeat1,
  [296649] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10286), 1,
      anon_sym_LBRACE,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    STATE(2752), 1,
      sym_requirement_seq,
    STATE(8480), 1,
      sym_requires_parameter_list,
  [296665] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12931), 1,
      anon_sym_DQUOTE,
    ACTIONS(12933), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12935), 1,
      sym_escape_sequence,
    STATE(7526), 1,
      aux_sym_string_literal_repeat1,
  [296681] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12937), 1,
      anon_sym_GT2,
    STATE(7972), 1,
      aux_sym_template_argument_list_repeat1,
  [296697] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12939), 1,
      anon_sym_DQUOTE,
    ACTIONS(12941), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12943), 1,
      sym_escape_sequence,
    STATE(7752), 1,
      aux_sym_string_literal_repeat1,
  [296713] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12945), 1,
      anon_sym_COMMA,
    STATE(7750), 1,
      aux_sym_gnu_asm_output_operand_list_repeat1,
    ACTIONS(12948), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [296727] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12662), 1,
      anon_sym_LPAREN,
    ACTIONS(12950), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12952), 1,
      sym_preproc_arg,
    STATE(8330), 1,
      sym_preproc_params,
  [296743] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12531), 1,
      aux_sym_string_literal_token1,
    ACTIONS(12533), 1,
      sym_escape_sequence,
    ACTIONS(12954), 1,
      anon_sym_DQUOTE,
    STATE(7610), 1,
      aux_sym_string_literal_repeat1,
  [296759] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12813), 1,
      anon_sym_COMMA,
    STATE(7758), 1,
      aux_sym_gnu_asm_input_operand_list_repeat1,
    ACTIONS(12956), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [296773] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12958), 1,
      anon_sym_COMMA,
    STATE(7757), 1,
      aux_sym_gnu_asm_clobber_list_repeat1,
    ACTIONS(12960), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [296787] = 5,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(12662), 1,
      anon_sym_LPAREN,
    ACTIONS(12962), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12964), 1,
      sym_preproc_arg,
    STATE(8239), 1,
      sym_preproc_params,
  [296803] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    STATE(3942), 1,
      sym_argument_list,
    STATE(3946), 1,
      sym_initializer_list,
  [296819] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12958), 1,
      anon_sym_COMMA,
    STATE(7544), 1,
      aux_sym_gnu_asm_clobber_list_repeat1,
    ACTIONS(12966), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [296833] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12968), 1,
      anon_sym_COMMA,
    STATE(7758), 1,
      aux_sym_gnu_asm_input_operand_list_repeat1,
    ACTIONS(12971), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [296847] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10294), 1,
      anon_sym_LBRACE,
    ACTIONS(12515), 1,
      anon_sym_LPAREN2,
    STATE(3731), 1,
      sym_requirement_seq,
    STATE(8256), 1,
      sym_requires_parameter_list,
  [296863] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12973), 1,
      anon_sym_GT2,
    STATE(8208), 1,
      aux_sym_template_argument_list_repeat1,
  [296879] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    ACTIONS(11500), 1,
      anon_sym_COLON,
    STATE(7795), 1,
      sym_compound_statement,
    STATE(8324), 1,
      sym_field_initializer_list,
  [296895] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7035), 1,
      anon_sym___attribute,
    ACTIONS(7037), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [296906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12975), 1,
      anon_sym_catch,
    STATE(275), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [296917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12977), 1,
      anon_sym_COMMA,
    ACTIONS(12979), 1,
      anon_sym_LBRACE,
    STATE(8083), 1,
      aux_sym_field_initializer_list_repeat1,
  [296930] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(12983), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8082), 1,
      aux_sym_attribute_declaration_repeat1,
  [296943] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(12987), 1,
      anon_sym_RPAREN,
    STATE(8056), 1,
      aux_sym_parameter_list_repeat1,
  [296956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12989), 1,
      anon_sym_catch,
    STATE(1880), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [296967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12991), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3734), 1,
      sym_template_function,
  [296980] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(12993), 1,
      anon_sym_GT2,
    STATE(7917), 1,
      aux_sym_template_argument_list_repeat1,
  [296993] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10561), 1,
      anon_sym_COMMA,
    ACTIONS(12995), 1,
      anon_sym_RPAREN,
    STATE(7825), 1,
      aux_sym_preproc_argument_list_repeat1,
  [297006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12997), 1,
      anon_sym_RPAREN,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    STATE(8157), 1,
      sym_gnu_asm_output_operand_list,
  [297019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13001), 1,
      anon_sym_catch,
    STATE(1876), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [297030] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13003), 1,
      anon_sym_COMMA,
    ACTIONS(13005), 1,
      anon_sym_RPAREN,
    STATE(7788), 1,
      aux_sym_requires_parameter_list_repeat1,
  [297043] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13007), 1,
      anon_sym_COMMA,
    ACTIONS(13009), 1,
      anon_sym_RPAREN,
    STATE(8094), 1,
      aux_sym_throw_specifier_repeat1,
  [297056] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13011), 1,
      anon_sym_GT2,
    STATE(7785), 1,
      aux_sym_template_argument_list_repeat1,
  [297069] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13013), 1,
      anon_sym_SEMI,
    STATE(7867), 1,
      aux_sym_declaration_repeat1,
  [297082] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13015), 1,
      anon_sym_COMMA,
    ACTIONS(13018), 1,
      anon_sym_RPAREN,
    STATE(7777), 1,
      aux_sym_gnu_asm_goto_list_repeat1,
  [297095] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13020), 1,
      anon_sym_SEMI,
    STATE(7826), 1,
      aux_sym_declaration_repeat1,
  [297108] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13022), 1,
      anon_sym_COMMA,
    ACTIONS(13024), 1,
      anon_sym_RPAREN,
    STATE(7965), 1,
      aux_sym_gnu_asm_goto_list_repeat1,
  [297121] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13026), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(6582), 1,
      sym_template_function,
  [297134] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13028), 1,
      anon_sym_COMMA,
    ACTIONS(13031), 1,
      anon_sym_LBRACE,
    STATE(7781), 1,
      aux_sym_field_initializer_list_repeat1,
  [297147] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13033), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13035), 1,
      anon_sym_LPAREN2,
    STATE(8900), 1,
      sym_preproc_argument_list,
  [297160] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13037), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [297173] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13039), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [297186] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13041), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [297199] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13043), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7840), 1,
      aux_sym_attribute_declaration_repeat1,
  [297212] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9502), 1,
      anon_sym_RBRACK,
    ACTIONS(13045), 1,
      anon_sym_COMMA,
    STATE(7787), 1,
      aux_sym_subscript_argument_list_repeat1,
  [297225] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13003), 1,
      anon_sym_COMMA,
    ACTIONS(13048), 1,
      anon_sym_RPAREN,
    STATE(8194), 1,
      aux_sym_requires_parameter_list_repeat1,
  [297238] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13050), 1,
      anon_sym_GT2,
    STATE(8162), 1,
      aux_sym_template_argument_list_repeat1,
  [297251] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13052), 1,
      anon_sym_SEMI,
    STATE(8077), 1,
      aux_sym_declaration_repeat1,
  [297264] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13054), 3,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_DOT,
  [297273] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13056), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [297286] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13058), 1,
      sym_identifier,
    STATE(1966), 1,
      sym_template_type,
    STATE(3734), 1,
      sym_template_function,
  [297299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13060), 1,
      sym_identifier,
    ACTIONS(13062), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [297310] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13064), 1,
      anon_sym_catch,
    STATE(350), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [297321] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9326), 1,
      anon_sym_RPAREN,
    STATE(7847), 1,
      aux_sym_argument_list_repeat1,
  [297334] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13001), 1,
      anon_sym_catch,
    STATE(1883), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [297345] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13066), 1,
      anon_sym_SEMI,
    STATE(7925), 1,
      aux_sym_declaration_repeat1,
  [297358] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9534), 1,
      aux_sym_kernel_call_syntax_token2,
    ACTIONS(13068), 1,
      anon_sym_COMMA,
    STATE(7799), 1,
      aux_sym_kernel_call_syntax_repeat1,
  [297371] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12753), 1,
      anon_sym_LBRACE,
    STATE(8010), 1,
      aux_sym_base_class_clause_repeat1,
  [297384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13071), 1,
      anon_sym_catch,
    STATE(147), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [297395] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9337), 1,
      anon_sym_COMMA,
    ACTIONS(9339), 1,
      anon_sym_RBRACE,
    STATE(7850), 1,
      aux_sym_initializer_list_repeat1,
  [297408] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12753), 1,
      anon_sym_LBRACE,
    STATE(7829), 1,
      aux_sym_base_class_clause_repeat1,
  [297421] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13073), 1,
      anon_sym_SEMI,
    STATE(7872), 1,
      aux_sym_declaration_repeat1,
  [297434] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(9209), 1,
      anon_sym_RBRACK,
    STATE(8060), 1,
      aux_sym_subscript_argument_list_repeat1,
  [297447] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13075), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [297460] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13077), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [297473] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13079), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(13081), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [297484] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13083), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [297497] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13085), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [297510] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9345), 1,
      anon_sym_RPAREN,
    STATE(7930), 1,
      aux_sym_argument_list_repeat1,
  [297523] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13087), 1,
      anon_sym_RPAREN,
    STATE(7852), 1,
      sym_gnu_asm_output_operand_list,
  [297536] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    STATE(550), 1,
      sym_declaration_list,
  [297549] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12989), 1,
      anon_sym_catch,
    STATE(1874), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [297560] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13089), 1,
      anon_sym_COMMA,
    ACTIONS(13091), 1,
      anon_sym_RPAREN,
    STATE(8000), 1,
      aux_sym_preproc_params_repeat1,
  [297573] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13093), 1,
      anon_sym_COMMA,
    ACTIONS(13096), 1,
      anon_sym_RBRACK,
    STATE(7816), 1,
      aux_sym_structured_binding_declarator_repeat1,
  [297586] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9347), 1,
      anon_sym_COMMA,
    ACTIONS(9349), 1,
      anon_sym_RBRACE,
    STATE(7938), 1,
      aux_sym_initializer_list_repeat1,
  [297599] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12893), 1,
      anon_sym_LBRACE,
    STATE(7803), 1,
      aux_sym_base_class_clause_repeat1,
  [297612] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13098), 1,
      anon_sym_GT2,
    STATE(7873), 1,
      aux_sym_template_argument_list_repeat1,
  [297625] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13100), 1,
      anon_sym_SEMI,
    STATE(7877), 1,
      aux_sym_declaration_repeat1,
  [297638] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13102), 1,
      anon_sym_RPAREN,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    STATE(7902), 1,
      sym_gnu_asm_clobber_list,
  [297651] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13106), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [297664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13108), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [297673] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13110), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [297686] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10923), 1,
      anon_sym_RPAREN,
    ACTIONS(13112), 1,
      anon_sym_COMMA,
    STATE(7825), 1,
      aux_sym_preproc_argument_list_repeat1,
  [297699] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13115), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [297712] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13117), 1,
      anon_sym_RPAREN,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    STATE(9240), 1,
      sym_gnu_asm_goto_list,
  [297725] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13121), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [297738] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13081), 1,
      anon_sym_LBRACE,
    ACTIONS(13123), 1,
      anon_sym_COMMA,
    STATE(7829), 1,
      aux_sym_base_class_clause_repeat1,
  [297751] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13126), 1,
      anon_sym_RPAREN,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    STATE(7903), 1,
      sym_gnu_asm_input_operand_list,
  [297764] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(13130), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [297777] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13132), 1,
      anon_sym_catch,
    STATE(1730), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [297788] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13134), 1,
      anon_sym_RPAREN,
    STATE(8147), 1,
      sym_gnu_asm_clobber_list,
  [297801] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4537), 1,
      anon_sym_RBRACE,
    ACTIONS(13136), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [297814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13132), 1,
      anon_sym_catch,
    STATE(1731), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [297825] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2018), 1,
      anon_sym_while,
    ACTIONS(13138), 1,
      anon_sym_else,
    STATE(345), 1,
      sym_else_clause,
  [297838] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13140), 1,
      anon_sym_COMMA,
    ACTIONS(13143), 1,
      anon_sym_RPAREN,
    STATE(7837), 1,
      aux_sym_preproc_params_repeat1,
  [297851] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13145), 1,
      sym_identifier,
    STATE(1966), 1,
      sym_template_type,
    STATE(3928), 1,
      sym_template_function,
  [297864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6975), 1,
      anon_sym___attribute,
    ACTIONS(6977), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [297875] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13147), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [297888] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13149), 1,
      anon_sym_RPAREN,
    STATE(7958), 1,
      sym_gnu_asm_output_operand_list,
  [297901] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13071), 1,
      anon_sym_catch,
    STATE(140), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [297912] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13151), 1,
      anon_sym_GT2,
    STATE(7962), 1,
      aux_sym_template_argument_list_repeat1,
  [297925] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9318), 1,
      anon_sym_RPAREN,
    STATE(7909), 1,
      aux_sym_argument_list_repeat1,
  [297938] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13153), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [297951] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13155), 1,
      anon_sym_COMMA,
    ACTIONS(13157), 1,
      anon_sym_GT2,
    STATE(7969), 1,
      aux_sym_template_parameter_list_repeat1,
  [297964] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13159), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [297977] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13161), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [297990] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9279), 1,
      anon_sym_COMMA,
    ACTIONS(9281), 1,
      anon_sym_RBRACE,
    STATE(7911), 1,
      aux_sym_initializer_list_repeat1,
  [298003] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4577), 1,
      anon_sym_RBRACE,
    ACTIONS(13163), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [298016] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13165), 1,
      anon_sym_GT2,
    STATE(7858), 1,
      aux_sym_template_argument_list_repeat1,
  [298029] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13167), 1,
      anon_sym_RPAREN,
    STATE(7882), 1,
      sym_gnu_asm_input_operand_list,
  [298042] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13171), 1,
      anon_sym_RPAREN,
    ACTIONS(13169), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [298053] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13173), 1,
      anon_sym_RPAREN,
    STATE(7884), 1,
      sym_gnu_asm_output_operand_list,
  [298066] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13175), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298079] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13177), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298092] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    ACTIONS(13181), 1,
      anon_sym_constexpr,
    STATE(678), 1,
      sym_condition_clause,
  [298105] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13183), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298118] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7592), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13185), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [298129] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13187), 1,
      anon_sym_RPAREN,
    STATE(7913), 1,
      sym_gnu_asm_output_operand_list,
  [298142] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13189), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298155] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13191), 1,
      anon_sym_GT2,
    STATE(7923), 1,
      aux_sym_template_argument_list_repeat1,
  [298168] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13193), 1,
      anon_sym_RPAREN,
    STATE(8087), 1,
      sym_gnu_asm_output_operand_list,
  [298181] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13195), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [298194] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13197), 1,
      anon_sym_SEMI,
    STATE(7975), 1,
      aux_sym_declaration_repeat1,
  [298207] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13199), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [298220] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13201), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [298233] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13203), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298246] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13205), 1,
      anon_sym_RPAREN,
    STATE(7977), 1,
      aux_sym_parameter_list_repeat1,
  [298259] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13207), 1,
      anon_sym_SEMI,
    STATE(7929), 1,
      aux_sym_declaration_repeat1,
  [298272] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13209), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [298285] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13211), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [298298] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13213), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298311] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13215), 1,
      anon_sym_default,
    ACTIONS(13217), 1,
      anon_sym_delete,
    ACTIONS(13219), 1,
      aux_sym_pure_virtual_clause_token1,
  [298324] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    STATE(252), 1,
      sym_declaration_list,
  [298337] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13221), 1,
      anon_sym_RPAREN,
    STATE(7935), 1,
      aux_sym_parameter_list_repeat1,
  [298350] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13223), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [298363] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12975), 1,
      anon_sym_catch,
    STATE(329), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [298374] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13225), 1,
      anon_sym_COMMA,
    ACTIONS(13228), 1,
      anon_sym_RPAREN,
    STATE(7879), 1,
      aux_sym_throw_specifier_repeat1,
  [298387] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4575), 1,
      anon_sym_RBRACE,
    ACTIONS(13230), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [298400] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13232), 1,
      anon_sym_RPAREN,
    STATE(8012), 1,
      sym_gnu_asm_input_operand_list,
  [298413] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_RPAREN,
    STATE(7885), 1,
      sym_gnu_asm_clobber_list,
  [298426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13236), 1,
      anon_sym_catch,
    STATE(323), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [298437] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13238), 1,
      anon_sym_RPAREN,
    STATE(7890), 1,
      sym_gnu_asm_input_operand_list,
  [298450] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13240), 1,
      anon_sym_RPAREN,
    STATE(8858), 1,
      sym_gnu_asm_goto_list,
  [298463] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13242), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [298476] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(9186), 1,
      anon_sym_RBRACK,
    STATE(7984), 1,
      aux_sym_subscript_argument_list_repeat1,
  [298489] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    STATE(619), 1,
      sym_declaration_list,
  [298502] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13244), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [298511] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13246), 1,
      anon_sym_RPAREN,
    STATE(7893), 1,
      sym_gnu_asm_clobber_list,
  [298524] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13248), 1,
      anon_sym_RPAREN,
    STATE(8015), 1,
      sym_gnu_asm_output_operand_list,
  [298537] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13250), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [298550] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13252), 1,
      anon_sym_RPAREN,
    STATE(8868), 1,
      sym_gnu_asm_goto_list,
  [298563] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(13254), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [298576] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4541), 1,
      anon_sym_RBRACE,
    ACTIONS(13256), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [298589] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13258), 1,
      sym_identifier,
    STATE(1966), 1,
      sym_template_type,
    STATE(2837), 1,
      sym_template_function,
  [298602] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13260), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298615] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(9176), 1,
      anon_sym_RBRACK,
    STATE(8111), 1,
      aux_sym_subscript_argument_list_repeat1,
  [298628] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13262), 1,
      anon_sym_COMMA,
    ACTIONS(13264), 1,
      anon_sym_RBRACK,
    STATE(8001), 1,
      aux_sym_lambda_capture_specifier_repeat1,
  [298641] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13266), 1,
      anon_sym_GT2,
    STATE(7908), 1,
      aux_sym_template_argument_list_repeat1,
  [298654] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13268), 1,
      anon_sym_COMMA,
    ACTIONS(13271), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [298667] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13273), 1,
      anon_sym_RPAREN,
    STATE(8736), 1,
      sym_gnu_asm_goto_list,
  [298680] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13275), 1,
      anon_sym_RPAREN,
    STATE(7954), 1,
      sym_gnu_asm_clobber_list,
  [298693] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13277), 1,
      anon_sym_COMMA,
    ACTIONS(13280), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [298706] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4567), 1,
      anon_sym_RBRACE,
    ACTIONS(13282), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [298719] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13284), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298732] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13286), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298745] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13288), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298758] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13290), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [298771] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6486), 1,
      anon_sym_COMMA,
    ACTIONS(13292), 1,
      anon_sym_RBRACK,
    STATE(7816), 1,
      aux_sym_structured_binding_declarator_repeat1,
  [298784] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4543), 1,
      anon_sym_RBRACE,
    ACTIONS(13294), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [298797] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13296), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298810] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13298), 1,
      anon_sym_RPAREN,
    STATE(7951), 1,
      sym_gnu_asm_input_operand_list,
  [298823] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13300), 1,
      anon_sym_RPAREN,
    STATE(7952), 1,
      sym_gnu_asm_output_operand_list,
  [298836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13302), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [298845] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    ACTIONS(13304), 1,
      anon_sym_constexpr,
    STATE(649), 1,
      sym_condition_clause,
  [298858] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13306), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298871] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7693), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13308), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [298882] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13310), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298895] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13262), 1,
      anon_sym_COMMA,
    ACTIONS(13312), 1,
      anon_sym_RBRACK,
    STATE(8091), 1,
      aux_sym_lambda_capture_specifier_repeat1,
  [298908] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13314), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [298917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13316), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298930] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13318), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [298943] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10561), 1,
      anon_sym_COMMA,
    ACTIONS(13320), 1,
      anon_sym_RPAREN,
    STATE(7825), 1,
      aux_sym_preproc_argument_list_repeat1,
  [298956] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13322), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [298969] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13324), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [298982] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13326), 1,
      anon_sym_SEMI,
    STATE(8173), 1,
      aux_sym_declaration_repeat1,
  [298995] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13328), 1,
      anon_sym_GT2,
    STATE(7937), 1,
      aux_sym_template_argument_list_repeat1,
  [299008] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13330), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [299021] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13332), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [299034] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13334), 1,
      anon_sym_default,
    ACTIONS(13336), 1,
      anon_sym_delete,
    ACTIONS(13338), 1,
      aux_sym_pure_virtual_clause_token1,
  [299047] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13340), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299060] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    STATE(584), 1,
      sym_declaration_list,
  [299073] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13342), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299086] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13344), 1,
      anon_sym_RPAREN,
    STATE(8201), 1,
      aux_sym_parameter_list_repeat1,
  [299099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13236), 1,
      anon_sym_catch,
    STATE(324), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [299110] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13346), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299123] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4551), 1,
      anon_sym_RBRACE,
    ACTIONS(13348), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [299136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12989), 1,
      anon_sym_catch,
    STATE(1879), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [299147] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13350), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [299160] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7678), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13352), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [299171] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(9287), 1,
      anon_sym_RBRACK,
    STATE(8185), 1,
      aux_sym_subscript_argument_list_repeat1,
  [299184] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9364), 1,
      anon_sym_RPAREN,
    STATE(7886), 1,
      aux_sym_argument_list_repeat1,
  [299197] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13354), 1,
      anon_sym_RPAREN,
    STATE(8139), 1,
      sym_gnu_asm_input_operand_list,
  [299210] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13356), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(2837), 1,
      sym_template_function,
  [299223] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7043), 1,
      anon_sym___attribute,
    ACTIONS(7045), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [299234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7051), 1,
      anon_sym___attribute,
    ACTIONS(7053), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [299245] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2012), 1,
      anon_sym_while,
    ACTIONS(13138), 1,
      anon_sym_else,
    STATE(355), 1,
      sym_else_clause,
  [299258] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6486), 1,
      anon_sym_COMMA,
    ACTIONS(13358), 1,
      anon_sym_RBRACK,
    STATE(7910), 1,
      aux_sym_structured_binding_declarator_repeat1,
  [299271] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13360), 1,
      anon_sym_RPAREN,
    STATE(8069), 1,
      sym_gnu_asm_clobber_list,
  [299284] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13362), 1,
      anon_sym_RPAREN,
    STATE(7955), 1,
      sym_gnu_asm_clobber_list,
  [299297] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13364), 1,
      anon_sym_RPAREN,
    STATE(7957), 1,
      sym_gnu_asm_input_operand_list,
  [299310] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13366), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8030), 1,
      aux_sym_attribute_declaration_repeat1,
  [299323] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13368), 1,
      anon_sym_RPAREN,
    STATE(8786), 1,
      sym_gnu_asm_goto_list,
  [299336] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13370), 1,
      anon_sym_RPAREN,
    STATE(8762), 1,
      sym_gnu_asm_goto_list,
  [299349] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7522), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13372), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [299360] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13374), 1,
      anon_sym_RPAREN,
    STATE(7966), 1,
      sym_gnu_asm_clobber_list,
  [299373] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13376), 1,
      anon_sym_RPAREN,
    STATE(8021), 1,
      sym_gnu_asm_input_operand_list,
  [299386] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13378), 1,
      anon_sym_RPAREN,
    STATE(8022), 1,
      sym_gnu_asm_output_operand_list,
  [299399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13380), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299412] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13382), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299425] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13384), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299438] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6999), 1,
      anon_sym___attribute,
    ACTIONS(7001), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [299449] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13386), 1,
      anon_sym_default,
    ACTIONS(13388), 1,
      anon_sym_delete,
    ACTIONS(13390), 1,
      aux_sym_pure_virtual_clause_token1,
  [299462] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13022), 1,
      anon_sym_COMMA,
    ACTIONS(13392), 1,
      anon_sym_RPAREN,
    STATE(7777), 1,
      aux_sym_gnu_asm_goto_list_repeat1,
  [299475] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13394), 1,
      anon_sym_RPAREN,
    STATE(8771), 1,
      sym_gnu_asm_goto_list,
  [299488] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(13396), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [299501] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13398), 1,
      anon_sym_GT2,
    STATE(7974), 1,
      aux_sym_template_argument_list_repeat1,
  [299514] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13155), 1,
      anon_sym_COMMA,
    ACTIONS(13400), 1,
      anon_sym_GT2,
    STATE(8154), 1,
      aux_sym_template_parameter_list_repeat1,
  [299527] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13402), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7007), 1,
      anon_sym___attribute,
    ACTIONS(7009), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [299551] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13404), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299564] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(13406), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [299577] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13408), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299590] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13410), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [299603] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13412), 1,
      anon_sym_RPAREN,
    STATE(8070), 1,
      sym_gnu_asm_input_operand_list,
  [299616] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13414), 1,
      anon_sym_RPAREN,
    STATE(8201), 1,
      aux_sym_parameter_list_repeat1,
  [299629] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6945), 1,
      anon_sym___attribute,
    ACTIONS(6947), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [299640] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7676), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13416), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [299651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7067), 1,
      anon_sym___attribute,
    ACTIONS(7069), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [299662] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13418), 1,
      anon_sym_RPAREN,
    STATE(8201), 1,
      aux_sym_parameter_list_repeat1,
  [299675] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12975), 1,
      anon_sym_catch,
    STATE(327), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [299686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7105), 1,
      anon_sym___attribute,
    ACTIONS(7107), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [299697] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(13420), 1,
      anon_sym_RBRACK,
    STATE(7787), 1,
      aux_sym_subscript_argument_list_repeat1,
  [299710] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13422), 1,
      anon_sym_RPAREN,
    STATE(8140), 1,
      sym_gnu_asm_output_operand_list,
  [299723] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13424), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(13426), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [299734] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13428), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299747] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13430), 1,
      anon_sym_default,
    ACTIONS(13432), 1,
      anon_sym_delete,
    ACTIONS(13434), 1,
      aux_sym_pure_virtual_clause_token1,
  [299760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12519), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(13436), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [299771] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13035), 1,
      anon_sym_LPAREN2,
    ACTIONS(13438), 1,
      aux_sym_preproc_include_token2,
    STATE(8900), 1,
      sym_preproc_argument_list,
  [299784] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(13440), 1,
      anon_sym_LBRACE,
    STATE(7829), 1,
      aux_sym_base_class_clause_repeat1,
  [299797] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9225), 3,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
  [299806] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13442), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299819] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13444), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299832] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    STATE(554), 1,
      sym_declaration_list,
  [299845] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13446), 1,
      anon_sym_SEMI,
    STATE(7809), 1,
      aux_sym_declaration_repeat1,
  [299858] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10561), 1,
      anon_sym_COMMA,
    ACTIONS(13448), 1,
      anon_sym_RPAREN,
    STATE(7825), 1,
      aux_sym_preproc_argument_list_repeat1,
  [299871] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13450), 1,
      sym_identifier,
    STATE(2397), 1,
      sym_template_type,
    STATE(4247), 1,
      sym_template_function,
  [299884] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13452), 1,
      anon_sym_COMMA,
    ACTIONS(13455), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299897] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13089), 1,
      anon_sym_COMMA,
    ACTIONS(13457), 1,
      anon_sym_RPAREN,
    STATE(7837), 1,
      aux_sym_preproc_params_repeat1,
  [299910] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13262), 1,
      anon_sym_COMMA,
    ACTIONS(13459), 1,
      anon_sym_RBRACK,
    STATE(8131), 1,
      aux_sym_lambda_capture_specifier_repeat1,
  [299923] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13461), 1,
      anon_sym_GT2,
    STATE(8007), 1,
      aux_sym_template_argument_list_repeat1,
  [299936] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7533), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13463), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [299947] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13465), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299960] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    STATE(760), 1,
      sym_declaration_list,
  [299973] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13467), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [299986] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13469), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [299999] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13471), 1,
      anon_sym_default,
    ACTIONS(13473), 1,
      anon_sym_delete,
    ACTIONS(13475), 1,
      aux_sym_pure_virtual_clause_token1,
  [300012] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13477), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [300025] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12761), 1,
      anon_sym_LBRACE,
    STATE(7829), 1,
      aux_sym_base_class_clause_repeat1,
  [300038] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13479), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [300051] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13481), 1,
      anon_sym_RPAREN,
    STATE(8029), 1,
      sym_gnu_asm_clobber_list,
  [300064] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12761), 1,
      anon_sym_LBRACE,
    STATE(8176), 1,
      aux_sym_base_class_clause_repeat1,
  [300077] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13483), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(13485), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [300088] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13487), 1,
      anon_sym_RPAREN,
    STATE(8034), 1,
      sym_gnu_asm_input_operand_list,
  [300101] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13489), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [300114] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13491), 1,
      anon_sym_RPAREN,
    STATE(8164), 1,
      sym_gnu_asm_input_operand_list,
  [300127] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13493), 1,
      anon_sym_GT2,
    STATE(8025), 1,
      aux_sym_template_argument_list_repeat1,
  [300140] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13495), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300153] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13497), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300166] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13499), 1,
      anon_sym_RPAREN,
    STATE(8046), 1,
      sym_gnu_asm_clobber_list,
  [300179] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13501), 1,
      anon_sym_RPAREN,
    STATE(8047), 1,
      sym_gnu_asm_input_operand_list,
  [300192] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13503), 1,
      anon_sym_default,
    ACTIONS(13505), 1,
      anon_sym_delete,
    ACTIONS(13507), 1,
      aux_sym_pure_virtual_clause_token1,
  [300205] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7596), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13509), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [300216] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13511), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300229] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13513), 1,
      anon_sym_GT2,
    STATE(8180), 1,
      aux_sym_template_argument_list_repeat1,
  [300242] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9366), 1,
      anon_sym_COMMA,
    ACTIONS(9368), 1,
      anon_sym_RBRACE,
    STATE(7895), 1,
      aux_sym_initializer_list_repeat1,
  [300255] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13515), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3928), 1,
      sym_template_function,
  [300268] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13517), 1,
      anon_sym_RPAREN,
    STATE(9306), 1,
      sym_gnu_asm_goto_list,
  [300281] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13519), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [300294] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7551), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13521), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [300305] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9190), 1,
      anon_sym_RPAREN,
    STATE(8103), 1,
      aux_sym_argument_list_repeat1,
  [300318] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13523), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [300331] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13525), 1,
      anon_sym_RPAREN,
    STATE(8051), 1,
      sym_gnu_asm_clobber_list,
  [300344] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7613), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13527), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [300355] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13529), 1,
      anon_sym_COMMA,
    ACTIONS(13532), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [300368] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7655), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13534), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [300379] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7707), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13536), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [300390] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7723), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13538), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [300401] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13540), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3928), 1,
      sym_template_function,
  [300414] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7737), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13542), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [300425] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13544), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [300434] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(13546), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [300447] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9376), 1,
      anon_sym_RPAREN,
    STATE(8189), 1,
      aux_sym_argument_list_repeat1,
  [300460] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13548), 1,
      anon_sym_GT2,
    STATE(8050), 1,
      aux_sym_template_argument_list_repeat1,
  [300473] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13550), 1,
      anon_sym_RPAREN,
    STATE(9023), 1,
      sym_gnu_asm_goto_list,
  [300486] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13552), 1,
      anon_sym_RPAREN,
    STATE(8054), 1,
      sym_gnu_asm_clobber_list,
  [300499] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13554), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300512] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13556), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300525] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13558), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300538] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13560), 1,
      anon_sym_RPAREN,
    STATE(9344), 1,
      sym_gnu_asm_goto_list,
  [300551] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(13562), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [300564] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    ACTIONS(13564), 1,
      anon_sym_constexpr,
    STATE(671), 1,
      sym_condition_clause,
  [300577] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13566), 1,
      anon_sym_RPAREN,
    STATE(9037), 1,
      sym_gnu_asm_goto_list,
  [300590] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13568), 1,
      anon_sym_RPAREN,
    STATE(8108), 1,
      sym_gnu_asm_output_operand_list,
  [300603] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13570), 1,
      anon_sym_RPAREN,
    STATE(8201), 1,
      aux_sym_parameter_list_repeat1,
  [300616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13001), 1,
      anon_sym_catch,
    STATE(1869), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [300627] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(13572), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [300640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13236), 1,
      anon_sym_catch,
    STATE(273), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [300651] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(13574), 1,
      anon_sym_RBRACK,
    STATE(7787), 1,
      aux_sym_subscript_argument_list_repeat1,
  [300664] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13576), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [300677] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13578), 1,
      anon_sym_GT2,
    STATE(8116), 1,
      aux_sym_template_argument_list_repeat1,
  [300690] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13580), 1,
      anon_sym_GT2,
    STATE(8068), 1,
      aux_sym_template_argument_list_repeat1,
  [300703] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13582), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8105), 1,
      aux_sym_attribute_declaration_repeat1,
  [300716] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13584), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300729] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13586), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300742] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13588), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [300755] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13590), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [300768] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13592), 1,
      anon_sym_RPAREN,
    STATE(9478), 1,
      sym_gnu_asm_goto_list,
  [300781] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13594), 1,
      anon_sym_RPAREN,
    STATE(8203), 1,
      sym_gnu_asm_clobber_list,
  [300794] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13596), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [300803] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13598), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [300812] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6825), 1,
      anon_sym_EQ,
    ACTIONS(6823), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [300823] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9324), 1,
      anon_sym_RPAREN,
    STATE(7864), 1,
      aux_sym_argument_list_repeat1,
  [300836] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9096), 1,
      anon_sym_RBRACE,
    ACTIONS(9269), 1,
      anon_sym_COMMA,
    STATE(7834), 1,
      aux_sym_initializer_list_repeat1,
  [300849] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13600), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(13602), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [300860] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13604), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [300873] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9456), 1,
      anon_sym_RPAREN,
    ACTIONS(13606), 1,
      anon_sym_COMMA,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [300886] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13609), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7940), 1,
      aux_sym_attribute_declaration_repeat1,
  [300899] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13155), 1,
      anon_sym_COMMA,
    ACTIONS(13611), 1,
      anon_sym_GT2,
    STATE(8153), 1,
      aux_sym_template_parameter_list_repeat1,
  [300912] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(12893), 1,
      anon_sym_LBRACE,
    STATE(7829), 1,
      aux_sym_base_class_clause_repeat1,
  [300925] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13613), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [300938] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12977), 1,
      anon_sym_COMMA,
    ACTIONS(13615), 1,
      anon_sym_LBRACE,
    STATE(7781), 1,
      aux_sym_field_initializer_list_repeat1,
  [300951] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13617), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(13619), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [300962] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13621), 1,
      anon_sym_catch,
    STATE(832), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [300973] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    STATE(269), 1,
      sym_declaration_list,
  [300986] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13623), 1,
      anon_sym_RPAREN,
    STATE(7950), 1,
      sym_gnu_asm_input_operand_list,
  [300999] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13625), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(4117), 1,
      sym_template_function,
  [301012] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12795), 1,
      anon_sym_DASH_GT,
    ACTIONS(13627), 1,
      anon_sym_SEMI,
    STATE(9544), 1,
      sym_trailing_return_type,
  [301025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7123), 1,
      anon_sym___attribute,
    ACTIONS(7125), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [301036] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13262), 1,
      anon_sym_COMMA,
    ACTIONS(13629), 1,
      anon_sym_RBRACK,
    STATE(8131), 1,
      aux_sym_lambda_capture_specifier_repeat1,
  [301049] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13631), 1,
      anon_sym_GT2,
    STATE(8099), 1,
      aux_sym_template_argument_list_repeat1,
  [301062] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13633), 1,
      anon_sym_SEMI,
    STATE(8123), 1,
      aux_sym_declaration_repeat1,
  [301075] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13007), 1,
      anon_sym_COMMA,
    ACTIONS(13635), 1,
      anon_sym_RPAREN,
    STATE(7879), 1,
      aux_sym_throw_specifier_repeat1,
  [301088] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13637), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301101] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13639), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13064), 1,
      anon_sym_catch,
    STATE(360), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [301125] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13641), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [301138] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13643), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13645), 3,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_DOT,
  [301160] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13649), 1,
      anon_sym_RPAREN,
    ACTIONS(13647), 2,
      anon_sym_DOT_DOT_DOT,
      sym_identifier,
  [301171] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13651), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [301180] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13653), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [301193] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9356), 1,
      anon_sym_COMMA,
    ACTIONS(9358), 1,
      anon_sym_RBRACE,
    STATE(7905), 1,
      aux_sym_initializer_list_repeat1,
  [301206] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13655), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8036), 1,
      aux_sym_attribute_declaration_repeat1,
  [301219] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9293), 1,
      anon_sym_RPAREN,
    STATE(8168), 1,
      aux_sym_argument_list_repeat1,
  [301232] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13657), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(4247), 1,
      sym_template_function,
  [301245] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13659), 1,
      anon_sym_RPAREN,
    STATE(8126), 1,
      sym_gnu_asm_input_operand_list,
  [301258] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13661), 1,
      anon_sym_RPAREN,
    STATE(8128), 1,
      sym_gnu_asm_output_operand_list,
  [301271] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13663), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301284] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(13665), 1,
      anon_sym_RBRACK,
    STATE(7787), 1,
      aux_sym_subscript_argument_list_repeat1,
  [301297] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9271), 1,
      anon_sym_COMMA,
    ACTIONS(9273), 1,
      anon_sym_RBRACE,
    STATE(8175), 1,
      aux_sym_initializer_list_repeat1,
  [301310] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13667), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(2837), 1,
      sym_template_function,
  [301323] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13669), 1,
      anon_sym_RPAREN,
    STATE(8187), 1,
      sym_gnu_asm_output_operand_list,
  [301336] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13671), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301349] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13673), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301362] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13675), 1,
      anon_sym_GT2,
    STATE(8197), 1,
      aux_sym_template_argument_list_repeat1,
  [301375] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13677), 1,
      anon_sym_EQ,
    ACTIONS(12070), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [301386] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(9343), 1,
      anon_sym_RPAREN,
    STATE(7845), 1,
      aux_sym_argument_list_repeat1,
  [301399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13679), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [301412] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13681), 1,
      anon_sym_SEMI,
    STATE(8206), 1,
      aux_sym_declaration_repeat1,
  [301425] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13683), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [301438] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13685), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [301451] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9231), 1,
      anon_sym_COMMA,
    ACTIONS(13687), 1,
      aux_sym_kernel_call_syntax_token2,
    STATE(7799), 1,
      aux_sym_kernel_call_syntax_repeat1,
  [301464] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13689), 1,
      anon_sym_RPAREN,
    STATE(8183), 1,
      aux_sym_parameter_list_repeat1,
  [301477] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13691), 1,
      anon_sym_RPAREN,
    STATE(8130), 1,
      sym_gnu_asm_clobber_list,
  [301490] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12561), 3,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
  [301499] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13693), 1,
      anon_sym_RPAREN,
    STATE(8133), 1,
      sym_gnu_asm_input_operand_list,
  [301512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13132), 1,
      anon_sym_catch,
    STATE(1726), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [301523] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13695), 1,
      anon_sym_RPAREN,
    STATE(9469), 1,
      sym_gnu_asm_goto_list,
  [301536] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13697), 1,
      anon_sym_COMMA,
    ACTIONS(13700), 1,
      anon_sym_RBRACK,
    STATE(8131), 1,
      aux_sym_lambda_capture_specifier_repeat1,
  [301549] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13702), 1,
      anon_sym_SEMI,
    STATE(8170), 1,
      aux_sym_declaration_repeat1,
  [301562] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13704), 1,
      anon_sym_RPAREN,
    STATE(8134), 1,
      sym_gnu_asm_clobber_list,
  [301575] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13706), 1,
      anon_sym_RPAREN,
    STATE(9528), 1,
      sym_gnu_asm_goto_list,
  [301588] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13708), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [301597] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    ACTIONS(13710), 1,
      anon_sym_constexpr,
    STATE(653), 1,
      sym_condition_clause,
  [301610] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    STATE(7672), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(13712), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [301621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13716), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13714), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [301632] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13718), 1,
      anon_sym_RPAREN,
    STATE(8148), 1,
      sym_gnu_asm_clobber_list,
  [301645] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13720), 1,
      anon_sym_RPAREN,
    STATE(8149), 1,
      sym_gnu_asm_input_operand_list,
  [301658] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13722), 1,
      anon_sym_RPAREN,
    STATE(7944), 1,
      sym_gnu_asm_output_operand_list,
  [301671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13708), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [301680] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13724), 1,
      anon_sym_RPAREN,
    STATE(7976), 1,
      sym_gnu_asm_output_operand_list,
  [301693] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13726), 1,
      anon_sym_SEMI,
    STATE(7892), 1,
      aux_sym_declaration_repeat1,
  [301706] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13728), 1,
      anon_sym_GT2,
    STATE(7994), 1,
      aux_sym_template_argument_list_repeat1,
  [301719] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13035), 1,
      anon_sym_LPAREN2,
    ACTIONS(13730), 1,
      aux_sym_preproc_include_token2,
    STATE(8900), 1,
      sym_preproc_argument_list,
  [301732] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13732), 1,
      anon_sym_RPAREN,
    STATE(9072), 1,
      sym_gnu_asm_goto_list,
  [301745] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13734), 1,
      anon_sym_RPAREN,
    STATE(9381), 1,
      sym_gnu_asm_goto_list,
  [301758] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13736), 1,
      anon_sym_RPAREN,
    STATE(8151), 1,
      sym_gnu_asm_clobber_list,
  [301771] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13738), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [301784] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13740), 1,
      anon_sym_RPAREN,
    STATE(9411), 1,
      sym_gnu_asm_goto_list,
  [301797] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9213), 1,
      anon_sym_COMMA,
    ACTIONS(13742), 1,
      anon_sym_RPAREN,
    STATE(7901), 1,
      aux_sym_generic_expression_repeat1,
  [301810] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13155), 1,
      anon_sym_COMMA,
    ACTIONS(13744), 1,
      anon_sym_GT2,
    STATE(8154), 1,
      aux_sym_template_parameter_list_repeat1,
  [301823] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13746), 1,
      anon_sym_COMMA,
    ACTIONS(13749), 1,
      anon_sym_GT2,
    STATE(8154), 1,
      aux_sym_template_parameter_list_repeat1,
  [301836] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    STATE(764), 1,
      sym_declaration_list,
  [301849] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13064), 1,
      anon_sym_catch,
    STATE(312), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [301860] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13751), 1,
      anon_sym_RPAREN,
    STATE(7821), 1,
      sym_gnu_asm_input_operand_list,
  [301873] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13753), 3,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_DOT,
  [301882] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13755), 1,
      anon_sym_RPAREN,
    STATE(7830), 1,
      sym_gnu_asm_output_operand_list,
  [301895] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13757), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301908] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13759), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301921] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13761), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301934] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13763), 1,
      anon_sym_default,
    ACTIONS(13765), 1,
      anon_sym_delete,
    ACTIONS(13767), 1,
      aux_sym_pure_virtual_clause_token1,
  [301947] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13104), 1,
      anon_sym_COLON,
    ACTIONS(13769), 1,
      anon_sym_RPAREN,
    STATE(7827), 1,
      sym_gnu_asm_clobber_list,
  [301960] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13771), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [301973] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9360), 1,
      anon_sym_COMMA,
    ACTIONS(9362), 1,
      anon_sym_RBRACE,
    STATE(7880), 1,
      aux_sym_initializer_list_repeat1,
  [301986] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13773), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7810), 1,
      aux_sym_attribute_declaration_repeat1,
  [301999] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13775), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [302012] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13777), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(3065), 1,
      sym_template_function,
  [302025] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13779), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [302038] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13781), 1,
      anon_sym_SEMI,
    STATE(8006), 1,
      aux_sym_declaration_repeat1,
  [302051] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13783), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [302064] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13785), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [302077] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13787), 3,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
  [302086] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4571), 1,
      anon_sym_RBRACE,
    ACTIONS(13789), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [302099] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(13791), 1,
      anon_sym_LBRACE,
    STATE(7829), 1,
      aux_sym_base_class_clause_repeat1,
  [302112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13793), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(13795), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [302123] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13797), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7792), 1,
      aux_sym_attribute_declaration_repeat1,
  [302136] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    ACTIONS(13799), 1,
      anon_sym_constexpr,
    STATE(627), 1,
      sym_condition_clause,
  [302149] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13801), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [302162] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12685), 1,
      anon_sym_COMMA,
    ACTIONS(13791), 1,
      anon_sym_LBRACE,
    STATE(7991), 1,
      aux_sym_base_class_clause_repeat1,
  [302175] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13803), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
    STATE(2837), 1,
      sym_template_function,
  [302188] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13805), 1,
      anon_sym_RPAREN,
    STATE(8201), 1,
      aux_sym_parameter_list_repeat1,
  [302201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13071), 1,
      anon_sym_catch,
    STATE(146), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [302212] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9148), 1,
      anon_sym_COMMA,
    ACTIONS(13807), 1,
      anon_sym_RBRACK,
    STATE(7787), 1,
      aux_sym_subscript_argument_list_repeat1,
  [302225] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    ACTIONS(6898), 1,
      anon_sym_SEMI,
    STATE(1905), 1,
      sym_template_argument_list,
  [302238] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13128), 1,
      anon_sym_COLON,
    ACTIONS(13809), 1,
      anon_sym_RPAREN,
    STATE(7833), 1,
      sym_gnu_asm_input_operand_list,
  [302251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13811), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [302260] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_COMMA,
    ACTIONS(13813), 1,
      anon_sym_RPAREN,
    STATE(8078), 1,
      aux_sym_argument_list_repeat1,
  [302273] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13815), 1,
      anon_sym_RPAREN,
    STATE(8017), 1,
      sym_gnu_asm_output_operand_list,
  [302286] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13817), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [302299] = 4,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13035), 1,
      anon_sym_LPAREN2,
    ACTIONS(13819), 1,
      aux_sym_preproc_include_token2,
    STATE(8900), 1,
      sym_preproc_argument_list,
  [302312] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13821), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [302325] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13823), 1,
      anon_sym_COMMA,
    ACTIONS(13826), 1,
      anon_sym_RPAREN,
    STATE(8194), 1,
      aux_sym_requires_parameter_list_repeat1,
  [302338] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9354), 1,
      anon_sym_RBRACE,
    ACTIONS(13828), 1,
      anon_sym_COMMA,
    STATE(8195), 1,
      aux_sym_initializer_list_repeat1,
  [302351] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13831), 1,
      anon_sym_SEMI,
    STATE(8033), 1,
      aux_sym_declaration_repeat1,
  [302364] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13833), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [302377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13716), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13835), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [302388] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13837), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [302401] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13839), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7828), 1,
      aux_sym_attribute_declaration_repeat1,
  [302414] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13841), 1,
      anon_sym_COMMA,
    ACTIONS(13844), 1,
      anon_sym_RPAREN,
    STATE(8201), 1,
      aux_sym_parameter_list_repeat1,
  [302427] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_COMMA,
    ACTIONS(13846), 1,
      anon_sym_RPAREN,
    STATE(7981), 1,
      aux_sym_parameter_list_repeat1,
  [302440] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_COLON,
    ACTIONS(13848), 1,
      anon_sym_RPAREN,
    STATE(9176), 1,
      sym_gnu_asm_goto_list,
  [302453] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_COMMA,
    ACTIONS(13850), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(8067), 1,
      aux_sym_attribute_declaration_repeat1,
  [302466] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      anon_sym_COLON,
    ACTIONS(13852), 1,
      anon_sym_RPAREN,
    STATE(7881), 1,
      sym_gnu_asm_output_operand_list,
  [302479] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_COMMA,
    ACTIONS(13854), 1,
      anon_sym_SEMI,
    STATE(7904), 1,
      aux_sym_declaration_repeat1,
  [302492] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    ACTIONS(13856), 1,
      anon_sym_constexpr,
    STATE(652), 1,
      sym_condition_clause,
  [302505] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9112), 1,
      anon_sym_COMMA,
    ACTIONS(13858), 1,
      anon_sym_GT2,
    STATE(7999), 1,
      aux_sym_template_argument_list_repeat1,
  [302518] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11686), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [302528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    STATE(767), 1,
      sym_declaration_list,
  [302538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13862), 1,
      anon_sym_SEMI,
  [302548] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_LBRACE,
    STATE(4315), 1,
      sym_initializer_list,
  [302558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    STATE(523), 1,
      sym_declaration_list,
  [302568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    STATE(3063), 1,
      sym_field_declaration_list,
  [302578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    STATE(2010), 1,
      sym_compound_statement,
  [302588] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13826), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [302596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(8200), 1,
      sym_attribute,
  [302606] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8987), 1,
      anon_sym_LPAREN2,
    STATE(5523), 1,
      sym_argument_list,
  [302616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    STATE(2296), 1,
      sym_field_declaration_list,
  [302626] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13866), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [302634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8726), 1,
      sym_parenthesized_expression,
  [302644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(8406), 1,
      sym_parameter_list,
  [302654] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(651), 1,
      sym_condition_clause,
  [302664] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    STATE(404), 1,
      sym_compound_statement,
  [302674] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13870), 1,
      sym_identifier,
    ACTIONS(13872), 1,
      anon_sym_LPAREN2,
  [302684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13874), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [302692] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13876), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13878), 1,
      sym_preproc_arg,
  [302702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7982), 1,
      sym_compound_statement,
  [302712] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13835), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [302720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13880), 1,
      sym_identifier,
    STATE(2986), 1,
      sym_template_type,
  [302730] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13844), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [302738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8430), 1,
      sym_parenthesized_expression,
  [302748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(2693), 1,
      sym_template_argument_list,
  [302758] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13882), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13884), 1,
      sym_preproc_arg,
  [302768] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13169), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [302776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    STATE(268), 1,
      sym_compound_statement,
  [302786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    STATE(527), 1,
      sym_declaration_list,
  [302796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7627), 1,
      sym_compound_statement,
  [302806] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13886), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13888), 1,
      sym_preproc_arg,
  [302816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    STATE(4914), 1,
      sym_field_declaration_list,
  [302826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(2360), 1,
      sym_template_argument_list,
  [302836] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_LBRACE,
    STATE(4395), 1,
      sym_initializer_list,
  [302846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2581), 1,
      sym_field_declaration_list,
  [302856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10246), 1,
      anon_sym_LBRACE,
    STATE(3930), 1,
      sym_requirement_seq,
  [302866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(9190), 1,
      sym_parenthesized_expression,
  [302876] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3369), 1,
      anon_sym_LBRACE,
    STATE(4198), 1,
      sym_initializer_list,
  [302886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13890), 1,
      sym_identifier,
    STATE(2397), 1,
      sym_template_type,
  [302896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10302), 1,
      anon_sym_LBRACE,
    STATE(4876), 1,
      sym_requirement_seq,
  [302906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    STATE(536), 1,
      sym_compound_statement,
  [302916] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10262), 1,
      anon_sym_LBRACE,
    STATE(4182), 1,
      sym_requirement_seq,
  [302926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13892), 1,
      sym_identifier,
    STATE(3093), 1,
      sym_template_type,
  [302936] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13894), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [302944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13031), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [302952] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9308), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [302960] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13896), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [302968] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10294), 1,
      anon_sym_LBRACE,
    STATE(3767), 1,
      sym_requirement_seq,
  [302978] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13898), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13900), 1,
      sym_preproc_arg,
  [302988] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9502), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [302996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    STATE(715), 1,
      sym_declaration_list,
  [303006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7342), 1,
      anon_sym_LT,
    STATE(3077), 1,
      sym_template_argument_list,
  [303016] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8649), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [303024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(453), 1,
      sym_compound_statement,
  [303034] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7435), 1,
      anon_sym_LPAREN2,
    STATE(3857), 1,
      sym_argument_list,
  [303044] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(699), 1,
      sym_compound_statement,
  [303054] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11645), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [303064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    STATE(2442), 1,
      sym_field_declaration_list,
  [303074] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6537), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [303082] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1660), 1,
      anon_sym_LBRACE,
    STATE(893), 1,
      sym_compound_statement,
  [303092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13902), 1,
      anon_sym_LT,
    STATE(4156), 1,
      sym_template_argument_list,
  [303102] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    STATE(4917), 1,
      sym_field_declaration_list,
  [303112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    STATE(4918), 1,
      sym_field_declaration_list,
  [303122] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13904), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13906), 1,
      sym_preproc_arg,
  [303132] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym_compound_statement,
  [303142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10270), 1,
      anon_sym_LBRACE,
    STATE(4389), 1,
      sym_requirement_seq,
  [303152] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
  [303162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(2717), 1,
      sym_template_argument_list,
  [303172] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13908), 2,
      anon_sym_DOT_DOT_DOT,
      sym_identifier,
  [303180] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    STATE(483), 1,
      sym_compound_statement,
  [303190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9001), 1,
      anon_sym_LPAREN2,
    STATE(5484), 1,
      sym_argument_list,
  [303200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13264), 1,
      anon_sym_RBRACK,
    ACTIONS(13910), 1,
      anon_sym_COMMA,
  [303210] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2604), 1,
      sym_field_declaration_list,
  [303220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13912), 1,
      anon_sym_RBRACE,
  [303230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    STATE(552), 1,
      sym_declaration_list,
  [303240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8967), 1,
      anon_sym_LBRACE,
    STATE(4913), 1,
      sym_field_declaration_list,
  [303250] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9354), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [303258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    STATE(2099), 1,
      sym_compound_statement,
  [303268] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13914), 1,
      sym_identifier,
    STATE(1966), 1,
      sym_template_type,
  [303278] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13916), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13918), 1,
      sym_preproc_arg,
  [303288] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5671), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
  [303298] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13920), 1,
      anon_sym_LT,
    STATE(2717), 1,
      sym_template_argument_list,
  [303308] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    STATE(3128), 1,
      sym_field_declaration_list,
  [303318] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13143), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [303326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    STATE(4767), 1,
      sym_field_declaration_list,
  [303336] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13922), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13924), 1,
      sym_preproc_arg,
  [303346] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13532), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [303354] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13926), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13928), 1,
      sym_preproc_arg,
  [303364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13930), 1,
      anon_sym_LT,
    STATE(2929), 1,
      sym_template_argument_list,
  [303374] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    STATE(3069), 1,
      sym_field_declaration_list,
  [303384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13932), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [303392] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9520), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [303400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8738), 1,
      anon_sym_LPAREN2,
    STATE(4386), 1,
      sym_argument_list,
  [303410] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    STATE(2306), 1,
      sym_field_declaration_list,
  [303420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    STATE(2311), 1,
      sym_field_declaration_list,
  [303430] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13934), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13936), 1,
      sym_preproc_arg,
  [303440] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13938), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13940), 1,
      sym_preproc_arg,
  [303450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12535), 1,
      anon_sym_LBRACE,
    STATE(1693), 1,
      sym_requirement_seq,
  [303460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13942), 1,
      sym_identifier,
    STATE(4672), 1,
      sym_template_type,
  [303470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7510), 1,
      anon_sym_LPAREN2,
    STATE(4114), 1,
      sym_argument_list,
  [303480] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11682), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [303490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11613), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [303500] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8999), 1,
      anon_sym_LT,
    STATE(2406), 1,
      sym_template_argument_list,
  [303510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    STATE(3169), 1,
      sym_field_declaration_list,
  [303520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    STATE(2454), 1,
      sym_field_declaration_list,
  [303530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    STATE(2456), 1,
      sym_field_declaration_list,
  [303540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(8204), 1,
      sym_attribute,
  [303550] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(8486), 1,
      sym_condition_clause,
  [303560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12517), 1,
      anon_sym_LBRACE,
    STATE(6507), 1,
      sym_requirement_seq,
  [303570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(654), 1,
      sym_condition_clause,
  [303580] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7842), 1,
      sym_compound_statement,
  [303590] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11179), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [303598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13944), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
  [303608] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13946), 1,
      anon_sym_LT,
    STATE(4544), 1,
      sym_template_argument_list,
  [303618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13948), 1,
      sym_identifier,
    STATE(2364), 1,
      sym_template_type,
  [303628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(8097), 1,
      sym_compound_statement,
  [303638] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9203), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [303646] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8923), 1,
      sym_argument_list,
  [303656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7675), 1,
      sym_compound_statement,
  [303666] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(634), 1,
      sym_condition_clause,
  [303676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [303686] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13950), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13952), 1,
      sym_preproc_arg,
  [303696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    STATE(2113), 1,
      sym_compound_statement,
  [303706] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    STATE(4738), 1,
      sym_field_declaration_list,
  [303716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13930), 1,
      anon_sym_LT,
    STATE(3884), 1,
      sym_template_argument_list,
  [303726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    STATE(3188), 1,
      sym_field_declaration_list,
  [303736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    STATE(3189), 1,
      sym_field_declaration_list,
  [303746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13954), 1,
      anon_sym_LT,
    STATE(2717), 1,
      sym_template_argument_list,
  [303756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(9210), 1,
      sym_parenthesized_expression,
  [303766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(8577), 1,
      sym_parameter_list,
  [303776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    STATE(4740), 1,
      sym_field_declaration_list,
  [303786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13956), 1,
      anon_sym_LT,
    STATE(4091), 1,
      sym_template_argument_list,
  [303796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11633), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [303806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(8184), 1,
      sym_compound_statement,
  [303816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13958), 1,
      anon_sym_RBRACE,
  [303826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7091), 1,
      anon_sym_LBRACE,
    STATE(3193), 1,
      sym_field_declaration_list,
  [303836] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8262), 1,
      sym_parenthesized_expression,
  [303846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    STATE(4746), 1,
      sym_field_declaration_list,
  [303856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    STATE(4753), 1,
      sym_field_declaration_list,
  [303866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(443), 1,
      sym_compound_statement,
  [303876] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3209), 1,
      anon_sym_LBRACE,
    STATE(4050), 1,
      sym_initializer_list,
  [303886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    STATE(501), 1,
      sym_compound_statement,
  [303896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
  [303906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    STATE(265), 1,
      sym_declaration_list,
  [303916] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    STATE(394), 1,
      sym_compound_statement,
  [303926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13960), 1,
      sym_identifier,
    STATE(2974), 1,
      sym_template_type,
  [303936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13962), 1,
      anon_sym_RBRACE,
  [303946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    STATE(191), 1,
      sym_compound_statement,
  [303956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    STATE(2465), 1,
      sym_field_declaration_list,
  [303966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13964), 1,
      sym_identifier,
    STATE(1966), 1,
      sym_template_type,
  [303976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    STATE(575), 1,
      sym_compound_statement,
  [303986] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6782), 1,
      anon_sym_LT,
    STATE(1659), 1,
      sym_template_argument_list,
  [303996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    STATE(621), 1,
      sym_declaration_list,
  [304006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(8079), 1,
      sym_attribute,
  [304016] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(8433), 1,
      sym_condition_clause,
  [304026] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(650), 1,
      sym_condition_clause,
  [304036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    STATE(4467), 1,
      sym_field_declaration_list,
  [304046] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(8059), 1,
      sym_compound_statement,
  [304056] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13966), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
  [304066] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11496), 1,
      anon_sym_LBRACE,
    STATE(1901), 1,
      sym_compound_statement,
  [304076] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13968), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [304084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(2998), 1,
      sym_template_argument_list,
  [304094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8915), 1,
      sym_argument_list,
  [304104] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7545), 1,
      sym_compound_statement,
  [304114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(659), 1,
      sym_condition_clause,
  [304124] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11674), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [304134] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13970), 1,
      anon_sym_RBRACE,
  [304144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym_compound_statement,
  [304154] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5181), 1,
      anon_sym_LBRACE,
    STATE(585), 1,
      sym_declaration_list,
  [304164] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    STATE(4438), 1,
      sym_field_declaration_list,
  [304174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    STATE(4441), 1,
      sym_field_declaration_list,
  [304184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8801), 1,
      sym_parenthesized_expression,
  [304194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13972), 1,
      sym_identifier,
    STATE(3080), 1,
      sym_template_type,
  [304204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(8436), 1,
      sym_parameter_list,
  [304214] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13956), 1,
      anon_sym_LT,
    STATE(3811), 1,
      sym_template_argument_list,
  [304224] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13974), 1,
      anon_sym_RBRACE,
  [304234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(8057), 1,
      sym_compound_statement,
  [304244] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8516), 1,
      sym_parenthesized_expression,
  [304254] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13976), 1,
      anon_sym_RBRACE,
  [304264] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8004), 1,
      anon_sym_LBRACE,
    STATE(4450), 1,
      sym_field_declaration_list,
  [304274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    STATE(2312), 1,
      sym_field_declaration_list,
  [304284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    STATE(403), 1,
      sym_compound_statement,
  [304294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13978), 1,
      anon_sym_RBRACE,
  [304304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13980), 1,
      anon_sym_RBRACE,
  [304314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(13982), 1,
      anon_sym_RBRACE,
  [304324] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(7786), 1,
      sym_attribute,
  [304334] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(8268), 1,
      sym_condition_clause,
  [304344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7797), 1,
      sym_compound_statement,
  [304354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8776), 1,
      anon_sym_LBRACE,
    STATE(4801), 1,
      sym_field_declaration_list,
  [304364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13984), 1,
      sym_identifier,
    STATE(4142), 1,
      sym_template_type,
  [304374] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    STATE(2455), 1,
      sym_field_declaration_list,
  [304384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8942), 1,
      sym_argument_list,
  [304394] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7550), 1,
      sym_compound_statement,
  [304404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    STATE(239), 1,
      sym_compound_statement,
  [304414] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13902), 1,
      anon_sym_LT,
    STATE(2982), 1,
      sym_template_argument_list,
  [304424] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8634), 1,
      sym_parenthesized_expression,
  [304434] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(8368), 1,
      sym_parameter_list,
  [304444] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    STATE(332), 1,
      sym_compound_statement,
  [304454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    STATE(1904), 1,
      sym_compound_statement,
  [304464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13986), 1,
      anon_sym_SEMI,
  [304474] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7936), 1,
      sym_compound_statement,
  [304484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8390), 1,
      sym_parenthesized_expression,
  [304494] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13426), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [304502] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12567), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
  [304512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13988), 1,
      anon_sym_SEMI,
  [304522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(8085), 1,
      sym_compound_statement,
  [304532] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13990), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(13992), 1,
      sym_preproc_arg,
  [304542] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(9136), 1,
      sym_argument_list,
  [304552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6309), 1,
      anon_sym_LPAREN2,
    STATE(2786), 1,
      sym_argument_list,
  [304562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6076), 1,
      anon_sym_LT,
    STATE(2360), 1,
      sym_template_argument_list,
  [304572] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13930), 1,
      anon_sym_LT,
    STATE(3678), 1,
      sym_template_argument_list,
  [304582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    STATE(2445), 1,
      sym_field_declaration_list,
  [304592] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8792), 1,
      anon_sym_LT,
    STATE(4670), 1,
      sym_template_argument_list,
  [304602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(8556), 1,
      sym_parameter_list,
  [304612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7832), 1,
      sym_compound_statement,
  [304622] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13994), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [304630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8490), 1,
      sym_parenthesized_expression,
  [304640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(7765), 1,
      sym_attribute,
  [304650] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11582), 1,
      anon_sym_LBRACE,
    STATE(2041), 1,
      sym_compound_statement,
  [304660] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7835), 1,
      sym_compound_statement,
  [304670] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    STATE(318), 1,
      sym_declaration_list,
  [304680] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym_compound_statement,
  [304690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8794), 1,
      sym_argument_list,
  [304700] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(8295), 1,
      sym_attribute,
  [304710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    STATE(383), 1,
      sym_compound_statement,
  [304720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8913), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
  [304730] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13996), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [304738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    STATE(336), 1,
      sym_compound_statement,
  [304748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
    STATE(762), 1,
      sym_declaration_list,
  [304758] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(8470), 1,
      sym_parameter_list,
  [304768] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4673), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [304776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13956), 1,
      anon_sym_LT,
    STATE(2989), 1,
      sym_template_argument_list,
  [304786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7939), 1,
      sym_compound_statement,
  [304796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13485), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [304804] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(8178), 1,
      sym_attribute,
  [304814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7767), 1,
      sym_compound_statement,
  [304824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(9149), 1,
      sym_argument_list,
  [304834] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13998), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(14000), 1,
      sym_preproc_arg,
  [304844] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(8407), 1,
      sym_parameter_list,
  [304854] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14002), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [304862] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(7953), 1,
      sym_attribute,
  [304872] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14004), 1,
      anon_sym_SEMI,
  [304882] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14006), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(14008), 1,
      sym_preproc_arg,
  [304892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(9115), 1,
      sym_argument_list,
  [304902] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2511), 1,
      sym_field_declaration_list,
  [304912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(672), 1,
      sym_condition_clause,
  [304922] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(9496), 1,
      sym_argument_list,
  [304932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(14010), 1,
      anon_sym_RBRACE,
  [304942] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14012), 1,
      anon_sym_LT,
    STATE(2155), 1,
      sym_template_argument_list,
  [304952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(9311), 1,
      sym_argument_list,
  [304962] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8671), 1,
      sym_argument_list,
  [304972] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14014), 1,
      sym_identifier,
    STATE(4581), 1,
      sym_template_type,
  [304982] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13700), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [304990] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_LBRACE,
    STATE(5511), 1,
      sym_initializer_list,
  [305000] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7644), 1,
      sym_compound_statement,
  [305010] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14016), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [305018] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14018), 1,
      sym_identifier,
    STATE(2178), 1,
      sym_template_type,
  [305028] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14020), 1,
      anon_sym_LPAREN2,
    ACTIONS(14022), 1,
      sym_raw_string_delimiter,
  [305038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    STATE(4686), 1,
      sym_field_declaration_list,
  [305048] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2550), 1,
      sym_field_declaration_list,
  [305058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(770), 1,
      sym_compound_statement,
  [305068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    STATE(1759), 1,
      sym_compound_statement,
  [305078] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6882), 1,
      anon_sym_LBRACE,
    STATE(3106), 1,
      sym_field_declaration_list,
  [305088] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 1,
      anon_sym_LBRACE,
    STATE(556), 1,
      sym_declaration_list,
  [305098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(655), 1,
      sym_condition_clause,
  [305108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    STATE(3152), 1,
      sym_field_declaration_list,
  [305118] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(629), 1,
      sym_condition_clause,
  [305128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    STATE(3331), 1,
      sym_field_declaration_list,
  [305138] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12588), 1,
      anon_sym_LBRACE,
    STATE(6212), 1,
      sym_requirement_seq,
  [305148] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7496), 1,
      anon_sym_LPAREN2,
    STATE(4243), 1,
      sym_argument_list,
  [305158] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13902), 1,
      anon_sym_LT,
    STATE(3971), 1,
      sym_template_argument_list,
  [305168] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10286), 1,
      anon_sym_LBRACE,
    STATE(2781), 1,
      sym_requirement_seq,
  [305178] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(402), 1,
      sym_compound_statement,
  [305188] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8879), 1,
      anon_sym_LBRACE,
    STATE(4712), 1,
      sym_field_declaration_list,
  [305198] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10254), 1,
      anon_sym_LBRACE,
    STATE(5475), 1,
      sym_requirement_seq,
  [305208] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14024), 1,
      anon_sym_LT,
    STATE(2998), 1,
      sym_template_argument_list,
  [305218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    STATE(1814), 1,
      sym_compound_statement,
  [305228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    STATE(197), 1,
      sym_compound_statement,
  [305238] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7763), 1,
      anon_sym_LPAREN2,
    STATE(4423), 1,
      sym_argument_list,
  [305248] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11623), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [305258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 1,
      anon_sym_LBRACE,
    STATE(272), 1,
      sym_declaration_list,
  [305268] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1660), 1,
      anon_sym_LBRACE,
    STATE(904), 1,
      sym_compound_statement,
  [305278] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13096), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [305286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14026), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [305294] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14028), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(14030), 1,
      sym_preproc_arg,
  [305304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13954), 1,
      anon_sym_LT,
    STATE(2363), 1,
      sym_template_argument_list,
  [305314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(8156), 1,
      sym_compound_statement,
  [305324] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11627), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [305334] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    STATE(5497), 1,
      sym_field_declaration_list,
  [305344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    STATE(5501), 1,
      sym_field_declaration_list,
  [305354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    STATE(5502), 1,
      sym_field_declaration_list,
  [305364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11692), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [305374] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(660), 1,
      sym_condition_clause,
  [305384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11631), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [305394] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6044), 1,
      anon_sym_LBRACE,
    STATE(5504), 1,
      sym_field_declaration_list,
  [305404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10310), 1,
      anon_sym_LPAREN2,
    STATE(8554), 1,
      sym_parameter_list,
  [305414] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    STATE(3332), 1,
      sym_field_declaration_list,
  [305424] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    STATE(3353), 1,
      sym_field_declaration_list,
  [305434] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(8481), 1,
      sym_condition_clause,
  [305444] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    STATE(3178), 1,
      sym_field_declaration_list,
  [305454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    STATE(3181), 1,
      sym_field_declaration_list,
  [305464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13954), 1,
      anon_sym_LT,
    STATE(2693), 1,
      sym_template_argument_list,
  [305474] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14032), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [305482] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11621), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [305492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_LBRACE,
    STATE(5419), 1,
      sym_initializer_list,
  [305502] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(4386), 1,
      sym_argument_list,
  [305512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    STATE(2430), 1,
      sym_field_declaration_list,
  [305522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    STATE(187), 1,
      sym_compound_statement,
  [305532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(8167), 1,
      sym_attribute,
  [305542] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6198), 1,
      anon_sym_LBRACE,
    STATE(2418), 1,
      sym_field_declaration_list,
  [305552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(8224), 1,
      sym_condition_clause,
  [305562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(657), 1,
      sym_condition_clause,
  [305572] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      anon_sym_LBRACE,
    STATE(3946), 1,
      sym_initializer_list,
  [305582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7763), 1,
      sym_compound_statement,
  [305592] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11556), 1,
      anon_sym_LBRACE,
    STATE(1834), 1,
      sym_compound_statement,
  [305602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(14034), 1,
      anon_sym_RBRACE,
  [305612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6967), 1,
      anon_sym_LBRACE,
    STATE(3207), 1,
      sym_field_declaration_list,
  [305622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14036), 1,
      sym_identifier,
    STATE(2150), 1,
      sym_template_type,
  [305632] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14038), 1,
      sym_identifier,
    ACTIONS(14040), 1,
      anon_sym_LPAREN2,
  [305642] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9370), 1,
      anon_sym_RPAREN,
    ACTIONS(9372), 1,
      anon_sym_SEMI,
  [305652] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14042), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(14044), 1,
      sym_preproc_arg,
  [305662] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14046), 1,
      sym_identifier,
    STATE(1966), 1,
      sym_template_type,
  [305672] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8772), 1,
      sym_argument_list,
  [305682] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1660), 1,
      anon_sym_LBRACE,
    STATE(870), 1,
      sym_compound_statement,
  [305692] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13714), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [305700] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(7534), 1,
      sym_compound_statement,
  [305710] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13749), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [305718] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14048), 1,
      anon_sym_LPAREN2,
    ACTIONS(14050), 1,
      sym_raw_string_delimiter,
  [305728] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13795), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [305736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2910), 1,
      sym_field_declaration_list,
  [305746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(633), 1,
      sym_condition_clause,
  [305756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2914), 1,
      sym_field_declaration_list,
  [305766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2915), 1,
      sym_field_declaration_list,
  [305776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6147), 1,
      anon_sym_LBRACE,
    STATE(2918), 1,
      sym_field_declaration_list,
  [305786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      anon_sym_LPAREN2,
    STATE(656), 1,
      sym_condition_clause,
  [305796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    ACTIONS(14052), 1,
      anon_sym_RBRACE,
  [305806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7315), 1,
      anon_sym_LBRACE,
    STATE(3337), 1,
      sym_field_declaration_list,
  [305816] = 3,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14054), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(14056), 1,
      sym_preproc_arg,
  [305826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2645), 1,
      anon_sym_LBRACE,
    STATE(2743), 1,
      sym_initializer_list,
  [305836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9456), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [305844] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10278), 1,
      anon_sym_LBRACE,
    STATE(4105), 1,
      sym_requirement_seq,
  [305854] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13868), 1,
      anon_sym_LPAREN2,
    STATE(8562), 1,
      sym_parenthesized_expression,
  [305864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(8613), 1,
      sym_argument_list,
  [305874] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14058), 1,
      sym_identifier,
    STATE(2899), 1,
      sym_template_type,
  [305884] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14060), 1,
      anon_sym_LPAREN2,
    ACTIONS(14062), 1,
      sym_raw_string_delimiter,
  [305894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LBRACE,
    STATE(341), 1,
      sym_compound_statement,
  [305904] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14064), 1,
      anon_sym_LPAREN2,
    ACTIONS(14066), 1,
      sym_raw_string_delimiter,
  [305914] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1660), 1,
      anon_sym_LBRACE,
    STATE(854), 1,
      sym_compound_statement,
  [305924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14068), 1,
      anon_sym_LPAREN2,
    ACTIONS(14070), 1,
      sym_raw_string_delimiter,
  [305934] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14072), 1,
      anon_sym_LPAREN2,
    ACTIONS(14074), 1,
      sym_raw_string_delimiter,
  [305944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14076), 1,
      sym_identifier,
    ACTIONS(14078), 1,
      anon_sym_RPAREN,
  [305954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14080), 1,
      anon_sym_LPAREN2,
    ACTIONS(14082), 1,
      sym_raw_string_delimiter,
  [305964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14084), 1,
      anon_sym_LPAREN2,
    ACTIONS(14086), 1,
      sym_raw_string_delimiter,
  [305974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym_compound_statement,
  [305984] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14088), 1,
      anon_sym_LPAREN2,
    ACTIONS(14090), 1,
      sym_raw_string_delimiter,
  [305994] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14092), 1,
      anon_sym_LPAREN2,
    ACTIONS(14094), 1,
      sym_raw_string_delimiter,
  [306004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14096), 1,
      anon_sym_LPAREN2,
    ACTIONS(14098), 1,
      sym_raw_string_delimiter,
  [306014] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14100), 1,
      anon_sym_LPAREN2,
    ACTIONS(14102), 1,
      sym_raw_string_delimiter,
  [306024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14104), 1,
      anon_sym_LPAREN2,
    ACTIONS(14106), 1,
      sym_raw_string_delimiter,
  [306034] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14108), 1,
      anon_sym_LPAREN2,
    ACTIONS(14110), 1,
      sym_raw_string_delimiter,
  [306044] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14112), 1,
      anon_sym_LPAREN2,
    ACTIONS(14114), 1,
      sym_raw_string_delimiter,
  [306054] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14116), 1,
      anon_sym_LPAREN2,
    ACTIONS(14118), 1,
      sym_raw_string_delimiter,
  [306064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14120), 1,
      anon_sym_LPAREN2,
    ACTIONS(14122), 1,
      sym_raw_string_delimiter,
  [306074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14124), 1,
      anon_sym_LPAREN2,
    ACTIONS(14126), 1,
      sym_raw_string_delimiter,
  [306084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14128), 1,
      anon_sym_LPAREN2,
    ACTIONS(14130), 1,
      sym_raw_string_delimiter,
  [306094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14132), 1,
      anon_sym_LPAREN2,
    ACTIONS(14134), 1,
      sym_raw_string_delimiter,
  [306104] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14136), 1,
      anon_sym_LPAREN2,
    ACTIONS(14138), 1,
      sym_raw_string_delimiter,
  [306114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8784), 1,
      anon_sym_LPAREN2,
    STATE(9302), 1,
      sym_argument_list,
  [306124] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      anon_sym_LBRACE,
    STATE(149), 1,
      sym_compound_statement,
  [306134] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13228), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [306142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13864), 1,
      sym_identifier,
    STATE(8064), 1,
      sym_attribute,
  [306152] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14140), 1,
      sym_raw_string_delimiter,
  [306159] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14142), 1,
      anon_sym_SEMI,
  [306166] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14144), 1,
      aux_sym_preproc_if_token2,
  [306173] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9464), 1,
      anon_sym_COLON,
  [306180] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9444), 1,
      anon_sym_COLON,
  [306187] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9450), 1,
      anon_sym_COLON,
  [306194] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13958), 1,
      anon_sym_RBRACE,
  [306201] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4964), 1,
      anon_sym_SEMI,
  [306208] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11633), 1,
      anon_sym_RBRACE,
  [306215] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14146), 1,
      anon_sym_RPAREN,
  [306222] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14148), 1,
      anon_sym_SEMI,
  [306229] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14150), 1,
      anon_sym_RPAREN,
  [306236] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14152), 1,
      anon_sym_RBRACE,
  [306243] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9538), 1,
      anon_sym_COLON,
  [306250] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14154), 1,
      sym_identifier,
  [306257] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14156), 1,
      anon_sym_COLON,
  [306264] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14158), 1,
      anon_sym_DQUOTE,
  [306271] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14160), 1,
      anon_sym_LBRACE,
  [306278] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14162), 1,
      anon_sym_DQUOTE,
  [306285] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14164), 1,
      anon_sym_SEMI,
  [306292] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14166), 1,
      aux_sym_preproc_if_token2,
  [306299] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14168), 1,
      anon_sym_LBRACE,
  [306306] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14170), 1,
      anon_sym_RPAREN,
  [306313] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9428), 1,
      anon_sym_SEMI,
  [306320] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14172), 1,
      sym_identifier,
  [306327] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14174), 1,
      anon_sym_RPAREN,
  [306334] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14176), 1,
      sym_raw_string_delimiter,
  [306341] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14178), 1,
      anon_sym_RPAREN,
  [306348] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14180), 1,
      aux_sym_preproc_if_token2,
  [306355] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14182), 1,
      anon_sym_LPAREN2,
  [306362] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12146), 1,
      anon_sym_COMMA,
  [306369] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14184), 1,
      anon_sym_SEMI,
  [306376] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14186), 1,
      anon_sym_SEMI,
  [306383] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14188), 1,
      anon_sym_STAR,
  [306390] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14190), 1,
      aux_sym_preproc_include_token2,
  [306397] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14192), 1,
      anon_sym_SEMI,
  [306404] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12691), 1,
      anon_sym_SEMI,
  [306411] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14194), 1,
      anon_sym_RPAREN,
  [306418] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14196), 1,
      anon_sym_RPAREN,
  [306425] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4757), 1,
      anon_sym_DOT_DOT_DOT,
  [306432] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9504), 1,
      anon_sym_RPAREN,
  [306439] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14198), 1,
      anon_sym_STAR,
  [306446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14200), 1,
      anon_sym_STAR,
  [306453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14202), 1,
      aux_sym_preproc_if_token2,
  [306460] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9622), 1,
      anon_sym_RPAREN,
  [306467] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14204), 1,
      anon_sym_RBRACE,
  [306474] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14206), 1,
      sym_identifier,
  [306481] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14208), 1,
      aux_sym_preproc_if_token2,
  [306488] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13962), 1,
      anon_sym_RBRACE,
  [306495] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14210), 1,
      anon_sym_SEMI,
  [306502] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14212), 1,
      anon_sym_SEMI,
  [306509] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14214), 1,
      anon_sym_SEMI,
  [306516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11645), 1,
      anon_sym_RBRACE,
  [306523] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14216), 1,
      anon_sym_DQUOTE,
  [306530] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14218), 1,
      anon_sym_SEMI,
  [306537] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14220), 1,
      anon_sym_RPAREN,
  [306544] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14222), 1,
      anon_sym_SEMI,
  [306551] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6389), 1,
      anon_sym_SEMI,
  [306558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14224), 1,
      anon_sym_DOT_DOT_DOT,
  [306565] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14227), 1,
      anon_sym_RPAREN,
  [306572] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14229), 1,
      aux_sym_preproc_include_token2,
  [306579] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14231), 1,
      anon_sym_RPAREN,
  [306586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14233), 1,
      anon_sym_DOT_DOT_DOT,
  [306593] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14235), 1,
      sym_identifier,
  [306600] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14237), 1,
      sym_identifier,
  [306607] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14239), 1,
      aux_sym_preproc_if_token2,
  [306614] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13033), 1,
      aux_sym_preproc_include_token2,
  [306621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4724), 1,
      anon_sym_DOT_DOT_DOT,
  [306628] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14241), 1,
      aux_sym_preproc_if_token2,
  [306635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14243), 1,
      anon_sym_LPAREN2,
  [306642] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14245), 1,
      anon_sym_LPAREN2,
  [306649] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14247), 1,
      aux_sym_preproc_include_token2,
  [306656] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14249), 1,
      anon_sym_STAR,
  [306663] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14251), 1,
      sym_identifier,
  [306670] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14253), 1,
      anon_sym_LPAREN2,
  [306677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14255), 1,
      anon_sym_RBRACE,
  [306684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4692), 1,
      anon_sym_DOT_DOT_DOT,
  [306691] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14257), 1,
      sym_auto,
  [306698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
  [306705] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9420), 1,
      anon_sym_RPAREN,
  [306712] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14259), 1,
      anon_sym_STAR,
  [306719] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9524), 1,
      anon_sym_COLON,
  [306726] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14261), 1,
      sym_auto,
  [306733] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4695), 1,
      anon_sym_DOT_DOT_DOT,
  [306740] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9432), 1,
      anon_sym_SEMI,
  [306747] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14263), 1,
      anon_sym_RPAREN,
  [306754] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14265), 1,
      anon_sym_SEMI,
  [306761] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14267), 1,
      anon_sym_SEMI,
  [306768] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14269), 1,
      anon_sym_SEMI,
  [306775] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4698), 1,
      anon_sym_DOT_DOT_DOT,
  [306782] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14271), 1,
      anon_sym_RPAREN,
  [306789] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14273), 1,
      anon_sym_RPAREN,
  [306796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14275), 1,
      anon_sym_SEMI,
  [306803] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14277), 1,
      anon_sym_LPAREN2,
  [306810] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14279), 1,
      anon_sym_DQUOTE,
  [306817] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14281), 1,
      sym_identifier,
  [306824] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14283), 1,
      aux_sym_preproc_if_token2,
  [306831] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9584), 1,
      anon_sym_RPAREN,
  [306838] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14285), 1,
      aux_sym_preproc_if_token2,
  [306845] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4705), 1,
      anon_sym_DOT_DOT_DOT,
  [306852] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14287), 1,
      anon_sym_COLON,
  [306859] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11674), 1,
      anon_sym_RBRACE,
  [306866] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14289), 1,
      aux_sym_preproc_include_token2,
  [306873] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13970), 1,
      anon_sym_RBRACE,
  [306880] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14291), 1,
      anon_sym_LPAREN2,
  [306887] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4708), 1,
      anon_sym_DOT_DOT_DOT,
  [306894] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14293), 1,
      anon_sym_SEMI,
  [306901] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12727), 1,
      anon_sym_SEMI,
  [306908] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8388), 1,
      sym_identifier,
  [306915] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14295), 1,
      sym_identifier,
  [306922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14297), 1,
      ts_builtin_sym_end,
  [306929] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14299), 1,
      anon_sym_SEMI,
  [306936] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14301), 1,
      anon_sym_RPAREN,
  [306943] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14303), 1,
      anon_sym_RPAREN,
  [306950] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14305), 1,
      sym_identifier,
  [306957] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4711), 1,
      anon_sym_DOT_DOT_DOT,
  [306964] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14307), 1,
      anon_sym_RPAREN,
  [306971] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7673), 1,
      anon_sym_RPAREN,
  [306978] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14309), 1,
      anon_sym_RPAREN,
  [306985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12080), 1,
      anon_sym_SEMI,
  [306992] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4716), 1,
      anon_sym_DOT_DOT_DOT,
  [306999] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14311), 1,
      anon_sym_RPAREN,
  [307006] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13974), 1,
      anon_sym_RBRACE,
  [307013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14313), 1,
      aux_sym_preproc_if_token2,
  [307020] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14315), 1,
      anon_sym_RPAREN,
  [307027] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14317), 1,
      anon_sym_SEMI,
  [307034] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4721), 1,
      anon_sym_DOT_DOT_DOT,
  [307041] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14319), 1,
      sym_auto,
  [307048] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14321), 1,
      anon_sym_RPAREN,
  [307055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14323), 1,
      anon_sym_RPAREN,
  [307062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14325), 1,
      anon_sym_SEMI,
  [307069] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14327), 1,
      anon_sym_RPAREN,
  [307076] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14329), 1,
      anon_sym_SEMI,
  [307083] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14331), 1,
      sym_identifier,
  [307090] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14333), 1,
      anon_sym_SEMI,
  [307097] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14335), 1,
      aux_sym_preproc_if_token2,
  [307104] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13976), 1,
      anon_sym_RBRACE,
  [307111] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4744), 1,
      anon_sym_DOT_DOT_DOT,
  [307118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4727), 1,
      anon_sym_DOT_DOT_DOT,
  [307125] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14337), 1,
      anon_sym_RPAREN,
  [307132] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14339), 1,
      anon_sym_RPAREN,
  [307139] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14341), 1,
      sym_raw_string_delimiter,
  [307146] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14343), 1,
      aux_sym_preproc_include_token2,
  [307153] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12741), 1,
      anon_sym_SEMI,
  [307160] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14345), 1,
      anon_sym_SEMI,
  [307167] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14347), 1,
      anon_sym_DQUOTE,
  [307174] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14349), 1,
      anon_sym_SEMI,
  [307181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9478), 1,
      anon_sym_SEMI,
  [307188] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14351), 1,
      sym_identifier,
  [307195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6387), 1,
      anon_sym_SEMI,
  [307202] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14353), 1,
      anon_sym_RPAREN,
  [307209] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14355), 1,
      anon_sym_RPAREN,
  [307216] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14357), 1,
      anon_sym_DQUOTE,
  [307223] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14359), 1,
      anon_sym_SEMI,
  [307230] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14361), 1,
      anon_sym_SEMI,
  [307237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14363), 1,
      anon_sym_RPAREN,
  [307244] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14365), 1,
      anon_sym_RPAREN,
  [307251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14367), 1,
      anon_sym_LPAREN2,
  [307258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14369), 1,
      anon_sym_SEMI,
  [307265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14371), 1,
      sym_identifier,
  [307272] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14373), 1,
      anon_sym_SEMI,
  [307279] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14375), 1,
      anon_sym_RPAREN,
  [307286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14377), 1,
      anon_sym_RPAREN,
  [307293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13978), 1,
      anon_sym_RBRACE,
  [307300] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14379), 1,
      sym_identifier,
  [307307] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9446), 1,
      anon_sym_SEMI,
  [307314] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14381), 1,
      sym_auto,
  [307321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14383), 1,
      anon_sym_RPAREN,
  [307328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14385), 1,
      anon_sym_RPAREN,
  [307335] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14387), 1,
      aux_sym_preproc_if_token2,
  [307342] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14389), 1,
      anon_sym_STAR,
  [307349] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14391), 1,
      anon_sym_RPAREN,
  [307356] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14393), 1,
      anon_sym_RPAREN,
  [307363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14395), 1,
      anon_sym_SEMI,
  [307370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14397), 1,
      sym_auto,
  [307377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14399), 1,
      anon_sym_RPAREN,
  [307384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13982), 1,
      anon_sym_RBRACE,
  [307391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9458), 1,
      anon_sym_COLON,
  [307398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14401), 1,
      anon_sym_DQUOTE,
  [307405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14403), 1,
      anon_sym_RPAREN,
  [307412] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9418), 1,
      anon_sym_COLON,
  [307419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14405), 1,
      aux_sym_preproc_if_token2,
  [307426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14407), 1,
      anon_sym_RPAREN,
  [307433] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14409), 1,
      anon_sym_SEMI,
  [307440] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5016), 1,
      anon_sym_SEMI,
  [307447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14411), 1,
      anon_sym_LPAREN2,
  [307454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14413), 1,
      anon_sym_SEMI,
  [307461] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14415), 1,
      anon_sym_STAR,
  [307468] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14417), 1,
      sym_identifier,
  [307475] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9638), 1,
      anon_sym_RPAREN,
  [307482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14419), 1,
      anon_sym_RPAREN,
  [307489] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14421), 1,
      anon_sym_RPAREN,
  [307496] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14423), 1,
      anon_sym_RPAREN,
  [307503] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14425), 1,
      sym_identifier,
  [307510] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14427), 1,
      anon_sym_RPAREN,
  [307517] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14429), 1,
      anon_sym_LPAREN2,
  [307524] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14431), 1,
      anon_sym_SEMI,
  [307531] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12084), 1,
      anon_sym_SEMI,
  [307538] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14433), 1,
      sym_identifier,
  [307545] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14435), 1,
      anon_sym_RPAREN,
  [307552] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14437), 1,
      anon_sym_SEMI,
  [307559] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14439), 1,
      anon_sym_SEMI,
  [307566] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14441), 1,
      anon_sym_LPAREN2,
  [307573] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14443), 1,
      anon_sym_SEMI,
  [307580] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14445), 1,
      anon_sym_SEMI,
  [307587] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14447), 1,
      anon_sym_RPAREN,
  [307594] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14449), 1,
      anon_sym_RPAREN,
  [307601] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14451), 1,
      anon_sym_DQUOTE,
  [307608] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14453), 1,
      anon_sym_DQUOTE,
  [307615] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14455), 1,
      sym_identifier,
  [307622] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13980), 1,
      anon_sym_RBRACE,
  [307629] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10680), 1,
      aux_sym_preproc_include_token2,
  [307636] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14457), 1,
      anon_sym_SEMI,
  [307643] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14459), 1,
      anon_sym_DQUOTE,
  [307650] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14461), 1,
      anon_sym_RPAREN,
  [307657] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14463), 1,
      anon_sym_RPAREN,
  [307664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14465), 1,
      sym_raw_string_delimiter,
  [307671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14467), 1,
      anon_sym_DQUOTE,
  [307678] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14469), 1,
      sym_identifier,
  [307685] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14471), 1,
      anon_sym_COLON,
  [307692] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14473), 1,
      sym_identifier,
  [307699] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14475), 1,
      anon_sym_SEMI,
  [307706] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14477), 1,
      sym_identifier,
  [307713] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14479), 1,
      sym_identifier,
  [307720] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_COMMA,
  [307727] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14483), 1,
      anon_sym_STAR,
  [307734] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14485), 1,
      sym_auto,
  [307741] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14487), 1,
      anon_sym_LPAREN2,
  [307748] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8161), 1,
      sym_identifier,
  [307755] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13912), 1,
      anon_sym_RBRACE,
  [307762] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12041), 1,
      anon_sym_SEMI,
  [307769] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14489), 1,
      anon_sym_COLON,
  [307776] = 2,
    ACTIONS(6165), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(10599), 1,
      sym_comment,
  [307783] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14491), 1,
      anon_sym_SEMI,
  [307790] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14493), 1,
      sym_identifier,
  [307797] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9679), 1,
      anon_sym_RPAREN,
  [307804] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14495), 1,
      anon_sym_RPAREN,
  [307811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9508), 1,
      anon_sym_COLON,
  [307818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9349), 1,
      anon_sym_RBRACE,
  [307825] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14497), 1,
      anon_sym_LPAREN2,
  [307832] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14499), 1,
      anon_sym_COLON,
  [307839] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14501), 1,
      anon_sym_RPAREN,
  [307846] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14503), 1,
      anon_sym_SEMI,
  [307853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14505), 1,
      aux_sym_preproc_if_token2,
  [307860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_DASH,
  [307867] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14507), 1,
      sym_identifier,
  [307874] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9662), 1,
      anon_sym_RPAREN,
  [307881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14509), 1,
      anon_sym_SEMI,
  [307888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_PLUS,
  [307895] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14511), 1,
      aux_sym_preproc_if_token2,
  [307902] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_STAR,
  [307909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14513), 1,
      anon_sym_RPAREN,
  [307916] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14515), 1,
      anon_sym_SLASH,
  [307923] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14517), 1,
      anon_sym_SEMI,
  [307930] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14519), 1,
      anon_sym_SEMI,
  [307937] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11686), 1,
      anon_sym_RBRACE,
  [307944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14521), 1,
      anon_sym_DQUOTE,
  [307951] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_PERCENT,
  [307958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14523), 1,
      aux_sym_preproc_if_token2,
  [307965] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14525), 1,
      aux_sym_preproc_if_token2,
  [307972] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14527), 1,
      sym_identifier,
  [307979] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14529), 1,
      anon_sym_RPAREN,
  [307986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14531), 1,
      anon_sym_RPAREN,
  [307993] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14533), 1,
      anon_sym_DQUOTE,
  [308000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14535), 1,
      anon_sym_DQUOTE,
  [308007] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14537), 1,
      anon_sym_SEMI,
  [308014] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14539), 1,
      anon_sym_RPAREN,
  [308021] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14541), 1,
      sym_raw_string_delimiter,
  [308028] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14543), 1,
      anon_sym_DQUOTE,
  [308035] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14545), 1,
      sym_identifier,
  [308042] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_PIPE_PIPE,
  [308049] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14547), 1,
      anon_sym_RPAREN,
  [308056] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14549), 1,
      anon_sym_SEMI,
  [308063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14551), 1,
      anon_sym_SEMI,
  [308070] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14553), 1,
      anon_sym_SEMI,
  [308077] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14555), 1,
      anon_sym_SEMI,
  [308084] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14557), 1,
      anon_sym_STAR,
  [308091] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10831), 1,
      aux_sym_preproc_include_token2,
  [308098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14559), 1,
      anon_sym_RPAREN,
  [308105] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14561), 1,
      aux_sym_preproc_include_token2,
  [308112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14563), 1,
      anon_sym_SEMI,
  [308119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_AMP_AMP,
  [308126] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14565), 1,
      anon_sym_SEMI,
  [308133] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14567), 1,
      anon_sym_STAR,
  [308140] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14569), 1,
      aux_sym_preproc_if_token2,
  [308147] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14571), 1,
      sym_identifier,
  [308154] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14573), 1,
      sym_identifier,
  [308161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6413), 1,
      anon_sym_SEMI,
  [308168] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14575), 1,
      anon_sym_RPAREN,
  [308175] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14577), 1,
      sym_identifier,
  [308182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14579), 1,
      anon_sym_LPAREN2,
  [308189] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14581), 1,
      anon_sym_DQUOTE,
  [308196] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14583), 1,
      anon_sym_COLON,
  [308203] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14585), 1,
      aux_sym_preproc_if_token2,
  [308210] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14587), 1,
      sym_identifier,
  [308217] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14589), 1,
      aux_sym_preproc_if_token2,
  [308224] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14591), 1,
      sym_identifier,
  [308231] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14593), 1,
      aux_sym_preproc_include_token2,
  [308238] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14595), 1,
      sym_identifier,
  [308245] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14597), 1,
      anon_sym_SEMI,
  [308252] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14599), 1,
      anon_sym_RPAREN,
  [308259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12076), 1,
      anon_sym_SEMI,
  [308266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14601), 1,
      anon_sym_SEMI,
  [308273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14603), 1,
      anon_sym_COLON,
  [308280] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14605), 1,
      sym_identifier,
  [308287] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14607), 1,
      aux_sym_preproc_if_token2,
  [308294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14609), 1,
      anon_sym_RPAREN,
  [308301] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14611), 1,
      sym_identifier,
  [308308] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14613), 1,
      sym_identifier,
  [308315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14615), 1,
      anon_sym_RPAREN,
  [308322] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14617), 1,
      anon_sym_LPAREN2,
  [308329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14619), 1,
      anon_sym_RPAREN,
  [308336] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14621), 1,
      aux_sym_preproc_include_token2,
  [308343] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14623), 1,
      anon_sym_DQUOTE,
  [308350] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14625), 1,
      anon_sym_RPAREN,
  [308357] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14627), 1,
      sym_raw_string_delimiter,
  [308364] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9644), 1,
      anon_sym_RPAREN,
  [308371] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14629), 1,
      aux_sym_preproc_if_token2,
  [308378] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14631), 1,
      anon_sym_DQUOTE,
  [308385] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14633), 1,
      anon_sym_SEMI,
  [308392] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10945), 1,
      aux_sym_preproc_include_token2,
  [308399] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14635), 1,
      anon_sym_RPAREN,
  [308406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14637), 1,
      anon_sym_SEMI,
  [308413] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14639), 1,
      sym_raw_string_delimiter,
  [308420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14641), 1,
      anon_sym_SEMI,
  [308427] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9096), 1,
      anon_sym_RBRACE,
  [308434] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14643), 1,
      anon_sym_LPAREN2,
  [308441] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14645), 1,
      anon_sym_LPAREN2,
  [308448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14647), 1,
      sym_identifier,
  [308455] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14649), 1,
      sym_identifier,
  [308462] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14651), 1,
      anon_sym_SEMI,
  [308469] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14653), 1,
      sym_identifier,
  [308476] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14655), 1,
      anon_sym_RPAREN,
  [308483] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_PIPE,
  [308490] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14657), 1,
      sym_identifier,
  [308497] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14659), 1,
      anon_sym_RPAREN,
  [308504] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_CARET,
  [308511] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14661), 1,
      sym_raw_string_delimiter,
  [308518] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_AMP,
  [308525] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14663), 1,
      anon_sym_SEMI,
  [308532] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6376), 1,
      anon_sym_SEMI,
  [308539] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14665), 1,
      anon_sym_RPAREN,
  [308546] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14667), 1,
      sym_identifier,
  [308553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14669), 1,
      anon_sym_RPAREN,
  [308560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14671), 1,
      anon_sym_SEMI,
  [308567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14673), 1,
      anon_sym_SEMI,
  [308574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14675), 1,
      anon_sym_LPAREN2,
  [308581] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14677), 1,
      anon_sym_RPAREN,
  [308588] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14679), 1,
      sym_identifier,
  [308595] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12106), 1,
      anon_sym_SEMI,
  [308602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14681), 1,
      anon_sym_RPAREN,
  [308609] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14683), 1,
      aux_sym_preproc_if_token2,
  [308616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13171), 1,
      anon_sym_RPAREN,
  [308623] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14685), 1,
      sym_raw_string_delimiter,
  [308630] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14687), 1,
      anon_sym_SEMI,
  [308637] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14689), 1,
      anon_sym_RPAREN,
  [308644] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14691), 1,
      aux_sym_preproc_if_token2,
  [308651] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_EQ_EQ,
  [308658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14693), 1,
      anon_sym_LPAREN2,
  [308665] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14695), 1,
      anon_sym_RPAREN,
  [308672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14697), 1,
      anon_sym_DQUOTE,
  [308679] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14699), 1,
      sym_raw_string_delimiter,
  [308686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14701), 1,
      anon_sym_RPAREN,
  [308693] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14703), 1,
      sym_identifier,
  [308700] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9498), 1,
      anon_sym_RPAREN,
  [308707] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_BANG_EQ,
  [308714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14705), 1,
      anon_sym_LPAREN2,
  [308721] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14707), 1,
      anon_sym_RPAREN,
  [308728] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14709), 1,
      sym_raw_string_delimiter,
  [308735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14711), 1,
      anon_sym_SEMI,
  [308742] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9707), 1,
      anon_sym_RPAREN,
  [308749] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9540), 1,
      anon_sym_RPAREN,
  [308756] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_GT,
  [308763] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14713), 1,
      anon_sym_LPAREN2,
  [308770] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14715), 1,
      anon_sym_RPAREN,
  [308777] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14717), 1,
      sym_raw_string_delimiter,
  [308784] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14719), 1,
      aux_sym_preproc_if_token2,
  [308791] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14010), 1,
      anon_sym_RBRACE,
  [308798] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14721), 1,
      anon_sym_RPAREN,
  [308805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14723), 1,
      sym_raw_string_delimiter,
  [308812] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14725), 1,
      aux_sym_preproc_if_token2,
  [308819] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14727), 1,
      anon_sym_SEMI,
  [308826] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14729), 1,
      anon_sym_RPAREN,
  [308833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14731), 1,
      sym_raw_string_delimiter,
  [308840] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14733), 1,
      anon_sym_RPAREN,
  [308847] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14735), 1,
      sym_raw_string_delimiter,
  [308854] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14737), 1,
      anon_sym_RPAREN,
  [308861] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14739), 1,
      sym_raw_string_delimiter,
  [308868] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14741), 1,
      anon_sym_RPAREN,
  [308875] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14743), 1,
      sym_raw_string_delimiter,
  [308882] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14745), 1,
      anon_sym_RPAREN,
  [308889] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14747), 1,
      sym_raw_string_delimiter,
  [308896] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14749), 1,
      anon_sym_RPAREN,
  [308903] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14751), 1,
      anon_sym_SEMI,
  [308910] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14753), 1,
      anon_sym_RPAREN,
  [308917] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14755), 1,
      sym_raw_string_delimiter,
  [308924] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14757), 1,
      anon_sym_RPAREN,
  [308931] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14759), 1,
      sym_raw_string_delimiter,
  [308938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14761), 1,
      anon_sym_RPAREN,
  [308945] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14763), 1,
      anon_sym_SEMI,
  [308952] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14765), 1,
      anon_sym_SEMI,
  [308959] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14767), 1,
      anon_sym_LPAREN2,
  [308966] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14769), 1,
      aux_sym_preproc_if_token2,
  [308973] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14771), 1,
      anon_sym_LPAREN2,
  [308980] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14773), 1,
      anon_sym_LPAREN2,
  [308987] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14775), 1,
      anon_sym_LPAREN2,
  [308994] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14777), 1,
      anon_sym_DQUOTE,
  [309001] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14779), 1,
      anon_sym_SEMI,
  [309008] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14781), 1,
      anon_sym_LPAREN2,
  [309015] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14783), 1,
      anon_sym_DQUOTE,
  [309022] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14785), 1,
      anon_sym_LPAREN2,
  [309029] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9362), 1,
      anon_sym_RBRACE,
  [309036] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14787), 1,
      anon_sym_STAR,
  [309043] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14789), 1,
      anon_sym_LPAREN2,
  [309050] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9685), 1,
      anon_sym_RPAREN,
  [309057] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14791), 1,
      anon_sym_RPAREN,
  [309064] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14793), 1,
      anon_sym_SEMI,
  [309071] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14795), 1,
      anon_sym_DQUOTE,
  [309078] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13438), 1,
      aux_sym_preproc_include_token2,
  [309085] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14797), 1,
      anon_sym_DQUOTE,
  [309092] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14799), 1,
      anon_sym_LPAREN2,
  [309099] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14801), 1,
      sym_identifier,
  [309106] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14803), 1,
      sym_identifier,
  [309113] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14805), 1,
      aux_sym_preproc_if_token2,
  [309120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14807), 1,
      anon_sym_STAR,
  [309127] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_GT_EQ,
  [309134] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14809), 1,
      anon_sym_while,
  [309141] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14811), 1,
      anon_sym_SEMI,
  [309148] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14813), 1,
      anon_sym_LPAREN2,
  [309155] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14815), 1,
      anon_sym_RPAREN,
  [309162] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14817), 1,
      anon_sym_RPAREN,
  [309169] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14819), 1,
      anon_sym_RPAREN,
  [309176] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14821), 1,
      anon_sym_SEMI,
  [309183] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14823), 1,
      anon_sym_EQ,
  [309190] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14825), 1,
      sym_raw_string_content,
  [309197] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14827), 1,
      anon_sym_RPAREN,
  [309204] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14829), 1,
      anon_sym_SEMI,
  [309211] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14831), 1,
      aux_sym_preproc_include_token2,
  [309218] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14833), 1,
      anon_sym_STAR,
  [309225] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14835), 1,
      sym_this,
  [309232] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14837), 1,
      aux_sym_preproc_if_token2,
  [309239] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14839), 1,
      anon_sym_SEMI,
  [309246] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9500), 1,
      anon_sym_RPAREN,
  [309253] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14841), 1,
      anon_sym_RPAREN,
  [309260] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14843), 1,
      anon_sym_RPAREN,
  [309267] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9526), 1,
      anon_sym_COLON,
  [309274] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14845), 1,
      sym_identifier,
  [309281] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14847), 1,
      anon_sym_SEMI,
  [309288] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14849), 1,
      sym_identifier,
  [309295] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14851), 1,
      anon_sym_COMMA,
  [309302] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14853), 1,
      anon_sym_RPAREN,
  [309309] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14855), 1,
      anon_sym_RPAREN,
  [309316] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14857), 1,
      anon_sym_SEMI,
  [309323] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9506), 1,
      anon_sym_COLON,
  [309330] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14859), 1,
      anon_sym_RPAREN,
  [309337] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14861), 1,
      anon_sym_RPAREN,
  [309344] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14863), 1,
      anon_sym_DQUOTE,
  [309351] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14865), 1,
      anon_sym_RPAREN,
  [309358] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_LT_EQ,
  [309365] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_LT,
  [309372] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_LT_LT,
  [309379] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6419), 1,
      anon_sym_SEMI,
  [309386] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_GT_GT,
  [309393] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14867), 1,
      anon_sym_RPAREN,
  [309400] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14869), 1,
      anon_sym_RPAREN,
  [309407] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14871), 1,
      anon_sym_RPAREN,
  [309414] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14873), 1,
      anon_sym_SEMI,
  [309421] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14875), 1,
      anon_sym_RPAREN,
  [309428] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14877), 1,
      anon_sym_RBRACK,
  [309435] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14879), 1,
      anon_sym_COLON,
  [309442] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14881), 1,
      anon_sym_LPAREN2,
  [309449] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14883), 1,
      anon_sym_RPAREN,
  [309456] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14885), 1,
      sym_identifier,
  [309463] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14887), 1,
      anon_sym_RPAREN,
  [309470] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14889), 1,
      anon_sym_RPAREN,
  [309477] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7729), 1,
      anon_sym_RPAREN,
  [309484] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14891), 1,
      anon_sym_DQUOTE,
  [309491] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14893), 1,
      anon_sym_DQUOTE,
  [309498] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_EQ,
  [309505] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14895), 1,
      sym_identifier,
  [309512] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14897), 1,
      anon_sym_RPAREN,
  [309519] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14899), 1,
      anon_sym_LPAREN2,
  [309526] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14901), 1,
      anon_sym_RPAREN,
  [309533] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14903), 1,
      anon_sym_RPAREN,
  [309540] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9372), 1,
      anon_sym_SEMI,
  [309547] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14905), 1,
      aux_sym_preproc_if_token2,
  [309554] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14907), 1,
      anon_sym_SEMI,
  [309561] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9719), 1,
      anon_sym_RPAREN,
  [309568] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14909), 1,
      anon_sym_COLON,
  [309575] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14911), 1,
      anon_sym_RPAREN,
  [309582] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14913), 1,
      anon_sym_SEMI,
  [309589] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14915), 1,
      anon_sym_RPAREN,
  [309596] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14917), 1,
      anon_sym_RPAREN,
  [309603] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14919), 1,
      anon_sym_EQ,
  [309610] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_STAR_EQ,
  [309617] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_SLASH_EQ,
  [309624] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9552), 1,
      anon_sym_RPAREN,
  [309631] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9368), 1,
      anon_sym_RBRACE,
  [309638] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14921), 1,
      anon_sym_SEMI,
  [309645] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_PERCENT_EQ,
  [309652] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14923), 1,
      anon_sym_LPAREN2,
  [309659] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9408), 1,
      anon_sym_COLON,
  [309666] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14925), 1,
      anon_sym_DQUOTE,
  [309673] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14927), 1,
      anon_sym_SEMI,
  [309680] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14929), 1,
      anon_sym_RPAREN,
  [309687] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9488), 1,
      anon_sym_SEMI,
  [309694] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14931), 1,
      anon_sym_RPAREN,
  [309701] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14933), 1,
      anon_sym_DQUOTE,
  [309708] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8403), 1,
      sym_identifier,
  [309715] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14935), 1,
      anon_sym_DQUOTE,
  [309722] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14937), 1,
      anon_sym_SEMI,
  [309729] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14939), 1,
      sym_identifier,
  [309736] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12112), 1,
      anon_sym_SEMI,
  [309743] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14941), 1,
      aux_sym_preproc_if_token2,
  [309750] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_PLUS_EQ,
  [309757] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14943), 1,
      anon_sym_SEMI,
  [309764] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14945), 1,
      anon_sym_DQUOTE,
  [309771] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_DASH_EQ,
  [309778] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_LT_LT_EQ,
  [309785] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14947), 1,
      anon_sym_RPAREN,
  [309792] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14949), 1,
      anon_sym_SEMI,
  [309799] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13627), 1,
      anon_sym_SEMI,
  [309806] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_GT_GT_EQ,
  [309813] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9454), 1,
      anon_sym_SEMI,
  [309820] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14951), 1,
      anon_sym_COMMA,
  [309827] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14953), 1,
      anon_sym_RPAREN,
  [309834] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12697), 1,
      anon_sym_SEMI,
  [309841] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9094), 1,
      anon_sym_SEMI,
  [309848] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14955), 1,
      anon_sym_LPAREN2,
  [309855] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9544), 1,
      anon_sym_RPAREN,
  [309862] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_AMP_EQ,
  [309869] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14957), 1,
      sym_identifier,
  [309876] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9281), 1,
      anon_sym_RBRACE,
  [309883] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14959), 1,
      aux_sym_preproc_if_token2,
  [309890] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14961), 1,
      anon_sym_RPAREN,
  [309897] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14963), 1,
      anon_sym_RPAREN,
  [309904] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14965), 1,
      aux_sym_preproc_if_token2,
  [309911] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8240), 1,
      sym_identifier,
  [309918] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11623), 1,
      anon_sym_RBRACE,
  [309925] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11613), 1,
      anon_sym_RBRACE,
  [309932] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_CARET_EQ,
  [309939] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14967), 1,
      anon_sym_SEMI,
  [309946] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14969), 1,
      aux_sym_preproc_if_token2,
  [309953] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_PIPE_EQ,
  [309960] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_or,
  [309967] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14971), 1,
      anon_sym_RPAREN,
  [309974] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11682), 1,
      anon_sym_RBRACE,
  [309981] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(14973), 1,
      aux_sym_preproc_include_token2,
  [309988] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14975), 1,
      sym_raw_string_content,
  [309995] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14977), 1,
      anon_sym_SEMI,
  [310002] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14979), 1,
      sym_identifier,
  [310009] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9484), 1,
      anon_sym_SEMI,
  [310016] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14981), 1,
      anon_sym_RPAREN,
  [310023] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9358), 1,
      anon_sym_RBRACE,
  [310030] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14983), 1,
      aux_sym_preproc_if_token2,
  [310037] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9705), 1,
      anon_sym_RPAREN,
  [310044] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14985), 1,
      anon_sym_RPAREN,
  [310051] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14987), 1,
      anon_sym_DQUOTE,
  [310058] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14989), 1,
      anon_sym_SEMI,
  [310065] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14991), 1,
      anon_sym_DQUOTE,
  [310072] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14993), 1,
      anon_sym_STAR,
  [310079] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14995), 1,
      sym_identifier,
  [310086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14997), 1,
      aux_sym_preproc_if_token2,
  [310093] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14999), 1,
      anon_sym_RPAREN,
  [310100] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11627), 1,
      anon_sym_RBRACE,
  [310107] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15001), 1,
      anon_sym_RPAREN,
  [310114] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15003), 1,
      aux_sym_preproc_include_token2,
  [310121] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15005), 1,
      anon_sym_SEMI,
  [310128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15007), 1,
      anon_sym_RBRACE,
  [310135] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15009), 1,
      anon_sym_RPAREN,
  [310142] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15011), 1,
      anon_sym_DQUOTE,
  [310149] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15013), 1,
      aux_sym_preproc_if_token2,
  [310156] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15015), 1,
      anon_sym_RBRACE,
  [310163] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9564), 1,
      anon_sym_RPAREN,
  [310170] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15017), 1,
      aux_sym_preproc_if_token2,
  [310177] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9273), 1,
      anon_sym_RBRACE,
  [310184] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15019), 1,
      anon_sym_DQUOTE,
  [310191] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15021), 1,
      sym_identifier,
  [310198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15023), 1,
      sym_identifier,
  [310205] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11631), 1,
      anon_sym_RBRACE,
  [310212] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15025), 1,
      aux_sym_preproc_if_token2,
  [310219] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15027), 1,
      sym_identifier,
  [310226] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15029), 1,
      aux_sym_preproc_include_token2,
  [310233] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15031), 1,
      aux_sym_preproc_if_token2,
  [310240] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15033), 1,
      aux_sym_preproc_include_token2,
  [310247] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11692), 1,
      anon_sym_RBRACE,
  [310254] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15035), 1,
      anon_sym_LPAREN2,
  [310261] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9448), 1,
      anon_sym_SEMI,
  [310268] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8418), 1,
      sym_identifier,
  [310275] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15037), 1,
      anon_sym_RPAREN,
  [310282] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15039), 1,
      anon_sym_RPAREN,
  [310289] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15041), 1,
      anon_sym_RPAREN,
  [310296] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15043), 1,
      anon_sym_STAR,
  [310303] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15045), 1,
      anon_sym_RPAREN,
  [310310] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15047), 1,
      anon_sym_RPAREN,
  [310317] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15049), 1,
      anon_sym_RPAREN,
  [310324] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15051), 1,
      anon_sym_RPAREN,
  [310331] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15053), 1,
      anon_sym_LBRACE,
  [310338] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15055), 1,
      anon_sym_DQUOTE,
  [310345] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15057), 1,
      anon_sym_DQUOTE,
  [310352] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15059), 1,
      anon_sym_RPAREN,
  [310359] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15061), 1,
      anon_sym_while,
  [310366] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15063), 1,
      anon_sym_RPAREN,
  [310373] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6393), 1,
      anon_sym_SEMI,
  [310380] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15065), 1,
      anon_sym_RBRACE,
  [310387] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12839), 1,
      anon_sym_SEMI,
  [310394] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15067), 1,
      anon_sym_RPAREN,
  [310401] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15069), 1,
      anon_sym_LPAREN2,
  [310408] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15071), 1,
      anon_sym_RPAREN,
  [310415] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15073), 1,
      anon_sym_DQUOTE,
  [310422] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15075), 1,
      anon_sym_SEMI,
  [310429] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15077), 1,
      anon_sym_RPAREN,
  [310436] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15079), 1,
      anon_sym_RPAREN,
  [310443] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15081), 1,
      sym_identifier,
  [310450] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15083), 1,
      anon_sym_RPAREN,
  [310457] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15085), 1,
      anon_sym_RPAREN,
  [310464] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15087), 1,
      sym_identifier,
  [310471] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15089), 1,
      sym_identifier,
  [310478] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_and,
  [310485] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_bitor,
  [310492] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15091), 1,
      anon_sym_SEMI,
  [310499] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15093), 1,
      aux_sym_preproc_if_token2,
  [310506] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_xor,
  [310513] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15095), 1,
      anon_sym_LPAREN2,
  [310520] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4919), 1,
      anon_sym_SEMI,
  [310527] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15097), 1,
      anon_sym_LPAREN2,
  [310534] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15099), 1,
      anon_sym_LPAREN2,
  [310541] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15101), 1,
      aux_sym_preproc_if_token2,
  [310548] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_bitand,
  [310555] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15103), 1,
      anon_sym_LPAREN2,
  [310562] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15105), 1,
      anon_sym_SEMI,
  [310569] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15107), 1,
      anon_sym_LPAREN2,
  [310576] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_not_eq,
  [310583] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_DOT_STAR,
  [310590] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15109), 1,
      anon_sym_SEMI,
  [310597] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15111), 1,
      anon_sym_RPAREN,
  [310604] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15113), 1,
      aux_sym_preproc_if_token2,
  [310611] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14481), 1,
      anon_sym_DASH_GT_STAR,
  [310618] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15115), 1,
      anon_sym_RPAREN,
  [310625] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15117), 1,
      anon_sym_while,
  [310632] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12610), 1,
      anon_sym_SEMI,
  [310639] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15119), 1,
      anon_sym_LPAREN2,
  [310646] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15121), 1,
      anon_sym_RPAREN,
  [310653] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15123), 1,
      aux_sym_preproc_include_token2,
  [310660] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15125), 1,
      sym_auto,
  [310667] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15127), 1,
      sym_auto,
  [310674] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15129), 1,
      anon_sym_EQ,
  [310681] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15131), 1,
      sym_raw_string_content,
  [310688] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15133), 1,
      anon_sym_LPAREN2,
  [310695] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15135), 1,
      anon_sym_STAR,
  [310702] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9474), 1,
      anon_sym_COLON,
  [310709] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11621), 1,
      anon_sym_RBRACE,
  [310716] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15137), 1,
      anon_sym_COMMA,
  [310723] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6415), 1,
      anon_sym_SEMI,
  [310730] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15139), 1,
      anon_sym_EQ,
  [310737] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9522), 1,
      anon_sym_COLON,
  [310744] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9536), 1,
      anon_sym_COLON,
  [310751] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15141), 1,
      anon_sym_SEMI,
  [310758] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15143), 1,
      anon_sym_RPAREN,
  [310765] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15145), 1,
      anon_sym_COLON,
  [310772] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15147), 1,
      anon_sym_RPAREN,
  [310779] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15149), 1,
      sym_raw_string_content,
  [310786] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15151), 1,
      anon_sym_LPAREN2,
  [310793] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15153), 1,
      anon_sym_LPAREN2,
  [310800] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15155), 1,
      anon_sym_LPAREN2,
  [310807] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15157), 1,
      aux_sym_preproc_if_token2,
  [310814] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15159), 1,
      anon_sym_LPAREN2,
  [310821] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5663), 1,
      anon_sym_COLON_COLON,
  [310828] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15161), 1,
      anon_sym_SEMI,
  [310835] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15163), 1,
      anon_sym_while,
  [310842] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15165), 1,
      anon_sym_RPAREN,
  [310849] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15167), 1,
      anon_sym_LPAREN2,
  [310856] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15169), 1,
      anon_sym_STAR,
  [310863] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15171), 1,
      sym_identifier,
  [310870] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15173), 1,
      anon_sym_SEMI,
  [310877] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15175), 1,
      anon_sym_EQ,
  [310884] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15177), 1,
      sym_raw_string_content,
  [310891] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15179), 1,
      anon_sym_COMMA,
  [310898] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12417), 1,
      anon_sym_COLON,
  [310905] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12033), 1,
      anon_sym_SEMI,
  [310912] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15181), 1,
      anon_sym_RPAREN,
  [310919] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15183), 1,
      anon_sym_RPAREN,
  [310926] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15185), 1,
      anon_sym_COLON,
  [310933] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15187), 1,
      aux_sym_preproc_if_token2,
  [310940] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15189), 1,
      anon_sym_LPAREN2,
  [310947] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15191), 1,
      anon_sym_LPAREN2,
  [310954] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15193), 1,
      anon_sym_LPAREN2,
  [310961] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15195), 1,
      aux_sym_preproc_include_token2,
  [310968] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15197), 1,
      anon_sym_LPAREN2,
  [310975] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15199), 1,
      anon_sym_SEMI,
  [310982] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15201), 1,
      anon_sym_SEMI,
  [310989] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15203), 1,
      anon_sym_while,
  [310996] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15205), 1,
      anon_sym_LPAREN2,
  [311003] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15207), 1,
      anon_sym_SEMI,
  [311010] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15209), 1,
      anon_sym_RPAREN,
  [311017] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15211), 1,
      anon_sym_EQ,
  [311024] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15213), 1,
      sym_raw_string_content,
  [311031] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15215), 1,
      anon_sym_COMMA,
  [311038] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15217), 1,
      anon_sym_STAR,
  [311045] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15219), 1,
      anon_sym_DQUOTE,
  [311052] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15221), 1,
      anon_sym_SEMI,
  [311059] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15223), 1,
      anon_sym_RPAREN,
  [311066] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15225), 1,
      anon_sym_COLON,
  [311073] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15227), 1,
      aux_sym_preproc_include_token2,
  [311080] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15229), 1,
      anon_sym_LPAREN2,
  [311087] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15231), 1,
      anon_sym_LPAREN2,
  [311094] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15233), 1,
      anon_sym_LPAREN2,
  [311101] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15235), 1,
      anon_sym_RPAREN,
  [311108] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15237), 1,
      anon_sym_LPAREN2,
  [311115] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14034), 1,
      anon_sym_RBRACE,
  [311122] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15239), 1,
      anon_sym_SEMI,
  [311129] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15241), 1,
      anon_sym_LPAREN2,
  [311136] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15243), 1,
      anon_sym_RPAREN,
  [311143] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15245), 1,
      anon_sym_RPAREN,
  [311150] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15247), 1,
      anon_sym_EQ,
  [311157] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15249), 1,
      sym_raw_string_content,
  [311164] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15251), 1,
      anon_sym_COMMA,
  [311171] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15253), 1,
      anon_sym_RPAREN,
  [311178] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13730), 1,
      aux_sym_preproc_include_token2,
  [311185] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6821), 1,
      sym_identifier,
  [311192] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15255), 1,
      anon_sym_RPAREN,
  [311199] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15257), 1,
      anon_sym_COLON,
  [311206] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15259), 1,
      anon_sym_RPAREN,
  [311213] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15261), 1,
      anon_sym_LPAREN2,
  [311220] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15263), 1,
      anon_sym_LPAREN2,
  [311227] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15265), 1,
      anon_sym_LPAREN2,
  [311234] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15267), 1,
      anon_sym_RPAREN,
  [311241] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15269), 1,
      anon_sym_LPAREN2,
  [311248] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15271), 1,
      aux_sym_preproc_if_token2,
  [311255] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15273), 1,
      anon_sym_SEMI,
  [311262] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15275), 1,
      anon_sym_LPAREN2,
  [311269] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15277), 1,
      anon_sym_RPAREN,
  [311276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15279), 1,
      anon_sym_RPAREN,
  [311283] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15281), 1,
      anon_sym_EQ,
  [311290] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15283), 1,
      sym_raw_string_content,
  [311297] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15285), 1,
      anon_sym_COMMA,
  [311304] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15287), 1,
      aux_sym_preproc_if_token2,
  [311311] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15289), 1,
      aux_sym_preproc_include_token2,
  [311318] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11105), 1,
      sym_identifier,
  [311325] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15291), 1,
      anon_sym_RPAREN,
  [311332] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15293), 1,
      anon_sym_COLON,
  [311339] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15295), 1,
      anon_sym_RPAREN,
  [311346] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15297), 1,
      anon_sym_LPAREN2,
  [311353] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15299), 1,
      anon_sym_LPAREN2,
  [311360] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15301), 1,
      anon_sym_LPAREN2,
  [311367] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12614), 1,
      anon_sym_SEMI,
  [311374] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15303), 1,
      anon_sym_LPAREN2,
  [311381] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15305), 1,
      anon_sym_SEMI,
  [311388] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15307), 1,
      anon_sym_LPAREN2,
  [311395] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15309), 1,
      sym_raw_string_delimiter,
  [311402] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15311), 1,
      sym_raw_string_content,
  [311409] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15313), 1,
      anon_sym_COMMA,
  [311416] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15315), 1,
      anon_sym_DQUOTE,
  [311423] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7731), 1,
      anon_sym_RPAREN,
  [311430] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15317), 1,
      anon_sym_RPAREN,
  [311437] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15319), 1,
      anon_sym_COLON,
  [311444] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(10713), 1,
      aux_sym_preproc_include_token2,
  [311451] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15321), 1,
      anon_sym_LPAREN2,
  [311458] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15323), 1,
      anon_sym_LPAREN2,
  [311465] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15325), 1,
      sym_identifier,
  [311472] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15327), 1,
      anon_sym_LPAREN2,
  [311479] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9510), 1,
      anon_sym_SEMI,
  [311486] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15329), 1,
      anon_sym_SEMI,
  [311493] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15331), 1,
      sym_raw_string_content,
  [311500] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15333), 1,
      anon_sym_RPAREN,
  [311507] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15335), 1,
      anon_sym_RPAREN,
  [311514] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15337), 1,
      anon_sym_LPAREN2,
  [311521] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15339), 1,
      anon_sym_LPAREN2,
  [311528] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15341), 1,
      anon_sym_LPAREN2,
  [311535] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15343), 1,
      sym_raw_string_content,
  [311542] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15345), 1,
      anon_sym_RPAREN,
  [311549] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15347), 1,
      anon_sym_LPAREN2,
  [311556] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15349), 1,
      anon_sym_LPAREN2,
  [311563] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15351), 1,
      anon_sym_LPAREN2,
  [311570] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15353), 1,
      sym_raw_string_content,
  [311577] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15355), 1,
      anon_sym_RPAREN,
  [311584] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15357), 1,
      anon_sym_LPAREN2,
  [311591] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15359), 1,
      anon_sym_LPAREN2,
  [311598] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15361), 1,
      anon_sym_LPAREN2,
  [311605] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15363), 1,
      sym_raw_string_content,
  [311612] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15365), 1,
      anon_sym_RPAREN,
  [311619] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15367), 1,
      anon_sym_LPAREN2,
  [311626] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15369), 1,
      sym_raw_string_content,
  [311633] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15371), 1,
      anon_sym_RPAREN,
  [311640] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15373), 1,
      anon_sym_LPAREN2,
  [311647] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15375), 1,
      sym_raw_string_content,
  [311654] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15377), 1,
      anon_sym_RPAREN,
  [311661] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15379), 1,
      sym_raw_string_content,
  [311668] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15381), 1,
      anon_sym_RPAREN,
  [311675] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15383), 1,
      sym_raw_string_content,
  [311682] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15385), 1,
      anon_sym_RPAREN,
  [311689] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15387), 1,
      sym_raw_string_content,
  [311696] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15389), 1,
      anon_sym_RPAREN,
  [311703] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15391), 1,
      sym_raw_string_content,
  [311710] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15393), 1,
      anon_sym_RPAREN,
  [311717] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15395), 1,
      sym_raw_string_content,
  [311724] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15397), 1,
      anon_sym_RPAREN,
  [311731] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15399), 1,
      sym_raw_string_content,
  [311738] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15401), 1,
      anon_sym_RPAREN,
  [311745] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15403), 1,
      sym_raw_string_content,
  [311752] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15405), 1,
      anon_sym_RPAREN,
  [311759] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15407), 1,
      anon_sym_RPAREN,
  [311766] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9687), 1,
      anon_sym_RPAREN,
  [311773] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15409), 1,
      anon_sym_LPAREN2,
  [311780] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15411), 1,
      anon_sym_LPAREN2,
  [311787] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15413), 1,
      sym_identifier,
  [311794] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15415), 1,
      anon_sym_SEMI,
  [311801] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12136), 1,
      anon_sym_EQ,
  [311808] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15417), 1,
      anon_sym_SEMI,
  [311815] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15419), 1,
      anon_sym_DQUOTE,
  [311822] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_RBRACE,
  [311829] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15421), 1,
      anon_sym_RPAREN,
  [311836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15423), 1,
      anon_sym_COLON,
  [311843] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9514), 1,
      anon_sym_SEMI,
  [311850] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15425), 1,
      aux_sym_preproc_if_token2,
  [311857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13716), 1,
      anon_sym_COLON_COLON,
  [311864] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15427), 1,
      sym_identifier,
  [311871] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15429), 1,
      sym_raw_string_content,
  [311878] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9486), 1,
      anon_sym_SEMI,
  [311885] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15431), 1,
      aux_sym_preproc_include_token2,
  [311892] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15433), 1,
      anon_sym_RPAREN,
  [311899] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15435), 1,
      anon_sym_SEMI,
  [311906] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15437), 1,
      anon_sym_SEMI,
  [311913] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15439), 1,
      anon_sym_RPAREN,
  [311920] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14052), 1,
      anon_sym_RBRACE,
  [311927] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15441), 1,
      anon_sym_RPAREN,
  [311934] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15443), 1,
      anon_sym_RPAREN,
  [311941] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15445), 1,
      anon_sym_SEMI,
  [311948] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15447), 1,
      anon_sym_COLON,
  [311955] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15449), 1,
      sym_identifier,
  [311962] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9466), 1,
      anon_sym_RPAREN,
  [311969] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15451), 1,
      anon_sym_RPAREN,
  [311976] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9640), 1,
      anon_sym_RPAREN,
  [311983] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15453), 1,
      anon_sym_SEMI,
  [311990] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15455), 1,
      anon_sym_RPAREN,
  [311997] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15457), 1,
      anon_sym_RPAREN,
  [312004] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15459), 1,
      aux_sym_preproc_if_token2,
  [312011] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15461), 1,
      anon_sym_RPAREN,
  [312018] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9370), 1,
      anon_sym_RPAREN,
  [312025] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15463), 1,
      anon_sym_RPAREN,
  [312032] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15465), 1,
      anon_sym_SEMI,
  [312039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15467), 1,
      sym_auto,
  [312046] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15469), 1,
      anon_sym_RPAREN,
  [312053] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15471), 1,
      anon_sym_LPAREN2,
  [312060] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(13819), 1,
      aux_sym_preproc_include_token2,
  [312067] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15473), 1,
      anon_sym_LPAREN2,
  [312074] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15475), 1,
      anon_sym_SEMI,
  [312081] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15477), 1,
      anon_sym_SEMI,
  [312088] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15479), 1,
      anon_sym_RPAREN,
  [312095] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9528), 1,
      anon_sym_COLON,
  [312102] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15481), 1,
      anon_sym_RBRACK,
  [312109] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15483), 1,
      aux_sym_preproc_include_token2,
  [312116] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15485), 1,
      anon_sym_SEMI,
  [312123] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15487), 1,
      anon_sym_LPAREN2,
  [312130] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15489), 1,
      anon_sym_LPAREN2,
  [312137] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15491), 1,
      sym_identifier,
  [312144] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15493), 1,
      anon_sym_SEMI,
  [312151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9648), 1,
      anon_sym_RPAREN,
  [312158] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7579), 1,
      anon_sym_RPAREN,
  [312165] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15495), 1,
      sym_identifier,
  [312172] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15497), 1,
      sym_raw_string_content,
  [312179] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9476), 1,
      anon_sym_SEMI,
  [312186] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15499), 1,
      sym_identifier,
  [312193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15501), 1,
      anon_sym_RPAREN,
  [312200] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15503), 1,
      anon_sym_RPAREN,
  [312207] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15505), 1,
      anon_sym_LPAREN2,
  [312214] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15507), 1,
      anon_sym_LPAREN2,
  [312221] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15509), 1,
      sym_identifier,
  [312228] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9339), 1,
      anon_sym_RBRACE,
  [312235] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15511), 1,
      anon_sym_RPAREN,
  [312242] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15513), 1,
      sym_identifier,
  [312249] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15515), 1,
      sym_raw_string_content,
  [312256] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15517), 1,
      anon_sym_RPAREN,
  [312263] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15519), 1,
      anon_sym_SEMI,
  [312270] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15521), 1,
      anon_sym_RPAREN,
  [312277] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15523), 1,
      anon_sym_LPAREN2,
  [312284] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15525), 1,
      sym_identifier,
  [312291] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15527), 1,
      anon_sym_RPAREN,
  [312298] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9434), 1,
      anon_sym_RPAREN,
  [312305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15529), 1,
      sym_identifier,
  [312312] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15531), 1,
      sym_raw_string_content,
  [312319] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15533), 1,
      anon_sym_DQUOTE,
  [312326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15535), 1,
      anon_sym_SEMI,
  [312333] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15537), 1,
      anon_sym_LPAREN2,
  [312340] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15539), 1,
      sym_identifier,
  [312347] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15541), 1,
      anon_sym_SEMI,
  [312354] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15543), 1,
      sym_identifier,
  [312361] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15545), 1,
      sym_identifier,
  [312368] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15547), 1,
      sym_raw_string_content,
  [312375] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15549), 1,
      anon_sym_RPAREN,
  [312382] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15551), 1,
      anon_sym_LPAREN2,
  [312389] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15553), 1,
      sym_identifier,
  [312396] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15555), 1,
      anon_sym_RPAREN,
  [312403] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15557), 1,
      anon_sym_SEMI,
  [312410] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15559), 1,
      sym_identifier,
  [312417] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15561), 1,
      sym_raw_string_content,
  [312424] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15563), 1,
      sym_identifier,
  [312431] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15565), 1,
      aux_sym_preproc_include_token2,
  [312438] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15567), 1,
      anon_sym_RPAREN,
  [312445] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15569), 1,
      sym_identifier,
  [312452] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15571), 1,
      sym_raw_string_content,
  [312459] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15573), 1,
      sym_auto,
  [312466] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15575), 1,
      sym_identifier,
  [312473] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15577), 1,
      sym_raw_string_content,
  [312480] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15579), 1,
      anon_sym_RPAREN,
  [312487] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15581), 1,
      sym_raw_string_content,
  [312494] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15583), 1,
      anon_sym_RPAREN,
  [312501] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15585), 1,
      sym_raw_string_content,
  [312508] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15587), 1,
      sym_identifier,
  [312515] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15589), 1,
      sym_raw_string_content,
  [312522] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15591), 1,
      anon_sym_RPAREN,
  [312529] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15593), 1,
      sym_raw_string_content,
  [312536] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15595), 1,
      anon_sym_SEMI,
  [312543] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15597), 1,
      sym_raw_string_content,
  [312550] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15599), 1,
      anon_sym_SEMI,
  [312557] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15601), 1,
      sym_raw_string_content,
  [312564] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15603), 1,
      anon_sym_RPAREN,
  [312571] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15605), 1,
      sym_raw_string_content,
  [312578] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15607), 1,
      anon_sym_RPAREN,
  [312585] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15609), 1,
      sym_raw_string_content,
  [312592] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15611), 1,
      sym_identifier,
  [312599] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15613), 1,
      sym_raw_string_content,
  [312606] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15615), 1,
      sym_auto,
  [312613] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15617), 1,
      sym_raw_string_content,
  [312620] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15619), 1,
      anon_sym_RPAREN,
  [312627] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15621), 1,
      sym_raw_string_content,
  [312634] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15623), 1,
      aux_sym_preproc_if_token2,
  [312641] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15625), 1,
      sym_raw_string_content,
  [312648] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15627), 1,
      anon_sym_LPAREN2,
  [312655] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15629), 1,
      anon_sym_LPAREN2,
  [312662] = 2,
    ACTIONS(6194), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(10599), 1,
      sym_comment,
  [312669] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15631), 1,
      anon_sym_LPAREN2,
  [312676] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15633), 1,
      anon_sym_LPAREN2,
  [312683] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15635), 1,
      anon_sym_DQUOTE,
  [312690] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15637), 1,
      anon_sym_LPAREN2,
  [312697] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15639), 1,
      anon_sym_LPAREN2,
  [312704] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15641), 1,
      anon_sym_LPAREN2,
  [312711] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15643), 1,
      anon_sym_LPAREN2,
  [312718] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15645), 1,
      anon_sym_LPAREN2,
  [312725] = 2,
    ACTIONS(10599), 1,
      sym_comment,
    ACTIONS(15647), 1,
      aux_sym_preproc_include_token2,
  [312732] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15649), 1,
      anon_sym_LPAREN2,
  [312739] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15651), 1,
      anon_sym_LPAREN2,
  [312746] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15653), 1,
      aux_sym_preproc_if_token2,
  [312753] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15655), 1,
      anon_sym_LPAREN2,
  [312760] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15657), 1,
      anon_sym_LPAREN2,
  [312767] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15659), 1,
      anon_sym_LPAREN2,
  [312774] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15661), 1,
      anon_sym_LPAREN2,
  [312781] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15663), 1,
      anon_sym_LPAREN2,
  [312788] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15665), 1,
      anon_sym_RPAREN,
  [312795] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15667), 1,
      anon_sym_LPAREN2,
  [312802] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15669), 1,
      anon_sym_LPAREN2,
  [312809] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15671), 1,
      anon_sym_LPAREN2,
  [312816] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15673), 1,
      anon_sym_LPAREN2,
  [312823] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15675), 1,
      anon_sym_LPAREN2,
  [312830] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15677), 1,
      anon_sym_LPAREN2,
  [312837] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15679), 1,
      anon_sym_LPAREN2,
  [312844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15681), 1,
      anon_sym_LPAREN2,
  [312851] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15683), 1,
      anon_sym_LPAREN2,
  [312858] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15685), 1,
      anon_sym_LPAREN2,
  [312865] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15687), 1,
      anon_sym_LPAREN2,
  [312872] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15689), 1,
      anon_sym_LPAREN2,
  [312879] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15691), 1,
      anon_sym_LPAREN2,
  [312886] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15693), 1,
      aux_sym_preproc_if_token2,
  [312893] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15695), 1,
      anon_sym_SEMI,
  [312900] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15697), 1,
      anon_sym_SEMI,
  [312907] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_SEMI,
  [312914] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15699), 1,
      sym_auto,
  [312921] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15701), 1,
      anon_sym_SEMI,
  [312928] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15703), 1,
      anon_sym_SEMI,
  [312935] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15705), 1,
      anon_sym_LPAREN2,
  [312942] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15707), 1,
      anon_sym_LPAREN2,
  [312949] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15709), 1,
      anon_sym_LPAREN2,
  [312956] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15711), 1,
      anon_sym_LPAREN2,
  [312963] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15713), 1,
      anon_sym_LPAREN2,
  [312970] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15715), 1,
      anon_sym_LPAREN2,
  [312977] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15717), 1,
      anon_sym_LPAREN2,
  [312984] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9546), 1,
      anon_sym_RPAREN,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2738)] = 0,
  [SMALL_STATE(2739)] = 71,
  [SMALL_STATE(2740)] = 142,
  [SMALL_STATE(2741)] = 221,
  [SMALL_STATE(2742)] = 292,
  [SMALL_STATE(2743)] = 363,
  [SMALL_STATE(2744)] = 434,
  [SMALL_STATE(2745)] = 523,
  [SMALL_STATE(2746)] = 594,
  [SMALL_STATE(2747)] = 673,
  [SMALL_STATE(2748)] = 750,
  [SMALL_STATE(2749)] = 821,
  [SMALL_STATE(2750)] = 892,
  [SMALL_STATE(2751)] = 963,
  [SMALL_STATE(2752)] = 1034,
  [SMALL_STATE(2753)] = 1105,
  [SMALL_STATE(2754)] = 1184,
  [SMALL_STATE(2755)] = 1265,
  [SMALL_STATE(2756)] = 1350,
  [SMALL_STATE(2757)] = 1421,
  [SMALL_STATE(2758)] = 1492,
  [SMALL_STATE(2759)] = 1563,
  [SMALL_STATE(2760)] = 1634,
  [SMALL_STATE(2761)] = 1705,
  [SMALL_STATE(2762)] = 1776,
  [SMALL_STATE(2763)] = 1847,
  [SMALL_STATE(2764)] = 1918,
  [SMALL_STATE(2765)] = 1989,
  [SMALL_STATE(2766)] = 2060,
  [SMALL_STATE(2767)] = 2131,
  [SMALL_STATE(2768)] = 2202,
  [SMALL_STATE(2769)] = 2273,
  [SMALL_STATE(2770)] = 2344,
  [SMALL_STATE(2771)] = 2415,
  [SMALL_STATE(2772)] = 2486,
  [SMALL_STATE(2773)] = 2557,
  [SMALL_STATE(2774)] = 2628,
  [SMALL_STATE(2775)] = 2699,
  [SMALL_STATE(2776)] = 2770,
  [SMALL_STATE(2777)] = 2841,
  [SMALL_STATE(2778)] = 2912,
  [SMALL_STATE(2779)] = 2983,
  [SMALL_STATE(2780)] = 3054,
  [SMALL_STATE(2781)] = 3125,
  [SMALL_STATE(2782)] = 3196,
  [SMALL_STATE(2783)] = 3267,
  [SMALL_STATE(2784)] = 3338,
  [SMALL_STATE(2785)] = 3409,
  [SMALL_STATE(2786)] = 3480,
  [SMALL_STATE(2787)] = 3551,
  [SMALL_STATE(2788)] = 3622,
  [SMALL_STATE(2789)] = 3693,
  [SMALL_STATE(2790)] = 3764,
  [SMALL_STATE(2791)] = 3841,
  [SMALL_STATE(2792)] = 3912,
  [SMALL_STATE(2793)] = 3983,
  [SMALL_STATE(2794)] = 4054,
  [SMALL_STATE(2795)] = 4125,
  [SMALL_STATE(2796)] = 4196,
  [SMALL_STATE(2797)] = 4267,
  [SMALL_STATE(2798)] = 4338,
  [SMALL_STATE(2799)] = 4409,
  [SMALL_STATE(2800)] = 4480,
  [SMALL_STATE(2801)] = 4551,
  [SMALL_STATE(2802)] = 4622,
  [SMALL_STATE(2803)] = 4693,
  [SMALL_STATE(2804)] = 4782,
  [SMALL_STATE(2805)] = 4853,
  [SMALL_STATE(2806)] = 4924,
  [SMALL_STATE(2807)] = 4995,
  [SMALL_STATE(2808)] = 5066,
  [SMALL_STATE(2809)] = 5151,
  [SMALL_STATE(2810)] = 5222,
  [SMALL_STATE(2811)] = 5293,
  [SMALL_STATE(2812)] = 5364,
  [SMALL_STATE(2813)] = 5435,
  [SMALL_STATE(2814)] = 5506,
  [SMALL_STATE(2815)] = 5589,
  [SMALL_STATE(2816)] = 5660,
  [SMALL_STATE(2817)] = 5743,
  [SMALL_STATE(2818)] = 5814,
  [SMALL_STATE(2819)] = 5885,
  [SMALL_STATE(2820)] = 5956,
  [SMALL_STATE(2821)] = 6027,
  [SMALL_STATE(2822)] = 6098,
  [SMALL_STATE(2823)] = 6169,
  [SMALL_STATE(2824)] = 6240,
  [SMALL_STATE(2825)] = 6311,
  [SMALL_STATE(2826)] = 6382,
  [SMALL_STATE(2827)] = 6453,
  [SMALL_STATE(2828)] = 6524,
  [SMALL_STATE(2829)] = 6595,
  [SMALL_STATE(2830)] = 6666,
  [SMALL_STATE(2831)] = 6737,
  [SMALL_STATE(2832)] = 6808,
  [SMALL_STATE(2833)] = 6879,
  [SMALL_STATE(2834)] = 6950,
  [SMALL_STATE(2835)] = 7021,
  [SMALL_STATE(2836)] = 7096,
  [SMALL_STATE(2837)] = 7167,
  [SMALL_STATE(2838)] = 7238,
  [SMALL_STATE(2839)] = 7312,
  [SMALL_STATE(2840)] = 7382,
  [SMALL_STATE(2841)] = 7456,
  [SMALL_STATE(2842)] = 7574,
  [SMALL_STATE(2843)] = 7644,
  [SMALL_STATE(2844)] = 7714,
  [SMALL_STATE(2845)] = 7790,
  [SMALL_STATE(2846)] = 7866,
  [SMALL_STATE(2847)] = 7940,
  [SMALL_STATE(2848)] = 8020,
  [SMALL_STATE(2849)] = 8100,
  [SMALL_STATE(2850)] = 8176,
  [SMALL_STATE(2851)] = 8246,
  [SMALL_STATE(2852)] = 8320,
  [SMALL_STATE(2853)] = 8444,
  [SMALL_STATE(2854)] = 8518,
  [SMALL_STATE(2855)] = 8588,
  [SMALL_STATE(2856)] = 8662,
  [SMALL_STATE(2857)] = 8742,
  [SMALL_STATE(2858)] = 8822,
  [SMALL_STATE(2859)] = 8892,
  [SMALL_STATE(2860)] = 8962,
  [SMALL_STATE(2861)] = 9036,
  [SMALL_STATE(2862)] = 9110,
  [SMALL_STATE(2863)] = 9180,
  [SMALL_STATE(2864)] = 9250,
  [SMALL_STATE(2865)] = 9324,
  [SMALL_STATE(2866)] = 9448,
  [SMALL_STATE(2867)] = 9526,
  [SMALL_STATE(2868)] = 9600,
  [SMALL_STATE(2869)] = 9674,
  [SMALL_STATE(2870)] = 9754,
  [SMALL_STATE(2871)] = 9872,
  [SMALL_STATE(2872)] = 9946,
  [SMALL_STATE(2873)] = 10016,
  [SMALL_STATE(2874)] = 10139,
  [SMALL_STATE(2875)] = 10210,
  [SMALL_STATE(2876)] = 10325,
  [SMALL_STATE(2877)] = 10440,
  [SMALL_STATE(2878)] = 10555,
  [SMALL_STATE(2879)] = 10638,
  [SMALL_STATE(2880)] = 10711,
  [SMALL_STATE(2881)] = 10790,
  [SMALL_STATE(2882)] = 10863,
  [SMALL_STATE(2883)] = 10938,
  [SMALL_STATE(2884)] = 11007,
  [SMALL_STATE(2885)] = 11122,
  [SMALL_STATE(2886)] = 11199,
  [SMALL_STATE(2887)] = 11272,
  [SMALL_STATE(2888)] = 11387,
  [SMALL_STATE(2889)] = 11466,
  [SMALL_STATE(2890)] = 11581,
  [SMALL_STATE(2891)] = 11654,
  [SMALL_STATE(2892)] = 11769,
  [SMALL_STATE(2893)] = 11840,
  [SMALL_STATE(2894)] = 11913,
  [SMALL_STATE(2895)] = 12028,
  [SMALL_STATE(2896)] = 12143,
  [SMALL_STATE(2897)] = 12258,
  [SMALL_STATE(2898)] = 12331,
  [SMALL_STATE(2899)] = 12446,
  [SMALL_STATE(2900)] = 12515,
  [SMALL_STATE(2901)] = 12630,
  [SMALL_STATE(2902)] = 12705,
  [SMALL_STATE(2903)] = 12820,
  [SMALL_STATE(2904)] = 12895,
  [SMALL_STATE(2905)] = 12966,
  [SMALL_STATE(2906)] = 13041,
  [SMALL_STATE(2907)] = 13156,
  [SMALL_STATE(2908)] = 13231,
  [SMALL_STATE(2909)] = 13308,
  [SMALL_STATE(2910)] = 13383,
  [SMALL_STATE(2911)] = 13458,
  [SMALL_STATE(2912)] = 13533,
  [SMALL_STATE(2913)] = 13648,
  [SMALL_STATE(2914)] = 13723,
  [SMALL_STATE(2915)] = 13798,
  [SMALL_STATE(2916)] = 13873,
  [SMALL_STATE(2917)] = 13946,
  [SMALL_STATE(2918)] = 14021,
  [SMALL_STATE(2919)] = 14096,
  [SMALL_STATE(2920)] = 14173,
  [SMALL_STATE(2921)] = 14296,
  [SMALL_STATE(2922)] = 14411,
  [SMALL_STATE(2923)] = 14484,
  [SMALL_STATE(2924)] = 14599,
  [SMALL_STATE(2925)] = 14672,
  [SMALL_STATE(2926)] = 14745,
  [SMALL_STATE(2927)] = 14818,
  [SMALL_STATE(2928)] = 14941,
  [SMALL_STATE(2929)] = 15056,
  [SMALL_STATE(2930)] = 15125,
  [SMALL_STATE(2931)] = 15248,
  [SMALL_STATE(2932)] = 15363,
  [SMALL_STATE(2933)] = 15478,
  [SMALL_STATE(2934)] = 15565,
  [SMALL_STATE(2935)] = 15640,
  [SMALL_STATE(2936)] = 15713,
  [SMALL_STATE(2937)] = 15796,
  [SMALL_STATE(2938)] = 15865,
  [SMALL_STATE(2939)] = 15980,
  [SMALL_STATE(2940)] = 16055,
  [SMALL_STATE(2941)] = 16170,
  [SMALL_STATE(2942)] = 16243,
  [SMALL_STATE(2943)] = 16318,
  [SMALL_STATE(2944)] = 16395,
  [SMALL_STATE(2945)] = 16518,
  [SMALL_STATE(2946)] = 16595,
  [SMALL_STATE(2947)] = 16668,
  [SMALL_STATE(2948)] = 16741,
  [SMALL_STATE(2949)] = 16814,
  [SMALL_STATE(2950)] = 16887,
  [SMALL_STATE(2951)] = 17002,
  [SMALL_STATE(2952)] = 17075,
  [SMALL_STATE(2953)] = 17190,
  [SMALL_STATE(2954)] = 17263,
  [SMALL_STATE(2955)] = 17378,
  [SMALL_STATE(2956)] = 17447,
  [SMALL_STATE(2957)] = 17570,
  [SMALL_STATE(2958)] = 17685,
  [SMALL_STATE(2959)] = 17800,
  [SMALL_STATE(2960)] = 17873,
  [SMALL_STATE(2961)] = 17946,
  [SMALL_STATE(2962)] = 18019,
  [SMALL_STATE(2963)] = 18092,
  [SMALL_STATE(2964)] = 18177,
  [SMALL_STATE(2965)] = 18250,
  [SMALL_STATE(2966)] = 18319,
  [SMALL_STATE(2967)] = 18434,
  [SMALL_STATE(2968)] = 18508,
  [SMALL_STATE(2969)] = 18576,
  [SMALL_STATE(2970)] = 18648,
  [SMALL_STATE(2971)] = 18720,
  [SMALL_STATE(2972)] = 18802,
  [SMALL_STATE(2973)] = 18870,
  [SMALL_STATE(2974)] = 18940,
  [SMALL_STATE(2975)] = 19008,
  [SMALL_STATE(2976)] = 19080,
  [SMALL_STATE(2977)] = 19202,
  [SMALL_STATE(2978)] = 19284,
  [SMALL_STATE(2979)] = 19352,
  [SMALL_STATE(2980)] = 19434,
  [SMALL_STATE(2981)] = 19556,
  [SMALL_STATE(2982)] = 19624,
  [SMALL_STATE(2983)] = 19692,
  [SMALL_STATE(2984)] = 19760,
  [SMALL_STATE(2985)] = 19830,
  [SMALL_STATE(2986)] = 19900,
  [SMALL_STATE(2987)] = 19968,
  [SMALL_STATE(2988)] = 20090,
  [SMALL_STATE(2989)] = 20158,
  [SMALL_STATE(2990)] = 20226,
  [SMALL_STATE(2991)] = 20294,
  [SMALL_STATE(2992)] = 20368,
  [SMALL_STATE(2993)] = 20436,
  [SMALL_STATE(2994)] = 20504,
  [SMALL_STATE(2995)] = 20572,
  [SMALL_STATE(2996)] = 20642,
  [SMALL_STATE(2997)] = 20764,
  [SMALL_STATE(2998)] = 20846,
  [SMALL_STATE(2999)] = 20914,
  [SMALL_STATE(3000)] = 21036,
  [SMALL_STATE(3001)] = 21158,
  [SMALL_STATE(3002)] = 21228,
  [SMALL_STATE(3003)] = 21296,
  [SMALL_STATE(3004)] = 21366,
  [SMALL_STATE(3005)] = 21436,
  [SMALL_STATE(3006)] = 21504,
  [SMALL_STATE(3007)] = 21626,
  [SMALL_STATE(3008)] = 21748,
  [SMALL_STATE(3009)] = 21870,
  [SMALL_STATE(3010)] = 21938,
  [SMALL_STATE(3011)] = 22060,
  [SMALL_STATE(3012)] = 22159,
  [SMALL_STATE(3013)] = 22232,
  [SMALL_STATE(3014)] = 22309,
  [SMALL_STATE(3015)] = 22376,
  [SMALL_STATE(3016)] = 22491,
  [SMALL_STATE(3017)] = 22606,
  [SMALL_STATE(3018)] = 22689,
  [SMALL_STATE(3019)] = 22808,
  [SMALL_STATE(3020)] = 22923,
  [SMALL_STATE(3021)] = 23032,
  [SMALL_STATE(3022)] = 23137,
  [SMALL_STATE(3023)] = 23240,
  [SMALL_STATE(3024)] = 23311,
  [SMALL_STATE(3025)] = 23412,
  [SMALL_STATE(3026)] = 23483,
  [SMALL_STATE(3027)] = 23554,
  [SMALL_STATE(3028)] = 23625,
  [SMALL_STATE(3029)] = 23696,
  [SMALL_STATE(3030)] = 23767,
  [SMALL_STATE(3031)] = 23838,
  [SMALL_STATE(3032)] = 23921,
  [SMALL_STATE(3033)] = 24004,
  [SMALL_STATE(3034)] = 24095,
  [SMALL_STATE(3035)] = 24166,
  [SMALL_STATE(3036)] = 24243,
  [SMALL_STATE(3037)] = 24358,
  [SMALL_STATE(3038)] = 24477,
  [SMALL_STATE(3039)] = 24592,
  [SMALL_STATE(3040)] = 24711,
  [SMALL_STATE(3041)] = 24782,
  [SMALL_STATE(3042)] = 24853,
  [SMALL_STATE(3043)] = 24920,
  [SMALL_STATE(3044)] = 24997,
  [SMALL_STATE(3045)] = 25078,
  [SMALL_STATE(3046)] = 25149,
  [SMALL_STATE(3047)] = 25220,
  [SMALL_STATE(3048)] = 25341,
  [SMALL_STATE(3049)] = 25414,
  [SMALL_STATE(3050)] = 25535,
  [SMALL_STATE(3051)] = 25618,
  [SMALL_STATE(3052)] = 25689,
  [SMALL_STATE(3053)] = 25774,
  [SMALL_STATE(3054)] = 25861,
  [SMALL_STATE(3055)] = 25950,
  [SMALL_STATE(3056)] = 26027,
  [SMALL_STATE(3057)] = 26098,
  [SMALL_STATE(3058)] = 26193,
  [SMALL_STATE(3059)] = 26313,
  [SMALL_STATE(3060)] = 26379,
  [SMALL_STATE(3061)] = 26445,
  [SMALL_STATE(3062)] = 26511,
  [SMALL_STATE(3063)] = 26583,
  [SMALL_STATE(3064)] = 26655,
  [SMALL_STATE(3065)] = 26721,
  [SMALL_STATE(3066)] = 26787,
  [SMALL_STATE(3067)] = 26853,
  [SMALL_STATE(3068)] = 26921,
  [SMALL_STATE(3069)] = 27003,
  [SMALL_STATE(3070)] = 27075,
  [SMALL_STATE(3071)] = 27141,
  [SMALL_STATE(3072)] = 27209,
  [SMALL_STATE(3073)] = 27275,
  [SMALL_STATE(3074)] = 27357,
  [SMALL_STATE(3075)] = 27423,
  [SMALL_STATE(3076)] = 27489,
  [SMALL_STATE(3077)] = 27561,
  [SMALL_STATE(3078)] = 27627,
  [SMALL_STATE(3079)] = 27693,
  [SMALL_STATE(3080)] = 27813,
  [SMALL_STATE(3081)] = 27879,
  [SMALL_STATE(3082)] = 27945,
  [SMALL_STATE(3083)] = 28027,
  [SMALL_STATE(3084)] = 28147,
  [SMALL_STATE(3085)] = 28213,
  [SMALL_STATE(3086)] = 28287,
  [SMALL_STATE(3087)] = 28353,
  [SMALL_STATE(3088)] = 28435,
  [SMALL_STATE(3089)] = 28501,
  [SMALL_STATE(3090)] = 28583,
  [SMALL_STATE(3091)] = 28649,
  [SMALL_STATE(3092)] = 28725,
  [SMALL_STATE(3093)] = 28797,
  [SMALL_STATE(3094)] = 28863,
  [SMALL_STATE(3095)] = 28983,
  [SMALL_STATE(3096)] = 29065,
  [SMALL_STATE(3097)] = 29185,
  [SMALL_STATE(3098)] = 29251,
  [SMALL_STATE(3099)] = 29333,
  [SMALL_STATE(3100)] = 29405,
  [SMALL_STATE(3101)] = 29487,
  [SMALL_STATE(3102)] = 29553,
  [SMALL_STATE(3103)] = 29625,
  [SMALL_STATE(3104)] = 29691,
  [SMALL_STATE(3105)] = 29763,
  [SMALL_STATE(3106)] = 29831,
  [SMALL_STATE(3107)] = 29903,
  [SMALL_STATE(3108)] = 29971,
  [SMALL_STATE(3109)] = 30037,
  [SMALL_STATE(3110)] = 30103,
  [SMALL_STATE(3111)] = 30169,
  [SMALL_STATE(3112)] = 30235,
  [SMALL_STATE(3113)] = 30301,
  [SMALL_STATE(3114)] = 30377,
  [SMALL_STATE(3115)] = 30445,
  [SMALL_STATE(3116)] = 30511,
  [SMALL_STATE(3117)] = 30577,
  [SMALL_STATE(3118)] = 30653,
  [SMALL_STATE(3119)] = 30733,
  [SMALL_STATE(3120)] = 30799,
  [SMALL_STATE(3121)] = 30875,
  [SMALL_STATE(3122)] = 30947,
  [SMALL_STATE(3123)] = 31015,
  [SMALL_STATE(3124)] = 31081,
  [SMALL_STATE(3125)] = 31147,
  [SMALL_STATE(3126)] = 31213,
  [SMALL_STATE(3127)] = 31295,
  [SMALL_STATE(3128)] = 31415,
  [SMALL_STATE(3129)] = 31487,
  [SMALL_STATE(3130)] = 31553,
  [SMALL_STATE(3131)] = 31619,
  [SMALL_STATE(3132)] = 31699,
  [SMALL_STATE(3133)] = 31765,
  [SMALL_STATE(3134)] = 31837,
  [SMALL_STATE(3135)] = 31917,
  [SMALL_STATE(3136)] = 31997,
  [SMALL_STATE(3137)] = 32069,
  [SMALL_STATE(3138)] = 32135,
  [SMALL_STATE(3139)] = 32201,
  [SMALL_STATE(3140)] = 32267,
  [SMALL_STATE(3141)] = 32332,
  [SMALL_STATE(3142)] = 32435,
  [SMALL_STATE(3143)] = 32538,
  [SMALL_STATE(3144)] = 32625,
  [SMALL_STATE(3145)] = 32744,
  [SMALL_STATE(3146)] = 32911,
  [SMALL_STATE(3147)] = 32978,
  [SMALL_STATE(3148)] = 33097,
  [SMALL_STATE(3149)] = 33264,
  [SMALL_STATE(3150)] = 33335,
  [SMALL_STATE(3151)] = 33406,
  [SMALL_STATE(3152)] = 33477,
  [SMALL_STATE(3153)] = 33548,
  [SMALL_STATE(3154)] = 33617,
  [SMALL_STATE(3155)] = 33688,
  [SMALL_STATE(3156)] = 33759,
  [SMALL_STATE(3157)] = 33878,
  [SMALL_STATE(3158)] = 33975,
  [SMALL_STATE(3159)] = 34094,
  [SMALL_STATE(3160)] = 34159,
  [SMALL_STATE(3161)] = 34262,
  [SMALL_STATE(3162)] = 34365,
  [SMALL_STATE(3163)] = 34430,
  [SMALL_STATE(3164)] = 34545,
  [SMALL_STATE(3165)] = 34610,
  [SMALL_STATE(3166)] = 34681,
  [SMALL_STATE(3167)] = 34752,
  [SMALL_STATE(3168)] = 34817,
  [SMALL_STATE(3169)] = 34888,
  [SMALL_STATE(3170)] = 34959,
  [SMALL_STATE(3171)] = 35030,
  [SMALL_STATE(3172)] = 35095,
  [SMALL_STATE(3173)] = 35214,
  [SMALL_STATE(3174)] = 35317,
  [SMALL_STATE(3175)] = 35382,
  [SMALL_STATE(3176)] = 35497,
  [SMALL_STATE(3177)] = 35582,
  [SMALL_STATE(3178)] = 35685,
  [SMALL_STATE(3179)] = 35756,
  [SMALL_STATE(3180)] = 35875,
  [SMALL_STATE(3181)] = 35946,
  [SMALL_STATE(3182)] = 36017,
  [SMALL_STATE(3183)] = 36084,
  [SMALL_STATE(3184)] = 36251,
  [SMALL_STATE(3185)] = 36322,
  [SMALL_STATE(3186)] = 36489,
  [SMALL_STATE(3187)] = 36560,
  [SMALL_STATE(3188)] = 36631,
  [SMALL_STATE(3189)] = 36702,
  [SMALL_STATE(3190)] = 36773,
  [SMALL_STATE(3191)] = 36892,
  [SMALL_STATE(3192)] = 36989,
  [SMALL_STATE(3193)] = 37060,
  [SMALL_STATE(3194)] = 37131,
  [SMALL_STATE(3195)] = 37214,
  [SMALL_STATE(3196)] = 37303,
  [SMALL_STATE(3197)] = 37418,
  [SMALL_STATE(3198)] = 37527,
  [SMALL_STATE(3199)] = 37632,
  [SMALL_STATE(3200)] = 37733,
  [SMALL_STATE(3201)] = 37798,
  [SMALL_STATE(3202)] = 37913,
  [SMALL_STATE(3203)] = 37984,
  [SMALL_STATE(3204)] = 38083,
  [SMALL_STATE(3205)] = 38198,
  [SMALL_STATE(3206)] = 38293,
  [SMALL_STATE(3207)] = 38386,
  [SMALL_STATE(3208)] = 38457,
  [SMALL_STATE(3209)] = 38528,
  [SMALL_STATE(3210)] = 38616,
  [SMALL_STATE(3211)] = 38680,
  [SMALL_STATE(3212)] = 38784,
  [SMALL_STATE(3213)] = 38848,
  [SMALL_STATE(3214)] = 38928,
  [SMALL_STATE(3215)] = 39002,
  [SMALL_STATE(3216)] = 39082,
  [SMALL_STATE(3217)] = 39156,
  [SMALL_STATE(3218)] = 39254,
  [SMALL_STATE(3219)] = 39328,
  [SMALL_STATE(3220)] = 39402,
  [SMALL_STATE(3221)] = 39466,
  [SMALL_STATE(3222)] = 39580,
  [SMALL_STATE(3223)] = 39646,
  [SMALL_STATE(3224)] = 39710,
  [SMALL_STATE(3225)] = 39774,
  [SMALL_STATE(3226)] = 39848,
  [SMALL_STATE(3227)] = 39912,
  [SMALL_STATE(3228)] = 40030,
  [SMALL_STATE(3229)] = 40144,
  [SMALL_STATE(3230)] = 40216,
  [SMALL_STATE(3231)] = 40310,
  [SMALL_STATE(3232)] = 40402,
  [SMALL_STATE(3233)] = 40466,
  [SMALL_STATE(3234)] = 40574,
  [SMALL_STATE(3235)] = 40650,
  [SMALL_STATE(3236)] = 40714,
  [SMALL_STATE(3237)] = 40832,
  [SMALL_STATE(3238)] = 40900,
  [SMALL_STATE(3239)] = 40964,
  [SMALL_STATE(3240)] = 41028,
  [SMALL_STATE(3241)] = 41108,
  [SMALL_STATE(3242)] = 41208,
  [SMALL_STATE(3243)] = 41282,
  [SMALL_STATE(3244)] = 41396,
  [SMALL_STATE(3245)] = 41510,
  [SMALL_STATE(3246)] = 41576,
  [SMALL_STATE(3247)] = 41690,
  [SMALL_STATE(3248)] = 41808,
  [SMALL_STATE(3249)] = 41882,
  [SMALL_STATE(3250)] = 41962,
  [SMALL_STATE(3251)] = 42034,
  [SMALL_STATE(3252)] = 42104,
  [SMALL_STATE(3253)] = 42168,
  [SMALL_STATE(3254)] = 42232,
  [SMALL_STATE(3255)] = 42344,
  [SMALL_STATE(3256)] = 42426,
  [SMALL_STATE(3257)] = 42510,
  [SMALL_STATE(3258)] = 42596,
  [SMALL_STATE(3259)] = 42660,
  [SMALL_STATE(3260)] = 42724,
  [SMALL_STATE(3261)] = 42811,
  [SMALL_STATE(3262)] = 42880,
  [SMALL_STATE(3263)] = 42989,
  [SMALL_STATE(3264)] = 43106,
  [SMALL_STATE(3265)] = 43169,
  [SMALL_STATE(3266)] = 43282,
  [SMALL_STATE(3267)] = 43351,
  [SMALL_STATE(3268)] = 43460,
  [SMALL_STATE(3269)] = 43523,
  [SMALL_STATE(3270)] = 43588,
  [SMALL_STATE(3271)] = 43697,
  [SMALL_STATE(3272)] = 43766,
  [SMALL_STATE(3273)] = 43875,
  [SMALL_STATE(3274)] = 43988,
  [SMALL_STATE(3275)] = 44097,
  [SMALL_STATE(3276)] = 44206,
  [SMALL_STATE(3277)] = 44297,
  [SMALL_STATE(3278)] = 44360,
  [SMALL_STATE(3279)] = 44423,
  [SMALL_STATE(3280)] = 44532,
  [SMALL_STATE(3281)] = 44595,
  [SMALL_STATE(3282)] = 44704,
  [SMALL_STATE(3283)] = 44773,
  [SMALL_STATE(3284)] = 44858,
  [SMALL_STATE(3285)] = 44921,
  [SMALL_STATE(3286)] = 44984,
  [SMALL_STATE(3287)] = 45057,
  [SMALL_STATE(3288)] = 45120,
  [SMALL_STATE(3289)] = 45183,
  [SMALL_STATE(3290)] = 45292,
  [SMALL_STATE(3291)] = 45365,
  [SMALL_STATE(3292)] = 45430,
  [SMALL_STATE(3293)] = 45539,
  [SMALL_STATE(3294)] = 45648,
  [SMALL_STATE(3295)] = 45723,
  [SMALL_STATE(3296)] = 45824,
  [SMALL_STATE(3297)] = 45933,
  [SMALL_STATE(3298)] = 46034,
  [SMALL_STATE(3299)] = 46113,
  [SMALL_STATE(3300)] = 46222,
  [SMALL_STATE(3301)] = 46331,
  [SMALL_STATE(3302)] = 46398,
  [SMALL_STATE(3303)] = 46507,
  [SMALL_STATE(3304)] = 46616,
  [SMALL_STATE(3305)] = 46679,
  [SMALL_STATE(3306)] = 46742,
  [SMALL_STATE(3307)] = 46851,
  [SMALL_STATE(3308)] = 46914,
  [SMALL_STATE(3309)] = 46993,
  [SMALL_STATE(3310)] = 47056,
  [SMALL_STATE(3311)] = 47119,
  [SMALL_STATE(3312)] = 47182,
  [SMALL_STATE(3313)] = 47291,
  [SMALL_STATE(3314)] = 47354,
  [SMALL_STATE(3315)] = 47417,
  [SMALL_STATE(3316)] = 47480,
  [SMALL_STATE(3317)] = 47543,
  [SMALL_STATE(3318)] = 47616,
  [SMALL_STATE(3319)] = 47725,
  [SMALL_STATE(3320)] = 47832,
  [SMALL_STATE(3321)] = 47895,
  [SMALL_STATE(3322)] = 47958,
  [SMALL_STATE(3323)] = 48061,
  [SMALL_STATE(3324)] = 48124,
  [SMALL_STATE(3325)] = 48233,
  [SMALL_STATE(3326)] = 48302,
  [SMALL_STATE(3327)] = 48365,
  [SMALL_STATE(3328)] = 48428,
  [SMALL_STATE(3329)] = 48537,
  [SMALL_STATE(3330)] = 48600,
  [SMALL_STATE(3331)] = 48669,
  [SMALL_STATE(3332)] = 48738,
  [SMALL_STATE(3333)] = 48807,
  [SMALL_STATE(3334)] = 48916,
  [SMALL_STATE(3335)] = 48995,
  [SMALL_STATE(3336)] = 49062,
  [SMALL_STATE(3337)] = 49171,
  [SMALL_STATE(3338)] = 49240,
  [SMALL_STATE(3339)] = 49305,
  [SMALL_STATE(3340)] = 49404,
  [SMALL_STATE(3341)] = 49467,
  [SMALL_STATE(3342)] = 49576,
  [SMALL_STATE(3343)] = 49693,
  [SMALL_STATE(3344)] = 49802,
  [SMALL_STATE(3345)] = 49865,
  [SMALL_STATE(3346)] = 49974,
  [SMALL_STATE(3347)] = 50037,
  [SMALL_STATE(3348)] = 50106,
  [SMALL_STATE(3349)] = 50183,
  [SMALL_STATE(3350)] = 50292,
  [SMALL_STATE(3351)] = 50355,
  [SMALL_STATE(3352)] = 50418,
  [SMALL_STATE(3353)] = 50527,
  [SMALL_STATE(3354)] = 50596,
  [SMALL_STATE(3355)] = 50705,
  [SMALL_STATE(3356)] = 50768,
  [SMALL_STATE(3357)] = 50837,
  [SMALL_STATE(3358)] = 50946,
  [SMALL_STATE(3359)] = 51009,
  [SMALL_STATE(3360)] = 51078,
  [SMALL_STATE(3361)] = 51141,
  [SMALL_STATE(3362)] = 51204,
  [SMALL_STATE(3363)] = 51313,
  [SMALL_STATE(3364)] = 51430,
  [SMALL_STATE(3365)] = 51539,
  [SMALL_STATE(3366)] = 51648,
  [SMALL_STATE(3367)] = 51727,
  [SMALL_STATE(3368)] = 51836,
  [SMALL_STATE(3369)] = 51909,
  [SMALL_STATE(3370)] = 51972,
  [SMALL_STATE(3371)] = 52081,
  [SMALL_STATE(3372)] = 52190,
  [SMALL_STATE(3373)] = 52299,
  [SMALL_STATE(3374)] = 52408,
  [SMALL_STATE(3375)] = 52471,
  [SMALL_STATE(3376)] = 52580,
  [SMALL_STATE(3377)] = 52653,
  [SMALL_STATE(3378)] = 52762,
  [SMALL_STATE(3379)] = 52875,
  [SMALL_STATE(3380)] = 52984,
  [SMALL_STATE(3381)] = 53093,
  [SMALL_STATE(3382)] = 53202,
  [SMALL_STATE(3383)] = 53271,
  [SMALL_STATE(3384)] = 53380,
  [SMALL_STATE(3385)] = 53489,
  [SMALL_STATE(3386)] = 53598,
  [SMALL_STATE(3387)] = 53707,
  [SMALL_STATE(3388)] = 53780,
  [SMALL_STATE(3389)] = 53849,
  [SMALL_STATE(3390)] = 53958,
  [SMALL_STATE(3391)] = 54067,
  [SMALL_STATE(3392)] = 54150,
  [SMALL_STATE(3393)] = 54259,
  [SMALL_STATE(3394)] = 54368,
  [SMALL_STATE(3395)] = 54437,
  [SMALL_STATE(3396)] = 54506,
  [SMALL_STATE(3397)] = 54579,
  [SMALL_STATE(3398)] = 54652,
  [SMALL_STATE(3399)] = 54729,
  [SMALL_STATE(3400)] = 54838,
  [SMALL_STATE(3401)] = 54909,
  [SMALL_STATE(3402)] = 54972,
  [SMALL_STATE(3403)] = 55047,
  [SMALL_STATE(3404)] = 55156,
  [SMALL_STATE(3405)] = 55219,
  [SMALL_STATE(3406)] = 55328,
  [SMALL_STATE(3407)] = 55425,
  [SMALL_STATE(3408)] = 55494,
  [SMALL_STATE(3409)] = 55575,
  [SMALL_STATE(3410)] = 55654,
  [SMALL_STATE(3411)] = 55763,
  [SMALL_STATE(3412)] = 55826,
  [SMALL_STATE(3413)] = 55935,
  [SMALL_STATE(3414)] = 56048,
  [SMALL_STATE(3415)] = 56157,
  [SMALL_STATE(3416)] = 56266,
  [SMALL_STATE(3417)] = 56337,
  [SMALL_STATE(3418)] = 56446,
  [SMALL_STATE(3419)] = 56555,
  [SMALL_STATE(3420)] = 56668,
  [SMALL_STATE(3421)] = 56777,
  [SMALL_STATE(3422)] = 56886,
  [SMALL_STATE(3423)] = 56995,
  [SMALL_STATE(3424)] = 57068,
  [SMALL_STATE(3425)] = 57131,
  [SMALL_STATE(3426)] = 57194,
  [SMALL_STATE(3427)] = 57303,
  [SMALL_STATE(3428)] = 57412,
  [SMALL_STATE(3429)] = 57475,
  [SMALL_STATE(3430)] = 57584,
  [SMALL_STATE(3431)] = 57693,
  [SMALL_STATE(3432)] = 57802,
  [SMALL_STATE(3433)] = 57911,
  [SMALL_STATE(3434)] = 58020,
  [SMALL_STATE(3435)] = 58129,
  [SMALL_STATE(3436)] = 58238,
  [SMALL_STATE(3437)] = 58347,
  [SMALL_STATE(3438)] = 58456,
  [SMALL_STATE(3439)] = 58565,
  [SMALL_STATE(3440)] = 58628,
  [SMALL_STATE(3441)] = 58691,
  [SMALL_STATE(3442)] = 58764,
  [SMALL_STATE(3443)] = 58857,
  [SMALL_STATE(3444)] = 58966,
  [SMALL_STATE(3445)] = 59075,
  [SMALL_STATE(3446)] = 59144,
  [SMALL_STATE(3447)] = 59253,
  [SMALL_STATE(3448)] = 59369,
  [SMALL_STATE(3449)] = 59437,
  [SMALL_STATE(3450)] = 59499,
  [SMALL_STATE(3451)] = 59561,
  [SMALL_STATE(3452)] = 59623,
  [SMALL_STATE(3453)] = 59685,
  [SMALL_STATE(3454)] = 59747,
  [SMALL_STATE(3455)] = 59809,
  [SMALL_STATE(3456)] = 59871,
  [SMALL_STATE(3457)] = 59933,
  [SMALL_STATE(3458)] = 60011,
  [SMALL_STATE(3459)] = 60131,
  [SMALL_STATE(3460)] = 60193,
  [SMALL_STATE(3461)] = 60299,
  [SMALL_STATE(3462)] = 60415,
  [SMALL_STATE(3463)] = 60485,
  [SMALL_STATE(3464)] = 60557,
  [SMALL_STATE(3465)] = 60627,
  [SMALL_STATE(3466)] = 60697,
  [SMALL_STATE(3467)] = 60761,
  [SMALL_STATE(3468)] = 60823,
  [SMALL_STATE(3469)] = 60891,
  [SMALL_STATE(3470)] = 60953,
  [SMALL_STATE(3471)] = 61051,
  [SMALL_STATE(3472)] = 61113,
  [SMALL_STATE(3473)] = 61179,
  [SMALL_STATE(3474)] = 61249,
  [SMALL_STATE(3475)] = 61315,
  [SMALL_STATE(3476)] = 61403,
  [SMALL_STATE(3477)] = 61473,
  [SMALL_STATE(3478)] = 61543,
  [SMALL_STATE(3479)] = 61613,
  [SMALL_STATE(3480)] = 61679,
  [SMALL_STATE(3481)] = 61841,
  [SMALL_STATE(3482)] = 61903,
  [SMALL_STATE(3483)] = 61965,
  [SMALL_STATE(3484)] = 62027,
  [SMALL_STATE(3485)] = 62093,
  [SMALL_STATE(3486)] = 62199,
  [SMALL_STATE(3487)] = 62317,
  [SMALL_STATE(3488)] = 62385,
  [SMALL_STATE(3489)] = 62451,
  [SMALL_STATE(3490)] = 62613,
  [SMALL_STATE(3491)] = 62679,
  [SMALL_STATE(3492)] = 62741,
  [SMALL_STATE(3493)] = 62807,
  [SMALL_STATE(3494)] = 62869,
  [SMALL_STATE(3495)] = 62935,
  [SMALL_STATE(3496)] = 63041,
  [SMALL_STATE(3497)] = 63105,
  [SMALL_STATE(3498)] = 63267,
  [SMALL_STATE(3499)] = 63333,
  [SMALL_STATE(3500)] = 63399,
  [SMALL_STATE(3501)] = 63465,
  [SMALL_STATE(3502)] = 63571,
  [SMALL_STATE(3503)] = 63733,
  [SMALL_STATE(3504)] = 63839,
  [SMALL_STATE(3505)] = 63905,
  [SMALL_STATE(3506)] = 64011,
  [SMALL_STATE(3507)] = 64077,
  [SMALL_STATE(3508)] = 64239,
  [SMALL_STATE(3509)] = 64317,
  [SMALL_STATE(3510)] = 64383,
  [SMALL_STATE(3511)] = 64489,
  [SMALL_STATE(3512)] = 64651,
  [SMALL_STATE(3513)] = 64713,
  [SMALL_STATE(3514)] = 64775,
  [SMALL_STATE(3515)] = 64841,
  [SMALL_STATE(3516)] = 64947,
  [SMALL_STATE(3517)] = 65023,
  [SMALL_STATE(3518)] = 65133,
  [SMALL_STATE(3519)] = 65195,
  [SMALL_STATE(3520)] = 65357,
  [SMALL_STATE(3521)] = 65419,
  [SMALL_STATE(3522)] = 65481,
  [SMALL_STATE(3523)] = 65543,
  [SMALL_STATE(3524)] = 65605,
  [SMALL_STATE(3525)] = 65683,
  [SMALL_STATE(3526)] = 65761,
  [SMALL_STATE(3527)] = 65825,
  [SMALL_STATE(3528)] = 65935,
  [SMALL_STATE(3529)] = 66041,
  [SMALL_STATE(3530)] = 66117,
  [SMALL_STATE(3531)] = 66179,
  [SMALL_STATE(3532)] = 66341,
  [SMALL_STATE(3533)] = 66447,
  [SMALL_STATE(3534)] = 66609,
  [SMALL_STATE(3535)] = 66719,
  [SMALL_STATE(3536)] = 66881,
  [SMALL_STATE(3537)] = 66947,
  [SMALL_STATE(3538)] = 67009,
  [SMALL_STATE(3539)] = 67071,
  [SMALL_STATE(3540)] = 67233,
  [SMALL_STATE(3541)] = 67295,
  [SMALL_STATE(3542)] = 67357,
  [SMALL_STATE(3543)] = 67419,
  [SMALL_STATE(3544)] = 67481,
  [SMALL_STATE(3545)] = 67543,
  [SMALL_STATE(3546)] = 67657,
  [SMALL_STATE(3547)] = 67725,
  [SMALL_STATE(3548)] = 67805,
  [SMALL_STATE(3549)] = 67883,
  [SMALL_STATE(3550)] = 67987,
  [SMALL_STATE(3551)] = 68093,
  [SMALL_STATE(3552)] = 68193,
  [SMALL_STATE(3553)] = 68289,
  [SMALL_STATE(3554)] = 68383,
  [SMALL_STATE(3555)] = 68473,
  [SMALL_STATE(3556)] = 68561,
  [SMALL_STATE(3557)] = 68647,
  [SMALL_STATE(3558)] = 68729,
  [SMALL_STATE(3559)] = 68813,
  [SMALL_STATE(3560)] = 68891,
  [SMALL_STATE(3561)] = 68953,
  [SMALL_STATE(3562)] = 69041,
  [SMALL_STATE(3563)] = 69109,
  [SMALL_STATE(3564)] = 69215,
  [SMALL_STATE(3565)] = 69277,
  [SMALL_STATE(3566)] = 69339,
  [SMALL_STATE(3567)] = 69427,
  [SMALL_STATE(3568)] = 69489,
  [SMALL_STATE(3569)] = 69551,
  [SMALL_STATE(3570)] = 69657,
  [SMALL_STATE(3571)] = 69719,
  [SMALL_STATE(3572)] = 69831,
  [SMALL_STATE(3573)] = 69893,
  [SMALL_STATE(3574)] = 69955,
  [SMALL_STATE(3575)] = 70061,
  [SMALL_STATE(3576)] = 70167,
  [SMALL_STATE(3577)] = 70229,
  [SMALL_STATE(3578)] = 70329,
  [SMALL_STATE(3579)] = 70429,
  [SMALL_STATE(3580)] = 70497,
  [SMALL_STATE(3581)] = 70607,
  [SMALL_STATE(3582)] = 70675,
  [SMALL_STATE(3583)] = 70781,
  [SMALL_STATE(3584)] = 70859,
  [SMALL_STATE(3585)] = 70957,
  [SMALL_STATE(3586)] = 71071,
  [SMALL_STATE(3587)] = 71177,
  [SMALL_STATE(3588)] = 71283,
  [SMALL_STATE(3589)] = 71393,
  [SMALL_STATE(3590)] = 71461,
  [SMALL_STATE(3591)] = 71523,
  [SMALL_STATE(3592)] = 71585,
  [SMALL_STATE(3593)] = 71647,
  [SMALL_STATE(3594)] = 71709,
  [SMALL_STATE(3595)] = 71771,
  [SMALL_STATE(3596)] = 71833,
  [SMALL_STATE(3597)] = 71939,
  [SMALL_STATE(3598)] = 72053,
  [SMALL_STATE(3599)] = 72115,
  [SMALL_STATE(3600)] = 72177,
  [SMALL_STATE(3601)] = 72239,
  [SMALL_STATE(3602)] = 72301,
  [SMALL_STATE(3603)] = 72377,
  [SMALL_STATE(3604)] = 72489,
  [SMALL_STATE(3605)] = 72551,
  [SMALL_STATE(3606)] = 72613,
  [SMALL_STATE(3607)] = 72675,
  [SMALL_STATE(3608)] = 72737,
  [SMALL_STATE(3609)] = 72815,
  [SMALL_STATE(3610)] = 72893,
  [SMALL_STATE(3611)] = 72957,
  [SMALL_STATE(3612)] = 73069,
  [SMALL_STATE(3613)] = 73145,
  [SMALL_STATE(3614)] = 73207,
  [SMALL_STATE(3615)] = 73283,
  [SMALL_STATE(3616)] = 73395,
  [SMALL_STATE(3617)] = 73473,
  [SMALL_STATE(3618)] = 73551,
  [SMALL_STATE(3619)] = 73663,
  [SMALL_STATE(3620)] = 73739,
  [SMALL_STATE(3621)] = 73851,
  [SMALL_STATE(3622)] = 73967,
  [SMALL_STATE(3623)] = 74047,
  [SMALL_STATE(3624)] = 74125,
  [SMALL_STATE(3625)] = 74231,
  [SMALL_STATE(3626)] = 74333,
  [SMALL_STATE(3627)] = 74431,
  [SMALL_STATE(3628)] = 74527,
  [SMALL_STATE(3629)] = 74619,
  [SMALL_STATE(3630)] = 74709,
  [SMALL_STATE(3631)] = 74795,
  [SMALL_STATE(3632)] = 74877,
  [SMALL_STATE(3633)] = 74961,
  [SMALL_STATE(3634)] = 75039,
  [SMALL_STATE(3635)] = 75151,
  [SMALL_STATE(3636)] = 75267,
  [SMALL_STATE(3637)] = 75379,
  [SMALL_STATE(3638)] = 75495,
  [SMALL_STATE(3639)] = 75607,
  [SMALL_STATE(3640)] = 75669,
  [SMALL_STATE(3641)] = 75731,
  [SMALL_STATE(3642)] = 75797,
  [SMALL_STATE(3643)] = 75859,
  [SMALL_STATE(3644)] = 75921,
  [SMALL_STATE(3645)] = 75983,
  [SMALL_STATE(3646)] = 76045,
  [SMALL_STATE(3647)] = 76107,
  [SMALL_STATE(3648)] = 76223,
  [SMALL_STATE(3649)] = 76291,
  [SMALL_STATE(3650)] = 76371,
  [SMALL_STATE(3651)] = 76449,
  [SMALL_STATE(3652)] = 76555,
  [SMALL_STATE(3653)] = 76657,
  [SMALL_STATE(3654)] = 76755,
  [SMALL_STATE(3655)] = 76851,
  [SMALL_STATE(3656)] = 76943,
  [SMALL_STATE(3657)] = 77033,
  [SMALL_STATE(3658)] = 77119,
  [SMALL_STATE(3659)] = 77201,
  [SMALL_STATE(3660)] = 77285,
  [SMALL_STATE(3661)] = 77363,
  [SMALL_STATE(3662)] = 77441,
  [SMALL_STATE(3663)] = 77503,
  [SMALL_STATE(3664)] = 77571,
  [SMALL_STATE(3665)] = 77633,
  [SMALL_STATE(3666)] = 77695,
  [SMALL_STATE(3667)] = 77757,
  [SMALL_STATE(3668)] = 77819,
  [SMALL_STATE(3669)] = 77881,
  [SMALL_STATE(3670)] = 77943,
  [SMALL_STATE(3671)] = 78005,
  [SMALL_STATE(3672)] = 78067,
  [SMALL_STATE(3673)] = 78129,
  [SMALL_STATE(3674)] = 78241,
  [SMALL_STATE(3675)] = 78309,
  [SMALL_STATE(3676)] = 78371,
  [SMALL_STATE(3677)] = 78432,
  [SMALL_STATE(3678)] = 78497,
  [SMALL_STATE(3679)] = 78560,
  [SMALL_STATE(3680)] = 78621,
  [SMALL_STATE(3681)] = 78682,
  [SMALL_STATE(3682)] = 78743,
  [SMALL_STATE(3683)] = 78842,
  [SMALL_STATE(3684)] = 78903,
  [SMALL_STATE(3685)] = 78964,
  [SMALL_STATE(3686)] = 79025,
  [SMALL_STATE(3687)] = 79086,
  [SMALL_STATE(3688)] = 79185,
  [SMALL_STATE(3689)] = 79248,
  [SMALL_STATE(3690)] = 79309,
  [SMALL_STATE(3691)] = 79370,
  [SMALL_STATE(3692)] = 79435,
  [SMALL_STATE(3693)] = 79534,
  [SMALL_STATE(3694)] = 79633,
  [SMALL_STATE(3695)] = 79698,
  [SMALL_STATE(3696)] = 79765,
  [SMALL_STATE(3697)] = 79832,
  [SMALL_STATE(3698)] = 79931,
  [SMALL_STATE(3699)] = 80008,
  [SMALL_STATE(3700)] = 80107,
  [SMALL_STATE(3701)] = 80174,
  [SMALL_STATE(3702)] = 80273,
  [SMALL_STATE(3703)] = 80334,
  [SMALL_STATE(3704)] = 80433,
  [SMALL_STATE(3705)] = 80494,
  [SMALL_STATE(3706)] = 80555,
  [SMALL_STATE(3707)] = 80654,
  [SMALL_STATE(3708)] = 80715,
  [SMALL_STATE(3709)] = 80792,
  [SMALL_STATE(3710)] = 80853,
  [SMALL_STATE(3711)] = 80952,
  [SMALL_STATE(3712)] = 81051,
  [SMALL_STATE(3713)] = 81118,
  [SMALL_STATE(3714)] = 81185,
  [SMALL_STATE(3715)] = 81246,
  [SMALL_STATE(3716)] = 81343,
  [SMALL_STATE(3717)] = 81404,
  [SMALL_STATE(3718)] = 81465,
  [SMALL_STATE(3719)] = 81526,
  [SMALL_STATE(3720)] = 81587,
  [SMALL_STATE(3721)] = 81648,
  [SMALL_STATE(3722)] = 81709,
  [SMALL_STATE(3723)] = 81770,
  [SMALL_STATE(3724)] = 81831,
  [SMALL_STATE(3725)] = 81892,
  [SMALL_STATE(3726)] = 81953,
  [SMALL_STATE(3727)] = 82020,
  [SMALL_STATE(3728)] = 82081,
  [SMALL_STATE(3729)] = 82178,
  [SMALL_STATE(3730)] = 82245,
  [SMALL_STATE(3731)] = 82306,
  [SMALL_STATE(3732)] = 82367,
  [SMALL_STATE(3733)] = 82428,
  [SMALL_STATE(3734)] = 82499,
  [SMALL_STATE(3735)] = 82560,
  [SMALL_STATE(3736)] = 82621,
  [SMALL_STATE(3737)] = 82682,
  [SMALL_STATE(3738)] = 82781,
  [SMALL_STATE(3739)] = 82842,
  [SMALL_STATE(3740)] = 82913,
  [SMALL_STATE(3741)] = 82974,
  [SMALL_STATE(3742)] = 83035,
  [SMALL_STATE(3743)] = 83096,
  [SMALL_STATE(3744)] = 83195,
  [SMALL_STATE(3745)] = 83256,
  [SMALL_STATE(3746)] = 83317,
  [SMALL_STATE(3747)] = 83416,
  [SMALL_STATE(3748)] = 83481,
  [SMALL_STATE(3749)] = 83542,
  [SMALL_STATE(3750)] = 83603,
  [SMALL_STATE(3751)] = 83702,
  [SMALL_STATE(3752)] = 83765,
  [SMALL_STATE(3753)] = 83864,
  [SMALL_STATE(3754)] = 83929,
  [SMALL_STATE(3755)] = 83990,
  [SMALL_STATE(3756)] = 84051,
  [SMALL_STATE(3757)] = 84118,
  [SMALL_STATE(3758)] = 84217,
  [SMALL_STATE(3759)] = 84278,
  [SMALL_STATE(3760)] = 84341,
  [SMALL_STATE(3761)] = 84404,
  [SMALL_STATE(3762)] = 84465,
  [SMALL_STATE(3763)] = 84534,
  [SMALL_STATE(3764)] = 84599,
  [SMALL_STATE(3765)] = 84660,
  [SMALL_STATE(3766)] = 84723,
  [SMALL_STATE(3767)] = 84784,
  [SMALL_STATE(3768)] = 84845,
  [SMALL_STATE(3769)] = 84906,
  [SMALL_STATE(3770)] = 84969,
  [SMALL_STATE(3771)] = 85030,
  [SMALL_STATE(3772)] = 85097,
  [SMALL_STATE(3773)] = 85196,
  [SMALL_STATE(3774)] = 85259,
  [SMALL_STATE(3775)] = 85358,
  [SMALL_STATE(3776)] = 85423,
  [SMALL_STATE(3777)] = 85522,
  [SMALL_STATE(3778)] = 85621,
  [SMALL_STATE(3779)] = 85681,
  [SMALL_STATE(3780)] = 85757,
  [SMALL_STATE(3781)] = 85821,
  [SMALL_STATE(3782)] = 85897,
  [SMALL_STATE(3783)] = 85965,
  [SMALL_STATE(3784)] = 86025,
  [SMALL_STATE(3785)] = 86087,
  [SMALL_STATE(3786)] = 86183,
  [SMALL_STATE(3787)] = 86243,
  [SMALL_STATE(3788)] = 86303,
  [SMALL_STATE(3789)] = 86377,
  [SMALL_STATE(3790)] = 86441,
  [SMALL_STATE(3791)] = 86503,
  [SMALL_STATE(3792)] = 86611,
  [SMALL_STATE(3793)] = 86685,
  [SMALL_STATE(3794)] = 86745,
  [SMALL_STATE(3795)] = 86813,
  [SMALL_STATE(3796)] = 86873,
  [SMALL_STATE(3797)] = 86933,
  [SMALL_STATE(3798)] = 86993,
  [SMALL_STATE(3799)] = 87053,
  [SMALL_STATE(3800)] = 87113,
  [SMALL_STATE(3801)] = 87207,
  [SMALL_STATE(3802)] = 87267,
  [SMALL_STATE(3803)] = 87327,
  [SMALL_STATE(3804)] = 87387,
  [SMALL_STATE(3805)] = 87447,
  [SMALL_STATE(3806)] = 87511,
  [SMALL_STATE(3807)] = 87571,
  [SMALL_STATE(3808)] = 87631,
  [SMALL_STATE(3809)] = 87725,
  [SMALL_STATE(3810)] = 87785,
  [SMALL_STATE(3811)] = 87845,
  [SMALL_STATE(3812)] = 87907,
  [SMALL_STATE(3813)] = 87967,
  [SMALL_STATE(3814)] = 88027,
  [SMALL_STATE(3815)] = 88087,
  [SMALL_STATE(3816)] = 88147,
  [SMALL_STATE(3817)] = 88207,
  [SMALL_STATE(3818)] = 88277,
  [SMALL_STATE(3819)] = 88341,
  [SMALL_STATE(3820)] = 88405,
  [SMALL_STATE(3821)] = 88469,
  [SMALL_STATE(3822)] = 88533,
  [SMALL_STATE(3823)] = 88597,
  [SMALL_STATE(3824)] = 88657,
  [SMALL_STATE(3825)] = 88719,
  [SMALL_STATE(3826)] = 88779,
  [SMALL_STATE(3827)] = 88843,
  [SMALL_STATE(3828)] = 88903,
  [SMALL_STATE(3829)] = 88963,
  [SMALL_STATE(3830)] = 89027,
  [SMALL_STATE(3831)] = 89095,
  [SMALL_STATE(3832)] = 89155,
  [SMALL_STATE(3833)] = 89219,
  [SMALL_STATE(3834)] = 89283,
  [SMALL_STATE(3835)] = 89343,
  [SMALL_STATE(3836)] = 89407,
  [SMALL_STATE(3837)] = 89471,
  [SMALL_STATE(3838)] = 89535,
  [SMALL_STATE(3839)] = 89595,
  [SMALL_STATE(3840)] = 89655,
  [SMALL_STATE(3841)] = 89715,
  [SMALL_STATE(3842)] = 89775,
  [SMALL_STATE(3843)] = 89835,
  [SMALL_STATE(3844)] = 89899,
  [SMALL_STATE(3845)] = 89963,
  [SMALL_STATE(3846)] = 90071,
  [SMALL_STATE(3847)] = 90131,
  [SMALL_STATE(3848)] = 90191,
  [SMALL_STATE(3849)] = 90251,
  [SMALL_STATE(3850)] = 90315,
  [SMALL_STATE(3851)] = 90375,
  [SMALL_STATE(3852)] = 90443,
  [SMALL_STATE(3853)] = 90503,
  [SMALL_STATE(3854)] = 90563,
  [SMALL_STATE(3855)] = 90623,
  [SMALL_STATE(3856)] = 90683,
  [SMALL_STATE(3857)] = 90743,
  [SMALL_STATE(3858)] = 90803,
  [SMALL_STATE(3859)] = 90863,
  [SMALL_STATE(3860)] = 90923,
  [SMALL_STATE(3861)] = 90983,
  [SMALL_STATE(3862)] = 91043,
  [SMALL_STATE(3863)] = 91103,
  [SMALL_STATE(3864)] = 91199,
  [SMALL_STATE(3865)] = 91259,
  [SMALL_STATE(3866)] = 91319,
  [SMALL_STATE(3867)] = 91379,
  [SMALL_STATE(3868)] = 91439,
  [SMALL_STATE(3869)] = 91499,
  [SMALL_STATE(3870)] = 91559,
  [SMALL_STATE(3871)] = 91619,
  [SMALL_STATE(3872)] = 91679,
  [SMALL_STATE(3873)] = 91745,
  [SMALL_STATE(3874)] = 91811,
  [SMALL_STATE(3875)] = 91871,
  [SMALL_STATE(3876)] = 91931,
  [SMALL_STATE(3877)] = 91991,
  [SMALL_STATE(3878)] = 92051,
  [SMALL_STATE(3879)] = 92111,
  [SMALL_STATE(3880)] = 92177,
  [SMALL_STATE(3881)] = 92237,
  [SMALL_STATE(3882)] = 92305,
  [SMALL_STATE(3883)] = 92379,
  [SMALL_STATE(3884)] = 92439,
  [SMALL_STATE(3885)] = 92499,
  [SMALL_STATE(3886)] = 92559,
  [SMALL_STATE(3887)] = 92671,
  [SMALL_STATE(3888)] = 92731,
  [SMALL_STATE(3889)] = 92791,
  [SMALL_STATE(3890)] = 92859,
  [SMALL_STATE(3891)] = 92955,
  [SMALL_STATE(3892)] = 93015,
  [SMALL_STATE(3893)] = 93085,
  [SMALL_STATE(3894)] = 93145,
  [SMALL_STATE(3895)] = 93205,
  [SMALL_STATE(3896)] = 93265,
  [SMALL_STATE(3897)] = 93331,
  [SMALL_STATE(3898)] = 93391,
  [SMALL_STATE(3899)] = 93451,
  [SMALL_STATE(3900)] = 93511,
  [SMALL_STATE(3901)] = 93571,
  [SMALL_STATE(3902)] = 93631,
  [SMALL_STATE(3903)] = 93709,
  [SMALL_STATE(3904)] = 93769,
  [SMALL_STATE(3905)] = 93845,
  [SMALL_STATE(3906)] = 93949,
  [SMALL_STATE(3907)] = 94043,
  [SMALL_STATE(3908)] = 94141,
  [SMALL_STATE(3909)] = 94205,
  [SMALL_STATE(3910)] = 94299,
  [SMALL_STATE(3911)] = 94407,
  [SMALL_STATE(3912)] = 94497,
  [SMALL_STATE(3913)] = 94585,
  [SMALL_STATE(3914)] = 94669,
  [SMALL_STATE(3915)] = 94729,
  [SMALL_STATE(3916)] = 94789,
  [SMALL_STATE(3917)] = 94887,
  [SMALL_STATE(3918)] = 94947,
  [SMALL_STATE(3919)] = 95007,
  [SMALL_STATE(3920)] = 95087,
  [SMALL_STATE(3921)] = 95147,
  [SMALL_STATE(3922)] = 95207,
  [SMALL_STATE(3923)] = 95289,
  [SMALL_STATE(3924)] = 95349,
  [SMALL_STATE(3925)] = 95447,
  [SMALL_STATE(3926)] = 95507,
  [SMALL_STATE(3927)] = 95567,
  [SMALL_STATE(3928)] = 95629,
  [SMALL_STATE(3929)] = 95689,
  [SMALL_STATE(3930)] = 95749,
  [SMALL_STATE(3931)] = 95809,
  [SMALL_STATE(3932)] = 95869,
  [SMALL_STATE(3933)] = 95929,
  [SMALL_STATE(3934)] = 95989,
  [SMALL_STATE(3935)] = 96049,
  [SMALL_STATE(3936)] = 96125,
  [SMALL_STATE(3937)] = 96185,
  [SMALL_STATE(3938)] = 96245,
  [SMALL_STATE(3939)] = 96343,
  [SMALL_STATE(3940)] = 96409,
  [SMALL_STATE(3941)] = 96469,
  [SMALL_STATE(3942)] = 96529,
  [SMALL_STATE(3943)] = 96589,
  [SMALL_STATE(3944)] = 96649,
  [SMALL_STATE(3945)] = 96709,
  [SMALL_STATE(3946)] = 96769,
  [SMALL_STATE(3947)] = 96829,
  [SMALL_STATE(3948)] = 96889,
  [SMALL_STATE(3949)] = 96949,
  [SMALL_STATE(3950)] = 97009,
  [SMALL_STATE(3951)] = 97069,
  [SMALL_STATE(3952)] = 97129,
  [SMALL_STATE(3953)] = 97189,
  [SMALL_STATE(3954)] = 97249,
  [SMALL_STATE(3955)] = 97345,
  [SMALL_STATE(3956)] = 97405,
  [SMALL_STATE(3957)] = 97465,
  [SMALL_STATE(3958)] = 97525,
  [SMALL_STATE(3959)] = 97593,
  [SMALL_STATE(3960)] = 97653,
  [SMALL_STATE(3961)] = 97751,
  [SMALL_STATE(3962)] = 97859,
  [SMALL_STATE(3963)] = 97925,
  [SMALL_STATE(3964)] = 98019,
  [SMALL_STATE(3965)] = 98079,
  [SMALL_STATE(3966)] = 98173,
  [SMALL_STATE(3967)] = 98233,
  [SMALL_STATE(3968)] = 98293,
  [SMALL_STATE(3969)] = 98353,
  [SMALL_STATE(3970)] = 98413,
  [SMALL_STATE(3971)] = 98473,
  [SMALL_STATE(3972)] = 98535,
  [SMALL_STATE(3973)] = 98595,
  [SMALL_STATE(3974)] = 98655,
  [SMALL_STATE(3975)] = 98715,
  [SMALL_STATE(3976)] = 98827,
  [SMALL_STATE(3977)] = 98887,
  [SMALL_STATE(3978)] = 98947,
  [SMALL_STATE(3979)] = 99007,
  [SMALL_STATE(3980)] = 99067,
  [SMALL_STATE(3981)] = 99127,
  [SMALL_STATE(3982)] = 99187,
  [SMALL_STATE(3983)] = 99247,
  [SMALL_STATE(3984)] = 99355,
  [SMALL_STATE(3985)] = 99421,
  [SMALL_STATE(3986)] = 99481,
  [SMALL_STATE(3987)] = 99541,
  [SMALL_STATE(3988)] = 99601,
  [SMALL_STATE(3989)] = 99661,
  [SMALL_STATE(3990)] = 99721,
  [SMALL_STATE(3991)] = 99781,
  [SMALL_STATE(3992)] = 99841,
  [SMALL_STATE(3993)] = 99901,
  [SMALL_STATE(3994)] = 99961,
  [SMALL_STATE(3995)] = 100021,
  [SMALL_STATE(3996)] = 100081,
  [SMALL_STATE(3997)] = 100141,
  [SMALL_STATE(3998)] = 100201,
  [SMALL_STATE(3999)] = 100295,
  [SMALL_STATE(4000)] = 100355,
  [SMALL_STATE(4001)] = 100415,
  [SMALL_STATE(4002)] = 100475,
  [SMALL_STATE(4003)] = 100537,
  [SMALL_STATE(4004)] = 100597,
  [SMALL_STATE(4005)] = 100709,
  [SMALL_STATE(4006)] = 100769,
  [SMALL_STATE(4007)] = 100829,
  [SMALL_STATE(4008)] = 100889,
  [SMALL_STATE(4009)] = 100949,
  [SMALL_STATE(4010)] = 101009,
  [SMALL_STATE(4011)] = 101069,
  [SMALL_STATE(4012)] = 101129,
  [SMALL_STATE(4013)] = 101189,
  [SMALL_STATE(4014)] = 101249,
  [SMALL_STATE(4015)] = 101309,
  [SMALL_STATE(4016)] = 101411,
  [SMALL_STATE(4017)] = 101474,
  [SMALL_STATE(4018)] = 101533,
  [SMALL_STATE(4019)] = 101592,
  [SMALL_STATE(4020)] = 101651,
  [SMALL_STATE(4021)] = 101710,
  [SMALL_STATE(4022)] = 101805,
  [SMALL_STATE(4023)] = 101864,
  [SMALL_STATE(4024)] = 101923,
  [SMALL_STATE(4025)] = 102018,
  [SMALL_STATE(4026)] = 102081,
  [SMALL_STATE(4027)] = 102140,
  [SMALL_STATE(4028)] = 102235,
  [SMALL_STATE(4029)] = 102294,
  [SMALL_STATE(4030)] = 102353,
  [SMALL_STATE(4031)] = 102412,
  [SMALL_STATE(4032)] = 102507,
  [SMALL_STATE(4033)] = 102566,
  [SMALL_STATE(4034)] = 102625,
  [SMALL_STATE(4035)] = 102684,
  [SMALL_STATE(4036)] = 102743,
  [SMALL_STATE(4037)] = 102802,
  [SMALL_STATE(4038)] = 102861,
  [SMALL_STATE(4039)] = 102920,
  [SMALL_STATE(4040)] = 102979,
  [SMALL_STATE(4041)] = 103038,
  [SMALL_STATE(4042)] = 103097,
  [SMALL_STATE(4043)] = 103156,
  [SMALL_STATE(4044)] = 103215,
  [SMALL_STATE(4045)] = 103276,
  [SMALL_STATE(4046)] = 103335,
  [SMALL_STATE(4047)] = 103394,
  [SMALL_STATE(4048)] = 103453,
  [SMALL_STATE(4049)] = 103512,
  [SMALL_STATE(4050)] = 103571,
  [SMALL_STATE(4051)] = 103630,
  [SMALL_STATE(4052)] = 103689,
  [SMALL_STATE(4053)] = 103748,
  [SMALL_STATE(4054)] = 103809,
  [SMALL_STATE(4055)] = 103868,
  [SMALL_STATE(4056)] = 103927,
  [SMALL_STATE(4057)] = 103986,
  [SMALL_STATE(4058)] = 104045,
  [SMALL_STATE(4059)] = 104104,
  [SMALL_STATE(4060)] = 104199,
  [SMALL_STATE(4061)] = 104258,
  [SMALL_STATE(4062)] = 104317,
  [SMALL_STATE(4063)] = 104376,
  [SMALL_STATE(4064)] = 104435,
  [SMALL_STATE(4065)] = 104494,
  [SMALL_STATE(4066)] = 104553,
  [SMALL_STATE(4067)] = 104612,
  [SMALL_STATE(4068)] = 104671,
  [SMALL_STATE(4069)] = 104730,
  [SMALL_STATE(4070)] = 104789,
  [SMALL_STATE(4071)] = 104848,
  [SMALL_STATE(4072)] = 104907,
  [SMALL_STATE(4073)] = 104966,
  [SMALL_STATE(4074)] = 105025,
  [SMALL_STATE(4075)] = 105084,
  [SMALL_STATE(4076)] = 105143,
  [SMALL_STATE(4077)] = 105202,
  [SMALL_STATE(4078)] = 105261,
  [SMALL_STATE(4079)] = 105320,
  [SMALL_STATE(4080)] = 105379,
  [SMALL_STATE(4081)] = 105438,
  [SMALL_STATE(4082)] = 105533,
  [SMALL_STATE(4083)] = 105592,
  [SMALL_STATE(4084)] = 105687,
  [SMALL_STATE(4085)] = 105782,
  [SMALL_STATE(4086)] = 105877,
  [SMALL_STATE(4087)] = 105936,
  [SMALL_STATE(4088)] = 105995,
  [SMALL_STATE(4089)] = 106054,
  [SMALL_STATE(4090)] = 106149,
  [SMALL_STATE(4091)] = 106212,
  [SMALL_STATE(4092)] = 106271,
  [SMALL_STATE(4093)] = 106330,
  [SMALL_STATE(4094)] = 106425,
  [SMALL_STATE(4095)] = 106484,
  [SMALL_STATE(4096)] = 106543,
  [SMALL_STATE(4097)] = 106602,
  [SMALL_STATE(4098)] = 106661,
  [SMALL_STATE(4099)] = 106720,
  [SMALL_STATE(4100)] = 106779,
  [SMALL_STATE(4101)] = 106838,
  [SMALL_STATE(4102)] = 106897,
  [SMALL_STATE(4103)] = 106992,
  [SMALL_STATE(4104)] = 107051,
  [SMALL_STATE(4105)] = 107110,
  [SMALL_STATE(4106)] = 107169,
  [SMALL_STATE(4107)] = 107228,
  [SMALL_STATE(4108)] = 107287,
  [SMALL_STATE(4109)] = 107346,
  [SMALL_STATE(4110)] = 107405,
  [SMALL_STATE(4111)] = 107464,
  [SMALL_STATE(4112)] = 107523,
  [SMALL_STATE(4113)] = 107582,
  [SMALL_STATE(4114)] = 107641,
  [SMALL_STATE(4115)] = 107700,
  [SMALL_STATE(4116)] = 107759,
  [SMALL_STATE(4117)] = 107818,
  [SMALL_STATE(4118)] = 107877,
  [SMALL_STATE(4119)] = 107936,
  [SMALL_STATE(4120)] = 107995,
  [SMALL_STATE(4121)] = 108054,
  [SMALL_STATE(4122)] = 108123,
  [SMALL_STATE(4123)] = 108218,
  [SMALL_STATE(4124)] = 108277,
  [SMALL_STATE(4125)] = 108336,
  [SMALL_STATE(4126)] = 108395,
  [SMALL_STATE(4127)] = 108454,
  [SMALL_STATE(4128)] = 108513,
  [SMALL_STATE(4129)] = 108608,
  [SMALL_STATE(4130)] = 108667,
  [SMALL_STATE(4131)] = 108726,
  [SMALL_STATE(4132)] = 108785,
  [SMALL_STATE(4133)] = 108844,
  [SMALL_STATE(4134)] = 108939,
  [SMALL_STATE(4135)] = 109034,
  [SMALL_STATE(4136)] = 109097,
  [SMALL_STATE(4137)] = 109192,
  [SMALL_STATE(4138)] = 109253,
  [SMALL_STATE(4139)] = 109314,
  [SMALL_STATE(4140)] = 109377,
  [SMALL_STATE(4141)] = 109436,
  [SMALL_STATE(4142)] = 109507,
  [SMALL_STATE(4143)] = 109566,
  [SMALL_STATE(4144)] = 109661,
  [SMALL_STATE(4145)] = 109756,
  [SMALL_STATE(4146)] = 109851,
  [SMALL_STATE(4147)] = 109910,
  [SMALL_STATE(4148)] = 109969,
  [SMALL_STATE(4149)] = 110028,
  [SMALL_STATE(4150)] = 110087,
  [SMALL_STATE(4151)] = 110146,
  [SMALL_STATE(4152)] = 110205,
  [SMALL_STATE(4153)] = 110264,
  [SMALL_STATE(4154)] = 110359,
  [SMALL_STATE(4155)] = 110454,
  [SMALL_STATE(4156)] = 110513,
  [SMALL_STATE(4157)] = 110572,
  [SMALL_STATE(4158)] = 110635,
  [SMALL_STATE(4159)] = 110694,
  [SMALL_STATE(4160)] = 110753,
  [SMALL_STATE(4161)] = 110824,
  [SMALL_STATE(4162)] = 110883,
  [SMALL_STATE(4163)] = 110942,
  [SMALL_STATE(4164)] = 111009,
  [SMALL_STATE(4165)] = 111104,
  [SMALL_STATE(4166)] = 111169,
  [SMALL_STATE(4167)] = 111228,
  [SMALL_STATE(4168)] = 111323,
  [SMALL_STATE(4169)] = 111418,
  [SMALL_STATE(4170)] = 111477,
  [SMALL_STATE(4171)] = 111572,
  [SMALL_STATE(4172)] = 111631,
  [SMALL_STATE(4173)] = 111690,
  [SMALL_STATE(4174)] = 111749,
  [SMALL_STATE(4175)] = 111808,
  [SMALL_STATE(4176)] = 111867,
  [SMALL_STATE(4177)] = 111926,
  [SMALL_STATE(4178)] = 111985,
  [SMALL_STATE(4179)] = 112044,
  [SMALL_STATE(4180)] = 112107,
  [SMALL_STATE(4181)] = 112166,
  [SMALL_STATE(4182)] = 112225,
  [SMALL_STATE(4183)] = 112284,
  [SMALL_STATE(4184)] = 112343,
  [SMALL_STATE(4185)] = 112402,
  [SMALL_STATE(4186)] = 112461,
  [SMALL_STATE(4187)] = 112520,
  [SMALL_STATE(4188)] = 112579,
  [SMALL_STATE(4189)] = 112638,
  [SMALL_STATE(4190)] = 112701,
  [SMALL_STATE(4191)] = 112760,
  [SMALL_STATE(4192)] = 112819,
  [SMALL_STATE(4193)] = 112878,
  [SMALL_STATE(4194)] = 112937,
  [SMALL_STATE(4195)] = 112996,
  [SMALL_STATE(4196)] = 113055,
  [SMALL_STATE(4197)] = 113114,
  [SMALL_STATE(4198)] = 113173,
  [SMALL_STATE(4199)] = 113232,
  [SMALL_STATE(4200)] = 113327,
  [SMALL_STATE(4201)] = 113386,
  [SMALL_STATE(4202)] = 113445,
  [SMALL_STATE(4203)] = 113504,
  [SMALL_STATE(4204)] = 113567,
  [SMALL_STATE(4205)] = 113632,
  [SMALL_STATE(4206)] = 113727,
  [SMALL_STATE(4207)] = 113786,
  [SMALL_STATE(4208)] = 113881,
  [SMALL_STATE(4209)] = 113940,
  [SMALL_STATE(4210)] = 113999,
  [SMALL_STATE(4211)] = 114094,
  [SMALL_STATE(4212)] = 114153,
  [SMALL_STATE(4213)] = 114216,
  [SMALL_STATE(4214)] = 114279,
  [SMALL_STATE(4215)] = 114338,
  [SMALL_STATE(4216)] = 114399,
  [SMALL_STATE(4217)] = 114494,
  [SMALL_STATE(4218)] = 114553,
  [SMALL_STATE(4219)] = 114612,
  [SMALL_STATE(4220)] = 114707,
  [SMALL_STATE(4221)] = 114802,
  [SMALL_STATE(4222)] = 114861,
  [SMALL_STATE(4223)] = 114920,
  [SMALL_STATE(4224)] = 114979,
  [SMALL_STATE(4225)] = 115038,
  [SMALL_STATE(4226)] = 115097,
  [SMALL_STATE(4227)] = 115192,
  [SMALL_STATE(4228)] = 115251,
  [SMALL_STATE(4229)] = 115346,
  [SMALL_STATE(4230)] = 115405,
  [SMALL_STATE(4231)] = 115464,
  [SMALL_STATE(4232)] = 115523,
  [SMALL_STATE(4233)] = 115582,
  [SMALL_STATE(4234)] = 115641,
  [SMALL_STATE(4235)] = 115710,
  [SMALL_STATE(4236)] = 115769,
  [SMALL_STATE(4237)] = 115828,
  [SMALL_STATE(4238)] = 115887,
  [SMALL_STATE(4239)] = 115946,
  [SMALL_STATE(4240)] = 116005,
  [SMALL_STATE(4241)] = 116064,
  [SMALL_STATE(4242)] = 116123,
  [SMALL_STATE(4243)] = 116182,
  [SMALL_STATE(4244)] = 116241,
  [SMALL_STATE(4245)] = 116300,
  [SMALL_STATE(4246)] = 116359,
  [SMALL_STATE(4247)] = 116418,
  [SMALL_STATE(4248)] = 116477,
  [SMALL_STATE(4249)] = 116536,
  [SMALL_STATE(4250)] = 116595,
  [SMALL_STATE(4251)] = 116654,
  [SMALL_STATE(4252)] = 116713,
  [SMALL_STATE(4253)] = 116772,
  [SMALL_STATE(4254)] = 116843,
  [SMALL_STATE(4255)] = 116938,
  [SMALL_STATE(4256)] = 117005,
  [SMALL_STATE(4257)] = 117064,
  [SMALL_STATE(4258)] = 117123,
  [SMALL_STATE(4259)] = 117182,
  [SMALL_STATE(4260)] = 117241,
  [SMALL_STATE(4261)] = 117300,
  [SMALL_STATE(4262)] = 117359,
  [SMALL_STATE(4263)] = 117426,
  [SMALL_STATE(4264)] = 117490,
  [SMALL_STATE(4265)] = 117548,
  [SMALL_STATE(4266)] = 117612,
  [SMALL_STATE(4267)] = 117670,
  [SMALL_STATE(4268)] = 117728,
  [SMALL_STATE(4269)] = 117786,
  [SMALL_STATE(4270)] = 117850,
  [SMALL_STATE(4271)] = 117944,
  [SMALL_STATE(4272)] = 118038,
  [SMALL_STATE(4273)] = 118096,
  [SMALL_STATE(4274)] = 118154,
  [SMALL_STATE(4275)] = 118218,
  [SMALL_STATE(4276)] = 118278,
  [SMALL_STATE(4277)] = 118352,
  [SMALL_STATE(4278)] = 118424,
  [SMALL_STATE(4279)] = 118488,
  [SMALL_STATE(4280)] = 118546,
  [SMALL_STATE(4281)] = 118620,
  [SMALL_STATE(4282)] = 118682,
  [SMALL_STATE(4283)] = 118740,
  [SMALL_STATE(4284)] = 118802,
  [SMALL_STATE(4285)] = 118894,
  [SMALL_STATE(4286)] = 118986,
  [SMALL_STATE(4287)] = 119044,
  [SMALL_STATE(4288)] = 119102,
  [SMALL_STATE(4289)] = 119166,
  [SMALL_STATE(4290)] = 119224,
  [SMALL_STATE(4291)] = 119282,
  [SMALL_STATE(4292)] = 119373,
  [SMALL_STATE(4293)] = 119430,
  [SMALL_STATE(4294)] = 119487,
  [SMALL_STATE(4295)] = 119578,
  [SMALL_STATE(4296)] = 119635,
  [SMALL_STATE(4297)] = 119692,
  [SMALL_STATE(4298)] = 119749,
  [SMALL_STATE(4299)] = 119840,
  [SMALL_STATE(4300)] = 119897,
  [SMALL_STATE(4301)] = 119954,
  [SMALL_STATE(4302)] = 120011,
  [SMALL_STATE(4303)] = 120068,
  [SMALL_STATE(4304)] = 120125,
  [SMALL_STATE(4305)] = 120218,
  [SMALL_STATE(4306)] = 120309,
  [SMALL_STATE(4307)] = 120366,
  [SMALL_STATE(4308)] = 120423,
  [SMALL_STATE(4309)] = 120514,
  [SMALL_STATE(4310)] = 120599,
  [SMALL_STATE(4311)] = 120656,
  [SMALL_STATE(4312)] = 120713,
  [SMALL_STATE(4313)] = 120770,
  [SMALL_STATE(4314)] = 120861,
  [SMALL_STATE(4315)] = 120918,
  [SMALL_STATE(4316)] = 120975,
  [SMALL_STATE(4317)] = 121036,
  [SMALL_STATE(4318)] = 121093,
  [SMALL_STATE(4319)] = 121164,
  [SMALL_STATE(4320)] = 121235,
  [SMALL_STATE(4321)] = 121292,
  [SMALL_STATE(4322)] = 121349,
  [SMALL_STATE(4323)] = 121406,
  [SMALL_STATE(4324)] = 121463,
  [SMALL_STATE(4325)] = 121520,
  [SMALL_STATE(4326)] = 121577,
  [SMALL_STATE(4327)] = 121634,
  [SMALL_STATE(4328)] = 121691,
  [SMALL_STATE(4329)] = 121748,
  [SMALL_STATE(4330)] = 121805,
  [SMALL_STATE(4331)] = 121878,
  [SMALL_STATE(4332)] = 121935,
  [SMALL_STATE(4333)] = 121992,
  [SMALL_STATE(4334)] = 122049,
  [SMALL_STATE(4335)] = 122106,
  [SMALL_STATE(4336)] = 122163,
  [SMALL_STATE(4337)] = 122248,
  [SMALL_STATE(4338)] = 122339,
  [SMALL_STATE(4339)] = 122396,
  [SMALL_STATE(4340)] = 122453,
  [SMALL_STATE(4341)] = 122510,
  [SMALL_STATE(4342)] = 122567,
  [SMALL_STATE(4343)] = 122624,
  [SMALL_STATE(4344)] = 122681,
  [SMALL_STATE(4345)] = 122746,
  [SMALL_STATE(4346)] = 122811,
  [SMALL_STATE(4347)] = 122868,
  [SMALL_STATE(4348)] = 122941,
  [SMALL_STATE(4349)] = 122998,
  [SMALL_STATE(4350)] = 123055,
  [SMALL_STATE(4351)] = 123112,
  [SMALL_STATE(4352)] = 123169,
  [SMALL_STATE(4353)] = 123254,
  [SMALL_STATE(4354)] = 123327,
  [SMALL_STATE(4355)] = 123384,
  [SMALL_STATE(4356)] = 123441,
  [SMALL_STATE(4357)] = 123526,
  [SMALL_STATE(4358)] = 123583,
  [SMALL_STATE(4359)] = 123676,
  [SMALL_STATE(4360)] = 123733,
  [SMALL_STATE(4361)] = 123790,
  [SMALL_STATE(4362)] = 123883,
  [SMALL_STATE(4363)] = 123956,
  [SMALL_STATE(4364)] = 124013,
  [SMALL_STATE(4365)] = 124098,
  [SMALL_STATE(4366)] = 124163,
  [SMALL_STATE(4367)] = 124220,
  [SMALL_STATE(4368)] = 124277,
  [SMALL_STATE(4369)] = 124366,
  [SMALL_STATE(4370)] = 124423,
  [SMALL_STATE(4371)] = 124480,
  [SMALL_STATE(4372)] = 124537,
  [SMALL_STATE(4373)] = 124594,
  [SMALL_STATE(4374)] = 124651,
  [SMALL_STATE(4375)] = 124708,
  [SMALL_STATE(4376)] = 124765,
  [SMALL_STATE(4377)] = 124858,
  [SMALL_STATE(4378)] = 124915,
  [SMALL_STATE(4379)] = 124972,
  [SMALL_STATE(4380)] = 125029,
  [SMALL_STATE(4381)] = 125086,
  [SMALL_STATE(4382)] = 125171,
  [SMALL_STATE(4383)] = 125228,
  [SMALL_STATE(4384)] = 125313,
  [SMALL_STATE(4385)] = 125398,
  [SMALL_STATE(4386)] = 125483,
  [SMALL_STATE(4387)] = 125540,
  [SMALL_STATE(4388)] = 125625,
  [SMALL_STATE(4389)] = 125682,
  [SMALL_STATE(4390)] = 125739,
  [SMALL_STATE(4391)] = 125796,
  [SMALL_STATE(4392)] = 125853,
  [SMALL_STATE(4393)] = 125938,
  [SMALL_STATE(4394)] = 125997,
  [SMALL_STATE(4395)] = 126054,
  [SMALL_STATE(4396)] = 126111,
  [SMALL_STATE(4397)] = 126168,
  [SMALL_STATE(4398)] = 126225,
  [SMALL_STATE(4399)] = 126282,
  [SMALL_STATE(4400)] = 126339,
  [SMALL_STATE(4401)] = 126396,
  [SMALL_STATE(4402)] = 126453,
  [SMALL_STATE(4403)] = 126544,
  [SMALL_STATE(4404)] = 126601,
  [SMALL_STATE(4405)] = 126692,
  [SMALL_STATE(4406)] = 126767,
  [SMALL_STATE(4407)] = 126824,
  [SMALL_STATE(4408)] = 126881,
  [SMALL_STATE(4409)] = 126938,
  [SMALL_STATE(4410)] = 127029,
  [SMALL_STATE(4411)] = 127086,
  [SMALL_STATE(4412)] = 127171,
  [SMALL_STATE(4413)] = 127260,
  [SMALL_STATE(4414)] = 127317,
  [SMALL_STATE(4415)] = 127374,
  [SMALL_STATE(4416)] = 127439,
  [SMALL_STATE(4417)] = 127496,
  [SMALL_STATE(4418)] = 127553,
  [SMALL_STATE(4419)] = 127610,
  [SMALL_STATE(4420)] = 127667,
  [SMALL_STATE(4421)] = 127724,
  [SMALL_STATE(4422)] = 127789,
  [SMALL_STATE(4423)] = 127854,
  [SMALL_STATE(4424)] = 127911,
  [SMALL_STATE(4425)] = 127968,
  [SMALL_STATE(4426)] = 128025,
  [SMALL_STATE(4427)] = 128082,
  [SMALL_STATE(4428)] = 128139,
  [SMALL_STATE(4429)] = 128196,
  [SMALL_STATE(4430)] = 128253,
  [SMALL_STATE(4431)] = 128313,
  [SMALL_STATE(4432)] = 128385,
  [SMALL_STATE(4433)] = 128441,
  [SMALL_STATE(4434)] = 128513,
  [SMALL_STATE(4435)] = 128573,
  [SMALL_STATE(4436)] = 128633,
  [SMALL_STATE(4437)] = 128693,
  [SMALL_STATE(4438)] = 128759,
  [SMALL_STATE(4439)] = 128819,
  [SMALL_STATE(4440)] = 128885,
  [SMALL_STATE(4441)] = 128951,
  [SMALL_STATE(4442)] = 129011,
  [SMALL_STATE(4443)] = 129077,
  [SMALL_STATE(4444)] = 129137,
  [SMALL_STATE(4445)] = 129197,
  [SMALL_STATE(4446)] = 129257,
  [SMALL_STATE(4447)] = 129317,
  [SMALL_STATE(4448)] = 129377,
  [SMALL_STATE(4449)] = 129449,
  [SMALL_STATE(4450)] = 129509,
  [SMALL_STATE(4451)] = 129569,
  [SMALL_STATE(4452)] = 129625,
  [SMALL_STATE(4453)] = 129717,
  [SMALL_STATE(4454)] = 129773,
  [SMALL_STATE(4455)] = 129833,
  [SMALL_STATE(4456)] = 129905,
  [SMALL_STATE(4457)] = 129993,
  [SMALL_STATE(4458)] = 130053,
  [SMALL_STATE(4459)] = 130113,
  [SMALL_STATE(4460)] = 130173,
  [SMALL_STATE(4461)] = 130233,
  [SMALL_STATE(4462)] = 130321,
  [SMALL_STATE(4463)] = 130413,
  [SMALL_STATE(4464)] = 130505,
  [SMALL_STATE(4465)] = 130575,
  [SMALL_STATE(4466)] = 130645,
  [SMALL_STATE(4467)] = 130705,
  [SMALL_STATE(4468)] = 130765,
  [SMALL_STATE(4469)] = 130821,
  [SMALL_STATE(4470)] = 130877,
  [SMALL_STATE(4471)] = 130949,
  [SMALL_STATE(4472)] = 131005,
  [SMALL_STATE(4473)] = 131097,
  [SMALL_STATE(4474)] = 131169,
  [SMALL_STATE(4475)] = 131229,
  [SMALL_STATE(4476)] = 131289,
  [SMALL_STATE(4477)] = 131349,
  [SMALL_STATE(4478)] = 131405,
  [SMALL_STATE(4479)] = 131465,
  [SMALL_STATE(4480)] = 131525,
  [SMALL_STATE(4481)] = 131581,
  [SMALL_STATE(4482)] = 131640,
  [SMALL_STATE(4483)] = 131699,
  [SMALL_STATE(4484)] = 131760,
  [SMALL_STATE(4485)] = 131819,
  [SMALL_STATE(4486)] = 131880,
  [SMALL_STATE(4487)] = 131939,
  [SMALL_STATE(4488)] = 131994,
  [SMALL_STATE(4489)] = 132055,
  [SMALL_STATE(4490)] = 132138,
  [SMALL_STATE(4491)] = 132197,
  [SMALL_STATE(4492)] = 132256,
  [SMALL_STATE(4493)] = 132317,
  [SMALL_STATE(4494)] = 132372,
  [SMALL_STATE(4495)] = 132455,
  [SMALL_STATE(4496)] = 132538,
  [SMALL_STATE(4497)] = 132593,
  [SMALL_STATE(4498)] = 132676,
  [SMALL_STATE(4499)] = 132737,
  [SMALL_STATE(4500)] = 132792,
  [SMALL_STATE(4501)] = 132851,
  [SMALL_STATE(4502)] = 132910,
  [SMALL_STATE(4503)] = 132969,
  [SMALL_STATE(4504)] = 133028,
  [SMALL_STATE(4505)] = 133089,
  [SMALL_STATE(4506)] = 133178,
  [SMALL_STATE(4507)] = 133265,
  [SMALL_STATE(4508)] = 133320,
  [SMALL_STATE(4509)] = 133381,
  [SMALL_STATE(4510)] = 133436,
  [SMALL_STATE(4511)] = 133491,
  [SMALL_STATE(4512)] = 133578,
  [SMALL_STATE(4513)] = 133633,
  [SMALL_STATE(4514)] = 133694,
  [SMALL_STATE(4515)] = 133755,
  [SMALL_STATE(4516)] = 133826,
  [SMALL_STATE(4517)] = 133891,
  [SMALL_STATE(4518)] = 133950,
  [SMALL_STATE(4519)] = 134009,
  [SMALL_STATE(4520)] = 134098,
  [SMALL_STATE(4521)] = 134159,
  [SMALL_STATE(4522)] = 134246,
  [SMALL_STATE(4523)] = 134317,
  [SMALL_STATE(4524)] = 134406,
  [SMALL_STATE(4525)] = 134479,
  [SMALL_STATE(4526)] = 134588,
  [SMALL_STATE(4527)] = 134649,
  [SMALL_STATE(4528)] = 134738,
  [SMALL_STATE(4529)] = 134793,
  [SMALL_STATE(4530)] = 134880,
  [SMALL_STATE(4531)] = 134989,
  [SMALL_STATE(4532)] = 135054,
  [SMALL_STATE(4533)] = 135115,
  [SMALL_STATE(4534)] = 135174,
  [SMALL_STATE(4535)] = 135264,
  [SMALL_STATE(4536)] = 135332,
  [SMALL_STATE(4537)] = 135396,
  [SMALL_STATE(4538)] = 135450,
  [SMALL_STATE(4539)] = 135510,
  [SMALL_STATE(4540)] = 135564,
  [SMALL_STATE(4541)] = 135644,
  [SMALL_STATE(4542)] = 135698,
  [SMALL_STATE(4543)] = 135752,
  [SMALL_STATE(4544)] = 135820,
  [SMALL_STATE(4545)] = 135874,
  [SMALL_STATE(4546)] = 135928,
  [SMALL_STATE(4547)] = 135996,
  [SMALL_STATE(4548)] = 136064,
  [SMALL_STATE(4549)] = 136146,
  [SMALL_STATE(4550)] = 136228,
  [SMALL_STATE(4551)] = 136310,
  [SMALL_STATE(4552)] = 136392,
  [SMALL_STATE(4553)] = 136472,
  [SMALL_STATE(4554)] = 136552,
  [SMALL_STATE(4555)] = 136638,
  [SMALL_STATE(4556)] = 136692,
  [SMALL_STATE(4557)] = 136748,
  [SMALL_STATE(4558)] = 136802,
  [SMALL_STATE(4559)] = 136856,
  [SMALL_STATE(4560)] = 136910,
  [SMALL_STATE(4561)] = 136966,
  [SMALL_STATE(4562)] = 137022,
  [SMALL_STATE(4563)] = 137086,
  [SMALL_STATE(4564)] = 137154,
  [SMALL_STATE(4565)] = 137244,
  [SMALL_STATE(4566)] = 137308,
  [SMALL_STATE(4567)] = 137362,
  [SMALL_STATE(4568)] = 137416,
  [SMALL_STATE(4569)] = 137470,
  [SMALL_STATE(4570)] = 137556,
  [SMALL_STATE(4571)] = 137642,
  [SMALL_STATE(4572)] = 137728,
  [SMALL_STATE(4573)] = 137798,
  [SMALL_STATE(4574)] = 137868,
  [SMALL_STATE(4575)] = 137936,
  [SMALL_STATE(4576)] = 138006,
  [SMALL_STATE(4577)] = 138076,
  [SMALL_STATE(4578)] = 138144,
  [SMALL_STATE(4579)] = 138208,
  [SMALL_STATE(4580)] = 138276,
  [SMALL_STATE(4581)] = 138356,
  [SMALL_STATE(4582)] = 138410,
  [SMALL_STATE(4583)] = 138466,
  [SMALL_STATE(4584)] = 138520,
  [SMALL_STATE(4585)] = 138573,
  [SMALL_STATE(4586)] = 138664,
  [SMALL_STATE(4587)] = 138717,
  [SMALL_STATE(4588)] = 138770,
  [SMALL_STATE(4589)] = 138823,
  [SMALL_STATE(4590)] = 138876,
  [SMALL_STATE(4591)] = 138929,
  [SMALL_STATE(4592)] = 138982,
  [SMALL_STATE(4593)] = 139035,
  [SMALL_STATE(4594)] = 139088,
  [SMALL_STATE(4595)] = 139141,
  [SMALL_STATE(4596)] = 139230,
  [SMALL_STATE(4597)] = 139315,
  [SMALL_STATE(4598)] = 139396,
  [SMALL_STATE(4599)] = 139471,
  [SMALL_STATE(4600)] = 139524,
  [SMALL_STATE(4601)] = 139623,
  [SMALL_STATE(4602)] = 139686,
  [SMALL_STATE(4603)] = 139739,
  [SMALL_STATE(4604)] = 139792,
  [SMALL_STATE(4605)] = 139871,
  [SMALL_STATE(4606)] = 139950,
  [SMALL_STATE(4607)] = 140029,
  [SMALL_STATE(4608)] = 140092,
  [SMALL_STATE(4609)] = 140145,
  [SMALL_STATE(4610)] = 140252,
  [SMALL_STATE(4611)] = 140305,
  [SMALL_STATE(4612)] = 140358,
  [SMALL_STATE(4613)] = 140469,
  [SMALL_STATE(4614)] = 140522,
  [SMALL_STATE(4615)] = 140629,
  [SMALL_STATE(4616)] = 140740,
  [SMALL_STATE(4617)] = 140793,
  [SMALL_STATE(4618)] = 140900,
  [SMALL_STATE(4619)] = 141007,
  [SMALL_STATE(4620)] = 141060,
  [SMALL_STATE(4621)] = 141113,
  [SMALL_STATE(4622)] = 141166,
  [SMALL_STATE(4623)] = 141219,
  [SMALL_STATE(4624)] = 141298,
  [SMALL_STATE(4625)] = 141351,
  [SMALL_STATE(4626)] = 141404,
  [SMALL_STATE(4627)] = 141515,
  [SMALL_STATE(4628)] = 141568,
  [SMALL_STATE(4629)] = 141621,
  [SMALL_STATE(4630)] = 141674,
  [SMALL_STATE(4631)] = 141727,
  [SMALL_STATE(4632)] = 141798,
  [SMALL_STATE(4633)] = 141851,
  [SMALL_STATE(4634)] = 141910,
  [SMALL_STATE(4635)] = 141967,
  [SMALL_STATE(4636)] = 142074,
  [SMALL_STATE(4637)] = 142127,
  [SMALL_STATE(4638)] = 142238,
  [SMALL_STATE(4639)] = 142311,
  [SMALL_STATE(4640)] = 142368,
  [SMALL_STATE(4641)] = 142425,
  [SMALL_STATE(4642)] = 142482,
  [SMALL_STATE(4643)] = 142551,
  [SMALL_STATE(4644)] = 142608,
  [SMALL_STATE(4645)] = 142665,
  [SMALL_STATE(4646)] = 142720,
  [SMALL_STATE(4647)] = 142805,
  [SMALL_STATE(4648)] = 142890,
  [SMALL_STATE(4649)] = 142943,
  [SMALL_STATE(4650)] = 143044,
  [SMALL_STATE(4651)] = 143101,
  [SMALL_STATE(4652)] = 143160,
  [SMALL_STATE(4653)] = 143213,
  [SMALL_STATE(4654)] = 143282,
  [SMALL_STATE(4655)] = 143339,
  [SMALL_STATE(4656)] = 143396,
  [SMALL_STATE(4657)] = 143453,
  [SMALL_STATE(4658)] = 143510,
  [SMALL_STATE(4659)] = 143567,
  [SMALL_STATE(4660)] = 143624,
  [SMALL_STATE(4661)] = 143681,
  [SMALL_STATE(4662)] = 143734,
  [SMALL_STATE(4663)] = 143831,
  [SMALL_STATE(4664)] = 143884,
  [SMALL_STATE(4665)] = 143979,
  [SMALL_STATE(4666)] = 144032,
  [SMALL_STATE(4667)] = 144087,
  [SMALL_STATE(4668)] = 144142,
  [SMALL_STATE(4669)] = 144211,
  [SMALL_STATE(4670)] = 144264,
  [SMALL_STATE(4671)] = 144317,
  [SMALL_STATE(4672)] = 144370,
  [SMALL_STATE(4673)] = 144423,
  [SMALL_STATE(4674)] = 144492,
  [SMALL_STATE(4675)] = 144571,
  [SMALL_STATE(4676)] = 144634,
  [SMALL_STATE(4677)] = 144687,
  [SMALL_STATE(4678)] = 144740,
  [SMALL_STATE(4679)] = 144820,
  [SMALL_STATE(4680)] = 144888,
  [SMALL_STATE(4681)] = 144968,
  [SMALL_STATE(4682)] = 145026,
  [SMALL_STATE(4683)] = 145106,
  [SMALL_STATE(4684)] = 145186,
  [SMALL_STATE(4685)] = 145244,
  [SMALL_STATE(4686)] = 145302,
  [SMALL_STATE(4687)] = 145360,
  [SMALL_STATE(4688)] = 145428,
  [SMALL_STATE(4689)] = 145494,
  [SMALL_STATE(4690)] = 145574,
  [SMALL_STATE(4691)] = 145654,
  [SMALL_STATE(4692)] = 145734,
  [SMALL_STATE(4693)] = 145796,
  [SMALL_STATE(4694)] = 145862,
  [SMALL_STATE(4695)] = 145920,
  [SMALL_STATE(4696)] = 145998,
  [SMALL_STATE(4697)] = 146060,
  [SMALL_STATE(4698)] = 146128,
  [SMALL_STATE(4699)] = 146194,
  [SMALL_STATE(4700)] = 146246,
  [SMALL_STATE(4701)] = 146330,
  [SMALL_STATE(4702)] = 146408,
  [SMALL_STATE(4703)] = 146486,
  [SMALL_STATE(4704)] = 146538,
  [SMALL_STATE(4705)] = 146606,
  [SMALL_STATE(4706)] = 146674,
  [SMALL_STATE(4707)] = 146732,
  [SMALL_STATE(4708)] = 146810,
  [SMALL_STATE(4709)] = 146868,
  [SMALL_STATE(4710)] = 146936,
  [SMALL_STATE(4711)] = 146988,
  [SMALL_STATE(4712)] = 147046,
  [SMALL_STATE(4713)] = 147104,
  [SMALL_STATE(4714)] = 147218,
  [SMALL_STATE(4715)] = 147298,
  [SMALL_STATE(4716)] = 147356,
  [SMALL_STATE(4717)] = 147414,
  [SMALL_STATE(4718)] = 147482,
  [SMALL_STATE(4719)] = 147596,
  [SMALL_STATE(4720)] = 147674,
  [SMALL_STATE(4721)] = 147726,
  [SMALL_STATE(4722)] = 147784,
  [SMALL_STATE(4723)] = 147842,
  [SMALL_STATE(4724)] = 147910,
  [SMALL_STATE(4725)] = 147978,
  [SMALL_STATE(4726)] = 148044,
  [SMALL_STATE(4727)] = 148128,
  [SMALL_STATE(4728)] = 148190,
  [SMALL_STATE(4729)] = 148268,
  [SMALL_STATE(4730)] = 148346,
  [SMALL_STATE(4731)] = 148404,
  [SMALL_STATE(4732)] = 148462,
  [SMALL_STATE(4733)] = 148576,
  [SMALL_STATE(4734)] = 148644,
  [SMALL_STATE(4735)] = 148702,
  [SMALL_STATE(4736)] = 148780,
  [SMALL_STATE(4737)] = 148838,
  [SMALL_STATE(4738)] = 148896,
  [SMALL_STATE(4739)] = 148954,
  [SMALL_STATE(4740)] = 149022,
  [SMALL_STATE(4741)] = 149080,
  [SMALL_STATE(4742)] = 149148,
  [SMALL_STATE(4743)] = 149206,
  [SMALL_STATE(4744)] = 149264,
  [SMALL_STATE(4745)] = 149332,
  [SMALL_STATE(4746)] = 149389,
  [SMALL_STATE(4747)] = 149446,
  [SMALL_STATE(4748)] = 149499,
  [SMALL_STATE(4749)] = 149578,
  [SMALL_STATE(4750)] = 149629,
  [SMALL_STATE(4751)] = 149708,
  [SMALL_STATE(4752)] = 149765,
  [SMALL_STATE(4753)] = 149844,
  [SMALL_STATE(4754)] = 149901,
  [SMALL_STATE(4755)] = 149952,
  [SMALL_STATE(4756)] = 150031,
  [SMALL_STATE(4757)] = 150082,
  [SMALL_STATE(4758)] = 150133,
  [SMALL_STATE(4759)] = 150186,
  [SMALL_STATE(4760)] = 150265,
  [SMALL_STATE(4761)] = 150316,
  [SMALL_STATE(4762)] = 150367,
  [SMALL_STATE(4763)] = 150418,
  [SMALL_STATE(4764)] = 150497,
  [SMALL_STATE(4765)] = 150548,
  [SMALL_STATE(4766)] = 150605,
  [SMALL_STATE(4767)] = 150684,
  [SMALL_STATE(4768)] = 150741,
  [SMALL_STATE(4769)] = 150792,
  [SMALL_STATE(4770)] = 150875,
  [SMALL_STATE(4771)] = 150930,
  [SMALL_STATE(4772)] = 150981,
  [SMALL_STATE(4773)] = 151060,
  [SMALL_STATE(4774)] = 151111,
  [SMALL_STATE(4775)] = 151190,
  [SMALL_STATE(4776)] = 151241,
  [SMALL_STATE(4777)] = 151320,
  [SMALL_STATE(4778)] = 151399,
  [SMALL_STATE(4779)] = 151450,
  [SMALL_STATE(4780)] = 151501,
  [SMALL_STATE(4781)] = 151552,
  [SMALL_STATE(4782)] = 151631,
  [SMALL_STATE(4783)] = 151710,
  [SMALL_STATE(4784)] = 151789,
  [SMALL_STATE(4785)] = 151846,
  [SMALL_STATE(4786)] = 151897,
  [SMALL_STATE(4787)] = 151976,
  [SMALL_STATE(4788)] = 152033,
  [SMALL_STATE(4789)] = 152126,
  [SMALL_STATE(4790)] = 152203,
  [SMALL_STATE(4791)] = 152280,
  [SMALL_STATE(4792)] = 152357,
  [SMALL_STATE(4793)] = 152434,
  [SMALL_STATE(4794)] = 152485,
  [SMALL_STATE(4795)] = 152538,
  [SMALL_STATE(4796)] = 152617,
  [SMALL_STATE(4797)] = 152696,
  [SMALL_STATE(4798)] = 152775,
  [SMALL_STATE(4799)] = 152854,
  [SMALL_STATE(4800)] = 152933,
  [SMALL_STATE(4801)] = 152990,
  [SMALL_STATE(4802)] = 153047,
  [SMALL_STATE(4803)] = 153104,
  [SMALL_STATE(4804)] = 153155,
  [SMALL_STATE(4805)] = 153234,
  [SMALL_STATE(4806)] = 153285,
  [SMALL_STATE(4807)] = 153364,
  [SMALL_STATE(4808)] = 153415,
  [SMALL_STATE(4809)] = 153466,
  [SMALL_STATE(4810)] = 153545,
  [SMALL_STATE(4811)] = 153628,
  [SMALL_STATE(4812)] = 153679,
  [SMALL_STATE(4813)] = 153730,
  [SMALL_STATE(4814)] = 153781,
  [SMALL_STATE(4815)] = 153832,
  [SMALL_STATE(4816)] = 153889,
  [SMALL_STATE(4817)] = 153940,
  [SMALL_STATE(4818)] = 154017,
  [SMALL_STATE(4819)] = 154094,
  [SMALL_STATE(4820)] = 154171,
  [SMALL_STATE(4821)] = 154222,
  [SMALL_STATE(4822)] = 154299,
  [SMALL_STATE(4823)] = 154350,
  [SMALL_STATE(4824)] = 154401,
  [SMALL_STATE(4825)] = 154452,
  [SMALL_STATE(4826)] = 154503,
  [SMALL_STATE(4827)] = 154554,
  [SMALL_STATE(4828)] = 154605,
  [SMALL_STATE(4829)] = 154662,
  [SMALL_STATE(4830)] = 154719,
  [SMALL_STATE(4831)] = 154770,
  [SMALL_STATE(4832)] = 154821,
  [SMALL_STATE(4833)] = 154872,
  [SMALL_STATE(4834)] = 154955,
  [SMALL_STATE(4835)] = 155034,
  [SMALL_STATE(4836)] = 155085,
  [SMALL_STATE(4837)] = 155136,
  [SMALL_STATE(4838)] = 155219,
  [SMALL_STATE(4839)] = 155321,
  [SMALL_STATE(4840)] = 155423,
  [SMALL_STATE(4841)] = 155521,
  [SMALL_STATE(4842)] = 155615,
  [SMALL_STATE(4843)] = 155705,
  [SMALL_STATE(4844)] = 155793,
  [SMALL_STATE(4845)] = 155877,
  [SMALL_STATE(4846)] = 155981,
  [SMALL_STATE(4847)] = 156063,
  [SMALL_STATE(4848)] = 156113,
  [SMALL_STATE(4849)] = 156191,
  [SMALL_STATE(4850)] = 156289,
  [SMALL_STATE(4851)] = 156361,
  [SMALL_STATE(4852)] = 156459,
  [SMALL_STATE(4853)] = 156509,
  [SMALL_STATE(4854)] = 156559,
  [SMALL_STATE(4855)] = 156609,
  [SMALL_STATE(4856)] = 156707,
  [SMALL_STATE(4857)] = 156783,
  [SMALL_STATE(4858)] = 156833,
  [SMALL_STATE(4859)] = 156883,
  [SMALL_STATE(4860)] = 156933,
  [SMALL_STATE(4861)] = 157031,
  [SMALL_STATE(4862)] = 157101,
  [SMALL_STATE(4863)] = 157161,
  [SMALL_STATE(4864)] = 157255,
  [SMALL_STATE(4865)] = 157355,
  [SMALL_STATE(4866)] = 157455,
  [SMALL_STATE(4867)] = 157547,
  [SMALL_STATE(4868)] = 157597,
  [SMALL_STATE(4869)] = 157647,
  [SMALL_STATE(4870)] = 157697,
  [SMALL_STATE(4871)] = 157787,
  [SMALL_STATE(4872)] = 157891,
  [SMALL_STATE(4873)] = 157941,
  [SMALL_STATE(4874)] = 157993,
  [SMALL_STATE(4875)] = 158101,
  [SMALL_STATE(4876)] = 158151,
  [SMALL_STATE(4877)] = 158201,
  [SMALL_STATE(4878)] = 158251,
  [SMALL_STATE(4879)] = 158355,
  [SMALL_STATE(4880)] = 158405,
  [SMALL_STATE(4881)] = 158455,
  [SMALL_STATE(4882)] = 158505,
  [SMALL_STATE(4883)] = 158605,
  [SMALL_STATE(4884)] = 158709,
  [SMALL_STATE(4885)] = 158759,
  [SMALL_STATE(4886)] = 158835,
  [SMALL_STATE(4887)] = 158889,
  [SMALL_STATE(4888)] = 158965,
  [SMALL_STATE(4889)] = 159041,
  [SMALL_STATE(4890)] = 159117,
  [SMALL_STATE(4891)] = 159221,
  [SMALL_STATE(4892)] = 159271,
  [SMALL_STATE(4893)] = 159331,
  [SMALL_STATE(4894)] = 159381,
  [SMALL_STATE(4895)] = 159431,
  [SMALL_STATE(4896)] = 159481,
  [SMALL_STATE(4897)] = 159531,
  [SMALL_STATE(4898)] = 159601,
  [SMALL_STATE(4899)] = 159701,
  [SMALL_STATE(4900)] = 159803,
  [SMALL_STATE(4901)] = 159903,
  [SMALL_STATE(4902)] = 159999,
  [SMALL_STATE(4903)] = 160087,
  [SMALL_STATE(4904)] = 160171,
  [SMALL_STATE(4905)] = 160221,
  [SMALL_STATE(4906)] = 160303,
  [SMALL_STATE(4907)] = 160381,
  [SMALL_STATE(4908)] = 160453,
  [SMALL_STATE(4909)] = 160529,
  [SMALL_STATE(4910)] = 160587,
  [SMALL_STATE(4911)] = 160688,
  [SMALL_STATE(4912)] = 160793,
  [SMALL_STATE(4913)] = 160842,
  [SMALL_STATE(4914)] = 160897,
  [SMALL_STATE(4915)] = 160952,
  [SMALL_STATE(4916)] = 161057,
  [SMALL_STATE(4917)] = 161162,
  [SMALL_STATE(4918)] = 161217,
  [SMALL_STATE(4919)] = 161272,
  [SMALL_STATE(4920)] = 161347,
  [SMALL_STATE(4921)] = 161410,
  [SMALL_STATE(4922)] = 161475,
  [SMALL_STATE(4923)] = 161578,
  [SMALL_STATE(4924)] = 161627,
  [SMALL_STATE(4925)] = 161702,
  [SMALL_STATE(4926)] = 161777,
  [SMALL_STATE(4927)] = 161852,
  [SMALL_STATE(4928)] = 161953,
  [SMALL_STATE(4929)] = 162044,
  [SMALL_STATE(4930)] = 162099,
  [SMALL_STATE(4931)] = 162180,
  [SMALL_STATE(4932)] = 162285,
  [SMALL_STATE(4933)] = 162386,
  [SMALL_STATE(4934)] = 162491,
  [SMALL_STATE(4935)] = 162566,
  [SMALL_STATE(4936)] = 162667,
  [SMALL_STATE(4937)] = 162768,
  [SMALL_STATE(4938)] = 162831,
  [SMALL_STATE(4939)] = 162906,
  [SMALL_STATE(4940)] = 162981,
  [SMALL_STATE(4941)] = 163082,
  [SMALL_STATE(4942)] = 163137,
  [SMALL_STATE(4943)] = 163240,
  [SMALL_STATE(4944)] = 163341,
  [SMALL_STATE(4945)] = 163444,
  [SMALL_STATE(4946)] = 163549,
  [SMALL_STATE(4947)] = 163654,
  [SMALL_STATE(4948)] = 163705,
  [SMALL_STATE(4949)] = 163768,
  [SMALL_STATE(4950)] = 163873,
  [SMALL_STATE(4951)] = 163978,
  [SMALL_STATE(4952)] = 164083,
  [SMALL_STATE(4953)] = 164188,
  [SMALL_STATE(4954)] = 164289,
  [SMALL_STATE(4955)] = 164394,
  [SMALL_STATE(4956)] = 164469,
  [SMALL_STATE(4957)] = 164570,
  [SMALL_STATE(4958)] = 164625,
  [SMALL_STATE(4959)] = 164700,
  [SMALL_STATE(4960)] = 164751,
  [SMALL_STATE(4961)] = 164856,
  [SMALL_STATE(4962)] = 164961,
  [SMALL_STATE(4963)] = 165062,
  [SMALL_STATE(4964)] = 165167,
  [SMALL_STATE(4965)] = 165268,
  [SMALL_STATE(4966)] = 165369,
  [SMALL_STATE(4967)] = 165474,
  [SMALL_STATE(4968)] = 165529,
  [SMALL_STATE(4969)] = 165634,
  [SMALL_STATE(4970)] = 165739,
  [SMALL_STATE(4971)] = 165798,
  [SMALL_STATE(4972)] = 165899,
  [SMALL_STATE(4973)] = 166000,
  [SMALL_STATE(4974)] = 166101,
  [SMALL_STATE(4975)] = 166156,
  [SMALL_STATE(4976)] = 166261,
  [SMALL_STATE(4977)] = 166342,
  [SMALL_STATE(4978)] = 166405,
  [SMALL_STATE(4979)] = 166506,
  [SMALL_STATE(4980)] = 166567,
  [SMALL_STATE(4981)] = 166622,
  [SMALL_STATE(4982)] = 166697,
  [SMALL_STATE(4983)] = 166802,
  [SMALL_STATE(4984)] = 166907,
  [SMALL_STATE(4985)] = 166972,
  [SMALL_STATE(4986)] = 167077,
  [SMALL_STATE(4987)] = 167178,
  [SMALL_STATE(4988)] = 167233,
  [SMALL_STATE(4989)] = 167338,
  [SMALL_STATE(4990)] = 167429,
  [SMALL_STATE(4991)] = 167534,
  [SMALL_STATE(4992)] = 167639,
  [SMALL_STATE(4993)] = 167744,
  [SMALL_STATE(4994)] = 167849,
  [SMALL_STATE(4995)] = 167954,
  [SMALL_STATE(4996)] = 168011,
  [SMALL_STATE(4997)] = 168086,
  [SMALL_STATE(4998)] = 168141,
  [SMALL_STATE(4999)] = 168216,
  [SMALL_STATE(5000)] = 168277,
  [SMALL_STATE(5001)] = 168382,
  [SMALL_STATE(5002)] = 168487,
  [SMALL_STATE(5003)] = 168542,
  [SMALL_STATE(5004)] = 168597,
  [SMALL_STATE(5005)] = 168702,
  [SMALL_STATE(5006)] = 168803,
  [SMALL_STATE(5007)] = 168908,
  [SMALL_STATE(5008)] = 169009,
  [SMALL_STATE(5009)] = 169057,
  [SMALL_STATE(5010)] = 169159,
  [SMALL_STATE(5011)] = 169207,
  [SMALL_STATE(5012)] = 169255,
  [SMALL_STATE(5013)] = 169303,
  [SMALL_STATE(5014)] = 169397,
  [SMALL_STATE(5015)] = 169451,
  [SMALL_STATE(5016)] = 169499,
  [SMALL_STATE(5017)] = 169601,
  [SMALL_STATE(5018)] = 169649,
  [SMALL_STATE(5019)] = 169697,
  [SMALL_STATE(5020)] = 169799,
  [SMALL_STATE(5021)] = 169895,
  [SMALL_STATE(5022)] = 169991,
  [SMALL_STATE(5023)] = 170091,
  [SMALL_STATE(5024)] = 170139,
  [SMALL_STATE(5025)] = 170187,
  [SMALL_STATE(5026)] = 170235,
  [SMALL_STATE(5027)] = 170335,
  [SMALL_STATE(5028)] = 170383,
  [SMALL_STATE(5029)] = 170431,
  [SMALL_STATE(5030)] = 170479,
  [SMALL_STATE(5031)] = 170543,
  [SMALL_STATE(5032)] = 170643,
  [SMALL_STATE(5033)] = 170707,
  [SMALL_STATE(5034)] = 170755,
  [SMALL_STATE(5035)] = 170849,
  [SMALL_STATE(5036)] = 170897,
  [SMALL_STATE(5037)] = 170945,
  [SMALL_STATE(5038)] = 170993,
  [SMALL_STATE(5039)] = 171041,
  [SMALL_STATE(5040)] = 171095,
  [SMALL_STATE(5041)] = 171143,
  [SMALL_STATE(5042)] = 171245,
  [SMALL_STATE(5043)] = 171347,
  [SMALL_STATE(5044)] = 171395,
  [SMALL_STATE(5045)] = 171457,
  [SMALL_STATE(5046)] = 171505,
  [SMALL_STATE(5047)] = 171607,
  [SMALL_STATE(5048)] = 171703,
  [SMALL_STATE(5049)] = 171767,
  [SMALL_STATE(5050)] = 171831,
  [SMALL_STATE(5051)] = 171923,
  [SMALL_STATE(5052)] = 172019,
  [SMALL_STATE(5053)] = 172081,
  [SMALL_STATE(5054)] = 172183,
  [SMALL_STATE(5055)] = 172275,
  [SMALL_STATE(5056)] = 172323,
  [SMALL_STATE(5057)] = 172425,
  [SMALL_STATE(5058)] = 172473,
  [SMALL_STATE(5059)] = 172575,
  [SMALL_STATE(5060)] = 172623,
  [SMALL_STATE(5061)] = 172671,
  [SMALL_STATE(5062)] = 172773,
  [SMALL_STATE(5063)] = 172821,
  [SMALL_STATE(5064)] = 172915,
  [SMALL_STATE(5065)] = 172989,
  [SMALL_STATE(5066)] = 173051,
  [SMALL_STATE(5067)] = 173153,
  [SMALL_STATE(5068)] = 173251,
  [SMALL_STATE(5069)] = 173353,
  [SMALL_STATE(5070)] = 173455,
  [SMALL_STATE(5071)] = 173503,
  [SMALL_STATE(5072)] = 173603,
  [SMALL_STATE(5073)] = 173701,
  [SMALL_STATE(5074)] = 173749,
  [SMALL_STATE(5075)] = 173797,
  [SMALL_STATE(5076)] = 173859,
  [SMALL_STATE(5077)] = 173933,
  [SMALL_STATE(5078)] = 174007,
  [SMALL_STATE(5079)] = 174101,
  [SMALL_STATE(5080)] = 174201,
  [SMALL_STATE(5081)] = 174255,
  [SMALL_STATE(5082)] = 174303,
  [SMALL_STATE(5083)] = 174357,
  [SMALL_STATE(5084)] = 174459,
  [SMALL_STATE(5085)] = 174507,
  [SMALL_STATE(5086)] = 174607,
  [SMALL_STATE(5087)] = 174655,
  [SMALL_STATE(5088)] = 174719,
  [SMALL_STATE(5089)] = 174767,
  [SMALL_STATE(5090)] = 174859,
  [SMALL_STATE(5091)] = 174907,
  [SMALL_STATE(5092)] = 175009,
  [SMALL_STATE(5093)] = 175109,
  [SMALL_STATE(5094)] = 175211,
  [SMALL_STATE(5095)] = 175259,
  [SMALL_STATE(5096)] = 175361,
  [SMALL_STATE(5097)] = 175457,
  [SMALL_STATE(5098)] = 175559,
  [SMALL_STATE(5099)] = 175661,
  [SMALL_STATE(5100)] = 175729,
  [SMALL_STATE(5101)] = 175793,
  [SMALL_STATE(5102)] = 175883,
  [SMALL_STATE(5103)] = 175971,
  [SMALL_STATE(5104)] = 176057,
  [SMALL_STATE(5105)] = 176153,
  [SMALL_STATE(5106)] = 176201,
  [SMALL_STATE(5107)] = 176249,
  [SMALL_STATE(5108)] = 176333,
  [SMALL_STATE(5109)] = 176431,
  [SMALL_STATE(5110)] = 176505,
  [SMALL_STATE(5111)] = 176605,
  [SMALL_STATE(5112)] = 176707,
  [SMALL_STATE(5113)] = 176809,
  [SMALL_STATE(5114)] = 176889,
  [SMALL_STATE(5115)] = 176991,
  [SMALL_STATE(5116)] = 177069,
  [SMALL_STATE(5117)] = 177143,
  [SMALL_STATE(5118)] = 177197,
  [SMALL_STATE(5119)] = 177267,
  [SMALL_STATE(5120)] = 177369,
  [SMALL_STATE(5121)] = 177471,
  [SMALL_STATE(5122)] = 177573,
  [SMALL_STATE(5123)] = 177675,
  [SMALL_STATE(5124)] = 177747,
  [SMALL_STATE(5125)] = 177795,
  [SMALL_STATE(5126)] = 177897,
  [SMALL_STATE(5127)] = 177997,
  [SMALL_STATE(5128)] = 178045,
  [SMALL_STATE(5129)] = 178147,
  [SMALL_STATE(5130)] = 178249,
  [SMALL_STATE(5131)] = 178297,
  [SMALL_STATE(5132)] = 178365,
  [SMALL_STATE(5133)] = 178467,
  [SMALL_STATE(5134)] = 178531,
  [SMALL_STATE(5135)] = 178619,
  [SMALL_STATE(5136)] = 178705,
  [SMALL_STATE(5137)] = 178789,
  [SMALL_STATE(5138)] = 178891,
  [SMALL_STATE(5139)] = 178973,
  [SMALL_STATE(5140)] = 179051,
  [SMALL_STATE(5141)] = 179127,
  [SMALL_STATE(5142)] = 179201,
  [SMALL_STATE(5143)] = 179271,
  [SMALL_STATE(5144)] = 179345,
  [SMALL_STATE(5145)] = 179417,
  [SMALL_STATE(5146)] = 179481,
  [SMALL_STATE(5147)] = 179545,
  [SMALL_STATE(5148)] = 179647,
  [SMALL_STATE(5149)] = 179695,
  [SMALL_STATE(5150)] = 179743,
  [SMALL_STATE(5151)] = 179791,
  [SMALL_STATE(5152)] = 179891,
  [SMALL_STATE(5153)] = 179939,
  [SMALL_STATE(5154)] = 179987,
  [SMALL_STATE(5155)] = 180089,
  [SMALL_STATE(5156)] = 180191,
  [SMALL_STATE(5157)] = 180255,
  [SMALL_STATE(5158)] = 180303,
  [SMALL_STATE(5159)] = 180351,
  [SMALL_STATE(5160)] = 180453,
  [SMALL_STATE(5161)] = 180545,
  [SMALL_STATE(5162)] = 180637,
  [SMALL_STATE(5163)] = 180739,
  [SMALL_STATE(5164)] = 180835,
  [SMALL_STATE(5165)] = 180931,
  [SMALL_STATE(5166)] = 181031,
  [SMALL_STATE(5167)] = 181079,
  [SMALL_STATE(5168)] = 181127,
  [SMALL_STATE(5169)] = 181229,
  [SMALL_STATE(5170)] = 181283,
  [SMALL_STATE(5171)] = 181331,
  [SMALL_STATE(5172)] = 181385,
  [SMALL_STATE(5173)] = 181433,
  [SMALL_STATE(5174)] = 181495,
  [SMALL_STATE(5175)] = 181543,
  [SMALL_STATE(5176)] = 181639,
  [SMALL_STATE(5177)] = 181739,
  [SMALL_STATE(5178)] = 181807,
  [SMALL_STATE(5179)] = 181855,
  [SMALL_STATE(5180)] = 181947,
  [SMALL_STATE(5181)] = 182037,
  [SMALL_STATE(5182)] = 182125,
  [SMALL_STATE(5183)] = 182211,
  [SMALL_STATE(5184)] = 182293,
  [SMALL_STATE(5185)] = 182373,
  [SMALL_STATE(5186)] = 182449,
  [SMALL_STATE(5187)] = 182519,
  [SMALL_STATE(5188)] = 182593,
  [SMALL_STATE(5189)] = 182641,
  [SMALL_STATE(5190)] = 182741,
  [SMALL_STATE(5191)] = 182837,
  [SMALL_STATE(5192)] = 182937,
  [SMALL_STATE(5193)] = 183033,
  [SMALL_STATE(5194)] = 183133,
  [SMALL_STATE(5195)] = 183181,
  [SMALL_STATE(5196)] = 183229,
  [SMALL_STATE(5197)] = 183325,
  [SMALL_STATE(5198)] = 183389,
  [SMALL_STATE(5199)] = 183437,
  [SMALL_STATE(5200)] = 183539,
  [SMALL_STATE(5201)] = 183635,
  [SMALL_STATE(5202)] = 183735,
  [SMALL_STATE(5203)] = 183783,
  [SMALL_STATE(5204)] = 183883,
  [SMALL_STATE(5205)] = 183931,
  [SMALL_STATE(5206)] = 184031,
  [SMALL_STATE(5207)] = 184079,
  [SMALL_STATE(5208)] = 184127,
  [SMALL_STATE(5209)] = 184175,
  [SMALL_STATE(5210)] = 184229,
  [SMALL_STATE(5211)] = 184325,
  [SMALL_STATE(5212)] = 184373,
  [SMALL_STATE(5213)] = 184421,
  [SMALL_STATE(5214)] = 184521,
  [SMALL_STATE(5215)] = 184569,
  [SMALL_STATE(5216)] = 184617,
  [SMALL_STATE(5217)] = 184719,
  [SMALL_STATE(5218)] = 184767,
  [SMALL_STATE(5219)] = 184841,
  [SMALL_STATE(5220)] = 184915,
  [SMALL_STATE(5221)] = 184963,
  [SMALL_STATE(5222)] = 185037,
  [SMALL_STATE(5223)] = 185139,
  [SMALL_STATE(5224)] = 185235,
  [SMALL_STATE(5225)] = 185331,
  [SMALL_STATE(5226)] = 185433,
  [SMALL_STATE(5227)] = 185481,
  [SMALL_STATE(5228)] = 185581,
  [SMALL_STATE(5229)] = 185629,
  [SMALL_STATE(5230)] = 185729,
  [SMALL_STATE(5231)] = 185831,
  [SMALL_STATE(5232)] = 185881,
  [SMALL_STATE(5233)] = 185929,
  [SMALL_STATE(5234)] = 186025,
  [SMALL_STATE(5235)] = 186087,
  [SMALL_STATE(5236)] = 186135,
  [SMALL_STATE(5237)] = 186229,
  [SMALL_STATE(5238)] = 186331,
  [SMALL_STATE(5239)] = 186433,
  [SMALL_STATE(5240)] = 186531,
  [SMALL_STATE(5241)] = 186599,
  [SMALL_STATE(5242)] = 186663,
  [SMALL_STATE(5243)] = 186755,
  [SMALL_STATE(5244)] = 186845,
  [SMALL_STATE(5245)] = 186933,
  [SMALL_STATE(5246)] = 187019,
  [SMALL_STATE(5247)] = 187101,
  [SMALL_STATE(5248)] = 187181,
  [SMALL_STATE(5249)] = 187257,
  [SMALL_STATE(5250)] = 187305,
  [SMALL_STATE(5251)] = 187375,
  [SMALL_STATE(5252)] = 187477,
  [SMALL_STATE(5253)] = 187579,
  [SMALL_STATE(5254)] = 187653,
  [SMALL_STATE(5255)] = 187755,
  [SMALL_STATE(5256)] = 187854,
  [SMALL_STATE(5257)] = 187909,
  [SMALL_STATE(5258)] = 188008,
  [SMALL_STATE(5259)] = 188107,
  [SMALL_STATE(5260)] = 188158,
  [SMALL_STATE(5261)] = 188257,
  [SMALL_STATE(5262)] = 188356,
  [SMALL_STATE(5263)] = 188455,
  [SMALL_STATE(5264)] = 188554,
  [SMALL_STATE(5265)] = 188653,
  [SMALL_STATE(5266)] = 188752,
  [SMALL_STATE(5267)] = 188851,
  [SMALL_STATE(5268)] = 188950,
  [SMALL_STATE(5269)] = 189049,
  [SMALL_STATE(5270)] = 189148,
  [SMALL_STATE(5271)] = 189247,
  [SMALL_STATE(5272)] = 189346,
  [SMALL_STATE(5273)] = 189445,
  [SMALL_STATE(5274)] = 189544,
  [SMALL_STATE(5275)] = 189643,
  [SMALL_STATE(5276)] = 189742,
  [SMALL_STATE(5277)] = 189841,
  [SMALL_STATE(5278)] = 189940,
  [SMALL_STATE(5279)] = 190039,
  [SMALL_STATE(5280)] = 190138,
  [SMALL_STATE(5281)] = 190237,
  [SMALL_STATE(5282)] = 190336,
  [SMALL_STATE(5283)] = 190435,
  [SMALL_STATE(5284)] = 190534,
  [SMALL_STATE(5285)] = 190633,
  [SMALL_STATE(5286)] = 190682,
  [SMALL_STATE(5287)] = 190781,
  [SMALL_STATE(5288)] = 190880,
  [SMALL_STATE(5289)] = 190979,
  [SMALL_STATE(5290)] = 191078,
  [SMALL_STATE(5291)] = 191177,
  [SMALL_STATE(5292)] = 191276,
  [SMALL_STATE(5293)] = 191375,
  [SMALL_STATE(5294)] = 191436,
  [SMALL_STATE(5295)] = 191535,
  [SMALL_STATE(5296)] = 191596,
  [SMALL_STATE(5297)] = 191695,
  [SMALL_STATE(5298)] = 191794,
  [SMALL_STATE(5299)] = 191893,
  [SMALL_STATE(5300)] = 191992,
  [SMALL_STATE(5301)] = 192091,
  [SMALL_STATE(5302)] = 192190,
  [SMALL_STATE(5303)] = 192289,
  [SMALL_STATE(5304)] = 192388,
  [SMALL_STATE(5305)] = 192437,
  [SMALL_STATE(5306)] = 192536,
  [SMALL_STATE(5307)] = 192635,
  [SMALL_STATE(5308)] = 192734,
  [SMALL_STATE(5309)] = 192833,
  [SMALL_STATE(5310)] = 192932,
  [SMALL_STATE(5311)] = 193031,
  [SMALL_STATE(5312)] = 193130,
  [SMALL_STATE(5313)] = 193229,
  [SMALL_STATE(5314)] = 193328,
  [SMALL_STATE(5315)] = 193427,
  [SMALL_STATE(5316)] = 193526,
  [SMALL_STATE(5317)] = 193625,
  [SMALL_STATE(5318)] = 193724,
  [SMALL_STATE(5319)] = 193777,
  [SMALL_STATE(5320)] = 193876,
  [SMALL_STATE(5321)] = 193975,
  [SMALL_STATE(5322)] = 194074,
  [SMALL_STATE(5323)] = 194173,
  [SMALL_STATE(5324)] = 194272,
  [SMALL_STATE(5325)] = 194371,
  [SMALL_STATE(5326)] = 194470,
  [SMALL_STATE(5327)] = 194569,
  [SMALL_STATE(5328)] = 194668,
  [SMALL_STATE(5329)] = 194767,
  [SMALL_STATE(5330)] = 194866,
  [SMALL_STATE(5331)] = 194965,
  [SMALL_STATE(5332)] = 195064,
  [SMALL_STATE(5333)] = 195163,
  [SMALL_STATE(5334)] = 195262,
  [SMALL_STATE(5335)] = 195361,
  [SMALL_STATE(5336)] = 195460,
  [SMALL_STATE(5337)] = 195559,
  [SMALL_STATE(5338)] = 195618,
  [SMALL_STATE(5339)] = 195717,
  [SMALL_STATE(5340)] = 195816,
  [SMALL_STATE(5341)] = 195867,
  [SMALL_STATE(5342)] = 195966,
  [SMALL_STATE(5343)] = 196065,
  [SMALL_STATE(5344)] = 196164,
  [SMALL_STATE(5345)] = 196263,
  [SMALL_STATE(5346)] = 196362,
  [SMALL_STATE(5347)] = 196411,
  [SMALL_STATE(5348)] = 196510,
  [SMALL_STATE(5349)] = 196609,
  [SMALL_STATE(5350)] = 196708,
  [SMALL_STATE(5351)] = 196807,
  [SMALL_STATE(5352)] = 196906,
  [SMALL_STATE(5353)] = 197005,
  [SMALL_STATE(5354)] = 197104,
  [SMALL_STATE(5355)] = 197203,
  [SMALL_STATE(5356)] = 197302,
  [SMALL_STATE(5357)] = 197401,
  [SMALL_STATE(5358)] = 197500,
  [SMALL_STATE(5359)] = 197599,
  [SMALL_STATE(5360)] = 197698,
  [SMALL_STATE(5361)] = 197797,
  [SMALL_STATE(5362)] = 197896,
  [SMALL_STATE(5363)] = 197995,
  [SMALL_STATE(5364)] = 198094,
  [SMALL_STATE(5365)] = 198193,
  [SMALL_STATE(5366)] = 198292,
  [SMALL_STATE(5367)] = 198391,
  [SMALL_STATE(5368)] = 198490,
  [SMALL_STATE(5369)] = 198589,
  [SMALL_STATE(5370)] = 198688,
  [SMALL_STATE(5371)] = 198787,
  [SMALL_STATE(5372)] = 198886,
  [SMALL_STATE(5373)] = 198985,
  [SMALL_STATE(5374)] = 199084,
  [SMALL_STATE(5375)] = 199183,
  [SMALL_STATE(5376)] = 199282,
  [SMALL_STATE(5377)] = 199381,
  [SMALL_STATE(5378)] = 199480,
  [SMALL_STATE(5379)] = 199579,
  [SMALL_STATE(5380)] = 199678,
  [SMALL_STATE(5381)] = 199777,
  [SMALL_STATE(5382)] = 199876,
  [SMALL_STATE(5383)] = 199975,
  [SMALL_STATE(5384)] = 200030,
  [SMALL_STATE(5385)] = 200129,
  [SMALL_STATE(5386)] = 200228,
  [SMALL_STATE(5387)] = 200327,
  [SMALL_STATE(5388)] = 200377,
  [SMALL_STATE(5389)] = 200449,
  [SMALL_STATE(5390)] = 200499,
  [SMALL_STATE(5391)] = 200549,
  [SMALL_STATE(5392)] = 200605,
  [SMALL_STATE(5393)] = 200655,
  [SMALL_STATE(5394)] = 200703,
  [SMALL_STATE(5395)] = 200799,
  [SMALL_STATE(5396)] = 200845,
  [SMALL_STATE(5397)] = 200895,
  [SMALL_STATE(5398)] = 200955,
  [SMALL_STATE(5399)] = 201015,
  [SMALL_STATE(5400)] = 201061,
  [SMALL_STATE(5401)] = 201109,
  [SMALL_STATE(5402)] = 201155,
  [SMALL_STATE(5403)] = 201205,
  [SMALL_STATE(5404)] = 201291,
  [SMALL_STATE(5405)] = 201347,
  [SMALL_STATE(5406)] = 201397,
  [SMALL_STATE(5407)] = 201447,
  [SMALL_STATE(5408)] = 201509,
  [SMALL_STATE(5409)] = 201581,
  [SMALL_STATE(5410)] = 201643,
  [SMALL_STATE(5411)] = 201693,
  [SMALL_STATE(5412)] = 201743,
  [SMALL_STATE(5413)] = 201815,
  [SMALL_STATE(5414)] = 201887,
  [SMALL_STATE(5415)] = 201933,
  [SMALL_STATE(5416)] = 201981,
  [SMALL_STATE(5417)] = 202031,
  [SMALL_STATE(5418)] = 202081,
  [SMALL_STATE(5419)] = 202126,
  [SMALL_STATE(5420)] = 202171,
  [SMALL_STATE(5421)] = 202216,
  [SMALL_STATE(5422)] = 202261,
  [SMALL_STATE(5423)] = 202306,
  [SMALL_STATE(5424)] = 202351,
  [SMALL_STATE(5425)] = 202396,
  [SMALL_STATE(5426)] = 202441,
  [SMALL_STATE(5427)] = 202486,
  [SMALL_STATE(5428)] = 202531,
  [SMALL_STATE(5429)] = 202576,
  [SMALL_STATE(5430)] = 202621,
  [SMALL_STATE(5431)] = 202666,
  [SMALL_STATE(5432)] = 202711,
  [SMALL_STATE(5433)] = 202756,
  [SMALL_STATE(5434)] = 202801,
  [SMALL_STATE(5435)] = 202846,
  [SMALL_STATE(5436)] = 202891,
  [SMALL_STATE(5437)] = 202936,
  [SMALL_STATE(5438)] = 202981,
  [SMALL_STATE(5439)] = 203068,
  [SMALL_STATE(5440)] = 203113,
  [SMALL_STATE(5441)] = 203158,
  [SMALL_STATE(5442)] = 203203,
  [SMALL_STATE(5443)] = 203248,
  [SMALL_STATE(5444)] = 203293,
  [SMALL_STATE(5445)] = 203374,
  [SMALL_STATE(5446)] = 203419,
  [SMALL_STATE(5447)] = 203464,
  [SMALL_STATE(5448)] = 203509,
  [SMALL_STATE(5449)] = 203554,
  [SMALL_STATE(5450)] = 203599,
  [SMALL_STATE(5451)] = 203644,
  [SMALL_STATE(5452)] = 203689,
  [SMALL_STATE(5453)] = 203734,
  [SMALL_STATE(5454)] = 203779,
  [SMALL_STATE(5455)] = 203824,
  [SMALL_STATE(5456)] = 203905,
  [SMALL_STATE(5457)] = 203950,
  [SMALL_STATE(5458)] = 203995,
  [SMALL_STATE(5459)] = 204040,
  [SMALL_STATE(5460)] = 204085,
  [SMALL_STATE(5461)] = 204130,
  [SMALL_STATE(5462)] = 204175,
  [SMALL_STATE(5463)] = 204220,
  [SMALL_STATE(5464)] = 204301,
  [SMALL_STATE(5465)] = 204346,
  [SMALL_STATE(5466)] = 204391,
  [SMALL_STATE(5467)] = 204472,
  [SMALL_STATE(5468)] = 204517,
  [SMALL_STATE(5469)] = 204600,
  [SMALL_STATE(5470)] = 204681,
  [SMALL_STATE(5471)] = 204726,
  [SMALL_STATE(5472)] = 204771,
  [SMALL_STATE(5473)] = 204852,
  [SMALL_STATE(5474)] = 204897,
  [SMALL_STATE(5475)] = 204942,
  [SMALL_STATE(5476)] = 204987,
  [SMALL_STATE(5477)] = 205032,
  [SMALL_STATE(5478)] = 205077,
  [SMALL_STATE(5479)] = 205122,
  [SMALL_STATE(5480)] = 205167,
  [SMALL_STATE(5481)] = 205212,
  [SMALL_STATE(5482)] = 205261,
  [SMALL_STATE(5483)] = 205318,
  [SMALL_STATE(5484)] = 205399,
  [SMALL_STATE(5485)] = 205444,
  [SMALL_STATE(5486)] = 205497,
  [SMALL_STATE(5487)] = 205542,
  [SMALL_STATE(5488)] = 205591,
  [SMALL_STATE(5489)] = 205636,
  [SMALL_STATE(5490)] = 205681,
  [SMALL_STATE(5491)] = 205726,
  [SMALL_STATE(5492)] = 205771,
  [SMALL_STATE(5493)] = 205820,
  [SMALL_STATE(5494)] = 205869,
  [SMALL_STATE(5495)] = 205918,
  [SMALL_STATE(5496)] = 205967,
  [SMALL_STATE(5497)] = 206016,
  [SMALL_STATE(5498)] = 206065,
  [SMALL_STATE(5499)] = 206114,
  [SMALL_STATE(5500)] = 206159,
  [SMALL_STATE(5501)] = 206208,
  [SMALL_STATE(5502)] = 206257,
  [SMALL_STATE(5503)] = 206306,
  [SMALL_STATE(5504)] = 206355,
  [SMALL_STATE(5505)] = 206404,
  [SMALL_STATE(5506)] = 206449,
  [SMALL_STATE(5507)] = 206494,
  [SMALL_STATE(5508)] = 206539,
  [SMALL_STATE(5509)] = 206584,
  [SMALL_STATE(5510)] = 206631,
  [SMALL_STATE(5511)] = 206676,
  [SMALL_STATE(5512)] = 206721,
  [SMALL_STATE(5513)] = 206766,
  [SMALL_STATE(5514)] = 206811,
  [SMALL_STATE(5515)] = 206856,
  [SMALL_STATE(5516)] = 206901,
  [SMALL_STATE(5517)] = 206946,
  [SMALL_STATE(5518)] = 206991,
  [SMALL_STATE(5519)] = 207036,
  [SMALL_STATE(5520)] = 207081,
  [SMALL_STATE(5521)] = 207138,
  [SMALL_STATE(5522)] = 207183,
  [SMALL_STATE(5523)] = 207228,
  [SMALL_STATE(5524)] = 207273,
  [SMALL_STATE(5525)] = 207360,
  [SMALL_STATE(5526)] = 207405,
  [SMALL_STATE(5527)] = 207450,
  [SMALL_STATE(5528)] = 207499,
  [SMALL_STATE(5529)] = 207544,
  [SMALL_STATE(5530)] = 207589,
  [SMALL_STATE(5531)] = 207634,
  [SMALL_STATE(5532)] = 207679,
  [SMALL_STATE(5533)] = 207724,
  [SMALL_STATE(5534)] = 207773,
  [SMALL_STATE(5535)] = 207818,
  [SMALL_STATE(5536)] = 207863,
  [SMALL_STATE(5537)] = 207908,
  [SMALL_STATE(5538)] = 207953,
  [SMALL_STATE(5539)] = 207998,
  [SMALL_STATE(5540)] = 208043,
  [SMALL_STATE(5541)] = 208088,
  [SMALL_STATE(5542)] = 208135,
  [SMALL_STATE(5543)] = 208180,
  [SMALL_STATE(5544)] = 208225,
  [SMALL_STATE(5545)] = 208311,
  [SMALL_STATE(5546)] = 208389,
  [SMALL_STATE(5547)] = 208435,
  [SMALL_STATE(5548)] = 208521,
  [SMALL_STATE(5549)] = 208599,
  [SMALL_STATE(5550)] = 208677,
  [SMALL_STATE(5551)] = 208755,
  [SMALL_STATE(5552)] = 208833,
  [SMALL_STATE(5553)] = 208919,
  [SMALL_STATE(5554)] = 209005,
  [SMALL_STATE(5555)] = 209083,
  [SMALL_STATE(5556)] = 209161,
  [SMALL_STATE(5557)] = 209247,
  [SMALL_STATE(5558)] = 209325,
  [SMALL_STATE(5559)] = 209411,
  [SMALL_STATE(5560)] = 209496,
  [SMALL_STATE(5561)] = 209587,
  [SMALL_STATE(5562)] = 209672,
  [SMALL_STATE(5563)] = 209757,
  [SMALL_STATE(5564)] = 209800,
  [SMALL_STATE(5565)] = 209885,
  [SMALL_STATE(5566)] = 209934,
  [SMALL_STATE(5567)] = 209977,
  [SMALL_STATE(5568)] = 210062,
  [SMALL_STATE(5569)] = 210147,
  [SMALL_STATE(5570)] = 210194,
  [SMALL_STATE(5571)] = 210279,
  [SMALL_STATE(5572)] = 210364,
  [SMALL_STATE(5573)] = 210415,
  [SMALL_STATE(5574)] = 210500,
  [SMALL_STATE(5575)] = 210551,
  [SMALL_STATE(5576)] = 210636,
  [SMALL_STATE(5577)] = 210682,
  [SMALL_STATE(5578)] = 210766,
  [SMALL_STATE(5579)] = 210844,
  [SMALL_STATE(5580)] = 210922,
  [SMALL_STATE(5581)] = 211006,
  [SMALL_STATE(5582)] = 211084,
  [SMALL_STATE(5583)] = 211162,
  [SMALL_STATE(5584)] = 211246,
  [SMALL_STATE(5585)] = 211323,
  [SMALL_STATE(5586)] = 211406,
  [SMALL_STATE(5587)] = 211489,
  [SMALL_STATE(5588)] = 211566,
  [SMALL_STATE(5589)] = 211643,
  [SMALL_STATE(5590)] = 211726,
  [SMALL_STATE(5591)] = 211809,
  [SMALL_STATE(5592)] = 211886,
  [SMALL_STATE(5593)] = 211963,
  [SMALL_STATE(5594)] = 212040,
  [SMALL_STATE(5595)] = 212117,
  [SMALL_STATE(5596)] = 212194,
  [SMALL_STATE(5597)] = 212271,
  [SMALL_STATE(5598)] = 212348,
  [SMALL_STATE(5599)] = 212425,
  [SMALL_STATE(5600)] = 212508,
  [SMALL_STATE(5601)] = 212585,
  [SMALL_STATE(5602)] = 212628,
  [SMALL_STATE(5603)] = 212711,
  [SMALL_STATE(5604)] = 212787,
  [SMALL_STATE(5605)] = 212863,
  [SMALL_STATE(5606)] = 212939,
  [SMALL_STATE(5607)] = 213015,
  [SMALL_STATE(5608)] = 213095,
  [SMALL_STATE(5609)] = 213175,
  [SMALL_STATE(5610)] = 213255,
  [SMALL_STATE(5611)] = 213335,
  [SMALL_STATE(5612)] = 213415,
  [SMALL_STATE(5613)] = 213491,
  [SMALL_STATE(5614)] = 213571,
  [SMALL_STATE(5615)] = 213647,
  [SMALL_STATE(5616)] = 213723,
  [SMALL_STATE(5617)] = 213805,
  [SMALL_STATE(5618)] = 213885,
  [SMALL_STATE(5619)] = 213961,
  [SMALL_STATE(5620)] = 214037,
  [SMALL_STATE(5621)] = 214117,
  [SMALL_STATE(5622)] = 214197,
  [SMALL_STATE(5623)] = 214277,
  [SMALL_STATE(5624)] = 214357,
  [SMALL_STATE(5625)] = 214433,
  [SMALL_STATE(5626)] = 214513,
  [SMALL_STATE(5627)] = 214593,
  [SMALL_STATE(5628)] = 214673,
  [SMALL_STATE(5629)] = 214753,
  [SMALL_STATE(5630)] = 214833,
  [SMALL_STATE(5631)] = 214909,
  [SMALL_STATE(5632)] = 214985,
  [SMALL_STATE(5633)] = 215065,
  [SMALL_STATE(5634)] = 215145,
  [SMALL_STATE(5635)] = 215221,
  [SMALL_STATE(5636)] = 215297,
  [SMALL_STATE(5637)] = 215377,
  [SMALL_STATE(5638)] = 215453,
  [SMALL_STATE(5639)] = 215535,
  [SMALL_STATE(5640)] = 215611,
  [SMALL_STATE(5641)] = 215687,
  [SMALL_STATE(5642)] = 215769,
  [SMALL_STATE(5643)] = 215851,
  [SMALL_STATE(5644)] = 215931,
  [SMALL_STATE(5645)] = 216007,
  [SMALL_STATE(5646)] = 216087,
  [SMALL_STATE(5647)] = 216167,
  [SMALL_STATE(5648)] = 216243,
  [SMALL_STATE(5649)] = 216319,
  [SMALL_STATE(5650)] = 216400,
  [SMALL_STATE(5651)] = 216481,
  [SMALL_STATE(5652)] = 216562,
  [SMALL_STATE(5653)] = 216643,
  [SMALL_STATE(5654)] = 216724,
  [SMALL_STATE(5655)] = 216805,
  [SMALL_STATE(5656)] = 216886,
  [SMALL_STATE(5657)] = 216967,
  [SMALL_STATE(5658)] = 217048,
  [SMALL_STATE(5659)] = 217129,
  [SMALL_STATE(5660)] = 217210,
  [SMALL_STATE(5661)] = 217291,
  [SMALL_STATE(5662)] = 217372,
  [SMALL_STATE(5663)] = 217453,
  [SMALL_STATE(5664)] = 217534,
  [SMALL_STATE(5665)] = 217615,
  [SMALL_STATE(5666)] = 217696,
  [SMALL_STATE(5667)] = 217777,
  [SMALL_STATE(5668)] = 217858,
  [SMALL_STATE(5669)] = 217939,
  [SMALL_STATE(5670)] = 218020,
  [SMALL_STATE(5671)] = 218101,
  [SMALL_STATE(5672)] = 218182,
  [SMALL_STATE(5673)] = 218257,
  [SMALL_STATE(5674)] = 218332,
  [SMALL_STATE(5675)] = 218413,
  [SMALL_STATE(5676)] = 218494,
  [SMALL_STATE(5677)] = 218575,
  [SMALL_STATE(5678)] = 218656,
  [SMALL_STATE(5679)] = 218737,
  [SMALL_STATE(5680)] = 218818,
  [SMALL_STATE(5681)] = 218899,
  [SMALL_STATE(5682)] = 218980,
  [SMALL_STATE(5683)] = 219061,
  [SMALL_STATE(5684)] = 219142,
  [SMALL_STATE(5685)] = 219223,
  [SMALL_STATE(5686)] = 219304,
  [SMALL_STATE(5687)] = 219385,
  [SMALL_STATE(5688)] = 219466,
  [SMALL_STATE(5689)] = 219547,
  [SMALL_STATE(5690)] = 219628,
  [SMALL_STATE(5691)] = 219709,
  [SMALL_STATE(5692)] = 219790,
  [SMALL_STATE(5693)] = 219871,
  [SMALL_STATE(5694)] = 219952,
  [SMALL_STATE(5695)] = 220033,
  [SMALL_STATE(5696)] = 220114,
  [SMALL_STATE(5697)] = 220195,
  [SMALL_STATE(5698)] = 220276,
  [SMALL_STATE(5699)] = 220357,
  [SMALL_STATE(5700)] = 220432,
  [SMALL_STATE(5701)] = 220507,
  [SMALL_STATE(5702)] = 220588,
  [SMALL_STATE(5703)] = 220669,
  [SMALL_STATE(5704)] = 220750,
  [SMALL_STATE(5705)] = 220831,
  [SMALL_STATE(5706)] = 220912,
  [SMALL_STATE(5707)] = 220993,
  [SMALL_STATE(5708)] = 221074,
  [SMALL_STATE(5709)] = 221155,
  [SMALL_STATE(5710)] = 221236,
  [SMALL_STATE(5711)] = 221317,
  [SMALL_STATE(5712)] = 221398,
  [SMALL_STATE(5713)] = 221479,
  [SMALL_STATE(5714)] = 221560,
  [SMALL_STATE(5715)] = 221641,
  [SMALL_STATE(5716)] = 221722,
  [SMALL_STATE(5717)] = 221803,
  [SMALL_STATE(5718)] = 221884,
  [SMALL_STATE(5719)] = 221965,
  [SMALL_STATE(5720)] = 222046,
  [SMALL_STATE(5721)] = 222127,
  [SMALL_STATE(5722)] = 222208,
  [SMALL_STATE(5723)] = 222289,
  [SMALL_STATE(5724)] = 222370,
  [SMALL_STATE(5725)] = 222451,
  [SMALL_STATE(5726)] = 222532,
  [SMALL_STATE(5727)] = 222613,
  [SMALL_STATE(5728)] = 222694,
  [SMALL_STATE(5729)] = 222775,
  [SMALL_STATE(5730)] = 222856,
  [SMALL_STATE(5731)] = 222937,
  [SMALL_STATE(5732)] = 223018,
  [SMALL_STATE(5733)] = 223099,
  [SMALL_STATE(5734)] = 223180,
  [SMALL_STATE(5735)] = 223261,
  [SMALL_STATE(5736)] = 223342,
  [SMALL_STATE(5737)] = 223423,
  [SMALL_STATE(5738)] = 223504,
  [SMALL_STATE(5739)] = 223547,
  [SMALL_STATE(5740)] = 223628,
  [SMALL_STATE(5741)] = 223709,
  [SMALL_STATE(5742)] = 223790,
  [SMALL_STATE(5743)] = 223871,
  [SMALL_STATE(5744)] = 223952,
  [SMALL_STATE(5745)] = 224033,
  [SMALL_STATE(5746)] = 224114,
  [SMALL_STATE(5747)] = 224195,
  [SMALL_STATE(5748)] = 224276,
  [SMALL_STATE(5749)] = 224357,
  [SMALL_STATE(5750)] = 224438,
  [SMALL_STATE(5751)] = 224519,
  [SMALL_STATE(5752)] = 224600,
  [SMALL_STATE(5753)] = 224681,
  [SMALL_STATE(5754)] = 224762,
  [SMALL_STATE(5755)] = 224843,
  [SMALL_STATE(5756)] = 224924,
  [SMALL_STATE(5757)] = 225002,
  [SMALL_STATE(5758)] = 225080,
  [SMALL_STATE(5759)] = 225154,
  [SMALL_STATE(5760)] = 225232,
  [SMALL_STATE(5761)] = 225306,
  [SMALL_STATE(5762)] = 225380,
  [SMALL_STATE(5763)] = 225458,
  [SMALL_STATE(5764)] = 225536,
  [SMALL_STATE(5765)] = 225610,
  [SMALL_STATE(5766)] = 225684,
  [SMALL_STATE(5767)] = 225758,
  [SMALL_STATE(5768)] = 225836,
  [SMALL_STATE(5769)] = 225910,
  [SMALL_STATE(5770)] = 225984,
  [SMALL_STATE(5771)] = 226058,
  [SMALL_STATE(5772)] = 226132,
  [SMALL_STATE(5773)] = 226210,
  [SMALL_STATE(5774)] = 226284,
  [SMALL_STATE(5775)] = 226358,
  [SMALL_STATE(5776)] = 226432,
  [SMALL_STATE(5777)] = 226510,
  [SMALL_STATE(5778)] = 226584,
  [SMALL_STATE(5779)] = 226658,
  [SMALL_STATE(5780)] = 226736,
  [SMALL_STATE(5781)] = 226810,
  [SMALL_STATE(5782)] = 226880,
  [SMALL_STATE(5783)] = 226958,
  [SMALL_STATE(5784)] = 227036,
  [SMALL_STATE(5785)] = 227110,
  [SMALL_STATE(5786)] = 227184,
  [SMALL_STATE(5787)] = 227258,
  [SMALL_STATE(5788)] = 227332,
  [SMALL_STATE(5789)] = 227406,
  [SMALL_STATE(5790)] = 227480,
  [SMALL_STATE(5791)] = 227554,
  [SMALL_STATE(5792)] = 227628,
  [SMALL_STATE(5793)] = 227702,
  [SMALL_STATE(5794)] = 227776,
  [SMALL_STATE(5795)] = 227846,
  [SMALL_STATE(5796)] = 227924,
  [SMALL_STATE(5797)] = 227998,
  [SMALL_STATE(5798)] = 228072,
  [SMALL_STATE(5799)] = 228142,
  [SMALL_STATE(5800)] = 228212,
  [SMALL_STATE(5801)] = 228286,
  [SMALL_STATE(5802)] = 228360,
  [SMALL_STATE(5803)] = 228434,
  [SMALL_STATE(5804)] = 228512,
  [SMALL_STATE(5805)] = 228586,
  [SMALL_STATE(5806)] = 228660,
  [SMALL_STATE(5807)] = 228734,
  [SMALL_STATE(5808)] = 228808,
  [SMALL_STATE(5809)] = 228878,
  [SMALL_STATE(5810)] = 228956,
  [SMALL_STATE(5811)] = 229030,
  [SMALL_STATE(5812)] = 229104,
  [SMALL_STATE(5813)] = 229178,
  [SMALL_STATE(5814)] = 229252,
  [SMALL_STATE(5815)] = 229326,
  [SMALL_STATE(5816)] = 229400,
  [SMALL_STATE(5817)] = 229474,
  [SMALL_STATE(5818)] = 229548,
  [SMALL_STATE(5819)] = 229622,
  [SMALL_STATE(5820)] = 229696,
  [SMALL_STATE(5821)] = 229774,
  [SMALL_STATE(5822)] = 229844,
  [SMALL_STATE(5823)] = 229918,
  [SMALL_STATE(5824)] = 229992,
  [SMALL_STATE(5825)] = 230066,
  [SMALL_STATE(5826)] = 230144,
  [SMALL_STATE(5827)] = 230222,
  [SMALL_STATE(5828)] = 230296,
  [SMALL_STATE(5829)] = 230374,
  [SMALL_STATE(5830)] = 230444,
  [SMALL_STATE(5831)] = 230522,
  [SMALL_STATE(5832)] = 230600,
  [SMALL_STATE(5833)] = 230674,
  [SMALL_STATE(5834)] = 230748,
  [SMALL_STATE(5835)] = 230822,
  [SMALL_STATE(5836)] = 230896,
  [SMALL_STATE(5837)] = 230970,
  [SMALL_STATE(5838)] = 231040,
  [SMALL_STATE(5839)] = 231114,
  [SMALL_STATE(5840)] = 231188,
  [SMALL_STATE(5841)] = 231262,
  [SMALL_STATE(5842)] = 231336,
  [SMALL_STATE(5843)] = 231403,
  [SMALL_STATE(5844)] = 231470,
  [SMALL_STATE(5845)] = 231537,
  [SMALL_STATE(5846)] = 231604,
  [SMALL_STATE(5847)] = 231671,
  [SMALL_STATE(5848)] = 231738,
  [SMALL_STATE(5849)] = 231805,
  [SMALL_STATE(5850)] = 231872,
  [SMALL_STATE(5851)] = 231945,
  [SMALL_STATE(5852)] = 232012,
  [SMALL_STATE(5853)] = 232085,
  [SMALL_STATE(5854)] = 232152,
  [SMALL_STATE(5855)] = 232219,
  [SMALL_STATE(5856)] = 232286,
  [SMALL_STATE(5857)] = 232353,
  [SMALL_STATE(5858)] = 232420,
  [SMALL_STATE(5859)] = 232487,
  [SMALL_STATE(5860)] = 232554,
  [SMALL_STATE(5861)] = 232627,
  [SMALL_STATE(5862)] = 232694,
  [SMALL_STATE(5863)] = 232761,
  [SMALL_STATE(5864)] = 232828,
  [SMALL_STATE(5865)] = 232895,
  [SMALL_STATE(5866)] = 232962,
  [SMALL_STATE(5867)] = 233035,
  [SMALL_STATE(5868)] = 233102,
  [SMALL_STATE(5869)] = 233169,
  [SMALL_STATE(5870)] = 233242,
  [SMALL_STATE(5871)] = 233315,
  [SMALL_STATE(5872)] = 233388,
  [SMALL_STATE(5873)] = 233455,
  [SMALL_STATE(5874)] = 233528,
  [SMALL_STATE(5875)] = 233595,
  [SMALL_STATE(5876)] = 233662,
  [SMALL_STATE(5877)] = 233729,
  [SMALL_STATE(5878)] = 233796,
  [SMALL_STATE(5879)] = 233863,
  [SMALL_STATE(5880)] = 233930,
  [SMALL_STATE(5881)] = 233997,
  [SMALL_STATE(5882)] = 234064,
  [SMALL_STATE(5883)] = 234131,
  [SMALL_STATE(5884)] = 234198,
  [SMALL_STATE(5885)] = 234264,
  [SMALL_STATE(5886)] = 234330,
  [SMALL_STATE(5887)] = 234396,
  [SMALL_STATE(5888)] = 234462,
  [SMALL_STATE(5889)] = 234528,
  [SMALL_STATE(5890)] = 234594,
  [SMALL_STATE(5891)] = 234660,
  [SMALL_STATE(5892)] = 234726,
  [SMALL_STATE(5893)] = 234792,
  [SMALL_STATE(5894)] = 234858,
  [SMALL_STATE(5895)] = 234924,
  [SMALL_STATE(5896)] = 234990,
  [SMALL_STATE(5897)] = 235056,
  [SMALL_STATE(5898)] = 235122,
  [SMALL_STATE(5899)] = 235188,
  [SMALL_STATE(5900)] = 235254,
  [SMALL_STATE(5901)] = 235320,
  [SMALL_STATE(5902)] = 235386,
  [SMALL_STATE(5903)] = 235451,
  [SMALL_STATE(5904)] = 235516,
  [SMALL_STATE(5905)] = 235581,
  [SMALL_STATE(5906)] = 235646,
  [SMALL_STATE(5907)] = 235711,
  [SMALL_STATE(5908)] = 235776,
  [SMALL_STATE(5909)] = 235841,
  [SMALL_STATE(5910)] = 235906,
  [SMALL_STATE(5911)] = 235971,
  [SMALL_STATE(5912)] = 236036,
  [SMALL_STATE(5913)] = 236101,
  [SMALL_STATE(5914)] = 236166,
  [SMALL_STATE(5915)] = 236231,
  [SMALL_STATE(5916)] = 236296,
  [SMALL_STATE(5917)] = 236361,
  [SMALL_STATE(5918)] = 236426,
  [SMALL_STATE(5919)] = 236491,
  [SMALL_STATE(5920)] = 236556,
  [SMALL_STATE(5921)] = 236621,
  [SMALL_STATE(5922)] = 236686,
  [SMALL_STATE(5923)] = 236751,
  [SMALL_STATE(5924)] = 236816,
  [SMALL_STATE(5925)] = 236881,
  [SMALL_STATE(5926)] = 236946,
  [SMALL_STATE(5927)] = 237011,
  [SMALL_STATE(5928)] = 237076,
  [SMALL_STATE(5929)] = 237141,
  [SMALL_STATE(5930)] = 237206,
  [SMALL_STATE(5931)] = 237271,
  [SMALL_STATE(5932)] = 237336,
  [SMALL_STATE(5933)] = 237394,
  [SMALL_STATE(5934)] = 237458,
  [SMALL_STATE(5935)] = 237522,
  [SMALL_STATE(5936)] = 237580,
  [SMALL_STATE(5937)] = 237644,
  [SMALL_STATE(5938)] = 237702,
  [SMALL_STATE(5939)] = 237766,
  [SMALL_STATE(5940)] = 237824,
  [SMALL_STATE(5941)] = 237882,
  [SMALL_STATE(5942)] = 237946,
  [SMALL_STATE(5943)] = 238010,
  [SMALL_STATE(5944)] = 238071,
  [SMALL_STATE(5945)] = 238132,
  [SMALL_STATE(5946)] = 238195,
  [SMALL_STATE(5947)] = 238258,
  [SMALL_STATE(5948)] = 238319,
  [SMALL_STATE(5949)] = 238382,
  [SMALL_STATE(5950)] = 238433,
  [SMALL_STATE(5951)] = 238494,
  [SMALL_STATE(5952)] = 238557,
  [SMALL_STATE(5953)] = 238608,
  [SMALL_STATE(5954)] = 238669,
  [SMALL_STATE(5955)] = 238732,
  [SMALL_STATE(5956)] = 238795,
  [SMALL_STATE(5957)] = 238858,
  [SMALL_STATE(5958)] = 238919,
  [SMALL_STATE(5959)] = 238982,
  [SMALL_STATE(5960)] = 239045,
  [SMALL_STATE(5961)] = 239108,
  [SMALL_STATE(5962)] = 239169,
  [SMALL_STATE(5963)] = 239230,
  [SMALL_STATE(5964)] = 239281,
  [SMALL_STATE(5965)] = 239344,
  [SMALL_STATE(5966)] = 239407,
  [SMALL_STATE(5967)] = 239470,
  [SMALL_STATE(5968)] = 239533,
  [SMALL_STATE(5969)] = 239596,
  [SMALL_STATE(5970)] = 239657,
  [SMALL_STATE(5971)] = 239720,
  [SMALL_STATE(5972)] = 239783,
  [SMALL_STATE(5973)] = 239846,
  [SMALL_STATE(5974)] = 239908,
  [SMALL_STATE(5975)] = 239970,
  [SMALL_STATE(5976)] = 240044,
  [SMALL_STATE(5977)] = 240086,
  [SMALL_STATE(5978)] = 240148,
  [SMALL_STATE(5979)] = 240210,
  [SMALL_STATE(5980)] = 240284,
  [SMALL_STATE(5981)] = 240338,
  [SMALL_STATE(5982)] = 240400,
  [SMALL_STATE(5983)] = 240442,
  [SMALL_STATE(5984)] = 240504,
  [SMALL_STATE(5985)] = 240566,
  [SMALL_STATE(5986)] = 240628,
  [SMALL_STATE(5987)] = 240690,
  [SMALL_STATE(5988)] = 240752,
  [SMALL_STATE(5989)] = 240814,
  [SMALL_STATE(5990)] = 240888,
  [SMALL_STATE(5991)] = 240950,
  [SMALL_STATE(5992)] = 240999,
  [SMALL_STATE(5993)] = 241030,
  [SMALL_STATE(5994)] = 241076,
  [SMALL_STATE(5995)] = 241114,
  [SMALL_STATE(5996)] = 241152,
  [SMALL_STATE(5997)] = 241222,
  [SMALL_STATE(5998)] = 241274,
  [SMALL_STATE(5999)] = 241344,
  [SMALL_STATE(6000)] = 241382,
  [SMALL_STATE(6001)] = 241416,
  [SMALL_STATE(6002)] = 241468,
  [SMALL_STATE(6003)] = 241500,
  [SMALL_STATE(6004)] = 241552,
  [SMALL_STATE(6005)] = 241586,
  [SMALL_STATE(6006)] = 241638,
  [SMALL_STATE(6007)] = 241708,
  [SMALL_STATE(6008)] = 241760,
  [SMALL_STATE(6009)] = 241812,
  [SMALL_STATE(6010)] = 241864,
  [SMALL_STATE(6011)] = 241916,
  [SMALL_STATE(6012)] = 241950,
  [SMALL_STATE(6013)] = 241990,
  [SMALL_STATE(6014)] = 242042,
  [SMALL_STATE(6015)] = 242094,
  [SMALL_STATE(6016)] = 242146,
  [SMALL_STATE(6017)] = 242198,
  [SMALL_STATE(6018)] = 242250,
  [SMALL_STATE(6019)] = 242302,
  [SMALL_STATE(6020)] = 242354,
  [SMALL_STATE(6021)] = 242406,
  [SMALL_STATE(6022)] = 242458,
  [SMALL_STATE(6023)] = 242510,
  [SMALL_STATE(6024)] = 242562,
  [SMALL_STATE(6025)] = 242614,
  [SMALL_STATE(6026)] = 242666,
  [SMALL_STATE(6027)] = 242718,
  [SMALL_STATE(6028)] = 242756,
  [SMALL_STATE(6029)] = 242790,
  [SMALL_STATE(6030)] = 242842,
  [SMALL_STATE(6031)] = 242894,
  [SMALL_STATE(6032)] = 242934,
  [SMALL_STATE(6033)] = 242972,
  [SMALL_STATE(6034)] = 243006,
  [SMALL_STATE(6035)] = 243058,
  [SMALL_STATE(6036)] = 243110,
  [SMALL_STATE(6037)] = 243162,
  [SMALL_STATE(6038)] = 243214,
  [SMALL_STATE(6039)] = 243266,
  [SMALL_STATE(6040)] = 243318,
  [SMALL_STATE(6041)] = 243370,
  [SMALL_STATE(6042)] = 243422,
  [SMALL_STATE(6043)] = 243474,
  [SMALL_STATE(6044)] = 243526,
  [SMALL_STATE(6045)] = 243564,
  [SMALL_STATE(6046)] = 243616,
  [SMALL_STATE(6047)] = 243668,
  [SMALL_STATE(6048)] = 243716,
  [SMALL_STATE(6049)] = 243768,
  [SMALL_STATE(6050)] = 243820,
  [SMALL_STATE(6051)] = 243872,
  [SMALL_STATE(6052)] = 243910,
  [SMALL_STATE(6053)] = 243962,
  [SMALL_STATE(6054)] = 244014,
  [SMALL_STATE(6055)] = 244052,
  [SMALL_STATE(6056)] = 244104,
  [SMALL_STATE(6057)] = 244142,
  [SMALL_STATE(6058)] = 244194,
  [SMALL_STATE(6059)] = 244246,
  [SMALL_STATE(6060)] = 244284,
  [SMALL_STATE(6061)] = 244336,
  [SMALL_STATE(6062)] = 244369,
  [SMALL_STATE(6063)] = 244428,
  [SMALL_STATE(6064)] = 244465,
  [SMALL_STATE(6065)] = 244494,
  [SMALL_STATE(6066)] = 244555,
  [SMALL_STATE(6067)] = 244584,
  [SMALL_STATE(6068)] = 244613,
  [SMALL_STATE(6069)] = 244656,
  [SMALL_STATE(6070)] = 244685,
  [SMALL_STATE(6071)] = 244738,
  [SMALL_STATE(6072)] = 244797,
  [SMALL_STATE(6073)] = 244856,
  [SMALL_STATE(6074)] = 244915,
  [SMALL_STATE(6075)] = 244976,
  [SMALL_STATE(6076)] = 245031,
  [SMALL_STATE(6077)] = 245090,
  [SMALL_STATE(6078)] = 245149,
  [SMALL_STATE(6079)] = 245208,
  [SMALL_STATE(6080)] = 245267,
  [SMALL_STATE(6081)] = 245326,
  [SMALL_STATE(6082)] = 245385,
  [SMALL_STATE(6083)] = 245444,
  [SMALL_STATE(6084)] = 245503,
  [SMALL_STATE(6085)] = 245562,
  [SMALL_STATE(6086)] = 245621,
  [SMALL_STATE(6087)] = 245680,
  [SMALL_STATE(6088)] = 245733,
  [SMALL_STATE(6089)] = 245794,
  [SMALL_STATE(6090)] = 245853,
  [SMALL_STATE(6091)] = 245912,
  [SMALL_STATE(6092)] = 245971,
  [SMALL_STATE(6093)] = 246004,
  [SMALL_STATE(6094)] = 246063,
  [SMALL_STATE(6095)] = 246122,
  [SMALL_STATE(6096)] = 246181,
  [SMALL_STATE(6097)] = 246240,
  [SMALL_STATE(6098)] = 246299,
  [SMALL_STATE(6099)] = 246358,
  [SMALL_STATE(6100)] = 246417,
  [SMALL_STATE(6101)] = 246476,
  [SMALL_STATE(6102)] = 246535,
  [SMALL_STATE(6103)] = 246594,
  [SMALL_STATE(6104)] = 246655,
  [SMALL_STATE(6105)] = 246714,
  [SMALL_STATE(6106)] = 246773,
  [SMALL_STATE(6107)] = 246832,
  [SMALL_STATE(6108)] = 246891,
  [SMALL_STATE(6109)] = 246950,
  [SMALL_STATE(6110)] = 247009,
  [SMALL_STATE(6111)] = 247068,
  [SMALL_STATE(6112)] = 247127,
  [SMALL_STATE(6113)] = 247186,
  [SMALL_STATE(6114)] = 247245,
  [SMALL_STATE(6115)] = 247304,
  [SMALL_STATE(6116)] = 247341,
  [SMALL_STATE(6117)] = 247374,
  [SMALL_STATE(6118)] = 247433,
  [SMALL_STATE(6119)] = 247492,
  [SMALL_STATE(6120)] = 247553,
  [SMALL_STATE(6121)] = 247612,
  [SMALL_STATE(6122)] = 247671,
  [SMALL_STATE(6123)] = 247704,
  [SMALL_STATE(6124)] = 247763,
  [SMALL_STATE(6125)] = 247822,
  [SMALL_STATE(6126)] = 247881,
  [SMALL_STATE(6127)] = 247944,
  [SMALL_STATE(6128)] = 247987,
  [SMALL_STATE(6129)] = 248046,
  [SMALL_STATE(6130)] = 248105,
  [SMALL_STATE(6131)] = 248164,
  [SMALL_STATE(6132)] = 248201,
  [SMALL_STATE(6133)] = 248262,
  [SMALL_STATE(6134)] = 248321,
  [SMALL_STATE(6135)] = 248380,
  [SMALL_STATE(6136)] = 248409,
  [SMALL_STATE(6137)] = 248468,
  [SMALL_STATE(6138)] = 248527,
  [SMALL_STATE(6139)] = 248586,
  [SMALL_STATE(6140)] = 248615,
  [SMALL_STATE(6141)] = 248674,
  [SMALL_STATE(6142)] = 248733,
  [SMALL_STATE(6143)] = 248792,
  [SMALL_STATE(6144)] = 248851,
  [SMALL_STATE(6145)] = 248910,
  [SMALL_STATE(6146)] = 248969,
  [SMALL_STATE(6147)] = 249000,
  [SMALL_STATE(6148)] = 249037,
  [SMALL_STATE(6149)] = 249066,
  [SMALL_STATE(6150)] = 249097,
  [SMALL_STATE(6151)] = 249126,
  [SMALL_STATE(6152)] = 249185,
  [SMALL_STATE(6153)] = 249244,
  [SMALL_STATE(6154)] = 249303,
  [SMALL_STATE(6155)] = 249362,
  [SMALL_STATE(6156)] = 249421,
  [SMALL_STATE(6157)] = 249458,
  [SMALL_STATE(6158)] = 249517,
  [SMALL_STATE(6159)] = 249576,
  [SMALL_STATE(6160)] = 249635,
  [SMALL_STATE(6161)] = 249694,
  [SMALL_STATE(6162)] = 249753,
  [SMALL_STATE(6163)] = 249812,
  [SMALL_STATE(6164)] = 249871,
  [SMALL_STATE(6165)] = 249930,
  [SMALL_STATE(6166)] = 249989,
  [SMALL_STATE(6167)] = 250048,
  [SMALL_STATE(6168)] = 250085,
  [SMALL_STATE(6169)] = 250122,
  [SMALL_STATE(6170)] = 250181,
  [SMALL_STATE(6171)] = 250240,
  [SMALL_STATE(6172)] = 250277,
  [SMALL_STATE(6173)] = 250336,
  [SMALL_STATE(6174)] = 250395,
  [SMALL_STATE(6175)] = 250454,
  [SMALL_STATE(6176)] = 250513,
  [SMALL_STATE(6177)] = 250572,
  [SMALL_STATE(6178)] = 250601,
  [SMALL_STATE(6179)] = 250630,
  [SMALL_STATE(6180)] = 250691,
  [SMALL_STATE(6181)] = 250728,
  [SMALL_STATE(6182)] = 250771,
  [SMALL_STATE(6183)] = 250826,
  [SMALL_STATE(6184)] = 250879,
  [SMALL_STATE(6185)] = 250938,
  [SMALL_STATE(6186)] = 250997,
  [SMALL_STATE(6187)] = 251056,
  [SMALL_STATE(6188)] = 251111,
  [SMALL_STATE(6189)] = 251170,
  [SMALL_STATE(6190)] = 251229,
  [SMALL_STATE(6191)] = 251274,
  [SMALL_STATE(6192)] = 251333,
  [SMALL_STATE(6193)] = 251392,
  [SMALL_STATE(6194)] = 251451,
  [SMALL_STATE(6195)] = 251510,
  [SMALL_STATE(6196)] = 251539,
  [SMALL_STATE(6197)] = 251598,
  [SMALL_STATE(6198)] = 251627,
  [SMALL_STATE(6199)] = 251664,
  [SMALL_STATE(6200)] = 251723,
  [SMALL_STATE(6201)] = 251782,
  [SMALL_STATE(6202)] = 251841,
  [SMALL_STATE(6203)] = 251870,
  [SMALL_STATE(6204)] = 251929,
  [SMALL_STATE(6205)] = 251988,
  [SMALL_STATE(6206)] = 252047,
  [SMALL_STATE(6207)] = 252076,
  [SMALL_STATE(6208)] = 252135,
  [SMALL_STATE(6209)] = 252164,
  [SMALL_STATE(6210)] = 252193,
  [SMALL_STATE(6211)] = 252222,
  [SMALL_STATE(6212)] = 252251,
  [SMALL_STATE(6213)] = 252280,
  [SMALL_STATE(6214)] = 252309,
  [SMALL_STATE(6215)] = 252338,
  [SMALL_STATE(6216)] = 252367,
  [SMALL_STATE(6217)] = 252426,
  [SMALL_STATE(6218)] = 252454,
  [SMALL_STATE(6219)] = 252506,
  [SMALL_STATE(6220)] = 252570,
  [SMALL_STATE(6221)] = 252622,
  [SMALL_STATE(6222)] = 252668,
  [SMALL_STATE(6223)] = 252720,
  [SMALL_STATE(6224)] = 252752,
  [SMALL_STATE(6225)] = 252780,
  [SMALL_STATE(6226)] = 252812,
  [SMALL_STATE(6227)] = 252856,
  [SMALL_STATE(6228)] = 252920,
  [SMALL_STATE(6229)] = 252972,
  [SMALL_STATE(6230)] = 253018,
  [SMALL_STATE(6231)] = 253070,
  [SMALL_STATE(6232)] = 253110,
  [SMALL_STATE(6233)] = 253138,
  [SMALL_STATE(6234)] = 253170,
  [SMALL_STATE(6235)] = 253198,
  [SMALL_STATE(6236)] = 253262,
  [SMALL_STATE(6237)] = 253310,
  [SMALL_STATE(6238)] = 253356,
  [SMALL_STATE(6239)] = 253402,
  [SMALL_STATE(6240)] = 253446,
  [SMALL_STATE(6241)] = 253488,
  [SMALL_STATE(6242)] = 253528,
  [SMALL_STATE(6243)] = 253564,
  [SMALL_STATE(6244)] = 253598,
  [SMALL_STATE(6245)] = 253650,
  [SMALL_STATE(6246)] = 253702,
  [SMALL_STATE(6247)] = 253766,
  [SMALL_STATE(6248)] = 253806,
  [SMALL_STATE(6249)] = 253846,
  [SMALL_STATE(6250)] = 253886,
  [SMALL_STATE(6251)] = 253926,
  [SMALL_STATE(6252)] = 253966,
  [SMALL_STATE(6253)] = 254006,
  [SMALL_STATE(6254)] = 254046,
  [SMALL_STATE(6255)] = 254086,
  [SMALL_STATE(6256)] = 254126,
  [SMALL_STATE(6257)] = 254166,
  [SMALL_STATE(6258)] = 254206,
  [SMALL_STATE(6259)] = 254258,
  [SMALL_STATE(6260)] = 254298,
  [SMALL_STATE(6261)] = 254362,
  [SMALL_STATE(6262)] = 254414,
  [SMALL_STATE(6263)] = 254454,
  [SMALL_STATE(6264)] = 254506,
  [SMALL_STATE(6265)] = 254546,
  [SMALL_STATE(6266)] = 254586,
  [SMALL_STATE(6267)] = 254650,
  [SMALL_STATE(6268)] = 254702,
  [SMALL_STATE(6269)] = 254754,
  [SMALL_STATE(6270)] = 254806,
  [SMALL_STATE(6271)] = 254870,
  [SMALL_STATE(6272)] = 254910,
  [SMALL_STATE(6273)] = 254942,
  [SMALL_STATE(6274)] = 254970,
  [SMALL_STATE(6275)] = 255034,
  [SMALL_STATE(6276)] = 255086,
  [SMALL_STATE(6277)] = 255138,
  [SMALL_STATE(6278)] = 255190,
  [SMALL_STATE(6279)] = 255218,
  [SMALL_STATE(6280)] = 255282,
  [SMALL_STATE(6281)] = 255334,
  [SMALL_STATE(6282)] = 255386,
  [SMALL_STATE(6283)] = 255450,
  [SMALL_STATE(6284)] = 255490,
  [SMALL_STATE(6285)] = 255554,
  [SMALL_STATE(6286)] = 255618,
  [SMALL_STATE(6287)] = 255682,
  [SMALL_STATE(6288)] = 255726,
  [SMALL_STATE(6289)] = 255766,
  [SMALL_STATE(6290)] = 255806,
  [SMALL_STATE(6291)] = 255856,
  [SMALL_STATE(6292)] = 255920,
  [SMALL_STATE(6293)] = 255972,
  [SMALL_STATE(6294)] = 256024,
  [SMALL_STATE(6295)] = 256074,
  [SMALL_STATE(6296)] = 256126,
  [SMALL_STATE(6297)] = 256178,
  [SMALL_STATE(6298)] = 256218,
  [SMALL_STATE(6299)] = 256270,
  [SMALL_STATE(6300)] = 256310,
  [SMALL_STATE(6301)] = 256350,
  [SMALL_STATE(6302)] = 256390,
  [SMALL_STATE(6303)] = 256422,
  [SMALL_STATE(6304)] = 256462,
  [SMALL_STATE(6305)] = 256502,
  [SMALL_STATE(6306)] = 256566,
  [SMALL_STATE(6307)] = 256606,
  [SMALL_STATE(6308)] = 256646,
  [SMALL_STATE(6309)] = 256686,
  [SMALL_STATE(6310)] = 256726,
  [SMALL_STATE(6311)] = 256766,
  [SMALL_STATE(6312)] = 256806,
  [SMALL_STATE(6313)] = 256846,
  [SMALL_STATE(6314)] = 256886,
  [SMALL_STATE(6315)] = 256926,
  [SMALL_STATE(6316)] = 256978,
  [SMALL_STATE(6317)] = 257028,
  [SMALL_STATE(6318)] = 257078,
  [SMALL_STATE(6319)] = 257128,
  [SMALL_STATE(6320)] = 257180,
  [SMALL_STATE(6321)] = 257230,
  [SMALL_STATE(6322)] = 257282,
  [SMALL_STATE(6323)] = 257322,
  [SMALL_STATE(6324)] = 257362,
  [SMALL_STATE(6325)] = 257402,
  [SMALL_STATE(6326)] = 257442,
  [SMALL_STATE(6327)] = 257482,
  [SMALL_STATE(6328)] = 257522,
  [SMALL_STATE(6329)] = 257562,
  [SMALL_STATE(6330)] = 257602,
  [SMALL_STATE(6331)] = 257642,
  [SMALL_STATE(6332)] = 257682,
  [SMALL_STATE(6333)] = 257722,
  [SMALL_STATE(6334)] = 257772,
  [SMALL_STATE(6335)] = 257812,
  [SMALL_STATE(6336)] = 257862,
  [SMALL_STATE(6337)] = 257912,
  [SMALL_STATE(6338)] = 257962,
  [SMALL_STATE(6339)] = 258012,
  [SMALL_STATE(6340)] = 258040,
  [SMALL_STATE(6341)] = 258090,
  [SMALL_STATE(6342)] = 258140,
  [SMALL_STATE(6343)] = 258190,
  [SMALL_STATE(6344)] = 258240,
  [SMALL_STATE(6345)] = 258290,
  [SMALL_STATE(6346)] = 258340,
  [SMALL_STATE(6347)] = 258390,
  [SMALL_STATE(6348)] = 258440,
  [SMALL_STATE(6349)] = 258480,
  [SMALL_STATE(6350)] = 258532,
  [SMALL_STATE(6351)] = 258584,
  [SMALL_STATE(6352)] = 258624,
  [SMALL_STATE(6353)] = 258652,
  [SMALL_STATE(6354)] = 258680,
  [SMALL_STATE(6355)] = 258708,
  [SMALL_STATE(6356)] = 258748,
  [SMALL_STATE(6357)] = 258788,
  [SMALL_STATE(6358)] = 258828,
  [SMALL_STATE(6359)] = 258868,
  [SMALL_STATE(6360)] = 258908,
  [SMALL_STATE(6361)] = 258960,
  [SMALL_STATE(6362)] = 259000,
  [SMALL_STATE(6363)] = 259040,
  [SMALL_STATE(6364)] = 259080,
  [SMALL_STATE(6365)] = 259120,
  [SMALL_STATE(6366)] = 259172,
  [SMALL_STATE(6367)] = 259224,
  [SMALL_STATE(6368)] = 259264,
  [SMALL_STATE(6369)] = 259304,
  [SMALL_STATE(6370)] = 259344,
  [SMALL_STATE(6371)] = 259384,
  [SMALL_STATE(6372)] = 259436,
  [SMALL_STATE(6373)] = 259476,
  [SMALL_STATE(6374)] = 259503,
  [SMALL_STATE(6375)] = 259530,
  [SMALL_STATE(6376)] = 259557,
  [SMALL_STATE(6377)] = 259598,
  [SMALL_STATE(6378)] = 259637,
  [SMALL_STATE(6379)] = 259694,
  [SMALL_STATE(6380)] = 259741,
  [SMALL_STATE(6381)] = 259786,
  [SMALL_STATE(6382)] = 259823,
  [SMALL_STATE(6383)] = 259858,
  [SMALL_STATE(6384)] = 259885,
  [SMALL_STATE(6385)] = 259930,
  [SMALL_STATE(6386)] = 259977,
  [SMALL_STATE(6387)] = 260022,
  [SMALL_STATE(6388)] = 260049,
  [SMALL_STATE(6389)] = 260098,
  [SMALL_STATE(6390)] = 260125,
  [SMALL_STATE(6391)] = 260158,
  [SMALL_STATE(6392)] = 260215,
  [SMALL_STATE(6393)] = 260242,
  [SMALL_STATE(6394)] = 260299,
  [SMALL_STATE(6395)] = 260326,
  [SMALL_STATE(6396)] = 260373,
  [SMALL_STATE(6397)] = 260400,
  [SMALL_STATE(6398)] = 260445,
  [SMALL_STATE(6399)] = 260502,
  [SMALL_STATE(6400)] = 260535,
  [SMALL_STATE(6401)] = 260582,
  [SMALL_STATE(6402)] = 260627,
  [SMALL_STATE(6403)] = 260654,
  [SMALL_STATE(6404)] = 260687,
  [SMALL_STATE(6405)] = 260718,
  [SMALL_STATE(6406)] = 260763,
  [SMALL_STATE(6407)] = 260810,
  [SMALL_STATE(6408)] = 260855,
  [SMALL_STATE(6409)] = 260882,
  [SMALL_STATE(6410)] = 260929,
  [SMALL_STATE(6411)] = 260974,
  [SMALL_STATE(6412)] = 261021,
  [SMALL_STATE(6413)] = 261048,
  [SMALL_STATE(6414)] = 261075,
  [SMALL_STATE(6415)] = 261102,
  [SMALL_STATE(6416)] = 261129,
  [SMALL_STATE(6417)] = 261162,
  [SMALL_STATE(6418)] = 261219,
  [SMALL_STATE(6419)] = 261266,
  [SMALL_STATE(6420)] = 261293,
  [SMALL_STATE(6421)] = 261340,
  [SMALL_STATE(6422)] = 261395,
  [SMALL_STATE(6423)] = 261452,
  [SMALL_STATE(6424)] = 261485,
  [SMALL_STATE(6425)] = 261530,
  [SMALL_STATE(6426)] = 261557,
  [SMALL_STATE(6427)] = 261584,
  [SMALL_STATE(6428)] = 261611,
  [SMALL_STATE(6429)] = 261658,
  [SMALL_STATE(6430)] = 261685,
  [SMALL_STATE(6431)] = 261730,
  [SMALL_STATE(6432)] = 261773,
  [SMALL_STATE(6433)] = 261800,
  [SMALL_STATE(6434)] = 261827,
  [SMALL_STATE(6435)] = 261854,
  [SMALL_STATE(6436)] = 261903,
  [SMALL_STATE(6437)] = 261950,
  [SMALL_STATE(6438)] = 261979,
  [SMALL_STATE(6439)] = 262006,
  [SMALL_STATE(6440)] = 262033,
  [SMALL_STATE(6441)] = 262078,
  [SMALL_STATE(6442)] = 262125,
  [SMALL_STATE(6443)] = 262170,
  [SMALL_STATE(6444)] = 262197,
  [SMALL_STATE(6445)] = 262224,
  [SMALL_STATE(6446)] = 262281,
  [SMALL_STATE(6447)] = 262308,
  [SMALL_STATE(6448)] = 262351,
  [SMALL_STATE(6449)] = 262378,
  [SMALL_STATE(6450)] = 262423,
  [SMALL_STATE(6451)] = 262468,
  [SMALL_STATE(6452)] = 262497,
  [SMALL_STATE(6453)] = 262524,
  [SMALL_STATE(6454)] = 262571,
  [SMALL_STATE(6455)] = 262618,
  [SMALL_STATE(6456)] = 262663,
  [SMALL_STATE(6457)] = 262706,
  [SMALL_STATE(6458)] = 262733,
  [SMALL_STATE(6459)] = 262769,
  [SMALL_STATE(6460)] = 262797,
  [SMALL_STATE(6461)] = 262823,
  [SMALL_STATE(6462)] = 262849,
  [SMALL_STATE(6463)] = 262897,
  [SMALL_STATE(6464)] = 262923,
  [SMALL_STATE(6465)] = 262949,
  [SMALL_STATE(6466)] = 262983,
  [SMALL_STATE(6467)] = 263009,
  [SMALL_STATE(6468)] = 263039,
  [SMALL_STATE(6469)] = 263087,
  [SMALL_STATE(6470)] = 263113,
  [SMALL_STATE(6471)] = 263147,
  [SMALL_STATE(6472)] = 263177,
  [SMALL_STATE(6473)] = 263203,
  [SMALL_STATE(6474)] = 263233,
  [SMALL_STATE(6475)] = 263269,
  [SMALL_STATE(6476)] = 263305,
  [SMALL_STATE(6477)] = 263331,
  [SMALL_STATE(6478)] = 263365,
  [SMALL_STATE(6479)] = 263391,
  [SMALL_STATE(6480)] = 263417,
  [SMALL_STATE(6481)] = 263451,
  [SMALL_STATE(6482)] = 263485,
  [SMALL_STATE(6483)] = 263511,
  [SMALL_STATE(6484)] = 263559,
  [SMALL_STATE(6485)] = 263585,
  [SMALL_STATE(6486)] = 263637,
  [SMALL_STATE(6487)] = 263663,
  [SMALL_STATE(6488)] = 263701,
  [SMALL_STATE(6489)] = 263739,
  [SMALL_STATE(6490)] = 263777,
  [SMALL_STATE(6491)] = 263811,
  [SMALL_STATE(6492)] = 263849,
  [SMALL_STATE(6493)] = 263887,
  [SMALL_STATE(6494)] = 263925,
  [SMALL_STATE(6495)] = 263963,
  [SMALL_STATE(6496)] = 264015,
  [SMALL_STATE(6497)] = 264063,
  [SMALL_STATE(6498)] = 264089,
  [SMALL_STATE(6499)] = 264143,
  [SMALL_STATE(6500)] = 264177,
  [SMALL_STATE(6501)] = 264207,
  [SMALL_STATE(6502)] = 264241,
  [SMALL_STATE(6503)] = 264283,
  [SMALL_STATE(6504)] = 264319,
  [SMALL_STATE(6505)] = 264371,
  [SMALL_STATE(6506)] = 264397,
  [SMALL_STATE(6507)] = 264423,
  [SMALL_STATE(6508)] = 264449,
  [SMALL_STATE(6509)] = 264475,
  [SMALL_STATE(6510)] = 264501,
  [SMALL_STATE(6511)] = 264553,
  [SMALL_STATE(6512)] = 264583,
  [SMALL_STATE(6513)] = 264609,
  [SMALL_STATE(6514)] = 264635,
  [SMALL_STATE(6515)] = 264669,
  [SMALL_STATE(6516)] = 264721,
  [SMALL_STATE(6517)] = 264755,
  [SMALL_STATE(6518)] = 264791,
  [SMALL_STATE(6519)] = 264829,
  [SMALL_STATE(6520)] = 264872,
  [SMALL_STATE(6521)] = 264909,
  [SMALL_STATE(6522)] = 264946,
  [SMALL_STATE(6523)] = 264987,
  [SMALL_STATE(6524)] = 265036,
  [SMALL_STATE(6525)] = 265085,
  [SMALL_STATE(6526)] = 265114,
  [SMALL_STATE(6527)] = 265163,
  [SMALL_STATE(6528)] = 265188,
  [SMALL_STATE(6529)] = 265237,
  [SMALL_STATE(6530)] = 265286,
  [SMALL_STATE(6531)] = 265333,
  [SMALL_STATE(6532)] = 265364,
  [SMALL_STATE(6533)] = 265413,
  [SMALL_STATE(6534)] = 265462,
  [SMALL_STATE(6535)] = 265499,
  [SMALL_STATE(6536)] = 265542,
  [SMALL_STATE(6537)] = 265579,
  [SMALL_STATE(6538)] = 265628,
  [SMALL_STATE(6539)] = 265677,
  [SMALL_STATE(6540)] = 265720,
  [SMALL_STATE(6541)] = 265747,
  [SMALL_STATE(6542)] = 265796,
  [SMALL_STATE(6543)] = 265829,
  [SMALL_STATE(6544)] = 265858,
  [SMALL_STATE(6545)] = 265907,
  [SMALL_STATE(6546)] = 265956,
  [SMALL_STATE(6547)] = 266005,
  [SMALL_STATE(6548)] = 266036,
  [SMALL_STATE(6549)] = 266067,
  [SMALL_STATE(6550)] = 266104,
  [SMALL_STATE(6551)] = 266141,
  [SMALL_STATE(6552)] = 266178,
  [SMALL_STATE(6553)] = 266215,
  [SMALL_STATE(6554)] = 266252,
  [SMALL_STATE(6555)] = 266289,
  [SMALL_STATE(6556)] = 266326,
  [SMALL_STATE(6557)] = 266363,
  [SMALL_STATE(6558)] = 266406,
  [SMALL_STATE(6559)] = 266455,
  [SMALL_STATE(6560)] = 266504,
  [SMALL_STATE(6561)] = 266553,
  [SMALL_STATE(6562)] = 266602,
  [SMALL_STATE(6563)] = 266643,
  [SMALL_STATE(6564)] = 266686,
  [SMALL_STATE(6565)] = 266735,
  [SMALL_STATE(6566)] = 266784,
  [SMALL_STATE(6567)] = 266821,
  [SMALL_STATE(6568)] = 266864,
  [SMALL_STATE(6569)] = 266901,
  [SMALL_STATE(6570)] = 266950,
  [SMALL_STATE(6571)] = 266981,
  [SMALL_STATE(6572)] = 267030,
  [SMALL_STATE(6573)] = 267079,
  [SMALL_STATE(6574)] = 267128,
  [SMALL_STATE(6575)] = 267177,
  [SMALL_STATE(6576)] = 267214,
  [SMALL_STATE(6577)] = 267251,
  [SMALL_STATE(6578)] = 267291,
  [SMALL_STATE(6579)] = 267315,
  [SMALL_STATE(6580)] = 267355,
  [SMALL_STATE(6581)] = 267379,
  [SMALL_STATE(6582)] = 267419,
  [SMALL_STATE(6583)] = 267443,
  [SMALL_STATE(6584)] = 267483,
  [SMALL_STATE(6585)] = 267507,
  [SMALL_STATE(6586)] = 267547,
  [SMALL_STATE(6587)] = 267571,
  [SMALL_STATE(6588)] = 267603,
  [SMALL_STATE(6589)] = 267627,
  [SMALL_STATE(6590)] = 267663,
  [SMALL_STATE(6591)] = 267695,
  [SMALL_STATE(6592)] = 267719,
  [SMALL_STATE(6593)] = 267743,
  [SMALL_STATE(6594)] = 267767,
  [SMALL_STATE(6595)] = 267791,
  [SMALL_STATE(6596)] = 267815,
  [SMALL_STATE(6597)] = 267851,
  [SMALL_STATE(6598)] = 267875,
  [SMALL_STATE(6599)] = 267915,
  [SMALL_STATE(6600)] = 267955,
  [SMALL_STATE(6601)] = 267979,
  [SMALL_STATE(6602)] = 268003,
  [SMALL_STATE(6603)] = 268027,
  [SMALL_STATE(6604)] = 268051,
  [SMALL_STATE(6605)] = 268079,
  [SMALL_STATE(6606)] = 268103,
  [SMALL_STATE(6607)] = 268139,
  [SMALL_STATE(6608)] = 268171,
  [SMALL_STATE(6609)] = 268195,
  [SMALL_STATE(6610)] = 268227,
  [SMALL_STATE(6611)] = 268251,
  [SMALL_STATE(6612)] = 268275,
  [SMALL_STATE(6613)] = 268307,
  [SMALL_STATE(6614)] = 268339,
  [SMALL_STATE(6615)] = 268363,
  [SMALL_STATE(6616)] = 268403,
  [SMALL_STATE(6617)] = 268443,
  [SMALL_STATE(6618)] = 268475,
  [SMALL_STATE(6619)] = 268499,
  [SMALL_STATE(6620)] = 268523,
  [SMALL_STATE(6621)] = 268555,
  [SMALL_STATE(6622)] = 268597,
  [SMALL_STATE(6623)] = 268629,
  [SMALL_STATE(6624)] = 268661,
  [SMALL_STATE(6625)] = 268693,
  [SMALL_STATE(6626)] = 268717,
  [SMALL_STATE(6627)] = 268743,
  [SMALL_STATE(6628)] = 268789,
  [SMALL_STATE(6629)] = 268829,
  [SMALL_STATE(6630)] = 268861,
  [SMALL_STATE(6631)] = 268885,
  [SMALL_STATE(6632)] = 268909,
  [SMALL_STATE(6633)] = 268941,
  [SMALL_STATE(6634)] = 268973,
  [SMALL_STATE(6635)] = 268997,
  [SMALL_STATE(6636)] = 269029,
  [SMALL_STATE(6637)] = 269053,
  [SMALL_STATE(6638)] = 269085,
  [SMALL_STATE(6639)] = 269117,
  [SMALL_STATE(6640)] = 269149,
  [SMALL_STATE(6641)] = 269173,
  [SMALL_STATE(6642)] = 269209,
  [SMALL_STATE(6643)] = 269241,
  [SMALL_STATE(6644)] = 269265,
  [SMALL_STATE(6645)] = 269289,
  [SMALL_STATE(6646)] = 269313,
  [SMALL_STATE(6647)] = 269337,
  [SMALL_STATE(6648)] = 269377,
  [SMALL_STATE(6649)] = 269409,
  [SMALL_STATE(6650)] = 269433,
  [SMALL_STATE(6651)] = 269465,
  [SMALL_STATE(6652)] = 269497,
  [SMALL_STATE(6653)] = 269529,
  [SMALL_STATE(6654)] = 269553,
  [SMALL_STATE(6655)] = 269585,
  [SMALL_STATE(6656)] = 269625,
  [SMALL_STATE(6657)] = 269649,
  [SMALL_STATE(6658)] = 269689,
  [SMALL_STATE(6659)] = 269721,
  [SMALL_STATE(6660)] = 269745,
  [SMALL_STATE(6661)] = 269769,
  [SMALL_STATE(6662)] = 269801,
  [SMALL_STATE(6663)] = 269833,
  [SMALL_STATE(6664)] = 269869,
  [SMALL_STATE(6665)] = 269893,
  [SMALL_STATE(6666)] = 269933,
  [SMALL_STATE(6667)] = 269973,
  [SMALL_STATE(6668)] = 269997,
  [SMALL_STATE(6669)] = 270029,
  [SMALL_STATE(6670)] = 270069,
  [SMALL_STATE(6671)] = 270093,
  [SMALL_STATE(6672)] = 270129,
  [SMALL_STATE(6673)] = 270169,
  [SMALL_STATE(6674)] = 270193,
  [SMALL_STATE(6675)] = 270233,
  [SMALL_STATE(6676)] = 270265,
  [SMALL_STATE(6677)] = 270305,
  [SMALL_STATE(6678)] = 270329,
  [SMALL_STATE(6679)] = 270361,
  [SMALL_STATE(6680)] = 270401,
  [SMALL_STATE(6681)] = 270441,
  [SMALL_STATE(6682)] = 270473,
  [SMALL_STATE(6683)] = 270505,
  [SMALL_STATE(6684)] = 270545,
  [SMALL_STATE(6685)] = 270577,
  [SMALL_STATE(6686)] = 270613,
  [SMALL_STATE(6687)] = 270653,
  [SMALL_STATE(6688)] = 270685,
  [SMALL_STATE(6689)] = 270709,
  [SMALL_STATE(6690)] = 270733,
  [SMALL_STATE(6691)] = 270757,
  [SMALL_STATE(6692)] = 270781,
  [SMALL_STATE(6693)] = 270805,
  [SMALL_STATE(6694)] = 270829,
  [SMALL_STATE(6695)] = 270865,
  [SMALL_STATE(6696)] = 270898,
  [SMALL_STATE(6697)] = 270937,
  [SMALL_STATE(6698)] = 270976,
  [SMALL_STATE(6699)] = 271011,
  [SMALL_STATE(6700)] = 271040,
  [SMALL_STATE(6701)] = 271069,
  [SMALL_STATE(6702)] = 271104,
  [SMALL_STATE(6703)] = 271139,
  [SMALL_STATE(6704)] = 271178,
  [SMALL_STATE(6705)] = 271213,
  [SMALL_STATE(6706)] = 271246,
  [SMALL_STATE(6707)] = 271279,
  [SMALL_STATE(6708)] = 271312,
  [SMALL_STATE(6709)] = 271345,
  [SMALL_STATE(6710)] = 271380,
  [SMALL_STATE(6711)] = 271423,
  [SMALL_STATE(6712)] = 271462,
  [SMALL_STATE(6713)] = 271497,
  [SMALL_STATE(6714)] = 271536,
  [SMALL_STATE(6715)] = 271571,
  [SMALL_STATE(6716)] = 271614,
  [SMALL_STATE(6717)] = 271647,
  [SMALL_STATE(6718)] = 271690,
  [SMALL_STATE(6719)] = 271725,
  [SMALL_STATE(6720)] = 271760,
  [SMALL_STATE(6721)] = 271789,
  [SMALL_STATE(6722)] = 271818,
  [SMALL_STATE(6723)] = 271847,
  [SMALL_STATE(6724)] = 271880,
  [SMALL_STATE(6725)] = 271909,
  [SMALL_STATE(6726)] = 271938,
  [SMALL_STATE(6727)] = 271971,
  [SMALL_STATE(6728)] = 272006,
  [SMALL_STATE(6729)] = 272035,
  [SMALL_STATE(6730)] = 272064,
  [SMALL_STATE(6731)] = 272107,
  [SMALL_STATE(6732)] = 272142,
  [SMALL_STATE(6733)] = 272185,
  [SMALL_STATE(6734)] = 272220,
  [SMALL_STATE(6735)] = 272255,
  [SMALL_STATE(6736)] = 272282,
  [SMALL_STATE(6737)] = 272317,
  [SMALL_STATE(6738)] = 272352,
  [SMALL_STATE(6739)] = 272387,
  [SMALL_STATE(6740)] = 272422,
  [SMALL_STATE(6741)] = 272455,
  [SMALL_STATE(6742)] = 272484,
  [SMALL_STATE(6743)] = 272527,
  [SMALL_STATE(6744)] = 272562,
  [SMALL_STATE(6745)] = 272605,
  [SMALL_STATE(6746)] = 272634,
  [SMALL_STATE(6747)] = 272673,
  [SMALL_STATE(6748)] = 272708,
  [SMALL_STATE(6749)] = 272743,
  [SMALL_STATE(6750)] = 272776,
  [SMALL_STATE(6751)] = 272811,
  [SMALL_STATE(6752)] = 272846,
  [SMALL_STATE(6753)] = 272881,
  [SMALL_STATE(6754)] = 272916,
  [SMALL_STATE(6755)] = 272955,
  [SMALL_STATE(6756)] = 272990,
  [SMALL_STATE(6757)] = 273019,
  [SMALL_STATE(6758)] = 273058,
  [SMALL_STATE(6759)] = 273087,
  [SMALL_STATE(6760)] = 273120,
  [SMALL_STATE(6761)] = 273163,
  [SMALL_STATE(6762)] = 273198,
  [SMALL_STATE(6763)] = 273227,
  [SMALL_STATE(6764)] = 273260,
  [SMALL_STATE(6765)] = 273299,
  [SMALL_STATE(6766)] = 273328,
  [SMALL_STATE(6767)] = 273357,
  [SMALL_STATE(6768)] = 273386,
  [SMALL_STATE(6769)] = 273419,
  [SMALL_STATE(6770)] = 273448,
  [SMALL_STATE(6771)] = 273477,
  [SMALL_STATE(6772)] = 273506,
  [SMALL_STATE(6773)] = 273535,
  [SMALL_STATE(6774)] = 273570,
  [SMALL_STATE(6775)] = 273613,
  [SMALL_STATE(6776)] = 273642,
  [SMALL_STATE(6777)] = 273685,
  [SMALL_STATE(6778)] = 273714,
  [SMALL_STATE(6779)] = 273757,
  [SMALL_STATE(6780)] = 273786,
  [SMALL_STATE(6781)] = 273819,
  [SMALL_STATE(6782)] = 273848,
  [SMALL_STATE(6783)] = 273881,
  [SMALL_STATE(6784)] = 273924,
  [SMALL_STATE(6785)] = 273953,
  [SMALL_STATE(6786)] = 273988,
  [SMALL_STATE(6787)] = 274023,
  [SMALL_STATE(6788)] = 274058,
  [SMALL_STATE(6789)] = 274093,
  [SMALL_STATE(6790)] = 274126,
  [SMALL_STATE(6791)] = 274166,
  [SMALL_STATE(6792)] = 274206,
  [SMALL_STATE(6793)] = 274236,
  [SMALL_STATE(6794)] = 274276,
  [SMALL_STATE(6795)] = 274306,
  [SMALL_STATE(6796)] = 274344,
  [SMALL_STATE(6797)] = 274368,
  [SMALL_STATE(6798)] = 274398,
  [SMALL_STATE(6799)] = 274428,
  [SMALL_STATE(6800)] = 274458,
  [SMALL_STATE(6801)] = 274488,
  [SMALL_STATE(6802)] = 274518,
  [SMALL_STATE(6803)] = 274548,
  [SMALL_STATE(6804)] = 274578,
  [SMALL_STATE(6805)] = 274610,
  [SMALL_STATE(6806)] = 274642,
  [SMALL_STATE(6807)] = 274674,
  [SMALL_STATE(6808)] = 274706,
  [SMALL_STATE(6809)] = 274736,
  [SMALL_STATE(6810)] = 274766,
  [SMALL_STATE(6811)] = 274796,
  [SMALL_STATE(6812)] = 274826,
  [SMALL_STATE(6813)] = 274856,
  [SMALL_STATE(6814)] = 274896,
  [SMALL_STATE(6815)] = 274934,
  [SMALL_STATE(6816)] = 274966,
  [SMALL_STATE(6817)] = 274998,
  [SMALL_STATE(6818)] = 275030,
  [SMALL_STATE(6819)] = 275062,
  [SMALL_STATE(6820)] = 275102,
  [SMALL_STATE(6821)] = 275142,
  [SMALL_STATE(6822)] = 275180,
  [SMALL_STATE(6823)] = 275218,
  [SMALL_STATE(6824)] = 275258,
  [SMALL_STATE(6825)] = 275298,
  [SMALL_STATE(6826)] = 275336,
  [SMALL_STATE(6827)] = 275374,
  [SMALL_STATE(6828)] = 275412,
  [SMALL_STATE(6829)] = 275434,
  [SMALL_STATE(6830)] = 275474,
  [SMALL_STATE(6831)] = 275506,
  [SMALL_STATE(6832)] = 275544,
  [SMALL_STATE(6833)] = 275582,
  [SMALL_STATE(6834)] = 275612,
  [SMALL_STATE(6835)] = 275634,
  [SMALL_STATE(6836)] = 275656,
  [SMALL_STATE(6837)] = 275686,
  [SMALL_STATE(6838)] = 275724,
  [SMALL_STATE(6839)] = 275754,
  [SMALL_STATE(6840)] = 275784,
  [SMALL_STATE(6841)] = 275822,
  [SMALL_STATE(6842)] = 275856,
  [SMALL_STATE(6843)] = 275890,
  [SMALL_STATE(6844)] = 275924,
  [SMALL_STATE(6845)] = 275958,
  [SMALL_STATE(6846)] = 275992,
  [SMALL_STATE(6847)] = 276022,
  [SMALL_STATE(6848)] = 276056,
  [SMALL_STATE(6849)] = 276090,
  [SMALL_STATE(6850)] = 276120,
  [SMALL_STATE(6851)] = 276160,
  [SMALL_STATE(6852)] = 276190,
  [SMALL_STATE(6853)] = 276220,
  [SMALL_STATE(6854)] = 276250,
  [SMALL_STATE(6855)] = 276290,
  [SMALL_STATE(6856)] = 276314,
  [SMALL_STATE(6857)] = 276354,
  [SMALL_STATE(6858)] = 276386,
  [SMALL_STATE(6859)] = 276424,
  [SMALL_STATE(6860)] = 276462,
  [SMALL_STATE(6861)] = 276500,
  [SMALL_STATE(6862)] = 276540,
  [SMALL_STATE(6863)] = 276572,
  [SMALL_STATE(6864)] = 276612,
  [SMALL_STATE(6865)] = 276644,
  [SMALL_STATE(6866)] = 276684,
  [SMALL_STATE(6867)] = 276724,
  [SMALL_STATE(6868)] = 276764,
  [SMALL_STATE(6869)] = 276804,
  [SMALL_STATE(6870)] = 276844,
  [SMALL_STATE(6871)] = 276884,
  [SMALL_STATE(6872)] = 276924,
  [SMALL_STATE(6873)] = 276962,
  [SMALL_STATE(6874)] = 277000,
  [SMALL_STATE(6875)] = 277032,
  [SMALL_STATE(6876)] = 277064,
  [SMALL_STATE(6877)] = 277104,
  [SMALL_STATE(6878)] = 277142,
  [SMALL_STATE(6879)] = 277174,
  [SMALL_STATE(6880)] = 277206,
  [SMALL_STATE(6881)] = 277238,
  [SMALL_STATE(6882)] = 277264,
  [SMALL_STATE(6883)] = 277294,
  [SMALL_STATE(6884)] = 277324,
  [SMALL_STATE(6885)] = 277354,
  [SMALL_STATE(6886)] = 277384,
  [SMALL_STATE(6887)] = 277414,
  [SMALL_STATE(6888)] = 277440,
  [SMALL_STATE(6889)] = 277478,
  [SMALL_STATE(6890)] = 277516,
  [SMALL_STATE(6891)] = 277556,
  [SMALL_STATE(6892)] = 277588,
  [SMALL_STATE(6893)] = 277610,
  [SMALL_STATE(6894)] = 277650,
  [SMALL_STATE(6895)] = 277684,
  [SMALL_STATE(6896)] = 277717,
  [SMALL_STATE(6897)] = 277754,
  [SMALL_STATE(6898)] = 277783,
  [SMALL_STATE(6899)] = 277812,
  [SMALL_STATE(6900)] = 277841,
  [SMALL_STATE(6901)] = 277870,
  [SMALL_STATE(6902)] = 277903,
  [SMALL_STATE(6903)] = 277932,
  [SMALL_STATE(6904)] = 277961,
  [SMALL_STATE(6905)] = 277990,
  [SMALL_STATE(6906)] = 278019,
  [SMALL_STATE(6907)] = 278052,
  [SMALL_STATE(6908)] = 278085,
  [SMALL_STATE(6909)] = 278120,
  [SMALL_STATE(6910)] = 278153,
  [SMALL_STATE(6911)] = 278186,
  [SMALL_STATE(6912)] = 278225,
  [SMALL_STATE(6913)] = 278258,
  [SMALL_STATE(6914)] = 278291,
  [SMALL_STATE(6915)] = 278316,
  [SMALL_STATE(6916)] = 278349,
  [SMALL_STATE(6917)] = 278382,
  [SMALL_STATE(6918)] = 278417,
  [SMALL_STATE(6919)] = 278444,
  [SMALL_STATE(6920)] = 278471,
  [SMALL_STATE(6921)] = 278498,
  [SMALL_STATE(6922)] = 278531,
  [SMALL_STATE(6923)] = 278570,
  [SMALL_STATE(6924)] = 278595,
  [SMALL_STATE(6925)] = 278632,
  [SMALL_STATE(6926)] = 278671,
  [SMALL_STATE(6927)] = 278704,
  [SMALL_STATE(6928)] = 278737,
  [SMALL_STATE(6929)] = 278764,
  [SMALL_STATE(6930)] = 278797,
  [SMALL_STATE(6931)] = 278830,
  [SMALL_STATE(6932)] = 278863,
  [SMALL_STATE(6933)] = 278896,
  [SMALL_STATE(6934)] = 278921,
  [SMALL_STATE(6935)] = 278954,
  [SMALL_STATE(6936)] = 278987,
  [SMALL_STATE(6937)] = 279020,
  [SMALL_STATE(6938)] = 279053,
  [SMALL_STATE(6939)] = 279088,
  [SMALL_STATE(6940)] = 279121,
  [SMALL_STATE(6941)] = 279154,
  [SMALL_STATE(6942)] = 279187,
  [SMALL_STATE(6943)] = 279222,
  [SMALL_STATE(6944)] = 279255,
  [SMALL_STATE(6945)] = 279288,
  [SMALL_STATE(6946)] = 279323,
  [SMALL_STATE(6947)] = 279356,
  [SMALL_STATE(6948)] = 279389,
  [SMALL_STATE(6949)] = 279414,
  [SMALL_STATE(6950)] = 279449,
  [SMALL_STATE(6951)] = 279482,
  [SMALL_STATE(6952)] = 279521,
  [SMALL_STATE(6953)] = 279556,
  [SMALL_STATE(6954)] = 279591,
  [SMALL_STATE(6955)] = 279624,
  [SMALL_STATE(6956)] = 279651,
  [SMALL_STATE(6957)] = 279678,
  [SMALL_STATE(6958)] = 279705,
  [SMALL_STATE(6959)] = 279744,
  [SMALL_STATE(6960)] = 279777,
  [SMALL_STATE(6961)] = 279804,
  [SMALL_STATE(6962)] = 279829,
  [SMALL_STATE(6963)] = 279862,
  [SMALL_STATE(6964)] = 279897,
  [SMALL_STATE(6965)] = 279930,
  [SMALL_STATE(6966)] = 279963,
  [SMALL_STATE(6967)] = 279996,
  [SMALL_STATE(6968)] = 280029,
  [SMALL_STATE(6969)] = 280062,
  [SMALL_STATE(6970)] = 280097,
  [SMALL_STATE(6971)] = 280136,
  [SMALL_STATE(6972)] = 280161,
  [SMALL_STATE(6973)] = 280196,
  [SMALL_STATE(6974)] = 280231,
  [SMALL_STATE(6975)] = 280261,
  [SMALL_STATE(6976)] = 280297,
  [SMALL_STATE(6977)] = 280333,
  [SMALL_STATE(6978)] = 280369,
  [SMALL_STATE(6979)] = 280399,
  [SMALL_STATE(6980)] = 280425,
  [SMALL_STATE(6981)] = 280461,
  [SMALL_STATE(6982)] = 280497,
  [SMALL_STATE(6983)] = 280523,
  [SMALL_STATE(6984)] = 280559,
  [SMALL_STATE(6985)] = 280585,
  [SMALL_STATE(6986)] = 280615,
  [SMALL_STATE(6987)] = 280641,
  [SMALL_STATE(6988)] = 280667,
  [SMALL_STATE(6989)] = 280703,
  [SMALL_STATE(6990)] = 280729,
  [SMALL_STATE(6991)] = 280755,
  [SMALL_STATE(6992)] = 280781,
  [SMALL_STATE(6993)] = 280801,
  [SMALL_STATE(6994)] = 280821,
  [SMALL_STATE(6995)] = 280851,
  [SMALL_STATE(6996)] = 280887,
  [SMALL_STATE(6997)] = 280907,
  [SMALL_STATE(6998)] = 280927,
  [SMALL_STATE(6999)] = 280949,
  [SMALL_STATE(7000)] = 280979,
  [SMALL_STATE(7001)] = 281015,
  [SMALL_STATE(7002)] = 281045,
  [SMALL_STATE(7003)] = 281081,
  [SMALL_STATE(7004)] = 281117,
  [SMALL_STATE(7005)] = 281153,
  [SMALL_STATE(7006)] = 281183,
  [SMALL_STATE(7007)] = 281219,
  [SMALL_STATE(7008)] = 281255,
  [SMALL_STATE(7009)] = 281291,
  [SMALL_STATE(7010)] = 281311,
  [SMALL_STATE(7011)] = 281347,
  [SMALL_STATE(7012)] = 281367,
  [SMALL_STATE(7013)] = 281387,
  [SMALL_STATE(7014)] = 281407,
  [SMALL_STATE(7015)] = 281427,
  [SMALL_STATE(7016)] = 281463,
  [SMALL_STATE(7017)] = 281499,
  [SMALL_STATE(7018)] = 281529,
  [SMALL_STATE(7019)] = 281549,
  [SMALL_STATE(7020)] = 281585,
  [SMALL_STATE(7021)] = 281621,
  [SMALL_STATE(7022)] = 281657,
  [SMALL_STATE(7023)] = 281693,
  [SMALL_STATE(7024)] = 281713,
  [SMALL_STATE(7025)] = 281738,
  [SMALL_STATE(7026)] = 281773,
  [SMALL_STATE(7027)] = 281798,
  [SMALL_STATE(7028)] = 281817,
  [SMALL_STATE(7029)] = 281848,
  [SMALL_STATE(7030)] = 281875,
  [SMALL_STATE(7031)] = 281894,
  [SMALL_STATE(7032)] = 281929,
  [SMALL_STATE(7033)] = 281964,
  [SMALL_STATE(7034)] = 281999,
  [SMALL_STATE(7035)] = 282030,
  [SMALL_STATE(7036)] = 282059,
  [SMALL_STATE(7037)] = 282086,
  [SMALL_STATE(7038)] = 282113,
  [SMALL_STATE(7039)] = 282144,
  [SMALL_STATE(7040)] = 282163,
  [SMALL_STATE(7041)] = 282196,
  [SMALL_STATE(7042)] = 282217,
  [SMALL_STATE(7043)] = 282246,
  [SMALL_STATE(7044)] = 282277,
  [SMALL_STATE(7045)] = 282310,
  [SMALL_STATE(7046)] = 282339,
  [SMALL_STATE(7047)] = 282370,
  [SMALL_STATE(7048)] = 282405,
  [SMALL_STATE(7049)] = 282434,
  [SMALL_STATE(7050)] = 282461,
  [SMALL_STATE(7051)] = 282488,
  [SMALL_STATE(7052)] = 282515,
  [SMALL_STATE(7053)] = 282542,
  [SMALL_STATE(7054)] = 282577,
  [SMALL_STATE(7055)] = 282604,
  [SMALL_STATE(7056)] = 282631,
  [SMALL_STATE(7057)] = 282658,
  [SMALL_STATE(7058)] = 282687,
  [SMALL_STATE(7059)] = 282722,
  [SMALL_STATE(7060)] = 282741,
  [SMALL_STATE(7061)] = 282776,
  [SMALL_STATE(7062)] = 282801,
  [SMALL_STATE(7063)] = 282820,
  [SMALL_STATE(7064)] = 282855,
  [SMALL_STATE(7065)] = 282884,
  [SMALL_STATE(7066)] = 282915,
  [SMALL_STATE(7067)] = 282942,
  [SMALL_STATE(7068)] = 282967,
  [SMALL_STATE(7069)] = 283002,
  [SMALL_STATE(7070)] = 283029,
  [SMALL_STATE(7071)] = 283064,
  [SMALL_STATE(7072)] = 283099,
  [SMALL_STATE(7073)] = 283134,
  [SMALL_STATE(7074)] = 283165,
  [SMALL_STATE(7075)] = 283196,
  [SMALL_STATE(7076)] = 283221,
  [SMALL_STATE(7077)] = 283252,
  [SMALL_STATE(7078)] = 283283,
  [SMALL_STATE(7079)] = 283310,
  [SMALL_STATE(7080)] = 283333,
  [SMALL_STATE(7081)] = 283358,
  [SMALL_STATE(7082)] = 283383,
  [SMALL_STATE(7083)] = 283410,
  [SMALL_STATE(7084)] = 283437,
  [SMALL_STATE(7085)] = 283462,
  [SMALL_STATE(7086)] = 283487,
  [SMALL_STATE(7087)] = 283518,
  [SMALL_STATE(7088)] = 283547,
  [SMALL_STATE(7089)] = 283582,
  [SMALL_STATE(7090)] = 283613,
  [SMALL_STATE(7091)] = 283632,
  [SMALL_STATE(7092)] = 283663,
  [SMALL_STATE(7093)] = 283690,
  [SMALL_STATE(7094)] = 283709,
  [SMALL_STATE(7095)] = 283734,
  [SMALL_STATE(7096)] = 283769,
  [SMALL_STATE(7097)] = 283796,
  [SMALL_STATE(7098)] = 283825,
  [SMALL_STATE(7099)] = 283856,
  [SMALL_STATE(7100)] = 283891,
  [SMALL_STATE(7101)] = 283922,
  [SMALL_STATE(7102)] = 283947,
  [SMALL_STATE(7103)] = 283972,
  [SMALL_STATE(7104)] = 283999,
  [SMALL_STATE(7105)] = 284032,
  [SMALL_STATE(7106)] = 284059,
  [SMALL_STATE(7107)] = 284086,
  [SMALL_STATE(7108)] = 284113,
  [SMALL_STATE(7109)] = 284148,
  [SMALL_STATE(7110)] = 284177,
  [SMALL_STATE(7111)] = 284202,
  [SMALL_STATE(7112)] = 284231,
  [SMALL_STATE(7113)] = 284258,
  [SMALL_STATE(7114)] = 284293,
  [SMALL_STATE(7115)] = 284324,
  [SMALL_STATE(7116)] = 284351,
  [SMALL_STATE(7117)] = 284378,
  [SMALL_STATE(7118)] = 284403,
  [SMALL_STATE(7119)] = 284428,
  [SMALL_STATE(7120)] = 284461,
  [SMALL_STATE(7121)] = 284496,
  [SMALL_STATE(7122)] = 284523,
  [SMALL_STATE(7123)] = 284548,
  [SMALL_STATE(7124)] = 284583,
  [SMALL_STATE(7125)] = 284614,
  [SMALL_STATE(7126)] = 284643,
  [SMALL_STATE(7127)] = 284678,
  [SMALL_STATE(7128)] = 284709,
  [SMALL_STATE(7129)] = 284738,
  [SMALL_STATE(7130)] = 284771,
  [SMALL_STATE(7131)] = 284798,
  [SMALL_STATE(7132)] = 284828,
  [SMALL_STATE(7133)] = 284850,
  [SMALL_STATE(7134)] = 284872,
  [SMALL_STATE(7135)] = 284898,
  [SMALL_STATE(7136)] = 284922,
  [SMALL_STATE(7137)] = 284946,
  [SMALL_STATE(7138)] = 284972,
  [SMALL_STATE(7139)] = 284994,
  [SMALL_STATE(7140)] = 285016,
  [SMALL_STATE(7141)] = 285048,
  [SMALL_STATE(7142)] = 285072,
  [SMALL_STATE(7143)] = 285100,
  [SMALL_STATE(7144)] = 285122,
  [SMALL_STATE(7145)] = 285152,
  [SMALL_STATE(7146)] = 285176,
  [SMALL_STATE(7147)] = 285200,
  [SMALL_STATE(7148)] = 285222,
  [SMALL_STATE(7149)] = 285252,
  [SMALL_STATE(7150)] = 285278,
  [SMALL_STATE(7151)] = 285300,
  [SMALL_STATE(7152)] = 285322,
  [SMALL_STATE(7153)] = 285348,
  [SMALL_STATE(7154)] = 285370,
  [SMALL_STATE(7155)] = 285394,
  [SMALL_STATE(7156)] = 285418,
  [SMALL_STATE(7157)] = 285442,
  [SMALL_STATE(7158)] = 285464,
  [SMALL_STATE(7159)] = 285494,
  [SMALL_STATE(7160)] = 285518,
  [SMALL_STATE(7161)] = 285542,
  [SMALL_STATE(7162)] = 285566,
  [SMALL_STATE(7163)] = 285596,
  [SMALL_STATE(7164)] = 285620,
  [SMALL_STATE(7165)] = 285644,
  [SMALL_STATE(7166)] = 285666,
  [SMALL_STATE(7167)] = 285688,
  [SMALL_STATE(7168)] = 285710,
  [SMALL_STATE(7169)] = 285734,
  [SMALL_STATE(7170)] = 285764,
  [SMALL_STATE(7171)] = 285788,
  [SMALL_STATE(7172)] = 285812,
  [SMALL_STATE(7173)] = 285834,
  [SMALL_STATE(7174)] = 285858,
  [SMALL_STATE(7175)] = 285882,
  [SMALL_STATE(7176)] = 285904,
  [SMALL_STATE(7177)] = 285934,
  [SMALL_STATE(7178)] = 285957,
  [SMALL_STATE(7179)] = 285988,
  [SMALL_STATE(7180)] = 286019,
  [SMALL_STATE(7181)] = 286042,
  [SMALL_STATE(7182)] = 286069,
  [SMALL_STATE(7183)] = 286096,
  [SMALL_STATE(7184)] = 286127,
  [SMALL_STATE(7185)] = 286148,
  [SMALL_STATE(7186)] = 286175,
  [SMALL_STATE(7187)] = 286202,
  [SMALL_STATE(7188)] = 286233,
  [SMALL_STATE(7189)] = 286260,
  [SMALL_STATE(7190)] = 286291,
  [SMALL_STATE(7191)] = 286318,
  [SMALL_STATE(7192)] = 286341,
  [SMALL_STATE(7193)] = 286364,
  [SMALL_STATE(7194)] = 286387,
  [SMALL_STATE(7195)] = 286414,
  [SMALL_STATE(7196)] = 286445,
  [SMALL_STATE(7197)] = 286472,
  [SMALL_STATE(7198)] = 286503,
  [SMALL_STATE(7199)] = 286534,
  [SMALL_STATE(7200)] = 286565,
  [SMALL_STATE(7201)] = 286596,
  [SMALL_STATE(7202)] = 286617,
  [SMALL_STATE(7203)] = 286648,
  [SMALL_STATE(7204)] = 286679,
  [SMALL_STATE(7205)] = 286710,
  [SMALL_STATE(7206)] = 286737,
  [SMALL_STATE(7207)] = 286760,
  [SMALL_STATE(7208)] = 286791,
  [SMALL_STATE(7209)] = 286814,
  [SMALL_STATE(7210)] = 286837,
  [SMALL_STATE(7211)] = 286868,
  [SMALL_STATE(7212)] = 286889,
  [SMALL_STATE(7213)] = 286910,
  [SMALL_STATE(7214)] = 286941,
  [SMALL_STATE(7215)] = 286968,
  [SMALL_STATE(7216)] = 286995,
  [SMALL_STATE(7217)] = 287014,
  [SMALL_STATE(7218)] = 287037,
  [SMALL_STATE(7219)] = 287068,
  [SMALL_STATE(7220)] = 287099,
  [SMALL_STATE(7221)] = 287130,
  [SMALL_STATE(7222)] = 287151,
  [SMALL_STATE(7223)] = 287182,
  [SMALL_STATE(7224)] = 287213,
  [SMALL_STATE(7225)] = 287244,
  [SMALL_STATE(7226)] = 287275,
  [SMALL_STATE(7227)] = 287302,
  [SMALL_STATE(7228)] = 287333,
  [SMALL_STATE(7229)] = 287364,
  [SMALL_STATE(7230)] = 287395,
  [SMALL_STATE(7231)] = 287426,
  [SMALL_STATE(7232)] = 287449,
  [SMALL_STATE(7233)] = 287480,
  [SMALL_STATE(7234)] = 287511,
  [SMALL_STATE(7235)] = 287542,
  [SMALL_STATE(7236)] = 287573,
  [SMALL_STATE(7237)] = 287599,
  [SMALL_STATE(7238)] = 287625,
  [SMALL_STATE(7239)] = 287651,
  [SMALL_STATE(7240)] = 287671,
  [SMALL_STATE(7241)] = 287697,
  [SMALL_STATE(7242)] = 287723,
  [SMALL_STATE(7243)] = 287751,
  [SMALL_STATE(7244)] = 287773,
  [SMALL_STATE(7245)] = 287795,
  [SMALL_STATE(7246)] = 287817,
  [SMALL_STATE(7247)] = 287839,
  [SMALL_STATE(7248)] = 287865,
  [SMALL_STATE(7249)] = 287891,
  [SMALL_STATE(7250)] = 287915,
  [SMALL_STATE(7251)] = 287941,
  [SMALL_STATE(7252)] = 287963,
  [SMALL_STATE(7253)] = 287985,
  [SMALL_STATE(7254)] = 288007,
  [SMALL_STATE(7255)] = 288029,
  [SMALL_STATE(7256)] = 288053,
  [SMALL_STATE(7257)] = 288077,
  [SMALL_STATE(7258)] = 288093,
  [SMALL_STATE(7259)] = 288119,
  [SMALL_STATE(7260)] = 288145,
  [SMALL_STATE(7261)] = 288169,
  [SMALL_STATE(7262)] = 288193,
  [SMALL_STATE(7263)] = 288209,
  [SMALL_STATE(7264)] = 288227,
  [SMALL_STATE(7265)] = 288249,
  [SMALL_STATE(7266)] = 288273,
  [SMALL_STATE(7267)] = 288299,
  [SMALL_STATE(7268)] = 288325,
  [SMALL_STATE(7269)] = 288351,
  [SMALL_STATE(7270)] = 288377,
  [SMALL_STATE(7271)] = 288403,
  [SMALL_STATE(7272)] = 288429,
  [SMALL_STATE(7273)] = 288451,
  [SMALL_STATE(7274)] = 288475,
  [SMALL_STATE(7275)] = 288501,
  [SMALL_STATE(7276)] = 288525,
  [SMALL_STATE(7277)] = 288547,
  [SMALL_STATE(7278)] = 288569,
  [SMALL_STATE(7279)] = 288595,
  [SMALL_STATE(7280)] = 288617,
  [SMALL_STATE(7281)] = 288637,
  [SMALL_STATE(7282)] = 288663,
  [SMALL_STATE(7283)] = 288689,
  [SMALL_STATE(7284)] = 288711,
  [SMALL_STATE(7285)] = 288737,
  [SMALL_STATE(7286)] = 288763,
  [SMALL_STATE(7287)] = 288789,
  [SMALL_STATE(7288)] = 288811,
  [SMALL_STATE(7289)] = 288837,
  [SMALL_STATE(7290)] = 288863,
  [SMALL_STATE(7291)] = 288889,
  [SMALL_STATE(7292)] = 288915,
  [SMALL_STATE(7293)] = 288935,
  [SMALL_STATE(7294)] = 288961,
  [SMALL_STATE(7295)] = 288987,
  [SMALL_STATE(7296)] = 289009,
  [SMALL_STATE(7297)] = 289029,
  [SMALL_STATE(7298)] = 289055,
  [SMALL_STATE(7299)] = 289070,
  [SMALL_STATE(7300)] = 289091,
  [SMALL_STATE(7301)] = 289108,
  [SMALL_STATE(7302)] = 289127,
  [SMALL_STATE(7303)] = 289152,
  [SMALL_STATE(7304)] = 289173,
  [SMALL_STATE(7305)] = 289196,
  [SMALL_STATE(7306)] = 289219,
  [SMALL_STATE(7307)] = 289244,
  [SMALL_STATE(7308)] = 289267,
  [SMALL_STATE(7309)] = 289292,
  [SMALL_STATE(7310)] = 289315,
  [SMALL_STATE(7311)] = 289338,
  [SMALL_STATE(7312)] = 289355,
  [SMALL_STATE(7313)] = 289376,
  [SMALL_STATE(7314)] = 289397,
  [SMALL_STATE(7315)] = 289420,
  [SMALL_STATE(7316)] = 289443,
  [SMALL_STATE(7317)] = 289468,
  [SMALL_STATE(7318)] = 289489,
  [SMALL_STATE(7319)] = 289510,
  [SMALL_STATE(7320)] = 289531,
  [SMALL_STATE(7321)] = 289552,
  [SMALL_STATE(7322)] = 289567,
  [SMALL_STATE(7323)] = 289584,
  [SMALL_STATE(7324)] = 289607,
  [SMALL_STATE(7325)] = 289626,
  [SMALL_STATE(7326)] = 289641,
  [SMALL_STATE(7327)] = 289662,
  [SMALL_STATE(7328)] = 289677,
  [SMALL_STATE(7329)] = 289694,
  [SMALL_STATE(7330)] = 289717,
  [SMALL_STATE(7331)] = 289740,
  [SMALL_STATE(7332)] = 289763,
  [SMALL_STATE(7333)] = 289784,
  [SMALL_STATE(7334)] = 289805,
  [SMALL_STATE(7335)] = 289828,
  [SMALL_STATE(7336)] = 289851,
  [SMALL_STATE(7337)] = 289874,
  [SMALL_STATE(7338)] = 289895,
  [SMALL_STATE(7339)] = 289920,
  [SMALL_STATE(7340)] = 289943,
  [SMALL_STATE(7341)] = 289958,
  [SMALL_STATE(7342)] = 289979,
  [SMALL_STATE(7343)] = 290002,
  [SMALL_STATE(7344)] = 290027,
  [SMALL_STATE(7345)] = 290052,
  [SMALL_STATE(7346)] = 290075,
  [SMALL_STATE(7347)] = 290092,
  [SMALL_STATE(7348)] = 290107,
  [SMALL_STATE(7349)] = 290126,
  [SMALL_STATE(7350)] = 290143,
  [SMALL_STATE(7351)] = 290158,
  [SMALL_STATE(7352)] = 290175,
  [SMALL_STATE(7353)] = 290196,
  [SMALL_STATE(7354)] = 290217,
  [SMALL_STATE(7355)] = 290238,
  [SMALL_STATE(7356)] = 290261,
  [SMALL_STATE(7357)] = 290276,
  [SMALL_STATE(7358)] = 290301,
  [SMALL_STATE(7359)] = 290320,
  [SMALL_STATE(7360)] = 290339,
  [SMALL_STATE(7361)] = 290356,
  [SMALL_STATE(7362)] = 290373,
  [SMALL_STATE(7363)] = 290394,
  [SMALL_STATE(7364)] = 290411,
  [SMALL_STATE(7365)] = 290432,
  [SMALL_STATE(7366)] = 290449,
  [SMALL_STATE(7367)] = 290466,
  [SMALL_STATE(7368)] = 290483,
  [SMALL_STATE(7369)] = 290500,
  [SMALL_STATE(7370)] = 290517,
  [SMALL_STATE(7371)] = 290534,
  [SMALL_STATE(7372)] = 290551,
  [SMALL_STATE(7373)] = 290574,
  [SMALL_STATE(7374)] = 290591,
  [SMALL_STATE(7375)] = 290608,
  [SMALL_STATE(7376)] = 290625,
  [SMALL_STATE(7377)] = 290642,
  [SMALL_STATE(7378)] = 290661,
  [SMALL_STATE(7379)] = 290678,
  [SMALL_STATE(7380)] = 290692,
  [SMALL_STATE(7381)] = 290714,
  [SMALL_STATE(7382)] = 290736,
  [SMALL_STATE(7383)] = 290754,
  [SMALL_STATE(7384)] = 290776,
  [SMALL_STATE(7385)] = 290790,
  [SMALL_STATE(7386)] = 290810,
  [SMALL_STATE(7387)] = 290824,
  [SMALL_STATE(7388)] = 290838,
  [SMALL_STATE(7389)] = 290860,
  [SMALL_STATE(7390)] = 290882,
  [SMALL_STATE(7391)] = 290904,
  [SMALL_STATE(7392)] = 290924,
  [SMALL_STATE(7393)] = 290944,
  [SMALL_STATE(7394)] = 290964,
  [SMALL_STATE(7395)] = 290986,
  [SMALL_STATE(7396)] = 291008,
  [SMALL_STATE(7397)] = 291030,
  [SMALL_STATE(7398)] = 291048,
  [SMALL_STATE(7399)] = 291070,
  [SMALL_STATE(7400)] = 291092,
  [SMALL_STATE(7401)] = 291106,
  [SMALL_STATE(7402)] = 291128,
  [SMALL_STATE(7403)] = 291150,
  [SMALL_STATE(7404)] = 291164,
  [SMALL_STATE(7405)] = 291184,
  [SMALL_STATE(7406)] = 291204,
  [SMALL_STATE(7407)] = 291226,
  [SMALL_STATE(7408)] = 291240,
  [SMALL_STATE(7409)] = 291254,
  [SMALL_STATE(7410)] = 291268,
  [SMALL_STATE(7411)] = 291286,
  [SMALL_STATE(7412)] = 291300,
  [SMALL_STATE(7413)] = 291322,
  [SMALL_STATE(7414)] = 291344,
  [SMALL_STATE(7415)] = 291362,
  [SMALL_STATE(7416)] = 291380,
  [SMALL_STATE(7417)] = 291402,
  [SMALL_STATE(7418)] = 291424,
  [SMALL_STATE(7419)] = 291442,
  [SMALL_STATE(7420)] = 291464,
  [SMALL_STATE(7421)] = 291484,
  [SMALL_STATE(7422)] = 291504,
  [SMALL_STATE(7423)] = 291524,
  [SMALL_STATE(7424)] = 291538,
  [SMALL_STATE(7425)] = 291558,
  [SMALL_STATE(7426)] = 291580,
  [SMALL_STATE(7427)] = 291600,
  [SMALL_STATE(7428)] = 291622,
  [SMALL_STATE(7429)] = 291636,
  [SMALL_STATE(7430)] = 291658,
  [SMALL_STATE(7431)] = 291680,
  [SMALL_STATE(7432)] = 291702,
  [SMALL_STATE(7433)] = 291716,
  [SMALL_STATE(7434)] = 291736,
  [SMALL_STATE(7435)] = 291750,
  [SMALL_STATE(7436)] = 291770,
  [SMALL_STATE(7437)] = 291790,
  [SMALL_STATE(7438)] = 291807,
  [SMALL_STATE(7439)] = 291824,
  [SMALL_STATE(7440)] = 291837,
  [SMALL_STATE(7441)] = 291854,
  [SMALL_STATE(7442)] = 291873,
  [SMALL_STATE(7443)] = 291890,
  [SMALL_STATE(7444)] = 291909,
  [SMALL_STATE(7445)] = 291926,
  [SMALL_STATE(7446)] = 291943,
  [SMALL_STATE(7447)] = 291962,
  [SMALL_STATE(7448)] = 291981,
  [SMALL_STATE(7449)] = 292000,
  [SMALL_STATE(7450)] = 292017,
  [SMALL_STATE(7451)] = 292034,
  [SMALL_STATE(7452)] = 292051,
  [SMALL_STATE(7453)] = 292068,
  [SMALL_STATE(7454)] = 292085,
  [SMALL_STATE(7455)] = 292102,
  [SMALL_STATE(7456)] = 292119,
  [SMALL_STATE(7457)] = 292136,
  [SMALL_STATE(7458)] = 292155,
  [SMALL_STATE(7459)] = 292172,
  [SMALL_STATE(7460)] = 292191,
  [SMALL_STATE(7461)] = 292210,
  [SMALL_STATE(7462)] = 292227,
  [SMALL_STATE(7463)] = 292240,
  [SMALL_STATE(7464)] = 292257,
  [SMALL_STATE(7465)] = 292276,
  [SMALL_STATE(7466)] = 292295,
  [SMALL_STATE(7467)] = 292314,
  [SMALL_STATE(7468)] = 292325,
  [SMALL_STATE(7469)] = 292342,
  [SMALL_STATE(7470)] = 292361,
  [SMALL_STATE(7471)] = 292380,
  [SMALL_STATE(7472)] = 292397,
  [SMALL_STATE(7473)] = 292414,
  [SMALL_STATE(7474)] = 292431,
  [SMALL_STATE(7475)] = 292448,
  [SMALL_STATE(7476)] = 292465,
  [SMALL_STATE(7477)] = 292484,
  [SMALL_STATE(7478)] = 292501,
  [SMALL_STATE(7479)] = 292518,
  [SMALL_STATE(7480)] = 292535,
  [SMALL_STATE(7481)] = 292554,
  [SMALL_STATE(7482)] = 292571,
  [SMALL_STATE(7483)] = 292590,
  [SMALL_STATE(7484)] = 292607,
  [SMALL_STATE(7485)] = 292624,
  [SMALL_STATE(7486)] = 292641,
  [SMALL_STATE(7487)] = 292658,
  [SMALL_STATE(7488)] = 292675,
  [SMALL_STATE(7489)] = 292692,
  [SMALL_STATE(7490)] = 292711,
  [SMALL_STATE(7491)] = 292728,
  [SMALL_STATE(7492)] = 292745,
  [SMALL_STATE(7493)] = 292762,
  [SMALL_STATE(7494)] = 292781,
  [SMALL_STATE(7495)] = 292798,
  [SMALL_STATE(7496)] = 292815,
  [SMALL_STATE(7497)] = 292834,
  [SMALL_STATE(7498)] = 292853,
  [SMALL_STATE(7499)] = 292870,
  [SMALL_STATE(7500)] = 292887,
  [SMALL_STATE(7501)] = 292904,
  [SMALL_STATE(7502)] = 292923,
  [SMALL_STATE(7503)] = 292942,
  [SMALL_STATE(7504)] = 292961,
  [SMALL_STATE(7505)] = 292978,
  [SMALL_STATE(7506)] = 292995,
  [SMALL_STATE(7507)] = 293012,
  [SMALL_STATE(7508)] = 293031,
  [SMALL_STATE(7509)] = 293048,
  [SMALL_STATE(7510)] = 293067,
  [SMALL_STATE(7511)] = 293084,
  [SMALL_STATE(7512)] = 293101,
  [SMALL_STATE(7513)] = 293117,
  [SMALL_STATE(7514)] = 293133,
  [SMALL_STATE(7515)] = 293147,
  [SMALL_STATE(7516)] = 293163,
  [SMALL_STATE(7517)] = 293179,
  [SMALL_STATE(7518)] = 293193,
  [SMALL_STATE(7519)] = 293209,
  [SMALL_STATE(7520)] = 293223,
  [SMALL_STATE(7521)] = 293239,
  [SMALL_STATE(7522)] = 293255,
  [SMALL_STATE(7523)] = 293269,
  [SMALL_STATE(7524)] = 293285,
  [SMALL_STATE(7525)] = 293301,
  [SMALL_STATE(7526)] = 293317,
  [SMALL_STATE(7527)] = 293333,
  [SMALL_STATE(7528)] = 293349,
  [SMALL_STATE(7529)] = 293363,
  [SMALL_STATE(7530)] = 293379,
  [SMALL_STATE(7531)] = 293395,
  [SMALL_STATE(7532)] = 293411,
  [SMALL_STATE(7533)] = 293425,
  [SMALL_STATE(7534)] = 293439,
  [SMALL_STATE(7535)] = 293453,
  [SMALL_STATE(7536)] = 293469,
  [SMALL_STATE(7537)] = 293485,
  [SMALL_STATE(7538)] = 293499,
  [SMALL_STATE(7539)] = 293515,
  [SMALL_STATE(7540)] = 293531,
  [SMALL_STATE(7541)] = 293547,
  [SMALL_STATE(7542)] = 293561,
  [SMALL_STATE(7543)] = 293577,
  [SMALL_STATE(7544)] = 293593,
  [SMALL_STATE(7545)] = 293607,
  [SMALL_STATE(7546)] = 293621,
  [SMALL_STATE(7547)] = 293637,
  [SMALL_STATE(7548)] = 293653,
  [SMALL_STATE(7549)] = 293669,
  [SMALL_STATE(7550)] = 293685,
  [SMALL_STATE(7551)] = 293699,
  [SMALL_STATE(7552)] = 293713,
  [SMALL_STATE(7553)] = 293729,
  [SMALL_STATE(7554)] = 293745,
  [SMALL_STATE(7555)] = 293761,
  [SMALL_STATE(7556)] = 293777,
  [SMALL_STATE(7557)] = 293791,
  [SMALL_STATE(7558)] = 293807,
  [SMALL_STATE(7559)] = 293821,
  [SMALL_STATE(7560)] = 293837,
  [SMALL_STATE(7561)] = 293853,
  [SMALL_STATE(7562)] = 293869,
  [SMALL_STATE(7563)] = 293885,
  [SMALL_STATE(7564)] = 293901,
  [SMALL_STATE(7565)] = 293917,
  [SMALL_STATE(7566)] = 293931,
  [SMALL_STATE(7567)] = 293947,
  [SMALL_STATE(7568)] = 293963,
  [SMALL_STATE(7569)] = 293979,
  [SMALL_STATE(7570)] = 293995,
  [SMALL_STATE(7571)] = 294011,
  [SMALL_STATE(7572)] = 294025,
  [SMALL_STATE(7573)] = 294041,
  [SMALL_STATE(7574)] = 294057,
  [SMALL_STATE(7575)] = 294073,
  [SMALL_STATE(7576)] = 294089,
  [SMALL_STATE(7577)] = 294105,
  [SMALL_STATE(7578)] = 294119,
  [SMALL_STATE(7579)] = 294135,
  [SMALL_STATE(7580)] = 294149,
  [SMALL_STATE(7581)] = 294165,
  [SMALL_STATE(7582)] = 294181,
  [SMALL_STATE(7583)] = 294197,
  [SMALL_STATE(7584)] = 294211,
  [SMALL_STATE(7585)] = 294225,
  [SMALL_STATE(7586)] = 294239,
  [SMALL_STATE(7587)] = 294255,
  [SMALL_STATE(7588)] = 294271,
  [SMALL_STATE(7589)] = 294287,
  [SMALL_STATE(7590)] = 294303,
  [SMALL_STATE(7591)] = 294317,
  [SMALL_STATE(7592)] = 294329,
  [SMALL_STATE(7593)] = 294343,
  [SMALL_STATE(7594)] = 294357,
  [SMALL_STATE(7595)] = 294373,
  [SMALL_STATE(7596)] = 294389,
  [SMALL_STATE(7597)] = 294403,
  [SMALL_STATE(7598)] = 294419,
  [SMALL_STATE(7599)] = 294435,
  [SMALL_STATE(7600)] = 294451,
  [SMALL_STATE(7601)] = 294467,
  [SMALL_STATE(7602)] = 294483,
  [SMALL_STATE(7603)] = 294499,
  [SMALL_STATE(7604)] = 294515,
  [SMALL_STATE(7605)] = 294529,
  [SMALL_STATE(7606)] = 294545,
  [SMALL_STATE(7607)] = 294561,
  [SMALL_STATE(7608)] = 294577,
  [SMALL_STATE(7609)] = 294593,
  [SMALL_STATE(7610)] = 294607,
  [SMALL_STATE(7611)] = 294623,
  [SMALL_STATE(7612)] = 294639,
  [SMALL_STATE(7613)] = 294655,
  [SMALL_STATE(7614)] = 294669,
  [SMALL_STATE(7615)] = 294685,
  [SMALL_STATE(7616)] = 294701,
  [SMALL_STATE(7617)] = 294711,
  [SMALL_STATE(7618)] = 294725,
  [SMALL_STATE(7619)] = 294739,
  [SMALL_STATE(7620)] = 294755,
  [SMALL_STATE(7621)] = 294771,
  [SMALL_STATE(7622)] = 294785,
  [SMALL_STATE(7623)] = 294801,
  [SMALL_STATE(7624)] = 294817,
  [SMALL_STATE(7625)] = 294833,
  [SMALL_STATE(7626)] = 294847,
  [SMALL_STATE(7627)] = 294863,
  [SMALL_STATE(7628)] = 294877,
  [SMALL_STATE(7629)] = 294893,
  [SMALL_STATE(7630)] = 294909,
  [SMALL_STATE(7631)] = 294923,
  [SMALL_STATE(7632)] = 294939,
  [SMALL_STATE(7633)] = 294953,
  [SMALL_STATE(7634)] = 294969,
  [SMALL_STATE(7635)] = 294985,
  [SMALL_STATE(7636)] = 294999,
  [SMALL_STATE(7637)] = 295015,
  [SMALL_STATE(7638)] = 295031,
  [SMALL_STATE(7639)] = 295045,
  [SMALL_STATE(7640)] = 295059,
  [SMALL_STATE(7641)] = 295071,
  [SMALL_STATE(7642)] = 295085,
  [SMALL_STATE(7643)] = 295101,
  [SMALL_STATE(7644)] = 295117,
  [SMALL_STATE(7645)] = 295131,
  [SMALL_STATE(7646)] = 295147,
  [SMALL_STATE(7647)] = 295163,
  [SMALL_STATE(7648)] = 295179,
  [SMALL_STATE(7649)] = 295195,
  [SMALL_STATE(7650)] = 295211,
  [SMALL_STATE(7651)] = 295227,
  [SMALL_STATE(7652)] = 295243,
  [SMALL_STATE(7653)] = 295259,
  [SMALL_STATE(7654)] = 295275,
  [SMALL_STATE(7655)] = 295291,
  [SMALL_STATE(7656)] = 295305,
  [SMALL_STATE(7657)] = 295321,
  [SMALL_STATE(7658)] = 295337,
  [SMALL_STATE(7659)] = 295353,
  [SMALL_STATE(7660)] = 295369,
  [SMALL_STATE(7661)] = 295383,
  [SMALL_STATE(7662)] = 295397,
  [SMALL_STATE(7663)] = 295411,
  [SMALL_STATE(7664)] = 295427,
  [SMALL_STATE(7665)] = 295441,
  [SMALL_STATE(7666)] = 295457,
  [SMALL_STATE(7667)] = 295467,
  [SMALL_STATE(7668)] = 295483,
  [SMALL_STATE(7669)] = 295499,
  [SMALL_STATE(7670)] = 295513,
  [SMALL_STATE(7671)] = 295527,
  [SMALL_STATE(7672)] = 295543,
  [SMALL_STATE(7673)] = 295557,
  [SMALL_STATE(7674)] = 295573,
  [SMALL_STATE(7675)] = 295589,
  [SMALL_STATE(7676)] = 295603,
  [SMALL_STATE(7677)] = 295617,
  [SMALL_STATE(7678)] = 295633,
  [SMALL_STATE(7679)] = 295647,
  [SMALL_STATE(7680)] = 295663,
  [SMALL_STATE(7681)] = 295677,
  [SMALL_STATE(7682)] = 295693,
  [SMALL_STATE(7683)] = 295707,
  [SMALL_STATE(7684)] = 295723,
  [SMALL_STATE(7685)] = 295737,
  [SMALL_STATE(7686)] = 295751,
  [SMALL_STATE(7687)] = 295767,
  [SMALL_STATE(7688)] = 295781,
  [SMALL_STATE(7689)] = 295797,
  [SMALL_STATE(7690)] = 295811,
  [SMALL_STATE(7691)] = 295827,
  [SMALL_STATE(7692)] = 295843,
  [SMALL_STATE(7693)] = 295859,
  [SMALL_STATE(7694)] = 295873,
  [SMALL_STATE(7695)] = 295889,
  [SMALL_STATE(7696)] = 295905,
  [SMALL_STATE(7697)] = 295919,
  [SMALL_STATE(7698)] = 295933,
  [SMALL_STATE(7699)] = 295949,
  [SMALL_STATE(7700)] = 295965,
  [SMALL_STATE(7701)] = 295977,
  [SMALL_STATE(7702)] = 295989,
  [SMALL_STATE(7703)] = 296005,
  [SMALL_STATE(7704)] = 296021,
  [SMALL_STATE(7705)] = 296035,
  [SMALL_STATE(7706)] = 296051,
  [SMALL_STATE(7707)] = 296065,
  [SMALL_STATE(7708)] = 296079,
  [SMALL_STATE(7709)] = 296095,
  [SMALL_STATE(7710)] = 296109,
  [SMALL_STATE(7711)] = 296125,
  [SMALL_STATE(7712)] = 296141,
  [SMALL_STATE(7713)] = 296155,
  [SMALL_STATE(7714)] = 296169,
  [SMALL_STATE(7715)] = 296183,
  [SMALL_STATE(7716)] = 296197,
  [SMALL_STATE(7717)] = 296211,
  [SMALL_STATE(7718)] = 296225,
  [SMALL_STATE(7719)] = 296241,
  [SMALL_STATE(7720)] = 296257,
  [SMALL_STATE(7721)] = 296271,
  [SMALL_STATE(7722)] = 296285,
  [SMALL_STATE(7723)] = 296301,
  [SMALL_STATE(7724)] = 296315,
  [SMALL_STATE(7725)] = 296331,
  [SMALL_STATE(7726)] = 296347,
  [SMALL_STATE(7727)] = 296361,
  [SMALL_STATE(7728)] = 296375,
  [SMALL_STATE(7729)] = 296391,
  [SMALL_STATE(7730)] = 296407,
  [SMALL_STATE(7731)] = 296423,
  [SMALL_STATE(7732)] = 296439,
  [SMALL_STATE(7733)] = 296453,
  [SMALL_STATE(7734)] = 296467,
  [SMALL_STATE(7735)] = 296483,
  [SMALL_STATE(7736)] = 296497,
  [SMALL_STATE(7737)] = 296513,
  [SMALL_STATE(7738)] = 296527,
  [SMALL_STATE(7739)] = 296541,
  [SMALL_STATE(7740)] = 296555,
  [SMALL_STATE(7741)] = 296571,
  [SMALL_STATE(7742)] = 296587,
  [SMALL_STATE(7743)] = 296601,
  [SMALL_STATE(7744)] = 296617,
  [SMALL_STATE(7745)] = 296633,
  [SMALL_STATE(7746)] = 296649,
  [SMALL_STATE(7747)] = 296665,
  [SMALL_STATE(7748)] = 296681,
  [SMALL_STATE(7749)] = 296697,
  [SMALL_STATE(7750)] = 296713,
  [SMALL_STATE(7751)] = 296727,
  [SMALL_STATE(7752)] = 296743,
  [SMALL_STATE(7753)] = 296759,
  [SMALL_STATE(7754)] = 296773,
  [SMALL_STATE(7755)] = 296787,
  [SMALL_STATE(7756)] = 296803,
  [SMALL_STATE(7757)] = 296819,
  [SMALL_STATE(7758)] = 296833,
  [SMALL_STATE(7759)] = 296847,
  [SMALL_STATE(7760)] = 296863,
  [SMALL_STATE(7761)] = 296879,
  [SMALL_STATE(7762)] = 296895,
  [SMALL_STATE(7763)] = 296906,
  [SMALL_STATE(7764)] = 296917,
  [SMALL_STATE(7765)] = 296930,
  [SMALL_STATE(7766)] = 296943,
  [SMALL_STATE(7767)] = 296956,
  [SMALL_STATE(7768)] = 296967,
  [SMALL_STATE(7769)] = 296980,
  [SMALL_STATE(7770)] = 296993,
  [SMALL_STATE(7771)] = 297006,
  [SMALL_STATE(7772)] = 297019,
  [SMALL_STATE(7773)] = 297030,
  [SMALL_STATE(7774)] = 297043,
  [SMALL_STATE(7775)] = 297056,
  [SMALL_STATE(7776)] = 297069,
  [SMALL_STATE(7777)] = 297082,
  [SMALL_STATE(7778)] = 297095,
  [SMALL_STATE(7779)] = 297108,
  [SMALL_STATE(7780)] = 297121,
  [SMALL_STATE(7781)] = 297134,
  [SMALL_STATE(7782)] = 297147,
  [SMALL_STATE(7783)] = 297160,
  [SMALL_STATE(7784)] = 297173,
  [SMALL_STATE(7785)] = 297186,
  [SMALL_STATE(7786)] = 297199,
  [SMALL_STATE(7787)] = 297212,
  [SMALL_STATE(7788)] = 297225,
  [SMALL_STATE(7789)] = 297238,
  [SMALL_STATE(7790)] = 297251,
  [SMALL_STATE(7791)] = 297264,
  [SMALL_STATE(7792)] = 297273,
  [SMALL_STATE(7793)] = 297286,
  [SMALL_STATE(7794)] = 297299,
  [SMALL_STATE(7795)] = 297310,
  [SMALL_STATE(7796)] = 297321,
  [SMALL_STATE(7797)] = 297334,
  [SMALL_STATE(7798)] = 297345,
  [SMALL_STATE(7799)] = 297358,
  [SMALL_STATE(7800)] = 297371,
  [SMALL_STATE(7801)] = 297384,
  [SMALL_STATE(7802)] = 297395,
  [SMALL_STATE(7803)] = 297408,
  [SMALL_STATE(7804)] = 297421,
  [SMALL_STATE(7805)] = 297434,
  [SMALL_STATE(7806)] = 297447,
  [SMALL_STATE(7807)] = 297460,
  [SMALL_STATE(7808)] = 297473,
  [SMALL_STATE(7809)] = 297484,
  [SMALL_STATE(7810)] = 297497,
  [SMALL_STATE(7811)] = 297510,
  [SMALL_STATE(7812)] = 297523,
  [SMALL_STATE(7813)] = 297536,
  [SMALL_STATE(7814)] = 297549,
  [SMALL_STATE(7815)] = 297560,
  [SMALL_STATE(7816)] = 297573,
  [SMALL_STATE(7817)] = 297586,
  [SMALL_STATE(7818)] = 297599,
  [SMALL_STATE(7819)] = 297612,
  [SMALL_STATE(7820)] = 297625,
  [SMALL_STATE(7821)] = 297638,
  [SMALL_STATE(7822)] = 297651,
  [SMALL_STATE(7823)] = 297664,
  [SMALL_STATE(7824)] = 297673,
  [SMALL_STATE(7825)] = 297686,
  [SMALL_STATE(7826)] = 297699,
  [SMALL_STATE(7827)] = 297712,
  [SMALL_STATE(7828)] = 297725,
  [SMALL_STATE(7829)] = 297738,
  [SMALL_STATE(7830)] = 297751,
  [SMALL_STATE(7831)] = 297764,
  [SMALL_STATE(7832)] = 297777,
  [SMALL_STATE(7833)] = 297788,
  [SMALL_STATE(7834)] = 297801,
  [SMALL_STATE(7835)] = 297814,
  [SMALL_STATE(7836)] = 297825,
  [SMALL_STATE(7837)] = 297838,
  [SMALL_STATE(7838)] = 297851,
  [SMALL_STATE(7839)] = 297864,
  [SMALL_STATE(7840)] = 297875,
  [SMALL_STATE(7841)] = 297888,
  [SMALL_STATE(7842)] = 297901,
  [SMALL_STATE(7843)] = 297912,
  [SMALL_STATE(7844)] = 297925,
  [SMALL_STATE(7845)] = 297938,
  [SMALL_STATE(7846)] = 297951,
  [SMALL_STATE(7847)] = 297964,
  [SMALL_STATE(7848)] = 297977,
  [SMALL_STATE(7849)] = 297990,
  [SMALL_STATE(7850)] = 298003,
  [SMALL_STATE(7851)] = 298016,
  [SMALL_STATE(7852)] = 298029,
  [SMALL_STATE(7853)] = 298042,
  [SMALL_STATE(7854)] = 298053,
  [SMALL_STATE(7855)] = 298066,
  [SMALL_STATE(7856)] = 298079,
  [SMALL_STATE(7857)] = 298092,
  [SMALL_STATE(7858)] = 298105,
  [SMALL_STATE(7859)] = 298118,
  [SMALL_STATE(7860)] = 298129,
  [SMALL_STATE(7861)] = 298142,
  [SMALL_STATE(7862)] = 298155,
  [SMALL_STATE(7863)] = 298168,
  [SMALL_STATE(7864)] = 298181,
  [SMALL_STATE(7865)] = 298194,
  [SMALL_STATE(7866)] = 298207,
  [SMALL_STATE(7867)] = 298220,
  [SMALL_STATE(7868)] = 298233,
  [SMALL_STATE(7869)] = 298246,
  [SMALL_STATE(7870)] = 298259,
  [SMALL_STATE(7871)] = 298272,
  [SMALL_STATE(7872)] = 298285,
  [SMALL_STATE(7873)] = 298298,
  [SMALL_STATE(7874)] = 298311,
  [SMALL_STATE(7875)] = 298324,
  [SMALL_STATE(7876)] = 298337,
  [SMALL_STATE(7877)] = 298350,
  [SMALL_STATE(7878)] = 298363,
  [SMALL_STATE(7879)] = 298374,
  [SMALL_STATE(7880)] = 298387,
  [SMALL_STATE(7881)] = 298400,
  [SMALL_STATE(7882)] = 298413,
  [SMALL_STATE(7883)] = 298426,
  [SMALL_STATE(7884)] = 298437,
  [SMALL_STATE(7885)] = 298450,
  [SMALL_STATE(7886)] = 298463,
  [SMALL_STATE(7887)] = 298476,
  [SMALL_STATE(7888)] = 298489,
  [SMALL_STATE(7889)] = 298502,
  [SMALL_STATE(7890)] = 298511,
  [SMALL_STATE(7891)] = 298524,
  [SMALL_STATE(7892)] = 298537,
  [SMALL_STATE(7893)] = 298550,
  [SMALL_STATE(7894)] = 298563,
  [SMALL_STATE(7895)] = 298576,
  [SMALL_STATE(7896)] = 298589,
  [SMALL_STATE(7897)] = 298602,
  [SMALL_STATE(7898)] = 298615,
  [SMALL_STATE(7899)] = 298628,
  [SMALL_STATE(7900)] = 298641,
  [SMALL_STATE(7901)] = 298654,
  [SMALL_STATE(7902)] = 298667,
  [SMALL_STATE(7903)] = 298680,
  [SMALL_STATE(7904)] = 298693,
  [SMALL_STATE(7905)] = 298706,
  [SMALL_STATE(7906)] = 298719,
  [SMALL_STATE(7907)] = 298732,
  [SMALL_STATE(7908)] = 298745,
  [SMALL_STATE(7909)] = 298758,
  [SMALL_STATE(7910)] = 298771,
  [SMALL_STATE(7911)] = 298784,
  [SMALL_STATE(7912)] = 298797,
  [SMALL_STATE(7913)] = 298810,
  [SMALL_STATE(7914)] = 298823,
  [SMALL_STATE(7915)] = 298836,
  [SMALL_STATE(7916)] = 298845,
  [SMALL_STATE(7917)] = 298858,
  [SMALL_STATE(7918)] = 298871,
  [SMALL_STATE(7919)] = 298882,
  [SMALL_STATE(7920)] = 298895,
  [SMALL_STATE(7921)] = 298908,
  [SMALL_STATE(7922)] = 298917,
  [SMALL_STATE(7923)] = 298930,
  [SMALL_STATE(7924)] = 298943,
  [SMALL_STATE(7925)] = 298956,
  [SMALL_STATE(7926)] = 298969,
  [SMALL_STATE(7927)] = 298982,
  [SMALL_STATE(7928)] = 298995,
  [SMALL_STATE(7929)] = 299008,
  [SMALL_STATE(7930)] = 299021,
  [SMALL_STATE(7931)] = 299034,
  [SMALL_STATE(7932)] = 299047,
  [SMALL_STATE(7933)] = 299060,
  [SMALL_STATE(7934)] = 299073,
  [SMALL_STATE(7935)] = 299086,
  [SMALL_STATE(7936)] = 299099,
  [SMALL_STATE(7937)] = 299110,
  [SMALL_STATE(7938)] = 299123,
  [SMALL_STATE(7939)] = 299136,
  [SMALL_STATE(7940)] = 299147,
  [SMALL_STATE(7941)] = 299160,
  [SMALL_STATE(7942)] = 299171,
  [SMALL_STATE(7943)] = 299184,
  [SMALL_STATE(7944)] = 299197,
  [SMALL_STATE(7945)] = 299210,
  [SMALL_STATE(7946)] = 299223,
  [SMALL_STATE(7947)] = 299234,
  [SMALL_STATE(7948)] = 299245,
  [SMALL_STATE(7949)] = 299258,
  [SMALL_STATE(7950)] = 299271,
  [SMALL_STATE(7951)] = 299284,
  [SMALL_STATE(7952)] = 299297,
  [SMALL_STATE(7953)] = 299310,
  [SMALL_STATE(7954)] = 299323,
  [SMALL_STATE(7955)] = 299336,
  [SMALL_STATE(7956)] = 299349,
  [SMALL_STATE(7957)] = 299360,
  [SMALL_STATE(7958)] = 299373,
  [SMALL_STATE(7959)] = 299386,
  [SMALL_STATE(7960)] = 299399,
  [SMALL_STATE(7961)] = 299412,
  [SMALL_STATE(7962)] = 299425,
  [SMALL_STATE(7963)] = 299438,
  [SMALL_STATE(7964)] = 299449,
  [SMALL_STATE(7965)] = 299462,
  [SMALL_STATE(7966)] = 299475,
  [SMALL_STATE(7967)] = 299488,
  [SMALL_STATE(7968)] = 299501,
  [SMALL_STATE(7969)] = 299514,
  [SMALL_STATE(7970)] = 299527,
  [SMALL_STATE(7971)] = 299540,
  [SMALL_STATE(7972)] = 299551,
  [SMALL_STATE(7973)] = 299564,
  [SMALL_STATE(7974)] = 299577,
  [SMALL_STATE(7975)] = 299590,
  [SMALL_STATE(7976)] = 299603,
  [SMALL_STATE(7977)] = 299616,
  [SMALL_STATE(7978)] = 299629,
  [SMALL_STATE(7979)] = 299640,
  [SMALL_STATE(7980)] = 299651,
  [SMALL_STATE(7981)] = 299662,
  [SMALL_STATE(7982)] = 299675,
  [SMALL_STATE(7983)] = 299686,
  [SMALL_STATE(7984)] = 299697,
  [SMALL_STATE(7985)] = 299710,
  [SMALL_STATE(7986)] = 299723,
  [SMALL_STATE(7987)] = 299734,
  [SMALL_STATE(7988)] = 299747,
  [SMALL_STATE(7989)] = 299760,
  [SMALL_STATE(7990)] = 299771,
  [SMALL_STATE(7991)] = 299784,
  [SMALL_STATE(7992)] = 299797,
  [SMALL_STATE(7993)] = 299806,
  [SMALL_STATE(7994)] = 299819,
  [SMALL_STATE(7995)] = 299832,
  [SMALL_STATE(7996)] = 299845,
  [SMALL_STATE(7997)] = 299858,
  [SMALL_STATE(7998)] = 299871,
  [SMALL_STATE(7999)] = 299884,
  [SMALL_STATE(8000)] = 299897,
  [SMALL_STATE(8001)] = 299910,
  [SMALL_STATE(8002)] = 299923,
  [SMALL_STATE(8003)] = 299936,
  [SMALL_STATE(8004)] = 299947,
  [SMALL_STATE(8005)] = 299960,
  [SMALL_STATE(8006)] = 299973,
  [SMALL_STATE(8007)] = 299986,
  [SMALL_STATE(8008)] = 299999,
  [SMALL_STATE(8009)] = 300012,
  [SMALL_STATE(8010)] = 300025,
  [SMALL_STATE(8011)] = 300038,
  [SMALL_STATE(8012)] = 300051,
  [SMALL_STATE(8013)] = 300064,
  [SMALL_STATE(8014)] = 300077,
  [SMALL_STATE(8015)] = 300088,
  [SMALL_STATE(8016)] = 300101,
  [SMALL_STATE(8017)] = 300114,
  [SMALL_STATE(8018)] = 300127,
  [SMALL_STATE(8019)] = 300140,
  [SMALL_STATE(8020)] = 300153,
  [SMALL_STATE(8021)] = 300166,
  [SMALL_STATE(8022)] = 300179,
  [SMALL_STATE(8023)] = 300192,
  [SMALL_STATE(8024)] = 300205,
  [SMALL_STATE(8025)] = 300216,
  [SMALL_STATE(8026)] = 300229,
  [SMALL_STATE(8027)] = 300242,
  [SMALL_STATE(8028)] = 300255,
  [SMALL_STATE(8029)] = 300268,
  [SMALL_STATE(8030)] = 300281,
  [SMALL_STATE(8031)] = 300294,
  [SMALL_STATE(8032)] = 300305,
  [SMALL_STATE(8033)] = 300318,
  [SMALL_STATE(8034)] = 300331,
  [SMALL_STATE(8035)] = 300344,
  [SMALL_STATE(8036)] = 300355,
  [SMALL_STATE(8037)] = 300368,
  [SMALL_STATE(8038)] = 300379,
  [SMALL_STATE(8039)] = 300390,
  [SMALL_STATE(8040)] = 300401,
  [SMALL_STATE(8041)] = 300414,
  [SMALL_STATE(8042)] = 300425,
  [SMALL_STATE(8043)] = 300434,
  [SMALL_STATE(8044)] = 300447,
  [SMALL_STATE(8045)] = 300460,
  [SMALL_STATE(8046)] = 300473,
  [SMALL_STATE(8047)] = 300486,
  [SMALL_STATE(8048)] = 300499,
  [SMALL_STATE(8049)] = 300512,
  [SMALL_STATE(8050)] = 300525,
  [SMALL_STATE(8051)] = 300538,
  [SMALL_STATE(8052)] = 300551,
  [SMALL_STATE(8053)] = 300564,
  [SMALL_STATE(8054)] = 300577,
  [SMALL_STATE(8055)] = 300590,
  [SMALL_STATE(8056)] = 300603,
  [SMALL_STATE(8057)] = 300616,
  [SMALL_STATE(8058)] = 300627,
  [SMALL_STATE(8059)] = 300640,
  [SMALL_STATE(8060)] = 300651,
  [SMALL_STATE(8061)] = 300664,
  [SMALL_STATE(8062)] = 300677,
  [SMALL_STATE(8063)] = 300690,
  [SMALL_STATE(8064)] = 300703,
  [SMALL_STATE(8065)] = 300716,
  [SMALL_STATE(8066)] = 300729,
  [SMALL_STATE(8067)] = 300742,
  [SMALL_STATE(8068)] = 300755,
  [SMALL_STATE(8069)] = 300768,
  [SMALL_STATE(8070)] = 300781,
  [SMALL_STATE(8071)] = 300794,
  [SMALL_STATE(8072)] = 300803,
  [SMALL_STATE(8073)] = 300812,
  [SMALL_STATE(8074)] = 300823,
  [SMALL_STATE(8075)] = 300836,
  [SMALL_STATE(8076)] = 300849,
  [SMALL_STATE(8077)] = 300860,
  [SMALL_STATE(8078)] = 300873,
  [SMALL_STATE(8079)] = 300886,
  [SMALL_STATE(8080)] = 300899,
  [SMALL_STATE(8081)] = 300912,
  [SMALL_STATE(8082)] = 300925,
  [SMALL_STATE(8083)] = 300938,
  [SMALL_STATE(8084)] = 300951,
  [SMALL_STATE(8085)] = 300962,
  [SMALL_STATE(8086)] = 300973,
  [SMALL_STATE(8087)] = 300986,
  [SMALL_STATE(8088)] = 300999,
  [SMALL_STATE(8089)] = 301012,
  [SMALL_STATE(8090)] = 301025,
  [SMALL_STATE(8091)] = 301036,
  [SMALL_STATE(8092)] = 301049,
  [SMALL_STATE(8093)] = 301062,
  [SMALL_STATE(8094)] = 301075,
  [SMALL_STATE(8095)] = 301088,
  [SMALL_STATE(8096)] = 301101,
  [SMALL_STATE(8097)] = 301114,
  [SMALL_STATE(8098)] = 301125,
  [SMALL_STATE(8099)] = 301138,
  [SMALL_STATE(8100)] = 301151,
  [SMALL_STATE(8101)] = 301160,
  [SMALL_STATE(8102)] = 301171,
  [SMALL_STATE(8103)] = 301180,
  [SMALL_STATE(8104)] = 301193,
  [SMALL_STATE(8105)] = 301206,
  [SMALL_STATE(8106)] = 301219,
  [SMALL_STATE(8107)] = 301232,
  [SMALL_STATE(8108)] = 301245,
  [SMALL_STATE(8109)] = 301258,
  [SMALL_STATE(8110)] = 301271,
  [SMALL_STATE(8111)] = 301284,
  [SMALL_STATE(8112)] = 301297,
  [SMALL_STATE(8113)] = 301310,
  [SMALL_STATE(8114)] = 301323,
  [SMALL_STATE(8115)] = 301336,
  [SMALL_STATE(8116)] = 301349,
  [SMALL_STATE(8117)] = 301362,
  [SMALL_STATE(8118)] = 301375,
  [SMALL_STATE(8119)] = 301386,
  [SMALL_STATE(8120)] = 301399,
  [SMALL_STATE(8121)] = 301412,
  [SMALL_STATE(8122)] = 301425,
  [SMALL_STATE(8123)] = 301438,
  [SMALL_STATE(8124)] = 301451,
  [SMALL_STATE(8125)] = 301464,
  [SMALL_STATE(8126)] = 301477,
  [SMALL_STATE(8127)] = 301490,
  [SMALL_STATE(8128)] = 301499,
  [SMALL_STATE(8129)] = 301512,
  [SMALL_STATE(8130)] = 301523,
  [SMALL_STATE(8131)] = 301536,
  [SMALL_STATE(8132)] = 301549,
  [SMALL_STATE(8133)] = 301562,
  [SMALL_STATE(8134)] = 301575,
  [SMALL_STATE(8135)] = 301588,
  [SMALL_STATE(8136)] = 301597,
  [SMALL_STATE(8137)] = 301610,
  [SMALL_STATE(8138)] = 301621,
  [SMALL_STATE(8139)] = 301632,
  [SMALL_STATE(8140)] = 301645,
  [SMALL_STATE(8141)] = 301658,
  [SMALL_STATE(8142)] = 301671,
  [SMALL_STATE(8143)] = 301680,
  [SMALL_STATE(8144)] = 301693,
  [SMALL_STATE(8145)] = 301706,
  [SMALL_STATE(8146)] = 301719,
  [SMALL_STATE(8147)] = 301732,
  [SMALL_STATE(8148)] = 301745,
  [SMALL_STATE(8149)] = 301758,
  [SMALL_STATE(8150)] = 301771,
  [SMALL_STATE(8151)] = 301784,
  [SMALL_STATE(8152)] = 301797,
  [SMALL_STATE(8153)] = 301810,
  [SMALL_STATE(8154)] = 301823,
  [SMALL_STATE(8155)] = 301836,
  [SMALL_STATE(8156)] = 301849,
  [SMALL_STATE(8157)] = 301860,
  [SMALL_STATE(8158)] = 301873,
  [SMALL_STATE(8159)] = 301882,
  [SMALL_STATE(8160)] = 301895,
  [SMALL_STATE(8161)] = 301908,
  [SMALL_STATE(8162)] = 301921,
  [SMALL_STATE(8163)] = 301934,
  [SMALL_STATE(8164)] = 301947,
  [SMALL_STATE(8165)] = 301960,
  [SMALL_STATE(8166)] = 301973,
  [SMALL_STATE(8167)] = 301986,
  [SMALL_STATE(8168)] = 301999,
  [SMALL_STATE(8169)] = 302012,
  [SMALL_STATE(8170)] = 302025,
  [SMALL_STATE(8171)] = 302038,
  [SMALL_STATE(8172)] = 302051,
  [SMALL_STATE(8173)] = 302064,
  [SMALL_STATE(8174)] = 302077,
  [SMALL_STATE(8175)] = 302086,
  [SMALL_STATE(8176)] = 302099,
  [SMALL_STATE(8177)] = 302112,
  [SMALL_STATE(8178)] = 302123,
  [SMALL_STATE(8179)] = 302136,
  [SMALL_STATE(8180)] = 302149,
  [SMALL_STATE(8181)] = 302162,
  [SMALL_STATE(8182)] = 302175,
  [SMALL_STATE(8183)] = 302188,
  [SMALL_STATE(8184)] = 302201,
  [SMALL_STATE(8185)] = 302212,
  [SMALL_STATE(8186)] = 302225,
  [SMALL_STATE(8187)] = 302238,
  [SMALL_STATE(8188)] = 302251,
  [SMALL_STATE(8189)] = 302260,
  [SMALL_STATE(8190)] = 302273,
  [SMALL_STATE(8191)] = 302286,
  [SMALL_STATE(8192)] = 302299,
  [SMALL_STATE(8193)] = 302312,
  [SMALL_STATE(8194)] = 302325,
  [SMALL_STATE(8195)] = 302338,
  [SMALL_STATE(8196)] = 302351,
  [SMALL_STATE(8197)] = 302364,
  [SMALL_STATE(8198)] = 302377,
  [SMALL_STATE(8199)] = 302388,
  [SMALL_STATE(8200)] = 302401,
  [SMALL_STATE(8201)] = 302414,
  [SMALL_STATE(8202)] = 302427,
  [SMALL_STATE(8203)] = 302440,
  [SMALL_STATE(8204)] = 302453,
  [SMALL_STATE(8205)] = 302466,
  [SMALL_STATE(8206)] = 302479,
  [SMALL_STATE(8207)] = 302492,
  [SMALL_STATE(8208)] = 302505,
  [SMALL_STATE(8209)] = 302518,
  [SMALL_STATE(8210)] = 302528,
  [SMALL_STATE(8211)] = 302538,
  [SMALL_STATE(8212)] = 302548,
  [SMALL_STATE(8213)] = 302558,
  [SMALL_STATE(8214)] = 302568,
  [SMALL_STATE(8215)] = 302578,
  [SMALL_STATE(8216)] = 302588,
  [SMALL_STATE(8217)] = 302596,
  [SMALL_STATE(8218)] = 302606,
  [SMALL_STATE(8219)] = 302616,
  [SMALL_STATE(8220)] = 302626,
  [SMALL_STATE(8221)] = 302634,
  [SMALL_STATE(8222)] = 302644,
  [SMALL_STATE(8223)] = 302654,
  [SMALL_STATE(8224)] = 302664,
  [SMALL_STATE(8225)] = 302674,
  [SMALL_STATE(8226)] = 302684,
  [SMALL_STATE(8227)] = 302692,
  [SMALL_STATE(8228)] = 302702,
  [SMALL_STATE(8229)] = 302712,
  [SMALL_STATE(8230)] = 302720,
  [SMALL_STATE(8231)] = 302730,
  [SMALL_STATE(8232)] = 302738,
  [SMALL_STATE(8233)] = 302748,
  [SMALL_STATE(8234)] = 302758,
  [SMALL_STATE(8235)] = 302768,
  [SMALL_STATE(8236)] = 302776,
  [SMALL_STATE(8237)] = 302786,
  [SMALL_STATE(8238)] = 302796,
  [SMALL_STATE(8239)] = 302806,
  [SMALL_STATE(8240)] = 302816,
  [SMALL_STATE(8241)] = 302826,
  [SMALL_STATE(8242)] = 302836,
  [SMALL_STATE(8243)] = 302846,
  [SMALL_STATE(8244)] = 302856,
  [SMALL_STATE(8245)] = 302866,
  [SMALL_STATE(8246)] = 302876,
  [SMALL_STATE(8247)] = 302886,
  [SMALL_STATE(8248)] = 302896,
  [SMALL_STATE(8249)] = 302906,
  [SMALL_STATE(8250)] = 302916,
  [SMALL_STATE(8251)] = 302926,
  [SMALL_STATE(8252)] = 302936,
  [SMALL_STATE(8253)] = 302944,
  [SMALL_STATE(8254)] = 302952,
  [SMALL_STATE(8255)] = 302960,
  [SMALL_STATE(8256)] = 302968,
  [SMALL_STATE(8257)] = 302978,
  [SMALL_STATE(8258)] = 302988,
  [SMALL_STATE(8259)] = 302996,
  [SMALL_STATE(8260)] = 303006,
  [SMALL_STATE(8261)] = 303016,
  [SMALL_STATE(8262)] = 303024,
  [SMALL_STATE(8263)] = 303034,
  [SMALL_STATE(8264)] = 303044,
  [SMALL_STATE(8265)] = 303054,
  [SMALL_STATE(8266)] = 303064,
  [SMALL_STATE(8267)] = 303074,
  [SMALL_STATE(8268)] = 303082,
  [SMALL_STATE(8269)] = 303092,
  [SMALL_STATE(8270)] = 303102,
  [SMALL_STATE(8271)] = 303112,
  [SMALL_STATE(8272)] = 303122,
  [SMALL_STATE(8273)] = 303132,
  [SMALL_STATE(8274)] = 303142,
  [SMALL_STATE(8275)] = 303152,
  [SMALL_STATE(8276)] = 303162,
  [SMALL_STATE(8277)] = 303172,
  [SMALL_STATE(8278)] = 303180,
  [SMALL_STATE(8279)] = 303190,
  [SMALL_STATE(8280)] = 303200,
  [SMALL_STATE(8281)] = 303210,
  [SMALL_STATE(8282)] = 303220,
  [SMALL_STATE(8283)] = 303230,
  [SMALL_STATE(8284)] = 303240,
  [SMALL_STATE(8285)] = 303250,
  [SMALL_STATE(8286)] = 303258,
  [SMALL_STATE(8287)] = 303268,
  [SMALL_STATE(8288)] = 303278,
  [SMALL_STATE(8289)] = 303288,
  [SMALL_STATE(8290)] = 303298,
  [SMALL_STATE(8291)] = 303308,
  [SMALL_STATE(8292)] = 303318,
  [SMALL_STATE(8293)] = 303326,
  [SMALL_STATE(8294)] = 303336,
  [SMALL_STATE(8295)] = 303346,
  [SMALL_STATE(8296)] = 303354,
  [SMALL_STATE(8297)] = 303364,
  [SMALL_STATE(8298)] = 303374,
  [SMALL_STATE(8299)] = 303384,
  [SMALL_STATE(8300)] = 303392,
  [SMALL_STATE(8301)] = 303400,
  [SMALL_STATE(8302)] = 303410,
  [SMALL_STATE(8303)] = 303420,
  [SMALL_STATE(8304)] = 303430,
  [SMALL_STATE(8305)] = 303440,
  [SMALL_STATE(8306)] = 303450,
  [SMALL_STATE(8307)] = 303460,
  [SMALL_STATE(8308)] = 303470,
  [SMALL_STATE(8309)] = 303480,
  [SMALL_STATE(8310)] = 303490,
  [SMALL_STATE(8311)] = 303500,
  [SMALL_STATE(8312)] = 303510,
  [SMALL_STATE(8313)] = 303520,
  [SMALL_STATE(8314)] = 303530,
  [SMALL_STATE(8315)] = 303540,
  [SMALL_STATE(8316)] = 303550,
  [SMALL_STATE(8317)] = 303560,
  [SMALL_STATE(8318)] = 303570,
  [SMALL_STATE(8319)] = 303580,
  [SMALL_STATE(8320)] = 303590,
  [SMALL_STATE(8321)] = 303598,
  [SMALL_STATE(8322)] = 303608,
  [SMALL_STATE(8323)] = 303618,
  [SMALL_STATE(8324)] = 303628,
  [SMALL_STATE(8325)] = 303638,
  [SMALL_STATE(8326)] = 303646,
  [SMALL_STATE(8327)] = 303656,
  [SMALL_STATE(8328)] = 303666,
  [SMALL_STATE(8329)] = 303676,
  [SMALL_STATE(8330)] = 303686,
  [SMALL_STATE(8331)] = 303696,
  [SMALL_STATE(8332)] = 303706,
  [SMALL_STATE(8333)] = 303716,
  [SMALL_STATE(8334)] = 303726,
  [SMALL_STATE(8335)] = 303736,
  [SMALL_STATE(8336)] = 303746,
  [SMALL_STATE(8337)] = 303756,
  [SMALL_STATE(8338)] = 303766,
  [SMALL_STATE(8339)] = 303776,
  [SMALL_STATE(8340)] = 303786,
  [SMALL_STATE(8341)] = 303796,
  [SMALL_STATE(8342)] = 303806,
  [SMALL_STATE(8343)] = 303816,
  [SMALL_STATE(8344)] = 303826,
  [SMALL_STATE(8345)] = 303836,
  [SMALL_STATE(8346)] = 303846,
  [SMALL_STATE(8347)] = 303856,
  [SMALL_STATE(8348)] = 303866,
  [SMALL_STATE(8349)] = 303876,
  [SMALL_STATE(8350)] = 303886,
  [SMALL_STATE(8351)] = 303896,
  [SMALL_STATE(8352)] = 303906,
  [SMALL_STATE(8353)] = 303916,
  [SMALL_STATE(8354)] = 303926,
  [SMALL_STATE(8355)] = 303936,
  [SMALL_STATE(8356)] = 303946,
  [SMALL_STATE(8357)] = 303956,
  [SMALL_STATE(8358)] = 303966,
  [SMALL_STATE(8359)] = 303976,
  [SMALL_STATE(8360)] = 303986,
  [SMALL_STATE(8361)] = 303996,
  [SMALL_STATE(8362)] = 304006,
  [SMALL_STATE(8363)] = 304016,
  [SMALL_STATE(8364)] = 304026,
  [SMALL_STATE(8365)] = 304036,
  [SMALL_STATE(8366)] = 304046,
  [SMALL_STATE(8367)] = 304056,
  [SMALL_STATE(8368)] = 304066,
  [SMALL_STATE(8369)] = 304076,
  [SMALL_STATE(8370)] = 304084,
  [SMALL_STATE(8371)] = 304094,
  [SMALL_STATE(8372)] = 304104,
  [SMALL_STATE(8373)] = 304114,
  [SMALL_STATE(8374)] = 304124,
  [SMALL_STATE(8375)] = 304134,
  [SMALL_STATE(8376)] = 304144,
  [SMALL_STATE(8377)] = 304154,
  [SMALL_STATE(8378)] = 304164,
  [SMALL_STATE(8379)] = 304174,
  [SMALL_STATE(8380)] = 304184,
  [SMALL_STATE(8381)] = 304194,
  [SMALL_STATE(8382)] = 304204,
  [SMALL_STATE(8383)] = 304214,
  [SMALL_STATE(8384)] = 304224,
  [SMALL_STATE(8385)] = 304234,
  [SMALL_STATE(8386)] = 304244,
  [SMALL_STATE(8387)] = 304254,
  [SMALL_STATE(8388)] = 304264,
  [SMALL_STATE(8389)] = 304274,
  [SMALL_STATE(8390)] = 304284,
  [SMALL_STATE(8391)] = 304294,
  [SMALL_STATE(8392)] = 304304,
  [SMALL_STATE(8393)] = 304314,
  [SMALL_STATE(8394)] = 304324,
  [SMALL_STATE(8395)] = 304334,
  [SMALL_STATE(8396)] = 304344,
  [SMALL_STATE(8397)] = 304354,
  [SMALL_STATE(8398)] = 304364,
  [SMALL_STATE(8399)] = 304374,
  [SMALL_STATE(8400)] = 304384,
  [SMALL_STATE(8401)] = 304394,
  [SMALL_STATE(8402)] = 304404,
  [SMALL_STATE(8403)] = 304414,
  [SMALL_STATE(8404)] = 304424,
  [SMALL_STATE(8405)] = 304434,
  [SMALL_STATE(8406)] = 304444,
  [SMALL_STATE(8407)] = 304454,
  [SMALL_STATE(8408)] = 304464,
  [SMALL_STATE(8409)] = 304474,
  [SMALL_STATE(8410)] = 304484,
  [SMALL_STATE(8411)] = 304494,
  [SMALL_STATE(8412)] = 304502,
  [SMALL_STATE(8413)] = 304512,
  [SMALL_STATE(8414)] = 304522,
  [SMALL_STATE(8415)] = 304532,
  [SMALL_STATE(8416)] = 304542,
  [SMALL_STATE(8417)] = 304552,
  [SMALL_STATE(8418)] = 304562,
  [SMALL_STATE(8419)] = 304572,
  [SMALL_STATE(8420)] = 304582,
  [SMALL_STATE(8421)] = 304592,
  [SMALL_STATE(8422)] = 304602,
  [SMALL_STATE(8423)] = 304612,
  [SMALL_STATE(8424)] = 304622,
  [SMALL_STATE(8425)] = 304630,
  [SMALL_STATE(8426)] = 304640,
  [SMALL_STATE(8427)] = 304650,
  [SMALL_STATE(8428)] = 304660,
  [SMALL_STATE(8429)] = 304670,
  [SMALL_STATE(8430)] = 304680,
  [SMALL_STATE(8431)] = 304690,
  [SMALL_STATE(8432)] = 304700,
  [SMALL_STATE(8433)] = 304710,
  [SMALL_STATE(8434)] = 304720,
  [SMALL_STATE(8435)] = 304730,
  [SMALL_STATE(8436)] = 304738,
  [SMALL_STATE(8437)] = 304748,
  [SMALL_STATE(8438)] = 304758,
  [SMALL_STATE(8439)] = 304768,
  [SMALL_STATE(8440)] = 304776,
  [SMALL_STATE(8441)] = 304786,
  [SMALL_STATE(8442)] = 304796,
  [SMALL_STATE(8443)] = 304804,
  [SMALL_STATE(8444)] = 304814,
  [SMALL_STATE(8445)] = 304824,
  [SMALL_STATE(8446)] = 304834,
  [SMALL_STATE(8447)] = 304844,
  [SMALL_STATE(8448)] = 304854,
  [SMALL_STATE(8449)] = 304862,
  [SMALL_STATE(8450)] = 304872,
  [SMALL_STATE(8451)] = 304882,
  [SMALL_STATE(8452)] = 304892,
  [SMALL_STATE(8453)] = 304902,
  [SMALL_STATE(8454)] = 304912,
  [SMALL_STATE(8455)] = 304922,
  [SMALL_STATE(8456)] = 304932,
  [SMALL_STATE(8457)] = 304942,
  [SMALL_STATE(8458)] = 304952,
  [SMALL_STATE(8459)] = 304962,
  [SMALL_STATE(8460)] = 304972,
  [SMALL_STATE(8461)] = 304982,
  [SMALL_STATE(8462)] = 304990,
  [SMALL_STATE(8463)] = 305000,
  [SMALL_STATE(8464)] = 305010,
  [SMALL_STATE(8465)] = 305018,
  [SMALL_STATE(8466)] = 305028,
  [SMALL_STATE(8467)] = 305038,
  [SMALL_STATE(8468)] = 305048,
  [SMALL_STATE(8469)] = 305058,
  [SMALL_STATE(8470)] = 305068,
  [SMALL_STATE(8471)] = 305078,
  [SMALL_STATE(8472)] = 305088,
  [SMALL_STATE(8473)] = 305098,
  [SMALL_STATE(8474)] = 305108,
  [SMALL_STATE(8475)] = 305118,
  [SMALL_STATE(8476)] = 305128,
  [SMALL_STATE(8477)] = 305138,
  [SMALL_STATE(8478)] = 305148,
  [SMALL_STATE(8479)] = 305158,
  [SMALL_STATE(8480)] = 305168,
  [SMALL_STATE(8481)] = 305178,
  [SMALL_STATE(8482)] = 305188,
  [SMALL_STATE(8483)] = 305198,
  [SMALL_STATE(8484)] = 305208,
  [SMALL_STATE(8485)] = 305218,
  [SMALL_STATE(8486)] = 305228,
  [SMALL_STATE(8487)] = 305238,
  [SMALL_STATE(8488)] = 305248,
  [SMALL_STATE(8489)] = 305258,
  [SMALL_STATE(8490)] = 305268,
  [SMALL_STATE(8491)] = 305278,
  [SMALL_STATE(8492)] = 305286,
  [SMALL_STATE(8493)] = 305294,
  [SMALL_STATE(8494)] = 305304,
  [SMALL_STATE(8495)] = 305314,
  [SMALL_STATE(8496)] = 305324,
  [SMALL_STATE(8497)] = 305334,
  [SMALL_STATE(8498)] = 305344,
  [SMALL_STATE(8499)] = 305354,
  [SMALL_STATE(8500)] = 305364,
  [SMALL_STATE(8501)] = 305374,
  [SMALL_STATE(8502)] = 305384,
  [SMALL_STATE(8503)] = 305394,
  [SMALL_STATE(8504)] = 305404,
  [SMALL_STATE(8505)] = 305414,
  [SMALL_STATE(8506)] = 305424,
  [SMALL_STATE(8507)] = 305434,
  [SMALL_STATE(8508)] = 305444,
  [SMALL_STATE(8509)] = 305454,
  [SMALL_STATE(8510)] = 305464,
  [SMALL_STATE(8511)] = 305474,
  [SMALL_STATE(8512)] = 305482,
  [SMALL_STATE(8513)] = 305492,
  [SMALL_STATE(8514)] = 305502,
  [SMALL_STATE(8515)] = 305512,
  [SMALL_STATE(8516)] = 305522,
  [SMALL_STATE(8517)] = 305532,
  [SMALL_STATE(8518)] = 305542,
  [SMALL_STATE(8519)] = 305552,
  [SMALL_STATE(8520)] = 305562,
  [SMALL_STATE(8521)] = 305572,
  [SMALL_STATE(8522)] = 305582,
  [SMALL_STATE(8523)] = 305592,
  [SMALL_STATE(8524)] = 305602,
  [SMALL_STATE(8525)] = 305612,
  [SMALL_STATE(8526)] = 305622,
  [SMALL_STATE(8527)] = 305632,
  [SMALL_STATE(8528)] = 305642,
  [SMALL_STATE(8529)] = 305652,
  [SMALL_STATE(8530)] = 305662,
  [SMALL_STATE(8531)] = 305672,
  [SMALL_STATE(8532)] = 305682,
  [SMALL_STATE(8533)] = 305692,
  [SMALL_STATE(8534)] = 305700,
  [SMALL_STATE(8535)] = 305710,
  [SMALL_STATE(8536)] = 305718,
  [SMALL_STATE(8537)] = 305728,
  [SMALL_STATE(8538)] = 305736,
  [SMALL_STATE(8539)] = 305746,
  [SMALL_STATE(8540)] = 305756,
  [SMALL_STATE(8541)] = 305766,
  [SMALL_STATE(8542)] = 305776,
  [SMALL_STATE(8543)] = 305786,
  [SMALL_STATE(8544)] = 305796,
  [SMALL_STATE(8545)] = 305806,
  [SMALL_STATE(8546)] = 305816,
  [SMALL_STATE(8547)] = 305826,
  [SMALL_STATE(8548)] = 305836,
  [SMALL_STATE(8549)] = 305844,
  [SMALL_STATE(8550)] = 305854,
  [SMALL_STATE(8551)] = 305864,
  [SMALL_STATE(8552)] = 305874,
  [SMALL_STATE(8553)] = 305884,
  [SMALL_STATE(8554)] = 305894,
  [SMALL_STATE(8555)] = 305904,
  [SMALL_STATE(8556)] = 305914,
  [SMALL_STATE(8557)] = 305924,
  [SMALL_STATE(8558)] = 305934,
  [SMALL_STATE(8559)] = 305944,
  [SMALL_STATE(8560)] = 305954,
  [SMALL_STATE(8561)] = 305964,
  [SMALL_STATE(8562)] = 305974,
  [SMALL_STATE(8563)] = 305984,
  [SMALL_STATE(8564)] = 305994,
  [SMALL_STATE(8565)] = 306004,
  [SMALL_STATE(8566)] = 306014,
  [SMALL_STATE(8567)] = 306024,
  [SMALL_STATE(8568)] = 306034,
  [SMALL_STATE(8569)] = 306044,
  [SMALL_STATE(8570)] = 306054,
  [SMALL_STATE(8571)] = 306064,
  [SMALL_STATE(8572)] = 306074,
  [SMALL_STATE(8573)] = 306084,
  [SMALL_STATE(8574)] = 306094,
  [SMALL_STATE(8575)] = 306104,
  [SMALL_STATE(8576)] = 306114,
  [SMALL_STATE(8577)] = 306124,
  [SMALL_STATE(8578)] = 306134,
  [SMALL_STATE(8579)] = 306142,
  [SMALL_STATE(8580)] = 306152,
  [SMALL_STATE(8581)] = 306159,
  [SMALL_STATE(8582)] = 306166,
  [SMALL_STATE(8583)] = 306173,
  [SMALL_STATE(8584)] = 306180,
  [SMALL_STATE(8585)] = 306187,
  [SMALL_STATE(8586)] = 306194,
  [SMALL_STATE(8587)] = 306201,
  [SMALL_STATE(8588)] = 306208,
  [SMALL_STATE(8589)] = 306215,
  [SMALL_STATE(8590)] = 306222,
  [SMALL_STATE(8591)] = 306229,
  [SMALL_STATE(8592)] = 306236,
  [SMALL_STATE(8593)] = 306243,
  [SMALL_STATE(8594)] = 306250,
  [SMALL_STATE(8595)] = 306257,
  [SMALL_STATE(8596)] = 306264,
  [SMALL_STATE(8597)] = 306271,
  [SMALL_STATE(8598)] = 306278,
  [SMALL_STATE(8599)] = 306285,
  [SMALL_STATE(8600)] = 306292,
  [SMALL_STATE(8601)] = 306299,
  [SMALL_STATE(8602)] = 306306,
  [SMALL_STATE(8603)] = 306313,
  [SMALL_STATE(8604)] = 306320,
  [SMALL_STATE(8605)] = 306327,
  [SMALL_STATE(8606)] = 306334,
  [SMALL_STATE(8607)] = 306341,
  [SMALL_STATE(8608)] = 306348,
  [SMALL_STATE(8609)] = 306355,
  [SMALL_STATE(8610)] = 306362,
  [SMALL_STATE(8611)] = 306369,
  [SMALL_STATE(8612)] = 306376,
  [SMALL_STATE(8613)] = 306383,
  [SMALL_STATE(8614)] = 306390,
  [SMALL_STATE(8615)] = 306397,
  [SMALL_STATE(8616)] = 306404,
  [SMALL_STATE(8617)] = 306411,
  [SMALL_STATE(8618)] = 306418,
  [SMALL_STATE(8619)] = 306425,
  [SMALL_STATE(8620)] = 306432,
  [SMALL_STATE(8621)] = 306439,
  [SMALL_STATE(8622)] = 306446,
  [SMALL_STATE(8623)] = 306453,
  [SMALL_STATE(8624)] = 306460,
  [SMALL_STATE(8625)] = 306467,
  [SMALL_STATE(8626)] = 306474,
  [SMALL_STATE(8627)] = 306481,
  [SMALL_STATE(8628)] = 306488,
  [SMALL_STATE(8629)] = 306495,
  [SMALL_STATE(8630)] = 306502,
  [SMALL_STATE(8631)] = 306509,
  [SMALL_STATE(8632)] = 306516,
  [SMALL_STATE(8633)] = 306523,
  [SMALL_STATE(8634)] = 306530,
  [SMALL_STATE(8635)] = 306537,
  [SMALL_STATE(8636)] = 306544,
  [SMALL_STATE(8637)] = 306551,
  [SMALL_STATE(8638)] = 306558,
  [SMALL_STATE(8639)] = 306565,
  [SMALL_STATE(8640)] = 306572,
  [SMALL_STATE(8641)] = 306579,
  [SMALL_STATE(8642)] = 306586,
  [SMALL_STATE(8643)] = 306593,
  [SMALL_STATE(8644)] = 306600,
  [SMALL_STATE(8645)] = 306607,
  [SMALL_STATE(8646)] = 306614,
  [SMALL_STATE(8647)] = 306621,
  [SMALL_STATE(8648)] = 306628,
  [SMALL_STATE(8649)] = 306635,
  [SMALL_STATE(8650)] = 306642,
  [SMALL_STATE(8651)] = 306649,
  [SMALL_STATE(8652)] = 306656,
  [SMALL_STATE(8653)] = 306663,
  [SMALL_STATE(8654)] = 306670,
  [SMALL_STATE(8655)] = 306677,
  [SMALL_STATE(8656)] = 306684,
  [SMALL_STATE(8657)] = 306691,
  [SMALL_STATE(8658)] = 306698,
  [SMALL_STATE(8659)] = 306705,
  [SMALL_STATE(8660)] = 306712,
  [SMALL_STATE(8661)] = 306719,
  [SMALL_STATE(8662)] = 306726,
  [SMALL_STATE(8663)] = 306733,
  [SMALL_STATE(8664)] = 306740,
  [SMALL_STATE(8665)] = 306747,
  [SMALL_STATE(8666)] = 306754,
  [SMALL_STATE(8667)] = 306761,
  [SMALL_STATE(8668)] = 306768,
  [SMALL_STATE(8669)] = 306775,
  [SMALL_STATE(8670)] = 306782,
  [SMALL_STATE(8671)] = 306789,
  [SMALL_STATE(8672)] = 306796,
  [SMALL_STATE(8673)] = 306803,
  [SMALL_STATE(8674)] = 306810,
  [SMALL_STATE(8675)] = 306817,
  [SMALL_STATE(8676)] = 306824,
  [SMALL_STATE(8677)] = 306831,
  [SMALL_STATE(8678)] = 306838,
  [SMALL_STATE(8679)] = 306845,
  [SMALL_STATE(8680)] = 306852,
  [SMALL_STATE(8681)] = 306859,
  [SMALL_STATE(8682)] = 306866,
  [SMALL_STATE(8683)] = 306873,
  [SMALL_STATE(8684)] = 306880,
  [SMALL_STATE(8685)] = 306887,
  [SMALL_STATE(8686)] = 306894,
  [SMALL_STATE(8687)] = 306901,
  [SMALL_STATE(8688)] = 306908,
  [SMALL_STATE(8689)] = 306915,
  [SMALL_STATE(8690)] = 306922,
  [SMALL_STATE(8691)] = 306929,
  [SMALL_STATE(8692)] = 306936,
  [SMALL_STATE(8693)] = 306943,
  [SMALL_STATE(8694)] = 306950,
  [SMALL_STATE(8695)] = 306957,
  [SMALL_STATE(8696)] = 306964,
  [SMALL_STATE(8697)] = 306971,
  [SMALL_STATE(8698)] = 306978,
  [SMALL_STATE(8699)] = 306985,
  [SMALL_STATE(8700)] = 306992,
  [SMALL_STATE(8701)] = 306999,
  [SMALL_STATE(8702)] = 307006,
  [SMALL_STATE(8703)] = 307013,
  [SMALL_STATE(8704)] = 307020,
  [SMALL_STATE(8705)] = 307027,
  [SMALL_STATE(8706)] = 307034,
  [SMALL_STATE(8707)] = 307041,
  [SMALL_STATE(8708)] = 307048,
  [SMALL_STATE(8709)] = 307055,
  [SMALL_STATE(8710)] = 307062,
  [SMALL_STATE(8711)] = 307069,
  [SMALL_STATE(8712)] = 307076,
  [SMALL_STATE(8713)] = 307083,
  [SMALL_STATE(8714)] = 307090,
  [SMALL_STATE(8715)] = 307097,
  [SMALL_STATE(8716)] = 307104,
  [SMALL_STATE(8717)] = 307111,
  [SMALL_STATE(8718)] = 307118,
  [SMALL_STATE(8719)] = 307125,
  [SMALL_STATE(8720)] = 307132,
  [SMALL_STATE(8721)] = 307139,
  [SMALL_STATE(8722)] = 307146,
  [SMALL_STATE(8723)] = 307153,
  [SMALL_STATE(8724)] = 307160,
  [SMALL_STATE(8725)] = 307167,
  [SMALL_STATE(8726)] = 307174,
  [SMALL_STATE(8727)] = 307181,
  [SMALL_STATE(8728)] = 307188,
  [SMALL_STATE(8729)] = 307195,
  [SMALL_STATE(8730)] = 307202,
  [SMALL_STATE(8731)] = 307209,
  [SMALL_STATE(8732)] = 307216,
  [SMALL_STATE(8733)] = 307223,
  [SMALL_STATE(8734)] = 307230,
  [SMALL_STATE(8735)] = 307237,
  [SMALL_STATE(8736)] = 307244,
  [SMALL_STATE(8737)] = 307251,
  [SMALL_STATE(8738)] = 307258,
  [SMALL_STATE(8739)] = 307265,
  [SMALL_STATE(8740)] = 307272,
  [SMALL_STATE(8741)] = 307279,
  [SMALL_STATE(8742)] = 307286,
  [SMALL_STATE(8743)] = 307293,
  [SMALL_STATE(8744)] = 307300,
  [SMALL_STATE(8745)] = 307307,
  [SMALL_STATE(8746)] = 307314,
  [SMALL_STATE(8747)] = 307321,
  [SMALL_STATE(8748)] = 307328,
  [SMALL_STATE(8749)] = 307335,
  [SMALL_STATE(8750)] = 307342,
  [SMALL_STATE(8751)] = 307349,
  [SMALL_STATE(8752)] = 307356,
  [SMALL_STATE(8753)] = 307363,
  [SMALL_STATE(8754)] = 307370,
  [SMALL_STATE(8755)] = 307377,
  [SMALL_STATE(8756)] = 307384,
  [SMALL_STATE(8757)] = 307391,
  [SMALL_STATE(8758)] = 307398,
  [SMALL_STATE(8759)] = 307405,
  [SMALL_STATE(8760)] = 307412,
  [SMALL_STATE(8761)] = 307419,
  [SMALL_STATE(8762)] = 307426,
  [SMALL_STATE(8763)] = 307433,
  [SMALL_STATE(8764)] = 307440,
  [SMALL_STATE(8765)] = 307447,
  [SMALL_STATE(8766)] = 307454,
  [SMALL_STATE(8767)] = 307461,
  [SMALL_STATE(8768)] = 307468,
  [SMALL_STATE(8769)] = 307475,
  [SMALL_STATE(8770)] = 307482,
  [SMALL_STATE(8771)] = 307489,
  [SMALL_STATE(8772)] = 307496,
  [SMALL_STATE(8773)] = 307503,
  [SMALL_STATE(8774)] = 307510,
  [SMALL_STATE(8775)] = 307517,
  [SMALL_STATE(8776)] = 307524,
  [SMALL_STATE(8777)] = 307531,
  [SMALL_STATE(8778)] = 307538,
  [SMALL_STATE(8779)] = 307545,
  [SMALL_STATE(8780)] = 307552,
  [SMALL_STATE(8781)] = 307559,
  [SMALL_STATE(8782)] = 307566,
  [SMALL_STATE(8783)] = 307573,
  [SMALL_STATE(8784)] = 307580,
  [SMALL_STATE(8785)] = 307587,
  [SMALL_STATE(8786)] = 307594,
  [SMALL_STATE(8787)] = 307601,
  [SMALL_STATE(8788)] = 307608,
  [SMALL_STATE(8789)] = 307615,
  [SMALL_STATE(8790)] = 307622,
  [SMALL_STATE(8791)] = 307629,
  [SMALL_STATE(8792)] = 307636,
  [SMALL_STATE(8793)] = 307643,
  [SMALL_STATE(8794)] = 307650,
  [SMALL_STATE(8795)] = 307657,
  [SMALL_STATE(8796)] = 307664,
  [SMALL_STATE(8797)] = 307671,
  [SMALL_STATE(8798)] = 307678,
  [SMALL_STATE(8799)] = 307685,
  [SMALL_STATE(8800)] = 307692,
  [SMALL_STATE(8801)] = 307699,
  [SMALL_STATE(8802)] = 307706,
  [SMALL_STATE(8803)] = 307713,
  [SMALL_STATE(8804)] = 307720,
  [SMALL_STATE(8805)] = 307727,
  [SMALL_STATE(8806)] = 307734,
  [SMALL_STATE(8807)] = 307741,
  [SMALL_STATE(8808)] = 307748,
  [SMALL_STATE(8809)] = 307755,
  [SMALL_STATE(8810)] = 307762,
  [SMALL_STATE(8811)] = 307769,
  [SMALL_STATE(8812)] = 307776,
  [SMALL_STATE(8813)] = 307783,
  [SMALL_STATE(8814)] = 307790,
  [SMALL_STATE(8815)] = 307797,
  [SMALL_STATE(8816)] = 307804,
  [SMALL_STATE(8817)] = 307811,
  [SMALL_STATE(8818)] = 307818,
  [SMALL_STATE(8819)] = 307825,
  [SMALL_STATE(8820)] = 307832,
  [SMALL_STATE(8821)] = 307839,
  [SMALL_STATE(8822)] = 307846,
  [SMALL_STATE(8823)] = 307853,
  [SMALL_STATE(8824)] = 307860,
  [SMALL_STATE(8825)] = 307867,
  [SMALL_STATE(8826)] = 307874,
  [SMALL_STATE(8827)] = 307881,
  [SMALL_STATE(8828)] = 307888,
  [SMALL_STATE(8829)] = 307895,
  [SMALL_STATE(8830)] = 307902,
  [SMALL_STATE(8831)] = 307909,
  [SMALL_STATE(8832)] = 307916,
  [SMALL_STATE(8833)] = 307923,
  [SMALL_STATE(8834)] = 307930,
  [SMALL_STATE(8835)] = 307937,
  [SMALL_STATE(8836)] = 307944,
  [SMALL_STATE(8837)] = 307951,
  [SMALL_STATE(8838)] = 307958,
  [SMALL_STATE(8839)] = 307965,
  [SMALL_STATE(8840)] = 307972,
  [SMALL_STATE(8841)] = 307979,
  [SMALL_STATE(8842)] = 307986,
  [SMALL_STATE(8843)] = 307993,
  [SMALL_STATE(8844)] = 308000,
  [SMALL_STATE(8845)] = 308007,
  [SMALL_STATE(8846)] = 308014,
  [SMALL_STATE(8847)] = 308021,
  [SMALL_STATE(8848)] = 308028,
  [SMALL_STATE(8849)] = 308035,
  [SMALL_STATE(8850)] = 308042,
  [SMALL_STATE(8851)] = 308049,
  [SMALL_STATE(8852)] = 308056,
  [SMALL_STATE(8853)] = 308063,
  [SMALL_STATE(8854)] = 308070,
  [SMALL_STATE(8855)] = 308077,
  [SMALL_STATE(8856)] = 308084,
  [SMALL_STATE(8857)] = 308091,
  [SMALL_STATE(8858)] = 308098,
  [SMALL_STATE(8859)] = 308105,
  [SMALL_STATE(8860)] = 308112,
  [SMALL_STATE(8861)] = 308119,
  [SMALL_STATE(8862)] = 308126,
  [SMALL_STATE(8863)] = 308133,
  [SMALL_STATE(8864)] = 308140,
  [SMALL_STATE(8865)] = 308147,
  [SMALL_STATE(8866)] = 308154,
  [SMALL_STATE(8867)] = 308161,
  [SMALL_STATE(8868)] = 308168,
  [SMALL_STATE(8869)] = 308175,
  [SMALL_STATE(8870)] = 308182,
  [SMALL_STATE(8871)] = 308189,
  [SMALL_STATE(8872)] = 308196,
  [SMALL_STATE(8873)] = 308203,
  [SMALL_STATE(8874)] = 308210,
  [SMALL_STATE(8875)] = 308217,
  [SMALL_STATE(8876)] = 308224,
  [SMALL_STATE(8877)] = 308231,
  [SMALL_STATE(8878)] = 308238,
  [SMALL_STATE(8879)] = 308245,
  [SMALL_STATE(8880)] = 308252,
  [SMALL_STATE(8881)] = 308259,
  [SMALL_STATE(8882)] = 308266,
  [SMALL_STATE(8883)] = 308273,
  [SMALL_STATE(8884)] = 308280,
  [SMALL_STATE(8885)] = 308287,
  [SMALL_STATE(8886)] = 308294,
  [SMALL_STATE(8887)] = 308301,
  [SMALL_STATE(8888)] = 308308,
  [SMALL_STATE(8889)] = 308315,
  [SMALL_STATE(8890)] = 308322,
  [SMALL_STATE(8891)] = 308329,
  [SMALL_STATE(8892)] = 308336,
  [SMALL_STATE(8893)] = 308343,
  [SMALL_STATE(8894)] = 308350,
  [SMALL_STATE(8895)] = 308357,
  [SMALL_STATE(8896)] = 308364,
  [SMALL_STATE(8897)] = 308371,
  [SMALL_STATE(8898)] = 308378,
  [SMALL_STATE(8899)] = 308385,
  [SMALL_STATE(8900)] = 308392,
  [SMALL_STATE(8901)] = 308399,
  [SMALL_STATE(8902)] = 308406,
  [SMALL_STATE(8903)] = 308413,
  [SMALL_STATE(8904)] = 308420,
  [SMALL_STATE(8905)] = 308427,
  [SMALL_STATE(8906)] = 308434,
  [SMALL_STATE(8907)] = 308441,
  [SMALL_STATE(8908)] = 308448,
  [SMALL_STATE(8909)] = 308455,
  [SMALL_STATE(8910)] = 308462,
  [SMALL_STATE(8911)] = 308469,
  [SMALL_STATE(8912)] = 308476,
  [SMALL_STATE(8913)] = 308483,
  [SMALL_STATE(8914)] = 308490,
  [SMALL_STATE(8915)] = 308497,
  [SMALL_STATE(8916)] = 308504,
  [SMALL_STATE(8917)] = 308511,
  [SMALL_STATE(8918)] = 308518,
  [SMALL_STATE(8919)] = 308525,
  [SMALL_STATE(8920)] = 308532,
  [SMALL_STATE(8921)] = 308539,
  [SMALL_STATE(8922)] = 308546,
  [SMALL_STATE(8923)] = 308553,
  [SMALL_STATE(8924)] = 308560,
  [SMALL_STATE(8925)] = 308567,
  [SMALL_STATE(8926)] = 308574,
  [SMALL_STATE(8927)] = 308581,
  [SMALL_STATE(8928)] = 308588,
  [SMALL_STATE(8929)] = 308595,
  [SMALL_STATE(8930)] = 308602,
  [SMALL_STATE(8931)] = 308609,
  [SMALL_STATE(8932)] = 308616,
  [SMALL_STATE(8933)] = 308623,
  [SMALL_STATE(8934)] = 308630,
  [SMALL_STATE(8935)] = 308637,
  [SMALL_STATE(8936)] = 308644,
  [SMALL_STATE(8937)] = 308651,
  [SMALL_STATE(8938)] = 308658,
  [SMALL_STATE(8939)] = 308665,
  [SMALL_STATE(8940)] = 308672,
  [SMALL_STATE(8941)] = 308679,
  [SMALL_STATE(8942)] = 308686,
  [SMALL_STATE(8943)] = 308693,
  [SMALL_STATE(8944)] = 308700,
  [SMALL_STATE(8945)] = 308707,
  [SMALL_STATE(8946)] = 308714,
  [SMALL_STATE(8947)] = 308721,
  [SMALL_STATE(8948)] = 308728,
  [SMALL_STATE(8949)] = 308735,
  [SMALL_STATE(8950)] = 308742,
  [SMALL_STATE(8951)] = 308749,
  [SMALL_STATE(8952)] = 308756,
  [SMALL_STATE(8953)] = 308763,
  [SMALL_STATE(8954)] = 308770,
  [SMALL_STATE(8955)] = 308777,
  [SMALL_STATE(8956)] = 308784,
  [SMALL_STATE(8957)] = 308791,
  [SMALL_STATE(8958)] = 308798,
  [SMALL_STATE(8959)] = 308805,
  [SMALL_STATE(8960)] = 308812,
  [SMALL_STATE(8961)] = 308819,
  [SMALL_STATE(8962)] = 308826,
  [SMALL_STATE(8963)] = 308833,
  [SMALL_STATE(8964)] = 308840,
  [SMALL_STATE(8965)] = 308847,
  [SMALL_STATE(8966)] = 308854,
  [SMALL_STATE(8967)] = 308861,
  [SMALL_STATE(8968)] = 308868,
  [SMALL_STATE(8969)] = 308875,
  [SMALL_STATE(8970)] = 308882,
  [SMALL_STATE(8971)] = 308889,
  [SMALL_STATE(8972)] = 308896,
  [SMALL_STATE(8973)] = 308903,
  [SMALL_STATE(8974)] = 308910,
  [SMALL_STATE(8975)] = 308917,
  [SMALL_STATE(8976)] = 308924,
  [SMALL_STATE(8977)] = 308931,
  [SMALL_STATE(8978)] = 308938,
  [SMALL_STATE(8979)] = 308945,
  [SMALL_STATE(8980)] = 308952,
  [SMALL_STATE(8981)] = 308959,
  [SMALL_STATE(8982)] = 308966,
  [SMALL_STATE(8983)] = 308973,
  [SMALL_STATE(8984)] = 308980,
  [SMALL_STATE(8985)] = 308987,
  [SMALL_STATE(8986)] = 308994,
  [SMALL_STATE(8987)] = 309001,
  [SMALL_STATE(8988)] = 309008,
  [SMALL_STATE(8989)] = 309015,
  [SMALL_STATE(8990)] = 309022,
  [SMALL_STATE(8991)] = 309029,
  [SMALL_STATE(8992)] = 309036,
  [SMALL_STATE(8993)] = 309043,
  [SMALL_STATE(8994)] = 309050,
  [SMALL_STATE(8995)] = 309057,
  [SMALL_STATE(8996)] = 309064,
  [SMALL_STATE(8997)] = 309071,
  [SMALL_STATE(8998)] = 309078,
  [SMALL_STATE(8999)] = 309085,
  [SMALL_STATE(9000)] = 309092,
  [SMALL_STATE(9001)] = 309099,
  [SMALL_STATE(9002)] = 309106,
  [SMALL_STATE(9003)] = 309113,
  [SMALL_STATE(9004)] = 309120,
  [SMALL_STATE(9005)] = 309127,
  [SMALL_STATE(9006)] = 309134,
  [SMALL_STATE(9007)] = 309141,
  [SMALL_STATE(9008)] = 309148,
  [SMALL_STATE(9009)] = 309155,
  [SMALL_STATE(9010)] = 309162,
  [SMALL_STATE(9011)] = 309169,
  [SMALL_STATE(9012)] = 309176,
  [SMALL_STATE(9013)] = 309183,
  [SMALL_STATE(9014)] = 309190,
  [SMALL_STATE(9015)] = 309197,
  [SMALL_STATE(9016)] = 309204,
  [SMALL_STATE(9017)] = 309211,
  [SMALL_STATE(9018)] = 309218,
  [SMALL_STATE(9019)] = 309225,
  [SMALL_STATE(9020)] = 309232,
  [SMALL_STATE(9021)] = 309239,
  [SMALL_STATE(9022)] = 309246,
  [SMALL_STATE(9023)] = 309253,
  [SMALL_STATE(9024)] = 309260,
  [SMALL_STATE(9025)] = 309267,
  [SMALL_STATE(9026)] = 309274,
  [SMALL_STATE(9027)] = 309281,
  [SMALL_STATE(9028)] = 309288,
  [SMALL_STATE(9029)] = 309295,
  [SMALL_STATE(9030)] = 309302,
  [SMALL_STATE(9031)] = 309309,
  [SMALL_STATE(9032)] = 309316,
  [SMALL_STATE(9033)] = 309323,
  [SMALL_STATE(9034)] = 309330,
  [SMALL_STATE(9035)] = 309337,
  [SMALL_STATE(9036)] = 309344,
  [SMALL_STATE(9037)] = 309351,
  [SMALL_STATE(9038)] = 309358,
  [SMALL_STATE(9039)] = 309365,
  [SMALL_STATE(9040)] = 309372,
  [SMALL_STATE(9041)] = 309379,
  [SMALL_STATE(9042)] = 309386,
  [SMALL_STATE(9043)] = 309393,
  [SMALL_STATE(9044)] = 309400,
  [SMALL_STATE(9045)] = 309407,
  [SMALL_STATE(9046)] = 309414,
  [SMALL_STATE(9047)] = 309421,
  [SMALL_STATE(9048)] = 309428,
  [SMALL_STATE(9049)] = 309435,
  [SMALL_STATE(9050)] = 309442,
  [SMALL_STATE(9051)] = 309449,
  [SMALL_STATE(9052)] = 309456,
  [SMALL_STATE(9053)] = 309463,
  [SMALL_STATE(9054)] = 309470,
  [SMALL_STATE(9055)] = 309477,
  [SMALL_STATE(9056)] = 309484,
  [SMALL_STATE(9057)] = 309491,
  [SMALL_STATE(9058)] = 309498,
  [SMALL_STATE(9059)] = 309505,
  [SMALL_STATE(9060)] = 309512,
  [SMALL_STATE(9061)] = 309519,
  [SMALL_STATE(9062)] = 309526,
  [SMALL_STATE(9063)] = 309533,
  [SMALL_STATE(9064)] = 309540,
  [SMALL_STATE(9065)] = 309547,
  [SMALL_STATE(9066)] = 309554,
  [SMALL_STATE(9067)] = 309561,
  [SMALL_STATE(9068)] = 309568,
  [SMALL_STATE(9069)] = 309575,
  [SMALL_STATE(9070)] = 309582,
  [SMALL_STATE(9071)] = 309589,
  [SMALL_STATE(9072)] = 309596,
  [SMALL_STATE(9073)] = 309603,
  [SMALL_STATE(9074)] = 309610,
  [SMALL_STATE(9075)] = 309617,
  [SMALL_STATE(9076)] = 309624,
  [SMALL_STATE(9077)] = 309631,
  [SMALL_STATE(9078)] = 309638,
  [SMALL_STATE(9079)] = 309645,
  [SMALL_STATE(9080)] = 309652,
  [SMALL_STATE(9081)] = 309659,
  [SMALL_STATE(9082)] = 309666,
  [SMALL_STATE(9083)] = 309673,
  [SMALL_STATE(9084)] = 309680,
  [SMALL_STATE(9085)] = 309687,
  [SMALL_STATE(9086)] = 309694,
  [SMALL_STATE(9087)] = 309701,
  [SMALL_STATE(9088)] = 309708,
  [SMALL_STATE(9089)] = 309715,
  [SMALL_STATE(9090)] = 309722,
  [SMALL_STATE(9091)] = 309729,
  [SMALL_STATE(9092)] = 309736,
  [SMALL_STATE(9093)] = 309743,
  [SMALL_STATE(9094)] = 309750,
  [SMALL_STATE(9095)] = 309757,
  [SMALL_STATE(9096)] = 309764,
  [SMALL_STATE(9097)] = 309771,
  [SMALL_STATE(9098)] = 309778,
  [SMALL_STATE(9099)] = 309785,
  [SMALL_STATE(9100)] = 309792,
  [SMALL_STATE(9101)] = 309799,
  [SMALL_STATE(9102)] = 309806,
  [SMALL_STATE(9103)] = 309813,
  [SMALL_STATE(9104)] = 309820,
  [SMALL_STATE(9105)] = 309827,
  [SMALL_STATE(9106)] = 309834,
  [SMALL_STATE(9107)] = 309841,
  [SMALL_STATE(9108)] = 309848,
  [SMALL_STATE(9109)] = 309855,
  [SMALL_STATE(9110)] = 309862,
  [SMALL_STATE(9111)] = 309869,
  [SMALL_STATE(9112)] = 309876,
  [SMALL_STATE(9113)] = 309883,
  [SMALL_STATE(9114)] = 309890,
  [SMALL_STATE(9115)] = 309897,
  [SMALL_STATE(9116)] = 309904,
  [SMALL_STATE(9117)] = 309911,
  [SMALL_STATE(9118)] = 309918,
  [SMALL_STATE(9119)] = 309925,
  [SMALL_STATE(9120)] = 309932,
  [SMALL_STATE(9121)] = 309939,
  [SMALL_STATE(9122)] = 309946,
  [SMALL_STATE(9123)] = 309953,
  [SMALL_STATE(9124)] = 309960,
  [SMALL_STATE(9125)] = 309967,
  [SMALL_STATE(9126)] = 309974,
  [SMALL_STATE(9127)] = 309981,
  [SMALL_STATE(9128)] = 309988,
  [SMALL_STATE(9129)] = 309995,
  [SMALL_STATE(9130)] = 310002,
  [SMALL_STATE(9131)] = 310009,
  [SMALL_STATE(9132)] = 310016,
  [SMALL_STATE(9133)] = 310023,
  [SMALL_STATE(9134)] = 310030,
  [SMALL_STATE(9135)] = 310037,
  [SMALL_STATE(9136)] = 310044,
  [SMALL_STATE(9137)] = 310051,
  [SMALL_STATE(9138)] = 310058,
  [SMALL_STATE(9139)] = 310065,
  [SMALL_STATE(9140)] = 310072,
  [SMALL_STATE(9141)] = 310079,
  [SMALL_STATE(9142)] = 310086,
  [SMALL_STATE(9143)] = 310093,
  [SMALL_STATE(9144)] = 310100,
  [SMALL_STATE(9145)] = 310107,
  [SMALL_STATE(9146)] = 310114,
  [SMALL_STATE(9147)] = 310121,
  [SMALL_STATE(9148)] = 310128,
  [SMALL_STATE(9149)] = 310135,
  [SMALL_STATE(9150)] = 310142,
  [SMALL_STATE(9151)] = 310149,
  [SMALL_STATE(9152)] = 310156,
  [SMALL_STATE(9153)] = 310163,
  [SMALL_STATE(9154)] = 310170,
  [SMALL_STATE(9155)] = 310177,
  [SMALL_STATE(9156)] = 310184,
  [SMALL_STATE(9157)] = 310191,
  [SMALL_STATE(9158)] = 310198,
  [SMALL_STATE(9159)] = 310205,
  [SMALL_STATE(9160)] = 310212,
  [SMALL_STATE(9161)] = 310219,
  [SMALL_STATE(9162)] = 310226,
  [SMALL_STATE(9163)] = 310233,
  [SMALL_STATE(9164)] = 310240,
  [SMALL_STATE(9165)] = 310247,
  [SMALL_STATE(9166)] = 310254,
  [SMALL_STATE(9167)] = 310261,
  [SMALL_STATE(9168)] = 310268,
  [SMALL_STATE(9169)] = 310275,
  [SMALL_STATE(9170)] = 310282,
  [SMALL_STATE(9171)] = 310289,
  [SMALL_STATE(9172)] = 310296,
  [SMALL_STATE(9173)] = 310303,
  [SMALL_STATE(9174)] = 310310,
  [SMALL_STATE(9175)] = 310317,
  [SMALL_STATE(9176)] = 310324,
  [SMALL_STATE(9177)] = 310331,
  [SMALL_STATE(9178)] = 310338,
  [SMALL_STATE(9179)] = 310345,
  [SMALL_STATE(9180)] = 310352,
  [SMALL_STATE(9181)] = 310359,
  [SMALL_STATE(9182)] = 310366,
  [SMALL_STATE(9183)] = 310373,
  [SMALL_STATE(9184)] = 310380,
  [SMALL_STATE(9185)] = 310387,
  [SMALL_STATE(9186)] = 310394,
  [SMALL_STATE(9187)] = 310401,
  [SMALL_STATE(9188)] = 310408,
  [SMALL_STATE(9189)] = 310415,
  [SMALL_STATE(9190)] = 310422,
  [SMALL_STATE(9191)] = 310429,
  [SMALL_STATE(9192)] = 310436,
  [SMALL_STATE(9193)] = 310443,
  [SMALL_STATE(9194)] = 310450,
  [SMALL_STATE(9195)] = 310457,
  [SMALL_STATE(9196)] = 310464,
  [SMALL_STATE(9197)] = 310471,
  [SMALL_STATE(9198)] = 310478,
  [SMALL_STATE(9199)] = 310485,
  [SMALL_STATE(9200)] = 310492,
  [SMALL_STATE(9201)] = 310499,
  [SMALL_STATE(9202)] = 310506,
  [SMALL_STATE(9203)] = 310513,
  [SMALL_STATE(9204)] = 310520,
  [SMALL_STATE(9205)] = 310527,
  [SMALL_STATE(9206)] = 310534,
  [SMALL_STATE(9207)] = 310541,
  [SMALL_STATE(9208)] = 310548,
  [SMALL_STATE(9209)] = 310555,
  [SMALL_STATE(9210)] = 310562,
  [SMALL_STATE(9211)] = 310569,
  [SMALL_STATE(9212)] = 310576,
  [SMALL_STATE(9213)] = 310583,
  [SMALL_STATE(9214)] = 310590,
  [SMALL_STATE(9215)] = 310597,
  [SMALL_STATE(9216)] = 310604,
  [SMALL_STATE(9217)] = 310611,
  [SMALL_STATE(9218)] = 310618,
  [SMALL_STATE(9219)] = 310625,
  [SMALL_STATE(9220)] = 310632,
  [SMALL_STATE(9221)] = 310639,
  [SMALL_STATE(9222)] = 310646,
  [SMALL_STATE(9223)] = 310653,
  [SMALL_STATE(9224)] = 310660,
  [SMALL_STATE(9225)] = 310667,
  [SMALL_STATE(9226)] = 310674,
  [SMALL_STATE(9227)] = 310681,
  [SMALL_STATE(9228)] = 310688,
  [SMALL_STATE(9229)] = 310695,
  [SMALL_STATE(9230)] = 310702,
  [SMALL_STATE(9231)] = 310709,
  [SMALL_STATE(9232)] = 310716,
  [SMALL_STATE(9233)] = 310723,
  [SMALL_STATE(9234)] = 310730,
  [SMALL_STATE(9235)] = 310737,
  [SMALL_STATE(9236)] = 310744,
  [SMALL_STATE(9237)] = 310751,
  [SMALL_STATE(9238)] = 310758,
  [SMALL_STATE(9239)] = 310765,
  [SMALL_STATE(9240)] = 310772,
  [SMALL_STATE(9241)] = 310779,
  [SMALL_STATE(9242)] = 310786,
  [SMALL_STATE(9243)] = 310793,
  [SMALL_STATE(9244)] = 310800,
  [SMALL_STATE(9245)] = 310807,
  [SMALL_STATE(9246)] = 310814,
  [SMALL_STATE(9247)] = 310821,
  [SMALL_STATE(9248)] = 310828,
  [SMALL_STATE(9249)] = 310835,
  [SMALL_STATE(9250)] = 310842,
  [SMALL_STATE(9251)] = 310849,
  [SMALL_STATE(9252)] = 310856,
  [SMALL_STATE(9253)] = 310863,
  [SMALL_STATE(9254)] = 310870,
  [SMALL_STATE(9255)] = 310877,
  [SMALL_STATE(9256)] = 310884,
  [SMALL_STATE(9257)] = 310891,
  [SMALL_STATE(9258)] = 310898,
  [SMALL_STATE(9259)] = 310905,
  [SMALL_STATE(9260)] = 310912,
  [SMALL_STATE(9261)] = 310919,
  [SMALL_STATE(9262)] = 310926,
  [SMALL_STATE(9263)] = 310933,
  [SMALL_STATE(9264)] = 310940,
  [SMALL_STATE(9265)] = 310947,
  [SMALL_STATE(9266)] = 310954,
  [SMALL_STATE(9267)] = 310961,
  [SMALL_STATE(9268)] = 310968,
  [SMALL_STATE(9269)] = 310975,
  [SMALL_STATE(9270)] = 310982,
  [SMALL_STATE(9271)] = 310989,
  [SMALL_STATE(9272)] = 310996,
  [SMALL_STATE(9273)] = 311003,
  [SMALL_STATE(9274)] = 311010,
  [SMALL_STATE(9275)] = 311017,
  [SMALL_STATE(9276)] = 311024,
  [SMALL_STATE(9277)] = 311031,
  [SMALL_STATE(9278)] = 311038,
  [SMALL_STATE(9279)] = 311045,
  [SMALL_STATE(9280)] = 311052,
  [SMALL_STATE(9281)] = 311059,
  [SMALL_STATE(9282)] = 311066,
  [SMALL_STATE(9283)] = 311073,
  [SMALL_STATE(9284)] = 311080,
  [SMALL_STATE(9285)] = 311087,
  [SMALL_STATE(9286)] = 311094,
  [SMALL_STATE(9287)] = 311101,
  [SMALL_STATE(9288)] = 311108,
  [SMALL_STATE(9289)] = 311115,
  [SMALL_STATE(9290)] = 311122,
  [SMALL_STATE(9291)] = 311129,
  [SMALL_STATE(9292)] = 311136,
  [SMALL_STATE(9293)] = 311143,
  [SMALL_STATE(9294)] = 311150,
  [SMALL_STATE(9295)] = 311157,
  [SMALL_STATE(9296)] = 311164,
  [SMALL_STATE(9297)] = 311171,
  [SMALL_STATE(9298)] = 311178,
  [SMALL_STATE(9299)] = 311185,
  [SMALL_STATE(9300)] = 311192,
  [SMALL_STATE(9301)] = 311199,
  [SMALL_STATE(9302)] = 311206,
  [SMALL_STATE(9303)] = 311213,
  [SMALL_STATE(9304)] = 311220,
  [SMALL_STATE(9305)] = 311227,
  [SMALL_STATE(9306)] = 311234,
  [SMALL_STATE(9307)] = 311241,
  [SMALL_STATE(9308)] = 311248,
  [SMALL_STATE(9309)] = 311255,
  [SMALL_STATE(9310)] = 311262,
  [SMALL_STATE(9311)] = 311269,
  [SMALL_STATE(9312)] = 311276,
  [SMALL_STATE(9313)] = 311283,
  [SMALL_STATE(9314)] = 311290,
  [SMALL_STATE(9315)] = 311297,
  [SMALL_STATE(9316)] = 311304,
  [SMALL_STATE(9317)] = 311311,
  [SMALL_STATE(9318)] = 311318,
  [SMALL_STATE(9319)] = 311325,
  [SMALL_STATE(9320)] = 311332,
  [SMALL_STATE(9321)] = 311339,
  [SMALL_STATE(9322)] = 311346,
  [SMALL_STATE(9323)] = 311353,
  [SMALL_STATE(9324)] = 311360,
  [SMALL_STATE(9325)] = 311367,
  [SMALL_STATE(9326)] = 311374,
  [SMALL_STATE(9327)] = 311381,
  [SMALL_STATE(9328)] = 311388,
  [SMALL_STATE(9329)] = 311395,
  [SMALL_STATE(9330)] = 311402,
  [SMALL_STATE(9331)] = 311409,
  [SMALL_STATE(9332)] = 311416,
  [SMALL_STATE(9333)] = 311423,
  [SMALL_STATE(9334)] = 311430,
  [SMALL_STATE(9335)] = 311437,
  [SMALL_STATE(9336)] = 311444,
  [SMALL_STATE(9337)] = 311451,
  [SMALL_STATE(9338)] = 311458,
  [SMALL_STATE(9339)] = 311465,
  [SMALL_STATE(9340)] = 311472,
  [SMALL_STATE(9341)] = 311479,
  [SMALL_STATE(9342)] = 311486,
  [SMALL_STATE(9343)] = 311493,
  [SMALL_STATE(9344)] = 311500,
  [SMALL_STATE(9345)] = 311507,
  [SMALL_STATE(9346)] = 311514,
  [SMALL_STATE(9347)] = 311521,
  [SMALL_STATE(9348)] = 311528,
  [SMALL_STATE(9349)] = 311535,
  [SMALL_STATE(9350)] = 311542,
  [SMALL_STATE(9351)] = 311549,
  [SMALL_STATE(9352)] = 311556,
  [SMALL_STATE(9353)] = 311563,
  [SMALL_STATE(9354)] = 311570,
  [SMALL_STATE(9355)] = 311577,
  [SMALL_STATE(9356)] = 311584,
  [SMALL_STATE(9357)] = 311591,
  [SMALL_STATE(9358)] = 311598,
  [SMALL_STATE(9359)] = 311605,
  [SMALL_STATE(9360)] = 311612,
  [SMALL_STATE(9361)] = 311619,
  [SMALL_STATE(9362)] = 311626,
  [SMALL_STATE(9363)] = 311633,
  [SMALL_STATE(9364)] = 311640,
  [SMALL_STATE(9365)] = 311647,
  [SMALL_STATE(9366)] = 311654,
  [SMALL_STATE(9367)] = 311661,
  [SMALL_STATE(9368)] = 311668,
  [SMALL_STATE(9369)] = 311675,
  [SMALL_STATE(9370)] = 311682,
  [SMALL_STATE(9371)] = 311689,
  [SMALL_STATE(9372)] = 311696,
  [SMALL_STATE(9373)] = 311703,
  [SMALL_STATE(9374)] = 311710,
  [SMALL_STATE(9375)] = 311717,
  [SMALL_STATE(9376)] = 311724,
  [SMALL_STATE(9377)] = 311731,
  [SMALL_STATE(9378)] = 311738,
  [SMALL_STATE(9379)] = 311745,
  [SMALL_STATE(9380)] = 311752,
  [SMALL_STATE(9381)] = 311759,
  [SMALL_STATE(9382)] = 311766,
  [SMALL_STATE(9383)] = 311773,
  [SMALL_STATE(9384)] = 311780,
  [SMALL_STATE(9385)] = 311787,
  [SMALL_STATE(9386)] = 311794,
  [SMALL_STATE(9387)] = 311801,
  [SMALL_STATE(9388)] = 311808,
  [SMALL_STATE(9389)] = 311815,
  [SMALL_STATE(9390)] = 311822,
  [SMALL_STATE(9391)] = 311829,
  [SMALL_STATE(9392)] = 311836,
  [SMALL_STATE(9393)] = 311843,
  [SMALL_STATE(9394)] = 311850,
  [SMALL_STATE(9395)] = 311857,
  [SMALL_STATE(9396)] = 311864,
  [SMALL_STATE(9397)] = 311871,
  [SMALL_STATE(9398)] = 311878,
  [SMALL_STATE(9399)] = 311885,
  [SMALL_STATE(9400)] = 311892,
  [SMALL_STATE(9401)] = 311899,
  [SMALL_STATE(9402)] = 311906,
  [SMALL_STATE(9403)] = 311913,
  [SMALL_STATE(9404)] = 311920,
  [SMALL_STATE(9405)] = 311927,
  [SMALL_STATE(9406)] = 311934,
  [SMALL_STATE(9407)] = 311941,
  [SMALL_STATE(9408)] = 311948,
  [SMALL_STATE(9409)] = 311955,
  [SMALL_STATE(9410)] = 311962,
  [SMALL_STATE(9411)] = 311969,
  [SMALL_STATE(9412)] = 311976,
  [SMALL_STATE(9413)] = 311983,
  [SMALL_STATE(9414)] = 311990,
  [SMALL_STATE(9415)] = 311997,
  [SMALL_STATE(9416)] = 312004,
  [SMALL_STATE(9417)] = 312011,
  [SMALL_STATE(9418)] = 312018,
  [SMALL_STATE(9419)] = 312025,
  [SMALL_STATE(9420)] = 312032,
  [SMALL_STATE(9421)] = 312039,
  [SMALL_STATE(9422)] = 312046,
  [SMALL_STATE(9423)] = 312053,
  [SMALL_STATE(9424)] = 312060,
  [SMALL_STATE(9425)] = 312067,
  [SMALL_STATE(9426)] = 312074,
  [SMALL_STATE(9427)] = 312081,
  [SMALL_STATE(9428)] = 312088,
  [SMALL_STATE(9429)] = 312095,
  [SMALL_STATE(9430)] = 312102,
  [SMALL_STATE(9431)] = 312109,
  [SMALL_STATE(9432)] = 312116,
  [SMALL_STATE(9433)] = 312123,
  [SMALL_STATE(9434)] = 312130,
  [SMALL_STATE(9435)] = 312137,
  [SMALL_STATE(9436)] = 312144,
  [SMALL_STATE(9437)] = 312151,
  [SMALL_STATE(9438)] = 312158,
  [SMALL_STATE(9439)] = 312165,
  [SMALL_STATE(9440)] = 312172,
  [SMALL_STATE(9441)] = 312179,
  [SMALL_STATE(9442)] = 312186,
  [SMALL_STATE(9443)] = 312193,
  [SMALL_STATE(9444)] = 312200,
  [SMALL_STATE(9445)] = 312207,
  [SMALL_STATE(9446)] = 312214,
  [SMALL_STATE(9447)] = 312221,
  [SMALL_STATE(9448)] = 312228,
  [SMALL_STATE(9449)] = 312235,
  [SMALL_STATE(9450)] = 312242,
  [SMALL_STATE(9451)] = 312249,
  [SMALL_STATE(9452)] = 312256,
  [SMALL_STATE(9453)] = 312263,
  [SMALL_STATE(9454)] = 312270,
  [SMALL_STATE(9455)] = 312277,
  [SMALL_STATE(9456)] = 312284,
  [SMALL_STATE(9457)] = 312291,
  [SMALL_STATE(9458)] = 312298,
  [SMALL_STATE(9459)] = 312305,
  [SMALL_STATE(9460)] = 312312,
  [SMALL_STATE(9461)] = 312319,
  [SMALL_STATE(9462)] = 312326,
  [SMALL_STATE(9463)] = 312333,
  [SMALL_STATE(9464)] = 312340,
  [SMALL_STATE(9465)] = 312347,
  [SMALL_STATE(9466)] = 312354,
  [SMALL_STATE(9467)] = 312361,
  [SMALL_STATE(9468)] = 312368,
  [SMALL_STATE(9469)] = 312375,
  [SMALL_STATE(9470)] = 312382,
  [SMALL_STATE(9471)] = 312389,
  [SMALL_STATE(9472)] = 312396,
  [SMALL_STATE(9473)] = 312403,
  [SMALL_STATE(9474)] = 312410,
  [SMALL_STATE(9475)] = 312417,
  [SMALL_STATE(9476)] = 312424,
  [SMALL_STATE(9477)] = 312431,
  [SMALL_STATE(9478)] = 312438,
  [SMALL_STATE(9479)] = 312445,
  [SMALL_STATE(9480)] = 312452,
  [SMALL_STATE(9481)] = 312459,
  [SMALL_STATE(9482)] = 312466,
  [SMALL_STATE(9483)] = 312473,
  [SMALL_STATE(9484)] = 312480,
  [SMALL_STATE(9485)] = 312487,
  [SMALL_STATE(9486)] = 312494,
  [SMALL_STATE(9487)] = 312501,
  [SMALL_STATE(9488)] = 312508,
  [SMALL_STATE(9489)] = 312515,
  [SMALL_STATE(9490)] = 312522,
  [SMALL_STATE(9491)] = 312529,
  [SMALL_STATE(9492)] = 312536,
  [SMALL_STATE(9493)] = 312543,
  [SMALL_STATE(9494)] = 312550,
  [SMALL_STATE(9495)] = 312557,
  [SMALL_STATE(9496)] = 312564,
  [SMALL_STATE(9497)] = 312571,
  [SMALL_STATE(9498)] = 312578,
  [SMALL_STATE(9499)] = 312585,
  [SMALL_STATE(9500)] = 312592,
  [SMALL_STATE(9501)] = 312599,
  [SMALL_STATE(9502)] = 312606,
  [SMALL_STATE(9503)] = 312613,
  [SMALL_STATE(9504)] = 312620,
  [SMALL_STATE(9505)] = 312627,
  [SMALL_STATE(9506)] = 312634,
  [SMALL_STATE(9507)] = 312641,
  [SMALL_STATE(9508)] = 312648,
  [SMALL_STATE(9509)] = 312655,
  [SMALL_STATE(9510)] = 312662,
  [SMALL_STATE(9511)] = 312669,
  [SMALL_STATE(9512)] = 312676,
  [SMALL_STATE(9513)] = 312683,
  [SMALL_STATE(9514)] = 312690,
  [SMALL_STATE(9515)] = 312697,
  [SMALL_STATE(9516)] = 312704,
  [SMALL_STATE(9517)] = 312711,
  [SMALL_STATE(9518)] = 312718,
  [SMALL_STATE(9519)] = 312725,
  [SMALL_STATE(9520)] = 312732,
  [SMALL_STATE(9521)] = 312739,
  [SMALL_STATE(9522)] = 312746,
  [SMALL_STATE(9523)] = 312753,
  [SMALL_STATE(9524)] = 312760,
  [SMALL_STATE(9525)] = 312767,
  [SMALL_STATE(9526)] = 312774,
  [SMALL_STATE(9527)] = 312781,
  [SMALL_STATE(9528)] = 312788,
  [SMALL_STATE(9529)] = 312795,
  [SMALL_STATE(9530)] = 312802,
  [SMALL_STATE(9531)] = 312809,
  [SMALL_STATE(9532)] = 312816,
  [SMALL_STATE(9533)] = 312823,
  [SMALL_STATE(9534)] = 312830,
  [SMALL_STATE(9535)] = 312837,
  [SMALL_STATE(9536)] = 312844,
  [SMALL_STATE(9537)] = 312851,
  [SMALL_STATE(9538)] = 312858,
  [SMALL_STATE(9539)] = 312865,
  [SMALL_STATE(9540)] = 312872,
  [SMALL_STATE(9541)] = 312879,
  [SMALL_STATE(9542)] = 312886,
  [SMALL_STATE(9543)] = 312893,
  [SMALL_STATE(9544)] = 312900,
  [SMALL_STATE(9545)] = 312907,
  [SMALL_STATE(9546)] = 312914,
  [SMALL_STATE(9547)] = 312921,
  [SMALL_STATE(9548)] = 312928,
  [SMALL_STATE(9549)] = 312935,
  [SMALL_STATE(9550)] = 312942,
  [SMALL_STATE(9551)] = 312949,
  [SMALL_STATE(9552)] = 312956,
  [SMALL_STATE(9553)] = 312963,
  [SMALL_STATE(9554)] = 312970,
  [SMALL_STATE(9555)] = 312977,
  [SMALL_STATE(9556)] = 312984,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_translation_unit, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(836),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7212),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9111),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6283),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8768),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8257),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1365),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5851),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(919),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(143),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3345),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2708),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2332),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9423),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7138),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8217),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8650),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8551),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2978),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2190),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6280),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2721),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2690),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1719),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9080),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2282),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6893),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5680),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5726),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5665),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8207),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8507),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8680),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8454),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(668),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9108),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8615),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8792),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8887),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8649),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8673),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8737),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7346),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5527),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7941),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7648),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5546),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4396),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2243),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9525),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3765),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5813),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(984),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8495),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7220),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7100),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8775),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8800),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1582),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8466),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1258),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5610),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5961),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9166),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(829),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7184),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9196),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8905),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6348),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9197),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8451),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3292),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2345),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2666),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8053),
  [195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8519),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1526),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9068),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8475),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8985),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1000),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9078),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9090),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9253),
  [215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8238),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9046),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9001),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4873),
  [223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4360),
  [225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8522),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7223),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7077),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9384),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9385),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1169),
  [241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1528),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1898),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7201),
  [267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9157),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6364),
  [271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9158),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6259),
  [279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8866),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8529),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(145),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3352),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2349),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2624),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8136),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8316),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1563),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8595),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8520),
  [305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(681),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9383),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9401),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9402),
  [315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9193),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8327),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9543),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8319),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7219),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7046),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9434),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9435),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1553),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(718),
  [343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elifdef, 2, 0, 10),
  [345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 3, 0, 80),
  [347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elifdef, 3, 0, 10),
  [349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 4, 0, 80),
  [351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [377] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(831),
  [380] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7201),
  [383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9157),
  [386] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6364),
  [389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0),
  [391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9158),
  [394] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8529),
  [397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(134),
  [400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1315),
  [406] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(677),
  [412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5851),
  [415] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(919),
  [418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(200),
  [421] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(145),
  [424] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(3352),
  [427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2708),
  [430] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2349),
  [433] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9423),
  [436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7138),
  [439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8217),
  [442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8650),
  [445] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8551),
  [448] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2978),
  [451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(43),
  [454] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2190),
  [457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6280),
  [460] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2721),
  [463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2624),
  [466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1719),
  [469] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9080),
  [472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2282),
  [475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6893),
  [478] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5680),
  [481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5726),
  [484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5665),
  [487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8136),
  [490] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8316),
  [493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1563),
  [496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8595),
  [499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8520),
  [502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(681),
  [505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9383),
  [508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1017),
  [511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9401),
  [514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9402),
  [517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9193),
  [520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8327),
  [523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9543),
  [526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1305),
  [529] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1172),
  [532] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8649),
  [535] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8673),
  [538] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8737),
  [541] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7346),
  [544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(4873),
  [547] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7941),
  [550] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7648),
  [553] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(4360),
  [556] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(4396),
  [559] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2243),
  [562] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9525),
  [565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(3765),
  [568] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5813),
  [571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(986),
  [574] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(801),
  [577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8319),
  [580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1253),
  [583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1231),
  [586] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7219),
  [589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7046),
  [592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9434),
  [595] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9435),
  [598] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1246),
  [601] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1553),
  [604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8466),
  [607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1258),
  [610] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5610),
  [613] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5961),
  [616] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9166),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(833),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3741),
  [629] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(833),
  [632] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7184),
  [635] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9196),
  [638] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6348),
  [641] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9197),
  [644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8451),
  [647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(365),
  [650] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(144),
  [653] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(3292),
  [656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2345),
  [659] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(47),
  [662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0),
  [664] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2666),
  [667] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8053),
  [670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8519),
  [673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1526),
  [676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9068),
  [679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8475),
  [682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(680),
  [685] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8985),
  [688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1000),
  [691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9078),
  [694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9090),
  [697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9253),
  [700] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8238),
  [703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9046),
  [706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(982),
  [709] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8522),
  [712] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1188),
  [715] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7223),
  [718] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7077),
  [721] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9384),
  [724] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9385),
  [727] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1169),
  [730] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1528),
  [733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3758),
  [735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(835),
  [742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7221),
  [745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8739),
  [748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6368),
  [751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8644),
  [754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8227),
  [757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(416),
  [760] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(3379),
  [766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2350),
  [769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(53),
  [772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2631),
  [775] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7857),
  [778] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8363),
  [781] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1570),
  [784] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8811),
  [787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8318),
  [790] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(683),
  [793] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9433),
  [796] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1015),
  [799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9548),
  [802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8822),
  [805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8653),
  [808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8372),
  [811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8853),
  [814] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(987),
  [817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8366),
  [820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1145),
  [823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7207),
  [826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7073),
  [829] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9455),
  [832] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(9447),
  [835] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1147),
  [838] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1564),
  [841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1908),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3858),
  [857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1912),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7221),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8739),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6368),
  [881] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 2, 0, 0),
  [883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8644),
  [885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8227),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3379),
  [893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2350),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2631),
  [899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7857),
  [901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8363),
  [903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1570),
  [905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8811),
  [907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8318),
  [909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(683),
  [911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9433),
  [913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9548),
  [917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8822),
  [919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8653),
  [921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8372),
  [923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8853),
  [925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(987),
  [927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8366),
  [929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1145),
  [931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7207),
  [933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7073),
  [935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9455),
  [937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9447),
  [939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1147),
  [941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1564),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 1, 0, 0),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4891),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4904),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4400),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4372),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5529),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5464),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4109),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2182),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6135),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6139),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4238),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4241),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1750),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6512),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6513),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_translation_unit, 1, 0, 0),
  [995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0),
  [997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(836),
  [1000] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7212),
  [1003] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9111),
  [1006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6283),
  [1009] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8768),
  [1012] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8257),
  [1015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(134),
  [1018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [1021] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1315),
  [1024] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [1027] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(677),
  [1030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5851),
  [1033] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(919),
  [1036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(739),
  [1039] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(143),
  [1042] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3345),
  [1045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2708),
  [1048] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2332),
  [1051] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9423),
  [1054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7138),
  [1057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8217),
  [1060] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8650),
  [1063] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8551),
  [1066] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2978),
  [1069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(55),
  [1072] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2190),
  [1075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6280),
  [1078] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2721),
  [1081] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2690),
  [1084] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1719),
  [1087] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9080),
  [1090] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2282),
  [1093] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6893),
  [1096] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5680),
  [1099] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5726),
  [1102] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5665),
  [1105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8207),
  [1108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8507),
  [1111] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1577),
  [1114] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8680),
  [1117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8454),
  [1120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(668),
  [1123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9108),
  [1126] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(994),
  [1129] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8615),
  [1132] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8792),
  [1135] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8887),
  [1138] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1305),
  [1141] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1172),
  [1144] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8649),
  [1147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8673),
  [1150] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8737),
  [1153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7346),
  [1156] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5527),
  [1159] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7941),
  [1162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7648),
  [1165] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5546),
  [1168] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4396),
  [1171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2243),
  [1174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9525),
  [1177] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3765),
  [1180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5813),
  [1183] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(984),
  [1186] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(801),
  [1189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8495),
  [1192] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1253),
  [1195] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1179),
  [1198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7220),
  [1201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7100),
  [1204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8775),
  [1207] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8800),
  [1210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1180),
  [1213] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1582),
  [1216] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8466),
  [1219] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1258),
  [1222] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5610),
  [1225] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5961),
  [1228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9166),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(912),
  [1233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 4, 0, 14),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [1239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 4, 0, 14),
  [1241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1353),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1909),
  [1247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8315),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6267),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8412),
  [1253] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(912),
  [1256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0),
  [1258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(154),
  [1261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [1264] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [1267] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1353),
  [1270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0),
  [1272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1353),
  [1275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(200),
  [1278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(288),
  [1281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3352),
  [1284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1909),
  [1287] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2721),
  [1290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9423),
  [1293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7138),
  [1296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8315),
  [1299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8650),
  [1302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(43),
  [1305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2190),
  [1308] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6267),
  [1311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1719),
  [1314] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9080),
  [1317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2282),
  [1320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6893),
  [1323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5680),
  [1326] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5726),
  [1329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5665),
  [1332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8136),
  [1335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8316),
  [1338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8520),
  [1341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(681),
  [1344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9383),
  [1347] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1017),
  [1350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9401),
  [1353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9402),
  [1356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9193),
  [1359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8327),
  [1362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9543),
  [1365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1305),
  [1368] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1172),
  [1371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8649),
  [1374] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8673),
  [1377] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8737),
  [1380] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7346),
  [1383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4873),
  [1386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7941),
  [1389] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7648),
  [1392] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4360),
  [1395] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4396),
  [1398] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2243),
  [1401] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9525),
  [1404] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5813),
  [1407] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8412),
  [1410] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8319),
  [1413] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1253),
  [1416] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1231),
  [1419] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1246),
  [1422] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1553),
  [1425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8466),
  [1428] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1258),
  [1431] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5610),
  [1434] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5961),
  [1437] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9166),
  [1440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 3, 0, 0),
  [1442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 3, 0, 0),
  [1444] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 3, 0, 14),
  [1446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 3, 0, 14),
  [1448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 2, 0, 0),
  [1450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 2, 0, 0),
  [1452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [1454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [1456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(916),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(310),
  [1462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8534),
  [1464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8860),
  [1466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(915),
  [1469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(416),
  [1472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(282),
  [1475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3379),
  [1478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(53),
  [1481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7857),
  [1484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8363),
  [1487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8318),
  [1490] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(683),
  [1493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9433),
  [1496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1015),
  [1499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9548),
  [1502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8822),
  [1505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8653),
  [1508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8372),
  [1511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8853),
  [1514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8366),
  [1517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1145),
  [1520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1147),
  [1523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1564),
  [1526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(916),
  [1529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(367),
  [1532] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(310),
  [1535] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3345),
  [1538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(55),
  [1541] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8207),
  [1544] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8507),
  [1547] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8454),
  [1550] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(668),
  [1553] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9108),
  [1556] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(994),
  [1559] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8615),
  [1562] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8792),
  [1565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8887),
  [1568] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8534),
  [1571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8860),
  [1574] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8495),
  [1577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1179),
  [1580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1180),
  [1583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1582),
  [1586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(908),
  [1588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(320),
  [1590] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(908),
  [1593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(365),
  [1596] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(320),
  [1599] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3292),
  [1602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(47),
  [1605] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8053),
  [1608] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8519),
  [1611] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8475),
  [1614] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(680),
  [1617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8985),
  [1620] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1000),
  [1623] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9078),
  [1626] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9090),
  [1629] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9253),
  [1632] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8238),
  [1635] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9046),
  [1638] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8522),
  [1641] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1188),
  [1644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1169),
  [1647] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1528),
  [1650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [1652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [1656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3371),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [1662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7916),
  [1664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8395),
  [1666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8364),
  [1668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [1670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9445),
  [1672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [1674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8834),
  [1676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8852),
  [1678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8744),
  [1680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8401),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8599),
  [1684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8414),
  [1686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [1688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [1690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1571),
  [1692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(910),
  [1695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(901),
  [1698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(261),
  [1701] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3371),
  [1704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(59),
  [1707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7916),
  [1710] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8395),
  [1713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8364),
  [1716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(675),
  [1719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9445),
  [1722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1009),
  [1725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8834),
  [1728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8852),
  [1731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8744),
  [1734] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8401),
  [1737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8599),
  [1740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8414),
  [1743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1250),
  [1746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1251),
  [1749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1571),
  [1752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [1754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8179),
  [1756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1552),
  [1758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9392),
  [1760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8543),
  [1762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9206),
  [1764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8463),
  [1766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [1768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(316),
  [1772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3375),
  [1774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8362),
  [1776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9396),
  [1778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9091),
  [1780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [1782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5346),
  [1784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8597),
  [1786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [1788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [1790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [1794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [1796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1907),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7150),
  [1800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2629),
  [1802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6871),
  [1804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5705),
  [1806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5708),
  [1808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5712),
  [1810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [1812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [1814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9266),
  [1816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9517),
  [1818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9552),
  [1820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7366),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4275),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8003),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7603),
  [1828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4307),
  [1830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4297),
  [1832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5796),
  [1834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8561),
  [1838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1300),
  [1840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5636),
  [1842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5950),
  [1844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8202),
  [1848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4794),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [1852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1649),
  [1854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [1858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [1860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1344),
  [1862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(918),
  [1866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [1868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7153),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7018),
  [1872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4448),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6280),
  [1876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5482),
  [1878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6868),
  [1880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5687),
  [1882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5688),
  [1884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5689),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [1888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1207),
  [1890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8988),
  [1892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9508),
  [1894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9549),
  [1896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7349),
  [1898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3751),
  [1900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7859),
  [1902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7745),
  [1904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3842),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3809),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2123),
  [1910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8990),
  [1912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5760),
  [1914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3488),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [1918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8536),
  [1920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [1922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5629),
  [1924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5943),
  [1926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_statement, 3, 0, 0),
  [1928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_statement, 3, 0, 0),
  [1930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_statement, 2, 0, 0),
  [1932] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_statement, 2, 0, 0),
  [1934] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 9),
  [1936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, 0, 9),
  [1938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8338),
  [1940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0),
  [1942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0),
  [1944] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8338),
  [1947] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(2387),
  [1950] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(154),
  [1953] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1365),
  [1956] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1353),
  [1959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0),
  [1961] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1353),
  [1964] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1367),
  [1967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3381),
  [1969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0),
  [1971] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7138),
  [1974] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(6267),
  [1977] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7665),
  [1980] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(8609),
  [1983] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(8412),
  [1986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3328),
  [1988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3300),
  [1990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3446),
  [1992] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_try_statement, 4, 0, 46),
  [1994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_try_statement, 4, 0, 46),
  [1996] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_try_statement, 3, 0, 9),
  [1998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_try_statement, 3, 0, 9),
  [2000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1650),
  [2002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6267),
  [2006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 162),
  [2008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 162),
  [2010] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 105),
  [2012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 105),
  [2014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(646),
  [2016] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 51),
  [2018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 3, 0, 51),
  [2020] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_seh_leave_statement, 2, 0, 0),
  [2022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_seh_leave_statement, 2, 0, 0),
  [2024] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 52),
  [2026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 3, 0, 52),
  [2028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 6, 0, 133),
  [2030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 6, 0, 133),
  [2032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 4, 0, 87),
  [2034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 4, 0, 87),
  [2036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_seh_except_clause, 3, 0, 180),
  [2038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_seh_except_clause, 3, 0, 180),
  [2040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_seh_try_statement, 3, 0, 9),
  [2042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_seh_try_statement, 3, 0, 9),
  [2044] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 5, 0, 87),
  [2046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, 0, 87),
  [2048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 0),
  [2050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 0),
  [2052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_seh_finally_clause, 2, 0, 9),
  [2054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_seh_finally_clause, 2, 0, 9),
  [2056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 3, 0, 53),
  [2058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 3, 0, 53),
  [2060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_list, 2, 0, 0),
  [2062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 106),
  [2064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 106),
  [2066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_statement, 3, 0, 55),
  [2068] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_statement, 3, 0, 55),
  [2070] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(2387),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [2075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(1367),
  [2078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [2080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(7138),
  [2083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [2085] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(7665),
  [2088] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(8609),
  [2091] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(8412),
  [2094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 52),
  [2096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 3, 0, 52),
  [2098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [2100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [2102] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(2387),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [2107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(1367),
  [2110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0),
  [2112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(7138),
  [2115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_statement, 1, 0, 0),
  [2117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(7665),
  [2120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(8609),
  [2123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(8412),
  [2126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0),
  [2128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [2130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2134] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 5, 0, 170),
  [2136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 5, 0, 170),
  [2138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [2140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [2142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 2, 0, 0),
  [2144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 2, 0, 0),
  [2146] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_co_return_statement, 2, 0, 0),
  [2148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_co_return_statement, 2, 0, 0),
  [2150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributed_statement, 2, 0, 0),
  [2152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributed_statement, 2, 0, 0),
  [2154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 148),
  [2156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 148),
  [2158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_statement, 5, 0, 149),
  [2164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_statement, 5, 0, 149),
  [2166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [2168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [2170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_co_return_statement, 3, 0, 0),
  [2172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_co_return_statement, 3, 0, 0),
  [2174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_co_yield_statement, 3, 0, 0),
  [2176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_co_yield_statement, 3, 0, 0),
  [2178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 3, 0, 66),
  [2180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 3, 0, 66),
  [2182] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 4, 0, 116),
  [2184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 4, 0, 116),
  [2186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 153),
  [2188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 153),
  [2190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 4, 0, 115),
  [2192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 4, 0, 115),
  [2194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(2387),
  [2197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [2199] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(1367),
  [2202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(7138),
  [2205] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(7665),
  [2208] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(8609),
  [2211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(8412),
  [2214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_range_loop, 5, 0, 154),
  [2216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_range_loop, 5, 0, 154),
  [2218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 5, 0, 133),
  [2220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, 0, 133),
  [2222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 0),
  [2224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [2226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_declaration, 4, 0, 0),
  [2228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_declaration, 4, 0, 0),
  [2230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_method_clause, 3, 0, 0),
  [2232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_method_clause, 3, 0, 0),
  [2234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 172),
  [2236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 172),
  [2238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3044),
  [2240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8798),
  [2242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6351),
  [2244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1957),
  [2246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8689),
  [2248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [2250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6265),
  [2252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8928),
  [2254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8446),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5551),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8865),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2950),
  [2262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5851),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [2266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2673),
  [2268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3383),
  [2270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5996),
  [2272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8909),
  [2274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2639),
  [2276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2347),
  [2278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6793),
  [2280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5690),
  [2282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5691),
  [2284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5692),
  [2286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5793),
  [2288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7601),
  [2290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1668),
  [2292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9258),
  [2294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7034),
  [2296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9463),
  [2298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1852),
  [2300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [2302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1770),
  [2304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1772),
  [2308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [2310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1780),
  [2312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 3, 0, 67),
  [2314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 67),
  [2316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pure_virtual_clause, 3, 0, 0),
  [2318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pure_virtual_clause, 3, 0, 0),
  [2320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_declaration, 5, 0, 177),
  [2322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_declaration, 5, 0, 177),
  [2324] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 6, 0, 178),
  [2326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 6, 0, 178),
  [2328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_method_clause, 3, 0, 0),
  [2330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_method_clause, 3, 0, 0),
  [2332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 69),
  [2334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 69),
  [2336] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8504),
  [2339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 77),
  [2341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 77),
  [2343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 5),
  [2345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 5),
  [2347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_declaration, 3, 0, 5),
  [2349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_declaration, 3, 0, 5),
  [2351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_definition, 3, 0, 77),
  [2353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_definition, 3, 0, 77),
  [2355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2079),
  [2357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [2359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2104),
  [2361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1982),
  [2363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [2365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1928),
  [2367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [2369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1930),
  [2371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1964),
  [2373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_def, 4, 0, 78),
  [2375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_def, 4, 0, 78),
  [2377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 5, 0, 138),
  [2379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 5, 0, 138),
  [2381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2055),
  [2383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_declaration, 6, 0, 197),
  [2385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_declaration, 6, 0, 197),
  [2387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_function_def, 4, 0, 79),
  [2389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_function_def, 4, 0, 79),
  [2391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elifdef_in_field_declaration_list, 2, 0, 10),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [2395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 4, 0, 80),
  [2397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 4, 0, 80),
  [2399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif_in_field_declaration_list, 3, 0, 80),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [2403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elifdef_in_field_declaration_list, 3, 0, 10),
  [2405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif_in_field_declaration_list, 4, 0, 80),
  [2407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3373),
  [2409] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__block_item, 1, 0, 0), REDUCE(sym_statement, 1, 0, 0),
  [2412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__block_item, 1, 0, 0), REDUCE(sym_statement, 1, 0, 0),
  [2415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_static_assert_declaration, 7, 0, 208),
  [2417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_static_assert_declaration, 7, 0, 208),
  [2419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 4, 0, 81),
  [2421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 4, 0, 81),
  [2423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 5, 0, 139),
  [2425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 5, 0, 139),
  [2427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 4, 0, 10),
  [2429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 4, 0, 10),
  [2431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_declaration, 4, 0, 123),
  [2433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_declaration, 4, 0, 123),
  [2435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 4, 0, 127),
  [2437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 4, 0, 127),
  [2439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 4, 0, 94),
  [2441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 4, 0, 94),
  [2443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 4, 0, 95),
  [2445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 4, 0, 95),
  [2447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_function_def, 5, 0, 128),
  [2449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_function_def, 5, 0, 128),
  [2451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 4, 0, 96),
  [2453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 4, 0, 96),
  [2455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8382),
  [2457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, 0, 129),
  [2459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, 0, 129),
  [2461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8222),
  [2463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_declaration, 3, 0, 0),
  [2465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_declaration, 3, 0, 0),
  [2467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_declaration, 2, 0, 26),
  [2469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_declaration, 2, 0, 26),
  [2471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, 0, 80),
  [2473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, 0, 80),
  [2475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 5, 0, 130),
  [2477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 5, 0, 130),
  [2479] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8222),
  [2482] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8382),
  [2485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_friend_declaration, 3, 0, 0),
  [2487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_friend_declaration, 3, 0, 0),
  [2489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call, 2, 0, 3),
  [2491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call, 2, 0, 3),
  [2493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_declaration, 3, 0, 5),
  [2495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_declaration, 3, 0, 5),
  [2497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_friend_declaration, 4, 0, 0),
  [2499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_friend_declaration, 4, 0, 0),
  [2501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_friend_declaration, 5, 0, 0),
  [2503] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_friend_declaration, 5, 0, 0),
  [2505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 2, 0, 9),
  [2507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 2, 0, 9),
  [2509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_instantiation, 3, 0, 5),
  [2511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_instantiation, 3, 0, 5),
  [2513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 2, 0, 25),
  [2515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 2, 0, 25),
  [2517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 2, 0, 26),
  [2519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 2, 0, 26),
  [2521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__empty_declaration, 2, 0, 0),
  [2523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__empty_declaration, 2, 0, 0),
  [2525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_declaration, 2, 0, 26),
  [2527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_declaration, 2, 0, 26),
  [2529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_definition, 2, 0, 25),
  [2531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_definition, 2, 0, 25),
  [2533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_declaration, 3, 0, 57),
  [2535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_declaration, 3, 0, 57),
  [2537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_include, 3, 0, 37),
  [2539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_include, 3, 0, 37),
  [2541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_def, 3, 0, 10),
  [2543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_def, 3, 0, 10),
  [2545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 3, 0, 10),
  [2547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 3, 0, 10),
  [2549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call, 3, 0, 38),
  [2551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call, 3, 0, 38),
  [2553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_linkage_specification, 3, 0, 44),
  [2555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_linkage_specification, 3, 0, 44),
  [2557] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_instantiation, 4, 0, 58),
  [2559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_instantiation, 4, 0, 58),
  [2561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 3, 0, 46),
  [2563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 3, 0, 46),
  [2565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_declaration, 4, 0, 57),
  [2567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_declaration, 4, 0, 57),
  [2569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_alias_definition, 5, 0, 163),
  [2571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_alias_definition, 5, 0, 163),
  [2573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 118),
  [2575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 118),
  [2577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_list, 3, 0, 0),
  [2579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_list, 3, 0, 0),
  [2581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_alias_definition, 5, 0, 164),
  [2583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_alias_definition, 5, 0, 164),
  [2585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 113),
  [2587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 113),
  [2589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8504),
  [2591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_list, 2, 0, 0),
  [2593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_list, 2, 0, 0),
  [2595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_declaration, 5, 0, 165),
  [2597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_declaration, 5, 0, 165),
  [2599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 3, 0, 60),
  [2601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 3, 0, 60),
  [2603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3377),
  [2605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_static_assert_declaration, 5, 0, 166),
  [2607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_static_assert_declaration, 5, 0, 166),
  [2609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 3, 0, 48),
  [2611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 3, 0, 48),
  [2613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concept_definition, 5, 0, 10),
  [2615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concept_definition, 5, 0, 10),
  [2617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_friend_declaration, 2, 0, 0),
  [2619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_friend_declaration, 2, 0, 0),
  [2621] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(2438),
  [2624] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1262),
  [2627] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7150),
  [2630] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7518),
  [2633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 4, 0, 45),
  [2635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 4, 0, 45),
  [2637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1513),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [2641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1493),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7175),
  [2645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [2647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7608),
  [2649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1240),
  [2651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9209),
  [2653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9511),
  [2655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9550),
  [2657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7360),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3146),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8041),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7586),
  [2665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2817),
  [2667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2800),
  [2669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8609),
  [2671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1432),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8558),
  [2675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [2677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5607),
  [2679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5957),
  [2681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(682),
  [2683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [2685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(638),
  [2687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2166),
  [2689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1395),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [2693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7166),
  [2697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3222),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7918),
  [2703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7628),
  [2705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1437),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8553),
  [2709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1438),
  [2711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5608),
  [2713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2373),
  [2715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1511),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [2719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1469),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7165),
  [2723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1225),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3466),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8039),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7562),
  [2731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1389),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8573),
  [2735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [2737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3044),
  [2740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8798),
  [2743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6351),
  [2746] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0),
  [2748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8689),
  [2751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8446),
  [2754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5551),
  [2757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8865),
  [2760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2950),
  [2763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5851),
  [2766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5851),
  [2769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(433),
  [2772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2673),
  [2775] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3383),
  [2778] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2708),
  [2781] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2721),
  [2784] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9423),
  [2787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5996),
  [2790] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8362),
  [2793] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8650),
  [2796] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8551),
  [2799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2190),
  [2802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8909),
  [2805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1719),
  [2808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2639),
  [2811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9080),
  [2814] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2347),
  [2817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6793),
  [2820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5690),
  [2823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5691),
  [2826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5692),
  [2829] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2243),
  [2832] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9525),
  [2835] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3765),
  [2838] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5793),
  [2841] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7601),
  [2844] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(801),
  [2847] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1668),
  [2850] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9258),
  [2853] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7034),
  [2856] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9463),
  [2859] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9166),
  [2862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1652),
  [2864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [2866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [2868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1434),
  [2870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [2872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7143),
  [2876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4515),
  [2878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5337),
  [2880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6819),
  [2882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5701),
  [2884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5755),
  [2886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5702),
  [2888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [2890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [2892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9244),
  [2894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9514),
  [2896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9551),
  [2898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7363),
  [2900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5415),
  [2902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7979),
  [2904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7540),
  [2906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5512),
  [2908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5506),
  [2910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2610),
  [2912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9268),
  [2914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5765),
  [2916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [2918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [2920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8560),
  [2922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [2924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5623),
  [2926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5962),
  [2928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [2930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1999),
  [2932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2435),
  [2934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1453),
  [2936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [2938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7756),
  [2940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [2942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2305),
  [2944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [2946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [2948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2396),
  [2950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [2952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4545),
  [2954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7039),
  [2956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4073),
  [2958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [2960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [2962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3115),
  [2964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3129),
  [2966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2981),
  [2968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4586),
  [2970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4030),
  [2972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2432),
  [2974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1367),
  [2976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7665),
  [2978] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2420),
  [2981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(154),
  [2984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1365),
  [2987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1365),
  [2990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1353),
  [2993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(200),
  [2996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1367),
  [2999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7138),
  [3002] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8315),
  [3005] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(43),
  [3008] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(6267),
  [3011] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7665),
  [3014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8136),
  [3017] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8316),
  [3020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1563),
  [3023] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8595),
  [3026] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8520),
  [3029] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(681),
  [3032] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9383),
  [3035] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1017),
  [3038] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9401),
  [3041] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9402),
  [3044] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9193),
  [3047] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8327),
  [3050] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9543),
  [3053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1305),
  [3056] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1172),
  [3059] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8649),
  [3062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8673),
  [3065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8737),
  [3068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7346),
  [3071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(4873),
  [3074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7941),
  [3077] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7648),
  [3080] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(4360),
  [3083] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(4396),
  [3086] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8609),
  [3089] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8412),
  [3092] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8319),
  [3095] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1253),
  [3098] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1231),
  [3101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1246),
  [3104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1553),
  [3107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8466),
  [3110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1258),
  [3113] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5610),
  [3116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5961),
  [3119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2461),
  [3121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2452),
  [3123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2371),
  [3125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(906),
  [3127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4537),
  [3129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4239),
  [3131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4245),
  [3133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8984),
  [3135] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2431),
  [3138] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(416),
  [3141] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(53),
  [3144] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7857),
  [3147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8363),
  [3150] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1570),
  [3153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8811),
  [3156] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8318),
  [3159] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(683),
  [3162] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9433),
  [3165] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1015),
  [3168] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9548),
  [3171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8822),
  [3174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8653),
  [3177] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8372),
  [3180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8853),
  [3183] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8366),
  [3186] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1145),
  [3189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1147),
  [3192] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1564),
  [3195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2420),
  [3197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2431),
  [3199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2607),
  [3201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1480),
  [3203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [3205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1439),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7147),
  [3209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [3211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7667),
  [3213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [3215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9305),
  [3217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9523),
  [3219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9554),
  [3221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7373),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4002),
  [3225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8031),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7722),
  [3229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4040),
  [3231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4038),
  [3233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [3235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8565),
  [3237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1319),
  [3239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5645),
  [3241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5953),
  [3243] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2461),
  [3246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(365),
  [3249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(47),
  [3252] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8053),
  [3255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8519),
  [3258] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1526),
  [3261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9068),
  [3264] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8475),
  [3267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(680),
  [3270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8985),
  [3273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1000),
  [3276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9078),
  [3279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9090),
  [3282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9253),
  [3285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8238),
  [3288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9046),
  [3291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8522),
  [3294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1188),
  [3297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1169),
  [3300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1528),
  [3303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2440),
  [3305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2432),
  [3308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(55),
  [3311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8179),
  [3314] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8507),
  [3317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1552),
  [3320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9392),
  [3323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8543),
  [3326] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(668),
  [3329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9206),
  [3332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(994),
  [3335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8615),
  [3338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8792),
  [3341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8887),
  [3344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8463),
  [3347] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8495),
  [3350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1179),
  [3353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1180),
  [3356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1582),
  [3359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2578),
  [3361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1504),
  [3363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [3365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1456),
  [3367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7139),
  [3369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [3371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7589),
  [3373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [3375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9324),
  [3377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9526),
  [3379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9555),
  [3381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7375),
  [3383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [3385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8035),
  [3387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7563),
  [3389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4193),
  [3391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4192),
  [3393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1325),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8568),
  [3397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1326),
  [3399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5622),
  [3401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5947),
  [3403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1597),
  [3405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [3407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1625),
  [3409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7172),
  [3411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [3413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [3415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1637),
  [3417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2377),
  [3419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [3421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [3423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [3425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [3427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2452),
  [3430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(367),
  [3433] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8207),
  [3436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1577),
  [3439] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8680),
  [3442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8454),
  [3445] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9108),
  [3448] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8534),
  [3451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8860),
  [3454] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2440),
  [3457] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(901),
  [3460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(59),
  [3463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7916),
  [3466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8395),
  [3469] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8364),
  [3472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(675),
  [3475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(9445),
  [3478] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1009),
  [3481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8834),
  [3484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8852),
  [3487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8744),
  [3490] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8401),
  [3493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8599),
  [3496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8414),
  [3499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1250),
  [3502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1251),
  [3505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1571),
  [3508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1655),
  [3510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [3512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5520),
  [3514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__top_level_expression_statement, 2, 0, 0),
  [3516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__top_level_expression_statement, 2, 0, 0),
  [3518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__top_level_expression_statement, 1, 0, 0),
  [3520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__top_level_expression_statement, 1, 0, 0),
  [3522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__top_level_item, 1, 0, 0), REDUCE(sym__top_level_statement, 1, 0, 0),
  [3525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__top_level_item, 1, 0, 0), REDUCE(sym__top_level_statement, 1, 0, 0),
  [3528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8643),
  [3530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6271),
  [3532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8778),
  [3534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8546),
  [3536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [3538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2634),
  [3540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3365),
  [3542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [3544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2658),
  [3546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7646),
  [3548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1684),
  [3550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7065),
  [3552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9446),
  [3554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2438),
  [3556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1262),
  [3558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [3560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7518),
  [3562] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8849),
  [3565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6367),
  [3568] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9466),
  [3571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8234),
  [3574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(773),
  [3577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2685),
  [3580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3385),
  [3583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2644),
  [3586] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7622),
  [3589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1671),
  [3592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7038),
  [3595] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9470),
  [3598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [3600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2229),
  [3602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [3604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [3606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2152),
  [3608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [3610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2242),
  [3612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8849),
  [3614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6367),
  [3616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else_in_field_declaration_list, 1, 0, 0),
  [3618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9466),
  [3620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8234),
  [3622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [3624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2685),
  [3626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3385),
  [3628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2644),
  [3630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7622),
  [3632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1671),
  [3634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7038),
  [3636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9470),
  [3638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [3640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3174),
  [3642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3167),
  [3644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [3646] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else_in_field_declaration_list, 2, 0, 0),
  [3648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [3650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [3652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [3654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [3656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [3658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [3660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3483),
  [3662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [3664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4768),
  [3666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4825),
  [3668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [3670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4879),
  [3672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4895),
  [3674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [3676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [3678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5212),
  [3680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5153),
  [3682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [3684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3235),
  [3686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3226),
  [3688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8643),
  [3691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6271),
  [3694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8778),
  [3697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8546),
  [3700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(796),
  [3703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2634),
  [3706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3365),
  [3709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0),
  [3711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2658),
  [3714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7646),
  [3717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1684),
  [3720] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7065),
  [3723] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(9446),
  [3726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [3728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4496),
  [3730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4512),
  [3732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [3734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [3736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2848),
  [3738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [3740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3679),
  [3742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1906),
  [3744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7232),
  [3746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2354),
  [3748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2640),
  [3750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6820),
  [3752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5703),
  [3754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5704),
  [3756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5707),
  [3758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5824),
  [3760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3496),
  [3762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8808),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6464),
  [3766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6464),
  [3768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6437),
  [3770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9318),
  [3772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1509),
  [3774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [3776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [3778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7151),
  [3780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [3782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1186),
  [3784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4747),
  [3786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8038),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7649),
  [3790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1398),
  [3792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8555),
  [3794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1399),
  [3796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5611),
  [3798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5969),
  [3800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2387),
  [3802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2390),
  [3804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [3806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [3808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1350),
  [3810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7132),
  [3812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [3814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5231),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8037),
  [3818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7547),
  [3820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1347),
  [3822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8572),
  [3824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1348),
  [3826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_declaration, 4, 0, 0),
  [3828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_declaration, 4, 0, 0),
  [3830] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_declaration, 3, 0, 0),
  [3832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_declaration, 3, 0, 0),
  [3834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2443),
  [3836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6006),
  [3838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9459),
  [3840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9456),
  [3842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6016),
  [3844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2635),
  [3846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7566),
  [3848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1686),
  [3850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9450),
  [3852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2643),
  [3854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7614),
  [3856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1678),
  [3858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9467),
  [3860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9474),
  [3862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9464),
  [3864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2692),
  [3866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7538),
  [3868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1680),
  [3870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9028),
  [3872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9479),
  [3874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9471),
  [3876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2626),
  [3878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7652),
  [3880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1673),
  [3882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9439),
  [3884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2594),
  [3886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1592),
  [3888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [3890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1529),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7133),
  [3894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1216),
  [3896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [3898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1595),
  [3900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5628),
  [3902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2576),
  [3904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1421),
  [3906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [3908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7515),
  [3910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2502),
  [3912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1467),
  [3914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [3916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1377),
  [3918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7167),
  [3920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [3922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7524),
  [3924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1152),
  [3926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9286),
  [3928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9520),
  [3930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9553),
  [3932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7370),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5400),
  [3936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8024),
  [3938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7647),
  [3940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5429),
  [3942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5425),
  [3944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [3946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8563),
  [3948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1311),
  [3950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5632),
  [3952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5944),
  [3954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2605),
  [3956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [3958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [3960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1642),
  [3962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7157),
  [3964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1229),
  [3966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1616),
  [3968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1617),
  [3970] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(2435),
  [3973] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1453),
  [3976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7153),
  [3979] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7756),
  [3982] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(2576),
  [3985] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1421),
  [3988] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7143),
  [3991] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7515),
  [3994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_pack_expansion, 2, 0, 28),
  [3996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [3998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_pack_expansion, 2, 0, 28),
  [4000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1615),
  [4002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_specifier, 1, 0, 1),
  [4004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [4006] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_type_specifier, 1, 0, 1), REDUCE(sym_expression, 1, 0, 0),
  [4010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 1),
  [4012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [4014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_specifier, 1, 0, 1), REDUCE(sym_expression, 1, 0, 0),
  [4017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 1), REDUCE(sym_expression, 1, 0, 0),
  [4020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(490),
  [4023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7257),
  [4025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_type_specifier, 1, 0, 1),
  [4028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_name, 1, 0, 1),
  [4030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2323),
  [4032] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_type_specifier, 1, 0, 1), REDUCE(sym_expression, 1, 0, 0),
  [4036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [4038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [4040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [4042] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__declaration_modifiers, 1, 0, 0), REDUCE(aux_sym_attributed_declarator_repeat1, 1, 0, 0),
  [4045] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declaration_modifiers, 1, 0, 0), REDUCE(aux_sym_attributed_declarator_repeat1, 1, 0, 0),
  [4048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 1, 0, 0),
  [4050] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 1, 0, 0),
  [4052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_modifiers, 1, 0, 0),
  [4054] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_modifiers, 1, 0, 0),
  [4056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [4058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8422),
  [4060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [4062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8422),
  [4065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [4067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [4069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [4071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2459),
  [4073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [4075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(909),
  [4077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2171),
  [4079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(864),
  [4081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6659),
  [4083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9265),
  [4085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [4087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(842),
  [4089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6605),
  [4091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [4093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [4095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6412),
  [4097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [4099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [4101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3877),
  [4103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [4105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1895),
  [4107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7014),
  [4109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [4111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6580),
  [4113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [4115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [4117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [4119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(855),
  [4121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2597),
  [4123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [4125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(863),
  [4127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6611),
  [4129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [4131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [4133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [4135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6375),
  [4137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [4139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [4141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3982),
  [4143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [4145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [4147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6425),
  [4149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [4151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [4153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6586),
  [4155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [4157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4012),
  [4159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [4161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2600),
  [4163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [4165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(841),
  [4167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7023),
  [4169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(662),
  [4171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [4173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [4175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3686),
  [4177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [4179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6408),
  [4181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [4183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6691),
  [4185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [4187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6677),
  [4189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [4191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6601),
  [4193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2700),
  [4195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4499),
  [4197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [4199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [4201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5403),
  [4203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5403),
  [4205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6286),
  [4207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [4209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(152),
  [4212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1344),
  [4215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1281),
  [4218] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1281),
  [4221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(6267),
  [4224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(2166),
  [4227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(155),
  [4230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1395),
  [4233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1282),
  [4236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7166),
  [4239] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(2605),
  [4242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(177),
  [4245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1614),
  [4248] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1614),
  [4251] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1642),
  [4254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7157),
  [4257] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1615),
  [4260] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1229),
  [4263] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(8649),
  [4266] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(8673),
  [4269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(8737),
  [4272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7346),
  [4275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(4873),
  [4278] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7941),
  [4281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(7648),
  [4284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(4360),
  [4287] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(4396),
  [4290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1616),
  [4293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(8466),
  [4296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(1617),
  [4299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(5628),
  [4302] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0), SHIFT(5961),
  [4305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(116),
  [4307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(113),
  [4309] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(598),
  [4312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [4314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7749),
  [4316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8567),
  [4318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3066),
  [4320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [4322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4162),
  [4324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7158),
  [4326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4104),
  [4328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3683),
  [4330] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 2, 0, 0),
  [4332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 2, 0, 0),
  [4334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2417),
  [4336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9448),
  [4338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4230),
  [4340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [4342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [4344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [4346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6211),
  [4348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6064),
  [4350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 4, 1, 0),
  [4352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 4, 1, 0),
  [4354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4181),
  [4356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 4, 3, 0),
  [4358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 4, 3, 0),
  [4360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9112),
  [4362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4418),
  [4364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4202),
  [4366] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 4, 2, 0),
  [4368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 4, 2, 0),
  [4370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6506),
  [4372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3903),
  [4374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9077),
  [4376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5422),
  [4378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6497),
  [4380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4382),
  [4382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4858),
  [4384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4350),
  [4386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4875),
  [4388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9155),
  [4390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5517),
  [4392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8818),
  [4394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [4396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 3, 1, 0),
  [4398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 3, 1, 0),
  [4400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4266),
  [4402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 3, 3, 0),
  [4404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 3, 3, 0),
  [4406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5467),
  [4408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 3, 2, 0),
  [4410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 3, 2, 0),
  [4412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4013),
  [4414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(2387),
  [4417] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(154),
  [4420] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [4423] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [4426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1353),
  [4429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(3066),
  [4432] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1367),
  [4435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7138),
  [4438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1623),
  [4441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0),
  [4443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(6267),
  [4446] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7665),
  [4449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1305),
  [4452] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1172),
  [4455] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8649),
  [4458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8673),
  [4461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8737),
  [4464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7346),
  [4467] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(4873),
  [4470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7941),
  [4473] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7648),
  [4476] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(4360),
  [4479] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(4396),
  [4482] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8609),
  [4485] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7158),
  [4488] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8412),
  [4491] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1253),
  [4494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8466),
  [4497] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1258),
  [4500] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(5610),
  [4503] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(5961),
  [4506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5491),
  [4508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [4510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [4512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35),
  [4514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_identifier, 2, 0, 34),
  [4516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_qualified_identifier, 2, 0, 34), REDUCE(sym_qualified_type_identifier, 2, 0, 35),
  [4519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35),
  [4521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34),
  [4523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), REDUCE(sym_qualified_type_identifier, 2, 0, 35),
  [4526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(560),
  [4529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8991),
  [4531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4082),
  [4533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9133),
  [4535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2773),
  [4537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4279),
  [4539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2834),
  [4541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5539),
  [4543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4399),
  [4545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4349),
  [4547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [4549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [4551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3806),
  [4553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_type, 2, 0, 16),
  [4555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_function, 2, 0, 17),
  [4557] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_template_type, 2, 0, 16), REDUCE(sym_template_function, 2, 0, 17),
  [4560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_type, 2, 0, 16),
  [4562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_function, 2, 0, 17),
  [4564] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_template_type, 2, 0, 16), REDUCE(sym_template_function, 2, 0, 17),
  [4567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [4569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4282),
  [4571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5538),
  [4573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5499),
  [4575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4177),
  [4577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4132),
  [4579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4229),
  [4581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5432),
  [4583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4186),
  [4585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2547),
  [4587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8814),
  [4589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [4591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [4593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7321),
  [4595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8439),
  [4597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5533),
  [4599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2426),
  [4601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2680),
  [4603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [4605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4472),
  [4607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6683),
  [4609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6683),
  [4611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7199),
  [4613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [4615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2963),
  [4617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [4619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6270),
  [4621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [4623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4363),
  [4625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [4627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4161),
  [4629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [4631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [4633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8581),
  [4635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [4637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [4639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8611),
  [4641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [4643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8763),
  [4645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [4647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8766),
  [4649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [4651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2811),
  [4653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4703),
  [4655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [4657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5516),
  [4659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [4661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5449),
  [4663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [4665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3880),
  [4667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [4669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2509),
  [4671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9500),
  [4673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_default_capture, 1, 0, 0),
  [4675] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(530),
  [4678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9200),
  [4680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1189),
  [4682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9214),
  [4684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 2, 0, 0),
  [4686] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 2, 0, 0),
  [4688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [4690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [4692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9074),
  [4695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9075),
  [4698] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9079),
  [4701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [4703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [4705] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9094),
  [4708] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9097),
  [4711] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9098),
  [4714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4052),
  [4716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9102),
  [4719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [4721] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9110),
  [4724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9058),
  [4727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9123),
  [4730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2313),
  [4732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [4734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [4736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [4738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [4740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4197),
  [4742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [4744] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9120),
  [4747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [4749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [4751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1393),
  [4753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [4755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [4757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8804),
  [4760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 4, 1, 190),
  [4762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [4764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1548),
  [4766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1280),
  [4768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [4770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1370),
  [4772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [4774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [4776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [4778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [4780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [4782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [4784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 80),
  [4786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 152),
  [4788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [4790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1419),
  [4792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [4794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1335),
  [4796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1546),
  [4798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1612),
  [4800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1322),
  [4802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [4804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 107),
  [4806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1640),
  [4808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 2, 1, 0),
  [4810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 2, 1, 107),
  [4812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1323),
  [4814] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8828),
  [4817] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9208),
  [4820] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9212),
  [4823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9251),
  [4825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [4827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8824),
  [4830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [4832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [4834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [4836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6656),
  [4838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6600),
  [4840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9310),
  [4842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [4844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6692),
  [4846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9291),
  [4848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [4850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8830),
  [4853] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8832),
  [4856] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8837),
  [4859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8850),
  [4862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8861),
  [4865] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8913),
  [4868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6177),
  [4870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8952),
  [4873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9086),
  [4875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8782),
  [4877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [4879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2614),
  [4881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [4883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7012),
  [4885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [4887] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9042),
  [4890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6693),
  [4892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6396),
  [4894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6414),
  [4896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8916),
  [4899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [4901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [4903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6631),
  [4905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9145),
  [4907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3718),
  [4909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9005),
  [4912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [4914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9038),
  [4917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [4919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [4921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6292),
  [4923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9457),
  [4925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9328),
  [4927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [4929] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8918),
  [4932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9293),
  [4934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4011),
  [4936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9180),
  [4938] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9039),
  [4941] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9040),
  [4944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8617),
  [4946] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9202),
  [4949] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8937),
  [4952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8618),
  [4954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9192),
  [4956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7013),
  [4958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9008),
  [4960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [4962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8742),
  [4964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1917),
  [4966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8945),
  [4969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9472),
  [4971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8704),
  [4973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [4975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9124),
  [4978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9198),
  [4981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3981),
  [4983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9221),
  [4985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [4987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [4989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6690),
  [4991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3705),
  [4993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [4995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [4997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [4999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6439),
  [5001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6610),
  [5003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3869),
  [5005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [5007] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9199),
  [5010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6443),
  [5012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6653),
  [5014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [5016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [5018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [5020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9272),
  [5022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [5024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [5026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [5028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8978),
  [5030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6293),
  [5032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6277),
  [5034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6296),
  [5036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6298),
  [5038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6315),
  [5040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6220),
  [5042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6222),
  [5044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4212),
  [5046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6228),
  [5048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6230),
  [5050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2392),
  [5052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6244),
  [5054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6245),
  [5056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6261),
  [5058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6263),
  [5060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6269),
  [5062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2391),
  [5064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6295),
  [5066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6268),
  [5068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6276),
  [5070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2379),
  [5072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6319),
  [5074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6321),
  [5076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6275),
  [5078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6281),
  [5080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6258),
  [5082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6350),
  [5084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6360),
  [5086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6349),
  [5088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6366),
  [5090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6365),
  [5092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6371),
  [5094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6218),
  [5096] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(530),
  [5099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declarator, 1, 0, 0),
  [5101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2201),
  [5103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7650),
  [5105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8557),
  [5107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(579),
  [5110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0),
  [5112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0),
  [5114] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1656),
  [5117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9323),
  [5120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(591),
  [5123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [5125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [5127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [5129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7736),
  [5131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8566),
  [5133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0),
  [5135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0),
  [5137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1654),
  [5140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(549),
  [5143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alignas_qualifier, 4, 0, 0),
  [5145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alignas_qualifier, 4, 0, 0),
  [5147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2462),
  [5149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7200),
  [5151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [5153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [5155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(2586),
  [5158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 1, 0, 0),
  [5160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0),
  [5162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [5164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1706),
  [5166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9323),
  [5168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2585),
  [5170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(2617),
  [5173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, 0, 0),
  [5175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0),
  [5177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2480),
  [5179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2616),
  [5181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [5183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [5185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2674),
  [5187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1710),
  [5189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2659),
  [5191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2633),
  [5193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2637),
  [5195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2684),
  [5197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2458),
  [5199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5662),
  [5201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5663),
  [5203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5664),
  [5205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5666),
  [5207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5667),
  [5209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5668),
  [5211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5669),
  [5213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5670),
  [5215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5671),
  [5217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5653),
  [5219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5654),
  [5221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5655),
  [5223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5681),
  [5225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5682),
  [5227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5683),
  [5229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5684),
  [5231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5685),
  [5233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5686),
  [5235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5752),
  [5237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5753),
  [5239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5754),
  [5241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5650),
  [5243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5651),
  [5245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5652),
  [5247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5674),
  [5249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5675),
  [5251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5676),
  [5253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5677),
  [5255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5678),
  [5257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5679),
  [5259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5723),
  [5261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5724),
  [5263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5725),
  [5265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5733),
  [5267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5656),
  [5269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5658),
  [5271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5659),
  [5273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5660),
  [5275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5661),
  [5277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5730),
  [5279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5731),
  [5281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5732),
  [5283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 3, 0, 74),
  [5285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, 0, 74),
  [5287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fold_expression, 3, 0, 40),
  [5289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fold_expression, 3, 0, 40),
  [5291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 4, 0, 126),
  [5293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, 0, 126),
  [5295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requirement_seq, 2, 0, 0),
  [5297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requirement_seq, 2, 0, 0),
  [5299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requires_expression, 3, 0, 65),
  [5301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_expression, 3, 0, 65),
  [5303] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 2, 0, 32),
  [5305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 2, 0, 32),
  [5307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 3, 0, 73),
  [5309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, 0, 73),
  [5311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 4, 0, 125),
  [5313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, 0, 125),
  [5315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constraint_conjunction, 3, 0, 54),
  [5317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_conjunction, 3, 0, 54),
  [5319] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1719),
  [5322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9080),
  [5325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 5, 0, 176),
  [5327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 5, 0, 176),
  [5329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requires_expression, 2, 0, 21),
  [5331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_expression, 2, 0, 21),
  [5333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requirement_seq, 3, 0, 0),
  [5335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requirement_seq, 3, 0, 0),
  [5337] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__requirement_clause_constraint, 3, 0, 0),
  [5339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__requirement_clause_constraint, 3, 0, 0),
  [5341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5560),
  [5343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5577),
  [5345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7671),
  [5347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7347),
  [5349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2221),
  [5351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0),
  [5354] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0),
  [5357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2853),
  [5359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1737),
  [5361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2855),
  [5363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9304),
  [5365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2846),
  [5367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2868),
  [5369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1729),
  [5371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2867),
  [5373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2925),
  [5375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1763),
  [5377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1736),
  [5379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9364),
  [5381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2951),
  [5383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2924),
  [5385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1754),
  [5387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1743),
  [5389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9357),
  [5391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2916),
  [5393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2953),
  [5395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2962),
  [5397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2949),
  [5399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1737),
  [5402] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9304),
  [5405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2961),
  [5407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2935),
  [5409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2959),
  [5411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1754),
  [5414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9357),
  [5417] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1763),
  [5420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9364),
  [5423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7766),
  [5425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3920),
  [5427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3028),
  [5429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1886),
  [5431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3029),
  [5433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9347),
  [5435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3027),
  [5437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8125),
  [5439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3702),
  [5441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3056),
  [5443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1844),
  [5445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3051),
  [5447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8438),
  [5449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7876),
  [5451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3900),
  [5453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7869),
  [5455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2735),
  [5457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1734),
  [5460] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8438),
  [5463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1741),
  [5466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1873),
  [5469] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9243),
  [5472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1886),
  [5475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9347),
  [5478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8231),
  [5480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1744),
  [5483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7209),
  [5485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2630),
  [5487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2701),
  [5489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2663),
  [5491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8981),
  [5493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6126),
  [5495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8517),
  [5497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8983),
  [5499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9205),
  [5501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8993),
  [5503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_list, 2, 0, 0),
  [5505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_field_declaration_list, 4, 0, 80),
  [5507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_field_declaration_list, 4, 0, 80),
  [5509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 4, 0, 81),
  [5511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 4, 0, 81),
  [5513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 4, 0, 10),
  [5515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 4, 0, 10),
  [5517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, 0, 66),
  [5519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 66),
  [5521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, 0, 182),
  [5523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 182),
  [5525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, 0, 183),
  [5527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 183),
  [5529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_field_declaration_list, 5, 0, 129),
  [5531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_field_declaration_list, 5, 0, 129),
  [5533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_field_declaration_list, 5, 0, 80),
  [5535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_field_declaration_list, 5, 0, 80),
  [5537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 5, 0, 130),
  [5539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 5, 0, 130),
  [5541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 196),
  [5543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 196),
  [5545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 66),
  [5547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 66),
  [5549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 200),
  [5551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 200),
  [5553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 182),
  [5555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 182),
  [5557] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 201),
  [5559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 201),
  [5561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 183),
  [5563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 183),
  [5565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_field_declaration_list, 6, 0, 178),
  [5567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_field_declaration_list, 6, 0, 178),
  [5569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 6, 0, 196),
  [5571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 6, 0, 196),
  [5573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 6, 0, 210),
  [5575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 6, 0, 210),
  [5577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 6, 0, 200),
  [5579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 6, 0, 200),
  [5581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 6, 0, 201),
  [5583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 6, 0, 201),
  [5585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 7, 0, 210),
  [5587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 7, 0, 210),
  [5589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 2, 0, 56),
  [5591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 56),
  [5593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__field_declaration_list_item, 2, 0, 0),
  [5595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_declaration_list_item, 2, 0, 0),
  [5597] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1846),
  [5600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1845),
  [5603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 3, 0, 10),
  [5605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 3, 0, 10),
  [5607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 56),
  [5609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 56),
  [5611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 66),
  [5613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 66),
  [5615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_method_definition, 3, 0, 67),
  [5617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_method_definition, 3, 0, 67),
  [5619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_method_definition, 3, 0, 66),
  [5621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_method_definition, 3, 0, 66),
  [5623] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8405),
  [5626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8405),
  [5628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_specifier, 4, 0, 0),
  [5630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_specifier, 4, 0, 0),
  [5632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8447),
  [5634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8447),
  [5637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0),
  [5639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0),
  [5641] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(2171),
  [5644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(1895),
  [5647] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(9265),
  [5650] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1902),
  [5653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2730),
  [5655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decltype, 4, 0, 0),
  [5657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decltype, 4, 0, 0),
  [5659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 34),
  [5661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_type_identifier, 2, 0, 34),
  [5663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7262),
  [5665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dependent_type_identifier, 2, 0, 0),
  [5667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dependent_type_identifier, 2, 0, 0),
  [5669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_name, 1, 0, 1),
  [5671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [5673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dependent_type, 2, -1, 0),
  [5675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dependent_type, 2, -1, 0),
  [5677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2160),
  [5679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9516),
  [5681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(579),
  [5684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_specifier, 1, 0, 0),
  [5686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 0),
  [5688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_name, 1, 0, 0),
  [5690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_name, 1, 0, 0),
  [5692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 9),
  [5694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 9),
  [5696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration, 3, 0, 103),
  [5698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration, 3, 0, 103),
  [5700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2203),
  [5702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1873),
  [5704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2205),
  [5706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9243),
  [5708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2197),
  [5710] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator_list, 4, 0, 0),
  [5712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator_list, 4, 0, 0),
  [5714] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator_list, 3, 0, 0),
  [5716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator_list, 3, 0, 0),
  [5718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 5, 0, 144),
  [5720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 5, 0, 144),
  [5722] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 4, 0, 104),
  [5724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 4, 0, 104),
  [5726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 5, 0, 96),
  [5728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 5, 0, 96),
  [5730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_placeholder_type_specifier, 1, 0, 0),
  [5732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_placeholder_type_specifier, 1, 0, 0),
  [5734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 5, 0, 98),
  [5736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 5, 0, 98),
  [5738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 10),
  [5740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 10),
  [5742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 5, 0, 101),
  [5744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 5, 0, 101),
  [5746] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [5748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [5750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration, 2, 0, 12),
  [5752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration, 2, 0, 12),
  [5754] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 6, 0, 143),
  [5756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 6, 0, 143),
  [5758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 4, 0, 46),
  [5760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 4, 0, 46),
  [5762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration, 4, 0, 145),
  [5764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration, 4, 0, 145),
  [5766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decltype_auto, 4, 0, 0),
  [5768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decltype_auto, 4, 0, 0),
  [5770] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__enum_base_clause, 2, 0, 99),
  [5772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_base_clause, 2, 0, 99),
  [5774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 48),
  [5776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 48),
  [5778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_specifier, 2, 0, 12),
  [5780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_specifier, 2, 0, 12),
  [5782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator_list, 2, 0, 0),
  [5784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator_list, 2, 0, 0),
  [5786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 2, 0, 11),
  [5788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 2, 0, 11),
  [5790] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(3835),
  [5793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3836),
  [5795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3833),
  [5797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 46),
  [5799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 46),
  [5801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 3, 0, 50),
  [5803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 3, 0, 50),
  [5805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 2, 0, 6),
  [5807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 2, 0, 6),
  [5809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 47),
  [5811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 47),
  [5813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_specifier, 2, 0, 12),
  [5815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_specifier, 2, 0, 12),
  [5817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 3, 0, 9),
  [5819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 3, 0, 9),
  [5821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [5823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [5825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_specifier, 2, 0, 12),
  [5827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_specifier, 2, 0, 12),
  [5829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration, 1, 0, 13),
  [5831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration, 1, 0, 13),
  [5833] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(612),
  [5836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2191),
  [5838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2213),
  [5840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2202),
  [5842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_placeholder_type_specifier, 2, 0, 27),
  [5844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_placeholder_type_specifier, 2, 0, 27),
  [5846] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(3822),
  [5849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2214),
  [5851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3821),
  [5853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 49),
  [5855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 49),
  [5857] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(586),
  [5860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constraint_disjunction, 3, 0, 54),
  [5862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_disjunction, 3, 0, 54),
  [5864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6055),
  [5866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6055),
  [5868] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(586),
  [5871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requires_clause, 2, 0, 22),
  [5873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_clause, 2, 0, 22),
  [5875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6036),
  [5877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6036),
  [5879] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2187),
  [5882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0),
  [5884] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0),
  [5886] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7586),
  [5889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8558),
  [5892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2279),
  [5895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9338),
  [5898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, 0, 2),
  [5900] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 2),
  [5902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [5904] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(2292),
  [5907] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(1719),
  [5910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2276),
  [5912] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(9080),
  [5915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2290),
  [5917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, -1, 36),
  [5919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, -1, 36),
  [5921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2206),
  [5923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6390),
  [5925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 2, 1, 0),
  [5927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2209),
  [5929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4788),
  [5931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4788),
  [5933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 2, 1, 0),
  [5935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6391),
  [5937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [5939] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(2288),
  [5942] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(1719),
  [5945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2308),
  [5947] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(9080),
  [5950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2325),
  [5952] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_specifiers, 1, 0, 2),
  [5954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_specifiers, 1, 0, 2),
  [5956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2256),
  [5958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2255),
  [5960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9050),
  [5962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 4, -1, 76),
  [5964] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 4, -1, 76),
  [5966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 3, 0, 45),
  [5968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, 0, 45),
  [5970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2210),
  [5972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_specifiers, 2, 0, 20),
  [5974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_specifiers, 2, 0, 20),
  [5976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2238),
  [5978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [5980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 3, 0, 20),
  [5982] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, 0, 20),
  [5984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, -1, 18),
  [5986] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, -1, 18),
  [5988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, 0, 20),
  [5990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 20),
  [5992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2200),
  [5994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 3, -1, 76),
  [5996] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, -1, 76),
  [5998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2195),
  [6000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2208),
  [6002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenated_string, 2, 0, 0),
  [6004] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenated_string, 2, 0, 0),
  [6006] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 3, 0, 0),
  [6008] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, 0, 0),
  [6010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 3, -1, 36),
  [6012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, -1, 36),
  [6014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2187),
  [6016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenated_string, 3, 0, 0),
  [6018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenated_string, 3, 0, 0),
  [6020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 1, 1, 0),
  [6022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 1, 1, 0),
  [6024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 4, 0, 45),
  [6026] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 4, 0, 45),
  [6028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_parameter_list, 3, 0, 0),
  [6030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_parameter_list, 3, 0, 0),
  [6032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_condition_clause, 3, 0, 14),
  [6034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_clause, 3, 0, 14),
  [6036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 1, 0, 6),
  [6038] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 1, 0, 6),
  [6040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9242),
  [6042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9242),
  [6044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [6046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6483),
  [6048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6413),
  [6050] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_condition_clause, 4, 0, 147),
  [6052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_clause, 4, 0, 147),
  [6054] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_parameter_list, 4, 0, 0),
  [6056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_parameter_list, 4, 0, 0),
  [6058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_parameter_list, 2, 0, 0),
  [6060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_parameter_list, 2, 0, 0),
  [6062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4503),
  [6064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2368),
  [6066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4481),
  [6068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9352),
  [6070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4502),
  [6072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__enum_base_clause, 2, 0, 100),
  [6074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_base_clause, 2, 0, 100),
  [6076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [6078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2226),
  [6080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4928),
  [6082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4928),
  [6084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2233),
  [6086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4989),
  [6088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4989),
  [6090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4491),
  [6092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2338),
  [6094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4490),
  [6096] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2237),
  [6099] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_specifiers, 3, 0, 20),
  [6101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_specifiers, 3, 0, 20),
  [6103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2261),
  [6105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2300),
  [6107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2279),
  [6109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2285),
  [6111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9338),
  [6113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2299),
  [6115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_specifiers, 2, 0, 2),
  [6117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_specifiers, 2, 0, 2),
  [6119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0),
  [6121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0),
  [6123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2630),
  [6126] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2261),
  [6129] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2663),
  [6132] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8981),
  [6135] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8517),
  [6138] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8983),
  [6141] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(9205),
  [6144] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8993),
  [6147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [6149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6483),
  [6151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6413),
  [6153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2295),
  [6155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2334),
  [6157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2294),
  [6159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raw_string_literal, 5, 0, 0),
  [6161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raw_string_literal, 5, 0, 0),
  [6163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 3, 0, 0),
  [6165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 3, 0, 0),
  [6167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raw_string_literal, 7, 0, 209),
  [6169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raw_string_literal, 7, 0, 209),
  [6171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2368),
  [6174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9352),
  [6177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 98),
  [6179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 98),
  [6181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6966),
  [6183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 49),
  [6185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 49),
  [6187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 0), SHIFT(1002),
  [6190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2309),
  [6192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 2, 0, 0),
  [6194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 2, 0, 0),
  [6196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9284),
  [6198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [6200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2237),
  [6202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9303),
  [6204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9303),
  [6206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [6208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2326),
  [6210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 2, 0, 50),
  [6212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 2, 0, 50),
  [6214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2321),
  [6216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 96),
  [6218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 96),
  [6220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2324),
  [6222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [6224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2298),
  [6226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 2, 0, 9),
  [6228] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 2, 0, 9),
  [6230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2314),
  [6232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2315),
  [6234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 46),
  [6236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 46),
  [6238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 2, 0, 9),
  [6240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 2, 0, 9),
  [6242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 1, 0, 11),
  [6244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 1, 0, 11),
  [6246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2319),
  [6248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 3, 0, 104),
  [6250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 3, 0, 104),
  [6252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 48),
  [6254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 48),
  [6256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2327),
  [6258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 5, 0, 143),
  [6260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 5, 0, 143),
  [6262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 3, 0, 46),
  [6264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 3, 0, 46),
  [6266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 4, 0, 144),
  [6268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 4, 0, 144),
  [6270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(623),
  [6273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [6275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [6277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 101),
  [6279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 101),
  [6281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2318),
  [6283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2327),
  [6286] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_storage_class_specifier, 1, 0, 0),
  [6288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_storage_class_specifier, 1, 0, 0),
  [6290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7719),
  [6292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2670),
  [6294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2638),
  [6296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2646),
  [6298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [6300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1803),
  [6302] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2337),
  [6305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 2, 0, 20),
  [6307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 2, 0, 20),
  [6309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [6311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [6313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2572),
  [6315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8684),
  [6317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [6319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [6321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [6323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 63),
  [6325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 63),
  [6327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(586),
  [6330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6393),
  [6332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 92),
  [6334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 92),
  [6336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [6338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [6340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2687),
  [6342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2470),
  [6344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2682),
  [6346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [6348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 45),
  [6350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 45),
  [6352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string, 1, 0, 0),
  [6354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string, 1, 0, 0),
  [6356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ms_declspec_modifier, 4, 0, 0),
  [6358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_declspec_modifier, 4, 0, 0),
  [6360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6909),
  [6362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6915),
  [6364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_expression, 1, 0, 0),
  [6367] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_expression, 1, 0, 0),
  [6370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2402),
  [6372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7576),
  [6374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8575),
  [6376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [6378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [6380] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(560),
  [6383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_destructor_name, 2, 0, 0),
  [6385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_destructor_name, 2, 0, 0),
  [6387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [6389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [6391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [6393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [6395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [6397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [6399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6946),
  [6401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2654),
  [6403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1126),
  [6405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [6407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7572),
  [6409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8574),
  [6411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2571),
  [6413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [6415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [6417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [6419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [6421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2410),
  [6423] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2410),
  [6426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7576),
  [6429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8575),
  [6432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [6434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2061),
  [6436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1128),
  [6438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type_declarator, 2, 1, 5),
  [6440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type_declarator, 2, 1, 5),
  [6442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [6444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8579),
  [6446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [6448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [6450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8765),
  [6452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type_declarator, 3, 1, 41),
  [6454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type_declarator, 3, 1, 41),
  [6456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(8299),
  [6459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__lambda_capture_identifier, 1, 0, 0), SHIFT(9002),
  [6462] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym__lambda_capture_identifier, 1, 0, 0), SHIFT(6588),
  [6466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1121),
  [6468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [6470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2460),
  [6472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(616),
  [6475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [6477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_type_specifier, 1, 0, 1),
  [6480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type_declarator, 5, 1, 171),
  [6482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type_declarator, 5, 1, 171),
  [6484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [6486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9002),
  [6488] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(6588),
  [6491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [6493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2464),
  [6495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2464),
  [6498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7650),
  [6501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8557),
  [6504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference_type_declarator, 2, 1, 0),
  [6506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_type_declarator, 2, 1, 0),
  [6508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type_declarator, 4, 1, 86),
  [6510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type_declarator, 4, 1, 86),
  [6512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 3, 1, 0),
  [6514] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 3, 1, 0),
  [6516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2537),
  [6518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2568),
  [6520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2533),
  [6522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7531),
  [6524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8571),
  [6526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(603),
  [6529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1093),
  [6531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [6533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7578),
  [6535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8569),
  [6537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_capture_identifier, 2, 0, 0),
  [6539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym__lambda_capture_identifier, 2, 0, 0),
  [6542] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2533),
  [6545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7531),
  [6548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8571),
  [6551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2497),
  [6553] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2537),
  [6556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_capture_identifier, 1, 0, 0),
  [6558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym__lambda_capture_identifier, 1, 0, 0),
  [6561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0),
  [6563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0),
  [6565] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(8579),
  [6568] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 62),
  [6570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 62),
  [6572] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(620),
  [6575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type_declarator, 3, -10, 0),
  [6577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type_declarator, 3, -10, 0),
  [6579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2598),
  [6581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7747),
  [6583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8570),
  [6585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 91),
  [6587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 91),
  [6589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2608),
  [6591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2612),
  [6593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributed_type_declarator, 2, 0, 0),
  [6595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributed_type_declarator, 2, 0, 0),
  [6597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type_declarator, 2, 0, 88),
  [6599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type_declarator, 2, 0, 88),
  [6601] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 136),
  [6603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 136),
  [6605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type_declarator, 4, -10, 0),
  [6607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type_declarator, 4, -10, 0),
  [6609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type_declarator, 4, 0, 119),
  [6611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type_declarator, 4, 0, 119),
  [6613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [6615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [6617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_declarator, 1, 0, 42),
  [6619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_declarator, 1, 0, 42),
  [6621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type_declarator, 3, 0, 26),
  [6623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type_declarator, 3, 0, 26),
  [6625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2609),
  [6627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_declarator, 1, 0, 0),
  [6629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_declarator, 1, 0, 0),
  [6631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type_declarator, 4, 0, 26),
  [6633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type_declarator, 4, 0, 26),
  [6635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_declarator, 1, 0, 1),
  [6637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_declarator, 1, 0, 1),
  [6639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_declarator, 1, 0, 43),
  [6641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_declarator, 1, 0, 43),
  [6643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(612),
  [6646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2609),
  [6649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7747),
  [6652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8570),
  [6655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type_declarator, 5, 0, 173),
  [6657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type_declarator, 5, 0, 173),
  [6659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 112),
  [6661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 112),
  [6663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2485),
  [6665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2486),
  [6667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2691),
  [6669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2645),
  [6671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 2, 0, 10),
  [6673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 2, 0, 10),
  [6675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6672),
  [6677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 47),
  [6679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 47),
  [6681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [6683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7233),
  [6685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1676),
  [6687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 4),
  [6689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 4),
  [6691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [6693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6703),
  [6695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6703),
  [6697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_co_await_expression, 2, 0, 4),
  [6699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_co_await_expression, 2, 0, 4),
  [6701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 0), SHIFT(1016),
  [6704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7224),
  [6706] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 4, 0, 85),
  [6708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 4, 0, 85),
  [6710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2759),
  [6712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [6714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3367),
  [6716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1667),
  [6718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [6720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [6722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1679),
  [6724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [6726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2647),
  [6728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_launch_bounds, 6, 0, 0),
  [6730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_launch_bounds, 6, 0, 0),
  [6732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_launch_bounds, 4, 0, 0),
  [6734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_launch_bounds, 4, 0, 0),
  [6736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9423),
  [6738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_declarator, 3, 0, 167),
  [6740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_declarator, 3, 0, 167),
  [6742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6615),
  [6744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1687),
  [6746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2655),
  [6748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_expression, 2, 0, 4),
  [6750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_expression, 2, 0, 4),
  [6752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 121),
  [6754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_field_identifier, 2, 1, 121),
  [6756] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 121), SHIFT(586),
  [6759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7235),
  [6761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2650),
  [6763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3384),
  [6765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2668),
  [6767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 54),
  [6769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 54),
  [6771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 4),
  [6773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 4),
  [6775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70),
  [6777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 1, 70),
  [6779] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70), SHIFT(586),
  [6782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [6784] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 2, 0, 14),
  [6786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 2, 0, 14),
  [6788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2689),
  [6790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [6792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3386),
  [6794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2661),
  [6796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7228),
  [6798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1670),
  [6800] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_method, 2, 0, 120),
  [6802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_method, 2, 0, 120),
  [6804] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 4, 0, 0),
  [6806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 4, 0, 0),
  [6808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2696),
  [6811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7749),
  [6814] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8567),
  [6817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_name, 2, 0, 0),
  [6819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_name, 2, 0, 0),
  [6821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2745),
  [6823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_declaration, 2, 0, 109),
  [6825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5822),
  [6827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0),
  [6829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0),
  [6831] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2630),
  [6834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2701),
  [6837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2663),
  [6840] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8981),
  [6843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8517),
  [6846] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8983),
  [6849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9205),
  [6852] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(3765),
  [6855] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8993),
  [6858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 40),
  [6860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 40),
  [6862] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__constructor_specifiers, 1, 0, 0), REDUCE(aux_sym__declaration_specifiers_repeat1, 1, 0, 0),
  [6865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_specifiers, 1, 0, 0),
  [6867] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_specifiers, 1, 0, 0),
  [6869] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__constructor_specifiers, 1, 0, 0), REDUCE(aux_sym__declaration_specifiers_repeat1, 1, 0, 0),
  [6872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 1, 0, 0),
  [6874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [6876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [6878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9264),
  [6880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9264),
  [6882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [6884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2727),
  [6886] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 0, 34),
  [6888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_field_identifier, 2, 0, 34),
  [6890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_method, 2, 0, 17),
  [6892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_method, 2, 0, 17),
  [6894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2860),
  [6896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 75),
  [6898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_identifier, 3, 0, 75),
  [6900] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 75), SHIFT(586),
  [6903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_declarator, 4, 0, 167),
  [6905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_declarator, 4, 0, 167),
  [6907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [6909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [6911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2696),
  [6913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dependent_field_identifier, 2, 0, 0),
  [6915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dependent_field_identifier, 2, 0, 0),
  [6917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(1719),
  [6920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2730),
  [6923] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2721),
  [6926] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(9423),
  [6929] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8362),
  [6932] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8650),
  [6935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(9080),
  [6938] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(9166),
  [6941] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [6943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [6945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 8, 0, 214),
  [6947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 8, 0, 214),
  [6949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2897),
  [6951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 5, 0, 155),
  [6953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 5, 0, 155),
  [6955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [6957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [6959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_literal_expression, 2, 0, 8),
  [6961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_literal_expression, 2, 0, 8),
  [6963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9346),
  [6965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9346),
  [6967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [6969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_name, 3, 0, 0),
  [6971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_name, 3, 0, 0),
  [6973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2947),
  [6975] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 5, 0, 158),
  [6977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 5, 0, 158),
  [6979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 0, 71),
  [6981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 71),
  [6983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6043),
  [6985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6045),
  [6987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6043),
  [6989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6045),
  [6991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9284),
  [6993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6666),
  [6995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 6, 0, 179),
  [6997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 6, 0, 179),
  [6999] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 7, 0, 206),
  [7001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 7, 0, 206),
  [7003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 29),
  [7005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 29),
  [7007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 7, 0, 207),
  [7009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 7, 0, 207),
  [7011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_list, 5, 0, 0),
  [7013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_list, 5, 0, 0),
  [7015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 54),
  [7017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 54),
  [7019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 7),
  [7021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 7),
  [7023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_expression, 8, 0, 0),
  [7025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_expression, 8, 0, 0),
  [7027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 61),
  [7029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 61),
  [7031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [7033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [7035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 5, 0, 157),
  [7037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 5, 0, 157),
  [7039] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_offsetof_expression, 6, 0, 191),
  [7041] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_offsetof_expression, 6, 0, 191),
  [7043] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 6, 0, 193),
  [7045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 6, 0, 193),
  [7047] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_kernel_call_expression, 3, 0, 72),
  [7049] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kernel_call_expression, 3, 0, 72),
  [7051] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 6, 0, 194),
  [7053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 6, 0, 194),
  [7055] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 134),
  [7057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 134),
  [7059] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 2, 0, 30),
  [7061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 2, 0, 30),
  [7063] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_argument_list, 3, 0, 0),
  [7065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_argument_list, 3, 0, 0),
  [7067] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 8, 0, 215),
  [7069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 8, 0, 215),
  [7071] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 135),
  [7073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 135),
  [7075] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_literal_expression, 4, 0, 85),
  [7077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_literal_expression, 4, 0, 85),
  [7079] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_null, 1, 0, 0),
  [7081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_null, 1, 0, 0),
  [7083] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_argument_list, 4, 0, 0),
  [7085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_argument_list, 4, 0, 0),
  [7087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9356),
  [7089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9356),
  [7091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [7093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 90),
  [7095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 90),
  [7097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 168),
  [7099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 168),
  [7101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_expression, 9, 0, 0),
  [7103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_expression, 9, 0, 0),
  [7105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 9, 0, 218),
  [7107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 9, 0, 218),
  [7109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [7111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [7113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_list, 3, 0, 0),
  [7115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_list, 3, 0, 0),
  [7117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6616),
  [7119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alignof_expression, 4, 0, 45),
  [7121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alignof_expression, 4, 0, 45),
  [7123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 4, 0, 108),
  [7125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 4, 0, 108),
  [7127] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_list, 4, 0, 0),
  [7129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_list, 4, 0, 0),
  [7131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_argument_list, 2, 0, 0),
  [7133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_argument_list, 2, 0, 0),
  [7135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 110),
  [7137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 110),
  [7139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 111),
  [7141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 111),
  [7143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_defined_literal, 2, 0, 0),
  [7145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_defined_literal, 2, 0, 0),
  [7147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dependent_identifier, 2, 0, 0),
  [7149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dependent_identifier, 2, 0, 0),
  [7151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [7153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(579),
  [7156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [7158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [7160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23),
  [7162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5992),
  [7164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5992),
  [7166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [7168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(9203),
  [7171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(9203),
  [7174] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(8394),
  [7177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 1, 0, 23),
  [7179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4003),
  [7181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9285),
  [7183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7368),
  [7185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7368),
  [7187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3324),
  [7189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6146),
  [7191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8907),
  [7193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6039),
  [7195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2864),
  [7197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2851),
  [7199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6413),
  [7202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6039),
  [7205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [7207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [7209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9203),
  [7211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9203),
  [7213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(7368),
  [7216] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(7368),
  [7219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3299),
  [7221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [7223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5865),
  [7225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5865),
  [7227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6445),
  [7229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8909),
  [7231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2876),
  [7233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5879),
  [7235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5879),
  [7237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6422),
  [7239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6968),
  [7241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6657),
  [7243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [7245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(612),
  [7247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [7249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2931),
  [7251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5843),
  [7253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5843),
  [7255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2885),
  [7258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7649),
  [7261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8555),
  [7264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [7266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2900),
  [7268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5862),
  [7270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5862),
  [7272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2896),
  [7274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5878),
  [7276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5878),
  [7278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7264),
  [7280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [7282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5844),
  [7284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5844),
  [7286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6398),
  [7288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [7290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2946),
  [7292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2885),
  [7294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3393),
  [7296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2948),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2926),
  [7300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [7302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(8517),
  [7305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9080),
  [7307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [7309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6005),
  [7311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9322),
  [7313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9322),
  [7315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [7317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(612),
  [7320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(620),
  [7323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2919),
  [7325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6005),
  [7328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [7330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2922),
  [7332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [7334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2886),
  [7336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [7338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [7340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2879),
  [7342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [7344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6965),
  [7346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6599),
  [7348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3372),
  [7350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6592),
  [7353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6042),
  [7356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ms_call_modifier, 1, 0, 0),
  [7358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_call_modifier, 1, 0, 0),
  [7360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6929),
  [7362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6665),
  [7364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(9423),
  [7367] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(9423),
  [7370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3312),
  [7372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3318),
  [7374] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6010),
  [7377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6592),
  [7379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6042),
  [7381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3405),
  [7383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6038),
  [7386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6010),
  [7388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3415),
  [7390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6038),
  [7392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1494),
  [7394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1495),
  [7396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1501),
  [7398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1502),
  [7400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [7402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1503),
  [7404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [7406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1501),
  [7408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(616),
  [7411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_expression, 3, 0, 0),
  [7413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_expression, 3, 0, 0),
  [7415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [7417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [7419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [7421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1499),
  [7423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1500),
  [7425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1496),
  [7427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [7429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [7431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extension_expression, 2, 0, 0),
  [7433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_expression, 2, 0, 0),
  [7435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [7437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1545),
  [7439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3355),
  [7441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9425),
  [7443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [7445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [7447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_expression, 2, 0, 0),
  [7449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_expression, 2, 0, 0),
  [7451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [7453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3040),
  [7455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3041),
  [7457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [7459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_expression, 4, 0, 0),
  [7461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_expression, 4, 0, 0),
  [7463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_expression, 4, 0, 122),
  [7465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 4, 0, 122),
  [7467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_expression, 5, 0, 0),
  [7469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_expression, 5, 0, 0),
  [7471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 174),
  [7473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 5, 0, 174),
  [7475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declarator, 1, 0, 0),
  [7477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [7479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6041),
  [7481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(616),
  [7483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6041),
  [7486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3025),
  [7488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3026),
  [7490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3362),
  [7492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_requirement, 5, 0, 0),
  [7494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_requirement, 5, 0, 0),
  [7496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [7498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [7500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [7502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8946),
  [7504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_requirement, 4, 0, 0),
  [7506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_requirement, 4, 0, 0),
  [7508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3417),
  [7510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [7512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [7514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3530),
  [7516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8926),
  [7518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0),
  [7520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0),
  [7522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(3268),
  [7525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(3307),
  [7528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_requirement, 6, 0, 0),
  [7530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_requirement, 6, 0, 0),
  [7532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3364),
  [7534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__requirement, 1, 0, 64),
  [7536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__requirement, 1, 0, 64),
  [7538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6962),
  [7540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6674),
  [7542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_requirement, 2, 0, 0),
  [7544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_requirement, 2, 0, 0),
  [7546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6655),
  [7548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [7550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3141),
  [7552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5963),
  [7554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5963),
  [7556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3268),
  [7558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3268),
  [7560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3307),
  [7562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [7564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1287),
  [7566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1288),
  [7568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [7570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3349),
  [7572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6009),
  [7575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3868),
  [7577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [7579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4201),
  [7581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [7583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [7585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [7587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [7589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [7591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [7593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1162),
  [7595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [7597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [7599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [7601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [7603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [7605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [7607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [7609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [7611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1197),
  [7613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [7615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [7617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [7619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1050),
  [7621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [7623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [7625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [7627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [7629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [7631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [7633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [7635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [7637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [7639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [7641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [7643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [7645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [7647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [7649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1247),
  [7651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [7653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [7655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [7657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [7659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3887),
  [7661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6754),
  [7663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6621),
  [7665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8638),
  [7667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2831),
  [7669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8394),
  [7671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3302),
  [7673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [7675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [7677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [7679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1291),
  [7681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1292),
  [7683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [7685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [7687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [7689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [7691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [7693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [7695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1289),
  [7697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1290),
  [7699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [7701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [7703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [7705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [7707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8650),
  [7709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2255),
  [7711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9050),
  [7713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9166),
  [7715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [7717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5949),
  [7719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5949),
  [7721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6009),
  [7723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3173),
  [7725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5952),
  [7727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5952),
  [7729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [7731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3977),
  [7733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3475),
  [7735] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_char_literal, 3, 0, 0),
  [7737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_char_literal, 3, 0, 0),
  [7739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1470),
  [7741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1471),
  [7743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1479),
  [7745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [7747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1474),
  [7749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1475),
  [7751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1476),
  [7753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [7755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1478),
  [7757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [7759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [7761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [7763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [7765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [7767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3796),
  [7769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8819),
  [7771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [7773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8426),
  [7775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(859),
  [7777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [7779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [7781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1472),
  [7783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1473),
  [7785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [7787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4578),
  [7789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6178),
  [7791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7203),
  [7793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2207),
  [7795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1482),
  [7797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1483),
  [7799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1491),
  [7801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6754),
  [7803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [7805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [7807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1486),
  [7809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1487),
  [7811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1488),
  [7813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [7815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1490),
  [7817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [7819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1484),
  [7821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1485),
  [7823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [7825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [7827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ms_pointer_modifier, 1, 0, 0),
  [7829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_pointer_modifier, 1, 0, 0),
  [7831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [7833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8443),
  [7835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(840),
  [7837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [7839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8449),
  [7841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [7843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5404),
  [7845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7222),
  [7847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4984),
  [7849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5569),
  [7851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6890),
  [7853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5696),
  [7855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5697),
  [7857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5698),
  [7859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5775),
  [7861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3892),
  [7863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7229),
  [7865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6876),
  [7867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5739),
  [7869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5740),
  [7871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5741),
  [7873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5766),
  [7875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6615),
  [7877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3295),
  [7879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5991),
  [7881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5991),
  [7883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4234),
  [7885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7210),
  [7887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3698),
  [7889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4434),
  [7891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6856),
  [7893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5719),
  [7895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5720),
  [7897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5721),
  [7899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4808),
  [7901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9307),
  [7903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5816),
  [7905] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ms_unaligned_ptr_modifier, 1, 0, 0),
  [7907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_unaligned_ptr_modifier, 1, 0, 0),
  [7909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4439),
  [7911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7230),
  [7913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4276),
  [7915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4639),
  [7917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6866),
  [7919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5742),
  [7921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5743),
  [7923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5744),
  [7925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5228),
  [7927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9348),
  [7929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5817),
  [7931] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(8426),
  [7934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4970),
  [7936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7225),
  [7938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6870),
  [7940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5749),
  [7942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5706),
  [7944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5737),
  [7946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5804),
  [7948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4696),
  [7950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7187),
  [7952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2317),
  [7954] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4003),
  [7957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9285),
  [7960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4209),
  [7962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1457),
  [7964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1458),
  [7966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [7968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [7970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1461),
  [7972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1462),
  [7974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1463),
  [7976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [7978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1465),
  [7980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [7982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1466),
  [7984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [7986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [7988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [7990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1459),
  [7992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1460),
  [7994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1461),
  [7996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [7998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4211),
  [8000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6696),
  [8002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6696),
  [8004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [8006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [8008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [8010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3464),
  [8012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3465),
  [8014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3465),
  [8017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7572),
  [8020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8574),
  [8023] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70), SHIFT(579),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3584),
  [8028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5993),
  [8030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5993),
  [8032] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(8443),
  [8035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3820),
  [8037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 75), SHIFT(530),
  [8040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3561),
  [8042] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(620),
  [8045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(4239),
  [8048] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(4245),
  [8051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4299),
  [8053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8619),
  [8055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3680),
  [8057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1144),
  [8059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [8061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [8063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1154),
  [8065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1155),
  [8067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [8069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [8071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [8073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [8075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1192),
  [8077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [8079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [8081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [8083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [8085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [8087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1217),
  [8089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1218),
  [8091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [8093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8647),
  [8095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [8097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8656),
  [8099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8663),
  [8101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8669),
  [8103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8679),
  [8105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8685),
  [8107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8695),
  [8109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8700),
  [8111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8706),
  [8113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8717),
  [8115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8718),
  [8117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [8119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [8121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [8123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [8125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [8127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [8129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [8131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4343),
  [8133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3714),
  [8135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3714),
  [8137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3526),
  [8139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9117),
  [8141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_initializer, 4, 0, 137),
  [8143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 121), SHIFT(579),
  [8146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6437),
  [8148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [8150] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 75), SHIFT(560),
  [8153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2793),
  [8155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2793),
  [8157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [8159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9299),
  [8161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3690),
  [8163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [8165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(8449),
  [8168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [8170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4857),
  [8172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3966),
  [8174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3966),
  [8176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [8178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8688),
  [8180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [8182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4051),
  [8184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4051),
  [8186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [8188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9088),
  [8190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4301),
  [8192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4036),
  [8194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4036),
  [8196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3790),
  [8198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9168),
  [8200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [8202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6764),
  [8204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6764),
  [8206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1440),
  [8208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1441),
  [8210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [8212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [8214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [8216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1445),
  [8218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1446),
  [8220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [8222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1448),
  [8224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1449),
  [8226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [8228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1442),
  [8230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1443),
  [8232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [8234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [8236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4063),
  [8238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6148),
  [8240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [8242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5540),
  [8244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4032),
  [8246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6482),
  [8248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [8250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4062),
  [8252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [8254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_fold_operator, 3, 0, 131),
  [8256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_fold_operator, 3, 0, 131),
  [8258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(1719),
  [8261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(3561),
  [8264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2721),
  [8267] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(9423),
  [8270] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8217),
  [8273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8650),
  [8276] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(9080),
  [8279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(9166),
  [8282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3577),
  [8284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6047),
  [8286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6047),
  [8288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4537),
  [8290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4239),
  [8292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4245),
  [8294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [8296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8984),
  [8298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6697),
  [8300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6697),
  [8302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1626),
  [8304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1627),
  [8306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [8308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [8310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1630),
  [8312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1631),
  [8314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1632),
  [8316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [8318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1634),
  [8320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [8322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1635),
  [8324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [8326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1628),
  [8328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1629),
  [8330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [8332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [8334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [8336] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 75), SHIFT(579),
  [8339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4458),
  [8341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(4003),
  [8344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4263),
  [8346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(9285),
  [8349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4457),
  [8351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 121), SHIFT(612),
  [8354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4478),
  [8356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(4003),
  [8359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4479),
  [8361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(9285),
  [8364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4476),
  [8366] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70), SHIFT(612),
  [8369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3728),
  [8371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6190),
  [8373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6190),
  [8375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [8377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3807),
  [8379] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70), SHIFT(620),
  [8382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_function_specifier, 1, 0, 0),
  [8384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [8386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explicit_function_specifier, 1, 0, 0),
  [8388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [8390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_function_specifier, 4, 0, 0),
  [8392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explicit_function_specifier, 4, 0, 0),
  [8394] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 121), SHIFT(620),
  [8397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6007),
  [8399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6007),
  [8401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3889),
  [8403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4173),
  [8405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3954),
  [8407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6226),
  [8409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6226),
  [8411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_start, 1, 0, 0),
  [8413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_start, 1, 0, 0),
  [8415] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 75), SHIFT(612),
  [8418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4231),
  [8420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1269),
  [8422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [8424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [8426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [8428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1273),
  [8430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [8432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1275),
  [8434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [8436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1277),
  [8438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [8440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1278),
  [8442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [8444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [8446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [8448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3830),
  [8450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 1, 0, 2),
  [8452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_descriptor, 1, 0, 2),
  [8454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4778),
  [8456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8870),
  [8458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(3805),
  [8461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 2, 0, 20),
  [8463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_descriptor, 2, 0, 20),
  [8465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [8467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3805),
  [8469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3826),
  [8471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3829),
  [8473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3881),
  [8475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3843),
  [8477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3844),
  [8479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3818),
  [8481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 75), SHIFT(620),
  [8484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6053),
  [8486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6053),
  [8488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3863),
  [8490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6287),
  [8492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6287),
  [8494] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(623),
  [8497] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3881),
  [8500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7578),
  [8503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8569),
  [8506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3958),
  [8508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3916),
  [8510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6221),
  [8512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6221),
  [8514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4043),
  [8516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3938),
  [8518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6229),
  [8520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6229),
  [8522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3958),
  [8525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7736),
  [8528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8566),
  [8531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4214),
  [8533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3840),
  [8535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5939),
  [8537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4021),
  [8539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6420),
  [8541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6420),
  [8543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3307),
  [8545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3838),
  [8547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3839),
  [8549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6645),
  [8551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5940),
  [8553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4031),
  [8555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6418),
  [8557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6418),
  [8559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6643),
  [8561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6644),
  [8563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2601),
  [8565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5937),
  [8567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4059),
  [8569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6395),
  [8571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6395),
  [8573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2595),
  [8575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2599),
  [8577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4226),
  [8579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6436),
  [8581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6436),
  [8583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6008),
  [8585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6008),
  [8587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3732),
  [8589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5932),
  [8591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4093),
  [8593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6441),
  [8595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6441),
  [8597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3761),
  [8599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3725),
  [8601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4454),
  [8603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4128),
  [8605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6428),
  [8607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6428),
  [8609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6943),
  [8611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6579),
  [8613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4153),
  [8615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6447),
  [8617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6447),
  [8619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [8621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6017),
  [8623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6034),
  [8625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6017),
  [8627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6034),
  [8629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4164),
  [8631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6379),
  [8633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6379),
  [8635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3854),
  [8637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5935),
  [8639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4254),
  [8641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6400),
  [8643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6400),
  [8645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3852),
  [8647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3853),
  [8649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_capture, 2, 0, 0),
  [8651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym__lambda_capture, 2, 0, 0),
  [8654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4220),
  [8656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6431),
  [8658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6431),
  [8660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6058),
  [8662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6058),
  [8664] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(4281),
  [8667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4270),
  [8669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6502),
  [8671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6502),
  [8673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4644),
  [8675] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(4539),
  [8678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4488),
  [8680] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(9361),
  [8683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4643),
  [8685] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(549),
  [8688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4656),
  [8690] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(4539),
  [8693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4657),
  [8695] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(9361),
  [8698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4655),
  [8700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6914),
  [8702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5980),
  [8704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4291),
  [8706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6519),
  [8708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6519),
  [8710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7414),
  [8712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4305),
  [8714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6563),
  [8716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6563),
  [8718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4304),
  [8720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6522),
  [8722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6522),
  [8724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 2, 0, 2),
  [8726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_descriptor, 2, 0, 2),
  [8728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5090),
  [8730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8938),
  [8732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6019),
  [8734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6060),
  [8736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6647),
  [8738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [8740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4616),
  [8742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8953),
  [8744] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4539),
  [8747] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9361),
  [8750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 3, 0, 20),
  [8752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_descriptor, 3, 0, 20),
  [8754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4358),
  [8756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6562),
  [8758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6562),
  [8760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [8762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5563),
  [8764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5563),
  [8766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5566),
  [8768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9243),
  [8770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4486),
  [8772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9337),
  [8774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9337),
  [8776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [8778] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4537),
  [8781] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8984),
  [8784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [8786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [8788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9516),
  [8790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4443),
  [8792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [8794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4641),
  [8796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_start, 2, 0, 0),
  [8798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_start, 2, 0, 0),
  [8800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4281),
  [8802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(1873),
  [8805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4651),
  [8807] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(9243),
  [8810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4474),
  [8812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4475),
  [8814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4462),
  [8816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6585),
  [8818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6585),
  [8820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6686),
  [8822] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(1873),
  [8825] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(9243),
  [8828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4445),
  [8830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4446),
  [8832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [8834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [8836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(4484),
  [8839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(591),
  [8842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4500),
  [8844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4501),
  [8846] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(603),
  [8849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4517),
  [8851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4518),
  [8853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [8855] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(2279),
  [8858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4731),
  [8860] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(9338),
  [8863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0),
  [8865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0),
  [8867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9423),
  [8870] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9423),
  [8873] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(2279),
  [8876] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(9338),
  [8879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [8881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7640),
  [8883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 1, 0, 56),
  [8885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4600),
  [8887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4600),
  [8889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [8891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [8893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4482),
  [8895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4534),
  [8897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6873),
  [8899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6873),
  [8901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6941),
  [8903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6628),
  [8905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6680),
  [8907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6950),
  [8909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6676),
  [8911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4359),
  [8913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [8915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1405),
  [8917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [8919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1406),
  [8921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1411),
  [8923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [8925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [8927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [8929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [8931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [8933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [8935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [8937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_reference_declarator, 1, 0, 0),
  [8939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_reference_declarator, 1, 0, 0),
  [8941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [8943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [8945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1409),
  [8947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [8949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [8951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [8953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [8955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4380),
  [8957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [8959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator, 3, 0, 142),
  [8961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 3, 0, 142),
  [8963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9351),
  [8965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9351),
  [8967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [8969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9203),
  [8972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9203),
  [8975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4640),
  [8977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4484),
  [8979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4650),
  [8981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4654),
  [8983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4659),
  [8985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4660),
  [8987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [8989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [8991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5226),
  [8993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8906),
  [8995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6916),
  [8997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6577),
  [8999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [9001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [9003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [9005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6557),
  [9007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [9009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [9011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1356),
  [9013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [9015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [9017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1359),
  [9019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [9021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1361),
  [9023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [9025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1363),
  [9027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [9029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1364),
  [9031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [9033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [9035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [9037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [9039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [9041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [9043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [9045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [9047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6035),
  [9049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6014),
  [9051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0), REDUCE(sym_argument_list, 2, 0, 0),
  [9054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [9056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [9058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1516),
  [9060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [9062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [9064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1519),
  [9066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [9068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1521),
  [9070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [9072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1523),
  [9074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [9076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1524),
  [9078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [9080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [9082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [9084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [9086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [9088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bitfield_clause, 2, 0, 0),
  [9090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bitfield_clause, 2, 0, 0),
  [9092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [9094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [9096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4267),
  [9098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 4, 0, 177),
  [9100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_declaration_repeat1, 4, 0, 177),
  [9102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6037),
  [9104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6037),
  [9106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6021),
  [9108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6021),
  [9110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5486),
  [9112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [9114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1379),
  [9116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [9118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1380),
  [9120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [9122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [9124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1383),
  [9126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1384),
  [9128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [9130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [9132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1387),
  [9134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1388),
  [9136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [9138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [9140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [9142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [9144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5510),
  [9146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [9148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [9150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1600),
  [9152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [9154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1601),
  [9156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [9158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [9160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1604),
  [9162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [9164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1606),
  [9166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [9168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1608),
  [9170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [9172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1609),
  [9174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [9176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2796),
  [9178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [9180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [9182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [9184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [9186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3894),
  [9188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [9190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5535),
  [9192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6598),
  [9194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(5390),
  [9197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(5396),
  [9200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), SHIFT(5389),
  [9203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_declarator, 3, 0, 114),
  [9205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_declaration, 4, 0, 185),
  [9207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [9209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4166),
  [9211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4086),
  [9213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3421),
  [9215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5442),
  [9217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [9219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4555),
  [9221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6679),
  [9223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [9225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comma_expression, 3, 0, 83),
  [9227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [9229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5435),
  [9231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [9233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1422),
  [9235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [9237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1423),
  [9239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [9241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1425),
  [9243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1426),
  [9245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [9247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1428),
  [9249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [9251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1430),
  [9253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [9255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1431),
  [9257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [9259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [9261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [9263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [9265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5436),
  [9267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9187),
  [9269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [9271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [9273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5446),
  [9275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [9277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4329),
  [9279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [9281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4342),
  [9283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4080),
  [9285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3123),
  [9287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4103),
  [9289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [9291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4190),
  [9293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [9295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [9297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [9299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [9301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4587),
  [9303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [9305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_initializer_pair, 3, 0, 140), SHIFT(1157),
  [9308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_pair, 3, 0, 140),
  [9310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5448),
  [9312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [9314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [9316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2328),
  [9318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4236),
  [9320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7059),
  [9322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6583),
  [9324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3883),
  [9326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4416),
  [9328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(5417),
  [9331] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(5411),
  [9334] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(5387),
  [9337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [9339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4249),
  [9341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [9343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5530),
  [9345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2742),
  [9347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [9349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3945),
  [9351] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_initializer_list_repeat1, 2, 0, 0), SHIFT(1157),
  [9354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_initializer_list_repeat1, 2, 0, 0),
  [9356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [9358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2812),
  [9360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [9362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4131),
  [9364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4710),
  [9366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [9368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5528),
  [9370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2216),
  [9372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [9374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [9376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3101),
  [9378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2983),
  [9380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [9382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1532),
  [9384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [9386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1533),
  [9388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [9390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [9392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1536),
  [9394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [9396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1538),
  [9398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [9400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1540),
  [9402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [9404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1541),
  [9406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [9408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [9410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [9412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [9414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [9416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [9418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [9420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 151),
  [9422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_initializer, 5, 0, 181),
  [9424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_initializer, 3, 0, 83),
  [9426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_parameter_declaration, 3, 0, 161),
  [9428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [9430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [9432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [9434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2219),
  [9436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6781),
  [9438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8919),
  [9440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6700),
  [9442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8783),
  [9444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [9446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [9448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [9450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [9452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_generic_expression_repeat1, 4, 0, 0),
  [9454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [9456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [9458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [9460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6765),
  [9462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8910),
  [9464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [9466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 5, 1, 202),
  [9468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 1, 0),
  [9470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6767),
  [9472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8949),
  [9474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [9476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [9478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [9480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6770),
  [9482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8668),
  [9484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3078),
  [9486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [9488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [9490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6772),
  [9492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9473),
  [9494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6775),
  [9496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9070),
  [9498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 4, 1, 186),
  [9500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 4, 1, 189),
  [9502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subscript_argument_list_repeat1, 2, 0, 0),
  [9504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 150),
  [9506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [9508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [9510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [9512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_parameter_declaration, 4, 0, 196),
  [9514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [9516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [9518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [9520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_pair, 3, 0, 141),
  [9522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [9524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [9526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [9528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [9530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [9532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2649),
  [9534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_kernel_call_syntax_repeat1, 2, 0, 0),
  [9536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [9538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [9540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 4, 1, 187),
  [9542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [9544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [9546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2362),
  [9548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [9550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [9552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [9554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [9556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5340),
  [9558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [9560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [9562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [9564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3885),
  [9566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2648),
  [9568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [9570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [9572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8158),
  [9574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3766),
  [9576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [9578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [9580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [9582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2436),
  [9584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [9586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [9588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [9590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [9592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [9594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3770),
  [9596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7889),
  [9598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [9600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4135),
  [9602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [9604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5259),
  [9606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [9608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6669),
  [9610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6195),
  [9612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [9614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [9616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2653),
  [9618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [9620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [9622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [9624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8072),
  [9626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [9628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [9630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [9632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_fold, 3, 0, 84),
  [9634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [9636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [9638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4542),
  [9640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_range_loop_body, 5, 0, 203),
  [9642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [9644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [9646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8100),
  [9648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [9650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7657),
  [9652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [9654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [9656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2054),
  [9658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [9660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3428),
  [9662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1752),
  [9664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [9666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [9668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [9670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [9672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [9674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 0), SHIFT(1013),
  [9677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3763),
  [9679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4559),
  [9681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7823),
  [9683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [9685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_range_loop_body, 4, 0, 188),
  [9687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [9689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [9691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [9693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1944),
  [9695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [9697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [9699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [9701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7915),
  [9703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [9705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2280),
  [9707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [9709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4558),
  [9711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unary_left_fold, 3, 0, 54),
  [9713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4912),
  [9715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [9717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4923),
  [9719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assignment_expression_lhs, 3, 0, 54),
  [9721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [9723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3346),
  [9725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [9727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [9729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3414),
  [9731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3392),
  [9733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3422),
  [9735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3427),
  [9737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3431),
  [9739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3434),
  [9741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3436),
  [9743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3438),
  [9745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [9747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [9749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 20), SHIFT(5405),
  [9752] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, 0, 45), SHIFT(5392),
  [9755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, -1, 76), SHIFT(5416),
  [9758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(5563),
  [9761] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(5563),
  [9764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(5566),
  [9767] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 4, 0, 45), SHIFT(1902),
  [9770] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, 0, 0), SHIFT(1902),
  [9773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_type, 1, 0, 2),
  [9775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_type, 1, 0, 2),
  [9777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_type, 2, 0, 20),
  [9779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_type, 2, 0, 20),
  [9781] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 2), SHIFT(1902),
  [9784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5410),
  [9786] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, 0, 20), SHIFT(1902),
  [9789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, -1, 36), SHIFT(1902),
  [9792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5565),
  [9794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, -1, 18), SHIFT(1902),
  [9797] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT(1902),
  [9801] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 4, -1, 76), SHIFT(1902),
  [9804] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, -1, 36), SHIFT(5406),
  [9807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23),
  [9809] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(9203),
  [9812] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(9203),
  [9815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(8394),
  [9818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 2, 0, 23),
  [9820] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6413),
  [9823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6039),
  [9826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6025),
  [9828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6049),
  [9830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6015),
  [9832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6018),
  [9834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_capture, 1, 0, 0),
  [9836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym__lambda_capture, 1, 0, 0),
  [9839] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(7368),
  [9842] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(7368),
  [9845] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(8517),
  [9848] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6005),
  [9851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2754),
  [9853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7794),
  [9855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_declaration, 1, 0, 0),
  [9857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5801),
  [9859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6592),
  [9862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6042),
  [9865] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(9423),
  [9868] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(9423),
  [9871] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6010),
  [9874] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_specifier, 1, 0, 0), SHIFT(5402),
  [9877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_type, 3, 0, 20),
  [9879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_type, 3, 0, 20),
  [9881] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6038),
  [9884] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_type, 2, 0, 2),
  [9886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_type, 2, 0, 2),
  [9888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2698),
  [9890] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23),
  [9892] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(9203),
  [9895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(9203),
  [9898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(8394),
  [9901] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 3, 0, 23),
  [9903] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6413),
  [9906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6039),
  [9909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6041),
  [9912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(7368),
  [9915] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(7368),
  [9918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(8517),
  [9921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6005),
  [9924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6038),
  [9927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2561),
  [9929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7178),
  [9931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1661),
  [9933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2706),
  [9935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6823),
  [9937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5716),
  [9939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5717),
  [9941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5718),
  [9943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2500),
  [9945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9246),
  [9947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5800),
  [9949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2472),
  [9951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1665),
  [9953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2619),
  [9955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6854),
  [9957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5806),
  [9959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4516),
  [9961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7213),
  [9963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2271),
  [9965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6829),
  [9967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5709),
  [9969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5710),
  [9971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5711),
  [9973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5788),
  [9975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3739),
  [9977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7197),
  [9979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2158),
  [9981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6824),
  [9983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5693),
  [9985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5694),
  [9987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5695),
  [9989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5812),
  [9991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3817),
  [9993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7189),
  [9995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2162),
  [9997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4283),
  [9999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6869),
  [10001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5649),
  [10003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5750),
  [10005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5751),
  [10007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4630),
  [10009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9358),
  [10011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5839),
  [10013] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(9423),
  [10016] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(9423),
  [10019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2847),
  [10021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7202),
  [10023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1709),
  [10025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2975),
  [10027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6813),
  [10029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5722),
  [10031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5748),
  [10033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5657),
  [10035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3401),
  [10037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9211),
  [10039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5777),
  [10041] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6592),
  [10044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6042),
  [10047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2888),
  [10049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7234),
  [10051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1711),
  [10053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3030),
  [10055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6867),
  [10057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5745),
  [10059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5746),
  [10061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5747),
  [10063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3600),
  [10065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9353),
  [10067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5841),
  [10069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6010),
  [10072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4531),
  [10074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7195),
  [10076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2236),
  [10078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4634),
  [10080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6861),
  [10082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5727),
  [10084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5728),
  [10086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5729),
  [10088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5166),
  [10090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9326),
  [10092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5758),
  [10094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2880),
  [10096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7218),
  [10098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1712),
  [10100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3045),
  [10102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6863),
  [10104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5734),
  [10106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5735),
  [10108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5736),
  [10110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3512),
  [10112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9340),
  [10114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5818),
  [10116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3055),
  [10118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7183),
  [10120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1725),
  [10122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3153),
  [10124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6790),
  [10126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5713),
  [10128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5714),
  [10130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5715),
  [10132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3917),
  [10134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9288),
  [10136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5802),
  [10138] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6009),
  [10141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3872),
  [10143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2567),
  [10145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2849),
  [10147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4721),
  [10149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7227),
  [10151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4288),
  [10153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4787),
  [10155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6041),
  [10158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4715),
  [10160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2790),
  [10162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2718),
  [10164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4513),
  [10166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3048),
  [10168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2352),
  [10170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4204),
  [10172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4483),
  [10174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2882),
  [10176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(8517),
  [10179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4514),
  [10181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2939),
  [10183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5407),
  [10185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6865),
  [10187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5786),
  [10189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23),
  [10191] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(9203),
  [10194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(9203),
  [10197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(8394),
  [10200] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 4, 0, 23),
  [10202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6413),
  [10205] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6039),
  [10208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6009),
  [10211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(7368),
  [10214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(7368),
  [10217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(8517),
  [10220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6005),
  [10223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(9423),
  [10226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(9423),
  [10229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6038),
  [10232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6592),
  [10235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6010),
  [10238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6042),
  [10241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6041),
  [10244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [10246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [10248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3851),
  [10250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7734),
  [10252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [10254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [10256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5487),
  [10258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7683),
  [10260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [10262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [10264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4255),
  [10266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7658),
  [10268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [10270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [10272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4316),
  [10274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7681),
  [10276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [10278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [10280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4163),
  [10282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7555),
  [10284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [10286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [10288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2753),
  [10290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7746),
  [10292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [10294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [10296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4770),
  [10298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7759),
  [10300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [10302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [10304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5481),
  [10306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7587),
  [10308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4909),
  [10310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [10312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [10314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [10316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(856),
  [10318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [10320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [10322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8396),
  [10324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_end, 2, 0, 0),
  [10326] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_end, 2, 0, 0),
  [10328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6009),
  [10331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [10333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [10335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [10337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8444),
  [10339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_end, 1, 0, 0),
  [10341] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_end, 1, 0, 0),
  [10343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [10345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [10347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [10349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8428),
  [10351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ref_qualifier, 1, 0, 0),
  [10353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ref_qualifier, 1, 0, 0),
  [10355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23),
  [10357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 6, 0, 23),
  [10359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23),
  [10361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 5, 0, 23),
  [10363] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6413),
  [10366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6005),
  [10369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3463),
  [10371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7926),
  [10373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [10375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3689),
  [10377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [10379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9442),
  [10381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5998),
  [10383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7848),
  [10385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(800),
  [10387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6413),
  [10390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6005),
  [10393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [10395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6150),
  [10397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7546),
  [10399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6040),
  [10401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [10403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6484),
  [10405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7512),
  [10407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_end, 3, 0, 0),
  [10409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_end, 3, 0, 0),
  [10411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [10413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6033),
  [10415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7525),
  [10417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2869),
  [10419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8016),
  [10421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [10423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3921),
  [10425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [10427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4047),
  [10429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7079),
  [10431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6473),
  [10433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [10435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6068),
  [10437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [10439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6459),
  [10441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4758),
  [10443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [10445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5541),
  [10447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1992),
  [10449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7179),
  [10451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2184),
  [10453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [10455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4203),
  [10457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5542),
  [10459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [10461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4393),
  [10463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [10465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6855),
  [10467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4886),
  [10469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6416),
  [10471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7204),
  [10473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6626),
  [10475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6002),
  [10477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5509),
  [10479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1697),
  [10481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7041),
  [10483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6796),
  [10485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6023),
  [10487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4033),
  [10489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2168),
  [10491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6887),
  [10493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6122),
  [10495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6881),
  [10497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6604),
  [10499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [10501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2835),
  [10503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2836),
  [10505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4847),
  [10507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6149),
  [10509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7211),
  [10511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3780),
  [10513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7216),
  [10515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4090),
  [10517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4391),
  [10519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_postfix, 1, 0, 0),
  [10521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_postfix, 1, 0, 0),
  [10523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5799),
  [10525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [10527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [10529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [10531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(845),
  [10533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [10535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7346),
  [10537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8319),
  [10539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6011),
  [10541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6217),
  [10543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6288),
  [10545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8527),
  [10547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6289),
  [10549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6289),
  [10551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6075),
  [10553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7956),
  [10555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [10557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [10559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8495),
  [10561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6231),
  [10563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6224),
  [10565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6355),
  [10567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6356),
  [10569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6356),
  [10571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6357),
  [10573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6358),
  [10575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6359),
  [10577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6361),
  [10579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6362),
  [10581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6363),
  [10583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6369),
  [10585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6369),
  [10587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6370),
  [10589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [10591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [10593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [10595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8366),
  [10597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6181),
  [10599] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [10601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [10603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [10605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_postfix_repeat1, 2, 0, 0),
  [10607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__function_postfix_repeat1, 2, 0, 0),
  [10609] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_postfix_repeat1, 2, 0, 0), SHIFT_REPEAT(6413),
  [10612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [10614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [10616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6048),
  [10618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6052),
  [10620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7231),
  [10622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7806),
  [10624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8791),
  [10626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6182),
  [10628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [10630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [10632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_noexcept, 1, 0, 0),
  [10634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [10636] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_noexcept, 1, 0, 0),
  [10638] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6039),
  [10641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6039),
  [10644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_noexcept, 3, 0, 0),
  [10646] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_noexcept, 3, 0, 0),
  [10648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_specifier, 3, 0, 0),
  [10650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_specifier, 3, 0, 0),
  [10652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [10654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [10656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8522),
  [10658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6444),
  [10660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6187),
  [10662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9336),
  [10664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [10666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6415),
  [10668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_noexcept, 4, 0, 0),
  [10670] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_noexcept, 4, 0, 0),
  [10672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_specifier, 4, 0, 0),
  [10674] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_specifier, 4, 0, 0),
  [10676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_specifier, 5, 0, 0),
  [10678] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_specifier, 5, 0, 0),
  [10680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 2, 0, 0),
  [10682] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 2, 0, 0),
  [10684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7315),
  [10686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9019),
  [10688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6942),
  [10690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6378),
  [10692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [10694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7899),
  [10696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3400),
  [10698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9482),
  [10700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6219),
  [10702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8028),
  [10704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3504),
  [10706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [10708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [10710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(8394),
  [10713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 3, 0, 0),
  [10715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 3, 0, 0),
  [10717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3250),
  [10719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9476),
  [10721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6227),
  [10723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7768),
  [10725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3484),
  [10727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [10729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [10731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6316),
  [10733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [10735] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [10737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_binary_expression, 3, 0, 54),
  [10739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_binary_expression, 3, 0, 54),
  [10741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2067),
  [10743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6235),
  [10745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7838),
  [10747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [10749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [10751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1900),
  [10753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6246),
  [10755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7793),
  [10757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6092),
  [10759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6331),
  [10761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8225),
  [10763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6332),
  [10765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6332),
  [10767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6451),
  [10769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8137),
  [10771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6452),
  [10773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6455),
  [10775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6456),
  [10777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6376),
  [10779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6377),
  [10781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6381),
  [10783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6382),
  [10785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6403),
  [10787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6404),
  [10789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6380),
  [10791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [10793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6405),
  [10795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2175),
  [10797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9130),
  [10799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6260),
  [10801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7896),
  [10803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3494),
  [10805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [10807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6384),
  [10809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [10811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6401),
  [10813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6407),
  [10815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(983),
  [10817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6266),
  [10819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7945),
  [10821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [10823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [10825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3234),
  [10827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8098),
  [10829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6424),
  [10831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 4, 0, 0),
  [10833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 4, 0, 0),
  [10835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2157),
  [10837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9052),
  [10839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6274),
  [10841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7998),
  [10843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3509),
  [10845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [10847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [10849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [10851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined, 4, 0, 0),
  [10853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined, 4, 0, 0),
  [10855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [10857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6279),
  [10859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8040),
  [10861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7242),
  [10863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [10865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3476),
  [10867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8884),
  [10869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6282),
  [10871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8088),
  [10873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3514),
  [10875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6430),
  [10877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3477),
  [10879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6284),
  [10881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8107),
  [10883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1061),
  [10885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6285),
  [10887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8113),
  [10889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3013),
  [10891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8120),
  [10893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6435),
  [10895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6354),
  [10897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2525),
  [10899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6291),
  [10901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8182),
  [10903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [10905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [10907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [10909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [10911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [10913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3229),
  [10915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6305),
  [10917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8169),
  [10919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3500),
  [10921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [10923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_argument_list_repeat1, 2, 0, 0),
  [10925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [10927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [10929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6440),
  [10931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6388),
  [10933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6402),
  [10935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6442),
  [10937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6449),
  [10939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [10941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [10943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6410),
  [10945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call_expression, 2, 0, 7),
  [10947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call_expression, 2, 0, 7),
  [10949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined, 2, 0, 0),
  [10951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined, 2, 0, 0),
  [10953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_unary_expression, 2, 0, 4),
  [10955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_unary_expression, 2, 0, 4),
  [10957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6233),
  [10959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6234),
  [10961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6236),
  [10963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6237),
  [10965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6238),
  [10967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [10969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6239),
  [10971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6240),
  [10973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6241),
  [10975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6450),
  [10977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [10979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [10981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6386),
  [10983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6397),
  [10985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6242),
  [10987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6243),
  [10989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [10991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trailing_return_type, 2, 0, 0),
  [10993] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trailing_return_type, 2, 0, 0),
  [10995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 4, 0, 26),
  [10997] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 4, 0, 26),
  [10999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6247),
  [11001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6248),
  [11003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6252),
  [11005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6253),
  [11007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6254),
  [11009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6255),
  [11011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6256),
  [11013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7454),
  [11015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7822),
  [11017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6757),
  [11019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6249),
  [11021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6250),
  [11023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6251),
  [11025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6746),
  [11027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [11029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6448),
  [11031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_parenthesized_declarator, 3, 0, 0),
  [11033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_parenthesized_declarator, 3, 0, 0),
  [11035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6399),
  [11037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7780),
  [11039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abstract_declarator, 1, 0, 0),
  [11041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__abstract_declarator, 1, 0, 0),
  [11043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 3, 0, 124),
  [11045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 3, 0, 124),
  [11047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [11049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7272),
  [11051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8061),
  [11053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7098),
  [11055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [11057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [11059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 3, 0, 0),
  [11061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 3, 0, 0),
  [11063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [11065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 3, 0, 26),
  [11067] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 3, 0, 26),
  [11069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_virtual_specifier, 1, 0, 0),
  [11071] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_virtual_specifier, 1, 0, 0),
  [11073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 5, 0, 173),
  [11075] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 5, 0, 173),
  [11077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7634),
  [11079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6417),
  [11081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8009),
  [11083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [11085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [11087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [11089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 2, 0, 0),
  [11091] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 2, 0, 0),
  [11093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 2, 0, 24),
  [11095] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_function_declarator, 2, 0, 24),
  [11097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 7, 0, 23),
  [11099] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 7, 0, 23),
  [11101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [11103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6232),
  [11105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6466),
  [11107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_parenthesized_declarator, 4, 0, 0),
  [11109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_parenthesized_declarator, 4, 0, 0),
  [11111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 4, 0, 175),
  [11113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 4, 0, 175),
  [11115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7091),
  [11117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7045),
  [11119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 4, 0, 119),
  [11121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 4, 0, 119),
  [11123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [11125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [11127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 1, 0, 33),
  [11129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_function_declarator, 1, 0, 33),
  [11131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [11133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6003),
  [11135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6859),
  [11137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7462),
  [11139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6821),
  [11141] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(8217),
  [11144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6013),
  [11146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6592),
  [11149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6010),
  [11152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6795),
  [11154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6592),
  [11157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6010),
  [11160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6837),
  [11162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [11164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_postfix_repeat1, 2, 0, 0), SHIFT_REPEAT(6592),
  [11167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [11169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6050),
  [11171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [11173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [11175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [11177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [11179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2, 0, 5),
  [11181] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6531),
  [11184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7699),
  [11187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(8564),
  [11190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [11192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [11194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7028),
  [11196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7920),
  [11198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [11200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6998),
  [11202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_clobber_list, 1, 0, 0),
  [11204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributed_declarator, 2, 0, 0),
  [11206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributed_declarator, 2, 0, 0),
  [11208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [11210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [11212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6548),
  [11214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7699),
  [11216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8564),
  [11218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6531),
  [11220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [11222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [11224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8461),
  [11226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__class_declaration_repeat1, 2, 0, 0),
  [11228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8981),
  [11231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__class_declaration_repeat1, 2, 0, 0),
  [11233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(9205),
  [11236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4440),
  [11238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4658),
  [11240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3473),
  [11242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3837),
  [11244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2389),
  [11246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2620),
  [11248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4995),
  [11250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5393),
  [11252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structured_binding_declarator, 3, -1, 0),
  [11254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structured_binding_declarator, 3, -1, 0),
  [11256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 3, 1, 41),
  [11258] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 3, 1, 41),
  [11260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(839),
  [11262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4675),
  [11264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2304),
  [11266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2740),
  [11268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2960),
  [11270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6022),
  [11272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6024),
  [11274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6038),
  [11277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 4, 0, 132),
  [11279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_descriptor, 4, 0, 132),
  [11281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 2, 1, 5),
  [11283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 2, 1, 5),
  [11285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 4, 0, 119),
  [11287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_declarator, 4, 0, 119),
  [11289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 3, 0, 26),
  [11291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_declarator, 3, 0, 26),
  [11293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_reference_declarator, 2, 0, 0),
  [11295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_reference_declarator, 2, 0, 0),
  [11297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 2, 0, 39),
  [11299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_descriptor, 2, 0, 39),
  [11301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_declarator, 3, -10, 0),
  [11303] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_declarator, 3, -10, 0),
  [11305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2224),
  [11307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2331),
  [11309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 3, 0, 82),
  [11311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_descriptor, 3, 0, 82),
  [11313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 2, 1, 24),
  [11315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declarator, 2, 1, 24),
  [11317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 3, 0, 62),
  [11319] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_descriptor, 3, 0, 62),
  [11321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3468),
  [11323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9213),
  [11326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6970),
  [11328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7469),
  [11330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 4, 1, 86),
  [11332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 4, 1, 86),
  [11334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_declarator, 4, -10, 0),
  [11336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_declarator, 4, -10, 0),
  [11338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 5),
  [11340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 5),
  [11342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [11344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4365),
  [11346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4533),
  [11348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 5, 0, 173),
  [11350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_declarator, 5, 0, 173),
  [11352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6042),
  [11355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3762),
  [11357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2199),
  [11359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6042),
  [11362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2719),
  [11364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2861),
  [11366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2746),
  [11368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2964),
  [11370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2453),
  [11372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2679),
  [11374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4121),
  [11376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4435),
  [11378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [11380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2481),
  [11382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structured_binding_declarator, 4, -1, 0),
  [11384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structured_binding_declarator, 4, -1, 0),
  [11386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2908),
  [11388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3034),
  [11390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 4, 0, 26),
  [11392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_declarator, 4, 0, 26),
  [11394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4565),
  [11396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4422),
  [11398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3756),
  [11400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6951),
  [11402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7466),
  [11404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2677),
  [11406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6958),
  [11408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7493),
  [11410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_field_declarator, 2, 1, 0),
  [11412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference_field_declarator, 2, 1, 0),
  [11414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 3, 1, 41),
  [11416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_declarator, 3, 1, 41),
  [11418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6911),
  [11420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7509),
  [11422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6041),
  [11425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7263),
  [11427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7403),
  [11429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7448),
  [11431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6262),
  [11433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9141),
  [11435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 4, 1, 86),
  [11437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_declarator, 4, 1, 86),
  [11439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list, 2, 0, 10),
  [11441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_field_declarator, 5, 1, 171),
  [11443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_field_declarator, 5, 1, 171),
  [11445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 2, 1, 5),
  [11447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_declarator, 2, 1, 5),
  [11449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_field_declarator, 2, 1, 5),
  [11451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_field_declarator, 2, 1, 5),
  [11453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list, 3, 0, 80),
  [11455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 5, 1, 171),
  [11457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_declarator, 5, 1, 171),
  [11459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_field_declarator, 3, 1, 41),
  [11461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_field_declarator, 3, 1, 41),
  [11463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_declarator, 2, 1, 0),
  [11465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference_declarator, 2, 1, 0),
  [11467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7434),
  [11469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_field_declarator, 4, 1, 86),
  [11471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_field_declarator, 4, 1, 86),
  [11473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3713),
  [11475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6925),
  [11477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7489),
  [11479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6995),
  [11481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 66),
  [11483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [11485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6976),
  [11487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6026),
  [11489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6041),
  [11492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7008),
  [11494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1989),
  [11496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [11498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7931),
  [11500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6924),
  [11502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7600),
  [11504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7000),
  [11506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7020),
  [11508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [11510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8023),
  [11512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7761),
  [11514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7010),
  [11516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7006),
  [11518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [11520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8163),
  [11522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7619),
  [11524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [11526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7874),
  [11528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7564),
  [11530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [11532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7964),
  [11534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7612),
  [11536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7022),
  [11538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [11540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [11542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [11544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [11546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6988),
  [11548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6046),
  [11550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7007),
  [11552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [11554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [11556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [11558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7988),
  [11560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7620),
  [11562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7019),
  [11564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7021),
  [11566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6975),
  [11568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6977),
  [11570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6980),
  [11572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7016),
  [11574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6981),
  [11576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6983),
  [11578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7002),
  [11580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2020),
  [11582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [11584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8008),
  [11586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7633),
  [11588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7004),
  [11590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [11592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6020),
  [11594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6038),
  [11597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6030),
  [11599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2044),
  [11601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [11603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7015),
  [11605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7003),
  [11607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8118),
  [11609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6257),
  [11611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9161),
  [11613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2521),
  [11615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7314),
  [11617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6922),
  [11619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [11621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2262),
  [11623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [11625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2239),
  [11627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [11629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2665),
  [11631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [11633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4853),
  [11635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_declarator, 1, 0, 102),
  [11637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [11639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__field_declarator, 1, 0, 102),
  [11641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [11643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5158),
  [11645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5086),
  [11647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7495),
  [11649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7464),
  [11651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributed_field_declarator, 2, 0, 0),
  [11653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributed_field_declarator, 2, 0, 0),
  [11655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3700),
  [11657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3223),
  [11659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_declarator, 1, 0, 0),
  [11661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__field_declarator, 1, 0, 0),
  [11663] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6009),
  [11666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3220),
  [11668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4852),
  [11670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7310),
  [11672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4493),
  [11674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4528),
  [11676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [11678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4760),
  [11680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3771),
  [11682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4811),
  [11684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3469),
  [11686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [11688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [11690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2138),
  [11692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [11694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3171),
  [11696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3487),
  [11698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_field_declarator, 2, 1, 24),
  [11700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_field_declarator, 2, 1, 24),
  [11702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_field_declarator, 3, -10, 0),
  [11704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_field_declarator, 3, -10, 0),
  [11706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_field_declarator, 4, -10, 0),
  [11708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_field_declarator, 4, -10, 0),
  [11710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_field_declarator, 5, 0, 173),
  [11712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_field_declarator, 5, 0, 173),
  [11714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_field_declarator, 4, 0, 119),
  [11716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_field_declarator, 4, 0, 119),
  [11718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_field_declarator, 4, 0, 26),
  [11720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_field_declarator, 4, 0, 26),
  [11722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_field_declarator, 3, 0, 26),
  [11724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_field_declarator, 3, 0, 26),
  [11726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7293),
  [11728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7226),
  [11730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8655),
  [11732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7593),
  [11734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6334),
  [11736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8675),
  [11738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7237),
  [11740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7215),
  [11742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7169),
  [11744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6001),
  [11746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list, 4, 0, 80),
  [11748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7580),
  [11750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6324),
  [11752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8604),
  [11754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7176),
  [11756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list_no_comma, 3, 0, 80),
  [11758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7286),
  [11760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7196),
  [11762] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8118),
  [11765] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6264),
  [11768] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8626),
  [11771] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8257),
  [11774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0),
  [11776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list_no_comma, 4, 0, 80),
  [11778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7241),
  [11780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7181),
  [11782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7269),
  [11784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7194),
  [11786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7411),
  [11788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7386),
  [11790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7266),
  [11792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7182),
  [11794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6029),
  [11796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list, 3, 0, 10),
  [11798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list_no_comma, 3, 0, 10),
  [11800] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6009),
  [11803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list_no_comma, 2, 0, 10),
  [11805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7423),
  [11807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7270),
  [11809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7185),
  [11811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7162),
  [11813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7408),
  [11815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6454),
  [11817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_declarators, 1, 0, 26),
  [11819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_declarators, 1, 0, 26),
  [11821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6581),
  [11823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9152),
  [11825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7148),
  [11827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__scope_resolution, 1, 0, 0),
  [11829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__scope_resolution, 1, 0, 0),
  [11831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1351),
  [11833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5621),
  [11835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1530),
  [11837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5620),
  [11839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand_list, 1, 0, 0),
  [11841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9059),
  [11843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1560),
  [11845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1327),
  [11847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5626),
  [11849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [11851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_definition_declarators_repeat1, 2, 0, 5),
  [11853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__type_definition_declarators_repeat1, 2, 0, 5),
  [11855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1263),
  [11857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5609),
  [11859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1320),
  [11861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5633),
  [11863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1301),
  [11865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5646),
  [11867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1402),
  [11869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5617),
  [11871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1283),
  [11873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5613),
  [11875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1599),
  [11877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2967),
  [11879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7198),
  [11881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand_list, 1, 0, 0),
  [11883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8803),
  [11885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [11887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5627),
  [11889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1455),
  [11891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [11893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5625),
  [11895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1638),
  [11897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1391),
  [11899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5643),
  [11901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2344),
  [11903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8323),
  [11905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2018),
  [11907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8465),
  [11909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7599),
  [11911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7559),
  [11913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3012),
  [11915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8381),
  [11917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8146),
  [11919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7530),
  [11921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9298),
  [11923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7597),
  [11925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4734),
  [11927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8247),
  [11929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3873),
  [11931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8398),
  [11933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7561),
  [11935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4492),
  [11937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8460),
  [11939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7631),
  [11941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4278),
  [11943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8287),
  [11945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2991),
  [11947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8251),
  [11949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2713),
  [11951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8321),
  [11953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2543),
  [11955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8526),
  [11957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8192),
  [11959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9424),
  [11961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2844),
  [11963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8552),
  [11965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4694),
  [11967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6423),
  [11969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8358),
  [11971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7535),
  [11973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7446),
  [11975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8728),
  [11977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4165),
  [11979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8367),
  [11981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6057),
  [11983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5997),
  [11985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7782),
  [11987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8646),
  [11989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4485),
  [11991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7626),
  [11993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2934),
  [11995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8230),
  [11997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7554),
  [11999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7729),
  [12001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7990),
  [12003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8998),
  [12005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4784),
  [12007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8530),
  [12009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7703),
  [12011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7995),
  [12013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2747),
  [12015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7695),
  [12017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8005),
  [12019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4508),
  [12021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8307),
  [12023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8086),
  [12025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2942),
  [12027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8354),
  [12029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7813),
  [12031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [12033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [12035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3279),
  [12037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [12039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [12041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2095),
  [12043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3343),
  [12045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8299),
  [12047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__lambda_capture_identifier, 1, 0, 0), SHIFT(6588),
  [12050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [12052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6625),
  [12054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6993),
  [12056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [12058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__scope_resolution, 2, 0, 15),
  [12060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__scope_resolution, 2, 0, 15),
  [12062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [12064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [12066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__scope_resolution, 2, 0, 31),
  [12068] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__scope_resolution, 2, 0, 31),
  [12070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 1, 0, 6),
  [12072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator, 1, 0, 6),
  [12074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [12076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [12078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3380),
  [12080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [12082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3262),
  [12084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [12086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3444),
  [12088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [12090] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8118),
  [12093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_repeat1, 2, 0, 0),
  [12095] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_repeat1, 2, 0, 0),
  [12097] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 2, 0, 0), SHIFT_REPEAT(7263),
  [12100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 2, 0, 0),
  [12102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 2, 0, 0),
  [12104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7011),
  [12106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [12108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [12110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6614),
  [12112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [12114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3272),
  [12116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [12118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast, 3, 0, 58),
  [12120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [12122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 5, 0, 0),
  [12124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 5, 0, 0),
  [12126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [12128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 56),
  [12130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7888),
  [12132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2591),
  [12134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6670),
  [12136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [12138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6725),
  [12140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7467),
  [12142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7933),
  [12144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 1, 0, 0),
  [12146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7384),
  [12148] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 1, 0, 0),
  [12150] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_initializer_pair_repeat1, 2, 0, 0), SHIFT_REPEAT(1306),
  [12153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_initializer_pair_repeat1, 2, 0, 0),
  [12155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_initializer_pair_repeat1, 2, 0, 0), SHIFT_REPEAT(9001),
  [12158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 6, 0, 0),
  [12160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 6, 0, 0),
  [12162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_expression_repeat1, 2, 0, 0),
  [12164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(7467),
  [12167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6688),
  [12169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3980),
  [12171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [12173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4007),
  [12175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 3, 0, 0),
  [12177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 3, 0, 0),
  [12179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [12181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8155),
  [12183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3876),
  [12185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6699),
  [12187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6721),
  [12189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6729),
  [12191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3978),
  [12193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 4, 0, 0),
  [12195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 4, 0, 0),
  [12197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7875),
  [12199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [12201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [12203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9001),
  [12205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 66),
  [12207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6722),
  [12209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6769),
  [12211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6720),
  [12213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6724),
  [12215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6741),
  [12217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6745),
  [12219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6756),
  [12221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6758),
  [12223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6762),
  [12225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6766),
  [12227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2579),
  [12229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6771),
  [12231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6777),
  [12233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6779),
  [12235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6784),
  [12237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [12239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list, 5, 0, 129),
  [12241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_enumerator_list, 5, 0, 129),
  [12243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [12245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [12247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [12249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [12251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [12253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 4, 0, 10),
  [12255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 4, 0, 10),
  [12257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list, 6, 0, 178),
  [12259] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_enumerator_list, 6, 0, 178),
  [12261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [12263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [12265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [12267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [12269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [12271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [12273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [12275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2109),
  [12277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [12279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [12281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2019),
  [12283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [12285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [12287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [12289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1953),
  [12291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1977),
  [12293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 3, 0, 10),
  [12295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 3, 0, 10),
  [12297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [12299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [12301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [12303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [12305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [12307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 4, 0, 81),
  [12309] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 4, 0, 81),
  [12311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list, 5, 0, 80),
  [12313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_enumerator_list, 5, 0, 80),
  [12315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 5, 0, 130),
  [12317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 5, 0, 130),
  [12319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2090),
  [12321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [12323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [12325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [12327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1970),
  [12329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [12331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [12333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [12335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [12337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [12339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [12341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list, 4, 0, 80),
  [12343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_enumerator_list, 4, 0, 80),
  [12345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [12347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [12349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1945),
  [12351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [12353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [12355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [12357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0),
  [12359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [12361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [12363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [12365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [12367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [12369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [12371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [12373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [12375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [12377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3311),
  [12379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_type_parameter_declaration, 3, 0, 160),
  [12381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7440),
  [12383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8073),
  [12385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6584),
  [12387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1960),
  [12389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8127),
  [12391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8408),
  [12393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enumerator_list, 1, 0, 0),
  [12395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3404),
  [12397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [12399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [12401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [12403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [12405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [12407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [12409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [12411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8413),
  [12413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [12415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_access_specifier, 1, 0, 0),
  [12417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_specifier, 1, 0, 0),
  [12419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2100),
  [12421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8233),
  [12423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8211),
  [12425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8383),
  [12427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_qualifier, 1, 0, 0),
  [12429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [12431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8419),
  [12433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6389),
  [12435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2110),
  [12437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [12439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1943),
  [12441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [12443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [12445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_declarators, 2, 0, 89),
  [12447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_declarators, 2, 0, 89),
  [12449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [12451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [12453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8450),
  [12455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [12457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6438),
  [12459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [12461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 184), SHIFT_REPEAT(6557),
  [12464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 184),
  [12466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 184),
  [12468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 6),
  [12470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9409),
  [12472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [12474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [12476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [12478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8479),
  [12480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [12482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [12484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_declarators_repeat1, 2, 0, 117), SHIFT_REPEAT(6454),
  [12487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_definition_declarators_repeat1, 2, 0, 117),
  [12489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__type_definition_declarators_repeat1, 2, 0, 117),
  [12491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8510),
  [12493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_type_parameter_declaration, 4, 0, 195),
  [12495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3320),
  [12497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1925),
  [12499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [12501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6689),
  [12503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [12505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [12507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [12509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3313),
  [12511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [12513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [12515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [12517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [12519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8220),
  [12521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2404),
  [12523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [12525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6339),
  [12527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7590),
  [12529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2872),
  [12531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7610),
  [12533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7610),
  [12535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [12537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2823),
  [12539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4588),
  [12541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9510),
  [12543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7679),
  [12545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7679),
  [12547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2824),
  [12549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7539),
  [12551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7539),
  [12553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3389),
  [12555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4268),
  [12557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8345),
  [12559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8348),
  [12561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_specifier, 1, 0, 19),
  [12563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7480),
  [12565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2709),
  [12567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8351),
  [12569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2826),
  [12571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4453),
  [12573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7552),
  [12575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7552),
  [12577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4018),
  [12579] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_clobber_list_repeat1, 2, 0, 216), SHIFT_REPEAT(6728),
  [12582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_clobber_list_repeat1, 2, 0, 216),
  [12584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8410),
  [12586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8353),
  [12588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [12590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4272),
  [12592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7553),
  [12594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7553),
  [12596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [12598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8425),
  [12600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8532),
  [12602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3861),
  [12604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4469),
  [12606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4273),
  [12608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7465),
  [12610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [12612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2329),
  [12614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [12616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2736),
  [12618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7567),
  [12620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7567),
  [12622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2843),
  [12624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7574),
  [12626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7574),
  [12628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2714),
  [12630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [12632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enumerator_list, 2, 0, 0),
  [12634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enumerator_list_no_comma, 2, 0, 0),
  [12636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4037),
  [12638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7575),
  [12640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7575),
  [12642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2850),
  [12644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4039),
  [12646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [12648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7581),
  [12650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7581),
  [12652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4401),
  [12654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7653),
  [12656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7653),
  [12658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2669),
  [12660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [12662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8101),
  [12664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8722),
  [12666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2283),
  [12668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7602),
  [12670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7602),
  [12672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [12674] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_char_literal_repeat1, 2, 0, 0),
  [12676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_char_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(7590),
  [12679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3676),
  [12681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enumerator_list_no_comma, 1, 0, 0),
  [12683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7818),
  [12685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6496),
  [12687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 2, 0, 0),
  [12689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5414),
  [12691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [12693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [12695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8682),
  [12697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [12699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2274),
  [12701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3002),
  [12703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7615),
  [12705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7615),
  [12707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [12709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3303),
  [12711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
  [12713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(7610),
  [12716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(7610),
  [12719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3798),
  [12721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2968),
  [12723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_operator_cast_identifier, 2, 0, 34),
  [12725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4557),
  [12727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [12729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8550),
  [12731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8273),
  [12733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2557),
  [12735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7718),
  [12737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7718),
  [12739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2774),
  [12741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [12743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [12745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 93),
  [12747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8042),
  [12749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_declarator, 1, 0, 0),
  [12751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8013),
  [12753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 4, 0, 0),
  [12755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8232),
  [12757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8376),
  [12759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8181),
  [12761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 5, 0, 0),
  [12763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4477),
  [12765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7656),
  [12767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7656),
  [12769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3940),
  [12771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7686),
  [12773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7686),
  [12775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3132),
  [12777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7677),
  [12779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7677),
  [12781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2702),
  [12783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7536),
  [12785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7536),
  [12787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4417),
  [12789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5028),
  [12791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4432),
  [12793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3075),
  [12795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3354),
  [12797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8089),
  [12799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [12801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9127),
  [12803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3429),
  [12805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [12807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [12809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7292),
  [12811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand_list, 3, 0, 192),
  [12813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7296),
  [12815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand_list, 2, 0, 156),
  [12817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6383),
  [12819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7062),
  [12821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8386),
  [12823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8356),
  [12825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5401),
  [12827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3139),
  [12829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4854),
  [12831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8812),
  [12833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3937),
  [12835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3212),
  [12837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [12839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [12841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3110),
  [12843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6835),
  [12845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7708),
  [12847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7708),
  [12849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 3, 0, 5),
  [12851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_declaration_repeat1, 3, 0, 5),
  [12853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 3, 0, 199),
  [12855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_declaration_repeat1, 3, 0, 199),
  [12857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7447),
  [12859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3306),
  [12861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4761),
  [12863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6892),
  [12865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4087),
  [12867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3357),
  [12869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2562),
  [12871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2859),
  [12873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7523),
  [12875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7523),
  [12877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3403),
  [12879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2863),
  [12881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7724),
  [12883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7724),
  [12885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3467),
  [12887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2842),
  [12889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3432),
  [12891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7800),
  [12893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 3, 0, 0),
  [12895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7460),
  [12897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [12899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9267),
  [12901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [12903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3267),
  [12905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand_list, 2, 0, 156),
  [12907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4314),
  [12909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7740),
  [12911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7740),
  [12913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3200),
  [12915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3275),
  [12917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4303),
  [12919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [12921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8892),
  [12923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3281),
  [12925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2749),
  [12927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7629),
  [12929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7629),
  [12931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2822),
  [12933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7526),
  [12935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7526),
  [12937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [12939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2937),
  [12941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7752),
  [12943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7752),
  [12945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_output_operand_list_repeat1, 2, 0, 204), SHIFT_REPEAT(7292),
  [12948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_output_operand_list_repeat1, 2, 0, 204),
  [12950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [12952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9164),
  [12954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2955),
  [12956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand_list, 3, 0, 192),
  [12958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6728),
  [12960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_clobber_list, 2, 0, 205),
  [12962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2001),
  [12964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8877),
  [12966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_clobber_list, 3, 0, 212),
  [12968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_input_operand_list_repeat1, 2, 0, 204), SHIFT_REPEAT(7296),
  [12971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_input_operand_list_repeat1, 2, 0, 204),
  [12973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [12975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8222),
  [12977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6896),
  [12979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer_list, 2, 0, 0),
  [12981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8432),
  [12983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [12985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1740),
  [12987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3964),
  [12989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8447),
  [12991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3492),
  [12993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [12995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6273),
  [12997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [12999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7164),
  [13001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8405),
  [13003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [13005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8601),
  [13007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [13009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6197),
  [13011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4583),
  [13013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [13015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_goto_list_repeat1, 2, 0, 219), SHIFT_REPEAT(9026),
  [13018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_goto_list_repeat1, 2, 0, 219),
  [13020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [13022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9026),
  [13024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_goto_list, 2, 0, 213),
  [13026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6511),
  [13028] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_initializer_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6896),
  [13031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_initializer_list_repeat1, 2, 0, 0),
  [13033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [13035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6127),
  [13037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4566),
  [13039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4567),
  [13041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4568),
  [13043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6486),
  [13045] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subscript_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1119),
  [13048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9177),
  [13050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [13052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [13054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_designator, 2, 0, 97),
  [13056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3997),
  [13058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3474),
  [13060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8448),
  [13062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_type_parameter_declaration, 2, 0, 0),
  [13064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8504),
  [13066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1849),
  [13068] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_kernel_call_syntax_repeat1, 2, 0, 0), SHIFT_REPEAT(1404),
  [13071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8338),
  [13073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [13075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7239),
  [13077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [13079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8442),
  [13081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 2, 0, 0),
  [13083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [13085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2004),
  [13087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4259),
  [13089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8277),
  [13091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8294),
  [13093] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_structured_binding_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(9002),
  [13096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_structured_binding_declarator_repeat1, 2, 0, 0),
  [13098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2405),
  [13100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [13102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [13104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6542),
  [13106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7696),
  [13108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand, 7, 0, 220),
  [13110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [13112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6231),
  [13115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2086),
  [13117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7980),
  [13119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8559),
  [13121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [13123] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(6496),
  [13126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [13128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7135),
  [13130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5443),
  [13132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8438),
  [13134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7946),
  [13136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [13138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [13140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_params_repeat1, 2, 0, 0), SHIFT_REPEAT(8277),
  [13143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_params_repeat1, 2, 0, 0),
  [13145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [13147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6505),
  [13149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [13151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [13153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5457),
  [13155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [13157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7327),
  [13159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4312),
  [13161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3536),
  [13163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [13165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7090),
  [13167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4152),
  [13169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_declarator, 2, 0, 68),
  [13171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_declaration, 3, 0, 146),
  [13173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4233),
  [13175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7093),
  [13177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7027),
  [13179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [13181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8328),
  [13183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7030),
  [13185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7592),
  [13187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4322),
  [13189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2411),
  [13191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2330),
  [13193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4332),
  [13195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3996),
  [13197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [13199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [13201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [13203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2412),
  [13205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2710),
  [13207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [13209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [13211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [13213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2413),
  [13215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8827),
  [13217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8854),
  [13219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8924),
  [13221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [13223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [13225] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_throw_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(3341),
  [13228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_throw_specifier_repeat1, 2, 0, 0),
  [13230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [13232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5460),
  [13234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4244),
  [13236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8382),
  [13238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4250),
  [13240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4257),
  [13242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4720),
  [13244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand, 7, 0, 220),
  [13246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4026),
  [13248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5461),
  [13250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [13252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4110),
  [13254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4112),
  [13256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [13258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4179),
  [13260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [13262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6567),
  [13264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7340),
  [13266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4088),
  [13268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_generic_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(3421),
  [13271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_generic_expression_repeat1, 2, 0, 0),
  [13273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [13275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [13277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2, 0, 117), SHIFT_REPEAT(5799),
  [13280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2, 0, 117),
  [13282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [13284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4094),
  [13286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4098),
  [13288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4099),
  [13290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4242),
  [13292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6673),
  [13294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [13296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1683),
  [13298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4428),
  [13300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4293),
  [13302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand, 4, 0, 211),
  [13304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8373),
  [13306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [13308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7693),
  [13310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2293),
  [13312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7298),
  [13314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_clobber_list_repeat1, 2, 0, 205),
  [13316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2320),
  [13318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [13320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8857),
  [13322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [13324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7442),
  [13326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [13328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [13330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [13332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [13334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8581),
  [13336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8587),
  [13338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8611),
  [13340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [13342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [13344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4000),
  [13346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [13348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [13350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2729),
  [13352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7678),
  [13354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5440),
  [13356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3499),
  [13358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6588),
  [13360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4302),
  [13362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4390),
  [13364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4398),
  [13366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3846),
  [13368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [13370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4426),
  [13372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7522),
  [13374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4388),
  [13376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3897),
  [13378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [13380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [13382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [13384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [13386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9453),
  [13388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9465),
  [13390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9492),
  [13392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_goto_list, 3, 0, 217),
  [13394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4328),
  [13396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4334),
  [13398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [13400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7350),
  [13402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2174),
  [13404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [13406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [13408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [13410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [13412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4311),
  [13414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [13416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7676),
  [13418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4510),
  [13420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [13422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5456),
  [13424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8369),
  [13426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 5, 0, 0),
  [13428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [13430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9200),
  [13432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9204),
  [13434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9214),
  [13436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 3, 0),
  [13438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [13440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 7, 0, 0),
  [13442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [13444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [13446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [13448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6387),
  [13450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3832),
  [13452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(635),
  [13455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 0, 0),
  [13457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8304),
  [13459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7356),
  [13461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3109),
  [13463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7533),
  [13465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3086),
  [13467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [13469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3064),
  [13471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8763),
  [13473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8764),
  [13475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8766),
  [13477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8186),
  [13479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [13481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5470),
  [13483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8537),
  [13485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 3, 0, 0),
  [13487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5471),
  [13489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7445),
  [13491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7947),
  [13493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3111),
  [13495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [13497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3124),
  [13499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [13501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [13503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9129),
  [13505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9147),
  [13507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9280),
  [13509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7596),
  [13511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3125),
  [13513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [13515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [13517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5473),
  [13519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3899),
  [13521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7551),
  [13523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [13525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5474),
  [13527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7613),
  [13529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8432),
  [13532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attribute_declaration_repeat1, 2, 0, 0),
  [13534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7655),
  [13536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7707),
  [13538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7723),
  [13540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [13542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7737),
  [13544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_declarator, 2, 0, 0),
  [13546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4351),
  [13548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [13550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [13552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [13554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2992),
  [13556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2993),
  [13558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [13560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5478),
  [13562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4191),
  [13564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8223),
  [13566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3831),
  [13568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4028),
  [13570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3953),
  [13572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3847),
  [13574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4124),
  [13576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7348),
  [13578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [13580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4589),
  [13582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [13584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4590),
  [13586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4591),
  [13588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [13590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4592),
  [13592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4425),
  [13594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4419),
  [13596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_reference_declarator, 2, 0, 0),
  [13598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand, 4, 0, 211),
  [13600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8252),
  [13602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 2, 0, 102),
  [13604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [13606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1048),
  [13609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2695),
  [13611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [13613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [13615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer_list, 3, 0, 0),
  [13617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8255),
  [13619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 2, 0, 0),
  [13621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8422),
  [13623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4406),
  [13625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3849),
  [13627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3059),
  [13629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7325),
  [13631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4019),
  [13633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [13635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6215),
  [13637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4020),
  [13639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4022),
  [13641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7410),
  [13643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4023),
  [13645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_range_designator, 5, 0, 198),
  [13647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7815),
  [13649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8305),
  [13651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_input_operand_list_repeat1, 2, 0, 156),
  [13653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5428),
  [13655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [13657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3789),
  [13659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [13661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4049),
  [13663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [13665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2802),
  [13667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [13669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8090),
  [13671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [13673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [13675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [13677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [13679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7397),
  [13681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [13683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [13685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1969),
  [13687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8654),
  [13689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3768),
  [13691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4055),
  [13693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4056),
  [13695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [13697] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_lambda_capture_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(6567),
  [13700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_lambda_capture_specifier_repeat1, 2, 0, 0),
  [13702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [13704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [13706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4068),
  [13708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_parameter_declaration, 2, 0, 66),
  [13710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8539),
  [13712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7672),
  [13714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nested_namespace_specifier, 2, 0, 0),
  [13716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7476),
  [13718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5420),
  [13720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5421),
  [13722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5537),
  [13724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4408),
  [13726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [13728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [13730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [13732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7963),
  [13734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5445),
  [13736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5447),
  [13738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [13740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5452),
  [13742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5453),
  [13744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2220),
  [13746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1717),
  [13749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_parameter_list_repeat1, 2, 0, 0),
  [13751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [13753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_designator, 3, 0, 0),
  [13755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [13757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [13759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2065),
  [13761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [13763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9427),
  [13765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9432),
  [13767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9436),
  [13769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7971),
  [13771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [13773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2037),
  [13775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4111),
  [13777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3490),
  [13779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [13781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [13783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [13785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [13787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_specifier, 2, 0, 59),
  [13789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [13791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 6, 0, 0),
  [13793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8411),
  [13795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 4, 0, 0),
  [13797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3969),
  [13799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8501),
  [13801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [13803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [13805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [13807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4227),
  [13809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7762),
  [13811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_output_operand_list_repeat1, 2, 0, 156),
  [13813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3060),
  [13815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7839),
  [13817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [13819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [13821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [13823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requires_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1748),
  [13826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_requires_parameter_list_repeat1, 2, 0, 0),
  [13828] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_initializer_list_repeat1, 2, 0, 0), SHIFT_REPEAT(977),
  [13831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [13833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [13835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nested_namespace_specifier, 3, 0, 0),
  [13837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [13839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [13841] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1740),
  [13844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0),
  [13846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4509),
  [13848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4341),
  [13850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [13852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5434),
  [13854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [13856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8473),
  [13858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [13860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7428),
  [13862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [13864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7485),
  [13866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_pack_expansion, 2, 0, 28),
  [13868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [13870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6394),
  [13872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8922),
  [13874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 3, 0, 169),
  [13876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [13878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9146),
  [13880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8403),
  [13882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1983),
  [13884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8651),
  [13886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2016),
  [13888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8859),
  [13890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8311),
  [13892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8260),
  [13894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 3, 0, 102),
  [13896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 3, 0, 0),
  [13898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [13900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9519),
  [13902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [13904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [13906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8640),
  [13908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8292),
  [13910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6539),
  [13912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5036),
  [13914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8434),
  [13916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [13918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9162),
  [13920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [13922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_params, 3, 0, 0),
  [13924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 3, 0, 0),
  [13926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [13928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8614),
  [13930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [13932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier_parameter_pack_expansion, 2, 0, 28),
  [13934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_params, 4, 0, 0),
  [13936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 4, 0, 0),
  [13938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_params, 2, 0, 0),
  [13940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 2, 0, 0),
  [13942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8421),
  [13944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8241),
  [13946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [13948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8494),
  [13950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [13952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9399),
  [13954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [13956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [13958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [13960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8440),
  [13962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [13964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8370),
  [13966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8360),
  [13968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 6, 0, 0),
  [13970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [13972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8484),
  [13974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2118),
  [13976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4507),
  [13978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4867),
  [13980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2249),
  [13982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [13984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8457),
  [13986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [13988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [13990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2053),
  [13992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9477),
  [13994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 2, 0, 6),
  [13996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 2, 0),
  [13998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [14000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9017),
  [14002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_type_parameter_declaration, 3, 0, 159),
  [14004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [14006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [14008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9317),
  [14010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4816),
  [14012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [14014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8322),
  [14016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_template_parameter_declaration, 3, 0, 57),
  [14018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8289),
  [14020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9241),
  [14022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9228),
  [14024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [14026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 4, 0, 93),
  [14028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [14030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9283),
  [14032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_goto_list_repeat1, 2, 0, 213),
  [14034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3252),
  [14036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8418),
  [14038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6353),
  [14040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8876),
  [14042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [14044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9431),
  [14046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8275),
  [14048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9014),
  [14050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9509),
  [14052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3491),
  [14054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1958),
  [14056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9223),
  [14058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8297),
  [14060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9227),
  [14062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9512),
  [14064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9256),
  [14066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9515),
  [14068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9276),
  [14070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9518),
  [14072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9295),
  [14074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9521),
  [14076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7779),
  [14078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_goto_list, 1, 0, 0),
  [14080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9314),
  [14082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9524),
  [14084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9330),
  [14086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9527),
  [14088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9343),
  [14090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9529),
  [14092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9349),
  [14094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9530),
  [14096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9354),
  [14098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9531),
  [14100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9359),
  [14102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9532),
  [14104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9362),
  [14106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9533),
  [14108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9365),
  [14110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9534),
  [14112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9367),
  [14114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9535),
  [14116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9369),
  [14118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9536),
  [14120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9371),
  [14122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9537),
  [14124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9373),
  [14126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9538),
  [14128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9375),
  [14130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9539),
  [14132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9377),
  [14134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9540),
  [14136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9379),
  [14138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9541),
  [14140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9139),
  [14142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [14144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [14146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [14148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [14150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4149),
  [14152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list_no_comma, 4, 0, 81),
  [14154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8851),
  [14156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [14158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2854),
  [14160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_parameter_list, 2, 0, 0),
  [14162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [14164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [14166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [14168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_parameter_list, 3, 0, 0),
  [14170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [14172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7089),
  [14174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8631),
  [14176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8633),
  [14178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4258),
  [14180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7409),
  [14182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [14184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [14186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [14188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_based_modifier, 2, 0, 0),
  [14190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [14192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [14194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4836),
  [14196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5045),
  [14198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [14200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4089),
  [14202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [14204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list_no_comma, 6, 0, 178),
  [14206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7074),
  [14208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [14210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [14212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [14214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [14216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [14218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [14220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4407),
  [14222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [14224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(9217),
  [14227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [14229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [14231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6278),
  [14233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9218),
  [14235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7582),
  [14237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [14239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [14241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [14243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [14245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8878),
  [14247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [14249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4216),
  [14251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9100),
  [14253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kernel_call_syntax, 4, 0, 0),
  [14255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list_no_comma, 4, 0, 10),
  [14257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8618),
  [14259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2966),
  [14261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9145),
  [14263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [14265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [14267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [14269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [14271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [14273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3459),
  [14275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [14277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3274),
  [14279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2703),
  [14281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7097),
  [14283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9184),
  [14285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [14287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [14289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [14291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8746),
  [14293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [14295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [14297] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [14299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [14301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [14303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [14305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8816),
  [14307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [14309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [14311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8999),
  [14313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [14315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4622),
  [14317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [14319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8704),
  [14321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [14323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [14325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [14327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [14329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [14331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9250),
  [14333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [14335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [14337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4077),
  [14339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9327),
  [14341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9332),
  [14343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [14345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1939),
  [14347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4348),
  [14349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [14351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8174),
  [14353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [14355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4379),
  [14357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4366),
  [14359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [14361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [14363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4146),
  [14365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [14367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [14369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [14371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7741),
  [14373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [14375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8940),
  [14377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5011),
  [14379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8667),
  [14381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9457),
  [14383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4147),
  [14385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3895),
  [14387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [14389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2932),
  [14391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [14393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [14395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [14397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8742),
  [14399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [14401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2707),
  [14403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4140),
  [14405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [14407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4327),
  [14409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [14411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9546),
  [14413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2035),
  [14415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4298),
  [14417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [14419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4420),
  [14421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4338),
  [14423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2355),
  [14425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8635),
  [14427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4078),
  [14429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [14431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [14433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [14435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8674),
  [14437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [14439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [14441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8911),
  [14443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [14445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [14447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2367),
  [14449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [14451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [14453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3005),
  [14455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8731),
  [14457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [14459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2965),
  [14461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [14463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8753),
  [14465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8758),
  [14467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [14469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7659),
  [14471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [14473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9234),
  [14475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [14477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8889),
  [14479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9048),
  [14481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [14483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2954),
  [14485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8617),
  [14487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [14489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [14491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [14493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9387),
  [14495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5439),
  [14497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9224),
  [14499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [14501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4240),
  [14503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [14505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list, 5, 0, 178),
  [14507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9414),
  [14509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [14511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list_no_comma, 5, 0, 178),
  [14513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9513),
  [14515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3560),
  [14517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [14519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [14521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6828),
  [14523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [14525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [14527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9054),
  [14529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [14531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4893),
  [14533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3009),
  [14535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [14537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [14539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8879),
  [14541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9036),
  [14543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2862),
  [14545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7755),
  [14547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [14549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [14551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [14553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [14555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [14557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [14559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [14561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [14563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [14565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [14567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4027),
  [14569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1771),
  [14571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6527),
  [14573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [14575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4113),
  [14577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8770),
  [14579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8806),
  [14581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6834),
  [14583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [14585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_field_declaration_list, 4, 0, 130),
  [14587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9034),
  [14589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [14591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8641),
  [14593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [14595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9195),
  [14597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [14599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9082),
  [14601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [14603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [14605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4127),
  [14607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list_no_comma, 4, 0, 130),
  [14609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4894),
  [14611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8629),
  [14613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9191),
  [14615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3783),
  [14617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [14619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4896),
  [14621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [14623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4370),
  [14625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9269),
  [14627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9279),
  [14629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [14631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4371),
  [14633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [14635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8996),
  [14637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [14639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8997),
  [14641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [14643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8657),
  [14645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3254),
  [14647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8759),
  [14649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7949),
  [14651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [14653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9105),
  [14655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8788),
  [14657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8821),
  [14659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [14661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8843),
  [14663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [14665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [14667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9175),
  [14669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4541),
  [14671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [14673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [14675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9225),
  [14677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [14679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [14681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9389),
  [14683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [14685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9461),
  [14687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [14689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9329),
  [14691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [14693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8754),
  [14695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8836),
  [14697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [14699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8871),
  [14701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3264),
  [14703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8748),
  [14705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9502),
  [14707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8596),
  [14709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8598),
  [14711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [14713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8707),
  [14715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8725),
  [14717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8732),
  [14719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [14721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8793),
  [14723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8797),
  [14725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_field_declaration_list, 5, 0, 178),
  [14727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1784),
  [14729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8844),
  [14731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8848),
  [14733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8893),
  [14735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8898),
  [14737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8986),
  [14739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8989),
  [14741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9056),
  [14743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9057),
  [14745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9087),
  [14747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9089),
  [14749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9137),
  [14751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [14753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9150),
  [14755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9156),
  [14757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9178),
  [14759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9179),
  [14761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2223),
  [14763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [14765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [14767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8531),
  [14769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_field_declaration_list, 4, 0, 129),
  [14771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9339),
  [14773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [14775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [14777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [14779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [14781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [14783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2815),
  [14785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [14787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4144),
  [14789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [14791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [14793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [14795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [14797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3088),
  [14799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [14801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7791),
  [14803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8491),
  [14805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [14807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [14809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8221),
  [14811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [14813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8943),
  [14815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [14817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6208),
  [14819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6209),
  [14821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [14823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [14825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9312),
  [14827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [14829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [14831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [14833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4134),
  [14835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8261),
  [14837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list, 4, 0, 129),
  [14839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [14841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [14843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6210),
  [14845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8511),
  [14847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [14849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7687),
  [14851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8802),
  [14853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [14855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [14857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [14859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4178),
  [14861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5490),
  [14863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [14865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3850),
  [14867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5513),
  [14869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8903),
  [14871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5514),
  [14873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [14875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4106),
  [14877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7432),
  [14879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [14881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9421),
  [14883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [14885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4119),
  [14887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [14889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5437),
  [14891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2818),
  [14893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [14895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9430),
  [14897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [14899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [14901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3989),
  [14903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [14905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 4, 0, 129),
  [14907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [14909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [14911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6476),
  [14913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [14915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6478),
  [14917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7978),
  [14919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [14921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [14923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [14925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4468),
  [14927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [14929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6479),
  [14931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [14933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4289),
  [14935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4264),
  [14937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [14939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7532),
  [14941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef, 4, 0, 130),
  [14943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [14945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3797),
  [14947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4295),
  [14949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [14951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8869),
  [14953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4335),
  [14955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [14957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7730),
  [14959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [14961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [14963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5172),
  [14965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list, 4, 0, 130),
  [14967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [14969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 5, 0, 178),
  [14971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [14973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [14975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8935),
  [14977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [14979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [14981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9095),
  [14983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list_no_comma, 4, 0, 129),
  [14985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2575),
  [14987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2732),
  [14989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1979),
  [14991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2733),
  [14993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4404),
  [14995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6713),
  [14997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [14999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [15001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3369),
  [15003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [15005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [15007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list_no_comma, 5, 0, 129),
  [15009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3859),
  [15011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [15013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7387),
  [15015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list_no_comma, 5, 0, 80),
  [15017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8625),
  [15019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4035),
  [15021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7751),
  [15023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [15025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list, 3, 0, 81),
  [15027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6711),
  [15029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [15031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list_no_comma, 3, 0, 81),
  [15033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [15035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [15037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [15039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4317),
  [15041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [15043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [15045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [15047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5543),
  [15049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6374),
  [15051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4355),
  [15053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_parameter_list, 4, 0, 0),
  [15055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2660),
  [15057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2664),
  [15059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3959),
  [15061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8245),
  [15063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [15065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list_no_comma, 5, 0, 130),
  [15067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [15069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kernel_call_syntax, 3, 0, 0),
  [15071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [15073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2505),
  [15075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [15077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4188),
  [15079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3576),
  [15081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9270),
  [15083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [15085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2731),
  [15087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7598),
  [15089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [15091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [15093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1923),
  [15095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8326),
  [15097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [15099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [15101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_field_declaration_list, 3, 0, 81),
  [15103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3289),
  [15105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [15107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [15109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [15111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [15113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7407),
  [15115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unary_right_fold, 3, 0, 54),
  [15117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8337),
  [15119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9488),
  [15121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4410),
  [15123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [15125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9180),
  [15127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9192),
  [15129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [15131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9504),
  [15133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9128),
  [15135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4168),
  [15137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8594),
  [15139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [15141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [15143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8606),
  [15145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [15147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7983),
  [15149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8741),
  [15151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8371),
  [15153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [15155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3336),
  [15157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [15159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [15161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [15163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8380),
  [15165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5477),
  [15167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8694),
  [15169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [15171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9494),
  [15173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1947),
  [15175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [15177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8701),
  [15179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8713),
  [15181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4367),
  [15183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8721),
  [15185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [15187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8592),
  [15189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8400),
  [15191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [15193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3370),
  [15195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [15197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [15199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [15201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [15203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8404),
  [15205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8773),
  [15207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [15209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2741),
  [15211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [15213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8779),
  [15215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8789),
  [15217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2957),
  [15219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4471),
  [15221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [15223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8796),
  [15225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [15227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [15229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8416),
  [15231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [15233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3410),
  [15235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [15237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [15239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [15241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8825),
  [15243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4346),
  [15245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2564),
  [15247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [15249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8831),
  [15251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8840),
  [15253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [15255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8847),
  [15257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [15259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [15261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8431),
  [15263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [15265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3443),
  [15267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5476),
  [15269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [15271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1961),
  [15273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1973),
  [15275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8874),
  [15277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5084),
  [15279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8787),
  [15281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [15283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8880),
  [15285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8888),
  [15287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [15289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [15291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8895),
  [15293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [15295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [15297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8445),
  [15299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [15301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [15303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [15305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [15307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8908),
  [15309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9096),
  [15311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8912),
  [15313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8914),
  [15315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3119),
  [15317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8917),
  [15319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [15321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8452),
  [15323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [15325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8785),
  [15327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [15329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [15331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8930),
  [15333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5479),
  [15335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8933),
  [15337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8455),
  [15339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [15341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [15343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8939),
  [15345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8941),
  [15347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8458),
  [15349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [15351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [15353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8947),
  [15355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8948),
  [15357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8459),
  [15359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [15361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [15363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8954),
  [15365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8955),
  [15367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [15369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8958),
  [15371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8959),
  [15373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [15375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8962),
  [15377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8963),
  [15379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8964),
  [15381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8965),
  [15383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8966),
  [15385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8967),
  [15387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8968),
  [15389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8969),
  [15391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8970),
  [15393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8971),
  [15395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8972),
  [15397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8580),
  [15399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8974),
  [15401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8975),
  [15403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8976),
  [15405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8977),
  [15407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5451),
  [15409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [15411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [15413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9013),
  [15415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [15417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1914),
  [15419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4451),
  [15421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [15423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [15425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1965),
  [15427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7664),
  [15429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9044),
  [15431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [15433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [15435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [15437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [15439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4008),
  [15441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4009),
  [15443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4010),
  [15445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [15447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [15449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7638),
  [15451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5454),
  [15453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [15455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5426),
  [15457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4014),
  [15459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [15461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [15463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [15465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3440),
  [15467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8978),
  [15469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [15471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8576),
  [15473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8662),
  [15475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [15477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [15479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5418),
  [15481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7400),
  [15483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [15485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [15487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [15489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [15491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9226),
  [15493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [15495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7706),
  [15497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9238),
  [15499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3684),
  [15501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [15503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [15505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [15507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [15509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9255),
  [15511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [15513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7713),
  [15515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9261),
  [15517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [15519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [15521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [15523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [15525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9275),
  [15527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2496),
  [15529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7721),
  [15531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9281),
  [15533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4480),
  [15535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3340),
  [15537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [15539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9294),
  [15541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [15543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [15545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7727),
  [15547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9300),
  [15549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4060),
  [15551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [15553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9313),
  [15555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [15557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [15559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7733),
  [15561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9319),
  [15563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3723),
  [15565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [15567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4339),
  [15569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7739),
  [15571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9334),
  [15573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9086),
  [15575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3860),
  [15577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9345),
  [15579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [15581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9350),
  [15583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [15585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9355),
  [15587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9274),
  [15589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9360),
  [15591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [15593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9363),
  [15595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [15597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9366),
  [15599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [15601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9368),
  [15603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [15605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9370),
  [15607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [15609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9372),
  [15611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9073),
  [15613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9374),
  [15615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9472),
  [15617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9376),
  [15619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9189),
  [15621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9378),
  [15623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7379),
  [15625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9380),
  [15627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [15629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9397),
  [15631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3420),
  [15633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9440),
  [15635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2273),
  [15637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3426),
  [15639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9451),
  [15641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9481),
  [15643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3430),
  [15645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9460),
  [15647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [15649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3433),
  [15651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9468),
  [15653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9148),
  [15655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3435),
  [15657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9475),
  [15659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [15661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [15663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9480),
  [15665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4072),
  [15667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9483),
  [15669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9485),
  [15671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9487),
  [15673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9489),
  [15675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9491),
  [15677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9493),
  [15679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9495),
  [15681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9497),
  [15683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9499),
  [15685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9501),
  [15687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9503),
  [15689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9505),
  [15691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9507),
  [15693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef, 3, 0, 81),
  [15695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [15697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3090),
  [15699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9293),
  [15701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1976),
  [15703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [15705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [15707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [15709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [15711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [15713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [15715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [15717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_raw_string_delimiter = 0,
  ts_external_token_raw_string_content = 1,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_raw_string_delimiter] = sym_raw_string_delimiter,
  [ts_external_token_raw_string_content] = sym_raw_string_content,
};

static const bool ts_external_scanner_states[4][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_raw_string_delimiter] = true,
    [ts_external_token_raw_string_content] = true,
  },
  [2] = {
    [ts_external_token_raw_string_delimiter] = true,
  },
  [3] = {
    [ts_external_token_raw_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_cuda_external_scanner_create(void);
void tree_sitter_cuda_external_scanner_destroy(void *);
bool tree_sitter_cuda_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_cuda_external_scanner_serialize(void *, char *);
void tree_sitter_cuda_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_cuda(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .supertype_map_slices = ts_supertype_map_slices,
    .supertype_map_entries = ts_supertype_map_entries,
    .supertype_symbols = ts_supertype_symbols,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_cuda_external_scanner_create,
      tree_sitter_cuda_external_scanner_destroy,
      tree_sitter_cuda_external_scanner_scan,
      tree_sitter_cuda_external_scanner_serialize,
      tree_sitter_cuda_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "cuda",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 21,
      .patch_version = 1,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
